# coding: utf8
from __future__ import unicode_literals


LOOKUP = {
    "Abris": "abril",
    "Agostos": "agosto",
    "Cérberos": "cérbero",
    "Dezembros": "dezembro",
    "Fevereiros": "fevereiro",
    "Janeiros": "janeiro",
    "Julhos": "julho",
    "Junhos": "junho",
    "Martes": "marte",
    "Marços": "março",
    "Novembros": "novembro",
    "Outubros": "outubro",
    "Portuguesas": "portuguesa",
    "Pradiais": "pradial",
    "Setembros": "setembro",
    "a": "o",
    "aa": "a",
    "aacheniana": "aacheniano",
    "aachenianas": "aacheniano",
    "aachenianos": "aacheniano",
    "aais": "aal",
    "aaleniana": "aaleniano",
    "aalenianas": "aaleniano",
    "aalenianos": "aaleniano",
    "aba": "abar",
    "ababalha": "ababalhar",
    "ababalhada": "ababalhar",
    "ababalhadas": "ababalhar",
    "ababalhado": "ababalhar",
    "ababalhados": "ababalhar",
    "ababalhai": "ababalhar",
    "ababalhais": "ababalhar",
    "ababalham": "ababalhar",
    "ababalhamentos": "ababalhamento",
    "ababalhamo": "ababalhar",
    "ababalhamos": "ababalhar",
    "ababalhando": "ababalhar",
    "ababalhara": "ababalhar",
    "ababalharam": "ababalhar",
    "ababalharas": "ababalhar",
    "ababalharde": "ababalhar",
    "ababalhardes": "ababalhar",
    "ababalhare": "ababalhar",
    "ababalharei": "ababalhar",
    "ababalhareis": "ababalhar",
    "ababalharem": "ababalhar",
    "ababalharemos": "ababalhar",
    "ababalhares": "ababalhar",
    "ababalharia": "ababalhar",
    "ababalhariam": "ababalhar",
    "ababalharias": "ababalhar",
    "ababalharmo": "ababalhar",
    "ababalharmos": "ababalhar",
    "ababalhará": "ababalhar",
    "ababalharás": "ababalhar",
    "ababalharão": "ababalhar",
    "ababalharíamos": "ababalhar",
    "ababalharíeis": "ababalhar",
    "ababalhas": "ababalhar",
    "ababalhasse": "ababalhar",
    "ababalhassem": "ababalhar",
    "ababalhasses": "ababalhar",
    "ababalhaste": "ababalhar",
    "ababalhastes": "ababalhar",
    "ababalhava": "ababalhar",
    "ababalhavam": "ababalhar",
    "ababalhavas": "ababalhar",
    "ababalhe": "ababalhar",
    "ababalhei": "ababalhar",
    "ababalheis": "ababalhar",
    "ababalhem": "ababalhar",
    "ababalhemo": "ababalhar",
    "ababalhemos": "ababalhar",
    "ababalhes": "ababalhar",
    "ababalho": "ababalhar",
    "ababalhou": "ababalhar",
    "ababalhá": "ababalhar",
    "ababalhámo": "ababalhar",
    "ababalhámos": "ababalhar",
    "ababalháramo": "ababalhar",
    "ababalháramos": "ababalhar",
    "ababalhárei": "ababalhar",
    "ababalháreis": "ababalhar",
    "ababalhásseis": "ababalhar",
    "ababalhássemos": "ababalhar",
    "ababalhávamo": "ababalhar",
    "ababalhávamos": "ababalhar",
    "ababalhávei": "ababalhar",
    "ababalháveis": "ababalhável",
    "ababosa": "ababosar",
    "ababosada": "ababosar",
    "ababosadas": "ababosar",
    "ababosado": "ababosar",
    "ababosados": "ababosar",
    "ababosai": "ababosar",
    "ababosais": "ababosar",
    "ababosam": "ababosar",
    "ababosamentos": "ababosamento",
    "ababosamo": "ababosar",
    "ababosamos": "ababosar",
    "ababosando": "ababosar",
    "ababosara": "ababosar",
    "ababosaram": "ababosar",
    "ababosaras": "ababosar",
    "ababosarde": "ababosar",
    "ababosardes": "ababosar",
    "ababosare": "ababosar",
    "ababosarei": "ababosar",
    "ababosareis": "ababosar",
    "ababosarem": "ababosar",
    "ababosaremos": "ababosar",
    "ababosares": "ababosar",
    "ababosaria": "ababosar",
    "ababosariam": "ababosar",
    "ababosarias": "ababosar",
    "ababosarmo": "ababosar",
    "ababosarmos": "ababosar",
    "ababosará": "ababosar",
    "ababosarás": "ababosar",
    "ababosarão": "ababosar",
    "ababosaríamos": "ababosar",
    "ababosaríeis": "ababosar",
    "ababosas": "ababosar",
    "ababosasse": "ababosar",
    "ababosassem": "ababosar",
    "ababosasses": "ababosar",
    "ababosaste": "ababosar",
    "ababosastes": "ababosar",
    "ababosava": "ababosar",
    "ababosavam": "ababosar",
    "ababosavas": "ababosar",
    "ababose": "ababosar",
    "ababosei": "ababosar",
    "ababoseis": "ababosar",
    "ababosem": "ababosar",
    "ababosemo": "ababosar",
    "ababosemos": "ababosar",
    "ababoses": "ababosar",
    "ababoso": "ababosar",
    "ababosou": "ababosar",
    "ababosá": "ababosar",
    "ababosámo": "ababosar",
    "ababosámos": "ababosar",
    "ababosáramo": "ababosar",
    "ababosáramos": "ababosar",
    "ababosárei": "ababosar",
    "ababosáreis": "ababosar",
    "ababosásseis": "ababosar",
    "ababosássemos": "ababosar",
    "ababosávamo": "ababosar",
    "ababosávamos": "ababosar",
    "ababosávei": "ababosar",
    "ababosáveis": "ababosável",
    "ababás": "ababá",
    "abacatadas": "abacatada",
    "abacateiras": "abacateira",
    "abacateiros": "abacateiro",
    "abacateranas": "abacaterana",
    "abacates": "abacate",
    "abacaxis": "abacaxi",
    "abacela": "abacelar",
    "abacelada": "abacelar",
    "abaceladas": "abacelar",
    "abacelado": "abacelar",
    "abacelados": "abacelar",
    "abacelai": "abacelar",
    "abacelais": "abacelar",
    "abacelam": "abacelar",
    "abacelamentos": "abacelamento",
    "abacelamo": "abacelar",
    "abacelamos": "abacelar",
    "abacelando": "abacelar",
    "abacelara": "abacelar",
    "abacelaram": "abacelar",
    "abacelaras": "abacelar",
    "abacelarde": "abacelar",
    "abacelardes": "abacelar",
    "abacelare": "abacelar",
    "abacelarei": "abacelar",
    "abacelareis": "abacelar",
    "abacelarem": "abacelar",
    "abacelaremos": "abacelar",
    "abacelares": "abacelar",
    "abacelaria": "abacelar",
    "abacelariam": "abacelar",
    "abacelarias": "abacelar",
    "abacelarmo": "abacelar",
    "abacelarmos": "abacelar",
    "abacelará": "abacelar",
    "abacelarás": "abacelar",
    "abacelarão": "abacelar",
    "abacelaríamos": "abacelar",
    "abacelaríeis": "abacelar",
    "abacelas": "abacelar",
    "abacelasse": "abacelar",
    "abacelassem": "abacelar",
    "abacelasses": "abacelar",
    "abacelaste": "abacelar",
    "abacelastes": "abacelar",
    "abacelava": "abacelar",
    "abacelavam": "abacelar",
    "abacelavas": "abacelar",
    "abacele": "abacelar",
    "abacelei": "abacelar",
    "abaceleis": "abacelar",
    "abacelem": "abacelar",
    "abacelemo": "abacelar",
    "abacelemos": "abacelar",
    "abaceles": "abacelar",
    "abacelo": "abacelar",
    "abacelou": "abacelar",
    "abacelá": "abacelar",
    "abacelámo": "abacelar",
    "abacelámos": "abacelar",
    "abaceláramo": "abacelar",
    "abaceláramos": "abacelar",
    "abacelárei": "abacelar",
    "abaceláreis": "abacelar",
    "abacelásseis": "abacelar",
    "abacelássemos": "abacelar",
    "abacelávamo": "abacelar",
    "abacelávamos": "abacelar",
    "abacelávei": "abacelar",
    "abaceláveis": "abacelável",
    "abaciais": "abacial",
    "abacina": "abacinar",
    "abacinada": "abacinar",
    "abacinadas": "abacinar",
    "abacinado": "abacinar",
    "abacinados": "abacinar",
    "abacinai": "abacinar",
    "abacinais": "abacinar",
    "abacinam": "abacinar",
    "abacinamentos": "abacinamento",
    "abacinamo": "abacinar",
    "abacinamos": "abacinar",
    "abacinando": "abacinar",
    "abacinara": "abacinar",
    "abacinaram": "abacinar",
    "abacinaras": "abacinar",
    "abacinarde": "abacinar",
    "abacinardes": "abacinar",
    "abacinare": "abacinar",
    "abacinarei": "abacinar",
    "abacinareis": "abacinar",
    "abacinarem": "abacinar",
    "abacinaremos": "abacinar",
    "abacinares": "abacinar",
    "abacinaria": "abacinar",
    "abacinariam": "abacinar",
    "abacinarias": "abacinar",
    "abacinarmo": "abacinar",
    "abacinarmos": "abacinar",
    "abacinará": "abacinar",
    "abacinarás": "abacinar",
    "abacinarão": "abacinar",
    "abacinaríamos": "abacinar",
    "abacinaríeis": "abacinar",
    "abacinas": "abacinar",
    "abacinasse": "abacinar",
    "abacinassem": "abacinar",
    "abacinasses": "abacinar",
    "abacinaste": "abacinar",
    "abacinastes": "abacinar",
    "abacinava": "abacinar",
    "abacinavam": "abacinar",
    "abacinavas": "abacinar",
    "abacine": "abacinar",
    "abacinei": "abacinar",
    "abacineis": "abacinar",
    "abacinem": "abacinar",
    "abacinemo": "abacinar",
    "abacinemos": "abacinar",
    "abacines": "abacinar",
    "abacino": "abacinar",
    "abacinou": "abacinar",
    "abaciná": "abacinar",
    "abacinámo": "abacinar",
    "abacinámos": "abacinar",
    "abacináramo": "abacinar",
    "abacináramos": "abacinar",
    "abacinárei": "abacinar",
    "abacináreis": "abacinar",
    "abacinásseis": "abacinar",
    "abacinássemos": "abacinar",
    "abacinávamo": "abacinar",
    "abacinávamos": "abacinar",
    "abacinávei": "abacinar",
    "abacináveis": "abacinável",
    "abacistas": "abacista",
    "abactora": "abactor",
    "abactoras": "abactor",
    "abactores": "abactor",
    "abactos": "abacto",
    "abacás": "abacá",
    "abada": "abar",
    "abadada": "abadar",
    "abadadas": "abadar",
    "abadado": "abadar",
    "abadados": "abadar",
    "abadai": "abadar",
    "abadais": "abadar",
    "abadam": "abadar",
    "abadamo": "abadar",
    "abadamos": "abadar",
    "abadando": "abadar",
    "abadara": "abadar",
    "abadaram": "abadar",
    "abadaras": "abadar",
    "abadarde": "abadar",
    "abadardes": "abadar",
    "abadare": "abadar",
    "abadarei": "abadar",
    "abadareis": "abadar",
    "abadarem": "abadar",
    "abadaremos": "abadar",
    "abadares": "abadar",
    "abadaria": "abadar",
    "abadariam": "abadar",
    "abadarias": "abadar",
    "abadarmo": "abadar",
    "abadarmos": "abadar",
    "abadará": "abadar",
    "abadarás": "abadar",
    "abadarão": "abadar",
    "abadaríamos": "abadar",
    "abadaríeis": "abadar",
    "abadas": "abar",
    "abadasse": "abadar",
    "abadassem": "abadar",
    "abadasses": "abadar",
    "abadaste": "abadar",
    "abadastes": "abadar",
    "abadava": "abadar",
    "abadavam": "abadar",
    "abadavas": "abadar",
    "abade": "abadar",
    "abadei": "abadar",
    "abadeis": "abadar",
    "abadejos": "abadejo",
    "abadem": "abadar",
    "abademo": "abadar",
    "abademos": "abadar",
    "abadenga": "abadengo",
    "abadengas": "abadengo",
    "abadengos": "abadengo",
    "abaderna": "abadernar",
    "abadernada": "abadernar",
    "abadernadas": "abadernar",
    "abadernado": "abadernar",
    "abadernados": "abadernar",
    "abadernai": "abadernar",
    "abadernais": "abadernar",
    "abadernam": "abadernar",
    "abadernamentos": "abadernamento",
    "abadernamo": "abadernar",
    "abadernamos": "abadernar",
    "abadernando": "abadernar",
    "abadernara": "abadernar",
    "abadernaram": "abadernar",
    "abadernaras": "abadernar",
    "abadernarde": "abadernar",
    "abadernardes": "abadernar",
    "abadernare": "abadernar",
    "abadernarei": "abadernar",
    "abadernareis": "abadernar",
    "abadernarem": "abadernar",
    "abadernaremos": "abadernar",
    "abadernares": "abadernar",
    "abadernaria": "abadernar",
    "abadernariam": "abadernar",
    "abadernarias": "abadernar",
    "abadernarmo": "abadernar",
    "abadernarmos": "abadernar",
    "abadernará": "abadernar",
    "abadernarás": "abadernar",
    "abadernarão": "abadernar",
    "abadernaríamos": "abadernar",
    "abadernaríeis": "abadernar",
    "abadernas": "abadernar",
    "abadernasse": "abadernar",
    "abadernassem": "abadernar",
    "abadernasses": "abadernar",
    "abadernaste": "abadernar",
    "abadernastes": "abadernar",
    "abadernava": "abadernar",
    "abadernavam": "abadernar",
    "abadernavas": "abadernar",
    "abaderne": "abadernar",
    "abadernei": "abadernar",
    "abaderneis": "abadernar",
    "abadernem": "abadernar",
    "abadernemo": "abadernar",
    "abadernemos": "abadernar",
    "abadernes": "abadernar",
    "abaderno": "abadernar",
    "abadernou": "abadernar",
    "abaderná": "abadernar",
    "abadernámo": "abadernar",
    "abadernámos": "abadernar",
    "abadernáramo": "abadernar",
    "abadernáramos": "abadernar",
    "abadernárei": "abadernar",
    "abadernáreis": "abadernar",
    "abadernásseis": "abadernar",
    "abadernássemos": "abadernar",
    "abadernávamo": "abadernar",
    "abadernávamos": "abadernar",
    "abadernávei": "abadernar",
    "abadernáveis": "abadernável",
    "abades": "abade",
    "abadesca": "abadesco",
    "abadescas": "abadesco",
    "abadescos": "abadesco",
    "abadessa": "abadessar",
    "abadessada": "abadessar",
    "abadessadas": "abadessar",
    "abadessado": "abadessar",
    "abadessados": "abadessar",
    "abadessai": "abadessar",
    "abadessais": "abadessar",
    "abadessam": "abadessar",
    "abadessamo": "abadessar",
    "abadessamos": "abadessar",
    "abadessando": "abadessar",
    "abadessara": "abadessar",
    "abadessaram": "abadessar",
    "abadessaras": "abadessar",
    "abadessarde": "abadessar",
    "abadessardes": "abadessar",
    "abadessare": "abadessar",
    "abadessarei": "abadessar",
    "abadessareis": "abadessar",
    "abadessarem": "abadessar",
    "abadessaremos": "abadessar",
    "abadessares": "abadessar",
    "abadessaria": "abadessar",
    "abadessariam": "abadessar",
    "abadessarias": "abadessar",
    "abadessarmo": "abadessar",
    "abadessarmos": "abadessar",
    "abadessará": "abadessar",
    "abadessarás": "abadessar",
    "abadessarão": "abadessar",
    "abadessaríamos": "abadessar",
    "abadessaríeis": "abadessar",
    "abadessas": "abadessar",
    "abadessasse": "abadessar",
    "abadessassem": "abadessar",
    "abadessasses": "abadessar",
    "abadessaste": "abadessar",
    "abadessastes": "abadessar",
    "abadessava": "abadessar",
    "abadessavam": "abadessar",
    "abadessavas": "abadessar",
    "abadessazinha": "abade",
    "abadessazinhas": "abade",
    "abadessazita": "abade",
    "abadessazitas": "abade",
    "abadesse": "abadessar",
    "abadessei": "abadessar",
    "abadesseis": "abadessar",
    "abadessem": "abadessar",
    "abadessemo": "abadessar",
    "abadessemos": "abadessar",
    "abadesses": "abadessar",
    "abadesso": "abadessar",
    "abadessou": "abadessar",
    "abadessá": "abadessar",
    "abadessámo": "abadessar",
    "abadessámos": "abadessar",
    "abadessáramo": "abadessar",
    "abadessáramos": "abadessar",
    "abadessárei": "abadessar",
    "abadessáreis": "abadessar",
    "abadessásseis": "abadessar",
    "abadessássemos": "abadessar",
    "abadessávamo": "abadessar",
    "abadessávamos": "abadessar",
    "abadessávei": "abadessar",
    "abadessáveis": "abadessável",
    "abadezinho": "abade",
    "abadezinhos": "abade",
    "abadezito": "abade",
    "abadezitos": "abade",
    "abadia": "abadiar",
    "abadiada": "abadiar",
    "abadiadas": "abadiar",
    "abadiado": "abadiar",
    "abadiados": "abadiar",
    "abadiai": "abadiar",
    "abadiais": "abadiar",
    "abadiam": "abadiar",
    "abadiamentos": "abadiamento",
    "abadiamo": "abadiar",
    "abadiamos": "abadiar",
    "abadiando": "abadiar",
    "abadiara": "abadiar",
    "abadiaram": "abadiar",
    "abadiaras": "abadiar",
    "abadiarde": "abadiar",
    "abadiardes": "abadiar",
    "abadiare": "abadiar",
    "abadiarei": "abadiar",
    "abadiareis": "abadiar",
    "abadiarem": "abadiar",
    "abadiaremos": "abadiar",
    "abadiares": "abadiar",
    "abadiaria": "abadiar",
    "abadiariam": "abadiar",
    "abadiarias": "abadiar",
    "abadiarmo": "abadiar",
    "abadiarmos": "abadiar",
    "abadiará": "abadiar",
    "abadiarás": "abadiar",
    "abadiarão": "abadiar",
    "abadiaríamos": "abadiar",
    "abadiaríeis": "abadiar",
    "abadias": "abadiar",
    "abadiasse": "abadiar",
    "abadiassem": "abadiar",
    "abadiasses": "abadiar",
    "abadiaste": "abadiar",
    "abadiastes": "abadiar",
    "abadiava": "abadiar",
    "abadiavam": "abadiar",
    "abadiavas": "abadiar",
    "abadie": "abadiar",
    "abadiei": "abadiar",
    "abadieis": "abadiar",
    "abadiem": "abadiar",
    "abadiemo": "abadiar",
    "abadiemos": "abadiar",
    "abadies": "abadiar",
    "abadio": "abadiar",
    "abadiou": "abadiar",
    "abadires": "abadir",
    "abadiá": "abadiar",
    "abadiámo": "abadiar",
    "abadiámos": "abadiar",
    "abadiáramo": "abadiar",
    "abadiáramos": "abadiar",
    "abadiárei": "abadiar",
    "abadiáreis": "abadiar",
    "abadiásseis": "abadiar",
    "abadiássemos": "abadiar",
    "abadiávamo": "abadiar",
    "abadiávamos": "abadiar",
    "abadiávei": "abadiar",
    "abadiáveis": "abadiar",
    "abado": "abar",
    "abados": "abar",
    "abadou": "abadar",
    "abadá": "abadar",
    "abadágios": "abadágio",
    "abadámo": "abadar",
    "abadámos": "abadar",
    "abadáramo": "abadar",
    "abadáramos": "abadar",
    "abadárei": "abadar",
    "abadáreis": "abadar",
    "abadásseis": "abadar",
    "abadássemos": "abadar",
    "abadávamo": "abadar",
    "abadávamos": "abadar",
    "abadávei": "abadar",
    "abadáveis": "abadável",
    "abaeta": "abaetar",
    "abaetada": "abaetar",
    "abaetadas": "abaetar",
    "abaetado": "abaetar",
    "abaetados": "abaetar",
    "abaetai": "abaetar",
    "abaetais": "abaetar",
    "abaetam": "abaetar",
    "abaetamentos": "abaetamento",
    "abaetamo": "abaetar",
    "abaetamos": "abaetar",
    "abaetando": "abaetar",
    "abaetara": "abaetar",
    "abaetaram": "abaetar",
    "abaetaras": "abaetar",
    "abaetarde": "abaetar",
    "abaetardes": "abaetar",
    "abaetare": "abaetar",
    "abaetarei": "abaetar",
    "abaetareis": "abaetar",
    "abaetarem": "abaetar",
    "abaetaremos": "abaetar",
    "abaetares": "abaetar",
    "abaetaria": "abaetar",
    "abaetariam": "abaetar",
    "abaetarias": "abaetar",
    "abaetarmo": "abaetar",
    "abaetarmos": "abaetar",
    "abaetará": "abaetar",
    "abaetarás": "abaetar",
    "abaetarão": "abaetar",
    "abaetaríamos": "abaetar",
    "abaetaríeis": "abaetar",
    "abaetas": "abaetar",
    "abaetasse": "abaetar",
    "abaetassem": "abaetar",
    "abaetasses": "abaetar",
    "abaetaste": "abaetar",
    "abaetastes": "abaetar",
    "abaetava": "abaetar",
    "abaetavam": "abaetar",
    "abaetavas": "abaetar",
    "abaete": "abaetar",
    "abaetei": "abaetar",
    "abaeteis": "abaetar",
    "abaetem": "abaetar",
    "abaetemo": "abaetar",
    "abaetemos": "abaetar",
    "abaetes": "abaetar",
    "abaeto": "abaetar",
    "abaetou": "abaetar",
    "abaetá": "abaetar",
    "abaetámo": "abaetar",
    "abaetámos": "abaetar",
    "abaetáramo": "abaetar",
    "abaetáramos": "abaetar",
    "abaetárei": "abaetar",
    "abaetáreis": "abaetar",
    "abaetásseis": "abaetar",
    "abaetássemos": "abaetar",
    "abaetávamo": "abaetar",
    "abaetávamos": "abaetar",
    "abaetávei": "abaetar",
    "abaetáveis": "abaetável",
    "abaetês": "abaetê",
    "abafa": "abafar",
    "abafada": "abafar",
    "abafadas": "abafar",
    "abafadelas": "abafadela",
    "abafadiça": "abafadiço",
    "abafadiças": "abafadiço",
    "abafadiços": "abafadiço",
    "abafado": "abafar",
    "abafadora": "abafador",
    "abafadoras": "abafador",
    "abafadores": "abafador",
    "abafados": "abafar",
    "abafaduras": "abafadura",
    "abafadíssima": "abafado",
    "abafadíssimas": "abafado",
    "abafadíssimo": "abafado",
    "abafadíssimos": "abafado",
    "abafai": "abafar",
    "abafais": "abafar",
    "abafam": "abafar",
    "abafamentos": "abafamento",
    "abafamo": "abafar",
    "abafamos": "abafar",
    "abafando": "abafar",
    "abafantes": "abafante",
    "abafara": "abafar",
    "abafaram": "abafar",
    "abafaras": "abafar",
    "abafarde": "abafar",
    "abafardes": "abafar",
    "abafare": "abafar",
    "abafarei": "abafar",
    "abafareis": "abafar",
    "abafarem": "abafar",
    "abafaremos": "abafar",
    "abafares": "abafar",
    "abafaretes": "abafarete",
    "abafaria": "abafar",
    "abafariam": "abafar",
    "abafarias": "abafar",
    "abafarmo": "abafar",
    "abafarmos": "abafar",
    "abafará": "abafar",
    "abafarás": "abafar",
    "abafarão": "abafar",
    "abafaríamos": "abafar",
    "abafaríeis": "abafar",
    "abafas": "abafar",
    "abafasse": "abafar",
    "abafassem": "abafar",
    "abafasses": "abafar",
    "abafaste": "abafar",
    "abafastes": "abafar",
    "abafava": "abafar",
    "abafavam": "abafar",
    "abafavas": "abafar",
    "abafações": "abafação",
    "abafe": "abafar",
    "abafei": "abafar",
    "abafeiras": "abafeira",
    "abafeis": "abafar",
    "abafem": "abafar",
    "abafemo": "abafar",
    "abafemos": "abafar",
    "abafes": "abafar",
    "abafo": "abafar",
    "abafos": "abafo",
    "abafou": "abafar",
    "abafá": "abafar",
    "abafámo": "abafar",
    "abafámos": "abafar",
    "abafáramo": "abafar",
    "abafáramos": "abafar",
    "abafárei": "abafar",
    "abafáreis": "abafar",
    "abafásseis": "abafar",
    "abafássemos": "abafar",
    "abafávamo": "abafar",
    "abafávamos": "abafar",
    "abafávei": "abafar",
    "abafáveis": "abafável",
    "abagace": "abagaçar",
    "abagacei": "abagaçar",
    "abagaceis": "abagaçar",
    "abagacem": "abagaçar",
    "abagacemo": "abagaçar",
    "abagacemos": "abagaçar",
    "abagaces": "abagaçar",
    "abaganha": "abaganhar",
    "abaganhada": "abaganhar",
    "abaganhadas": "abaganhar",
    "abaganhado": "abaganhar",
    "abaganhados": "abaganhar",
    "abaganhai": "abaganhar",
    "abaganhais": "abaganhar",
    "abaganham": "abaganhar",
    "abaganhamo": "abaganhar",
    "abaganhamos": "abaganhar",
    "abaganhando": "abaganhar",
    "abaganhara": "abaganhar",
    "abaganharam": "abaganhar",
    "abaganharas": "abaganhar",
    "abaganhardes": "abaganhar",
    "abaganharei": "abaganhar",
    "abaganhareis": "abaganhar",
    "abaganharem": "abaganhar",
    "abaganharemos": "abaganhar",
    "abaganhares": "abaganhar",
    "abaganharia": "abaganhar",
    "abaganhariam": "abaganhar",
    "abaganharias": "abaganhar",
    "abaganharmo": "abaganhar",
    "abaganharmos": "abaganhar",
    "abaganhará": "abaganhar",
    "abaganharás": "abaganhar",
    "abaganharão": "abaganhar",
    "abaganharíamos": "abaganhar",
    "abaganharíeis": "abaganhar",
    "abaganhas": "abaganhar",
    "abaganhasse": "abaganhar",
    "abaganhassem": "abaganhar",
    "abaganhasses": "abaganhar",
    "abaganhaste": "abaganhar",
    "abaganhastes": "abaganhar",
    "abaganhava": "abaganhar",
    "abaganhavam": "abaganhar",
    "abaganhavas": "abaganhar",
    "abaganhe": "abaganhar",
    "abaganhei": "abaganhar",
    "abaganheis": "abaganhar",
    "abaganhem": "abaganhar",
    "abaganhemo": "abaganhar",
    "abaganhemos": "abaganhar",
    "abaganhes": "abaganhar",
    "abaganho": "abaganhar",
    "abaganhou": "abaganhar",
    "abaganhámo": "abaganhar",
    "abaganhámos": "abaganhar",
    "abaganháramo": "abaganhar",
    "abaganháramos": "abaganhar",
    "abaganháreis": "abaganhar",
    "abaganhásseis": "abaganhar",
    "abaganhássemos": "abaganhar",
    "abaganhávamo": "abaganhar",
    "abaganhávamos": "abaganhar",
    "abaganháveis": "abaganhável",
    "abagaça": "abagaçar",
    "abagaçada": "abagaçar",
    "abagaçadas": "abagaçar",
    "abagaçado": "abagaçar",
    "abagaçados": "abagaçar",
    "abagaçai": "abagaçar",
    "abagaçais": "abagaçar",
    "abagaçam": "abagaçar",
    "abagaçamo": "abagaçar",
    "abagaçamos": "abagaçar",
    "abagaçando": "abagaçar",
    "abagaçara": "abagaçar",
    "abagaçaram": "abagaçar",
    "abagaçaras": "abagaçar",
    "abagaçarde": "abagaçar",
    "abagaçardes": "abagaçar",
    "abagaçare": "abagaçar",
    "abagaçarei": "abagaçar",
    "abagaçareis": "abagaçar",
    "abagaçarem": "abagaçar",
    "abagaçaremos": "abagaçar",
    "abagaçares": "abagaçar",
    "abagaçaria": "abagaçar",
    "abagaçariam": "abagaçar",
    "abagaçarias": "abagaçar",
    "abagaçarmo": "abagaçar",
    "abagaçarmos": "abagaçar",
    "abagaçará": "abagaçar",
    "abagaçarás": "abagaçar",
    "abagaçarão": "abagaçar",
    "abagaçaríamos": "abagaçar",
    "abagaçaríeis": "abagaçar",
    "abagaças": "abagaçar",
    "abagaçasse": "abagaçar",
    "abagaçassem": "abagaçar",
    "abagaçasses": "abagaçar",
    "abagaçaste": "abagaçar",
    "abagaçastes": "abagaçar",
    "abagaçava": "abagaçar",
    "abagaçavam": "abagaçar",
    "abagaçavas": "abagaçar",
    "abagaço": "abagaçar",
    "abagaçou": "abagaçar",
    "abagaçá": "abagaçar",
    "abagaçámo": "abagaçar",
    "abagaçámos": "abagaçar",
    "abagaçáramo": "abagaçar",
    "abagaçáramos": "abagaçar",
    "abagaçárei": "abagaçar",
    "abagaçáreis": "abagaçar",
    "abagaçásseis": "abagaçar",
    "abagaçássemos": "abagaçar",
    "abagaçávamo": "abagaçar",
    "abagaçávamos": "abagaçar",
    "abagaçávei": "abagaçar",
    "abagaçáveis": "abagaçável",
    "abagoa": "abagoar",
    "abagoada": "abagoar",
    "abagoadas": "abagoar",
    "abagoado": "abagoar",
    "abagoados": "abagoar",
    "abagoai": "abagoar",
    "abagoais": "abagoar",
    "abagoam": "abagoar",
    "abagoamo": "abagoar",
    "abagoamos": "abagoar",
    "abagoando": "abagoar",
    "abagoara": "abagoar",
    "abagoaram": "abagoar",
    "abagoaras": "abagoar",
    "abagoarde": "abagoar",
    "abagoardes": "abagoar",
    "abagoare": "abagoar",
    "abagoarei": "abagoar",
    "abagoareis": "abagoar",
    "abagoarem": "abagoar",
    "abagoaremos": "abagoar",
    "abagoares": "abagoar",
    "abagoaria": "abagoar",
    "abagoariam": "abagoar",
    "abagoarias": "abagoar",
    "abagoarmo": "abagoar",
    "abagoarmos": "abagoar",
    "abagoará": "abagoar",
    "abagoarás": "abagoar",
    "abagoarão": "abagoar",
    "abagoaríamos": "abagoar",
    "abagoaríeis": "abagoar",
    "abagoas": "abagoar",
    "abagoasse": "abagoar",
    "abagoassem": "abagoar",
    "abagoasses": "abagoar",
    "abagoaste": "abagoar",
    "abagoastes": "abagoar",
    "abagoava": "abagoar",
    "abagoavam": "abagoar",
    "abagoavas": "abagoar",
    "abagoe": "abagoar",
    "abagoei": "abagoar",
    "abagoeis": "abagoar",
    "abagoem": "abagoar",
    "abagoemo": "abagoar",
    "abagoemos": "abagoar",
    "abagoes": "abagoar",
    "abagoo": "abagoar",
    "abagoou": "abagoar",
    "abagoá": "abagoar",
    "abagoámo": "abagoar",
    "abagoámos": "abagoar",
    "abagoáramo": "abagoar",
    "abagoáramos": "abagoar",
    "abagoárei": "abagoar",
    "abagoáreis": "abagoar",
    "abagoásseis": "abagoar",
    "abagoássemos": "abagoar",
    "abagoávamo": "abagoar",
    "abagoávamos": "abagoar",
    "abagoávei": "abagoar",
    "abagoáveis": "abagoável",
    "abagulhada": "abagulhado",
    "abagulhadas": "abagulhado",
    "abagulhados": "abagulhado",
    "abagulhaveis": "abagulhavel",
    "abai": "abar",
    "abaianadas": "abaianada",
    "abainha": "abainhar",
    "abainhada": "abainhar",
    "abainhadas": "abainhar",
    "abainhado": "abainhar",
    "abainhados": "abainhar",
    "abainhai": "abainhar",
    "abainhais": "abainhar",
    "abainham": "abainhar",
    "abainhamo": "abainhar",
    "abainhamos": "abainhar",
    "abainhando": "abainhar",
    "abainhara": "abainhar",
    "abainharam": "abainhar",
    "abainharas": "abainhar",
    "abainharde": "abainhar",
    "abainhardes": "abainhar",
    "abainhare": "abainhar",
    "abainharei": "abainhar",
    "abainhareis": "abainhar",
    "abainharem": "abainhar",
    "abainharemos": "abainhar",
    "abainhares": "abainhar",
    "abainharia": "abainhar",
    "abainhariam": "abainhar",
    "abainharias": "abainhar",
    "abainharmo": "abainhar",
    "abainharmos": "abainhar",
    "abainhará": "abainhar",
    "abainharás": "abainhar",
    "abainharão": "abainhar",
    "abainharíamos": "abainhar",
    "abainharíeis": "abainhar",
    "abainhas": "abainhar",
    "abainhasse": "abainhar",
    "abainhassem": "abainhar",
    "abainhasses": "abainhar",
    "abainhaste": "abainhar",
    "abainhastes": "abainhar",
    "abainhava": "abainhar",
    "abainhavam": "abainhar",
    "abainhavas": "abainhar",
    "abainhe": "abainhar",
    "abainhei": "abainhar",
    "abainheis": "abainhar",
    "abainhem": "abainhar",
    "abainhemo": "abainhar",
    "abainhemos": "abainhar",
    "abainhes": "abainhar",
    "abainho": "abainhar",
    "abainhou": "abainhar",
    "abainhá": "abainhar",
    "abainhámo": "abainhar",
    "abainhámos": "abainhar",
    "abainháramo": "abainhar",
    "abainháramos": "abainhar",
    "abainhárei": "abainhar",
    "abainháreis": "abainhar",
    "abainhásseis": "abainhar",
    "abainhássemos": "abainhar",
    "abainhávamo": "abainhar",
    "abainhávamos": "abainhar",
    "abainhávei": "abainhar",
    "abainháveis": "abainhar",
    "abaioneta": "abaionetar",
    "abaionetada": "abaionetar",
    "abaionetadas": "abaionetar",
    "abaionetado": "abaionetar",
    "abaionetados": "abaionetar",
    "abaionetai": "abaionetar",
    "abaionetais": "abaionetar",
    "abaionetam": "abaionetar",
    "abaionetamo": "abaionetar",
    "abaionetamos": "abaionetar",
    "abaionetando": "abaionetar",
    "abaionetara": "abaionetar",
    "abaionetaram": "abaionetar",
    "abaionetaras": "abaionetar",
    "abaionetarde": "abaionetar",
    "abaionetardes": "abaionetar",
    "abaionetare": "abaionetar",
    "abaionetarei": "abaionetar",
    "abaionetareis": "abaionetar",
    "abaionetarem": "abaionetar",
    "abaionetaremos": "abaionetar",
    "abaionetares": "abaionetar",
    "abaionetaria": "abaionetar",
    "abaionetariam": "abaionetar",
    "abaionetarias": "abaionetar",
    "abaionetarmo": "abaionetar",
    "abaionetarmos": "abaionetar",
    "abaionetará": "abaionetar",
    "abaionetarás": "abaionetar",
    "abaionetarão": "abaionetar",
    "abaionetaríamos": "abaionetar",
    "abaionetaríeis": "abaionetar",
    "abaionetas": "abaionetar",
    "abaionetasse": "abaionetar",
    "abaionetassem": "abaionetar",
    "abaionetasses": "abaionetar",
    "abaionetaste": "abaionetar",
    "abaionetastes": "abaionetar",
    "abaionetava": "abaionetar",
    "abaionetavam": "abaionetar",
    "abaionetavas": "abaionetar",
    "abaionete": "abaionetar",
    "abaionetei": "abaionetar",
    "abaioneteis": "abaionetar",
    "abaionetem": "abaionetar",
    "abaionetemo": "abaionetar",
    "abaionetemos": "abaionetar",
    "abaionetes": "abaionetar",
    "abaioneto": "abaionetar",
    "abaionetou": "abaionetar",
    "abaionetá": "abaionetar",
    "abaionetámo": "abaionetar",
    "abaionetámos": "abaionetar",
    "abaionetáramo": "abaionetar",
    "abaionetáramos": "abaionetar",
    "abaionetárei": "abaionetar",
    "abaionetáreis": "abaionetar",
    "abaionetásseis": "abaionetar",
    "abaionetássemos": "abaionetar",
    "abaionetávamo": "abaionetar",
    "abaionetávamos": "abaionetar",
    "abaionetávei": "abaionetar",
    "abaionetáveis": "abaionetar",
    "abairra": "abairrar",
    "abairrada": "abairrar",
    "abairradas": "abairrar",
    "abairrado": "abairrar",
    "abairrados": "abairrar",
    "abairrai": "abairrar",
    "abairrais": "abairrar",
    "abairram": "abairrar",
    "abairramentos": "abairramento",
    "abairramo": "abairrar",
    "abairramos": "abairrar",
    "abairrando": "abairrar",
    "abairrara": "abairrar",
    "abairraram": "abairrar",
    "abairraras": "abairrar",
    "abairrarde": "abairrar",
    "abairrardes": "abairrar",
    "abairrare": "abairrar",
    "abairrarei": "abairrar",
    "abairrareis": "abairrar",
    "abairrarem": "abairrar",
    "abairraremos": "abairrar",
    "abairrares": "abairrar",
    "abairraria": "abairrar",
    "abairrariam": "abairrar",
    "abairrarias": "abairrar",
    "abairrarmo": "abairrar",
    "abairrarmos": "abairrar",
    "abairrará": "abairrar",
    "abairrarás": "abairrar",
    "abairrarão": "abairrar",
    "abairraríamos": "abairrar",
    "abairraríeis": "abairrar",
    "abairras": "abairrar",
    "abairrasse": "abairrar",
    "abairrassem": "abairrar",
    "abairrasses": "abairrar",
    "abairraste": "abairrar",
    "abairrastes": "abairrar",
    "abairrava": "abairrar",
    "abairravam": "abairrar",
    "abairravas": "abairrar",
    "abairre": "abairrar",
    "abairrei": "abairrar",
    "abairreis": "abairrar",
    "abairrem": "abairrar",
    "abairremo": "abairrar",
    "abairremos": "abairrar",
    "abairres": "abairrar",
    "abairro": "abairrar",
    "abairrou": "abairrar",
    "abairrá": "abairrar",
    "abairrámo": "abairrar",
    "abairrámos": "abairrar",
    "abairráramo": "abairrar",
    "abairráramos": "abairrar",
    "abairrárei": "abairrar",
    "abairráreis": "abairrar",
    "abairrásseis": "abairrar",
    "abairrássemos": "abairrar",
    "abairrávamo": "abairrar",
    "abairrávamos": "abairrar",
    "abairrávei": "abairrar",
    "abairráveis": "abairrar",
    "abais": "abar",
    "abaisires": "abaisir",
    "abaités": "abaité",
    "abaiuca": "abaiucar",
    "abaiucada": "abaiucar",
    "abaiucadas": "abaiucar",
    "abaiucado": "abaiucar",
    "abaiucados": "abaiucar",
    "abaiucai": "abaiucar",
    "abaiucais": "abaiucar",
    "abaiucam": "abaiucar",
    "abaiucamo": "abaiucar",
    "abaiucamos": "abaiucar",
    "abaiucando": "abaiucar",
    "abaiucara": "abaiucar",
    "abaiucaram": "abaiucar",
    "abaiucaras": "abaiucar",
    "abaiucarde": "abaiucar",
    "abaiucardes": "abaiucar",
    "abaiucare": "abaiucar",
    "abaiucarei": "abaiucar",
    "abaiucareis": "abaiucar",
    "abaiucarem": "abaiucar",
    "abaiucaremos": "abaiucar",
    "abaiucares": "abaiucar",
    "abaiucaria": "abaiucar",
    "abaiucariam": "abaiucar",
    "abaiucarias": "abaiucar",
    "abaiucarmo": "abaiucar",
    "abaiucarmos": "abaiucar",
    "abaiucará": "abaiucar",
    "abaiucarás": "abaiucar",
    "abaiucarão": "abaiucar",
    "abaiucaríamos": "abaiucar",
    "abaiucaríeis": "abaiucar",
    "abaiucas": "abaiucar",
    "abaiucasse": "abaiucar",
    "abaiucassem": "abaiucar",
    "abaiucasses": "abaiucar",
    "abaiucaste": "abaiucar",
    "abaiucastes": "abaiucar",
    "abaiucava": "abaiucar",
    "abaiucavam": "abaiucar",
    "abaiucavas": "abaiucar",
    "abaiuco": "abaiucar",
    "abaiucou": "abaiucar",
    "abaiucá": "abaiucar",
    "abaiucámo": "abaiucar",
    "abaiucámos": "abaiucar",
    "abaiucáramo": "abaiucar",
    "abaiucáramos": "abaiucar",
    "abaiucárei": "abaiucar",
    "abaiucáreis": "abaiucar",
    "abaiucásseis": "abaiucar",
    "abaiucássemos": "abaiucar",
    "abaiucávamo": "abaiucar",
    "abaiucávamos": "abaiucar",
    "abaiucávei": "abaiucar",
    "abaiucáveis": "abaiucar",
    "abaiuque": "abaiucar",
    "abaiuquei": "abaiucar",
    "abaiuqueis": "abaiucar",
    "abaiuquem": "abaiucar",
    "abaiuquemo": "abaiucar",
    "abaiuquemos": "abaiucar",
    "abaiuques": "abaiucar",
    "abaixa": "abaixar",
    "abaixada": "abaixar",
    "abaixadas": "abaixar",
    "abaixadelas": "abaixadela",
    "abaixado": "abaixar",
    "abaixadora": "abaixador",
    "abaixadoras": "abaixador",
    "abaixadores": "abaixador",
    "abaixados": "abaixar",
    "abaixai": "abaixar",
    "abaixais": "abaixar",
    "abaixam": "abaixar",
    "abaixamentos": "abaixamento",
    "abaixamo": "abaixar",
    "abaixamos": "abaixar",
    "abaixando": "abaixar",
    "abaixantes": "abaixante",
    "abaixara": "abaixar",
    "abaixaram": "abaixar",
    "abaixaras": "abaixar",
    "abaixarde": "abaixar",
    "abaixardes": "abaixar",
    "abaixare": "abaixar",
    "abaixarei": "abaixar",
    "abaixareis": "abaixar",
    "abaixarem": "abaixar",
    "abaixaremos": "abaixar",
    "abaixares": "abaixar",
    "abaixaria": "abaixar",
    "abaixariam": "abaixar",
    "abaixarias": "abaixar",
    "abaixarmo": "abaixar",
    "abaixarmos": "abaixar",
    "abaixará": "abaixar",
    "abaixarás": "abaixar",
    "abaixarão": "abaixar",
    "abaixaríamos": "abaixar",
    "abaixaríeis": "abaixar",
    "abaixas": "abaixar",
    "abaixasse": "abaixar",
    "abaixassem": "abaixar",
    "abaixasses": "abaixar",
    "abaixaste": "abaixar",
    "abaixastes": "abaixar",
    "abaixava": "abaixar",
    "abaixavam": "abaixar",
    "abaixavas": "abaixar",
    "abaixe": "abaixar",
    "abaixei": "abaixar",
    "abaixeis": "abaixar",
    "abaixem": "abaixar",
    "abaixemo": "abaixar",
    "abaixemos": "abaixar",
    "abaixes": "abaixar",
    "abaixo": "abaixar",
    "abaixou": "abaixar",
    "abaixá": "abaixar",
    "abaixámo": "abaixar",
    "abaixámos": "abaixar",
    "abaixáramo": "abaixar",
    "abaixáramos": "abaixar",
    "abaixárei": "abaixar",
    "abaixáreis": "abaixar",
    "abaixásseis": "abaixar",
    "abaixássemos": "abaixar",
    "abaixávamo": "abaixar",
    "abaixávamos": "abaixar",
    "abaixávei": "abaixar",
    "abaixáveis": "abaixar",
    "abaiôs": "abaiô",
    "abajerus": "abajeru",
    "abajouja": "abajoujar",
    "abajoujada": "abajoujar",
    "abajoujadas": "abajoujar",
    "abajoujado": "abajoujar",
    "abajoujados": "abajoujar",
    "abajoujadíssima": "abajoujado",
    "abajoujadíssimas": "abajoujado",
    "abajoujadíssimo": "abajoujado",
    "abajoujadíssimos": "abajoujado",
    "abajoujai": "abajoujar",
    "abajoujais": "abajoujar",
    "abajoujam": "abajoujar",
    "abajoujamentos": "abajoujamento",
    "abajoujamo": "abajoujar",
    "abajoujamos": "abajoujar",
    "abajoujando": "abajoujar",
    "abajoujara": "abajoujar",
    "abajoujaram": "abajoujar",
    "abajoujaras": "abajoujar",
    "abajoujarde": "abajoujar",
    "abajoujardes": "abajoujar",
    "abajoujare": "abajoujar",
    "abajoujarei": "abajoujar",
    "abajoujareis": "abajoujar",
    "abajoujarem": "abajoujar",
    "abajoujaremos": "abajoujar",
    "abajoujares": "abajoujar",
    "abajoujaria": "abajoujar",
    "abajoujariam": "abajoujar",
    "abajoujarias": "abajoujar",
    "abajoujarmo": "abajoujar",
    "abajoujarmos": "abajoujar",
    "abajoujará": "abajoujar",
    "abajoujarás": "abajoujar",
    "abajoujarão": "abajoujar",
    "abajoujaríamos": "abajoujar",
    "abajoujaríeis": "abajoujar",
    "abajoujas": "abajoujar",
    "abajoujasse": "abajoujar",
    "abajoujassem": "abajoujar",
    "abajoujasses": "abajoujar",
    "abajoujaste": "abajoujar",
    "abajoujastes": "abajoujar",
    "abajoujava": "abajoujar",
    "abajoujavam": "abajoujar",
    "abajoujavas": "abajoujar",
    "abajouje": "abajoujar",
    "abajoujei": "abajoujar",
    "abajoujeis": "abajoujar",
    "abajoujem": "abajoujar",
    "abajoujemo": "abajoujar",
    "abajoujemos": "abajoujar",
    "abajoujes": "abajoujar",
    "abajoujo": "abajoujar",
    "abajoujou": "abajoujar",
    "abajoujá": "abajoujar",
    "abajoujámo": "abajoujar",
    "abajoujámos": "abajoujar",
    "abajoujáramo": "abajoujar",
    "abajoujáramos": "abajoujar",
    "abajoujárei": "abajoujar",
    "abajoujáreis": "abajoujar",
    "abajoujásseis": "abajoujar",
    "abajoujássemos": "abajoujar",
    "abajoujávamo": "abajoujar",
    "abajoujávamos": "abajoujar",
    "abajoujávei": "abajoujar",
    "abajoujáveis": "abajoujar",
    "abajures": "abajur",
    "abajus": "abaju",
    "abala": "abalar",
    "abalada": "abalar",
    "abaladas": "abalar",
    "abaladazinha": "abalado",
    "abaladazinhas": "abalado",
    "abaladazita": "abalado",
    "abaladazitas": "abalado",
    "abaladelas": "abaladela",
    "abaladinha": "abalado",
    "abaladinhas": "abalado",
    "abaladinho": "abalado",
    "abaladinhos": "abalado",
    "abaladita": "abalado",
    "abaladitas": "abalado",
    "abaladito": "abalado",
    "abaladitos": "abalado",
    "abaladiça": "abaladiço",
    "abaladiças": "abaladiço",
    "abaladiços": "abaladiço",
    "abalado": "abalar",
    "abaladora": "abalador",
    "abaladoras": "abalador",
    "abaladores": "abalador",
    "abalados": "abalar",
    "abaladozinho": "abalado",
    "abaladozinhos": "abalado",
    "abaladozito": "abalado",
    "abaladozitos": "abalado",
    "abaladuras": "abaladura",
    "abaladíssima": "abalado",
    "abaladíssimas": "abalado",
    "abaladíssimo": "abalado",
    "abaladíssimos": "abalado",
    "abalai": "abalar",
    "abalaiada": "abalaiado",
    "abalaiadas": "abalaiado",
    "abalaiados": "abalaiado",
    "abalais": "abalar",
    "abalam": "abalar",
    "abalamentos": "abalamento",
    "abalamo": "abalar",
    "abalamos": "abalar",
    "abalance": "abalançar",
    "abalancei": "abalançar",
    "abalanceis": "abalançar",
    "abalancem": "abalançar",
    "abalancemo": "abalançar",
    "abalancemos": "abalançar",
    "abalances": "abalançar",
    "abalando": "abalar",
    "abalança": "abalançar",
    "abalançada": "abalançar",
    "abalançadas": "abalançar",
    "abalançado": "abalançar",
    "abalançados": "abalançar",
    "abalançadíssima": "abalançado",
    "abalançadíssimas": "abalançado",
    "abalançadíssimo": "abalançado",
    "abalançadíssimos": "abalançado",
    "abalançai": "abalançar",
    "abalançais": "abalançar",
    "abalançam": "abalançar",
    "abalançamentos": "abalançamento",
    "abalançamo": "abalançar",
    "abalançamos": "abalançar",
    "abalançando": "abalançar",
    "abalançara": "abalançar",
    "abalançaram": "abalançar",
    "abalançaras": "abalançar",
    "abalançarde": "abalançar",
    "abalançardes": "abalançar",
    "abalançare": "abalançar",
    "abalançarei": "abalançar",
    "abalançareis": "abalançar",
    "abalançarem": "abalançar",
    "abalançaremos": "abalançar",
    "abalançares": "abalançar",
    "abalançaria": "abalançar",
    "abalançariam": "abalançar",
    "abalançarias": "abalançar",
    "abalançarmo": "abalançar",
    "abalançarmos": "abalançar",
    "abalançará": "abalançar",
    "abalançarás": "abalançar",
    "abalançarão": "abalançar",
    "abalançaríamos": "abalançar",
    "abalançaríeis": "abalançar",
    "abalanças": "abalançar",
    "abalançasse": "abalançar",
    "abalançassem": "abalançar",
    "abalançasses": "abalançar",
    "abalançaste": "abalançar",
    "abalançastes": "abalançar",
    "abalançava": "abalançar",
    "abalançavam": "abalançar",
    "abalançavas": "abalançar",
    "abalanço": "abalançar",
    "abalançou": "abalançar",
    "abalançá": "abalançar",
    "abalançámo": "abalançar",
    "abalançámos": "abalançar",
    "abalançáramo": "abalançar",
    "abalançáramos": "abalançar",
    "abalançárei": "abalançar",
    "abalançáreis": "abalançar",
    "abalançásseis": "abalançar",
    "abalançássemos": "abalançar",
    "abalançávamo": "abalançar",
    "abalançávamos": "abalançar",
    "abalançávei": "abalançar",
    "abalançáveis": "abalançar",
    "abalara": "abalar",
    "abalaram": "abalar",
    "abalaras": "abalar",
    "abalarde": "abalar",
    "abalardes": "abalar",
    "abalare": "abalar",
    "abalarei": "abalar",
    "abalareis": "abalar",
    "abalarem": "abalar",
    "abalaremos": "abalar",
    "abalares": "abalar",
    "abalaria": "abalar",
    "abalariam": "abalar",
    "abalarias": "abalar",
    "abalarmo": "abalar",
    "abalarmos": "abalar",
    "abalará": "abalar",
    "abalarás": "abalar",
    "abalarão": "abalar",
    "abalaríamos": "abalar",
    "abalaríeis": "abalar",
    "abalas": "abalar",
    "abalasse": "abalar",
    "abalassem": "abalar",
    "abalasses": "abalar",
    "abalaste": "abalar",
    "abalastes": "abalar",
    "abalaustra": "abalaustrar",
    "abalaustrada": "abalaustrar",
    "abalaustradas": "abalaustrar",
    "abalaustrado": "abalaustrar",
    "abalaustrados": "abalaustrar",
    "abalaustrai": "abalaustrar",
    "abalaustrais": "abalaustrar",
    "abalaustram": "abalaustrar",
    "abalaustramentos": "abalaustramento",
    "abalaustramo": "abalaustrar",
    "abalaustramos": "abalaustrar",
    "abalaustrando": "abalaustrar",
    "abalaustrara": "abalaustrar",
    "abalaustraram": "abalaustrar",
    "abalaustraras": "abalaustrar",
    "abalaustrarde": "abalaustrar",
    "abalaustrardes": "abalaustrar",
    "abalaustrare": "abalaustrar",
    "abalaustrarei": "abalaustrar",
    "abalaustrareis": "abalaustrar",
    "abalaustrarem": "abalaustrar",
    "abalaustraremos": "abalaustrar",
    "abalaustrares": "abalaustrar",
    "abalaustraria": "abalaustrar",
    "abalaustrariam": "abalaustrar",
    "abalaustrarias": "abalaustrar",
    "abalaustrarmo": "abalaustrar",
    "abalaustrarmos": "abalaustrar",
    "abalaustrará": "abalaustrar",
    "abalaustrarás": "abalaustrar",
    "abalaustrarão": "abalaustrar",
    "abalaustraríamos": "abalaustrar",
    "abalaustraríeis": "abalaustrar",
    "abalaustras": "abalaustrar",
    "abalaustrasse": "abalaustrar",
    "abalaustrassem": "abalaustrar",
    "abalaustrasses": "abalaustrar",
    "abalaustraste": "abalaustrar",
    "abalaustrastes": "abalaustrar",
    "abalaustrava": "abalaustrar",
    "abalaustravam": "abalaustrar",
    "abalaustravas": "abalaustrar",
    "abalaustre": "abalaustrar",
    "abalaustrei": "abalaustrar",
    "abalaustreis": "abalaustrar",
    "abalaustrem": "abalaustrar",
    "abalaustremo": "abalaustrar",
    "abalaustremos": "abalaustrar",
    "abalaustres": "abalaustrar",
    "abalaustro": "abalaustrar",
    "abalaustrou": "abalaustrar",
    "abalaustrá": "abalaustrar",
    "abalaustrámo": "abalaustrar",
    "abalaustrámos": "abalaustrar",
    "abalaustráramo": "abalaustrar",
    "abalaustráramos": "abalaustrar",
    "abalaustrárei": "abalaustrar",
    "abalaustráreis": "abalaustrar",
    "abalaustrásseis": "abalaustrar",
    "abalaustrássemos": "abalaustrar",
    "abalaustrávamo": "abalaustrar",
    "abalaustrávamos": "abalaustrar",
    "abalaustrávei": "abalaustrar",
    "abalaustráveis": "abalaustrável",
    "abalava": "abalar",
    "abalavam": "abalar",
    "abalavas": "abalar",
    "abale": "abalar",
    "abalei": "abalar",
    "abaleis": "abalar",
    "abalem": "abalar",
    "abalemo": "abalar",
    "abalemos": "abalar",
    "abales": "abalar",
    "abaliena": "abalienar",
    "abalienada": "abalienar",
    "abalienadas": "abalienar",
    "abalienado": "abalienar",
    "abalienados": "abalienar",
    "abalienai": "abalienar",
    "abalienais": "abalienar",
    "abalienam": "abalienar",
    "abalienamo": "abalienar",
    "abalienamos": "abalienar",
    "abalienando": "abalienar",
    "abalienara": "abalienar",
    "abalienaram": "abalienar",
    "abalienaras": "abalienar",
    "abalienarde": "abalienar",
    "abalienardes": "abalienar",
    "abalienare": "abalienar",
    "abalienarei": "abalienar",
    "abalienareis": "abalienar",
    "abalienarem": "abalienar",
    "abalienaremos": "abalienar",
    "abalienares": "abalienar",
    "abalienaria": "abalienar",
    "abalienariam": "abalienar",
    "abalienarias": "abalienar",
    "abalienarmo": "abalienar",
    "abalienarmos": "abalienar",
    "abalienará": "abalienar",
    "abalienarás": "abalienar",
    "abalienarão": "abalienar",
    "abalienaríamos": "abalienar",
    "abalienaríeis": "abalienar",
    "abalienas": "abalienar",
    "abalienasse": "abalienar",
    "abalienassem": "abalienar",
    "abalienasses": "abalienar",
    "abalienaste": "abalienar",
    "abalienastes": "abalienar",
    "abalienava": "abalienar",
    "abalienavam": "abalienar",
    "abalienavas": "abalienar",
    "abalienações": "abalienação",
    "abaliene": "abalienar",
    "abalienei": "abalienar",
    "abalieneis": "abalienar",
    "abalienem": "abalienar",
    "abalienemo": "abalienar",
    "abalienemos": "abalienar",
    "abalienes": "abalienar",
    "abalieno": "abalienar",
    "abalienou": "abalienar",
    "abaliená": "abalienar",
    "abalienámo": "abalienar",
    "abalienámos": "abalienar",
    "abalienáramo": "abalienar",
    "abalienáramos": "abalienar",
    "abalienárei": "abalienar",
    "abalienáreis": "abalienar",
    "abalienásseis": "abalienar",
    "abalienássemos": "abalienar",
    "abalienávamo": "abalienar",
    "abalienávamos": "abalienar",
    "abalienávei": "abalienar",
    "abalienáveis": "abalienável",
    "abalista": "abalistar",
    "abalistada": "abalistar",
    "abalistadas": "abalistar",
    "abalistado": "abalistar",
    "abalistados": "abalistar",
    "abalistai": "abalistar",
    "abalistais": "abalistar",
    "abalistam": "abalistar",
    "abalistamo": "abalistar",
    "abalistamos": "abalistar",
    "abalistando": "abalistar",
    "abalistara": "abalistar",
    "abalistaram": "abalistar",
    "abalistaras": "abalistar",
    "abalistarde": "abalistar",
    "abalistardes": "abalistar",
    "abalistare": "abalistar",
    "abalistarei": "abalistar",
    "abalistareis": "abalistar",
    "abalistarem": "abalistar",
    "abalistaremos": "abalistar",
    "abalistares": "abalistar",
    "abalistaria": "abalistar",
    "abalistariam": "abalistar",
    "abalistarias": "abalistar",
    "abalistarmo": "abalistar",
    "abalistarmos": "abalistar",
    "abalistará": "abalistar",
    "abalistarás": "abalistar",
    "abalistarão": "abalistar",
    "abalistaríamos": "abalistar",
    "abalistaríeis": "abalistar",
    "abalistas": "abalistar",
    "abalistasse": "abalistar",
    "abalistassem": "abalistar",
    "abalistasses": "abalistar",
    "abalistaste": "abalistar",
    "abalistastes": "abalistar",
    "abalistava": "abalistar",
    "abalistavam": "abalistar",
    "abalistavas": "abalistar",
    "abaliste": "abalistar",
    "abalistei": "abalistar",
    "abalisteis": "abalistar",
    "abalistem": "abalistar",
    "abalistemo": "abalistar",
    "abalistemos": "abalistar",
    "abalistes": "abalistar",
    "abalisto": "abalistar",
    "abalistou": "abalistar",
    "abalistá": "abalistar",
    "abalistámo": "abalistar",
    "abalistámos": "abalistar",
    "abalistáramo": "abalistar",
    "abalistáramos": "abalistar",
    "abalistárei": "abalistar",
    "abalistáreis": "abalistar",
    "abalistásseis": "abalistar",
    "abalistássemos": "abalistar",
    "abalistávamo": "abalistar",
    "abalistávamos": "abalistar",
    "abalistávei": "abalistar",
    "abalistáveis": "abalistar",
    "abaliza": "abalizar",
    "abalizada": "abalizar",
    "abalizadas": "abalizar",
    "abalizado": "abalizar",
    "abalizadora": "abalizador",
    "abalizadoras": "abalizador",
    "abalizadores": "abalizador",
    "abalizados": "abalizar",
    "abalizai": "abalizar",
    "abalizais": "abalizar",
    "abalizam": "abalizar",
    "abalizamentos": "abalizamento",
    "abalizamo": "abalizar",
    "abalizamos": "abalizar",
    "abalizando": "abalizar",
    "abalizara": "abalizar",
    "abalizaram": "abalizar",
    "abalizaras": "abalizar",
    "abalizarde": "abalizar",
    "abalizardes": "abalizar",
    "abalizare": "abalizar",
    "abalizarei": "abalizar",
    "abalizareis": "abalizar",
    "abalizarem": "abalizar",
    "abalizaremos": "abalizar",
    "abalizares": "abalizar",
    "abalizaria": "abalizar",
    "abalizariam": "abalizar",
    "abalizarias": "abalizar",
    "abalizarmo": "abalizar",
    "abalizarmos": "abalizar",
    "abalizará": "abalizar",
    "abalizarás": "abalizar",
    "abalizarão": "abalizar",
    "abalizaríamos": "abalizar",
    "abalizaríeis": "abalizar",
    "abalizas": "abalizar",
    "abalizasse": "abalizar",
    "abalizassem": "abalizar",
    "abalizasses": "abalizar",
    "abalizaste": "abalizar",
    "abalizastes": "abalizar",
    "abalizava": "abalizar",
    "abalizavam": "abalizar",
    "abalizavas": "abalizar",
    "abalize": "abalizar",
    "abalizei": "abalizar",
    "abalizeis": "abalizar",
    "abalizem": "abalizar",
    "abalizemo": "abalizar",
    "abalizemos": "abalizar",
    "abalizes": "abalizar",
    "abalizo": "abalizar",
    "abalizou": "abalizar",
    "abalizá": "abalizar",
    "abalizámo": "abalizar",
    "abalizámos": "abalizar",
    "abalizáramo": "abalizar",
    "abalizáramos": "abalizar",
    "abalizárei": "abalizar",
    "abalizáreis": "abalizar",
    "abalizásseis": "abalizar",
    "abalizássemos": "abalizar",
    "abalizávamo": "abalizar",
    "abalizávamos": "abalizar",
    "abalizávei": "abalizar",
    "abalizáveis": "abalizável",
    "abalo": "abalar",
    "abaloa": "abaloar",
    "abaloada": "abaloar",
    "abaloadas": "abaloar",
    "abaloado": "abaloar",
    "abaloados": "abaloar",
    "abaloai": "abaloar",
    "abaloais": "abaloar",
    "abaloam": "abaloar",
    "abaloamo": "abaloar",
    "abaloamos": "abaloar",
    "abaloando": "abaloar",
    "abaloara": "abaloar",
    "abaloaram": "abaloar",
    "abaloaras": "abaloar",
    "abaloarde": "abaloar",
    "abaloardes": "abaloar",
    "abaloare": "abaloar",
    "abaloarei": "abaloar",
    "abaloareis": "abaloar",
    "abaloarem": "abaloar",
    "abaloaremos": "abaloar",
    "abaloares": "abaloar",
    "abaloaria": "abaloar",
    "abaloariam": "abaloar",
    "abaloarias": "abaloar",
    "abaloarmo": "abaloar",
    "abaloarmos": "abaloar",
    "abaloará": "abaloar",
    "abaloarás": "abaloar",
    "abaloarão": "abaloar",
    "abaloaríamos": "abaloar",
    "abaloaríeis": "abaloar",
    "abaloas": "abaloar",
    "abaloasse": "abaloar",
    "abaloassem": "abaloar",
    "abaloasses": "abaloar",
    "abaloaste": "abaloar",
    "abaloastes": "abaloar",
    "abaloava": "abaloar",
    "abaloavam": "abaloar",
    "abaloavas": "abaloar",
    "abaloe": "abaloar",
    "abaloei": "abaloar",
    "abaloeis": "abaloar",
    "abaloem": "abaloar",
    "abaloemo": "abaloar",
    "abaloemos": "abaloar",
    "abaloes": "abaloar",
    "abalofa": "abalofar",
    "abalofada": "abalofar",
    "abalofadas": "abalofar",
    "abalofado": "abalofar",
    "abalofados": "abalofar",
    "abalofai": "abalofar",
    "abalofais": "abalofar",
    "abalofam": "abalofar",
    "abalofamo": "abalofar",
    "abalofamos": "abalofar",
    "abalofando": "abalofar",
    "abalofara": "abalofar",
    "abalofaram": "abalofar",
    "abalofaras": "abalofar",
    "abalofarde": "abalofar",
    "abalofardes": "abalofar",
    "abalofare": "abalofar",
    "abalofarei": "abalofar",
    "abalofareis": "abalofar",
    "abalofarem": "abalofar",
    "abalofaremos": "abalofar",
    "abalofares": "abalofar",
    "abalofaria": "abalofar",
    "abalofariam": "abalofar",
    "abalofarias": "abalofar",
    "abalofarmo": "abalofar",
    "abalofarmos": "abalofar",
    "abalofará": "abalofar",
    "abalofarás": "abalofar",
    "abalofarão": "abalofar",
    "abalofaríamos": "abalofar",
    "abalofaríeis": "abalofar",
    "abalofas": "abalofar",
    "abalofasse": "abalofar",
    "abalofassem": "abalofar",
    "abalofasses": "abalofar",
    "abalofaste": "abalofar",
    "abalofastes": "abalofar",
    "abalofava": "abalofar",
    "abalofavam": "abalofar",
    "abalofavas": "abalofar",
    "abalofe": "abalofar",
    "abalofei": "abalofar",
    "abalofeis": "abalofar",
    "abalofem": "abalofar",
    "abalofemo": "abalofar",
    "abalofemos": "abalofar",
    "abalofes": "abalofar",
    "abalofo": "abalofar",
    "abalofou": "abalofar",
    "abalofá": "abalofar",
    "abalofámo": "abalofar",
    "abalofámos": "abalofar",
    "abalofáramo": "abalofar",
    "abalofáramos": "abalofar",
    "abalofárei": "abalofar",
    "abalofáreis": "abalofar",
    "abalofásseis": "abalofar",
    "abalofássemos": "abalofar",
    "abalofávamo": "abalofar",
    "abalofávamos": "abalofar",
    "abalofávei": "abalofar",
    "abalofáveis": "abalofar",
    "abaloo": "abaloar",
    "abaloou": "abaloar",
    "abalos": "abalo",
    "abalou": "abalar",
    "abaloá": "abaloar",
    "abaloámo": "abaloar",
    "abaloámos": "abaloar",
    "abaloáramo": "abaloar",
    "abaloáramos": "abaloar",
    "abaloárei": "abaloar",
    "abaloáreis": "abaloar",
    "abaloásseis": "abaloar",
    "abaloássemos": "abaloar",
    "abaloávamo": "abaloar",
    "abaloávamos": "abaloar",
    "abaloávei": "abaloar",
    "abaloáveis": "abaloável",
    "abalroa": "abalroar",
    "abalroada": "abalroar",
    "abalroadas": "abalroar",
    "abalroado": "abalroar",
    "abalroados": "abalroar",
    "abalroai": "abalroar",
    "abalroais": "abalroar",
    "abalroam": "abalroar",
    "abalroamentos": "abalroamento",
    "abalroamo": "abalroar",
    "abalroamos": "abalroar",
    "abalroando": "abalroar",
    "abalroara": "abalroar",
    "abalroaram": "abalroar",
    "abalroaras": "abalroar",
    "abalroarde": "abalroar",
    "abalroardes": "abalroar",
    "abalroare": "abalroar",
    "abalroarei": "abalroar",
    "abalroareis": "abalroar",
    "abalroarem": "abalroar",
    "abalroaremos": "abalroar",
    "abalroares": "abalroar",
    "abalroaria": "abalroar",
    "abalroariam": "abalroar",
    "abalroarias": "abalroar",
    "abalroarmo": "abalroar",
    "abalroarmos": "abalroar",
    "abalroará": "abalroar",
    "abalroarás": "abalroar",
    "abalroarão": "abalroar",
    "abalroaríamos": "abalroar",
    "abalroaríeis": "abalroar",
    "abalroas": "abalroar",
    "abalroasse": "abalroar",
    "abalroassem": "abalroar",
    "abalroasses": "abalroar",
    "abalroaste": "abalroar",
    "abalroastes": "abalroar",
    "abalroava": "abalroar",
    "abalroavam": "abalroar",
    "abalroavas": "abalroar",
    "abalroações": "abalroação",
    "abalroe": "abalroar",
    "abalroei": "abalroar",
    "abalroeis": "abalroar",
    "abalroem": "abalroar",
    "abalroemo": "abalroar",
    "abalroemos": "abalroar",
    "abalroes": "abalroar",
    "abalroo": "abalroar",
    "abalroou": "abalroar",
    "abalroá": "abalroar",
    "abalroámo": "abalroar",
    "abalroámos": "abalroar",
    "abalroáramo": "abalroar",
    "abalroáramos": "abalroar",
    "abalroárei": "abalroar",
    "abalroáreis": "abalroar",
    "abalroásseis": "abalroar",
    "abalroássemos": "abalroar",
    "abalroávamo": "abalroar",
    "abalroávamos": "abalroar",
    "abalroávei": "abalroar",
    "abalroáveis": "abalroável",
    "abalsa": "abalsar",
    "abalsada": "abalsar",
    "abalsadas": "abalsar",
    "abalsado": "abalsar",
    "abalsados": "abalsar",
    "abalsai": "abalsar",
    "abalsais": "abalsar",
    "abalsam": "abalsar",
    "abalsamo": "abalsar",
    "abalsamos": "abalsar",
    "abalsando": "abalsar",
    "abalsara": "abalsar",
    "abalsaram": "abalsar",
    "abalsaras": "abalsar",
    "abalsarde": "abalsar",
    "abalsardes": "abalsar",
    "abalsare": "abalsar",
    "abalsarei": "abalsar",
    "abalsareis": "abalsar",
    "abalsarem": "abalsar",
    "abalsaremos": "abalsar",
    "abalsares": "abalsar",
    "abalsaria": "abalsar",
    "abalsariam": "abalsar",
    "abalsarias": "abalsar",
    "abalsarmo": "abalsar",
    "abalsarmos": "abalsar",
    "abalsará": "abalsar",
    "abalsarás": "abalsar",
    "abalsarão": "abalsar",
    "abalsaríamos": "abalsar",
    "abalsaríeis": "abalsar",
    "abalsas": "abalsar",
    "abalsasse": "abalsar",
    "abalsassem": "abalsar",
    "abalsasses": "abalsar",
    "abalsaste": "abalsar",
    "abalsastes": "abalsar",
    "abalsava": "abalsar",
    "abalsavam": "abalsar",
    "abalsavas": "abalsar",
    "abalse": "abalsar",
    "abalsei": "abalsar",
    "abalseira": "abalseirar",
    "abalseirada": "abalseirar",
    "abalseiradas": "abalseirar",
    "abalseirado": "abalseirar",
    "abalseirados": "abalseirar",
    "abalseirai": "abalseirar",
    "abalseirais": "abalseirar",
    "abalseiram": "abalseirar",
    "abalseiramo": "abalseirar",
    "abalseiramos": "abalseirar",
    "abalseirando": "abalseirar",
    "abalseirara": "abalseirar",
    "abalseiraram": "abalseirar",
    "abalseiraras": "abalseirar",
    "abalseirarde": "abalseirar",
    "abalseirardes": "abalseirar",
    "abalseirare": "abalseirar",
    "abalseirarei": "abalseirar",
    "abalseirareis": "abalseirar",
    "abalseirarem": "abalseirar",
    "abalseiraremos": "abalseirar",
    "abalseirares": "abalseirar",
    "abalseiraria": "abalseirar",
    "abalseirariam": "abalseirar",
    "abalseirarias": "abalseirar",
    "abalseirarmo": "abalseirar",
    "abalseirarmos": "abalseirar",
    "abalseirará": "abalseirar",
    "abalseirarás": "abalseirar",
    "abalseirarão": "abalseirar",
    "abalseiraríamos": "abalseirar",
    "abalseiraríeis": "abalseirar",
    "abalseiras": "abalseirar",
    "abalseirasse": "abalseirar",
    "abalseirassem": "abalseirar",
    "abalseirasses": "abalseirar",
    "abalseiraste": "abalseirar",
    "abalseirastes": "abalseirar",
    "abalseirava": "abalseirar",
    "abalseiravam": "abalseirar",
    "abalseiravas": "abalseirar",
    "abalseire": "abalseirar",
    "abalseirei": "abalseirar",
    "abalseireis": "abalseirar",
    "abalseirem": "abalseirar",
    "abalseiremo": "abalseirar",
    "abalseiremos": "abalseirar",
    "abalseires": "abalseirar",
    "abalseiro": "abalseirar",
    "abalseirou": "abalseirar",
    "abalseirá": "abalseirar",
    "abalseirámo": "abalseirar",
    "abalseirámos": "abalseirar",
    "abalseiráramo": "abalseirar",
    "abalseiráramos": "abalseirar",
    "abalseirárei": "abalseirar",
    "abalseiráreis": "abalseirar",
    "abalseirásseis": "abalseirar",
    "abalseirássemos": "abalseirar",
    "abalseirávamo": "abalseirar",
    "abalseirávamos": "abalseirar",
    "abalseirávei": "abalseirar",
    "abalseiráveis": "abalseirável",
    "abalseis": "abalsar",
    "abalsem": "abalsar",
    "abalsemo": "abalsar",
    "abalsemos": "abalsar",
    "abalses": "abalsar",
    "abalso": "abalsar",
    "abalsou": "abalsar",
    "abalsá": "abalsar",
    "abalsámo": "abalsar",
    "abalsámos": "abalsar",
    "abalsáramo": "abalsar",
    "abalsáramos": "abalsar",
    "abalsárei": "abalsar",
    "abalsáreis": "abalsar",
    "abalsásseis": "abalsar",
    "abalsássemos": "abalsar",
    "abalsávamo": "abalsar",
    "abalsávamos": "abalsar",
    "abalsávei": "abalsar",
    "abalsáveis": "abalsável",
    "abaluarta": "abaluartar",
    "abaluartada": "abaluartar",
    "abaluartadas": "abaluartar",
    "abaluartado": "abaluartar",
    "abaluartados": "abaluartar",
    "abaluartai": "abaluartar",
    "abaluartais": "abaluartar",
    "abaluartam": "abaluartar",
    "abaluartamentos": "abaluartamento",
    "abaluartamo": "abaluartar",
    "abaluartamos": "abaluartar",
    "abaluartando": "abaluartar",
    "abaluartara": "abaluartar",
    "abaluartaram": "abaluartar",
    "abaluartaras": "abaluartar",
    "abaluartarde": "abaluartar",
    "abaluartardes": "abaluartar",
    "abaluartare": "abaluartar",
    "abaluartarei": "abaluartar",
    "abaluartareis": "abaluartar",
    "abaluartarem": "abaluartar",
    "abaluartaremos": "abaluartar",
    "abaluartares": "abaluartar",
    "abaluartaria": "abaluartar",
    "abaluartariam": "abaluartar",
    "abaluartarias": "abaluartar",
    "abaluartarmo": "abaluartar",
    "abaluartarmos": "abaluartar",
    "abaluartará": "abaluartar",
    "abaluartarás": "abaluartar",
    "abaluartarão": "abaluartar",
    "abaluartaríamos": "abaluartar",
    "abaluartaríeis": "abaluartar",
    "abaluartas": "abaluartar",
    "abaluartasse": "abaluartar",
    "abaluartassem": "abaluartar",
    "abaluartasses": "abaluartar",
    "abaluartaste": "abaluartar",
    "abaluartastes": "abaluartar",
    "abaluartava": "abaluartar",
    "abaluartavam": "abaluartar",
    "abaluartavas": "abaluartar",
    "abaluarte": "abaluartar",
    "abaluartei": "abaluartar",
    "abaluarteis": "abaluartar",
    "abaluartem": "abaluartar",
    "abaluartemo": "abaluartar",
    "abaluartemos": "abaluartar",
    "abaluartes": "abaluartar",
    "abaluarto": "abaluartar",
    "abaluartou": "abaluartar",
    "abaluartá": "abaluartar",
    "abaluartámo": "abaluartar",
    "abaluartámos": "abaluartar",
    "abaluartáramo": "abaluartar",
    "abaluartáramos": "abaluartar",
    "abaluartárei": "abaluartar",
    "abaluartáreis": "abaluartar",
    "abaluartásseis": "abaluartar",
    "abaluartássemos": "abaluartar",
    "abaluartávamo": "abaluartar",
    "abaluartávamos": "abaluartar",
    "abaluartávei": "abaluartar",
    "abaluartáveis": "abaluartável",
    "abalá": "abalar",
    "abalámo": "abalar",
    "abalámos": "abalar",
    "abaláramo": "abalar",
    "abaláramos": "abalar",
    "abalárei": "abalar",
    "abaláreis": "abalar",
    "abalásseis": "abalar",
    "abalássemos": "abalar",
    "abalávamo": "abalar",
    "abalávamos": "abalar",
    "abalávei": "abalar",
    "abaláveis": "abalável",
    "abam": "abar",
    "abambolina": "abambolinar",
    "abambolinada": "abambolinar",
    "abambolinadas": "abambolinar",
    "abambolinado": "abambolinar",
    "abambolinados": "abambolinar",
    "abambolinai": "abambolinar",
    "abambolinais": "abambolinar",
    "abambolinam": "abambolinar",
    "abambolinamo": "abambolinar",
    "abambolinamos": "abambolinar",
    "abambolinando": "abambolinar",
    "abambolinara": "abambolinar",
    "abambolinaram": "abambolinar",
    "abambolinaras": "abambolinar",
    "abambolinarde": "abambolinar",
    "abambolinardes": "abambolinar",
    "abambolinare": "abambolinar",
    "abambolinarei": "abambolinar",
    "abambolinareis": "abambolinar",
    "abambolinarem": "abambolinar",
    "abambolinaremos": "abambolinar",
    "abambolinares": "abambolinar",
    "abambolinaria": "abambolinar",
    "abambolinariam": "abambolinar",
    "abambolinarias": "abambolinar",
    "abambolinarmo": "abambolinar",
    "abambolinarmos": "abambolinar",
    "abambolinará": "abambolinar",
    "abambolinarás": "abambolinar",
    "abambolinarão": "abambolinar",
    "abambolinaríamos": "abambolinar",
    "abambolinaríeis": "abambolinar",
    "abambolinas": "abambolinar",
    "abambolinasse": "abambolinar",
    "abambolinassem": "abambolinar",
    "abambolinasses": "abambolinar",
    "abambolinaste": "abambolinar",
    "abambolinastes": "abambolinar",
    "abambolinava": "abambolinar",
    "abambolinavam": "abambolinar",
    "abambolinavas": "abambolinar",
    "abamboline": "abambolinar",
    "abambolinei": "abambolinar",
    "abambolineis": "abambolinar",
    "abambolinem": "abambolinar",
    "abambolinemo": "abambolinar",
    "abambolinemos": "abambolinar",
    "abambolines": "abambolinar",
    "abambolino": "abambolinar",
    "abambolinou": "abambolinar",
    "abamboliná": "abambolinar",
    "abambolinámo": "abambolinar",
    "abambolinámos": "abambolinar",
    "abambolináramo": "abambolinar",
    "abambolináramos": "abambolinar",
    "abambolinárei": "abambolinar",
    "abambolináreis": "abambolinar",
    "abambolinásseis": "abambolinar",
    "abambolinássemos": "abambolinar",
    "abambolinávamo": "abambolinar",
    "abambolinávamos": "abambolinar",
    "abambolinávei": "abambolinar",
    "abambolináveis": "abambolinar",
    "abamo": "abar",
    "abamos": "abar",
    "abana": "abanar",
    "abanada": "abanar",
    "abanadas": "abanar",
    "abanadelas": "abanadela",
    "abanado": "abanar",
    "abanadores": "abanador",
    "abanados": "abanar",
    "abanaduras": "abanadura",
    "abanadíssima": "abanado",
    "abanadíssimas": "abanado",
    "abanadíssimo": "abanado",
    "abanadíssimos": "abanado",
    "abanai": "abanar",
    "abanais": "abanar",
    "abanam": "abanar",
    "abanamo": "abanar",
    "abanamos": "abanar",
    "abanana": "abananar",
    "abananada": "abananar",
    "abananadas": "abananar",
    "abananado": "abananar",
    "abananados": "abananar",
    "abananadíssima": "abananado",
    "abananadíssimas": "abananado",
    "abananadíssimo": "abananado",
    "abananadíssimos": "abananado",
    "abananai": "abananar",
    "abananais": "abananar",
    "abananam": "abananar",
    "abananamo": "abananar",
    "abananamos": "abananar",
    "abananando": "abananar",
    "abananara": "abananar",
    "abananaram": "abananar",
    "abananaras": "abananar",
    "abananarde": "abananar",
    "abananardes": "abananar",
    "abananare": "abananar",
    "abananarei": "abananar",
    "abananareis": "abananar",
    "abananarem": "abananar",
    "abananaremos": "abananar",
    "abananares": "abananar",
    "abananaria": "abananar",
    "abananariam": "abananar",
    "abananarias": "abananar",
    "abananarmo": "abananar",
    "abananarmos": "abananar",
    "abananará": "abananar",
    "abananarás": "abananar",
    "abananarão": "abananar",
    "abananaríamos": "abananar",
    "abananaríeis": "abananar",
    "abananas": "abananar",
    "abananasse": "abananar",
    "abananassem": "abananar",
    "abananasses": "abananar",
    "abananaste": "abananar",
    "abananastes": "abananar",
    "abananava": "abananar",
    "abananavam": "abananar",
    "abananavas": "abananar",
    "abanando": "abanar",
    "abanane": "abananar",
    "abananei": "abananar",
    "abananeis": "abananar",
    "abananem": "abananar",
    "abananemo": "abananar",
    "abananemos": "abananar",
    "abananes": "abananar",
    "abanano": "abananar",
    "abananou": "abananar",
    "abananá": "abananar",
    "abananámo": "abananar",
    "abananámos": "abananar",
    "abananáramo": "abananar",
    "abananáramos": "abananar",
    "abananárei": "abananar",
    "abananáreis": "abananar",
    "abananásseis": "abananar",
    "abananássemos": "abananar",
    "abananávamo": "abananar",
    "abananávamos": "abananar",
    "abananávei": "abananar",
    "abananáveis": "abananar",
    "abananços": "abananço",
    "abanara": "abanar",
    "abanaram": "abanar",
    "abanaras": "abanar",
    "abanarde": "abanar",
    "abanardes": "abanar",
    "abanare": "abanar",
    "abanarei": "abanar",
    "abanareis": "abanar",
    "abanarem": "abanar",
    "abanaremos": "abanar",
    "abanares": "abanar",
    "abanaria": "abanar",
    "abanariam": "abanar",
    "abanarias": "abanar",
    "abanarmo": "abanar",
    "abanarmos": "abanar",
    "abanará": "abanar",
    "abanarás": "abanar",
    "abanarão": "abanar",
    "abanaríamos": "abanar",
    "abanaríeis": "abanar",
    "abanas": "abanar",
    "abanasse": "abanar",
    "abanassem": "abanar",
    "abanasses": "abanar",
    "abanaste": "abanar",
    "abanastes": "abanar",
    "abanava": "abanar",
    "abanavam": "abanar",
    "abanavas": "abanar",
    "abanações": "abanação",
    "abanca": "abancar",
    "abancada": "abancar",
    "abancadas": "abancar",
    "abancado": "abancar",
    "abancados": "abancar",
    "abancai": "abancar",
    "abancais": "abancar",
    "abancam": "abancar",
    "abancamo": "abancar",
    "abancamos": "abancar",
    "abancando": "abancar",
    "abancara": "abancar",
    "abancaram": "abancar",
    "abancaras": "abancar",
    "abancarde": "abancar",
    "abancardes": "abancar",
    "abancare": "abancar",
    "abancarei": "abancar",
    "abancareis": "abancar",
    "abancarem": "abancar",
    "abancaremos": "abancar",
    "abancares": "abancar",
    "abancaria": "abancar",
    "abancariam": "abancar",
    "abancarias": "abancar",
    "abancarmo": "abancar",
    "abancarmos": "abancar",
    "abancará": "abancar",
    "abancarás": "abancar",
    "abancarão": "abancar",
    "abancaríamos": "abancar",
    "abancaríeis": "abancar",
    "abancas": "abancar",
    "abancasse": "abancar",
    "abancassem": "abancar",
    "abancasses": "abancar",
    "abancaste": "abancar",
    "abancastes": "abancar",
    "abancava": "abancar",
    "abancavam": "abancar",
    "abancavas": "abancar",
    "abanco": "abancar",
    "abancou": "abancar",
    "abancá": "abancar",
    "abancámo": "abancar",
    "abancámos": "abancar",
    "abancáramo": "abancar",
    "abancáramos": "abancar",
    "abancárei": "abancar",
    "abancáreis": "abancar",
    "abancásseis": "abancar",
    "abancássemos": "abancar",
    "abancávamo": "abancar",
    "abancávamos": "abancar",
    "abancávei": "abancar",
    "abancáveis": "abancar",
    "abanda": "abandar",
    "abandada": "abandar",
    "abandadas": "abandar",
    "abandado": "abandar",
    "abandados": "abandar",
    "abandai": "abandar",
    "abandais": "abandar",
    "abandalha": "abandalhar",
    "abandalhada": "abandalhar",
    "abandalhadas": "abandalhar",
    "abandalhado": "abandalhar",
    "abandalhados": "abandalhar",
    "abandalhadíssima": "abandalhado",
    "abandalhadíssimas": "abandalhado",
    "abandalhadíssimo": "abandalhado",
    "abandalhadíssimos": "abandalhado",
    "abandalhai": "abandalhar",
    "abandalhais": "abandalhar",
    "abandalham": "abandalhar",
    "abandalhamentos": "abandalhamento",
    "abandalhamo": "abandalhar",
    "abandalhamos": "abandalhar",
    "abandalhando": "abandalhar",
    "abandalhara": "abandalhar",
    "abandalharam": "abandalhar",
    "abandalharas": "abandalhar",
    "abandalharde": "abandalhar",
    "abandalhardes": "abandalhar",
    "abandalhare": "abandalhar",
    "abandalharei": "abandalhar",
    "abandalhareis": "abandalhar",
    "abandalharem": "abandalhar",
    "abandalharemos": "abandalhar",
    "abandalhares": "abandalhar",
    "abandalharia": "abandalhar",
    "abandalhariam": "abandalhar",
    "abandalharias": "abandalhar",
    "abandalharmo": "abandalhar",
    "abandalharmos": "abandalhar",
    "abandalhará": "abandalhar",
    "abandalharás": "abandalhar",
    "abandalharão": "abandalhar",
    "abandalharíamos": "abandalhar",
    "abandalharíeis": "abandalhar",
    "abandalhas": "abandalhar",
    "abandalhasse": "abandalhar",
    "abandalhassem": "abandalhar",
    "abandalhasses": "abandalhar",
    "abandalhaste": "abandalhar",
    "abandalhastes": "abandalhar",
    "abandalhava": "abandalhar",
    "abandalhavam": "abandalhar",
    "abandalhavas": "abandalhar",
    "abandalhações": "abandalhação",
    "abandalhe": "abandalhar",
    "abandalhei": "abandalhar",
    "abandalheis": "abandalhar",
    "abandalhem": "abandalhar",
    "abandalhemo": "abandalhar",
    "abandalhemos": "abandalhar",
    "abandalhes": "abandalhar",
    "abandalho": "abandalhar",
    "abandalhou": "abandalhar",
    "abandalhá": "abandalhar",
    "abandalhámo": "abandalhar",
    "abandalhámos": "abandalhar",
    "abandalháramo": "abandalhar",
    "abandalháramos": "abandalhar",
    "abandalhárei": "abandalhar",
    "abandalháreis": "abandalhar",
    "abandalhásseis": "abandalhar",
    "abandalhássemos": "abandalhar",
    "abandalhávamo": "abandalhar",
    "abandalhávamos": "abandalhar",
    "abandalhávei": "abandalhar",
    "abandalháveis": "abandalhável",
    "abandam": "abandar",
    "abandamo": "abandar",
    "abandamos": "abandar",
    "abandando": "abandar",
    "abandara": "abandar",
    "abandaram": "abandar",
    "abandaras": "abandar",
    "abandarde": "abandar",
    "abandardes": "abandar",
    "abandare": "abandar",
    "abandarei": "abandar",
    "abandareis": "abandar",
    "abandarem": "abandar",
    "abandaremos": "abandar",
    "abandares": "abandar",
    "abandaria": "abandar",
    "abandariam": "abandar",
    "abandarias": "abandar",
    "abandarmo": "abandar",
    "abandarmos": "abandar",
    "abandará": "abandar",
    "abandarás": "abandar",
    "abandarão": "abandar",
    "abandaríamos": "abandar",
    "abandaríeis": "abandar",
    "abandas": "abandar",
    "abandasse": "abandar",
    "abandassem": "abandar",
    "abandasses": "abandar",
    "abandaste": "abandar",
    "abandastes": "abandar",
    "abandava": "abandar",
    "abandavam": "abandar",
    "abandavas": "abandar",
    "abande": "abandar",
    "abandeada": "abandear",
    "abandeadas": "abandear",
    "abandeado": "abandear",
    "abandeados": "abandear",
    "abandeai": "abandear",
    "abandeais": "abandear",
    "abandeamo": "abandear",
    "abandeamos": "abandear",
    "abandeando": "abandear",
    "abandeara": "abandear",
    "abandearam": "abandear",
    "abandearas": "abandear",
    "abandearde": "abandear",
    "abandeardes": "abandear",
    "abandeare": "abandear",
    "abandearei": "abandear",
    "abandeareis": "abandear",
    "abandearem": "abandear",
    "abandearemos": "abandear",
    "abandeares": "abandear",
    "abandearia": "abandear",
    "abandeariam": "abandear",
    "abandearias": "abandear",
    "abandearmo": "abandear",
    "abandearmos": "abandear",
    "abandeará": "abandear",
    "abandearás": "abandear",
    "abandearão": "abandear",
    "abandearíamos": "abandear",
    "abandearíeis": "abandear",
    "abandeasse": "abandear",
    "abandeassem": "abandear",
    "abandeasses": "abandear",
    "abandeaste": "abandear",
    "abandeastes": "abandear",
    "abandeava": "abandear",
    "abandeavam": "abandear",
    "abandeavas": "abandear",
    "abandeei": "abandear",
    "abandeeis": "abandear",
    "abandeemo": "abandear",
    "abandeemos": "abandear",
    "abandei": "abandar",
    "abandeia": "abandear",
    "abandeiam": "abandear",
    "abandeias": "abandear",
    "abandeie": "abandear",
    "abandeiem": "abandear",
    "abandeies": "abandear",
    "abandeio": "abandear",
    "abandeira": "abandeirar",
    "abandeirada": "abandeirar",
    "abandeiradas": "abandeirar",
    "abandeirado": "abandeirar",
    "abandeirados": "abandeirar",
    "abandeirai": "abandeirar",
    "abandeirais": "abandeirar",
    "abandeiram": "abandeirar",
    "abandeiramo": "abandeirar",
    "abandeiramos": "abandeirar",
    "abandeirando": "abandeirar",
    "abandeirara": "abandeirar",
    "abandeiraram": "abandeirar",
    "abandeiraras": "abandeirar",
    "abandeirarde": "abandeirar",
    "abandeirardes": "abandeirar",
    "abandeirare": "abandeirar",
    "abandeirarei": "abandeirar",
    "abandeirareis": "abandeirar",
    "abandeirarem": "abandeirar",
    "abandeiraremos": "abandeirar",
    "abandeirares": "abandeirar",
    "abandeiraria": "abandeirar",
    "abandeirariam": "abandeirar",
    "abandeirarias": "abandeirar",
    "abandeirarmo": "abandeirar",
    "abandeirarmos": "abandeirar",
    "abandeirará": "abandeirar",
    "abandeirarás": "abandeirar",
    "abandeirarão": "abandeirar",
    "abandeiraríamos": "abandeirar",
    "abandeiraríeis": "abandeirar",
    "abandeiras": "abandeirar",
    "abandeirasse": "abandeirar",
    "abandeirassem": "abandeirar",
    "abandeirasses": "abandeirar",
    "abandeiraste": "abandeirar",
    "abandeirastes": "abandeirar",
    "abandeirava": "abandeirar",
    "abandeiravam": "abandeirar",
    "abandeiravas": "abandeirar",
    "abandeire": "abandeirar",
    "abandeirei": "abandeirar",
    "abandeireis": "abandeirar",
    "abandeirem": "abandeirar",
    "abandeiremo": "abandeirar",
    "abandeiremos": "abandeirar",
    "abandeires": "abandeirar",
    "abandeiro": "abandeirar",
    "abandeirou": "abandeirar",
    "abandeirá": "abandeirar",
    "abandeirámo": "abandeirar",
    "abandeirámos": "abandeirar",
    "abandeiráramo": "abandeirar",
    "abandeiráramos": "abandeirar",
    "abandeirárei": "abandeirar",
    "abandeiráreis": "abandeirar",
    "abandeirásseis": "abandeirar",
    "abandeirássemos": "abandeirar",
    "abandeirávamo": "abandeirar",
    "abandeirávamos": "abandeirar",
    "abandeirávei": "abandeirar",
    "abandeiráveis": "abandeirar",
    "abandeis": "abandar",
    "abandeja": "abandejar",
    "abandejada": "abandejar",
    "abandejadas": "abandejar",
    "abandejado": "abandejar",
    "abandejados": "abandejar",
    "abandejai": "abandejar",
    "abandejais": "abandejar",
    "abandejam": "abandejar",
    "abandejamo": "abandejar",
    "abandejamos": "abandejar",
    "abandejando": "abandejar",
    "abandejara": "abandejar",
    "abandejaram": "abandejar",
    "abandejaras": "abandejar",
    "abandejarde": "abandejar",
    "abandejardes": "abandejar",
    "abandejare": "abandejar",
    "abandejarei": "abandejar",
    "abandejareis": "abandejar",
    "abandejarem": "abandejar",
    "abandejaremos": "abandejar",
    "abandejares": "abandejar",
    "abandejaria": "abandejar",
    "abandejariam": "abandejar",
    "abandejarias": "abandejar",
    "abandejarmo": "abandejar",
    "abandejarmos": "abandejar",
    "abandejará": "abandejar",
    "abandejarás": "abandejar",
    "abandejarão": "abandejar",
    "abandejaríamos": "abandejar",
    "abandejaríeis": "abandejar",
    "abandejas": "abandejar",
    "abandejasse": "abandejar",
    "abandejassem": "abandejar",
    "abandejasses": "abandejar",
    "abandejaste": "abandejar",
    "abandejastes": "abandejar",
    "abandejava": "abandejar",
    "abandejavam": "abandejar",
    "abandejavas": "abandejar",
    "abandeje": "abandejar",
    "abandejei": "abandejar",
    "abandejeis": "abandejar",
    "abandejem": "abandejar",
    "abandejemo": "abandejar",
    "abandejemos": "abandejar",
    "abandejes": "abandejar",
    "abandejo": "abandejar",
    "abandejos": "abandejo",
    "abandejou": "abandejar",
    "abandejá": "abandejar",
    "abandejámo": "abandejar",
    "abandejámos": "abandejar",
    "abandejáramo": "abandejar",
    "abandejáramos": "abandejar",
    "abandejárei": "abandejar",
    "abandejáreis": "abandejar",
    "abandejásseis": "abandejar",
    "abandejássemos": "abandejar",
    "abandejávamo": "abandejar",
    "abandejávamos": "abandejar",
    "abandejávei": "abandejar",
    "abandejáveis": "abandejar",
    "abandem": "abandar",
    "abandemo": "abandar",
    "abandemos": "abandar",
    "abandeou": "abandear",
    "abandes": "abandar",
    "abandeá": "abandear",
    "abandeámo": "abandear",
    "abandeámos": "abandear",
    "abandeáramo": "abandear",
    "abandeáramos": "abandear",
    "abandeárei": "abandear",
    "abandeáreis": "abandear",
    "abandeásseis": "abandear",
    "abandeássemos": "abandear",
    "abandeávamo": "abandear",
    "abandeávamos": "abandear",
    "abandeávei": "abandear",
    "abandeáveis": "abandear",
    "abandida": "abandidar",
    "abandidada": "abandidar",
    "abandidadas": "abandidar",
    "abandidado": "abandidar",
    "abandidados": "abandidar",
    "abandidai": "abandidar",
    "abandidais": "abandidar",
    "abandidam": "abandidar",
    "abandidamo": "abandidar",
    "abandidamos": "abandidar",
    "abandidando": "abandidar",
    "abandidara": "abandidar",
    "abandidaram": "abandidar",
    "abandidaras": "abandidar",
    "abandidarde": "abandidar",
    "abandidardes": "abandidar",
    "abandidare": "abandidar",
    "abandidarei": "abandidar",
    "abandidareis": "abandidar",
    "abandidarem": "abandidar",
    "abandidaremos": "abandidar",
    "abandidares": "abandidar",
    "abandidaria": "abandidar",
    "abandidariam": "abandidar",
    "abandidarias": "abandidar",
    "abandidarmo": "abandidar",
    "abandidarmos": "abandidar",
    "abandidará": "abandidar",
    "abandidarás": "abandidar",
    "abandidarão": "abandidar",
    "abandidaríamos": "abandidar",
    "abandidaríeis": "abandidar",
    "abandidas": "abandidar",
    "abandidasse": "abandidar",
    "abandidassem": "abandidar",
    "abandidasses": "abandidar",
    "abandidaste": "abandidar",
    "abandidastes": "abandidar",
    "abandidava": "abandidar",
    "abandidavam": "abandidar",
    "abandidavas": "abandidar",
    "abandide": "abandidar",
    "abandidei": "abandidar",
    "abandideis": "abandidar",
    "abandidem": "abandidar",
    "abandidemo": "abandidar",
    "abandidemos": "abandidar",
    "abandides": "abandidar",
    "abandido": "abandidar",
    "abandidou": "abandidar",
    "abandidá": "abandidar",
    "abandidámo": "abandidar",
    "abandidámos": "abandidar",
    "abandidáramo": "abandidar",
    "abandidáramos": "abandidar",
    "abandidárei": "abandidar",
    "abandidáreis": "abandidar",
    "abandidásseis": "abandidar",
    "abandidássemos": "abandidar",
    "abandidávamo": "abandidar",
    "abandidávamos": "abandidar",
    "abandidávei": "abandidar",
    "abandidáveis": "abandidar",
    "abando": "abar",
    "abandoa": "abandoar",
    "abandoada": "abandoar",
    "abandoadas": "abandoar",
    "abandoado": "abandoar",
    "abandoadora": "abandoador",
    "abandoadoras": "abandoador",
    "abandoadores": "abandoador",
    "abandoados": "abandoar",
    "abandoai": "abandoar",
    "abandoais": "abandoar",
    "abandoam": "abandoar",
    "abandoamo": "abandoar",
    "abandoamos": "abandoar",
    "abandoando": "abandoar",
    "abandoara": "abandoar",
    "abandoaram": "abandoar",
    "abandoaras": "abandoar",
    "abandoarde": "abandoar",
    "abandoardes": "abandoar",
    "abandoare": "abandoar",
    "abandoarei": "abandoar",
    "abandoareis": "abandoar",
    "abandoarem": "abandoar",
    "abandoaremos": "abandoar",
    "abandoares": "abandoar",
    "abandoaria": "abandoar",
    "abandoariam": "abandoar",
    "abandoarias": "abandoar",
    "abandoarmo": "abandoar",
    "abandoarmos": "abandoar",
    "abandoará": "abandoar",
    "abandoarás": "abandoar",
    "abandoarão": "abandoar",
    "abandoaríamos": "abandoar",
    "abandoaríeis": "abandoar",
    "abandoas": "abandoar",
    "abandoasse": "abandoar",
    "abandoassem": "abandoar",
    "abandoasses": "abandoar",
    "abandoaste": "abandoar",
    "abandoastes": "abandoar",
    "abandoava": "abandoar",
    "abandoavam": "abandoar",
    "abandoavas": "abandoar",
    "abandoe": "abandoar",
    "abandoei": "abandoar",
    "abandoeis": "abandoar",
    "abandoem": "abandoar",
    "abandoemo": "abandoar",
    "abandoemos": "abandoar",
    "abandoes": "abandoar",
    "abandona": "abandonar",
    "abandonada": "abandonar",
    "abandonadas": "abandonar",
    "abandonado": "abandonar",
    "abandonados": "abandonar",
    "abandonadíssima": "abandonado",
    "abandonadíssimas": "abandonado",
    "abandonadíssimo": "abandonado",
    "abandonadíssimos": "abandonado",
    "abandonai": "abandonar",
    "abandonais": "abandonar",
    "abandonam": "abandonar",
    "abandonamentos": "abandonamento",
    "abandonamo": "abandonar",
    "abandonamos": "abandonar",
    "abandonando": "abandonar",
    "abandonara": "abandonar",
    "abandonaram": "abandonar",
    "abandonaras": "abandonar",
    "abandonarde": "abandonar",
    "abandonardes": "abandonar",
    "abandonare": "abandonar",
    "abandonarei": "abandonar",
    "abandonareis": "abandonar",
    "abandonarem": "abandonar",
    "abandonaremos": "abandonar",
    "abandonares": "abandonar",
    "abandonaria": "abandonar",
    "abandonariam": "abandonar",
    "abandonarias": "abandonar",
    "abandonarmo": "abandonar",
    "abandonarmos": "abandonar",
    "abandonará": "abandonar",
    "abandonarás": "abandonar",
    "abandonarão": "abandonar",
    "abandonaríamos": "abandonar",
    "abandonaríeis": "abandonar",
    "abandonas": "abandonar",
    "abandonasse": "abandonar",
    "abandonassem": "abandonar",
    "abandonasses": "abandonar",
    "abandonaste": "abandonar",
    "abandonastes": "abandonar",
    "abandonatária": "abandonatário",
    "abandonatárias": "abandonatário",
    "abandonatários": "abandonatário",
    "abandonava": "abandonar",
    "abandonavam": "abandonar",
    "abandonavas": "abandonar",
    "abandone": "abandonar",
    "abandonei": "abandonar",
    "abandoneis": "abandonar",
    "abandonem": "abandonar",
    "abandonemo": "abandonar",
    "abandonemos": "abandonar",
    "abandones": "abandonar",
    "abandono": "abandonar",
    "abandonos": "abandono",
    "abandonou": "abandonar",
    "abandoná": "abandonar",
    "abandonámo": "abandonar",
    "abandonámos": "abandonar",
    "abandonáramo": "abandonar",
    "abandonáramos": "abandonar",
    "abandonárei": "abandonar",
    "abandonáreis": "abandonar",
    "abandonásseis": "abandonar",
    "abandonássemos": "abandonar",
    "abandonávamo": "abandonar",
    "abandonávamos": "abandonar",
    "abandonávei": "abandonar",
    "abandonáveis": "abandonável",
    "abandoo": "abandoar",
    "abandoou": "abandoar",
    "abandou": "abandar",
    "abandoá": "abandoar",
    "abandoámo": "abandoar",
    "abandoámos": "abandoar",
    "abandoáramo": "abandoar",
    "abandoáramos": "abandoar",
    "abandoárei": "abandoar",
    "abandoáreis": "abandoar",
    "abandoásseis": "abandoar",
    "abandoássemos": "abandoar",
    "abandoávamo": "abandoar",
    "abandoávamos": "abandoar",
    "abandoávei": "abandoar",
    "abandoáveis": "abandoar",
    "abandá": "abandar",
    "abandámo": "abandar",
    "abandámos": "abandar",
    "abandáramo": "abandar",
    "abandáramos": "abandar",
    "abandárei": "abandar",
    "abandáreis": "abandar",
    "abandásseis": "abandar",
    "abandássemos": "abandar",
    "abandávamo": "abandar",
    "abandávamos": "abandar",
    "abandávei": "abandar",
    "abandáveis": "abandar",
    "abane": "abanar",
    "abanei": "abanar",
    "abaneiros": "abaneiro",
    "abaneis": "abanar",
    "abanem": "abanar",
    "abanemo": "abanar",
    "abanemos": "abanar",
    "abanes": "abanar",
    "abangas": "abanga",
    "abanica": "abanicar",
    "abanicada": "abanicar",
    "abanicadas": "abanicar",
    "abanicado": "abanicar",
    "abanicados": "abanicar",
    "abanicai": "abanicar",
    "abanicais": "abanicar",
    "abanicam": "abanicar",
    "abanicamo": "abanicar",
    "abanicamos": "abanicar",
    "abanicando": "abanicar",
    "abanicara": "abanicar",
    "abanicaram": "abanicar",
    "abanicaras": "abanicar",
    "abanicarde": "abanicar",
    "abanicardes": "abanicar",
    "abanicare": "abanicar",
    "abanicarei": "abanicar",
    "abanicareis": "abanicar",
    "abanicarem": "abanicar",
    "abanicaremos": "abanicar",
    "abanicares": "abanicar",
    "abanicaria": "abanicar",
    "abanicariam": "abanicar",
    "abanicarias": "abanicar",
    "abanicarmo": "abanicar",
    "abanicarmos": "abanicar",
    "abanicará": "abanicar",
    "abanicarás": "abanicar",
    "abanicarão": "abanicar",
    "abanicaríamos": "abanicar",
    "abanicaríeis": "abanicar",
    "abanicas": "abanicar",
    "abanicasse": "abanicar",
    "abanicassem": "abanicar",
    "abanicasses": "abanicar",
    "abanicaste": "abanicar",
    "abanicastes": "abanicar",
    "abanicava": "abanicar",
    "abanicavam": "abanicar",
    "abanicavas": "abanicar",
    "abanico": "abanicar",
    "abanicos": "abanico",
    "abanicou": "abanicar",
    "abanicá": "abanicar",
    "abanicámo": "abanicar",
    "abanicámos": "abanicar",
    "abanicáramo": "abanicar",
    "abanicáramos": "abanicar",
    "abanicárei": "abanicar",
    "abanicáreis": "abanicar",
    "abanicásseis": "abanicar",
    "abanicássemos": "abanicar",
    "abanicávamo": "abanicar",
    "abanicávamos": "abanicar",
    "abanicávei": "abanicar",
    "abanicáveis": "abanicar",
    "abanique": "abanicar",
    "abaniquei": "abanicar",
    "abaniqueis": "abanicar",
    "abaniquem": "abanicar",
    "abaniquemo": "abanicar",
    "abaniquemos": "abanicar",
    "abaniques": "abanicar",
    "abano": "abanar",
    "abanos": "abano",
    "abanou": "abanar",
    "abanque": "abancar",
    "abanquei": "abancar",
    "abanqueis": "abancar",
    "abanquem": "abancar",
    "abanquemo": "abancar",
    "abanquemos": "abancar",
    "abanques": "abancar",
    "abantesmas": "abantesma",
    "abaná": "abanar",
    "abanámo": "abanar",
    "abanámos": "abanar",
    "abanáramo": "abanar",
    "abanáramos": "abanar",
    "abanárei": "abanar",
    "abanáreis": "abanar",
    "abanásseis": "abanar",
    "abanássemos": "abanar",
    "abanávamo": "abanar",
    "abanávamos": "abanar",
    "abanávei": "abanar",
    "abanáveis": "abanável",
    "abanões": "abanão",
    "abaqueta": "abaquetar",
    "abaquetada": "abaquetar",
    "abaquetadas": "abaquetar",
    "abaquetado": "abaquetar",
    "abaquetados": "abaquetar",
    "abaquetai": "abaquetar",
    "abaquetais": "abaquetar",
    "abaquetam": "abaquetar",
    "abaquetamo": "abaquetar",
    "abaquetamos": "abaquetar",
    "abaquetando": "abaquetar",
    "abaquetara": "abaquetar",
    "abaquetaram": "abaquetar",
    "abaquetaras": "abaquetar",
    "abaquetarde": "abaquetar",
    "abaquetardes": "abaquetar",
    "abaquetare": "abaquetar",
    "abaquetarei": "abaquetar",
    "abaquetareis": "abaquetar",
    "abaquetarem": "abaquetar",
    "abaquetaremos": "abaquetar",
    "abaquetares": "abaquetar",
    "abaquetaria": "abaquetar",
    "abaquetariam": "abaquetar",
    "abaquetarias": "abaquetar",
    "abaquetarmo": "abaquetar",
    "abaquetarmos": "abaquetar",
    "abaquetará": "abaquetar",
    "abaquetarás": "abaquetar",
    "abaquetarão": "abaquetar",
    "abaquetaríamos": "abaquetar",
    "abaquetaríeis": "abaquetar",
    "abaquetas": "abaquetar",
    "abaquetasse": "abaquetar",
    "abaquetassem": "abaquetar",
    "abaquetasses": "abaquetar",
    "abaquetaste": "abaquetar",
    "abaquetastes": "abaquetar",
    "abaquetava": "abaquetar",
    "abaquetavam": "abaquetar",
    "abaquetavas": "abaquetar",
    "abaquete": "abaquetar",
    "abaquetei": "abaquetar",
    "abaqueteis": "abaquetar",
    "abaquetem": "abaquetar",
    "abaquetemo": "abaquetar",
    "abaquetemos": "abaquetar",
    "abaquetes": "abaquetar",
    "abaqueto": "abaquetar",
    "abaquetou": "abaquetar",
    "abaquetá": "abaquetar",
    "abaquetámo": "abaquetar",
    "abaquetámos": "abaquetar",
    "abaquetáramo": "abaquetar",
    "abaquetáramos": "abaquetar",
    "abaquetárei": "abaquetar",
    "abaquetáreis": "abaquetar",
    "abaquetásseis": "abaquetar",
    "abaquetássemos": "abaquetar",
    "abaquetávamo": "abaquetar",
    "abaquetávamos": "abaquetar",
    "abaquetávei": "abaquetar",
    "abaquetáveis": "abaquetar",
    "abara": "abar",
    "abaram": "abar",
    "abaras": "abar",
    "abarata": "abaratar",
    "abaratada": "abaratar",
    "abaratadas": "abaratar",
    "abaratado": "abaratar",
    "abaratados": "abaratar",
    "abaratai": "abaratar",
    "abaratais": "abaratar",
    "abaratam": "abaratar",
    "abaratamo": "abaratar",
    "abaratamos": "abaratar",
    "abaratando": "abaratar",
    "abaratara": "abaratar",
    "abarataram": "abaratar",
    "abarataras": "abaratar",
    "abaratarde": "abaratar",
    "abaratardes": "abaratar",
    "abaratare": "abaratar",
    "abaratarei": "abaratar",
    "abaratareis": "abaratar",
    "abaratarem": "abaratar",
    "abarataremos": "abaratar",
    "abaratares": "abaratar",
    "abarataria": "abaratar",
    "abaratariam": "abaratar",
    "abaratarias": "abaratar",
    "abaratarmo": "abaratar",
    "abaratarmos": "abaratar",
    "abaratará": "abaratar",
    "abaratarás": "abaratar",
    "abaratarão": "abaratar",
    "abarataríamos": "abaratar",
    "abarataríeis": "abaratar",
    "abaratas": "abaratar",
    "abaratasse": "abaratar",
    "abaratassem": "abaratar",
    "abaratasses": "abaratar",
    "abarataste": "abaratar",
    "abaratastes": "abaratar",
    "abaratava": "abaratar",
    "abaratavam": "abaratar",
    "abaratavas": "abaratar",
    "abarate": "abaratar",
    "abaratei": "abaratar",
    "abarateis": "abaratar",
    "abaratem": "abaratar",
    "abaratemo": "abaratar",
    "abaratemos": "abaratar",
    "abarates": "abaratar",
    "abarato": "abaratar",
    "abaratou": "abaratar",
    "abaratá": "abaratar",
    "abaratámo": "abaratar",
    "abaratámos": "abaratar",
    "abaratáramo": "abaratar",
    "abaratáramos": "abaratar",
    "abaratárei": "abaratar",
    "abaratáreis": "abaratar",
    "abaratásseis": "abaratar",
    "abaratássemos": "abaratar",
    "abaratávamo": "abaratar",
    "abaratávamos": "abaratar",
    "abaratávei": "abaratar",
    "abaratáveis": "abaratar",
    "abarba": "abarbar",
    "abarbada": "abarbar",
    "abarbadas": "abarbar",
    "abarbado": "abarbar",
    "abarbados": "abarbar",
    "abarbai": "abarbar",
    "abarbais": "abarbar",
    "abarbam": "abarbar",
    "abarbamo": "abarbar",
    "abarbamos": "abarbar",
    "abarbando": "abarbar",
    "abarbara": "abarbar",
    "abarbaram": "abarbar",
    "abarbaras": "abarbar",
    "abarbarde": "abarbar",
    "abarbardes": "abarbar",
    "abarbare": "abarbar",
    "abarbarei": "abarbar",
    "abarbareis": "abarbar",
    "abarbarem": "abarbar",
    "abarbaremos": "abarbar",
    "abarbares": "abarbar",
    "abarbaria": "abarbar",
    "abarbariam": "abarbar",
    "abarbarias": "abarbar",
    "abarbariza": "abarbarizar",
    "abarbarizada": "abarbarizar",
    "abarbarizadas": "abarbarizar",
    "abarbarizado": "abarbarizar",
    "abarbarizados": "abarbarizar",
    "abarbarizai": "abarbarizar",
    "abarbarizais": "abarbarizar",
    "abarbarizam": "abarbarizar",
    "abarbarizamo": "abarbarizar",
    "abarbarizamos": "abarbarizar",
    "abarbarizando": "abarbarizar",
    "abarbarizara": "abarbarizar",
    "abarbarizaram": "abarbarizar",
    "abarbarizaras": "abarbarizar",
    "abarbarizarde": "abarbarizar",
    "abarbarizardes": "abarbarizar",
    "abarbarizare": "abarbarizar",
    "abarbarizarei": "abarbarizar",
    "abarbarizareis": "abarbarizar",
    "abarbarizarem": "abarbarizar",
    "abarbarizaremos": "abarbarizar",
    "abarbarizares": "abarbarizar",
    "abarbarizaria": "abarbarizar",
    "abarbarizariam": "abarbarizar",
    "abarbarizarias": "abarbarizar",
    "abarbarizarmo": "abarbarizar",
    "abarbarizarmos": "abarbarizar",
    "abarbarizará": "abarbarizar",
    "abarbarizarás": "abarbarizar",
    "abarbarizarão": "abarbarizar",
    "abarbarizaríamos": "abarbarizar",
    "abarbarizaríeis": "abarbarizar",
    "abarbarizas": "abarbarizar",
    "abarbarizasse": "abarbarizar",
    "abarbarizassem": "abarbarizar",
    "abarbarizasses": "abarbarizar",
    "abarbarizaste": "abarbarizar",
    "abarbarizastes": "abarbarizar",
    "abarbarizava": "abarbarizar",
    "abarbarizavam": "abarbarizar",
    "abarbarizavas": "abarbarizar",
    "abarbarize": "abarbarizar",
    "abarbarizei": "abarbarizar",
    "abarbarizeis": "abarbarizar",
    "abarbarizem": "abarbarizar",
    "abarbarizemo": "abarbarizar",
    "abarbarizemos": "abarbarizar",
    "abarbarizes": "abarbarizar",
    "abarbarizo": "abarbarizar",
    "abarbarizou": "abarbarizar",
    "abarbarizá": "abarbarizar",
    "abarbarizámo": "abarbarizar",
    "abarbarizámos": "abarbarizar",
    "abarbarizáramo": "abarbarizar",
    "abarbarizáramos": "abarbarizar",
    "abarbarizárei": "abarbarizar",
    "abarbarizáreis": "abarbarizar",
    "abarbarizásseis": "abarbarizar",
    "abarbarizássemos": "abarbarizar",
    "abarbarizávamo": "abarbarizar",
    "abarbarizávamos": "abarbarizar",
    "abarbarizávei": "abarbarizar",
    "abarbarizáveis": "abarbarizar",
    "abarbarmo": "abarbar",
    "abarbarmos": "abarbar",
    "abarbará": "abarbar",
    "abarbarás": "abarbar",
    "abarbarão": "abarbar",
    "abarbaríamos": "abarbar",
    "abarbaríeis": "abarbar",
    "abarbas": "abarbar",
    "abarbasse": "abarbar",
    "abarbassem": "abarbar",
    "abarbasses": "abarbar",
    "abarbaste": "abarbar",
    "abarbastes": "abarbar",
    "abarbata": "abarbatar",
    "abarbatada": "abarbatar",
    "abarbatadas": "abarbatar",
    "abarbatado": "abarbatar",
    "abarbatados": "abarbatar",
    "abarbatai": "abarbatar",
    "abarbatais": "abarbatar",
    "abarbatam": "abarbatar",
    "abarbatamo": "abarbatar",
    "abarbatamos": "abarbatar",
    "abarbatando": "abarbatar",
    "abarbatara": "abarbatar",
    "abarbataram": "abarbatar",
    "abarbataras": "abarbatar",
    "abarbatarde": "abarbatar",
    "abarbatardes": "abarbatar",
    "abarbatare": "abarbatar",
    "abarbatarei": "abarbatar",
    "abarbatareis": "abarbatar",
    "abarbatarem": "abarbatar",
    "abarbataremos": "abarbatar",
    "abarbatares": "abarbatar",
    "abarbataria": "abarbatar",
    "abarbatariam": "abarbatar",
    "abarbatarias": "abarbatar",
    "abarbatarmo": "abarbatar",
    "abarbatarmos": "abarbatar",
    "abarbatará": "abarbatar",
    "abarbatarás": "abarbatar",
    "abarbatarão": "abarbatar",
    "abarbataríamos": "abarbatar",
    "abarbataríeis": "abarbatar",
    "abarbatas": "abarbatar",
    "abarbatasse": "abarbatar",
    "abarbatassem": "abarbatar",
    "abarbatasses": "abarbatar",
    "abarbataste": "abarbatar",
    "abarbatastes": "abarbatar",
    "abarbatava": "abarbatar",
    "abarbatavam": "abarbatar",
    "abarbatavas": "abarbatar",
    "abarbate": "abarbatar",
    "abarbatei": "abarbatar",
    "abarbateis": "abarbatar",
    "abarbatem": "abarbatar",
    "abarbatemo": "abarbatar",
    "abarbatemos": "abarbatar",
    "abarbates": "abarbatar",
    "abarbato": "abarbatar",
    "abarbatou": "abarbatar",
    "abarbatá": "abarbatar",
    "abarbatámo": "abarbatar",
    "abarbatámos": "abarbatar",
    "abarbatáramo": "abarbatar",
    "abarbatáramos": "abarbatar",
    "abarbatárei": "abarbatar",
    "abarbatáreis": "abarbatar",
    "abarbatásseis": "abarbatar",
    "abarbatássemos": "abarbatar",
    "abarbatávamo": "abarbatar",
    "abarbatávamos": "abarbatar",
    "abarbatávei": "abarbatar",
    "abarbatáveis": "abarbatar",
    "abarbava": "abarbar",
    "abarbavam": "abarbar",
    "abarbavas": "abarbar",
    "abarbe": "abarbar",
    "abarbei": "abarbar",
    "abarbeis": "abarbar",
    "abarbela": "abarbelar",
    "abarbelada": "abarbelar",
    "abarbeladas": "abarbelar",
    "abarbelado": "abarbelar",
    "abarbelados": "abarbelar",
    "abarbelai": "abarbelar",
    "abarbelais": "abarbelar",
    "abarbelam": "abarbelar",
    "abarbelamo": "abarbelar",
    "abarbelamos": "abarbelar",
    "abarbelando": "abarbelar",
    "abarbelara": "abarbelar",
    "abarbelaram": "abarbelar",
    "abarbelaras": "abarbelar",
    "abarbelarde": "abarbelar",
    "abarbelardes": "abarbelar",
    "abarbelare": "abarbelar",
    "abarbelarei": "abarbelar",
    "abarbelareis": "abarbelar",
    "abarbelarem": "abarbelar",
    "abarbelaremos": "abarbelar",
    "abarbelares": "abarbelar",
    "abarbelaria": "abarbelar",
    "abarbelariam": "abarbelar",
    "abarbelarias": "abarbelar",
    "abarbelarmo": "abarbelar",
    "abarbelarmos": "abarbelar",
    "abarbelará": "abarbelar",
    "abarbelarás": "abarbelar",
    "abarbelarão": "abarbelar",
    "abarbelaríamos": "abarbelar",
    "abarbelaríeis": "abarbelar",
    "abarbelas": "abarbelar",
    "abarbelasse": "abarbelar",
    "abarbelassem": "abarbelar",
    "abarbelasses": "abarbelar",
    "abarbelaste": "abarbelar",
    "abarbelastes": "abarbelar",
    "abarbelava": "abarbelar",
    "abarbelavam": "abarbelar",
    "abarbelavas": "abarbelar",
    "abarbele": "abarbelar",
    "abarbelei": "abarbelar",
    "abarbeleis": "abarbelar",
    "abarbelem": "abarbelar",
    "abarbelemo": "abarbelar",
    "abarbelemos": "abarbelar",
    "abarbeles": "abarbelar",
    "abarbelo": "abarbelar",
    "abarbelou": "abarbelar",
    "abarbelá": "abarbelar",
    "abarbelámo": "abarbelar",
    "abarbelámos": "abarbelar",
    "abarbeláramo": "abarbelar",
    "abarbeláramos": "abarbelar",
    "abarbelárei": "abarbelar",
    "abarbeláreis": "abarbelar",
    "abarbelásseis": "abarbelar",
    "abarbelássemos": "abarbelar",
    "abarbelávamo": "abarbelar",
    "abarbelávamos": "abarbelar",
    "abarbelávei": "abarbelar",
    "abarbeláveis": "abarbelar",
    "abarbem": "abarbar",
    "abarbemo": "abarbar",
    "abarbemos": "abarbar",
    "abarbes": "abarbar",
    "abarbeta": "abarbetar",
    "abarbetada": "abarbetar",
    "abarbetadas": "abarbetar",
    "abarbetado": "abarbetar",
    "abarbetados": "abarbetar",
    "abarbetai": "abarbetar",
    "abarbetais": "abarbetar",
    "abarbetam": "abarbetar",
    "abarbetamo": "abarbetar",
    "abarbetamos": "abarbetar",
    "abarbetando": "abarbetar",
    "abarbetara": "abarbetar",
    "abarbetaram": "abarbetar",
    "abarbetaras": "abarbetar",
    "abarbetarde": "abarbetar",
    "abarbetardes": "abarbetar",
    "abarbetare": "abarbetar",
    "abarbetarei": "abarbetar",
    "abarbetareis": "abarbetar",
    "abarbetarem": "abarbetar",
    "abarbetaremos": "abarbetar",
    "abarbetares": "abarbetar",
    "abarbetaria": "abarbetar",
    "abarbetariam": "abarbetar",
    "abarbetarias": "abarbetar",
    "abarbetarmo": "abarbetar",
    "abarbetarmos": "abarbetar",
    "abarbetará": "abarbetar",
    "abarbetarás": "abarbetar",
    "abarbetarão": "abarbetar",
    "abarbetaríamos": "abarbetar",
    "abarbetaríeis": "abarbetar",
    "abarbetas": "abarbetar",
    "abarbetasse": "abarbetar",
    "abarbetassem": "abarbetar",
    "abarbetasses": "abarbetar",
    "abarbetaste": "abarbetar",
    "abarbetastes": "abarbetar",
    "abarbetava": "abarbetar",
    "abarbetavam": "abarbetar",
    "abarbetavas": "abarbetar",
    "abarbete": "abarbetar",
    "abarbetei": "abarbetar",
    "abarbeteis": "abarbetar",
    "abarbetem": "abarbetar",
    "abarbetemo": "abarbetar",
    "abarbetemos": "abarbetar",
    "abarbetes": "abarbetar",
    "abarbeto": "abarbetar",
    "abarbetou": "abarbetar",
    "abarbetá": "abarbetar",
    "abarbetámo": "abarbetar",
    "abarbetámos": "abarbetar",
    "abarbetáramo": "abarbetar",
    "abarbetáramos": "abarbetar",
    "abarbetárei": "abarbetar",
    "abarbetáreis": "abarbetar",
    "abarbetásseis": "abarbetar",
    "abarbetássemos": "abarbetar",
    "abarbetávamo": "abarbetar",
    "abarbetávamos": "abarbetar",
    "abarbetávei": "abarbetar",
    "abarbetáveis": "abarbetar",
    "abarbilha": "abarbilhar",
    "abarbilhada": "abarbilhar",
    "abarbilhadas": "abarbilhar",
    "abarbilhado": "abarbilhar",
    "abarbilhados": "abarbilhar",
    "abarbilhai": "abarbilhar",
    "abarbilhais": "abarbilhar",
    "abarbilham": "abarbilhar",
    "abarbilhamo": "abarbilhar",
    "abarbilhamos": "abarbilhar",
    "abarbilhando": "abarbilhar",
    "abarbilhara": "abarbilhar",
    "abarbilharam": "abarbilhar",
    "abarbilharas": "abarbilhar",
    "abarbilharde": "abarbilhar",
    "abarbilhardes": "abarbilhar",
    "abarbilhare": "abarbilhar",
    "abarbilharei": "abarbilhar",
    "abarbilhareis": "abarbilhar",
    "abarbilharem": "abarbilhar",
    "abarbilharemos": "abarbilhar",
    "abarbilhares": "abarbilhar",
    "abarbilharia": "abarbilhar",
    "abarbilhariam": "abarbilhar",
    "abarbilharias": "abarbilhar",
    "abarbilharmo": "abarbilhar",
    "abarbilharmos": "abarbilhar",
    "abarbilhará": "abarbilhar",
    "abarbilharás": "abarbilhar",
    "abarbilharão": "abarbilhar",
    "abarbilharíamos": "abarbilhar",
    "abarbilharíeis": "abarbilhar",
    "abarbilhas": "abarbilhar",
    "abarbilhasse": "abarbilhar",
    "abarbilhassem": "abarbilhar",
    "abarbilhasses": "abarbilhar",
    "abarbilhaste": "abarbilhar",
    "abarbilhastes": "abarbilhar",
    "abarbilhava": "abarbilhar",
    "abarbilhavam": "abarbilhar",
    "abarbilhavas": "abarbilhar",
    "abarbilhe": "abarbilhar",
    "abarbilhei": "abarbilhar",
    "abarbilheis": "abarbilhar",
    "abarbilhem": "abarbilhar",
    "abarbilhemo": "abarbilhar",
    "abarbilhemos": "abarbilhar",
    "abarbilhes": "abarbilhar",
    "abarbilho": "abarbilhar",
    "abarbilhou": "abarbilhar",
    "abarbilhá": "abarbilhar",
    "abarbilhámo": "abarbilhar",
    "abarbilhámos": "abarbilhar",
    "abarbilháramo": "abarbilhar",
    "abarbilháramos": "abarbilhar",
    "abarbilhárei": "abarbilhar",
    "abarbilháreis": "abarbilhar",
    "abarbilhásseis": "abarbilhar",
    "abarbilhássemos": "abarbilhar",
    "abarbilhávamo": "abarbilhar",
    "abarbilhávamos": "abarbilhar",
    "abarbilhávei": "abarbilhar",
    "abarbilháveis": "abarbilhar",
    "abarbo": "abarbar",
    "abarbou": "abarbar",
    "abarbá": "abarbar",
    "abarbámo": "abarbar",
    "abarbámos": "abarbar",
    "abarbáramo": "abarbar",
    "abarbáramos": "abarbar",
    "abarbárei": "abarbar",
    "abarbáreis": "abarbar",
    "abarbásseis": "abarbar",
    "abarbássemos": "abarbar",
    "abarbávamo": "abarbar",
    "abarbávamos": "abarbar",
    "abarbávei": "abarbar",
    "abarbáveis": "abarbar",
    "abarca": "abarcar",
    "abarcada": "abarcar",
    "abarcadas": "abarcar",
    "abarcadeira": "abarcador",
    "abarcadeiras": "abarcador",
    "abarcado": "abarcar",
    "abarcadora": "abarcador",
    "abarcadoras": "abarcador",
    "abarcadores": "abarcador",
    "abarcados": "abarcar",
    "abarcai": "abarcar",
    "abarcais": "abarcar",
    "abarcam": "abarcar",
    "abarcamentos": "abarcamento",
    "abarcamo": "abarcar",
    "abarcamos": "abarcar",
    "abarcando": "abarcar",
    "abarcantes": "abarcante",
    "abarcara": "abarcar",
    "abarcaram": "abarcar",
    "abarcaras": "abarcar",
    "abarcarde": "abarcar",
    "abarcardes": "abarcar",
    "abarcare": "abarcar",
    "abarcarei": "abarcar",
    "abarcareis": "abarcar",
    "abarcarem": "abarcar",
    "abarcaremos": "abarcar",
    "abarcares": "abarcar",
    "abarcaria": "abarcar",
    "abarcariam": "abarcar",
    "abarcarias": "abarcar",
    "abarcarmo": "abarcar",
    "abarcarmos": "abarcar",
    "abarcará": "abarcar",
    "abarcarás": "abarcar",
    "abarcarão": "abarcar",
    "abarcaríamos": "abarcar",
    "abarcaríeis": "abarcar",
    "abarcas": "abarcar",
    "abarcasse": "abarcar",
    "abarcassem": "abarcar",
    "abarcasses": "abarcar",
    "abarcaste": "abarcar",
    "abarcastes": "abarcar",
    "abarcava": "abarcar",
    "abarcavam": "abarcar",
    "abarcavas": "abarcar",
    "abarco": "abarcar",
    "abarcou": "abarcar",
    "abarcá": "abarcar",
    "abarcámo": "abarcar",
    "abarcámos": "abarcar",
    "abarcáramo": "abarcar",
    "abarcáramos": "abarcar",
    "abarcárei": "abarcar",
    "abarcáreis": "abarcar",
    "abarcásseis": "abarcar",
    "abarcássemos": "abarcar",
    "abarcávamo": "abarcar",
    "abarcávamos": "abarcar",
    "abarcávei": "abarcar",
    "abarcáveis": "abarcável",
    "abarde": "abar",
    "abardes": "abar",
    "abare": "abar",
    "abarei": "abar",
    "abareis": "abar",
    "abarem": "abar",
    "abaremos": "abar",
    "abares": "abar",
    "abarganta": "abargantar",
    "abargantada": "abargantar",
    "abargantadas": "abargantar",
    "abargantado": "abargantar",
    "abargantados": "abargantar",
    "abargantai": "abargantar",
    "abargantais": "abargantar",
    "abargantam": "abargantar",
    "abargantamo": "abargantar",
    "abargantamos": "abargantar",
    "abargantando": "abargantar",
    "abargantara": "abargantar",
    "abargantaram": "abargantar",
    "abargantaras": "abargantar",
    "abargantarde": "abargantar",
    "abargantardes": "abargantar",
    "abargantare": "abargantar",
    "abargantarei": "abargantar",
    "abargantareis": "abargantar",
    "abargantarem": "abargantar",
    "abargantaremos": "abargantar",
    "abargantares": "abargantar",
    "abargantaria": "abargantar",
    "abargantariam": "abargantar",
    "abargantarias": "abargantar",
    "abargantarmo": "abargantar",
    "abargantarmos": "abargantar",
    "abargantará": "abargantar",
    "abargantarás": "abargantar",
    "abargantarão": "abargantar",
    "abargantaríamos": "abargantar",
    "abargantaríeis": "abargantar",
    "abargantas": "abargantar",
    "abargantasse": "abargantar",
    "abargantassem": "abargantar",
    "abargantasses": "abargantar",
    "abargantaste": "abargantar",
    "abargantastes": "abargantar",
    "abargantava": "abargantar",
    "abargantavam": "abargantar",
    "abargantavas": "abargantar",
    "abargante": "abargantar",
    "abargantei": "abargantar",
    "abarganteis": "abargantar",
    "abargantem": "abargantar",
    "abargantemo": "abargantar",
    "abargantemos": "abargantar",
    "abargantes": "abargantar",
    "abarganto": "abargantar",
    "abargantou": "abargantar",
    "abargantá": "abargantar",
    "abargantámo": "abargantar",
    "abargantámos": "abargantar",
    "abargantáramo": "abargantar",
    "abargantáramos": "abargantar",
    "abargantárei": "abargantar",
    "abargantáreis": "abargantar",
    "abargantásseis": "abargantar",
    "abargantássemos": "abargantar",
    "abargantávamo": "abargantar",
    "abargantávamos": "abargantar",
    "abargantávei": "abargantar",
    "abargantáveis": "abargantar",
    "abargas": "abarga",
    "abaria": "abar",
    "abariam": "abar",
    "abarias": "abar",
    "abarigas": "abariga",
    "abaritona": "abaritonar",
    "abaritonada": "abaritonar",
    "abaritonadas": "abaritonar",
    "abaritonado": "abaritonar",
    "abaritonados": "abaritonar",
    "abaritonai": "abaritonar",
    "abaritonais": "abaritonar",
    "abaritonam": "abaritonar",
    "abaritonamo": "abaritonar",
    "abaritonamos": "abaritonar",
    "abaritonando": "abaritonar",
    "abaritonara": "abaritonar",
    "abaritonaram": "abaritonar",
    "abaritonaras": "abaritonar",
    "abaritonarde": "abaritonar",
    "abaritonardes": "abaritonar",
    "abaritonare": "abaritonar",
    "abaritonarei": "abaritonar",
    "abaritonareis": "abaritonar",
    "abaritonarem": "abaritonar",
    "abaritonaremos": "abaritonar",
    "abaritonares": "abaritonar",
    "abaritonaria": "abaritonar",
    "abaritonariam": "abaritonar",
    "abaritonarias": "abaritonar",
    "abaritonarmo": "abaritonar",
    "abaritonarmos": "abaritonar",
    "abaritonará": "abaritonar",
    "abaritonarás": "abaritonar",
    "abaritonarão": "abaritonar",
    "abaritonaríamos": "abaritonar",
    "abaritonaríeis": "abaritonar",
    "abaritonas": "abaritonar",
    "abaritonasse": "abaritonar",
    "abaritonassem": "abaritonar",
    "abaritonasses": "abaritonar",
    "abaritonaste": "abaritonar",
    "abaritonastes": "abaritonar",
    "abaritonava": "abaritonar",
    "abaritonavam": "abaritonar",
    "abaritonavas": "abaritonar",
    "abaritone": "abaritonar",
    "abaritonei": "abaritonar",
    "abaritoneis": "abaritonar",
    "abaritonem": "abaritonar",
    "abaritonemo": "abaritonar",
    "abaritonemos": "abaritonar",
    "abaritones": "abaritonar",
    "abaritono": "abaritonar",
    "abaritonou": "abaritonar",
    "abaritoná": "abaritonar",
    "abaritonámo": "abaritonar",
    "abaritonámos": "abaritonar",
    "abaritonáramo": "abaritonar",
    "abaritonáramos": "abaritonar",
    "abaritonárei": "abaritonar",
    "abaritonáreis": "abaritonar",
    "abaritonásseis": "abaritonar",
    "abaritonássemos": "abaritonar",
    "abaritonávamo": "abaritonar",
    "abaritonávamos": "abaritonar",
    "abaritonávei": "abaritonar",
    "abaritonáveis": "abaritonar",
    "abarmo": "abar",
    "abarmos": "abar",
    "abarona": "abaronar",
    "abaronada": "abaronar",
    "abaronadas": "abaronar",
    "abaronado": "abaronar",
    "abaronados": "abaronar",
    "abaronai": "abaronar",
    "abaronais": "abaronar",
    "abaronam": "abaronar",
    "abaronamo": "abaronar",
    "abaronamos": "abaronar",
    "abaronando": "abaronar",
    "abaronara": "abaronar",
    "abaronaram": "abaronar",
    "abaronaras": "abaronar",
    "abaronarde": "abaronar",
    "abaronardes": "abaronar",
    "abaronare": "abaronar",
    "abaronarei": "abaronar",
    "abaronareis": "abaronar",
    "abaronarem": "abaronar",
    "abaronaremos": "abaronar",
    "abaronares": "abaronar",
    "abaronaria": "abaronar",
    "abaronariam": "abaronar",
    "abaronarias": "abaronar",
    "abaronarmo": "abaronar",
    "abaronarmos": "abaronar",
    "abaronará": "abaronar",
    "abaronarás": "abaronar",
    "abaronarão": "abaronar",
    "abaronaríamos": "abaronar",
    "abaronaríeis": "abaronar",
    "abaronas": "abaronar",
    "abaronasse": "abaronar",
    "abaronassem": "abaronar",
    "abaronasses": "abaronar",
    "abaronaste": "abaronar",
    "abaronastes": "abaronar",
    "abaronava": "abaronar",
    "abaronavam": "abaronar",
    "abaronavas": "abaronar",
    "abarone": "abaronar",
    "abaronei": "abaronar",
    "abaroneis": "abaronar",
    "abaronem": "abaronar",
    "abaronemo": "abaronar",
    "abaronemos": "abaronar",
    "abarones": "abaronar",
    "abarono": "abaronar",
    "abaronou": "abaronar",
    "abaroná": "abaronar",
    "abaronámo": "abaronar",
    "abaronámos": "abaronar",
    "abaronáramo": "abaronar",
    "abaronáramos": "abaronar",
    "abaronárei": "abaronar",
    "abaronáreis": "abaronar",
    "abaronásseis": "abaronar",
    "abaronássemos": "abaronar",
    "abaronávamo": "abaronar",
    "abaronávamos": "abaronar",
    "abaronávei": "abaronar",
    "abaronáveis": "abaronar",
    "abarque": "abarcar",
    "abarquei": "abarcar",
    "abarqueiros": "abarqueiro",
    "abarqueis": "abarcar",
    "abarquem": "abarcar",
    "abarquemo": "abarcar",
    "abarquemos": "abarcar",
    "abarques": "abarcar",
    "abarraca": "abarracar",
    "abarracada": "abarracar",
    "abarracadas": "abarracar",
    "abarracado": "abarracar",
    "abarracados": "abarracar",
    "abarracai": "abarracar",
    "abarracais": "abarracar",
    "abarracam": "abarracar",
    "abarracamentos": "abarracamento",
    "abarracamo": "abarracar",
    "abarracamos": "abarracar",
    "abarracando": "abarracar",
    "abarracara": "abarracar",
    "abarracaram": "abarracar",
    "abarracaras": "abarracar",
    "abarracarde": "abarracar",
    "abarracardes": "abarracar",
    "abarracare": "abarracar",
    "abarracarei": "abarracar",
    "abarracareis": "abarracar",
    "abarracarem": "abarracar",
    "abarracaremos": "abarracar",
    "abarracares": "abarracar",
    "abarracaria": "abarracar",
    "abarracariam": "abarracar",
    "abarracarias": "abarracar",
    "abarracarmo": "abarracar",
    "abarracarmos": "abarracar",
    "abarracará": "abarracar",
    "abarracarás": "abarracar",
    "abarracarão": "abarracar",
    "abarracaríamos": "abarracar",
    "abarracaríeis": "abarracar",
    "abarracas": "abarracar",
    "abarracasse": "abarracar",
    "abarracassem": "abarracar",
    "abarracasses": "abarracar",
    "abarracaste": "abarracar",
    "abarracastes": "abarracar",
    "abarracava": "abarracar",
    "abarracavam": "abarracar",
    "abarracavas": "abarracar",
    "abarraco": "abarracar",
    "abarracou": "abarracar",
    "abarracá": "abarracar",
    "abarracámo": "abarracar",
    "abarracámos": "abarracar",
    "abarracáramo": "abarracar",
    "abarracáramos": "abarracar",
    "abarracárei": "abarracar",
    "abarracáreis": "abarracar",
    "abarracásseis": "abarracar",
    "abarracássemos": "abarracar",
    "abarracávamo": "abarracar",
    "abarracávamos": "abarracar",
    "abarracávei": "abarracar",
    "abarracáveis": "abarracar",
    "abarranca": "abarrancar",
    "abarrancada": "abarrancar",
    "abarrancadas": "abarrancar",
    "abarrancado": "abarrancar",
    "abarrancados": "abarrancar",
    "abarrancai": "abarrancar",
    "abarrancais": "abarrancar",
    "abarrancam": "abarrancar",
    "abarrancamentos": "abarrancamento",
    "abarrancamo": "abarrancar",
    "abarrancamos": "abarrancar",
    "abarrancando": "abarrancar",
    "abarrancara": "abarrancar",
    "abarrancaram": "abarrancar",
    "abarrancaras": "abarrancar",
    "abarrancarde": "abarrancar",
    "abarrancardes": "abarrancar",
    "abarrancare": "abarrancar",
    "abarrancarei": "abarrancar",
    "abarrancareis": "abarrancar",
    "abarrancarem": "abarrancar",
    "abarrancaremos": "abarrancar",
    "abarrancares": "abarrancar",
    "abarrancaria": "abarrancar",
    "abarrancariam": "abarrancar",
    "abarrancarias": "abarrancar",
    "abarrancarmo": "abarrancar",
    "abarrancarmos": "abarrancar",
    "abarrancará": "abarrancar",
    "abarrancarás": "abarrancar",
    "abarrancarão": "abarrancar",
    "abarrancaríamos": "abarrancar",
    "abarrancaríeis": "abarrancar",
    "abarrancas": "abarrancar",
    "abarrancasse": "abarrancar",
    "abarrancassem": "abarrancar",
    "abarrancasses": "abarrancar",
    "abarrancaste": "abarrancar",
    "abarrancastes": "abarrancar",
    "abarrancava": "abarrancar",
    "abarrancavam": "abarrancar",
    "abarrancavas": "abarrancar",
    "abarranco": "abarrancar",
    "abarrancou": "abarrancar",
    "abarrancá": "abarrancar",
    "abarrancámo": "abarrancar",
    "abarrancámos": "abarrancar",
    "abarrancáramo": "abarrancar",
    "abarrancáramos": "abarrancar",
    "abarrancárei": "abarrancar",
    "abarrancáreis": "abarrancar",
    "abarrancásseis": "abarrancar",
    "abarrancássemos": "abarrancar",
    "abarrancávamo": "abarrancar",
    "abarrancávamos": "abarrancar",
    "abarrancávei": "abarrancar",
    "abarrancáveis": "abarrancar",
    "abarranque": "abarrancar",
    "abarranquei": "abarrancar",
    "abarranqueis": "abarrancar",
    "abarranquem": "abarrancar",
    "abarranquemo": "abarrancar",
    "abarranquemos": "abarrancar",
    "abarranques": "abarrancar",
    "abarraque": "abarracar",
    "abarraquei": "abarracar",
    "abarraqueis": "abarracar",
    "abarraquem": "abarracar",
    "abarraquemo": "abarracar",
    "abarraquemos": "abarracar",
    "abarraques": "abarracar",
    "abarrega": "abarregar",
    "abarregada": "abarregar",
    "abarregadas": "abarregar",
    "abarregado": "abarregar",
    "abarregados": "abarregar",
    "abarregai": "abarregar",
    "abarregais": "abarregar",
    "abarregam": "abarregar",
    "abarregamo": "abarregar",
    "abarregamos": "abarregar",
    "abarregando": "abarregar",
    "abarregara": "abarregar",
    "abarregaram": "abarregar",
    "abarregaras": "abarregar",
    "abarregarde": "abarregar",
    "abarregardes": "abarregar",
    "abarregare": "abarregar",
    "abarregarei": "abarregar",
    "abarregareis": "abarregar",
    "abarregarem": "abarregar",
    "abarregaremos": "abarregar",
    "abarregares": "abarregar",
    "abarregaria": "abarregar",
    "abarregariam": "abarregar",
    "abarregarias": "abarregar",
    "abarregarmo": "abarregar",
    "abarregarmos": "abarregar",
    "abarregará": "abarregar",
    "abarregarás": "abarregar",
    "abarregarão": "abarregar",
    "abarregaríamos": "abarregar",
    "abarregaríeis": "abarregar",
    "abarregas": "abarregar",
    "abarregasse": "abarregar",
    "abarregassem": "abarregar",
    "abarregasses": "abarregar",
    "abarregaste": "abarregar",
    "abarregastes": "abarregar",
    "abarregava": "abarregar",
    "abarregavam": "abarregar",
    "abarregavas": "abarregar",
    "abarrego": "abarregar",
    "abarregou": "abarregar",
    "abarregue": "abarregar",
    "abarreguei": "abarregar",
    "abarregueis": "abarregar",
    "abarreguem": "abarregar",
    "abarreguemo": "abarregar",
    "abarreguemos": "abarregar",
    "abarregues": "abarregar",
    "abarregá": "abarregar",
    "abarregámo": "abarregar",
    "abarregámos": "abarregar",
    "abarregáramo": "abarregar",
    "abarregáramos": "abarregar",
    "abarregárei": "abarregar",
    "abarregáreis": "abarregar",
    "abarregásseis": "abarregar",
    "abarregássemos": "abarregar",
    "abarregávamo": "abarregar",
    "abarregávamos": "abarregar",
    "abarregávei": "abarregar",
    "abarregáveis": "abarregar",
    "abarreira": "abarreirar",
    "abarreirada": "abarreirar",
    "abarreiradas": "abarreirar",
    "abarreirado": "abarreirar",
    "abarreirados": "abarreirar",
    "abarreirai": "abarreirar",
    "abarreirais": "abarreirar",
    "abarreiram": "abarreirar",
    "abarreiramo": "abarreirar",
    "abarreiramos": "abarreirar",
    "abarreirando": "abarreirar",
    "abarreirara": "abarreirar",
    "abarreiraram": "abarreirar",
    "abarreiraras": "abarreirar",
    "abarreirarde": "abarreirar",
    "abarreirardes": "abarreirar",
    "abarreirare": "abarreirar",
    "abarreirarei": "abarreirar",
    "abarreirareis": "abarreirar",
    "abarreirarem": "abarreirar",
    "abarreiraremos": "abarreirar",
    "abarreirares": "abarreirar",
    "abarreiraria": "abarreirar",
    "abarreirariam": "abarreirar",
    "abarreirarias": "abarreirar",
    "abarreirarmo": "abarreirar",
    "abarreirarmos": "abarreirar",
    "abarreirará": "abarreirar",
    "abarreirarás": "abarreirar",
    "abarreirarão": "abarreirar",
    "abarreiraríamos": "abarreirar",
    "abarreiraríeis": "abarreirar",
    "abarreiras": "abarreirar",
    "abarreirasse": "abarreirar",
    "abarreirassem": "abarreirar",
    "abarreirasses": "abarreirar",
    "abarreiraste": "abarreirar",
    "abarreirastes": "abarreirar",
    "abarreirava": "abarreirar",
    "abarreiravam": "abarreirar",
    "abarreiravas": "abarreirar",
    "abarreire": "abarreirar",
    "abarreirei": "abarreirar",
    "abarreireis": "abarreirar",
    "abarreirem": "abarreirar",
    "abarreiremo": "abarreirar",
    "abarreiremos": "abarreirar",
    "abarreires": "abarreirar",
    "abarreiro": "abarreirar",
    "abarreirou": "abarreirar",
    "abarreirá": "abarreirar",
    "abarreirámo": "abarreirar",
    "abarreirámos": "abarreirar",
    "abarreiráramo": "abarreirar",
    "abarreiráramos": "abarreirar",
    "abarreirárei": "abarreirar",
    "abarreiráreis": "abarreirar",
    "abarreirásseis": "abarreirar",
    "abarreirássemos": "abarreirar",
    "abarreirávamo": "abarreirar",
    "abarreirávamos": "abarreirar",
    "abarreirávei": "abarreirar",
    "abarreiráveis": "abarreirar",
    "abarreta": "abarretar",
    "abarretada": "abarretar",
    "abarretadas": "abarretar",
    "abarretado": "abarretar",
    "abarretados": "abarretar",
    "abarretai": "abarretar",
    "abarretais": "abarretar",
    "abarretam": "abarretar",
    "abarretamo": "abarretar",
    "abarretamos": "abarretar",
    "abarretando": "abarretar",
    "abarretara": "abarretar",
    "abarretaram": "abarretar",
    "abarretaras": "abarretar",
    "abarretarde": "abarretar",
    "abarretardes": "abarretar",
    "abarretare": "abarretar",
    "abarretarei": "abarretar",
    "abarretareis": "abarretar",
    "abarretarem": "abarretar",
    "abarretaremos": "abarretar",
    "abarretares": "abarretar",
    "abarretaria": "abarretar",
    "abarretariam": "abarretar",
    "abarretarias": "abarretar",
    "abarretarmo": "abarretar",
    "abarretarmos": "abarretar",
    "abarretará": "abarretar",
    "abarretarás": "abarretar",
    "abarretarão": "abarretar",
    "abarretaríamos": "abarretar",
    "abarretaríeis": "abarretar",
    "abarretas": "abarretar",
    "abarretasse": "abarretar",
    "abarretassem": "abarretar",
    "abarretasses": "abarretar",
    "abarretaste": "abarretar",
    "abarretastes": "abarretar",
    "abarretava": "abarretar",
    "abarretavam": "abarretar",
    "abarretavas": "abarretar",
    "abarrete": "abarretar",
    "abarretei": "abarretar",
    "abarreteis": "abarretar",
    "abarretem": "abarretar",
    "abarretemo": "abarretar",
    "abarretemos": "abarretar",
    "abarretes": "abarretar",
    "abarretina": "abarretinar",
    "abarretinada": "abarretinar",
    "abarretinadas": "abarretinar",
    "abarretinado": "abarretinar",
    "abarretinados": "abarretinar",
    "abarretinai": "abarretinar",
    "abarretinais": "abarretinar",
    "abarretinam": "abarretinar",
    "abarretinamo": "abarretinar",
    "abarretinamos": "abarretinar",
    "abarretinando": "abarretinar",
    "abarretinara": "abarretinar",
    "abarretinaram": "abarretinar",
    "abarretinaras": "abarretinar",
    "abarretinarde": "abarretinar",
    "abarretinardes": "abarretinar",
    "abarretinare": "abarretinar",
    "abarretinarei": "abarretinar",
    "abarretinareis": "abarretinar",
    "abarretinarem": "abarretinar",
    "abarretinaremos": "abarretinar",
    "abarretinares": "abarretinar",
    "abarretinaria": "abarretinar",
    "abarretinariam": "abarretinar",
    "abarretinarias": "abarretinar",
    "abarretinarmo": "abarretinar",
    "abarretinarmos": "abarretinar",
    "abarretinará": "abarretinar",
    "abarretinarás": "abarretinar",
    "abarretinarão": "abarretinar",
    "abarretinaríamos": "abarretinar",
    "abarretinaríeis": "abarretinar",
    "abarretinas": "abarretinar",
    "abarretinasse": "abarretinar",
    "abarretinassem": "abarretinar",
    "abarretinasses": "abarretinar",
    "abarretinaste": "abarretinar",
    "abarretinastes": "abarretinar",
    "abarretinava": "abarretinar",
    "abarretinavam": "abarretinar",
    "abarretinavas": "abarretinar",
    "abarretine": "abarretinar",
    "abarretinei": "abarretinar",
    "abarretineis": "abarretinar",
    "abarretinem": "abarretinar",
    "abarretinemo": "abarretinar",
    "abarretinemos": "abarretinar",
    "abarretines": "abarretinar",
    "abarretino": "abarretinar",
    "abarretinou": "abarretinar",
    "abarretiná": "abarretinar",
    "abarretinámo": "abarretinar",
    "abarretinámos": "abarretinar",
    "abarretináramo": "abarretinar",
    "abarretináramos": "abarretinar",
    "abarretinárei": "abarretinar",
    "abarretináreis": "abarretinar",
    "abarretinásseis": "abarretinar",
    "abarretinássemos": "abarretinar",
    "abarretinávamo": "abarretinar",
    "abarretinávamos": "abarretinar",
    "abarretinávei": "abarretinar",
    "abarretináveis": "abarretinar",
    "abarreto": "abarretar",
    "abarretou": "abarretar",
    "abarretá": "abarretar",
    "abarretámo": "abarretar",
    "abarretámos": "abarretar",
    "abarretáramo": "abarretar",
    "abarretáramos": "abarretar",
    "abarretárei": "abarretar",
    "abarretáreis": "abarretar",
    "abarretásseis": "abarretar",
    "abarretássemos": "abarretar",
    "abarretávamo": "abarretar",
    "abarretávamos": "abarretar",
    "abarretávei": "abarretar",
    "abarretáveis": "abarretar",
    "abarrica": "abarricar",
    "abarricada": "abarricar",
    "abarricadas": "abarricar",
    "abarricado": "abarricar",
    "abarricados": "abarricar",
    "abarricai": "abarricar",
    "abarricais": "abarricar",
    "abarricam": "abarricar",
    "abarricamo": "abarricar",
    "abarricamos": "abarricar",
    "abarricando": "abarricar",
    "abarricara": "abarricar",
    "abarricaram": "abarricar",
    "abarricaras": "abarricar",
    "abarricarde": "abarricar",
    "abarricardes": "abarricar",
    "abarricare": "abarricar",
    "abarricarei": "abarricar",
    "abarricareis": "abarricar",
    "abarricarem": "abarricar",
    "abarricaremos": "abarricar",
    "abarricares": "abarricar",
    "abarricaria": "abarricar",
    "abarricariam": "abarricar",
    "abarricarias": "abarricar",
    "abarricarmo": "abarricar",
    "abarricarmos": "abarricar",
    "abarricará": "abarricar",
    "abarricarás": "abarricar",
    "abarricarão": "abarricar",
    "abarricaríamos": "abarricar",
    "abarricaríeis": "abarricar",
    "abarricas": "abarricar",
    "abarricasse": "abarricar",
    "abarricassem": "abarricar",
    "abarricasses": "abarricar",
    "abarricaste": "abarricar",
    "abarricastes": "abarricar",
    "abarricava": "abarricar",
    "abarricavam": "abarricar",
    "abarricavas": "abarricar",
    "abarrico": "abarricar",
    "abarricou": "abarricar",
    "abarricá": "abarricar",
    "abarricámo": "abarricar",
    "abarricámos": "abarricar",
    "abarricáramo": "abarricar",
    "abarricáramos": "abarricar",
    "abarricárei": "abarricar",
    "abarricáreis": "abarricar",
    "abarricásseis": "abarricar",
    "abarricássemos": "abarricar",
    "abarricávamo": "abarricar",
    "abarricávamos": "abarricar",
    "abarricávei": "abarricar",
    "abarricáveis": "abarricar",
    "abarriga": "abarrigar",
    "abarrigada": "abarrigar",
    "abarrigadas": "abarrigar",
    "abarrigado": "abarrigar",
    "abarrigados": "abarrigar",
    "abarrigai": "abarrigar",
    "abarrigais": "abarrigar",
    "abarrigam": "abarrigar",
    "abarrigamo": "abarrigar",
    "abarrigamos": "abarrigar",
    "abarrigando": "abarrigar",
    "abarrigara": "abarrigar",
    "abarrigaram": "abarrigar",
    "abarrigaras": "abarrigar",
    "abarrigarde": "abarrigar",
    "abarrigardes": "abarrigar",
    "abarrigare": "abarrigar",
    "abarrigarei": "abarrigar",
    "abarrigareis": "abarrigar",
    "abarrigarem": "abarrigar",
    "abarrigaremos": "abarrigar",
    "abarrigares": "abarrigar",
    "abarrigaria": "abarrigar",
    "abarrigariam": "abarrigar",
    "abarrigarias": "abarrigar",
    "abarrigarmo": "abarrigar",
    "abarrigarmos": "abarrigar",
    "abarrigará": "abarrigar",
    "abarrigarás": "abarrigar",
    "abarrigarão": "abarrigar",
    "abarrigaríamos": "abarrigar",
    "abarrigaríeis": "abarrigar",
    "abarrigas": "abarrigar",
    "abarrigasse": "abarrigar",
    "abarrigassem": "abarrigar",
    "abarrigasses": "abarrigar",
    "abarrigaste": "abarrigar",
    "abarrigastes": "abarrigar",
    "abarrigava": "abarrigar",
    "abarrigavam": "abarrigar",
    "abarrigavas": "abarrigar",
    "abarrigo": "abarrigar",
    "abarrigou": "abarrigar",
    "abarrigue": "abarrigar",
    "abarriguei": "abarrigar",
    "abarrigueis": "abarrigar",
    "abarriguem": "abarrigar",
    "abarriguemo": "abarrigar",
    "abarriguemos": "abarrigar",
    "abarrigues": "abarrigar",
    "abarrigá": "abarrigar",
    "abarrigámo": "abarrigar",
    "abarrigámos": "abarrigar",
    "abarrigáramo": "abarrigar",
    "abarrigáramos": "abarrigar",
    "abarrigárei": "abarrigar",
    "abarrigáreis": "abarrigar",
    "abarrigásseis": "abarrigar",
    "abarrigássemos": "abarrigar",
    "abarrigávamo": "abarrigar",
    "abarrigávamos": "abarrigar",
    "abarrigávei": "abarrigar",
    "abarrigáveis": "abarrigar",
    "abarrila": "abarrilar",
    "abarrilada": "abarrilar",
    "abarriladas": "abarrilar",
    "abarrilado": "abarrilar",
    "abarrilados": "abarrilar",
    "abarrilai": "abarrilar",
    "abarrilais": "abarrilar",
    "abarrilam": "abarrilar",
    "abarrilamo": "abarrilar",
    "abarrilamos": "abarrilar",
    "abarrilando": "abarrilar",
    "abarrilara": "abarrilar",
    "abarrilaram": "abarrilar",
    "abarrilaras": "abarrilar",
    "abarrilarde": "abarrilar",
    "abarrilardes": "abarrilar",
    "abarrilare": "abarrilar",
    "abarrilarei": "abarrilar",
    "abarrilareis": "abarrilar",
    "abarrilarem": "abarrilar",
    "abarrilaremos": "abarrilar",
    "abarrilares": "abarrilar",
    "abarrilaria": "abarrilar",
    "abarrilariam": "abarrilar",
    "abarrilarias": "abarrilar",
    "abarrilarmo": "abarrilar",
    "abarrilarmos": "abarrilar",
    "abarrilará": "abarrilar",
    "abarrilarás": "abarrilar",
    "abarrilarão": "abarrilar",
    "abarrilaríamos": "abarrilar",
    "abarrilaríeis": "abarrilar",
    "abarrilas": "abarrilar",
    "abarrilasse": "abarrilar",
    "abarrilassem": "abarrilar",
    "abarrilasses": "abarrilar",
    "abarrilaste": "abarrilar",
    "abarrilastes": "abarrilar",
    "abarrilava": "abarrilar",
    "abarrilavam": "abarrilar",
    "abarrilavas": "abarrilar",
    "abarrile": "abarrilar",
    "abarrilei": "abarrilar",
    "abarrileis": "abarrilar",
    "abarrilem": "abarrilar",
    "abarrilemo": "abarrilar",
    "abarrilemos": "abarrilar",
    "abarriles": "abarrilar",
    "abarrilo": "abarrilar",
    "abarrilou": "abarrilar",
    "abarrilá": "abarrilar",
    "abarrilámo": "abarrilar",
    "abarrilámos": "abarrilar",
    "abarriláramo": "abarrilar",
    "abarriláramos": "abarrilar",
    "abarrilárei": "abarrilar",
    "abarriláreis": "abarrilar",
    "abarrilásseis": "abarrilar",
    "abarrilássemos": "abarrilar",
    "abarrilávamo": "abarrilar",
    "abarrilávamos": "abarrilar",
    "abarrilávei": "abarrilar",
    "abarriláveis": "abarrilar",
    "abarrique": "abarricar",
    "abarriquei": "abarricar",
    "abarriqueis": "abarricar",
    "abarriquem": "abarricar",
    "abarriquemo": "abarricar",
    "abarriquemos": "abarricar",
    "abarriques": "abarricar",
    "abarroca": "abarrocar",
    "abarrocada": "abarrocar",
    "abarrocadas": "abarrocar",
    "abarrocado": "abarrocar",
    "abarrocados": "abarrocar",
    "abarrocai": "abarrocar",
    "abarrocais": "abarrocar",
    "abarrocam": "abarrocar",
    "abarrocamo": "abarrocar",
    "abarrocamos": "abarrocar",
    "abarrocando": "abarrocar",
    "abarrocara": "abarrocar",
    "abarrocaram": "abarrocar",
    "abarrocaras": "abarrocar",
    "abarrocarde": "abarrocar",
    "abarrocardes": "abarrocar",
    "abarrocare": "abarrocar",
    "abarrocarei": "abarrocar",
    "abarrocareis": "abarrocar",
    "abarrocarem": "abarrocar",
    "abarrocaremos": "abarrocar",
    "abarrocares": "abarrocar",
    "abarrocaria": "abarrocar",
    "abarrocariam": "abarrocar",
    "abarrocarias": "abarrocar",
    "abarrocarmo": "abarrocar",
    "abarrocarmos": "abarrocar",
    "abarrocará": "abarrocar",
    "abarrocarás": "abarrocar",
    "abarrocarão": "abarrocar",
    "abarrocaríamos": "abarrocar",
    "abarrocaríeis": "abarrocar",
    "abarrocas": "abarrocar",
    "abarrocasse": "abarrocar",
    "abarrocassem": "abarrocar",
    "abarrocasses": "abarrocar",
    "abarrocaste": "abarrocar",
    "abarrocastes": "abarrocar",
    "abarrocava": "abarrocar",
    "abarrocavam": "abarrocar",
    "abarrocavas": "abarrocar",
    "abarroco": "abarrocar",
    "abarrocou": "abarrocar",
    "abarrocá": "abarrocar",
    "abarrocámo": "abarrocar",
    "abarrocámos": "abarrocar",
    "abarrocáramo": "abarrocar",
    "abarrocáramos": "abarrocar",
    "abarrocárei": "abarrocar",
    "abarrocáreis": "abarrocar",
    "abarrocásseis": "abarrocar",
    "abarrocássemos": "abarrocar",
    "abarrocávamo": "abarrocar",
    "abarrocávamos": "abarrocar",
    "abarrocávei": "abarrocar",
    "abarrocáveis": "abarrocar",
    "abarroque": "abarrocar",
    "abarroquei": "abarrocar",
    "abarroqueis": "abarrocar",
    "abarroquem": "abarrocar",
    "abarroquemo": "abarrocar",
    "abarroquemos": "abarrocar",
    "abarroques": "abarrocar",
    "abarrota": "abarrotar",
    "abarrotada": "abarrotar",
    "abarrotadas": "abarrotar",
    "abarrotado": "abarrotar",
    "abarrotados": "abarrotar",
    "abarrotadíssima": "abarrotado",
    "abarrotadíssimas": "abarrotado",
    "abarrotadíssimo": "abarrotado",
    "abarrotadíssimos": "abarrotado",
    "abarrotai": "abarrotar",
    "abarrotais": "abarrotar",
    "abarrotam": "abarrotar",
    "abarrotamentos": "abarrotamento",
    "abarrotamo": "abarrotar",
    "abarrotamos": "abarrotar",
    "abarrotando": "abarrotar",
    "abarrotara": "abarrotar",
    "abarrotaram": "abarrotar",
    "abarrotaras": "abarrotar",
    "abarrotarde": "abarrotar",
    "abarrotardes": "abarrotar",
    "abarrotare": "abarrotar",
    "abarrotarei": "abarrotar",
    "abarrotareis": "abarrotar",
    "abarrotarem": "abarrotar",
    "abarrotaremos": "abarrotar",
    "abarrotares": "abarrotar",
    "abarrotaria": "abarrotar",
    "abarrotariam": "abarrotar",
    "abarrotarias": "abarrotar",
    "abarrotarmo": "abarrotar",
    "abarrotarmos": "abarrotar",
    "abarrotará": "abarrotar",
    "abarrotarás": "abarrotar",
    "abarrotarão": "abarrotar",
    "abarrotaríamos": "abarrotar",
    "abarrotaríeis": "abarrotar",
    "abarrotas": "abarrotar",
    "abarrotasse": "abarrotar",
    "abarrotassem": "abarrotar",
    "abarrotasses": "abarrotar",
    "abarrotaste": "abarrotar",
    "abarrotastes": "abarrotar",
    "abarrotava": "abarrotar",
    "abarrotavam": "abarrotar",
    "abarrotavas": "abarrotar",
    "abarrote": "abarrotar",
    "abarrotei": "abarrotar",
    "abarroteis": "abarrotar",
    "abarrotem": "abarrotar",
    "abarrotemo": "abarrotar",
    "abarrotemos": "abarrotar",
    "abarrotes": "abarrotar",
    "abarroto": "abarrotar",
    "abarrotou": "abarrotar",
    "abarrotá": "abarrotar",
    "abarrotámo": "abarrotar",
    "abarrotámos": "abarrotar",
    "abarrotáramo": "abarrotar",
    "abarrotáramos": "abarrotar",
    "abarrotárei": "abarrotar",
    "abarrotáreis": "abarrotar",
    "abarrotásseis": "abarrotar",
    "abarrotássemos": "abarrotar",
    "abarrotávamo": "abarrotar",
    "abarrotávamos": "abarrotar",
    "abarrotávei": "abarrotar",
    "abarrotáveis": "abarrotar",
    "abarunas": "abaruna",
    "abará": "abar",
    "abarás": "abará",
    "abarão": "abar",
    "abarés": "abaré",
    "abaríamos": "abar",
    "abaríeis": "abar",
    "abas": "abar",
    "abasbaca": "abasbacar",
    "abasbacada": "abasbacar",
    "abasbacadas": "abasbacar",
    "abasbacado": "abasbacar",
    "abasbacados": "abasbacar",
    "abasbacai": "abasbacar",
    "abasbacais": "abasbacar",
    "abasbacam": "abasbacar",
    "abasbacamo": "abasbacar",
    "abasbacamos": "abasbacar",
    "abasbacando": "abasbacar",
    "abasbacara": "abasbacar",
    "abasbacaram": "abasbacar",
    "abasbacaras": "abasbacar",
    "abasbacarde": "abasbacar",
    "abasbacardes": "abasbacar",
    "abasbacare": "abasbacar",
    "abasbacarei": "abasbacar",
    "abasbacareis": "abasbacar",
    "abasbacarem": "abasbacar",
    "abasbacaremos": "abasbacar",
    "abasbacares": "abasbacar",
    "abasbacaria": "abasbacar",
    "abasbacariam": "abasbacar",
    "abasbacarias": "abasbacar",
    "abasbacarmo": "abasbacar",
    "abasbacarmos": "abasbacar",
    "abasbacará": "abasbacar",
    "abasbacarás": "abasbacar",
    "abasbacarão": "abasbacar",
    "abasbacaríamos": "abasbacar",
    "abasbacaríeis": "abasbacar",
    "abasbacas": "abasbacar",
    "abasbacasse": "abasbacar",
    "abasbacassem": "abasbacar",
    "abasbacasses": "abasbacar",
    "abasbacaste": "abasbacar",
    "abasbacastes": "abasbacar",
    "abasbacava": "abasbacar",
    "abasbacavam": "abasbacar",
    "abasbacavas": "abasbacar",
    "abasbaco": "abasbacar",
    "abasbacou": "abasbacar",
    "abasbacá": "abasbacar",
    "abasbacámo": "abasbacar",
    "abasbacámos": "abasbacar",
    "abasbacáramo": "abasbacar",
    "abasbacáramos": "abasbacar",
    "abasbacárei": "abasbacar",
    "abasbacáreis": "abasbacar",
    "abasbacásseis": "abasbacar",
    "abasbacássemos": "abasbacar",
    "abasbacávamo": "abasbacar",
    "abasbacávamos": "abasbacar",
    "abasbacávei": "abasbacar",
    "abasbacáveis": "abasbacar",
    "abasbaque": "abasbacar",
    "abasbaquei": "abasbacar",
    "abasbaqueis": "abasbacar",
    "abasbaquem": "abasbacar",
    "abasbaquemo": "abasbacar",
    "abasbaquemos": "abasbacar",
    "abasbaques": "abasbacar",
    "abasias": "abasia",
    "abasse": "abar",
    "abassem": "abar",
    "abasses": "abar",
    "abasta": "abastar",
    "abastada": "abastar",
    "abastadas": "abastar",
    "abastado": "abastar",
    "abastados": "abastar",
    "abastadíssima": "abastado",
    "abastadíssimas": "abastado",
    "abastadíssimo": "abastado",
    "abastadíssimos": "abastado",
    "abastai": "abastar",
    "abastais": "abastar",
    "abastam": "abastar",
    "abastamentos": "abastamento",
    "abastamo": "abastar",
    "abastamos": "abastar",
    "abastando": "abastar",
    "abastanças": "abastança",
    "abastara": "abastar",
    "abastaram": "abastar",
    "abastaras": "abastar",
    "abastarda": "abastardar",
    "abastardada": "abastardar",
    "abastardadas": "abastardar",
    "abastardado": "abastardar",
    "abastardados": "abastardar",
    "abastardai": "abastardar",
    "abastardais": "abastardar",
    "abastardam": "abastardar",
    "abastardamentos": "abastardamento",
    "abastardamo": "abastardar",
    "abastardamos": "abastardar",
    "abastardando": "abastardar",
    "abastardara": "abastardar",
    "abastardaram": "abastardar",
    "abastardaras": "abastardar",
    "abastardarde": "abastardar",
    "abastardardes": "abastardar",
    "abastardare": "abastardar",
    "abastardarei": "abastardar",
    "abastardareis": "abastardar",
    "abastardarem": "abastardar",
    "abastardaremos": "abastardar",
    "abastardares": "abastardar",
    "abastardaria": "abastardar",
    "abastardariam": "abastardar",
    "abastardarias": "abastardar",
    "abastardarmo": "abastardar",
    "abastardarmos": "abastardar",
    "abastardará": "abastardar",
    "abastardarás": "abastardar",
    "abastardarão": "abastardar",
    "abastardaríamos": "abastardar",
    "abastardaríeis": "abastardar",
    "abastardas": "abastardar",
    "abastardasse": "abastardar",
    "abastardassem": "abastardar",
    "abastardasses": "abastardar",
    "abastardaste": "abastardar",
    "abastardastes": "abastardar",
    "abastardava": "abastardar",
    "abastardavam": "abastardar",
    "abastardavas": "abastardar",
    "abastarde": "abastardar",
    "abastardei": "abastardar",
    "abastardeis": "abastardar",
    "abastardem": "abastardar",
    "abastardemo": "abastardar",
    "abastardemos": "abastardar",
    "abastardes": "abastardar",
    "abastardo": "abastardar",
    "abastardou": "abastardar",
    "abastardá": "abastardar",
    "abastardámo": "abastardar",
    "abastardámos": "abastardar",
    "abastardáramo": "abastardar",
    "abastardáramos": "abastardar",
    "abastardárei": "abastardar",
    "abastardáreis": "abastardar",
    "abastardásseis": "abastardar",
    "abastardássemos": "abastardar",
    "abastardávamo": "abastardar",
    "abastardávamos": "abastardar",
    "abastardávei": "abastardar",
    "abastardáveis": "abastardar",
    "abastare": "abastar",
    "abastarei": "abastar",
    "abastareis": "abastar",
    "abastarem": "abastar",
    "abastaremos": "abastar",
    "abastares": "abastar",
    "abastaria": "abastar",
    "abastariam": "abastar",
    "abastarias": "abastar",
    "abastarmo": "abastar",
    "abastarmos": "abastar",
    "abastará": "abastar",
    "abastarás": "abastar",
    "abastarão": "abastar",
    "abastaríamos": "abastar",
    "abastaríeis": "abastar",
    "abastas": "abastar",
    "abastasse": "abastar",
    "abastassem": "abastar",
    "abastasses": "abastar",
    "abastaste": "abastar",
    "abastastes": "abastar",
    "abastava": "abastar",
    "abastavam": "abastar",
    "abastavas": "abastar",
    "abaste": "abastar",
    "abastece": "abastecer",
    "abastecedoiros": "abastecedoiro",
    "abastecedora": "abastecedor",
    "abastecedoras": "abastecedor",
    "abastecedores": "abastecedor",
    "abastecedouros": "abastecedouro",
    "abastecei": "abastecer",
    "abasteceis": "abastecer",
    "abastecem": "abastecer",
    "abastecemo": "abastecer",
    "abastecemos": "abastecer",
    "abastecendo": "abastecer",
    "abastecera": "abastecer",
    "abasteceram": "abastecer",
    "abasteceras": "abastecer",
    "abastecerde": "abastecer",
    "abastecerdes": "abastecer",
    "abastecere": "abastecer",
    "abastecerei": "abastecer",
    "abastecereis": "abastecer",
    "abastecerem": "abastecer",
    "abasteceremos": "abastecer",
    "abasteceres": "abastecer",
    "abasteceria": "abastecer",
    "abasteceriam": "abastecer",
    "abastecerias": "abastecer",
    "abastecermo": "abastecer",
    "abastecermos": "abastecer",
    "abastecerá": "abastecer",
    "abastecerás": "abastecer",
    "abastecerão": "abastecer",
    "abasteceríamos": "abastecer",
    "abasteceríeis": "abastecer",
    "abasteces": "abastecer",
    "abastecesse": "abastecer",
    "abastecessem": "abastecer",
    "abastecesses": "abastecer",
    "abasteceste": "abastecer",
    "abastecestes": "abastecer",
    "abasteceu": "abastecer",
    "abasteci": "abastecer",
    "abastecia": "abastecer",
    "abasteciam": "abastecer",
    "abastecias": "abastecer",
    "abastecida": "abastecido",
    "abastecidas": "abastecido",
    "abastecido": "abastecer",
    "abastecidos": "abastecido",
    "abastecimentos": "abastecimento",
    "abastecê": "abastecer",
    "abastecêramo": "abastecer",
    "abastecêramos": "abastecer",
    "abastecêrei": "abastecer",
    "abastecêreis": "abastecer",
    "abastecêsseis": "abastecer",
    "abastecêssemos": "abastecer",
    "abastecíamo": "abastecer",
    "abastecíamos": "abastecer",
    "abastecíei": "abastecer",
    "abastecíeis": "abastecer",
    "abastei": "abastar",
    "abasteis": "abastar",
    "abastem": "abastar",
    "abastemo": "abastar",
    "abastemos": "abastar",
    "abastes": "abastar",
    "abasteça": "abastecer",
    "abasteçais": "abastecer",
    "abasteçam": "abastecer",
    "abasteçamo": "abastecer",
    "abasteçamos": "abastecer",
    "abasteças": "abastecer",
    "abasteço": "abastecer",
    "abastiona": "abastionar",
    "abastionada": "abastionar",
    "abastionadas": "abastionar",
    "abastionado": "abastionar",
    "abastionados": "abastionar",
    "abastionai": "abastionar",
    "abastionais": "abastionar",
    "abastionam": "abastionar",
    "abastionamo": "abastionar",
    "abastionamos": "abastionar",
    "abastionando": "abastionar",
    "abastionara": "abastionar",
    "abastionaram": "abastionar",
    "abastionaras": "abastionar",
    "abastionarde": "abastionar",
    "abastionardes": "abastionar",
    "abastionare": "abastionar",
    "abastionarei": "abastionar",
    "abastionareis": "abastionar",
    "abastionarem": "abastionar",
    "abastionaremos": "abastionar",
    "abastionares": "abastionar",
    "abastionaria": "abastionar",
    "abastionariam": "abastionar",
    "abastionarias": "abastionar",
    "abastionarmo": "abastionar",
    "abastionarmos": "abastionar",
    "abastionará": "abastionar",
    "abastionarás": "abastionar",
    "abastionarão": "abastionar",
    "abastionaríamos": "abastionar",
    "abastionaríeis": "abastionar",
    "abastionas": "abastionar",
    "abastionasse": "abastionar",
    "abastionassem": "abastionar",
    "abastionasses": "abastionar",
    "abastionaste": "abastionar",
    "abastionastes": "abastionar",
    "abastionava": "abastionar",
    "abastionavam": "abastionar",
    "abastionavas": "abastionar",
    "abastione": "abastionar",
    "abastionei": "abastionar",
    "abastioneis": "abastionar",
    "abastionem": "abastionar",
    "abastionemo": "abastionar",
    "abastionemos": "abastionar",
    "abastiones": "abastionar",
    "abastiono": "abastionar",
    "abastionou": "abastionar",
    "abastioná": "abastionar",
    "abastionámo": "abastionar",
    "abastionámos": "abastionar",
    "abastionáramo": "abastionar",
    "abastionáramos": "abastionar",
    "abastionárei": "abastionar",
    "abastionáreis": "abastionar",
    "abastionásseis": "abastionar",
    "abastionássemos": "abastionar",
    "abastionávamo": "abastionar",
    "abastionávamos": "abastionar",
    "abastionávei": "abastionar",
    "abastionáveis": "abastionar",
    "abasto": "abastar",
    "abastona": "abastonar",
    "abastonada": "abastonar",
    "abastonadas": "abastonar",
    "abastonado": "abastonar",
    "abastonados": "abastonar",
    "abastonai": "abastonar",
    "abastonais": "abastonar",
    "abastonam": "abastonar",
    "abastonamo": "abastonar",
    "abastonamos": "abastonar",
    "abastonando": "abastonar",
    "abastonara": "abastonar",
    "abastonaram": "abastonar",
    "abastonaras": "abastonar",
    "abastonarde": "abastonar",
    "abastonardes": "abastonar",
    "abastonare": "abastonar",
    "abastonarei": "abastonar",
    "abastonareis": "abastonar",
    "abastonarem": "abastonar",
    "abastonaremos": "abastonar",
    "abastonares": "abastonar",
    "abastonaria": "abastonar",
    "abastonariam": "abastonar",
    "abastonarias": "abastonar",
    "abastonarmo": "abastonar",
    "abastonarmos": "abastonar",
    "abastonará": "abastonar",
    "abastonarás": "abastonar",
    "abastonarão": "abastonar",
    "abastonaríamos": "abastonar",
    "abastonaríeis": "abastonar",
    "abastonas": "abastonar",
    "abastonasse": "abastonar",
    "abastonassem": "abastonar",
    "abastonasses": "abastonar",
    "abastonaste": "abastonar",
    "abastonastes": "abastonar",
    "abastonava": "abastonar",
    "abastonavam": "abastonar",
    "abastonavas": "abastonar",
    "abastone": "abastonar",
    "abastonei": "abastonar",
    "abastoneis": "abastonar",
    "abastonem": "abastonar",
    "abastonemo": "abastonar",
    "abastonemos": "abastonar",
    "abastones": "abastonar",
    "abastono": "abastonar",
    "abastonou": "abastonar",
    "abastoná": "abastonar",
    "abastonámo": "abastonar",
    "abastonámos": "abastonar",
    "abastonáramo": "abastonar",
    "abastonáramos": "abastonar",
    "abastonárei": "abastonar",
    "abastonáreis": "abastonar",
    "abastonásseis": "abastonar",
    "abastonássemos": "abastonar",
    "abastonávamo": "abastonar",
    "abastonávamos": "abastonar",
    "abastonávei": "abastonar",
    "abastonáveis": "abastonar",
    "abastou": "abastar",
    "abastá": "abastar",
    "abastámo": "abastar",
    "abastámos": "abastar",
    "abastáramo": "abastar",
    "abastáramos": "abastar",
    "abastárei": "abastar",
    "abastáreis": "abastar",
    "abastásseis": "abastar",
    "abastássemos": "abastar",
    "abastávamo": "abastar",
    "abastávamos": "abastar",
    "abastávei": "abastar",
    "abastáveis": "abastar",
    "abata": "abater",
    "abatais": "abater",
    "abatam": "abater",
    "abatamo": "abater",
    "abatamos": "abater",
    "abatas": "abater",
    "abatata": "abatatar",
    "abatatada": "abatatar",
    "abatatadas": "abatatar",
    "abatatado": "abatatar",
    "abatatados": "abatatar",
    "abatatai": "abatatar",
    "abatatais": "abatatar",
    "abatatam": "abatatar",
    "abatatamo": "abatatar",
    "abatatamos": "abatatar",
    "abatatando": "abatatar",
    "abatatara": "abatatar",
    "abatataram": "abatatar",
    "abatataras": "abatatar",
    "abatatarde": "abatatar",
    "abatatardes": "abatatar",
    "abatatare": "abatatar",
    "abatatarei": "abatatar",
    "abatatareis": "abatatar",
    "abatatarem": "abatatar",
    "abatataremos": "abatatar",
    "abatatares": "abatatar",
    "abatataria": "abatatar",
    "abatatariam": "abatatar",
    "abatatarias": "abatatar",
    "abatatarmo": "abatatar",
    "abatatarmos": "abatatar",
    "abatatará": "abatatar",
    "abatatarás": "abatatar",
    "abatatarão": "abatatar",
    "abatataríamos": "abatatar",
    "abatataríeis": "abatatar",
    "abatatas": "abatatar",
    "abatatasse": "abatatar",
    "abatatassem": "abatatar",
    "abatatasses": "abatatar",
    "abatataste": "abatatar",
    "abatatastes": "abatatar",
    "abatatava": "abatatar",
    "abatatavam": "abatatar",
    "abatatavas": "abatatar",
    "abatate": "abatatar",
    "abatatei": "abatatar",
    "abatateis": "abatatar",
    "abatatem": "abatatar",
    "abatatemo": "abatatar",
    "abatatemos": "abatatar",
    "abatates": "abatatar",
    "abatato": "abatatar",
    "abatatou": "abatatar",
    "abatatá": "abatatar",
    "abatatámo": "abatatar",
    "abatatámos": "abatatar",
    "abatatáramo": "abatatar",
    "abatatáramos": "abatatar",
    "abatatárei": "abatatar",
    "abatatáreis": "abatatar",
    "abatatásseis": "abatatar",
    "abatatássemos": "abatatar",
    "abatatávamo": "abatatar",
    "abatatávamos": "abatatar",
    "abatatávei": "abatatar",
    "abatatáveis": "abatatar",
    "abate": "abater",
    "abatedora": "abatedor",
    "abatedoras": "abatedor",
    "abatedores": "abatedor",
    "abatei": "abater",
    "abateis": "abater",
    "abatem": "abater",
    "abatemo": "abater",
    "abatemos": "abater",
    "abatendo": "abater",
    "abatera": "abater",
    "abateram": "abater",
    "abateras": "abater",
    "abaterde": "abater",
    "abaterdes": "abater",
    "abatere": "abater",
    "abaterei": "abater",
    "abatereis": "abater",
    "abaterem": "abater",
    "abateremos": "abater",
    "abateres": "abater",
    "abateria": "abater",
    "abateriam": "abater",
    "abaterias": "abater",
    "abatermo": "abater",
    "abatermos": "abater",
    "abaterá": "abater",
    "abaterás": "abater",
    "abaterão": "abater",
    "abateríamos": "abater",
    "abateríeis": "abater",
    "abates": "abater",
    "abatesse": "abater",
    "abatessem": "abater",
    "abatesses": "abater",
    "abateste": "abater",
    "abatestes": "abater",
    "abateu": "abater",
    "abati": "abater",
    "abatia": "abater",
    "abatiam": "abater",
    "abatias": "abater",
    "abatida": "abatido",
    "abatidas": "abatido",
    "abatido": "abater",
    "abatidos": "abatido",
    "abatidíssima": "abatido",
    "abatidíssimas": "abatido",
    "abatidíssimo": "abatido",
    "abatidíssimos": "abatido",
    "abatimentos": "abatimento",
    "abatimirins": "abatimirim",
    "abatina": "abatinar",
    "abatinada": "abatinar",
    "abatinadas": "abatinar",
    "abatinado": "abatinar",
    "abatinados": "abatinar",
    "abatinai": "abatinar",
    "abatinais": "abatinar",
    "abatinam": "abatinar",
    "abatinamo": "abatinar",
    "abatinamos": "abatinar",
    "abatinando": "abatinar",
    "abatinara": "abatinar",
    "abatinaram": "abatinar",
    "abatinaras": "abatinar",
    "abatinarde": "abatinar",
    "abatinardes": "abatinar",
    "abatinare": "abatinar",
    "abatinarei": "abatinar",
    "abatinareis": "abatinar",
    "abatinarem": "abatinar",
    "abatinaremos": "abatinar",
    "abatinares": "abatinar",
    "abatinaria": "abatinar",
    "abatinariam": "abatinar",
    "abatinarias": "abatinar",
    "abatinarmo": "abatinar",
    "abatinarmos": "abatinar",
    "abatinará": "abatinar",
    "abatinarás": "abatinar",
    "abatinarão": "abatinar",
    "abatinaríamos": "abatinar",
    "abatinaríeis": "abatinar",
    "abatinas": "abatinar",
    "abatinasse": "abatinar",
    "abatinassem": "abatinar",
    "abatinasses": "abatinar",
    "abatinaste": "abatinar",
    "abatinastes": "abatinar",
    "abatinava": "abatinar",
    "abatinavam": "abatinar",
    "abatinavas": "abatinar",
    "abatine": "abatinar",
    "abatinei": "abatinar",
    "abatineis": "abatinar",
    "abatinem": "abatinar",
    "abatinemo": "abatinar",
    "abatinemos": "abatinar",
    "abatines": "abatinar",
    "abatino": "abatinar",
    "abatinou": "abatinar",
    "abatiná": "abatinar",
    "abatinámo": "abatinar",
    "abatinámos": "abatinar",
    "abatináramo": "abatinar",
    "abatináramos": "abatinar",
    "abatinárei": "abatinar",
    "abatináreis": "abatinar",
    "abatinásseis": "abatinar",
    "abatinássemos": "abatinar",
    "abatinávamo": "abatinar",
    "abatinávamos": "abatinar",
    "abatinávei": "abatinar",
    "abatináveis": "abatinar",
    "abatirás": "abatirá",
    "abatis": "abati",
    "abatises": "abatis",
    "abato": "abater",
    "abatoca": "abatocar",
    "abatocada": "abatocar",
    "abatocadas": "abatocar",
    "abatocado": "abatocar",
    "abatocados": "abatocar",
    "abatocai": "abatocar",
    "abatocais": "abatocar",
    "abatocam": "abatocar",
    "abatocamo": "abatocar",
    "abatocamos": "abatocar",
    "abatocando": "abatocar",
    "abatocara": "abatocar",
    "abatocaram": "abatocar",
    "abatocaras": "abatocar",
    "abatocarde": "abatocar",
    "abatocardes": "abatocar",
    "abatocare": "abatocar",
    "abatocarei": "abatocar",
    "abatocareis": "abatocar",
    "abatocarem": "abatocar",
    "abatocaremos": "abatocar",
    "abatocares": "abatocar",
    "abatocaria": "abatocar",
    "abatocariam": "abatocar",
    "abatocarias": "abatocar",
    "abatocarmo": "abatocar",
    "abatocarmos": "abatocar",
    "abatocará": "abatocar",
    "abatocarás": "abatocar",
    "abatocarão": "abatocar",
    "abatocaríamos": "abatocar",
    "abatocaríeis": "abatocar",
    "abatocas": "abatocar",
    "abatocasse": "abatocar",
    "abatocassem": "abatocar",
    "abatocasses": "abatocar",
    "abatocaste": "abatocar",
    "abatocastes": "abatocar",
    "abatocava": "abatocar",
    "abatocavam": "abatocar",
    "abatocavas": "abatocar",
    "abatoco": "abatocar",
    "abatocou": "abatocar",
    "abatocá": "abatocar",
    "abatocámo": "abatocar",
    "abatocámos": "abatocar",
    "abatocáramo": "abatocar",
    "abatocáramos": "abatocar",
    "abatocárei": "abatocar",
    "abatocáreis": "abatocar",
    "abatocásseis": "abatocar",
    "abatocássemos": "abatocar",
    "abatocávamo": "abatocar",
    "abatocávamos": "abatocar",
    "abatocávei": "abatocar",
    "abatocáveis": "abatocar",
    "abatoque": "abatocar",
    "abatoquei": "abatocar",
    "abatoqueis": "abatocar",
    "abatoquem": "abatocar",
    "abatoquemo": "abatocar",
    "abatoquemos": "abatocar",
    "abatoques": "abatocar",
    "abatê": "abater",
    "abatêramo": "abater",
    "abatêramos": "abater",
    "abatêrei": "abater",
    "abatêreis": "abater",
    "abatêsseis": "abater",
    "abatêssemos": "abater",
    "abatíamo": "abater",
    "abatíamos": "abater",
    "abatíei": "abater",
    "abatíeis": "abater",
    "abatíveis": "abatível",
    "abatómetros": "abatómetro",
    "abaulada": "abaular",
    "abauladas": "abaular",
    "abaulado": "abaular",
    "abaulados": "abaular",
    "abauladíssima": "abaulado",
    "abauladíssimas": "abaulado",
    "abauladíssimo": "abaulado",
    "abauladíssimos": "abaulado",
    "abaulai": "abaular",
    "abaulais": "abaular",
    "abaulam": "abaular",
    "abaulamentos": "abaulamento",
    "abaulamo": "abaular",
    "abaulamos": "abaular",
    "abaulando": "abaular",
    "abaulara": "abaular",
    "abaularam": "abaular",
    "abaularas": "abaular",
    "abaularde": "abaular",
    "abaulardes": "abaular",
    "abaulare": "abaular",
    "abaularei": "abaular",
    "abaulareis": "abaular",
    "abaularem": "abaular",
    "abaularemos": "abaular",
    "abaulares": "abaular",
    "abaularia": "abaular",
    "abaulariam": "abaular",
    "abaularias": "abaular",
    "abaularmo": "abaular",
    "abaularmos": "abaular",
    "abaulará": "abaular",
    "abaularás": "abaular",
    "abaularão": "abaular",
    "abaularíamos": "abaular",
    "abaularíeis": "abaular",
    "abaulasse": "abaular",
    "abaulassem": "abaular",
    "abaulasses": "abaular",
    "abaulaste": "abaular",
    "abaulastes": "abaular",
    "abaulava": "abaular",
    "abaulavam": "abaular",
    "abaulavas": "abaular",
    "abaulei": "abaular",
    "abauleis": "abaular",
    "abaulemo": "abaular",
    "abaulemos": "abaular",
    "abaulou": "abaular",
    "abaulá": "abaular",
    "abaulámo": "abaular",
    "abaulámos": "abaular",
    "abauláramo": "abaular",
    "abauláramos": "abaular",
    "abaulárei": "abaular",
    "abauláreis": "abaular",
    "abaulásseis": "abaular",
    "abaulássemos": "abaular",
    "abaulávamo": "abaular",
    "abaulávamos": "abaular",
    "abaulávei": "abaular",
    "abauláveis": "abaular",
    "abaunilha": "abaunilhar",
    "abaunilhada": "abaunilhar",
    "abaunilhadas": "abaunilhar",
    "abaunilhado": "abaunilhar",
    "abaunilhados": "abaunilhar",
    "abaunilhai": "abaunilhar",
    "abaunilhais": "abaunilhar",
    "abaunilham": "abaunilhar",
    "abaunilhamo": "abaunilhar",
    "abaunilhamos": "abaunilhar",
    "abaunilhando": "abaunilhar",
    "abaunilhara": "abaunilhar",
    "abaunilharam": "abaunilhar",
    "abaunilharas": "abaunilhar",
    "abaunilharde": "abaunilhar",
    "abaunilhardes": "abaunilhar",
    "abaunilhare": "abaunilhar",
    "abaunilharei": "abaunilhar",
    "abaunilhareis": "abaunilhar",
    "abaunilharem": "abaunilhar",
    "abaunilharemos": "abaunilhar",
    "abaunilhares": "abaunilhar",
    "abaunilharia": "abaunilhar",
    "abaunilhariam": "abaunilhar",
    "abaunilharias": "abaunilhar",
    "abaunilharmo": "abaunilhar",
    "abaunilharmos": "abaunilhar",
    "abaunilhará": "abaunilhar",
    "abaunilharás": "abaunilhar",
    "abaunilharão": "abaunilhar",
    "abaunilharíamos": "abaunilhar",
    "abaunilharíeis": "abaunilhar",
    "abaunilhas": "abaunilhar",
    "abaunilhasse": "abaunilhar",
    "abaunilhassem": "abaunilhar",
    "abaunilhasses": "abaunilhar",
    "abaunilhaste": "abaunilhar",
    "abaunilhastes": "abaunilhar",
    "abaunilhava": "abaunilhar",
    "abaunilhavam": "abaunilhar",
    "abaunilhavas": "abaunilhar",
    "abaunilhe": "abaunilhar",
    "abaunilhei": "abaunilhar",
    "abaunilheis": "abaunilhar",
    "abaunilhem": "abaunilhar",
    "abaunilhemo": "abaunilhar",
    "abaunilhemos": "abaunilhar",
    "abaunilhes": "abaunilhar",
    "abaunilho": "abaunilhar",
    "abaunilhou": "abaunilhar",
    "abaunilhá": "abaunilhar",
    "abaunilhámo": "abaunilhar",
    "abaunilhámos": "abaunilhar",
    "abaunilháramo": "abaunilhar",
    "abaunilháramos": "abaunilhar",
    "abaunilhárei": "abaunilhar",
    "abaunilháreis": "abaunilhar",
    "abaunilhásseis": "abaunilhar",
    "abaunilhássemos": "abaunilhar",
    "abaunilhávamo": "abaunilhar",
    "abaunilhávamos": "abaunilhar",
    "abaunilhávei": "abaunilhar",
    "abaunilháveis": "abaunilhar",
    "abava": "abar",
    "abavam": "abar",
    "abavas": "abar",
    "abaçana": "anar",
    "abaçanada": "abaçanar",
    "abaçanadas": "abaçanar",
    "abaçanado": "abaçanar",
    "abaçanados": "abaçanar",
    "abaçanai": "abaçanar",
    "abaçanais": "abaçanar",
    "abaçanam": "abaçanar",
    "abaçanamo": "abaçanar",
    "abaçanamos": "abaçanar",
    "abaçanando": "abaçanar",
    "abaçanar": "anar",
    "abaçanara": "anar",
    "abaçanaram": "anar",
    "abaçanaras": "abaçanar",
    "abaçanarde": "abaçanar",
    "abaçanardes": "abaçanar",
    "abaçanare": "abaçanar",
    "abaçanarei": "abaçanar",
    "abaçanareis": "abaçanar",
    "abaçanarem": "anar",
    "abaçanaremos": "abaçanar",
    "abaçanares": "abaçanar",
    "abaçanaria": "anar",
    "abaçanariam": "abaçanar",
    "abaçanarias": "abaçanar",
    "abaçanarmo": "abaçanar",
    "abaçanarmos": "abaçanar",
    "abaçanará": "abaçanar",
    "abaçanarás": "abaçanar",
    "abaçanarão": "abaçanar",
    "abaçanaríamos": "abaçanar",
    "abaçanaríeis": "abaçanar",
    "abaçanas": "abaçanar",
    "abaçanasse": "anar",
    "abaçanassem": "abaçanar",
    "abaçanasses": "abaçanar",
    "abaçanaste": "abaçanar",
    "abaçanastes": "abaçanar",
    "abaçanava": "anar",
    "abaçanavam": "abaçanar",
    "abaçanavas": "abaçanar",
    "abaçane": "anar",
    "abaçanei": "abaçanar",
    "abaçaneis": "abaçanar",
    "abaçanem": "anar",
    "abaçanemo": "abaçanar",
    "abaçanemos": "abaçanar",
    "abaçanes": "abaçanar",
    "abaçano": "abaçanar",
    "abaçanou": "abaçanar",
    "abaçaná": "anar",
    "abaçanámo": "abaçanar",
    "abaçanámos": "abaçanar",
    "abaçanáramo": "abaçanar",
    "abaçanáramos": "abaçanar",
    "abaçanárei": "abaçanar",
    "abaçanáreis": "abaçanar",
    "abaçanásseis": "abaçanar",
    "abaçanássemos": "abaçanar",
    "abaçanávamo": "abaçanar",
    "abaçanávamos": "abaçanar",
    "abaçanávei": "abaçanar",
    "abaçanáveis": "abaçanar",
    "abaçaís": "abaçaí",
    "abaíbas": "abaíba",
    "abaúla": "abaular",
    "abaúlas": "abaular",
    "abaúle": "abaular",
    "abaúlem": "abaular",
    "abaúles": "abaular",
    "abaúlo": "abaular",
    "abaúnas": "abaúna",
    "abbevillenses": "abbevillense",
    "abceda": "abceder",
    "abcedais": "abceder",
    "abcedam": "abceder",
    "abcedamo": "abceder",
    "abcedamos": "abceder",
    "abcedas": "abceder",
    "abcede": "abceder",
    "abcedei": "abceder",
    "abcedeis": "abceder",
    "abcedem": "abceder",
    "abcedemo": "abceder",
    "abcedemos": "abceder",
    "abcedendo": "abceder",
    "abcedera": "abceder",
    "abcederam": "abceder",
    "abcederas": "abceder",
    "abcederdes": "abceder",
    "abcederei": "abceder",
    "abcedereis": "abceder",
    "abcederem": "abceder",
    "abcederemos": "abceder",
    "abcederes": "abceder",
    "abcederia": "abceder",
    "abcederiam": "abceder",
    "abcederias": "abceder",
    "abcedermo": "abceder",
    "abcedermos": "abceder",
    "abcederá": "abceder",
    "abcederás": "abceder",
    "abcederão": "abceder",
    "abcederíamos": "abceder",
    "abcederíeis": "abceder",
    "abcedes": "abceder",
    "abcedesse": "abceder",
    "abcedessem": "abceder",
    "abcedesses": "abceder",
    "abcedeste": "abceder",
    "abcedestes": "abceder",
    "abcedeu": "abceder",
    "abcedi": "abceder",
    "abcedia": "abceder",
    "abcediam": "abceder",
    "abcedias": "abceder",
    "abcedida": "abceder",
    "abcedidas": "abceder",
    "abcedido": "abceder",
    "abcedidos": "abceder",
    "abcedo": "abceder",
    "abcedêramo": "abceder",
    "abcedêramos": "abceder",
    "abcedêreis": "abceder",
    "abcedêsseis": "abceder",
    "abcedêssemos": "abceder",
    "abcedíamo": "abceder",
    "abcedíamos": "abceder",
    "abcedíeis": "abceder",
    "abcessos": "abcesso",
    "abcissas": "abcissa",
    "abcisões": "abcisão",
    "abdica": "abdicar",
    "abdicada": "abdicar",
    "abdicadas": "abdicar",
    "abdicado": "abdicar",
    "abdicadora": "abdicador",
    "abdicadoras": "abdicador",
    "abdicadores": "abdicador",
    "abdicados": "abdicar",
    "abdicadriz": "abdicador",
    "abdicadrizes": "abdicador",
    "abdicais": "abdicar",
    "abdicam": "abdicar",
    "abdicamo": "abdicar",
    "abdicamos": "abdicar",
    "abdicando": "abdicar",
    "abdicantes": "abdicante",
    "abdicara": "abdicar",
    "abdicaram": "abdicar",
    "abdicaras": "abdicar",
    "abdicardes": "abdicar",
    "abdicarei": "abdicar",
    "abdicareis": "abdicar",
    "abdicarem": "abdicar",
    "abdicaremos": "abdicar",
    "abdicares": "abdicar",
    "abdicaria": "abdicar",
    "abdicariam": "abdicar",
    "abdicarias": "abdicar",
    "abdicarmo": "abdicar",
    "abdicarmos": "abdicar",
    "abdicará": "abdicar",
    "abdicarás": "abdicar",
    "abdicarão": "abdicar",
    "abdicaríamos": "abdicar",
    "abdicaríeis": "abdicar",
    "abdicas": "abdicar",
    "abdicasse": "abdicar",
    "abdicassem": "abdicar",
    "abdicasses": "abdicar",
    "abdicaste": "abdicar",
    "abdicastes": "abdicar",
    "abdicativa": "abdicativo",
    "abdicativas": "abdicativo",
    "abdicativos": "abdicativo",
    "abdicatária": "abdicatário",
    "abdicatárias": "abdicatário",
    "abdicatários": "abdicatário",
    "abdicatória": "abdicatório",
    "abdicatórias": "abdicatório",
    "abdicatórios": "abdicatório",
    "abdicava": "abdicar",
    "abdicavam": "abdicar",
    "abdicavas": "abdicar",
    "abdicações": "abdicação",
    "abdico": "abdicar",
    "abdicou": "abdicar",
    "abdicámo": "abdicar",
    "abdicámos": "abdicar",
    "abdicáramo": "abdicar",
    "abdicáramos": "abdicar",
    "abdicáreis": "abdicar",
    "abdicásseis": "abdicar",
    "abdicássemos": "abdicar",
    "abdicávamo": "abdicar",
    "abdicávamos": "abdicar",
    "abdicáveis": "abdicável",
    "abdique": "abdicar",
    "abdiquei": "abdicar",
    "abdiqueis": "abdicar",
    "abdiquem": "abdicar",
    "abdiquemos": "abdicar",
    "abdiques": "abdicar",
    "abdomes": "abdome",
    "abdominais": "abdominal",
    "abdominias": "abdominia",
    "abdominosa": "abdominoso",
    "abdominosas": "abdominoso",
    "abdominoscopias": "abdominoscopia",
    "abdominosos": "abdominoso",
    "abdominotorácica": "abdominotorácico",
    "abdominotorácicas": "abdominotorácico",
    "abdominotorácicos": "abdominotorácico",
    "abducentes": "abducente",
    "abdutiva": "abdutivo",
    "abdutivas": "abdutivo",
    "abdutivos": "abdutivo",
    "abdutora": "abdutor",
    "abdutoras": "abdutor",
    "abdutores": "abdutor",
    "abduz": "abduzir",
    "abduza": "abduzir",
    "abduzais": "abduzir",
    "abduzam": "abduzir",
    "abduzamo": "abduzir",
    "abduzamos": "abduzir",
    "abduzas": "abduzir",
    "abduze": "abduzir",
    "abduzem": "abduzir",
    "abduzes": "abduzir",
    "abduzi": "abduzir",
    "abduzia": "abduzir",
    "abduziam": "abduzir",
    "abduzias": "abduzir",
    "abduzida": "abduzir",
    "abduzidas": "abduzir",
    "abduzido": "abduzir",
    "abduzidos": "abduzir",
    "abduzimo": "abduzir",
    "abduzimos": "abduzir",
    "abduzindo": "abduzir",
    "abduzira": "abduzir",
    "abduziram": "abduzir",
    "abduziras": "abduzir",
    "abduzirde": "abduzir",
    "abduzirdes": "abduzir",
    "abduzire": "abduzir",
    "abduzirei": "abduzir",
    "abduzireis": "abduzir",
    "abduzirem": "abduzir",
    "abduziremos": "abduzir",
    "abduzires": "abduzir",
    "abduziria": "abduzir",
    "abduziriam": "abduzir",
    "abduzirias": "abduzir",
    "abduzirmo": "abduzir",
    "abduzirmos": "abduzir",
    "abduzirá": "abduzir",
    "abduzirás": "abduzir",
    "abduzirão": "abduzir",
    "abduziríamos": "abduzir",
    "abduziríeis": "abduzir",
    "abduzis": "abduzir",
    "abduzisse": "abduzir",
    "abduzissem": "abduzir",
    "abduzisses": "abduzir",
    "abduziste": "abduzir",
    "abduzistes": "abduzir",
    "abduziu": "abduzir",
    "abduzo": "abduzir",
    "abduzíamo": "abduzir",
    "abduzíamos": "abduzir",
    "abduzíei": "abduzir",
    "abduzíeis": "abduzir",
    "abduzíramo": "abduzir",
    "abduzíramos": "abduzir",
    "abduzírei": "abduzir",
    "abduzíreis": "abduzir",
    "abduzísseis": "abduzir",
    "abduzíssemos": "abduzir",
    "abduções": "abdução",
    "abdómenes": "abdómen",
    "abdómens": "abdómen",
    "abe": "abar",
    "abeata": "abeatar",
    "abeatada": "abeatar",
    "abeatadas": "abeatar",
    "abeatado": "abeatar",
    "abeatados": "abeatar",
    "abeatai": "abeatar",
    "abeatais": "abeatar",
    "abeatam": "abeatar",
    "abeatamo": "abeatar",
    "abeatamos": "abeatar",
    "abeatando": "abeatar",
    "abeatara": "abeatar",
    "abeataram": "abeatar",
    "abeataras": "abeatar",
    "abeatarde": "abeatar",
    "abeatardes": "abeatar",
    "abeatare": "abeatar",
    "abeatarei": "abeatar",
    "abeatareis": "abeatar",
    "abeatarem": "abeatar",
    "abeataremos": "abeatar",
    "abeatares": "abeatar",
    "abeataria": "abeatar",
    "abeatariam": "abeatar",
    "abeatarias": "abeatar",
    "abeatarmo": "abeatar",
    "abeatarmos": "abeatar",
    "abeatará": "abeatar",
    "abeatarás": "abeatar",
    "abeatarão": "abeatar",
    "abeataríamos": "abeatar",
    "abeataríeis": "abeatar",
    "abeatas": "abeatar",
    "abeatasse": "abeatar",
    "abeatassem": "abeatar",
    "abeatasses": "abeatar",
    "abeataste": "abeatar",
    "abeatastes": "abeatar",
    "abeatava": "abeatar",
    "abeatavam": "abeatar",
    "abeatavas": "abeatar",
    "abeate": "abeatar",
    "abeatei": "abeatar",
    "abeateis": "abeatar",
    "abeatem": "abeatar",
    "abeatemo": "abeatar",
    "abeatemos": "abeatar",
    "abeates": "abeatar",
    "abeato": "abeatar",
    "abeatou": "abeatar",
    "abeatá": "abeatar",
    "abeatámo": "abeatar",
    "abeatámos": "abeatar",
    "abeatáramo": "abeatar",
    "abeatáramos": "abeatar",
    "abeatárei": "abeatar",
    "abeatáreis": "abeatar",
    "abeatásseis": "abeatar",
    "abeatássemos": "abeatar",
    "abeatávamo": "abeatar",
    "abeatávamos": "abeatar",
    "abeatávei": "abeatar",
    "abeatáveis": "abeatar",
    "abebera": "abeberar",
    "abeberada": "abeberar",
    "abeberadas": "abeberar",
    "abeberado": "abeberar",
    "abeberados": "abeberar",
    "abeberai": "abeberar",
    "abeberais": "abeberar",
    "abeberam": "abeberar",
    "abeberamo": "abeberar",
    "abeberamos": "abeberar",
    "abeberando": "abeberar",
    "abeberara": "abeberar",
    "abeberaram": "abeberar",
    "abeberaras": "abeberar",
    "abeberarde": "abeberar",
    "abeberardes": "abeberar",
    "abeberare": "abeberar",
    "abeberarei": "abeberar",
    "abeberareis": "abeberar",
    "abeberarem": "abeberar",
    "abeberaremos": "abeberar",
    "abeberares": "abeberar",
    "abeberaria": "abeberar",
    "abeberariam": "abeberar",
    "abeberarias": "abeberar",
    "abeberarmo": "abeberar",
    "abeberarmos": "abeberar",
    "abeberará": "abeberar",
    "abeberarás": "abeberar",
    "abeberarão": "abeberar",
    "abeberaríamos": "abeberar",
    "abeberaríeis": "abeberar",
    "abeberas": "abeberar",
    "abeberasse": "abeberar",
    "abeberassem": "abeberar",
    "abeberasses": "abeberar",
    "abeberaste": "abeberar",
    "abeberastes": "abeberar",
    "abeberava": "abeberar",
    "abeberavam": "abeberar",
    "abeberavas": "abeberar",
    "abebere": "abeberar",
    "abeberei": "abeberar",
    "abebereiras": "abebereira",
    "abebereis": "abeberar",
    "abeberem": "abeberar",
    "abeberemo": "abeberar",
    "abeberemos": "abeberar",
    "abeberes": "abeberar",
    "abebero": "abeberar",
    "abeberou": "abeberar",
    "abeberá": "abeberar",
    "abeberámo": "abeberar",
    "abeberámos": "abeberar",
    "abeberáramo": "abeberar",
    "abeberáramos": "abeberar",
    "abeberárei": "abeberar",
    "abeberáreis": "abeberar",
    "abeberásseis": "abeberar",
    "abeberássemos": "abeberar",
    "abeberávamo": "abeberar",
    "abeberávamos": "abeberar",
    "abeberávei": "abeberar",
    "abeberáveis": "abeberar",
    "abebras": "abebra",
    "abeceda": "abecedar",
    "abecedada": "abecedar",
    "abecedadas": "abecedar",
    "abecedado": "abecedar",
    "abecedados": "abecedar",
    "abecedai": "abecedar",
    "abecedais": "abecedar",
    "abecedam": "abecedar",
    "abecedamo": "abecedar",
    "abecedamos": "abecedar",
    "abecedando": "abecedar",
    "abecedara": "abecedar",
    "abecedaram": "abecedar",
    "abecedaras": "abecedar",
    "abecedarde": "abecedar",
    "abecedardes": "abecedar",
    "abecedare": "abecedar",
    "abecedarei": "abecedar",
    "abecedareis": "abecedar",
    "abecedarem": "abecedar",
    "abecedaremos": "abecedar",
    "abecedares": "abecedar",
    "abecedaria": "abecedar",
    "abecedariam": "abecedar",
    "abecedarias": "abecedar",
    "abecedarmo": "abecedar",
    "abecedarmos": "abecedar",
    "abecedará": "abecedar",
    "abecedarás": "abecedar",
    "abecedarão": "abecedar",
    "abecedaríamos": "abecedar",
    "abecedaríeis": "abecedar",
    "abecedas": "abecedar",
    "abecedasse": "abecedar",
    "abecedassem": "abecedar",
    "abecedasses": "abecedar",
    "abecedaste": "abecedar",
    "abecedastes": "abecedar",
    "abecedava": "abecedar",
    "abecedavam": "abecedar",
    "abecedavas": "abecedar",
    "abecede": "abecedar",
    "abecedei": "abecedar",
    "abecedeis": "abecedar",
    "abecedem": "abecedar",
    "abecedemo": "abecedar",
    "abecedemos": "abecedar",
    "abecedes": "abecedar",
    "abecedo": "abecedar",
    "abecedou": "abecedar",
    "abecedá": "abecedar",
    "abecedámo": "abecedar",
    "abecedámos": "abecedar",
    "abecedáramo": "abecedar",
    "abecedáramos": "abecedar",
    "abecedárei": "abecedar",
    "abecedáreis": "abecedar",
    "abecedária": "abecedário",
    "abecedárias": "abecedário",
    "abecedários": "abecedário",
    "abecedásseis": "abecedar",
    "abecedássemos": "abecedar",
    "abecedávamo": "abecedar",
    "abecedávamos": "abecedar",
    "abecedávei": "abecedar",
    "abecedáveis": "abecedar",
    "abecoinhas": "abecoinha",
    "abegoa": "abegão",
    "abegoarias": "abegoaria",
    "abegoas": "abegão",
    "abegões": "abegão",
    "abei": "abar",
    "abeice": "abeiçar",
    "abeicei": "abeiçar",
    "abeiceis": "abeiçar",
    "abeicem": "abeiçar",
    "abeicemo": "abeiçar",
    "abeicemos": "abeiçar",
    "abeices": "abeiçar",
    "abeira": "abeiro",
    "abeirada": "abeirar",
    "abeiradas": "abeirar",
    "abeirado": "abeirar",
    "abeirados": "abeirar",
    "abeirai": "abeirar",
    "abeirais": "abeirar",
    "abeiram": "abeirar",
    "abeiramentos": "abeiramento",
    "abeiramo": "abeirar",
    "abeiramos": "abeirar",
    "abeirando": "abeirar",
    "abeirara": "abeirar",
    "abeiraram": "abeirar",
    "abeiraras": "abeirar",
    "abeirardes": "abeirar",
    "abeirarei": "abeirar",
    "abeirareis": "abeirar",
    "abeirarem": "abeirar",
    "abeiraremos": "abeirar",
    "abeirares": "abeirar",
    "abeiraria": "abeirar",
    "abeirariam": "abeirar",
    "abeirarias": "abeirar",
    "abeirarmo": "abeirar",
    "abeirarmos": "abeirar",
    "abeirará": "abeirar",
    "abeirarás": "abeirar",
    "abeirarão": "abeirar",
    "abeiraríamos": "abeirar",
    "abeiraríeis": "abeirar",
    "abeiras": "abeiro",
    "abeirasse": "abeirar",
    "abeirassem": "abeirar",
    "abeirasses": "abeirar",
    "abeiraste": "abeirar",
    "abeirastes": "abeirar",
    "abeirava": "abeirar",
    "abeiravam": "abeirar",
    "abeiravas": "abeirar",
    "abeire": "abeirar",
    "abeirei": "abeirar",
    "abeireis": "abeirar",
    "abeirem": "abeirar",
    "abeiremo": "abeirar",
    "abeiremos": "abeirar",
    "abeires": "abeirar",
    "abeiro": "abeirar",
    "abeiros": "abeiro",
    "abeirou": "abeirar",
    "abeirámo": "abeirar",
    "abeirámos": "abeirar",
    "abeiráramo": "abeirar",
    "abeiráramos": "abeirar",
    "abeiráreis": "abeirar",
    "abeirásseis": "abeirar",
    "abeirássemos": "abeirar",
    "abeirávamo": "abeirar",
    "abeirávamos": "abeirar",
    "abeiráveis": "abeirar",
    "abeis": "abar",
    "abeiça": "abeiçar",
    "abeiçada": "abeiçar",
    "abeiçadas": "abeiçar",
    "abeiçado": "abeiçar",
    "abeiçados": "abeiçar",
    "abeiçai": "abeiçar",
    "abeiçais": "abeiçar",
    "abeiçam": "abeiçar",
    "abeiçamo": "abeiçar",
    "abeiçamos": "abeiçar",
    "abeiçando": "abeiçar",
    "abeiçara": "abeiçar",
    "abeiçaram": "abeiçar",
    "abeiçaras": "abeiçar",
    "abeiçarde": "abeiçar",
    "abeiçardes": "abeiçar",
    "abeiçare": "abeiçar",
    "abeiçarei": "abeiçar",
    "abeiçareis": "abeiçar",
    "abeiçarem": "abeiçar",
    "abeiçaremos": "abeiçar",
    "abeiçares": "abeiçar",
    "abeiçaria": "abeiçar",
    "abeiçariam": "abeiçar",
    "abeiçarias": "abeiçar",
    "abeiçarmo": "abeiçar",
    "abeiçarmos": "abeiçar",
    "abeiçará": "abeiçar",
    "abeiçarás": "abeiçar",
    "abeiçarão": "abeiçar",
    "abeiçaríamos": "abeiçar",
    "abeiçaríeis": "abeiçar",
    "abeiças": "abeiçar",
    "abeiçasse": "abeiçar",
    "abeiçassem": "abeiçar",
    "abeiçasses": "abeiçar",
    "abeiçaste": "abeiçar",
    "abeiçastes": "abeiçar",
    "abeiçava": "abeiçar",
    "abeiçavam": "abeiçar",
    "abeiçavas": "abeiçar",
    "abeiço": "abeiçar",
    "abeiçou": "abeiçar",
    "abeiçá": "abeiçar",
    "abeiçámo": "abeiçar",
    "abeiçámos": "abeiçar",
    "abeiçáramo": "abeiçar",
    "abeiçáramos": "abeiçar",
    "abeiçárei": "abeiçar",
    "abeiçáreis": "abeiçar",
    "abeiçásseis": "abeiçar",
    "abeiçássemos": "abeiçar",
    "abeiçávamo": "abeiçar",
    "abeiçávamos": "abeiçar",
    "abeiçávei": "abeiçar",
    "abeiçáveis": "abeiçar",
    "abeleira": "abeleirar",
    "abeleirada": "abeleirar",
    "abeleiradas": "abeleirar",
    "abeleirado": "abeleirar",
    "abeleirados": "abeleirar",
    "abeleirai": "abeleirar",
    "abeleirais": "abeleirar",
    "abeleiram": "abeleirar",
    "abeleiramo": "abeleirar",
    "abeleiramos": "abeleirar",
    "abeleirando": "abeleirar",
    "abeleirara": "abeleirar",
    "abeleiraram": "abeleirar",
    "abeleiraras": "abeleirar",
    "abeleirardes": "abeleirar",
    "abeleirarei": "abeleirar",
    "abeleirareis": "abeleirar",
    "abeleirarem": "abeleirar",
    "abeleiraremos": "abeleirar",
    "abeleirares": "abeleirar",
    "abeleiraria": "abeleirar",
    "abeleirariam": "abeleirar",
    "abeleirarias": "abeleirar",
    "abeleirarmo": "abeleirar",
    "abeleirarmos": "abeleirar",
    "abeleirará": "abeleirar",
    "abeleirarás": "abeleirar",
    "abeleirarão": "abeleirar",
    "abeleiraríamos": "abeleirar",
    "abeleiraríeis": "abeleirar",
    "abeleiras": "abeleirar",
    "abeleirasse": "abeleirar",
    "abeleirassem": "abeleirar",
    "abeleirasses": "abeleirar",
    "abeleiraste": "abeleirar",
    "abeleirastes": "abeleirar",
    "abeleirava": "abeleirar",
    "abeleiravam": "abeleirar",
    "abeleiravas": "abeleirar",
    "abeleire": "abeleirar",
    "abeleirei": "abeleirar",
    "abeleireis": "abeleirar",
    "abeleirem": "abeleirar",
    "abeleiremo": "abeleirar",
    "abeleiremos": "abeleirar",
    "abeleires": "abeleirar",
    "abeleiro": "abeleirar",
    "abeleirou": "abeleirar",
    "abeleirámo": "abeleirar",
    "abeleirámos": "abeleirar",
    "abeleiráramo": "abeleirar",
    "abeleiráramos": "abeleirar",
    "abeleiráreis": "abeleirar",
    "abeleirásseis": "abeleirar",
    "abeleirássemos": "abeleirar",
    "abeleirávamo": "abeleirar",
    "abeleirávamos": "abeleirar",
    "abeleiráveis": "abeleirar",
    "abelha": "abelhar",
    "abelhada": "abelhar",
    "abelhadas": "abelhar",
    "abelhado": "abelhar",
    "abelhados": "abelhar",
    "abelhai": "abelhar",
    "abelhais": "abelhar",
    "abelham": "abelhar",
    "abelhamo": "abelhar",
    "abelhamos": "abelhar",
    "abelhando": "abelhar",
    "abelhara": "abelhar",
    "abelharam": "abelhar",
    "abelharas": "abelhar",
    "abelhardes": "abelhar",
    "abelharei": "abelhar",
    "abelhareis": "abelhar",
    "abelharem": "abelhar",
    "abelharemos": "abelhar",
    "abelhares": "abelhar",
    "abelharia": "abelhar",
    "abelhariam": "abelhar",
    "abelharias": "abelhar",
    "abelharmo": "abelhar",
    "abelharmos": "abelhar",
    "abelharucos": "abelharuco",
    "abelhará": "abelhar",
    "abelharás": "abelhar",
    "abelharão": "abelhar",
    "abelharíamos": "abelhar",
    "abelharíeis": "abelhar",
    "abelhas": "abelhar",
    "abelhasse": "abelhar",
    "abelhassem": "abelhar",
    "abelhasses": "abelhar",
    "abelhaste": "abelhar",
    "abelhastes": "abelhar",
    "abelhava": "abelhar",
    "abelhavam": "abelhar",
    "abelhavas": "abelhar",
    "abelhe": "abelhar",
    "abelhei": "abelhar",
    "abelheiras": "abelheira",
    "abelheiros": "abelheiro",
    "abelheis": "abelhar",
    "abelhem": "abelhar",
    "abelhemo": "abelhar",
    "abelhemos": "abelhar",
    "abelhes": "abelhar",
    "abelhinha": "abelha",
    "abelhinhas": "abelha",
    "abelhita": "abelha",
    "abelhitas": "abelha",
    "abelho": "abelhar",
    "abelhou": "abelhar",
    "abelhucos": "abelhuco",
    "abelhuda": "abelhudo",
    "abelhudas": "abelhudo",
    "abelhudices": "abelhudice",
    "abelhudos": "abelhudo",
    "abelhudíssima": "abelhudo",
    "abelhudíssimas": "abelhudo",
    "abelhudíssimo": "abelhudo",
    "abelhudíssimos": "abelhudo",
    "abelhámo": "abelhar",
    "abelhámos": "abelhar",
    "abelháramo": "abelhar",
    "abelháramos": "abelhar",
    "abelháreis": "abelhar",
    "abelhásseis": "abelhar",
    "abelhássemos": "abelhar",
    "abelhávamo": "abelhar",
    "abelhávamos": "abelhar",
    "abelháveis": "abelhar",
    "abelhões": "abelhão",
    "abeliana": "abeliano",
    "abelianas": "abeliano",
    "abelianos": "abeliano",
    "abelida": "abelidar",
    "abelidada": "abelidar",
    "abelidadas": "abelidar",
    "abelidado": "abelidar",
    "abelidados": "abelidar",
    "abelidai": "abelidar",
    "abelidais": "abelidar",
    "abelidam": "abelidar",
    "abelidamo": "abelidar",
    "abelidamos": "abelidar",
    "abelidando": "abelidar",
    "abelidara": "abelidar",
    "abelidaram": "abelidar",
    "abelidaras": "abelidar",
    "abelidarde": "abelidar",
    "abelidardes": "abelidar",
    "abelidare": "abelidar",
    "abelidarei": "abelidar",
    "abelidareis": "abelidar",
    "abelidarem": "abelidar",
    "abelidaremos": "abelidar",
    "abelidares": "abelidar",
    "abelidaria": "abelidar",
    "abelidariam": "abelidar",
    "abelidarias": "abelidar",
    "abelidarmo": "abelidar",
    "abelidarmos": "abelidar",
    "abelidará": "abelidar",
    "abelidarás": "abelidar",
    "abelidarão": "abelidar",
    "abelidaríamos": "abelidar",
    "abelidaríeis": "abelidar",
    "abelidas": "abelidar",
    "abelidasse": "abelidar",
    "abelidassem": "abelidar",
    "abelidasses": "abelidar",
    "abelidaste": "abelidar",
    "abelidastes": "abelidar",
    "abelidava": "abelidar",
    "abelidavam": "abelidar",
    "abelidavas": "abelidar",
    "abelide": "abelidar",
    "abelidei": "abelidar",
    "abelideis": "abelidar",
    "abelidem": "abelidar",
    "abelidemo": "abelidar",
    "abelidemos": "abelidar",
    "abelides": "abelidar",
    "abelido": "abelidar",
    "abelidou": "abelidar",
    "abelidá": "abelidar",
    "abelidámo": "abelidar",
    "abelidámos": "abelidar",
    "abelidáramo": "abelidar",
    "abelidáramos": "abelidar",
    "abelidárei": "abelidar",
    "abelidáreis": "abelidar",
    "abelidásseis": "abelidar",
    "abelidássemos": "abelidar",
    "abelidávamo": "abelidar",
    "abelidávamos": "abelidar",
    "abelidávei": "abelidar",
    "abelidáveis": "abelidar",
    "abelmoscos": "abelmosco",
    "abeloiras": "abeloira",
    "abelouras": "abeloura",
    "abem": "abar",
    "abemo": "abar",
    "abemola": "abemolar",
    "abemolada": "abemolar",
    "abemoladas": "abemolar",
    "abemolado": "abemolar",
    "abemolados": "abemolar",
    "abemolai": "abemolar",
    "abemolais": "abemolar",
    "abemolam": "abemolar",
    "abemolamo": "abemolar",
    "abemolamos": "abemolar",
    "abemolando": "abemolar",
    "abemolara": "abemolar",
    "abemolaram": "abemolar",
    "abemolaras": "abemolar",
    "abemolarde": "abemolar",
    "abemolardes": "abemolar",
    "abemolare": "abemolar",
    "abemolarei": "abemolar",
    "abemolareis": "abemolar",
    "abemolarem": "abemolar",
    "abemolaremos": "abemolar",
    "abemolares": "abemolar",
    "abemolaria": "abemolar",
    "abemolariam": "abemolar",
    "abemolarias": "abemolar",
    "abemolarmo": "abemolar",
    "abemolarmos": "abemolar",
    "abemolará": "abemolar",
    "abemolarás": "abemolar",
    "abemolarão": "abemolar",
    "abemolaríamos": "abemolar",
    "abemolaríeis": "abemolar",
    "abemolas": "abemolar",
    "abemolasse": "abemolar",
    "abemolassem": "abemolar",
    "abemolasses": "abemolar",
    "abemolaste": "abemolar",
    "abemolastes": "abemolar",
    "abemolava": "abemolar",
    "abemolavam": "abemolar",
    "abemolavas": "abemolar",
    "abemole": "abemolar",
    "abemolei": "abemolar",
    "abemoleis": "abemolar",
    "abemolem": "abemolar",
    "abemolemo": "abemolar",
    "abemolemos": "abemolar",
    "abemoles": "abemolar",
    "abemolo": "abemolar",
    "abemolou": "abemolar",
    "abemolá": "abemolar",
    "abemolámo": "abemolar",
    "abemolámos": "abemolar",
    "abemoláramo": "abemolar",
    "abemoláramos": "abemolar",
    "abemolárei": "abemolar",
    "abemoláreis": "abemolar",
    "abemolásseis": "abemolar",
    "abemolássemos": "abemolar",
    "abemolávamo": "abemolar",
    "abemolávamos": "abemolar",
    "abemolávei": "abemolar",
    "abemoláveis": "abemolar",
    "abemos": "abar",
    "abencerrage": "abencerragem",
    "abencerragens": "abencerragem",
    "abencerrages": "abencerragem",
    "abendiçoa": "abendiçoar",
    "abendiçoada": "abendiçoar",
    "abendiçoadas": "abendiçoar",
    "abendiçoado": "abendiçoar",
    "abendiçoados": "abendiçoar",
    "abendiçoai": "abendiçoar",
    "abendiçoais": "abendiçoar",
    "abendiçoam": "abendiçoar",
    "abendiçoamo": "abendiçoar",
    "abendiçoamos": "abendiçoar",
    "abendiçoando": "abendiçoar",
    "abendiçoara": "abendiçoar",
    "abendiçoaram": "abendiçoar",
    "abendiçoaras": "abendiçoar",
    "abendiçoarde": "abendiçoar",
    "abendiçoardes": "abendiçoar",
    "abendiçoare": "abendiçoar",
    "abendiçoarei": "abendiçoar",
    "abendiçoareis": "abendiçoar",
    "abendiçoarem": "abendiçoar",
    "abendiçoaremos": "abendiçoar",
    "abendiçoares": "abendiçoar",
    "abendiçoaria": "abendiçoar",
    "abendiçoariam": "abendiçoar",
    "abendiçoarias": "abendiçoar",
    "abendiçoarmo": "abendiçoar",
    "abendiçoarmos": "abendiçoar",
    "abendiçoará": "abendiçoar",
    "abendiçoarás": "abendiçoar",
    "abendiçoarão": "abendiçoar",
    "abendiçoaríamos": "abendiçoar",
    "abendiçoaríeis": "abendiçoar",
    "abendiçoas": "abendiçoar",
    "abendiçoasse": "abendiçoar",
    "abendiçoassem": "abendiçoar",
    "abendiçoasses": "abendiçoar",
    "abendiçoaste": "abendiçoar",
    "abendiçoastes": "abendiçoar",
    "abendiçoava": "abendiçoar",
    "abendiçoavam": "abendiçoar",
    "abendiçoavas": "abendiçoar",
    "abendiçoe": "abendiçoar",
    "abendiçoei": "abendiçoar",
    "abendiçoeis": "abendiçoar",
    "abendiçoem": "abendiçoar",
    "abendiçoemo": "abendiçoar",
    "abendiçoemos": "abendiçoar",
    "abendiçoes": "abendiçoar",
    "abendiçoo": "abendiçoar",
    "abendiçoou": "abendiçoar",
    "abendiçoá": "abendiçoar",
    "abendiçoámo": "abendiçoar",
    "abendiçoámos": "abendiçoar",
    "abendiçoáramo": "abendiçoar",
    "abendiçoáramos": "abendiçoar",
    "abendiçoárei": "abendiçoar",
    "abendiçoáreis": "abendiçoar",
    "abendiçoásseis": "abendiçoar",
    "abendiçoássemos": "abendiçoar",
    "abendiçoávamo": "abendiçoar",
    "abendiçoávamos": "abendiçoar",
    "abendiçoávei": "abendiçoar",
    "abendiçoáveis": "abendiçoar",
    "abentões": "abentão",
    "abençoa": "abençoar",
    "abençoada": "abençoar",
    "abençoadas": "abençoar",
    "abençoadeira": "abençoador",
    "abençoadeiras": "abençoador",
    "abençoado": "abençoar",
    "abençoadora": "abençoador",
    "abençoadoras": "abençoador",
    "abençoadores": "abençoador",
    "abençoados": "abençoar",
    "abençoai": "abençoar",
    "abençoais": "abençoar",
    "abençoam": "abençoar",
    "abençoamo": "abençoar",
    "abençoamos": "abençoar",
    "abençoando": "abençoar",
    "abençoara": "abençoar",
    "abençoaram": "abençoar",
    "abençoaras": "abençoar",
    "abençoarde": "abençoar",
    "abençoardes": "abençoar",
    "abençoare": "abençoar",
    "abençoarei": "abençoar",
    "abençoareis": "abençoar",
    "abençoarem": "abençoar",
    "abençoaremos": "abençoar",
    "abençoares": "abençoar",
    "abençoaria": "abençoar",
    "abençoariam": "abençoar",
    "abençoarias": "abençoar",
    "abençoarmo": "abençoar",
    "abençoarmos": "abençoar",
    "abençoará": "abençoar",
    "abençoarás": "abençoar",
    "abençoarão": "abençoar",
    "abençoaríamos": "abençoar",
    "abençoaríeis": "abençoar",
    "abençoas": "abençoar",
    "abençoasse": "abençoar",
    "abençoassem": "abençoar",
    "abençoasses": "abençoar",
    "abençoaste": "abençoar",
    "abençoastes": "abençoar",
    "abençoava": "abençoar",
    "abençoavam": "abençoar",
    "abençoavas": "abençoar",
    "abençoe": "abençoar",
    "abençoei": "abençoar",
    "abençoeis": "abençoar",
    "abençoem": "abençoar",
    "abençoemo": "abençoar",
    "abençoemos": "abençoar",
    "abençoes": "abençoar",
    "abençoo": "abençoar",
    "abençoou": "abençoar",
    "abençoá": "abençoar",
    "abençoámo": "abençoar",
    "abençoámos": "abençoar",
    "abençoáramo": "abençoar",
    "abençoáramos": "abençoar",
    "abençoárei": "abençoar",
    "abençoáreis": "abençoar",
    "abençoásseis": "abençoar",
    "abençoássemos": "abençoar",
    "abençoávamo": "abençoar",
    "abençoávamos": "abençoar",
    "abençoávei": "abençoar",
    "abençoáveis": "abençoar",
    "aberingelada": "aberingelado",
    "aberingeladas": "aberingelado",
    "aberingelados": "aberingelado",
    "aberlindada": "aberlindado",
    "aberlindadas": "aberlindado",
    "aberlindados": "aberlindado",
    "aberra": "aberrar",
    "aberrada": "aberrar",
    "aberradas": "aberrar",
    "aberrado": "aberrar",
    "aberrados": "aberrar",
    "aberrai": "aberrar",
    "aberrais": "aberrar",
    "aberram": "aberrar",
    "aberramo": "aberrar",
    "aberramos": "aberrar",
    "aberrando": "aberrar",
    "aberrantes": "aberrante",
    "aberrara": "aberrar",
    "aberraram": "aberrar",
    "aberraras": "aberrar",
    "aberrardes": "aberrar",
    "aberrarei": "aberrar",
    "aberrareis": "aberrar",
    "aberrarem": "aberrar",
    "aberraremos": "aberrar",
    "aberrares": "aberrar",
    "aberraria": "aberrar",
    "aberrariam": "aberrar",
    "aberrarias": "aberrar",
    "aberrarmo": "aberrar",
    "aberrarmos": "aberrar",
    "aberrará": "aberrar",
    "aberrarás": "aberrar",
    "aberrarão": "aberrar",
    "aberraríamos": "aberrar",
    "aberraríeis": "aberrar",
    "aberras": "aberrar",
    "aberrasse": "aberrar",
    "aberrassem": "aberrar",
    "aberrasses": "aberrar",
    "aberraste": "aberrar",
    "aberrastes": "aberrar",
    "aberrativa": "aberrativo",
    "aberrativas": "aberrativo",
    "aberrativos": "aberrativo",
    "aberrava": "aberrar",
    "aberravam": "aberrar",
    "aberravas": "aberrar",
    "aberrações": "aberração",
    "aberre": "aberrar",
    "aberrei": "aberrar",
    "aberreis": "aberrar",
    "aberrem": "aberrar",
    "aberremo": "aberrar",
    "aberremos": "aberrar",
    "aberres": "aberrar",
    "aberro": "aberrar",
    "aberrou": "aberrar",
    "aberrámo": "aberrar",
    "aberrámos": "aberrar",
    "aberráramo": "aberrar",
    "aberráramos": "aberrar",
    "aberráreis": "aberrar",
    "aberrásseis": "aberrar",
    "aberrássemos": "aberrar",
    "aberrávamo": "aberrar",
    "aberrávamos": "aberrar",
    "aberráveis": "aberrar",
    "aberta": "aberto",
    "abertas": "aberto",
    "abertinha": "aberto",
    "abertinhas": "aberto",
    "abertinho": "aberto",
    "abertinhos": "aberto",
    "abertita": "aberto",
    "abertitas": "aberto",
    "abertito": "aberto",
    "abertitos": "aberto",
    "abertiva": "abertivo",
    "abertivas": "abertivo",
    "abertivos": "abertivo",
    "abertiça": "abertiço",
    "abertiças": "abertiço",
    "abertiços": "abertiço",
    "abertonas": "abertona",
    "abertos": "aberto",
    "aberturas": "abertura",
    "abertíssima": "aberto",
    "abertíssimas": "aberto",
    "abertíssimo": "aberto",
    "abertíssimos": "aberto",
    "abertões": "abertão",
    "aberéns": "aberém",
    "aberêmoas": "aberêmoa",
    "abes": "abar",
    "abesanta": "abesantar",
    "abesantada": "abesantar",
    "abesantadas": "abesantar",
    "abesantado": "abesantar",
    "abesantados": "abesantar",
    "abesantai": "abesantar",
    "abesantais": "abesantar",
    "abesantam": "abesantar",
    "abesantamo": "abesantar",
    "abesantamos": "abesantar",
    "abesantando": "abesantar",
    "abesantara": "abesantar",
    "abesantaram": "abesantar",
    "abesantaras": "abesantar",
    "abesantarde": "abesantar",
    "abesantardes": "abesantar",
    "abesantare": "abesantar",
    "abesantarei": "abesantar",
    "abesantareis": "abesantar",
    "abesantarem": "abesantar",
    "abesantaremos": "abesantar",
    "abesantares": "abesantar",
    "abesantaria": "abesantar",
    "abesantariam": "abesantar",
    "abesantarias": "abesantar",
    "abesantarmo": "abesantar",
    "abesantarmos": "abesantar",
    "abesantará": "abesantar",
    "abesantarás": "abesantar",
    "abesantarão": "abesantar",
    "abesantaríamos": "abesantar",
    "abesantaríeis": "abesantar",
    "abesantas": "abesantar",
    "abesantasse": "abesantar",
    "abesantassem": "abesantar",
    "abesantasses": "abesantar",
    "abesantaste": "abesantar",
    "abesantastes": "abesantar",
    "abesantava": "abesantar",
    "abesantavam": "abesantar",
    "abesantavas": "abesantar",
    "abesante": "abesantar",
    "abesantei": "abesantar",
    "abesanteis": "abesantar",
    "abesantem": "abesantar",
    "abesantemo": "abesantar",
    "abesantemos": "abesantar",
    "abesantes": "abesantar",
    "abesanto": "abesantar",
    "abesantou": "abesantar",
    "abesantá": "abesantar",
    "abesantámo": "abesantar",
    "abesantámos": "abesantar",
    "abesantáramo": "abesantar",
    "abesantáramos": "abesantar",
    "abesantárei": "abesantar",
    "abesantáreis": "abesantar",
    "abesantásseis": "abesantar",
    "abesantássemos": "abesantar",
    "abesantávamo": "abesantar",
    "abesantávamos": "abesantar",
    "abesantávei": "abesantar",
    "abesantáveis": "abesantar",
    "abesoira": "abesoirar",
    "abesoirada": "abesoirar",
    "abesoiradas": "abesoirar",
    "abesoirado": "abesoirar",
    "abesoirados": "abesoirar",
    "abesoirai": "abesoirar",
    "abesoirais": "abesoirar",
    "abesoiram": "abesoirar",
    "abesoiramo": "abesoirar",
    "abesoiramos": "abesoirar",
    "abesoirando": "abesoirar",
    "abesoirara": "abesoirar",
    "abesoiraram": "abesoirar",
    "abesoiraras": "abesoirar",
    "abesoirarde": "abesoirar",
    "abesoirardes": "abesoirar",
    "abesoirare": "abesoirar",
    "abesoirarei": "abesoirar",
    "abesoirareis": "abesoirar",
    "abesoirarem": "abesoirar",
    "abesoiraremos": "abesoirar",
    "abesoirares": "abesoirar",
    "abesoiraria": "abesoirar",
    "abesoirariam": "abesoirar",
    "abesoirarias": "abesoirar",
    "abesoirarmo": "abesoirar",
    "abesoirarmos": "abesoirar",
    "abesoirará": "abesoirar",
    "abesoirarás": "abesoirar",
    "abesoirarão": "abesoirar",
    "abesoiraríamos": "abesoirar",
    "abesoiraríeis": "abesoirar",
    "abesoiras": "abesoirar",
    "abesoirasse": "abesoirar",
    "abesoirassem": "abesoirar",
    "abesoirasses": "abesoirar",
    "abesoiraste": "abesoirar",
    "abesoirastes": "abesoirar",
    "abesoirava": "abesoirar",
    "abesoiravam": "abesoirar",
    "abesoiravas": "abesoirar",
    "abesoire": "abesoirar",
    "abesoirei": "abesoirar",
    "abesoireis": "abesoirar",
    "abesoirem": "abesoirar",
    "abesoiremo": "abesoirar",
    "abesoiremos": "abesoirar",
    "abesoires": "abesoirar",
    "abesoiro": "abesoirar",
    "abesoirou": "abesoirar",
    "abesoirá": "abesoirar",
    "abesoirámo": "abesoirar",
    "abesoirámos": "abesoirar",
    "abesoiráramo": "abesoirar",
    "abesoiráramos": "abesoirar",
    "abesoirárei": "abesoirar",
    "abesoiráreis": "abesoirar",
    "abesoirásseis": "abesoirar",
    "abesoirássemos": "abesoirar",
    "abesoirávamo": "abesoirar",
    "abesoirávamos": "abesoirar",
    "abesoirávei": "abesoirar",
    "abesoiráveis": "abesoirar",
    "abesoura": "abesourar",
    "abesourada": "abesourar",
    "abesouradas": "abesourar",
    "abesourado": "abesourar",
    "abesourados": "abesourar",
    "abesourai": "abesourar",
    "abesourais": "abesourar",
    "abesouram": "abesourar",
    "abesouramo": "abesourar",
    "abesouramos": "abesourar",
    "abesourando": "abesourar",
    "abesourara": "abesourar",
    "abesouraram": "abesourar",
    "abesouraras": "abesourar",
    "abesourarde": "abesourar",
    "abesourardes": "abesourar",
    "abesourare": "abesourar",
    "abesourarei": "abesourar",
    "abesourareis": "abesourar",
    "abesourarem": "abesourar",
    "abesouraremos": "abesourar",
    "abesourares": "abesourar",
    "abesouraria": "abesourar",
    "abesourariam": "abesourar",
    "abesourarias": "abesourar",
    "abesourarmo": "abesourar",
    "abesourarmos": "abesourar",
    "abesourará": "abesourar",
    "abesourarás": "abesourar",
    "abesourarão": "abesourar",
    "abesouraríamos": "abesourar",
    "abesouraríeis": "abesourar",
    "abesouras": "abesourar",
    "abesourasse": "abesourar",
    "abesourassem": "abesourar",
    "abesourasses": "abesourar",
    "abesouraste": "abesourar",
    "abesourastes": "abesourar",
    "abesourava": "abesourar",
    "abesouravam": "abesourar",
    "abesouravas": "abesourar",
    "abesoure": "abesourar",
    "abesourei": "abesourar",
    "abesoureis": "abesourar",
    "abesourem": "abesourar",
    "abesouremo": "abesourar",
    "abesouremos": "abesourar",
    "abesoures": "abesourar",
    "abesouro": "abesourar",
    "abesourou": "abesourar",
    "abesourá": "abesourar",
    "abesourámo": "abesourar",
    "abesourámos": "abesourar",
    "abesouráramo": "abesourar",
    "abesouráramos": "abesourar",
    "abesourárei": "abesourar",
    "abesouráreis": "abesourar",
    "abesourásseis": "abesourar",
    "abesourássemos": "abesourar",
    "abesourávamo": "abesourar",
    "abesourávamos": "abesourar",
    "abesourávei": "abesourar",
    "abesouráveis": "abesourar",
    "abespinha": "abespinhar",
    "abespinhada": "abespinhar",
    "abespinhadas": "abespinhar",
    "abespinhado": "abespinhar",
    "abespinhados": "abespinhar",
    "abespinhadíssima": "abespinhado",
    "abespinhadíssimas": "abespinhado",
    "abespinhadíssimo": "abespinhado",
    "abespinhadíssimos": "abespinhado",
    "abespinhai": "abespinhar",
    "abespinhais": "abespinhar",
    "abespinham": "abespinhar",
    "abespinhamentos": "abespinhamento",
    "abespinhamo": "abespinhar",
    "abespinhamos": "abespinhar",
    "abespinhando": "abespinhar",
    "abespinhara": "abespinhar",
    "abespinharam": "abespinhar",
    "abespinharas": "abespinhar",
    "abespinharde": "abespinhar",
    "abespinhardes": "abespinhar",
    "abespinhare": "abespinhar",
    "abespinharei": "abespinhar",
    "abespinhareis": "abespinhar",
    "abespinharem": "abespinhar",
    "abespinharemos": "abespinhar",
    "abespinhares": "abespinhar",
    "abespinharia": "abespinhar",
    "abespinhariam": "abespinhar",
    "abespinharias": "abespinhar",
    "abespinharmo": "abespinhar",
    "abespinharmos": "abespinhar",
    "abespinhará": "abespinhar",
    "abespinharás": "abespinhar",
    "abespinharão": "abespinhar",
    "abespinharíamos": "abespinhar",
    "abespinharíeis": "abespinhar",
    "abespinhas": "abespinhar",
    "abespinhasse": "abespinhar",
    "abespinhassem": "abespinhar",
    "abespinhasses": "abespinhar",
    "abespinhaste": "abespinhar",
    "abespinhastes": "abespinhar",
    "abespinhava": "abespinhar",
    "abespinhavam": "abespinhar",
    "abespinhavas": "abespinhar",
    "abespinhe": "abespinhar",
    "abespinhei": "abespinhar",
    "abespinheis": "abespinhar",
    "abespinhem": "abespinhar",
    "abespinhemo": "abespinhar",
    "abespinhemos": "abespinhar",
    "abespinhes": "abespinhar",
    "abespinho": "abespinhar",
    "abespinhou": "abespinhar",
    "abespinhá": "abespinhar",
    "abespinhámo": "abespinhar",
    "abespinhámos": "abespinhar",
    "abespinháramo": "abespinhar",
    "abespinháramos": "abespinhar",
    "abespinhárei": "abespinhar",
    "abespinháreis": "abespinhar",
    "abespinhásseis": "abespinhar",
    "abespinhássemos": "abespinhar",
    "abespinhávamo": "abespinhar",
    "abespinhávamos": "abespinhar",
    "abespinhávei": "abespinhar",
    "abespinháveis": "abespinhar",
    "abessins": "abessim",
    "abestalha": "abestalhar",
    "abestalhada": "abestalhar",
    "abestalhadas": "abestalhar",
    "abestalhado": "abestalhar",
    "abestalhados": "abestalhar",
    "abestalhai": "abestalhar",
    "abestalhais": "abestalhar",
    "abestalham": "abestalhar",
    "abestalhamo": "abestalhar",
    "abestalhamos": "abestalhar",
    "abestalhando": "abestalhar",
    "abestalhara": "abestalhar",
    "abestalharam": "abestalhar",
    "abestalharas": "abestalhar",
    "abestalharde": "abestalhar",
    "abestalhardes": "abestalhar",
    "abestalhare": "abestalhar",
    "abestalharei": "abestalhar",
    "abestalhareis": "abestalhar",
    "abestalharem": "abestalhar",
    "abestalharemos": "abestalhar",
    "abestalhares": "abestalhar",
    "abestalharia": "abestalhar",
    "abestalhariam": "abestalhar",
    "abestalharias": "abestalhar",
    "abestalharmo": "abestalhar",
    "abestalharmos": "abestalhar",
    "abestalhará": "abestalhar",
    "abestalharás": "abestalhar",
    "abestalharão": "abestalhar",
    "abestalharíamos": "abestalhar",
    "abestalharíeis": "abestalhar",
    "abestalhas": "abestalhar",
    "abestalhasse": "abestalhar",
    "abestalhassem": "abestalhar",
    "abestalhasses": "abestalhar",
    "abestalhaste": "abestalhar",
    "abestalhastes": "abestalhar",
    "abestalhava": "abestalhar",
    "abestalhavam": "abestalhar",
    "abestalhavas": "abestalhar",
    "abestalhe": "abestalhar",
    "abestalhei": "abestalhar",
    "abestalheis": "abestalhar",
    "abestalhem": "abestalhar",
    "abestalhemo": "abestalhar",
    "abestalhemos": "abestalhar",
    "abestalhes": "abestalhar",
    "abestalho": "abestalhar",
    "abestalhou": "abestalhar",
    "abestalhá": "abestalhar",
    "abestalhámo": "abestalhar",
    "abestalhámos": "abestalhar",
    "abestalháramo": "abestalhar",
    "abestalháramos": "abestalhar",
    "abestalhárei": "abestalhar",
    "abestalháreis": "abestalhar",
    "abestalhásseis": "abestalhar",
    "abestalhássemos": "abestalhar",
    "abestalhávamo": "abestalhar",
    "abestalhávamos": "abestalhar",
    "abestalhávei": "abestalhar",
    "abestalháveis": "abestalhar",
    "abestia": "abestiar",
    "abestiada": "abestiar",
    "abestiadas": "abestiar",
    "abestiado": "abestiar",
    "abestiados": "abestiar",
    "abestiai": "abestiar",
    "abestiais": "abestiar",
    "abestiam": "abestiar",
    "abestiamo": "abestiar",
    "abestiamos": "abestiar",
    "abestiando": "abestiar",
    "abestiara": "abestiar",
    "abestiaram": "abestiar",
    "abestiaras": "abestiar",
    "abestiarde": "abestiar",
    "abestiardes": "abestiar",
    "abestiare": "abestiar",
    "abestiarei": "abestiar",
    "abestiareis": "abestiar",
    "abestiarem": "abestiar",
    "abestiaremos": "abestiar",
    "abestiares": "abestiar",
    "abestiaria": "abestiar",
    "abestiariam": "abestiar",
    "abestiarias": "abestiar",
    "abestiarmo": "abestiar",
    "abestiarmos": "abestiar",
    "abestiará": "abestiar",
    "abestiarás": "abestiar",
    "abestiarão": "abestiar",
    "abestiaríamos": "abestiar",
    "abestiaríeis": "abestiar",
    "abestias": "abestiar",
    "abestiasse": "abestiar",
    "abestiassem": "abestiar",
    "abestiasses": "abestiar",
    "abestiaste": "abestiar",
    "abestiastes": "abestiar",
    "abestiava": "abestiar",
    "abestiavam": "abestiar",
    "abestiavas": "abestiar",
    "abestie": "abestiar",
    "abestiei": "abestiar",
    "abestieis": "abestiar",
    "abestiem": "abestiar",
    "abestiemo": "abestiar",
    "abestiemos": "abestiar",
    "abesties": "abestiar",
    "abestio": "abestiar",
    "abestiou": "abestiar",
    "abestiá": "abestiar",
    "abestiámo": "abestiar",
    "abestiámos": "abestiar",
    "abestiáramo": "abestiar",
    "abestiáramos": "abestiar",
    "abestiárei": "abestiar",
    "abestiáreis": "abestiar",
    "abestiásseis": "abestiar",
    "abestiássemos": "abestiar",
    "abestiávamo": "abestiar",
    "abestiávamos": "abestiar",
    "abestiávei": "abestiar",
    "abestiáveis": "abestiar",
    "abetardada": "abetardado",
    "abetardadas": "abetardado",
    "abetardados": "abetardado",
    "abetardas": "abetarda",
    "abetardinhas": "abetardinha",
    "abetesgada": "abetesgado",
    "abetesgadas": "abetesgado",
    "abetesgados": "abetesgado",
    "abetoiras": "abetoira",
    "abetoiros": "abetoiro",
    "abetoninhas": "abetoninha",
    "abetos": "abeto",
    "abetouras": "abetoura",
    "abetouros": "abetouro",
    "abetuma": "abetumar",
    "abetumada": "abetumar",
    "abetumadas": "abetumar",
    "abetumado": "abetumar",
    "abetumados": "abetumar",
    "abetumai": "abetumar",
    "abetumais": "abetumar",
    "abetumam": "abetumar",
    "abetumamo": "abetumar",
    "abetumamos": "abetumar",
    "abetumando": "abetumar",
    "abetumara": "abetumar",
    "abetumaram": "abetumar",
    "abetumaras": "abetumar",
    "abetumarde": "abetumar",
    "abetumardes": "abetumar",
    "abetumare": "abetumar",
    "abetumarei": "abetumar",
    "abetumareis": "abetumar",
    "abetumarem": "abetumar",
    "abetumaremos": "abetumar",
    "abetumares": "abetumar",
    "abetumaria": "abetumar",
    "abetumariam": "abetumar",
    "abetumarias": "abetumar",
    "abetumarmo": "abetumar",
    "abetumarmos": "abetumar",
    "abetumará": "abetumar",
    "abetumarás": "abetumar",
    "abetumarão": "abetumar",
    "abetumaríamos": "abetumar",
    "abetumaríeis": "abetumar",
    "abetumas": "abetumar",
    "abetumasse": "abetumar",
    "abetumassem": "abetumar",
    "abetumasses": "abetumar",
    "abetumaste": "abetumar",
    "abetumastes": "abetumar",
    "abetumava": "abetumar",
    "abetumavam": "abetumar",
    "abetumavas": "abetumar",
    "abetume": "abetumar",
    "abetumei": "abetumar",
    "abetumeis": "abetumar",
    "abetumem": "abetumar",
    "abetumemo": "abetumar",
    "abetumemos": "abetumar",
    "abetumes": "abetumar",
    "abetumo": "abetumar",
    "abetumou": "abetumar",
    "abetumá": "abetumar",
    "abetumámo": "abetumar",
    "abetumámos": "abetumar",
    "abetumáramo": "abetumar",
    "abetumáramos": "abetumar",
    "abetumárei": "abetumar",
    "abetumáreis": "abetumar",
    "abetumásseis": "abetumar",
    "abetumássemos": "abetumar",
    "abetumávamo": "abetumar",
    "abetumávamos": "abetumar",
    "abetumávei": "abetumar",
    "abetumáveis": "abetumar",
    "abetuns": "abetum",
    "abevillenses": "abevillense",
    "abexiga": "abexigar",
    "abexigada": "abexigar",
    "abexigadas": "abexigar",
    "abexigado": "abexigar",
    "abexigados": "abexigar",
    "abexigai": "abexigar",
    "abexigais": "abexigar",
    "abexigam": "abexigar",
    "abexigamo": "abexigar",
    "abexigamos": "abexigar",
    "abexigando": "abexigar",
    "abexigara": "abexigar",
    "abexigaram": "abexigar",
    "abexigaras": "abexigar",
    "abexigarde": "abexigar",
    "abexigardes": "abexigar",
    "abexigare": "abexigar",
    "abexigarei": "abexigar",
    "abexigareis": "abexigar",
    "abexigarem": "abexigar",
    "abexigaremos": "abexigar",
    "abexigares": "abexigar",
    "abexigaria": "abexigar",
    "abexigariam": "abexigar",
    "abexigarias": "abexigar",
    "abexigarmo": "abexigar",
    "abexigarmos": "abexigar",
    "abexigará": "abexigar",
    "abexigarás": "abexigar",
    "abexigarão": "abexigar",
    "abexigaríamos": "abexigar",
    "abexigaríeis": "abexigar",
    "abexigas": "abexigar",
    "abexigasse": "abexigar",
    "abexigassem": "abexigar",
    "abexigasses": "abexigar",
    "abexigaste": "abexigar",
    "abexigastes": "abexigar",
    "abexigava": "abexigar",
    "abexigavam": "abexigar",
    "abexigavas": "abexigar",
    "abexigo": "abexigar",
    "abexigou": "abexigar",
    "abexigue": "abexigar",
    "abexiguei": "abexigar",
    "abexigueis": "abexigar",
    "abexiguem": "abexigar",
    "abexiguemo": "abexigar",
    "abexiguemos": "abexigar",
    "abexigues": "abexigar",
    "abexigá": "abexigar",
    "abexigámo": "abexigar",
    "abexigámos": "abexigar",
    "abexigáramo": "abexigar",
    "abexigáramos": "abexigar",
    "abexigárei": "abexigar",
    "abexigáreis": "abexigar",
    "abexigásseis": "abexigar",
    "abexigássemos": "abexigar",
    "abexigávamo": "abexigar",
    "abexigávamos": "abexigar",
    "abexigávei": "abexigar",
    "abexigáveis": "abexigar",
    "abexins": "abexim",
    "abezerrada": "abezerrado",
    "abezerradas": "abezerrado",
    "abezerrados": "abezerrado",
    "abibes": "abibe",
    "abiburas": "abibura",
    "abica": "abicar",
    "abicada": "abicar",
    "abicadas": "abicar",
    "abicado": "abicar",
    "abicadoiros": "abicadoiro",
    "abicados": "abicar",
    "abicadouros": "abicadouro",
    "abicai": "abicar",
    "abicais": "abicar",
    "abicam": "abicar",
    "abicamo": "abicar",
    "abicamos": "abicar",
    "abicando": "abicar",
    "abicara": "abicar",
    "abicaram": "abicar",
    "abicaras": "abicar",
    "abicarde": "abicar",
    "abicardes": "abicar",
    "abicare": "abicar",
    "abicarei": "abicar",
    "abicareis": "abicar",
    "abicarem": "abicar",
    "abicaremos": "abicar",
    "abicares": "abicar",
    "abicaria": "abicar",
    "abicariam": "abicar",
    "abicarias": "abicar",
    "abicarmo": "abicar",
    "abicarmos": "abicar",
    "abicará": "abicar",
    "abicarás": "abicar",
    "abicarão": "abicar",
    "abicaríamos": "abicar",
    "abicaríeis": "abicar",
    "abicas": "abicar",
    "abicasse": "abicar",
    "abicassem": "abicar",
    "abicasses": "abicar",
    "abicaste": "abicar",
    "abicastes": "abicar",
    "abicava": "abicar",
    "abicavam": "abicar",
    "abicavas": "abicar",
    "abicha": "abichar",
    "abichada": "abichar",
    "abichadas": "abichar",
    "abichado": "abichar",
    "abichados": "abichar",
    "abichai": "abichar",
    "abichais": "abichar",
    "abicham": "abichar",
    "abichamo": "abichar",
    "abichamos": "abichar",
    "abichando": "abichar",
    "abichara": "abichar",
    "abicharam": "abichar",
    "abicharas": "abichar",
    "abicharde": "abichar",
    "abichardes": "abichar",
    "abichare": "abichar",
    "abicharei": "abichar",
    "abichareis": "abichar",
    "abicharem": "abichar",
    "abicharemos": "abichar",
    "abichares": "abichar",
    "abicharia": "abichar",
    "abichariam": "abichar",
    "abicharias": "abichar",
    "abicharmo": "abichar",
    "abicharmos": "abichar",
    "abichará": "abichar",
    "abicharás": "abichar",
    "abicharão": "abichar",
    "abicharíamos": "abichar",
    "abicharíeis": "abichar",
    "abichas": "abichar",
    "abichasse": "abichar",
    "abichassem": "abichar",
    "abichasses": "abichar",
    "abichaste": "abichar",
    "abichastes": "abichar",
    "abichava": "abichar",
    "abichavam": "abichar",
    "abichavas": "abichar",
    "abiche": "abichar",
    "abichei": "abichar",
    "abicheis": "abichar",
    "abichem": "abichar",
    "abichemo": "abichar",
    "abichemos": "abichar",
    "abiches": "abichar",
    "abicho": "abichar",
    "abichou": "abichar",
    "abichá": "abichar",
    "abichámo": "abichar",
    "abichámos": "abichar",
    "abicháramo": "abichar",
    "abicháramos": "abichar",
    "abichárei": "abichar",
    "abicháreis": "abichar",
    "abichásseis": "abichar",
    "abichássemos": "abichar",
    "abichávamo": "abichar",
    "abichávamos": "abichar",
    "abichávei": "abichar",
    "abicháveis": "abichar",
    "abico": "abicar",
    "abicou": "abicar",
    "abicá": "abicar",
    "abicámo": "abicar",
    "abicámos": "abicar",
    "abicáramo": "abicar",
    "abicáramos": "abicar",
    "abicárei": "abicar",
    "abicáreis": "abicar",
    "abicásseis": "abicar",
    "abicássemos": "abicar",
    "abicávamo": "abicar",
    "abicávamos": "abicar",
    "abicávei": "abicar",
    "abicáveis": "abicar",
    "abicôs": "abicô",
    "abieiros": "abieiro",
    "abietinas": "abietina",
    "abietíneas": "abietínea",
    "abigarrada": "abigarrado",
    "abigarradas": "abigarrado",
    "abigarrados": "abigarrado",
    "abigeatos": "abigeato",
    "abigeatária": "abigeatário",
    "abigeatárias": "abigeatário",
    "abigeatários": "abigeatário",
    "abigodada": "abigodado",
    "abigodadas": "abigodado",
    "abigodados": "abigodado",
    "abinha": "aba",
    "abinhas": "aba",
    "abiofilias": "abiofilia",
    "abiogéneses": "abiogénese",
    "abiomba": "abiombar",
    "abiombada": "abiombar",
    "abiombadas": "abiombar",
    "abiombado": "abiombar",
    "abiombados": "abiombar",
    "abiombai": "abiombar",
    "abiombais": "abiombar",
    "abiombam": "abiombar",
    "abiombamo": "abiombar",
    "abiombamos": "abiombar",
    "abiombando": "abiombar",
    "abiombara": "abiombar",
    "abiombaram": "abiombar",
    "abiombaras": "abiombar",
    "abiombarde": "abiombar",
    "abiombardes": "abiombar",
    "abiombare": "abiombar",
    "abiombarei": "abiombar",
    "abiombareis": "abiombar",
    "abiombarem": "abiombar",
    "abiombaremos": "abiombar",
    "abiombares": "abiombar",
    "abiombaria": "abiombar",
    "abiombariam": "abiombar",
    "abiombarias": "abiombar",
    "abiombarmo": "abiombar",
    "abiombarmos": "abiombar",
    "abiombará": "abiombar",
    "abiombarás": "abiombar",
    "abiombarão": "abiombar",
    "abiombaríamos": "abiombar",
    "abiombaríeis": "abiombar",
    "abiombas": "abiombar",
    "abiombasse": "abiombar",
    "abiombassem": "abiombar",
    "abiombasses": "abiombar",
    "abiombaste": "abiombar",
    "abiombastes": "abiombar",
    "abiombava": "abiombar",
    "abiombavam": "abiombar",
    "abiombavas": "abiombar",
    "abiombe": "abiombar",
    "abiombei": "abiombar",
    "abiombeis": "abiombar",
    "abiombem": "abiombar",
    "abiombemo": "abiombar",
    "abiombemos": "abiombar",
    "abiombes": "abiombar",
    "abiombo": "abiombar",
    "abiombou": "abiombar",
    "abiombá": "abiombar",
    "abiombámo": "abiombar",
    "abiombámos": "abiombar",
    "abiombáramo": "abiombar",
    "abiombáramos": "abiombar",
    "abiombárei": "abiombar",
    "abiombáreis": "abiombar",
    "abiombásseis": "abiombar",
    "abiombássemos": "abiombar",
    "abiombávamo": "abiombar",
    "abiombávamos": "abiombar",
    "abiombávei": "abiombar",
    "abiombáveis": "abiombar",
    "abioris": "abiori",
    "abios": "abio",
    "abioses": "abiose",
    "abiotos": "abioto",
    "abiotrofias": "abiotrofia",
    "abique": "abicar",
    "abiquei": "abicar",
    "abiqueirada": "abiqueirado",
    "abiqueiradas": "abiqueirado",
    "abiqueirados": "abiqueirado",
    "abiqueis": "abicar",
    "abiquem": "abicar",
    "abiquemo": "abicar",
    "abiquemos": "abicar",
    "abiques": "abicar",
    "abirrita": "abirritar",
    "abirritada": "abirritar",
    "abirritadas": "abirritar",
    "abirritado": "abirritar",
    "abirritados": "abirritar",
    "abirritai": "abirritar",
    "abirritais": "abirritar",
    "abirritam": "abirritar",
    "abirritamo": "abirritar",
    "abirritamos": "abirritar",
    "abirritando": "abirritar",
    "abirritantes": "abirritante",
    "abirritara": "abirritar",
    "abirritaram": "abirritar",
    "abirritaras": "abirritar",
    "abirritarde": "abirritar",
    "abirritardes": "abirritar",
    "abirritare": "abirritar",
    "abirritarei": "abirritar",
    "abirritareis": "abirritar",
    "abirritarem": "abirritar",
    "abirritaremos": "abirritar",
    "abirritares": "abirritar",
    "abirritaria": "abirritar",
    "abirritariam": "abirritar",
    "abirritarias": "abirritar",
    "abirritarmo": "abirritar",
    "abirritarmos": "abirritar",
    "abirritará": "abirritar",
    "abirritarás": "abirritar",
    "abirritarão": "abirritar",
    "abirritaríamos": "abirritar",
    "abirritaríeis": "abirritar",
    "abirritas": "abirritar",
    "abirritasse": "abirritar",
    "abirritassem": "abirritar",
    "abirritasses": "abirritar",
    "abirritaste": "abirritar",
    "abirritastes": "abirritar",
    "abirritava": "abirritar",
    "abirritavam": "abirritar",
    "abirritavas": "abirritar",
    "abirritações": "abirritação",
    "abirrite": "abirritar",
    "abirritei": "abirritar",
    "abirriteis": "abirritar",
    "abirritem": "abirritar",
    "abirritemo": "abirritar",
    "abirritemos": "abirritar",
    "abirrites": "abirritar",
    "abirrito": "abirritar",
    "abirritou": "abirritar",
    "abirritá": "abirritar",
    "abirritámo": "abirritar",
    "abirritámos": "abirritar",
    "abirritáramo": "abirritar",
    "abirritáramos": "abirritar",
    "abirritárei": "abirritar",
    "abirritáreis": "abirritar",
    "abirritásseis": "abirritar",
    "abirritássemos": "abirritar",
    "abirritávamo": "abirritar",
    "abirritávamos": "abirritar",
    "abirritávei": "abirritar",
    "abirritáveis": "abirritar",
    "abiscoita": "abiscoitar",
    "abiscoitada": "abiscoitar",
    "abiscoitadas": "abiscoitar",
    "abiscoitado": "abiscoitar",
    "abiscoitados": "abiscoitar",
    "abiscoitai": "abiscoitar",
    "abiscoitais": "abiscoitar",
    "abiscoitam": "abiscoitar",
    "abiscoitamo": "abiscoitar",
    "abiscoitamos": "abiscoitar",
    "abiscoitando": "abiscoitar",
    "abiscoitara": "abiscoitar",
    "abiscoitaram": "abiscoitar",
    "abiscoitaras": "abiscoitar",
    "abiscoitarde": "abiscoitar",
    "abiscoitardes": "abiscoitar",
    "abiscoitare": "abiscoitar",
    "abiscoitarei": "abiscoitar",
    "abiscoitareis": "abiscoitar",
    "abiscoitarem": "abiscoitar",
    "abiscoitaremos": "abiscoitar",
    "abiscoitares": "abiscoitar",
    "abiscoitaria": "abiscoitar",
    "abiscoitariam": "abiscoitar",
    "abiscoitarias": "abiscoitar",
    "abiscoitarmo": "abiscoitar",
    "abiscoitarmos": "abiscoitar",
    "abiscoitará": "abiscoitar",
    "abiscoitarás": "abiscoitar",
    "abiscoitarão": "abiscoitar",
    "abiscoitaríamos": "abiscoitar",
    "abiscoitaríeis": "abiscoitar",
    "abiscoitas": "abiscoitar",
    "abiscoitasse": "abiscoitar",
    "abiscoitassem": "abiscoitar",
    "abiscoitasses": "abiscoitar",
    "abiscoitaste": "abiscoitar",
    "abiscoitastes": "abiscoitar",
    "abiscoitava": "abiscoitar",
    "abiscoitavam": "abiscoitar",
    "abiscoitavas": "abiscoitar",
    "abiscoite": "abiscoitar",
    "abiscoitei": "abiscoitar",
    "abiscoiteis": "abiscoitar",
    "abiscoitem": "abiscoitar",
    "abiscoitemo": "abiscoitar",
    "abiscoitemos": "abiscoitar",
    "abiscoites": "abiscoitar",
    "abiscoito": "abiscoitar",
    "abiscoitou": "abiscoitar",
    "abiscoitá": "abiscoitar",
    "abiscoitámo": "abiscoitar",
    "abiscoitámos": "abiscoitar",
    "abiscoitáramo": "abiscoitar",
    "abiscoitáramos": "abiscoitar",
    "abiscoitárei": "abiscoitar",
    "abiscoitáreis": "abiscoitar",
    "abiscoitásseis": "abiscoitar",
    "abiscoitássemos": "abiscoitar",
    "abiscoitávamo": "abiscoitar",
    "abiscoitávamos": "abiscoitar",
    "abiscoitávei": "abiscoitar",
    "abiscoitáveis": "abiscoitar",
    "abiscouta": "abiscoutar",
    "abiscoutada": "abiscoutar",
    "abiscoutadas": "abiscoutar",
    "abiscoutado": "abiscoutar",
    "abiscoutados": "abiscoutar",
    "abiscoutai": "abiscoutar",
    "abiscoutais": "abiscoutar",
    "abiscoutam": "abiscoutar",
    "abiscoutamo": "abiscoutar",
    "abiscoutamos": "abiscoutar",
    "abiscoutando": "abiscoutar",
    "abiscoutara": "abiscoutar",
    "abiscoutaram": "abiscoutar",
    "abiscoutaras": "abiscoutar",
    "abiscoutarde": "abiscoutar",
    "abiscoutardes": "abiscoutar",
    "abiscoutare": "abiscoutar",
    "abiscoutarei": "abiscoutar",
    "abiscoutareis": "abiscoutar",
    "abiscoutarem": "abiscoutar",
    "abiscoutaremos": "abiscoutar",
    "abiscoutares": "abiscoutar",
    "abiscoutaria": "abiscoutar",
    "abiscoutariam": "abiscoutar",
    "abiscoutarias": "abiscoutar",
    "abiscoutarmo": "abiscoutar",
    "abiscoutarmos": "abiscoutar",
    "abiscoutará": "abiscoutar",
    "abiscoutarás": "abiscoutar",
    "abiscoutarão": "abiscoutar",
    "abiscoutaríamos": "abiscoutar",
    "abiscoutaríeis": "abiscoutar",
    "abiscoutas": "abiscoutar",
    "abiscoutasse": "abiscoutar",
    "abiscoutassem": "abiscoutar",
    "abiscoutasses": "abiscoutar",
    "abiscoutaste": "abiscoutar",
    "abiscoutastes": "abiscoutar",
    "abiscoutava": "abiscoutar",
    "abiscoutavam": "abiscoutar",
    "abiscoutavas": "abiscoutar",
    "abiscoute": "abiscoutar",
    "abiscoutei": "abiscoutar",
    "abiscouteis": "abiscoutar",
    "abiscoutem": "abiscoutar",
    "abiscoutemo": "abiscoutar",
    "abiscoutemos": "abiscoutar",
    "abiscoutes": "abiscoutar",
    "abiscouto": "abiscoutar",
    "abiscoutou": "abiscoutar",
    "abiscoutá": "abiscoutar",
    "abiscoutámo": "abiscoutar",
    "abiscoutámos": "abiscoutar",
    "abiscoutáramo": "abiscoutar",
    "abiscoutáramos": "abiscoutar",
    "abiscoutárei": "abiscoutar",
    "abiscoutáreis": "abiscoutar",
    "abiscoutásseis": "abiscoutar",
    "abiscoutássemos": "abiscoutar",
    "abiscoutávamo": "abiscoutar",
    "abiscoutávamos": "abiscoutar",
    "abiscoutávei": "abiscoutar",
    "abiscoutáveis": "abiscoutar",
    "abisma": "abismar",
    "abismada": "abismar",
    "abismadas": "abismar",
    "abismado": "abismar",
    "abismados": "abismar",
    "abismadíssima": "abismado",
    "abismadíssimas": "abismado",
    "abismadíssimo": "abismado",
    "abismadíssimos": "abismado",
    "abismai": "abismar",
    "abismais": "abismar",
    "abismam": "abismar",
    "abismamo": "abismar",
    "abismamos": "abismar",
    "abismando": "abismar",
    "abismara": "abismar",
    "abismaram": "abismar",
    "abismaras": "abismar",
    "abismarde": "abismar",
    "abismardes": "abismar",
    "abismare": "abismar",
    "abismarei": "abismar",
    "abismareis": "abismar",
    "abismarem": "abismar",
    "abismaremos": "abismar",
    "abismares": "abismar",
    "abismaria": "abismar",
    "abismariam": "abismar",
    "abismarias": "abismar",
    "abismarmo": "abismar",
    "abismarmos": "abismar",
    "abismará": "abismar",
    "abismarás": "abismar",
    "abismarão": "abismar",
    "abismaríamos": "abismar",
    "abismaríeis": "abismar",
    "abismas": "abismar",
    "abismasse": "abismar",
    "abismassem": "abismar",
    "abismasses": "abismar",
    "abismaste": "abismar",
    "abismastes": "abismar",
    "abismava": "abismar",
    "abismavam": "abismar",
    "abismavas": "abismar",
    "abisme": "abismar",
    "abismei": "abismar",
    "abismeis": "abismar",
    "abismem": "abismar",
    "abismemo": "abismar",
    "abismemos": "abismar",
    "abismes": "abismar",
    "abismo": "abismar",
    "abismos": "abismo",
    "abismou": "abismar",
    "abismá": "abismar",
    "abismámo": "abismar",
    "abismámos": "abismar",
    "abismáramo": "abismar",
    "abismáramos": "abismar",
    "abismárei": "abismar",
    "abismáreis": "abismar",
    "abismásseis": "abismar",
    "abismássemos": "abismar",
    "abismávamo": "abismar",
    "abismávamos": "abismar",
    "abismávei": "abismar",
    "abismáveis": "abismar",
    "abisonha": "abisonhar",
    "abisonhada": "abisonhar",
    "abisonhadas": "abisonhar",
    "abisonhado": "abisonhar",
    "abisonhados": "abisonhar",
    "abisonhai": "abisonhar",
    "abisonhais": "abisonhar",
    "abisonham": "abisonhar",
    "abisonhamo": "abisonhar",
    "abisonhamos": "abisonhar",
    "abisonhando": "abisonhar",
    "abisonhara": "abisonhar",
    "abisonharam": "abisonhar",
    "abisonharas": "abisonhar",
    "abisonharde": "abisonhar",
    "abisonhardes": "abisonhar",
    "abisonhare": "abisonhar",
    "abisonharei": "abisonhar",
    "abisonhareis": "abisonhar",
    "abisonharem": "abisonhar",
    "abisonharemos": "abisonhar",
    "abisonhares": "abisonhar",
    "abisonharia": "abisonhar",
    "abisonhariam": "abisonhar",
    "abisonharias": "abisonhar",
    "abisonharmo": "abisonhar",
    "abisonharmos": "abisonhar",
    "abisonhará": "abisonhar",
    "abisonharás": "abisonhar",
    "abisonharão": "abisonhar",
    "abisonharíamos": "abisonhar",
    "abisonharíeis": "abisonhar",
    "abisonhas": "abisonhar",
    "abisonhasse": "abisonhar",
    "abisonhassem": "abisonhar",
    "abisonhasses": "abisonhar",
    "abisonhaste": "abisonhar",
    "abisonhastes": "abisonhar",
    "abisonhava": "abisonhar",
    "abisonhavam": "abisonhar",
    "abisonhavas": "abisonhar",
    "abisonhe": "abisonhar",
    "abisonhei": "abisonhar",
    "abisonheis": "abisonhar",
    "abisonhem": "abisonhar",
    "abisonhemo": "abisonhar",
    "abisonhemos": "abisonhar",
    "abisonhes": "abisonhar",
    "abisonho": "abisonhar",
    "abisonhou": "abisonhar",
    "abisonhá": "abisonhar",
    "abisonhámo": "abisonhar",
    "abisonhámos": "abisonhar",
    "abisonháramo": "abisonhar",
    "abisonháramos": "abisonhar",
    "abisonhárei": "abisonhar",
    "abisonháreis": "abisonhar",
    "abisonhásseis": "abisonhar",
    "abisonhássemos": "abisonhar",
    "abisonhávamo": "abisonhar",
    "abisonhávamos": "abisonhar",
    "abisonhávei": "abisonhar",
    "abisonháveis": "abisonhar",
    "abispa": "abispar",
    "abispada": "abispar",
    "abispadas": "abispar",
    "abispado": "abispar",
    "abispados": "abispar",
    "abispadíssima": "abispado",
    "abispadíssimas": "abispado",
    "abispadíssimo": "abispado",
    "abispadíssimos": "abispado",
    "abispai": "abispar",
    "abispais": "abispar",
    "abispam": "abispar",
    "abispamentos": "abispamento",
    "abispamo": "abispar",
    "abispamos": "abispar",
    "abispando": "abispar",
    "abispara": "abispar",
    "abisparam": "abispar",
    "abisparas": "abispar",
    "abisparde": "abispar",
    "abispardes": "abispar",
    "abispare": "abispar",
    "abisparei": "abispar",
    "abispareis": "abispar",
    "abisparem": "abispar",
    "abisparemos": "abispar",
    "abispares": "abispar",
    "abisparia": "abispar",
    "abispariam": "abispar",
    "abisparias": "abispar",
    "abisparmo": "abispar",
    "abisparmos": "abispar",
    "abispará": "abispar",
    "abisparás": "abispar",
    "abisparão": "abispar",
    "abisparíamos": "abispar",
    "abisparíeis": "abispar",
    "abispas": "abispar",
    "abispasse": "abispar",
    "abispassem": "abispar",
    "abispasses": "abispar",
    "abispaste": "abispar",
    "abispastes": "abispar",
    "abispava": "abispar",
    "abispavam": "abispar",
    "abispavas": "abispar",
    "abispe": "abispar",
    "abispei": "abispar",
    "abispeis": "abispar",
    "abispem": "abispar",
    "abispemo": "abispar",
    "abispemos": "abispar",
    "abispes": "abispar",
    "abispo": "abispar",
    "abispou": "abispar",
    "abispá": "abispar",
    "abispámo": "abispar",
    "abispámos": "abispar",
    "abispáramo": "abispar",
    "abispáramos": "abispar",
    "abispárei": "abispar",
    "abispáreis": "abispar",
    "abispásseis": "abispar",
    "abispássemos": "abispar",
    "abispávamo": "abispar",
    "abispávamos": "abispar",
    "abispávei": "abispar",
    "abispáveis": "abispar",
    "abissais": "abissal",
    "abissínia": "abissínio",
    "abissínias": "abissínio",
    "abissínios": "abissínio",
    "abissólitos": "abissólito",
    "abita": "abitar",
    "abitada": "abitar",
    "abitadas": "abitar",
    "abitado": "abitar",
    "abitados": "abitar",
    "abitaduras": "abitadura",
    "abitai": "abitar",
    "abitais": "abitar",
    "abitam": "abitar",
    "abitamo": "abitar",
    "abitamos": "abitar",
    "abitanas": "abitana",
    "abitando": "abitar",
    "abitara": "abitar",
    "abitaram": "abitar",
    "abitaras": "abitar",
    "abitarde": "abitar",
    "abitardes": "abitar",
    "abitare": "abitar",
    "abitarei": "abitar",
    "abitareis": "abitar",
    "abitarem": "abitar",
    "abitaremos": "abitar",
    "abitares": "abitar",
    "abitaria": "abitar",
    "abitariam": "abitar",
    "abitarias": "abitar",
    "abitarmo": "abitar",
    "abitarmos": "abitar",
    "abitará": "abitar",
    "abitarás": "abitar",
    "abitarão": "abitar",
    "abitaríamos": "abitar",
    "abitaríeis": "abitar",
    "abitas": "abitar",
    "abitasse": "abitar",
    "abitassem": "abitar",
    "abitasses": "abitar",
    "abitaste": "abitar",
    "abitastes": "abitar",
    "abitava": "abitar",
    "abitavam": "abitar",
    "abitavas": "abitar",
    "abite": "abitar",
    "abitei": "abitar",
    "abiteis": "abitar",
    "abitem": "abitar",
    "abitemo": "abitar",
    "abitemos": "abitar",
    "abites": "abitar",
    "abito": "abitar",
    "abitoninhas": "abitoninha",
    "abitou": "abitar",
    "abitá": "abitar",
    "abitámo": "abitar",
    "abitámos": "abitar",
    "abitáramo": "abitar",
    "abitáramos": "abitar",
    "abitárei": "abitar",
    "abitáreis": "abitar",
    "abitásseis": "abitar",
    "abitássemos": "abitar",
    "abitávamo": "abitar",
    "abitávamos": "abitar",
    "abitávei": "abitar",
    "abitáveis": "abitar",
    "abiuranas": "abiurana",
    "abius": "abiu",
    "abiética": "abiético",
    "abiéticas": "abiético",
    "abiéticos": "abiético",
    "abiótica": "abiótico",
    "abióticas": "abiótico",
    "abióticos": "abiótico",
    "abjecta": "abjecto",
    "abjectas": "abjecto",
    "abjectos": "abjecto",
    "abjecções": "abjecção",
    "abjudica": "abjudicar",
    "abjudicada": "abjudicar",
    "abjudicadas": "abjudicar",
    "abjudicado": "abjudicar",
    "abjudicadora": "abjudicador",
    "abjudicadoras": "abjudicador",
    "abjudicadores": "abjudicador",
    "abjudicados": "abjudicar",
    "abjudicai": "abjudicar",
    "abjudicais": "abjudicar",
    "abjudicam": "abjudicar",
    "abjudicamo": "abjudicar",
    "abjudicamos": "abjudicar",
    "abjudicando": "abjudicar",
    "abjudicantes": "abjudicante",
    "abjudicara": "abjudicar",
    "abjudicaram": "abjudicar",
    "abjudicaras": "abjudicar",
    "abjudicarde": "abjudicar",
    "abjudicardes": "abjudicar",
    "abjudicare": "abjudicar",
    "abjudicarei": "abjudicar",
    "abjudicareis": "abjudicar",
    "abjudicarem": "abjudicar",
    "abjudicaremos": "abjudicar",
    "abjudicares": "abjudicar",
    "abjudicaria": "abjudicar",
    "abjudicariam": "abjudicar",
    "abjudicarias": "abjudicar",
    "abjudicarmo": "abjudicar",
    "abjudicarmos": "abjudicar",
    "abjudicará": "abjudicar",
    "abjudicarás": "abjudicar",
    "abjudicarão": "abjudicar",
    "abjudicaríamos": "abjudicar",
    "abjudicaríeis": "abjudicar",
    "abjudicas": "abjudicar",
    "abjudicasse": "abjudicar",
    "abjudicassem": "abjudicar",
    "abjudicasses": "abjudicar",
    "abjudicaste": "abjudicar",
    "abjudicastes": "abjudicar",
    "abjudicava": "abjudicar",
    "abjudicavam": "abjudicar",
    "abjudicavas": "abjudicar",
    "abjudicações": "abjudicação",
    "abjudico": "abjudicar",
    "abjudicou": "abjudicar",
    "abjudicá": "abjudicar",
    "abjudicámo": "abjudicar",
    "abjudicámos": "abjudicar",
    "abjudicáramo": "abjudicar",
    "abjudicáramos": "abjudicar",
    "abjudicárei": "abjudicar",
    "abjudicáreis": "abjudicar",
    "abjudicásseis": "abjudicar",
    "abjudicássemos": "abjudicar",
    "abjudicávamo": "abjudicar",
    "abjudicávamos": "abjudicar",
    "abjudicávei": "abjudicar",
    "abjudicáveis": "abjudicável",
    "abjudique": "abjudicar",
    "abjudiquei": "abjudicar",
    "abjudiqueis": "abjudicar",
    "abjudiquem": "abjudicar",
    "abjudiquemo": "abjudicar",
    "abjudiquemos": "abjudicar",
    "abjudiques": "abjudicar",
    "abjuga": "abjugar",
    "abjugada": "abjugar",
    "abjugadas": "abjugar",
    "abjugado": "abjugar",
    "abjugados": "abjugar",
    "abjugai": "abjugar",
    "abjugais": "abjugar",
    "abjugam": "abjugar",
    "abjugamo": "abjugar",
    "abjugamos": "abjugar",
    "abjugando": "abjugar",
    "abjugara": "abjugar",
    "abjugaram": "abjugar",
    "abjugaras": "abjugar",
    "abjugarde": "abjugar",
    "abjugardes": "abjugar",
    "abjugare": "abjugar",
    "abjugarei": "abjugar",
    "abjugareis": "abjugar",
    "abjugarem": "abjugar",
    "abjugaremos": "abjugar",
    "abjugares": "abjugar",
    "abjugaria": "abjugar",
    "abjugariam": "abjugar",
    "abjugarias": "abjugar",
    "abjugarmo": "abjugar",
    "abjugarmos": "abjugar",
    "abjugará": "abjugar",
    "abjugarás": "abjugar",
    "abjugarão": "abjugar",
    "abjugaríamos": "abjugar",
    "abjugaríeis": "abjugar",
    "abjugas": "abjugar",
    "abjugasse": "abjugar",
    "abjugassem": "abjugar",
    "abjugasses": "abjugar",
    "abjugaste": "abjugar",
    "abjugastes": "abjugar",
    "abjugava": "abjugar",
    "abjugavam": "abjugar",
    "abjugavas": "abjugar",
    "abjugo": "abjugar",
    "abjugou": "abjugar",
    "abjugue": "abjugar",
    "abjuguei": "abjugar",
    "abjugueis": "abjugar",
    "abjuguem": "abjugar",
    "abjuguemo": "abjugar",
    "abjuguemos": "abjugar",
    "abjugues": "abjugar",
    "abjugá": "abjugar",
    "abjugámo": "abjugar",
    "abjugámos": "abjugar",
    "abjugáramo": "abjugar",
    "abjugáramos": "abjugar",
    "abjugárei": "abjugar",
    "abjugáreis": "abjugar",
    "abjugásseis": "abjugar",
    "abjugássemos": "abjugar",
    "abjugávamo": "abjugar",
    "abjugávamos": "abjugar",
    "abjugávei": "abjugar",
    "abjugáveis": "abjugar",
    "abjunge": "abjungir",
    "abjungem": "abjungir",
    "abjunges": "abjungir",
    "abjungi": "abjungir",
    "abjungia": "abjungir",
    "abjungiam": "abjungir",
    "abjungias": "abjungir",
    "abjungida": "abjungir",
    "abjungidas": "abjungir",
    "abjungido": "abjungir",
    "abjungidos": "abjungir",
    "abjungimo": "abjungir",
    "abjungimos": "abjungir",
    "abjungindo": "abjungir",
    "abjungira": "abjungir",
    "abjungiram": "abjungir",
    "abjungiras": "abjungir",
    "abjungirde": "abjungir",
    "abjungirdes": "abjungir",
    "abjungire": "abjungir",
    "abjungirei": "abjungir",
    "abjungireis": "abjungir",
    "abjungirem": "abjungir",
    "abjungiremos": "abjungir",
    "abjungires": "abjungir",
    "abjungiria": "abjungir",
    "abjungiriam": "abjungir",
    "abjungirias": "abjungir",
    "abjungirmo": "abjungir",
    "abjungirmos": "abjungir",
    "abjungirá": "abjungir",
    "abjungirás": "abjungir",
    "abjungirão": "abjungir",
    "abjungiríamos": "abjungir",
    "abjungiríeis": "abjungir",
    "abjungis": "abjungir",
    "abjungisse": "abjungir",
    "abjungissem": "abjungir",
    "abjungisses": "abjungir",
    "abjungiste": "abjungir",
    "abjungistes": "abjungir",
    "abjungiu": "abjungir",
    "abjungíamo": "abjungir",
    "abjungíamos": "abjungir",
    "abjungíei": "abjungir",
    "abjungíeis": "abjungir",
    "abjungíramo": "abjungir",
    "abjungíramos": "abjungir",
    "abjungírei": "abjungir",
    "abjungíreis": "abjungir",
    "abjungísseis": "abjungir",
    "abjungíssemos": "abjungir",
    "abjunja": "abjungir",
    "abjunjais": "abjungir",
    "abjunjam": "abjungir",
    "abjunjamo": "abjungir",
    "abjunjamos": "abjungir",
    "abjunjas": "abjungir",
    "abjunjo": "abjungir",
    "abjunções": "abjunção",
    "abjura": "abjurar",
    "abjurada": "abjurar",
    "abjuradas": "abjurar",
    "abjurado": "abjurar",
    "abjuradora": "abjurador",
    "abjuradoras": "abjurador",
    "abjuradores": "abjurador",
    "abjurados": "abjurar",
    "abjurai": "abjurar",
    "abjurais": "abjurar",
    "abjuram": "abjurar",
    "abjuramentos": "abjuramento",
    "abjuramo": "abjurar",
    "abjuramos": "abjurar",
    "abjurando": "abjurar",
    "abjurantes": "abjurante",
    "abjurara": "abjurar",
    "abjuraram": "abjurar",
    "abjuraras": "abjurar",
    "abjurarde": "abjurar",
    "abjurardes": "abjurar",
    "abjurare": "abjurar",
    "abjurarei": "abjurar",
    "abjurareis": "abjurar",
    "abjurarem": "abjurar",
    "abjuraremos": "abjurar",
    "abjurares": "abjurar",
    "abjuraria": "abjurar",
    "abjurariam": "abjurar",
    "abjurarias": "abjurar",
    "abjurarmo": "abjurar",
    "abjurarmos": "abjurar",
    "abjurará": "abjurar",
    "abjurarás": "abjurar",
    "abjurarão": "abjurar",
    "abjuraríamos": "abjurar",
    "abjuraríeis": "abjurar",
    "abjuras": "abjurar",
    "abjurasse": "abjurar",
    "abjurassem": "abjurar",
    "abjurasses": "abjurar",
    "abjuraste": "abjurar",
    "abjurastes": "abjurar",
    "abjuratória": "abjuratório",
    "abjuratórias": "abjuratório",
    "abjuratórios": "abjuratório",
    "abjurava": "abjurar",
    "abjuravam": "abjurar",
    "abjuravas": "abjurar",
    "abjurações": "abjuração",
    "abjure": "abjurar",
    "abjurei": "abjurar",
    "abjureis": "abjurar",
    "abjurem": "abjurar",
    "abjuremo": "abjurar",
    "abjuremos": "abjurar",
    "abjures": "abjurar",
    "abjurga": "abjurgar",
    "abjurgada": "abjurgar",
    "abjurgadas": "abjurgar",
    "abjurgado": "abjurgar",
    "abjurgados": "abjurgar",
    "abjurgai": "abjurgar",
    "abjurgais": "abjurgar",
    "abjurgam": "abjurgar",
    "abjurgamo": "abjurgar",
    "abjurgamos": "abjurgar",
    "abjurgando": "abjurgar",
    "abjurgara": "abjurgar",
    "abjurgaram": "abjurgar",
    "abjurgaras": "abjurgar",
    "abjurgarde": "abjurgar",
    "abjurgardes": "abjurgar",
    "abjurgare": "abjurgar",
    "abjurgarei": "abjurgar",
    "abjurgareis": "abjurgar",
    "abjurgarem": "abjurgar",
    "abjurgaremos": "abjurgar",
    "abjurgares": "abjurgar",
    "abjurgaria": "abjurgar",
    "abjurgariam": "abjurgar",
    "abjurgarias": "abjurgar",
    "abjurgarmo": "abjurgar",
    "abjurgarmos": "abjurgar",
    "abjurgará": "abjurgar",
    "abjurgarás": "abjurgar",
    "abjurgarão": "abjurgar",
    "abjurgaríamos": "abjurgar",
    "abjurgaríeis": "abjurgar",
    "abjurgas": "abjurgar",
    "abjurgasse": "abjurgar",
    "abjurgassem": "abjurgar",
    "abjurgasses": "abjurgar",
    "abjurgaste": "abjurgar",
    "abjurgastes": "abjurgar",
    "abjurgatória": "abjurgatório",
    "abjurgatórias": "abjurgatório",
    "abjurgatórios": "abjurgatório",
    "abjurgava": "abjurgar",
    "abjurgavam": "abjurgar",
    "abjurgavas": "abjurgar",
    "abjurgo": "abjurgar",
    "abjurgou": "abjurgar",
    "abjurgue": "abjurgar",
    "abjurguei": "abjurgar",
    "abjurgueis": "abjurgar",
    "abjurguem": "abjurgar",
    "abjurguemo": "abjurgar",
    "abjurguemos": "abjurgar",
    "abjurgues": "abjurgar",
    "abjurgá": "abjurgar",
    "abjurgámo": "abjurgar",
    "abjurgámos": "abjurgar",
    "abjurgáramo": "abjurgar",
    "abjurgáramos": "abjurgar",
    "abjurgárei": "abjurgar",
    "abjurgáreis": "abjurgar",
    "abjurgásseis": "abjurgar",
    "abjurgássemos": "abjurgar",
    "abjurgávamo": "abjurgar",
    "abjurgávamos": "abjurgar",
    "abjurgávei": "abjurgar",
    "abjurgáveis": "abjurgar",
    "abjuro": "abjurar",
    "abjurou": "abjurar",
    "abjurá": "abjurar",
    "abjurámo": "abjurar",
    "abjurámos": "abjurar",
    "abjuráramo": "abjurar",
    "abjuráramos": "abjurar",
    "abjurárei": "abjurar",
    "abjuráreis": "abjurar",
    "abjurásseis": "abjurar",
    "abjurássemos": "abjurar",
    "abjurávamo": "abjurar",
    "abjurávamos": "abjurar",
    "abjurávei": "abjurar",
    "abjuráveis": "abjurável",
    "ablacas": "ablaca",
    "ablacta": "ablactar",
    "ablactada": "ablactar",
    "ablactadas": "ablactar",
    "ablactado": "ablactar",
    "ablactados": "ablactar",
    "ablactai": "ablactar",
    "ablactais": "ablactar",
    "ablactam": "ablactar",
    "ablactamo": "ablactar",
    "ablactamos": "ablactar",
    "ablactando": "ablactar",
    "ablactara": "ablactar",
    "ablactaram": "ablactar",
    "ablactaras": "ablactar",
    "ablactarde": "ablactar",
    "ablactardes": "ablactar",
    "ablactare": "ablactar",
    "ablactarei": "ablactar",
    "ablactareis": "ablactar",
    "ablactarem": "ablactar",
    "ablactaremos": "ablactar",
    "ablactares": "ablactar",
    "ablactaria": "ablactar",
    "ablactariam": "ablactar",
    "ablactarias": "ablactar",
    "ablactarmo": "ablactar",
    "ablactarmos": "ablactar",
    "ablactará": "ablactar",
    "ablactarás": "ablactar",
    "ablactarão": "ablactar",
    "ablactaríamos": "ablactar",
    "ablactaríeis": "ablactar",
    "ablactas": "ablactar",
    "ablactasse": "ablactar",
    "ablactassem": "ablactar",
    "ablactasses": "ablactar",
    "ablactaste": "ablactar",
    "ablactastes": "ablactar",
    "ablactava": "ablactar",
    "ablactavam": "ablactar",
    "ablactavas": "ablactar",
    "ablactações": "ablactação",
    "ablacte": "ablactar",
    "ablactei": "ablactar",
    "ablacteis": "ablactar",
    "ablactem": "ablactar",
    "ablactemo": "ablactar",
    "ablactemos": "ablactar",
    "ablactes": "ablactar",
    "ablacto": "ablactar",
    "ablactou": "ablactar",
    "ablactá": "ablactar",
    "ablactámo": "ablactar",
    "ablactámos": "ablactar",
    "ablactáramo": "ablactar",
    "ablactáramos": "ablactar",
    "ablactárei": "ablactar",
    "ablactáreis": "ablactar",
    "ablactásseis": "ablactar",
    "ablactássemos": "ablactar",
    "ablactávamo": "ablactar",
    "ablactávamos": "ablactar",
    "ablactávei": "ablactar",
    "ablactáveis": "ablactar",
    "ablaqueada": "ablaquear",
    "ablaqueadas": "ablaquear",
    "ablaqueado": "ablaquear",
    "ablaqueados": "ablaquear",
    "ablaqueai": "ablaquear",
    "ablaqueais": "ablaquear",
    "ablaqueamo": "ablaquear",
    "ablaqueamos": "ablaquear",
    "ablaqueando": "ablaquear",
    "ablaqueara": "ablaquear",
    "ablaquearam": "ablaquear",
    "ablaquearas": "ablaquear",
    "ablaquearde": "ablaquear",
    "ablaqueardes": "ablaquear",
    "ablaqueare": "ablaquear",
    "ablaquearei": "ablaquear",
    "ablaqueareis": "ablaquear",
    "ablaquearem": "ablaquear",
    "ablaquearemos": "ablaquear",
    "ablaqueares": "ablaquear",
    "ablaquearia": "ablaquear",
    "ablaqueariam": "ablaquear",
    "ablaquearias": "ablaquear",
    "ablaquearmo": "ablaquear",
    "ablaquearmos": "ablaquear",
    "ablaqueará": "ablaquear",
    "ablaquearás": "ablaquear",
    "ablaquearão": "ablaquear",
    "ablaquearíamos": "ablaquear",
    "ablaquearíeis": "ablaquear",
    "ablaqueasse": "ablaquear",
    "ablaqueassem": "ablaquear",
    "ablaqueasses": "ablaquear",
    "ablaqueaste": "ablaquear",
    "ablaqueastes": "ablaquear",
    "ablaqueava": "ablaquear",
    "ablaqueavam": "ablaquear",
    "ablaqueavas": "ablaquear",
    "ablaqueações": "ablaqueação",
    "ablaqueei": "ablaquear",
    "ablaqueeis": "ablaquear",
    "ablaqueemo": "ablaquear",
    "ablaqueemos": "ablaquear",
    "ablaqueia": "ablaquear",
    "ablaqueiam": "ablaquear",
    "ablaqueias": "ablaquear",
    "ablaqueie": "ablaquear",
    "ablaqueiem": "ablaquear",
    "ablaqueies": "ablaquear",
    "ablaqueio": "ablaquear",
    "ablaqueou": "ablaquear",
    "ablaqueá": "ablaquear",
    "ablaqueámo": "ablaquear",
    "ablaqueámos": "ablaquear",
    "ablaqueáramo": "ablaquear",
    "ablaqueáramos": "ablaquear",
    "ablaqueárei": "ablaquear",
    "ablaqueáreis": "ablaquear",
    "ablaqueásseis": "ablaquear",
    "ablaqueássemos": "ablaquear",
    "ablaqueávamo": "ablaquear",
    "ablaqueávamos": "ablaquear",
    "ablaqueávei": "ablaquear",
    "ablaqueáveis": "ablaquear",
    "ablativa": "ablativo",
    "ablativas": "ablativo",
    "ablativos": "ablativo",
    "ablatora": "ablator",
    "ablatoras": "ablator",
    "ablatores": "ablator",
    "ablações": "ablação",
    "ablefarias": "ablefaria",
    "ablega": "ablegar",
    "ablegada": "ablegar",
    "ablegadas": "ablegar",
    "ablegado": "ablegar",
    "ablegados": "ablegar",
    "ablegai": "ablegar",
    "ablegais": "ablegar",
    "ablegam": "ablegar",
    "ablegamo": "ablegar",
    "ablegamos": "ablegar",
    "ablegando": "ablegar",
    "ablegara": "ablegar",
    "ablegaram": "ablegar",
    "ablegaras": "ablegar",
    "ablegarde": "ablegar",
    "ablegardes": "ablegar",
    "ablegare": "ablegar",
    "ablegarei": "ablegar",
    "ablegareis": "ablegar",
    "ablegarem": "ablegar",
    "ablegaremos": "ablegar",
    "ablegares": "ablegar",
    "ablegaria": "ablegar",
    "ablegariam": "ablegar",
    "ablegarias": "ablegar",
    "ablegarmo": "ablegar",
    "ablegarmos": "ablegar",
    "ablegará": "ablegar",
    "ablegarás": "ablegar",
    "ablegarão": "ablegar",
    "ablegaríamos": "ablegar",
    "ablegaríeis": "ablegar",
    "ablegas": "ablegar",
    "ablegasse": "ablegar",
    "ablegassem": "ablegar",
    "ablegasses": "ablegar",
    "ablegaste": "ablegar",
    "ablegastes": "ablegar",
    "ablegava": "ablegar",
    "ablegavam": "ablegar",
    "ablegavas": "ablegar",
    "ablegações": "ablegação",
    "ablego": "ablegar",
    "ablegou": "ablegar",
    "ablegue": "ablegar",
    "ableguei": "ablegar",
    "ablegueis": "ablegar",
    "ableguem": "ablegar",
    "ableguemo": "ablegar",
    "ableguemos": "ablegar",
    "ablegues": "ablegar",
    "ablegá": "ablegar",
    "ablegámo": "ablegar",
    "ablegámos": "ablegar",
    "ablegáramo": "ablegar",
    "ablegáramos": "ablegar",
    "ablegárei": "ablegar",
    "ablegáreis": "ablegar",
    "ablegásseis": "ablegar",
    "ablegássemos": "ablegar",
    "ablegávamo": "ablegar",
    "ablegávamos": "ablegar",
    "ablegávei": "ablegar",
    "ablegáveis": "ablegar",
    "ablepsias": "ablepsia",
    "ablua": "abluir",
    "abluais": "abluir",
    "abluam": "abluir",
    "abluamo": "abluir",
    "abluamos": "abluir",
    "abluas": "abluir",
    "abluem": "abluir",
    "abluentes": "abluente",
    "ablui": "abluir",
    "abluindo": "abluir",
    "abluirde": "abluir",
    "abluirdes": "abluir",
    "abluirei": "abluir",
    "abluireis": "abluir",
    "abluiremos": "abluir",
    "abluiria": "abluir",
    "abluiriam": "abluir",
    "abluirias": "abluir",
    "abluirmo": "abluir",
    "abluirmos": "abluir",
    "abluirá": "abluir",
    "abluirás": "abluir",
    "abluirão": "abluir",
    "abluiríamos": "abluir",
    "abluiríeis": "abluir",
    "abluis": "abluir",
    "abluiu": "abluir",
    "abluo": "abluir",
    "ablutora": "ablutor",
    "ablutoras": "ablutor",
    "ablutores": "ablutor",
    "abluções": "ablução",
    "abluí": "abluir",
    "abluía": "abluir",
    "abluíam": "abluir",
    "abluíamo": "abluir",
    "abluíamos": "abluir",
    "abluías": "abluir",
    "abluída": "abluir",
    "abluídas": "abluir",
    "abluído": "abluir",
    "abluídos": "abluir",
    "abluíei": "abluir",
    "abluíeis": "abluir",
    "abluímo": "abluir",
    "abluímos": "abluir",
    "abluíra": "abluir",
    "abluíram": "abluir",
    "abluíramo": "abluir",
    "abluíramos": "abluir",
    "abluíras": "abluir",
    "abluíre": "abluir",
    "abluírei": "abluir",
    "abluíreis": "abluir",
    "abluírem": "abluir",
    "abluíres": "abluir",
    "abluís": "abluir",
    "abluísse": "abluir",
    "abluísseis": "abluir",
    "abluíssem": "abluir",
    "abluíssemos": "abluir",
    "abluísses": "abluir",
    "abluíste": "abluir",
    "abluístes": "abluir",
    "abléfara": "abléfaro",
    "abléfaras": "abléfaro",
    "abléfaros": "abléfaro",
    "abnega": "abnegar",
    "abnegada": "abnegar",
    "abnegadas": "abnegar",
    "abnegado": "abnegar",
    "abnegadora": "abnegador",
    "abnegadoras": "abnegador",
    "abnegadores": "abnegador",
    "abnegados": "abnegar",
    "abnegadíssima": "abnegado",
    "abnegadíssimas": "abnegado",
    "abnegadíssimo": "abnegado",
    "abnegadíssimos": "abnegado",
    "abnegai": "abnegar",
    "abnegais": "abnegar",
    "abnegam": "abnegar",
    "abnegamo": "abnegar",
    "abnegamos": "abnegar",
    "abnegando": "abnegar",
    "abnegara": "abnegar",
    "abnegaram": "abnegar",
    "abnegaras": "abnegar",
    "abnegarde": "abnegar",
    "abnegardes": "abnegar",
    "abnegare": "abnegar",
    "abnegarei": "abnegar",
    "abnegareis": "abnegar",
    "abnegarem": "abnegar",
    "abnegaremos": "abnegar",
    "abnegares": "abnegar",
    "abnegaria": "abnegar",
    "abnegariam": "abnegar",
    "abnegarias": "abnegar",
    "abnegarmo": "abnegar",
    "abnegarmos": "abnegar",
    "abnegará": "abnegar",
    "abnegarás": "abnegar",
    "abnegarão": "abnegar",
    "abnegaríamos": "abnegar",
    "abnegaríeis": "abnegar",
    "abnegas": "abnegar",
    "abnegasse": "abnegar",
    "abnegassem": "abnegar",
    "abnegasses": "abnegar",
    "abnegaste": "abnegar",
    "abnegastes": "abnegar",
    "abnegativa": "abnegativo",
    "abnegativas": "abnegativo",
    "abnegativos": "abnegativo",
    "abnegava": "abnegar",
    "abnegavam": "abnegar",
    "abnegavas": "abnegar",
    "abnegações": "abnegação",
    "abnego": "abnegar",
    "abnegou": "abnegar",
    "abnegue": "abnegar",
    "abneguei": "abnegar",
    "abnegueis": "abnegar",
    "abneguem": "abnegar",
    "abneguemo": "abnegar",
    "abneguemos": "abnegar",
    "abnegues": "abnegar",
    "abnegá": "abnegar",
    "abnegámo": "abnegar",
    "abnegámos": "abnegar",
    "abnegáramo": "abnegar",
    "abnegáramos": "abnegar",
    "abnegárei": "abnegar",
    "abnegáreis": "abnegar",
    "abnegásseis": "abnegar",
    "abnegássemos": "abnegar",
    "abnegávamo": "abnegar",
    "abnegávamos": "abnegar",
    "abnegávei": "abnegar",
    "abnegáveis": "abnegar",
    "abnoda": "abnodar",
    "abnodada": "abnodar",
    "abnodadas": "abnodar",
    "abnodado": "abnodar",
    "abnodados": "abnodar",
    "abnodai": "abnodar",
    "abnodais": "abnodar",
    "abnodam": "abnodar",
    "abnodamo": "abnodar",
    "abnodamos": "abnodar",
    "abnodando": "abnodar",
    "abnodara": "abnodar",
    "abnodaram": "abnodar",
    "abnodaras": "abnodar",
    "abnodarde": "abnodar",
    "abnodardes": "abnodar",
    "abnodare": "abnodar",
    "abnodarei": "abnodar",
    "abnodareis": "abnodar",
    "abnodarem": "abnodar",
    "abnodaremos": "abnodar",
    "abnodares": "abnodar",
    "abnodaria": "abnodar",
    "abnodariam": "abnodar",
    "abnodarias": "abnodar",
    "abnodarmo": "abnodar",
    "abnodarmos": "abnodar",
    "abnodará": "abnodar",
    "abnodarás": "abnodar",
    "abnodarão": "abnodar",
    "abnodaríamos": "abnodar",
    "abnodaríeis": "abnodar",
    "abnodas": "abnodar",
    "abnodasse": "abnodar",
    "abnodassem": "abnodar",
    "abnodasses": "abnodar",
    "abnodaste": "abnodar",
    "abnodastes": "abnodar",
    "abnodava": "abnodar",
    "abnodavam": "abnodar",
    "abnodavas": "abnodar",
    "abnodações": "abnodação",
    "abnode": "abnodar",
    "abnodei": "abnodar",
    "abnodeis": "abnodar",
    "abnodem": "abnodar",
    "abnodemo": "abnodar",
    "abnodemos": "abnodar",
    "abnodes": "abnodar",
    "abnodo": "abnodar",
    "abnodou": "abnodar",
    "abnodá": "abnodar",
    "abnodámo": "abnodar",
    "abnodámos": "abnodar",
    "abnodáramo": "abnodar",
    "abnodáramos": "abnodar",
    "abnodárei": "abnodar",
    "abnodáreis": "abnodar",
    "abnodásseis": "abnodar",
    "abnodássemos": "abnodar",
    "abnodávamo": "abnodar",
    "abnodávamos": "abnodar",
    "abnodávei": "abnodar",
    "abnodáveis": "abnodar",
    "abnuências": "abnuência",
    "abnóxia": "abnóxio",
    "abnóxias": "abnóxio",
    "abnóxios": "abnóxio",
    "abo": "abar",
    "aboa": "aboar",
    "aboada": "aboar",
    "aboadas": "aboar",
    "aboado": "aboar",
    "aboados": "aboar",
    "aboai": "aboar",
    "aboais": "aboar",
    "aboam": "aboar",
    "aboamo": "aboar",
    "aboamos": "aboar",
    "aboando": "aboar",
    "aboara": "aboar",
    "aboaram": "aboar",
    "aboaras": "aboar",
    "aboardes": "aboar",
    "aboarei": "aboar",
    "aboareis": "aboar",
    "aboarem": "aboar",
    "aboaremos": "aboar",
    "aboares": "aboar",
    "aboaria": "aboar",
    "aboariam": "aboar",
    "aboarias": "aboar",
    "aboarmo": "aboar",
    "aboarmos": "aboar",
    "aboará": "aboar",
    "aboarás": "aboar",
    "aboarão": "aboar",
    "aboaríamos": "aboar",
    "aboaríeis": "aboar",
    "aboas": "aboar",
    "aboasse": "aboar",
    "aboassem": "aboar",
    "aboasses": "aboar",
    "aboaste": "aboar",
    "aboastes": "aboar",
    "aboava": "aboar",
    "aboavam": "aboar",
    "aboavas": "aboar",
    "aboba": "abobar",
    "abobabada": "abobabado",
    "abobabadas": "abobabado",
    "abobabados": "abobabado",
    "abobada": "abobar",
    "abobadada": "abobadar",
    "abobadadas": "abobadar",
    "abobadado": "abobadar",
    "abobadados": "abobadar",
    "abobadai": "abobadar",
    "abobadais": "abobadar",
    "abobadam": "abobadar",
    "abobadamo": "abobadar",
    "abobadamos": "abobadar",
    "abobadando": "abobadar",
    "abobadara": "abobadar",
    "abobadaram": "abobadar",
    "abobadaras": "abobadar",
    "abobadarde": "abobadar",
    "abobadardes": "abobadar",
    "abobadare": "abobadar",
    "abobadarei": "abobadar",
    "abobadareis": "abobadar",
    "abobadarem": "abobadar",
    "abobadaremos": "abobadar",
    "abobadares": "abobadar",
    "abobadaria": "abobadar",
    "abobadariam": "abobadar",
    "abobadarias": "abobadar",
    "abobadarmo": "abobadar",
    "abobadarmos": "abobadar",
    "abobadará": "abobadar",
    "abobadarás": "abobadar",
    "abobadarão": "abobadar",
    "abobadaríamos": "abobadar",
    "abobadaríeis": "abobadar",
    "abobadas": "abobar",
    "abobadasse": "abobadar",
    "abobadassem": "abobadar",
    "abobadasses": "abobadar",
    "abobadaste": "abobadar",
    "abobadastes": "abobadar",
    "abobadava": "abobadar",
    "abobadavam": "abobadar",
    "abobadavas": "abobadar",
    "abobadazinha": "abobado",
    "abobadazinhas": "abobado",
    "abobadazita": "abobado",
    "abobadazitas": "abobado",
    "abobade": "abobadar",
    "abobadei": "abobadar",
    "abobadeis": "abobadar",
    "abobadem": "abobadar",
    "abobademo": "abobadar",
    "abobademos": "abobadar",
    "abobades": "abobadar",
    "abobadilhas": "abobadilha",
    "abobadilheiros": "abobadilheiro",
    "abobadinha": "abobado",
    "abobadinhas": "abobado",
    "abobadinho": "abobado",
    "abobadinhos": "abobado",
    "abobadita": "abobado",
    "abobaditas": "abobado",
    "abobadito": "abobado",
    "abobaditos": "abobado",
    "abobado": "abobar",
    "abobados": "abobar",
    "abobadou": "abobadar",
    "abobadozinho": "abobado",
    "abobadozinhos": "abobado",
    "abobadozito": "abobado",
    "abobadozitos": "abobado",
    "abobadá": "abobadar",
    "abobadámo": "abobadar",
    "abobadámos": "abobadar",
    "abobadáramo": "abobadar",
    "abobadáramos": "abobadar",
    "abobadárei": "abobadar",
    "abobadáreis": "abobadar",
    "abobadásseis": "abobadar",
    "abobadássemos": "abobadar",
    "abobadávamo": "abobadar",
    "abobadávamos": "abobadar",
    "abobadávei": "abobadar",
    "abobadáveis": "abobadar",
    "abobadíssima": "abobado",
    "abobadíssimas": "abobado",
    "abobadíssimo": "abobado",
    "abobadíssimos": "abobado",
    "abobai": "abobar",
    "abobais": "abobar",
    "abobam": "abobar",
    "abobamo": "abobar",
    "abobamos": "abobar",
    "abobando": "abobar",
    "abobara": "abobar",
    "abobaram": "abobar",
    "abobaras": "abobar",
    "abobarde": "abobar",
    "abobardes": "abobar",
    "abobare": "abobar",
    "abobarei": "abobar",
    "abobareis": "abobar",
    "abobarem": "abobar",
    "abobaremos": "abobar",
    "abobares": "abobar",
    "abobaria": "abobar",
    "abobariam": "abobar",
    "abobarias": "abobar",
    "abobarmo": "abobar",
    "abobarmos": "abobar",
    "abobará": "abobar",
    "abobarás": "abobar",
    "abobarão": "abobar",
    "abobaríamos": "abobar",
    "abobaríeis": "abobar",
    "abobas": "abobar",
    "abobasse": "abobar",
    "abobassem": "abobar",
    "abobasses": "abobar",
    "abobaste": "abobar",
    "abobastes": "abobar",
    "abobava": "abobar",
    "abobavam": "abobar",
    "abobavas": "abobar",
    "abobe": "abobar",
    "abobei": "abobar",
    "abobeis": "abobar",
    "abobem": "abobar",
    "abobemo": "abobar",
    "abobemos": "abobar",
    "abobes": "abobar",
    "abobo": "abobar",
    "abobora": "aboborar",
    "aboborada": "aboborar",
    "aboboradas": "aboborar",
    "aboborado": "aboborar",
    "aboborados": "aboborar",
    "aboborai": "aboborar",
    "aboborais": "aboborar",
    "aboboram": "aboborar",
    "aboboramo": "aboborar",
    "aboboramos": "aboborar",
    "aboborando": "aboborar",
    "aboborara": "aboborar",
    "aboboraram": "aboborar",
    "aboboraras": "aboborar",
    "aboborarde": "aboborar",
    "aboborardes": "aboborar",
    "aboborare": "aboborar",
    "aboborarei": "aboborar",
    "aboborareis": "aboborar",
    "aboborarem": "aboborar",
    "aboboraremos": "aboborar",
    "aboborares": "aboborar",
    "aboboraria": "aboborar",
    "aboborariam": "aboborar",
    "aboborarias": "aboborar",
    "aboborarmo": "aboborar",
    "aboborarmos": "aboborar",
    "aboborará": "aboborar",
    "aboborarás": "aboborar",
    "aboborarão": "aboborar",
    "aboboraríamos": "aboborar",
    "aboboraríeis": "aboborar",
    "aboboras": "aboborar",
    "aboborasse": "aboborar",
    "aboborassem": "aboborar",
    "aboborasses": "aboborar",
    "aboboraste": "aboborar",
    "aboborastes": "aboborar",
    "aboborava": "aboborar",
    "aboboravam": "aboborar",
    "aboboravas": "aboborar",
    "abobore": "aboborar",
    "aboborei": "aboborar",
    "aboboreiras": "aboboreira",
    "aboboreis": "aboborar",
    "aboborem": "aboborar",
    "aboboremo": "aboborar",
    "aboboremos": "aboborar",
    "abobores": "aboborar",
    "aboborinha": "abóbora",
    "aboborinhas": "abóbora",
    "aboborita": "abóbora",
    "aboboritas": "abóbora",
    "aboboro": "aboborar",
    "aboborou": "aboborar",
    "aboborá": "aboborar",
    "aboborámo": "aboborar",
    "aboborámos": "aboborar",
    "aboboráramo": "aboborar",
    "aboboráramos": "aboborar",
    "aboborárei": "aboborar",
    "aboboráreis": "aboborar",
    "aboborásseis": "aboborar",
    "aboborássemos": "aboborar",
    "aboborávamo": "aboborar",
    "aboborávamos": "aboborar",
    "aboborávei": "aboborar",
    "aboboráveis": "aboborar",
    "abobou": "abobar",
    "abobras": "abobra",
    "abobrinhas": "abobrinha",
    "abobá": "abobar",
    "abobámo": "abobar",
    "abobámos": "abobar",
    "abobáramo": "abobar",
    "abobáramos": "abobar",
    "abobárei": "abobar",
    "abobáreis": "abobar",
    "abobásseis": "abobar",
    "abobássemos": "abobar",
    "abobávamo": "abobar",
    "abobávamos": "abobar",
    "abobávei": "abobar",
    "abobáveis": "abobar",
    "abobós": "abobó",
    "aboca": "abocar",
    "abocada": "abocar",
    "abocadas": "abocar",
    "abocado": "abocar",
    "abocados": "abocar",
    "abocaduras": "abocadura",
    "abocai": "abocar",
    "abocais": "abocar",
    "abocam": "abocar",
    "abocamentos": "abocamento",
    "abocamo": "abocar",
    "abocamos": "abocar",
    "abocando": "abocar",
    "abocanha": "abocanhar",
    "abocanhada": "abocanhar",
    "abocanhadas": "abocanhar",
    "abocanhado": "abocanhar",
    "abocanhados": "abocanhar",
    "abocanhai": "abocanhar",
    "abocanhais": "abocanhar",
    "abocanham": "abocanhar",
    "abocanhamo": "abocanhar",
    "abocanhamos": "abocanhar",
    "abocanhando": "abocanhar",
    "abocanhara": "abocanhar",
    "abocanharam": "abocanhar",
    "abocanharas": "abocanhar",
    "abocanharde": "abocanhar",
    "abocanhardes": "abocanhar",
    "abocanhare": "abocanhar",
    "abocanharei": "abocanhar",
    "abocanhareis": "abocanhar",
    "abocanharem": "abocanhar",
    "abocanharemos": "abocanhar",
    "abocanhares": "abocanhar",
    "abocanharia": "abocanhar",
    "abocanhariam": "abocanhar",
    "abocanharias": "abocanhar",
    "abocanharmo": "abocanhar",
    "abocanharmos": "abocanhar",
    "abocanhará": "abocanhar",
    "abocanharás": "abocanhar",
    "abocanharão": "abocanhar",
    "abocanharíamos": "abocanhar",
    "abocanharíeis": "abocanhar",
    "abocanhas": "abocanhar",
    "abocanhasse": "abocanhar",
    "abocanhassem": "abocanhar",
    "abocanhasses": "abocanhar",
    "abocanhaste": "abocanhar",
    "abocanhastes": "abocanhar",
    "abocanhava": "abocanhar",
    "abocanhavam": "abocanhar",
    "abocanhavas": "abocanhar",
    "abocanhe": "abocanhar",
    "abocanhei": "abocanhar",
    "abocanheis": "abocanhar",
    "abocanhem": "abocanhar",
    "abocanhemo": "abocanhar",
    "abocanhemos": "abocanhar",
    "abocanhes": "abocanhar",
    "abocanho": "abocanhar",
    "abocanhou": "abocanhar",
    "abocanhá": "abocanhar",
    "abocanhámo": "abocanhar",
    "abocanhámos": "abocanhar",
    "abocanháramo": "abocanhar",
    "abocanháramos": "abocanhar",
    "abocanhárei": "abocanhar",
    "abocanháreis": "abocanhar",
    "abocanhásseis": "abocanhar",
    "abocanhássemos": "abocanhar",
    "abocanhávamo": "abocanhar",
    "abocanhávamos": "abocanhar",
    "abocanhávei": "abocanhar",
    "abocanháveis": "abocanhar",
    "abocara": "abocar",
    "abocaram": "abocar",
    "abocaras": "abocar",
    "abocarde": "abocar",
    "abocardes": "abocar",
    "abocare": "abocar",
    "abocarei": "abocar",
    "abocareis": "abocar",
    "abocarem": "abocar",
    "abocaremos": "abocar",
    "abocares": "abocar",
    "abocaria": "abocar",
    "abocariam": "abocar",
    "abocarias": "abocar",
    "abocarmo": "abocar",
    "abocarmos": "abocar",
    "abocará": "abocar",
    "abocarás": "abocar",
    "abocarão": "abocar",
    "abocaríamos": "abocar",
    "abocaríeis": "abocar",
    "abocas": "abocar",
    "abocasse": "abocar",
    "abocassem": "abocar",
    "abocasses": "abocar",
    "abocaste": "abocar",
    "abocastes": "abocar",
    "abocava": "abocar",
    "abocavam": "abocar",
    "abocavas": "abocar",
    "aboce": "aboçar",
    "abocei": "aboçar",
    "aboceis": "aboçar",
    "abocem": "aboçar",
    "abocemo": "aboçar",
    "abocemos": "aboçar",
    "aboces": "aboçar",
    "aboceta": "abocetar",
    "abocetada": "abocetar",
    "abocetadas": "abocetar",
    "abocetado": "abocetar",
    "abocetados": "abocetar",
    "abocetai": "abocetar",
    "abocetais": "abocetar",
    "abocetam": "abocetar",
    "abocetamo": "abocetar",
    "abocetamos": "abocetar",
    "abocetando": "abocetar",
    "abocetara": "abocetar",
    "abocetaram": "abocetar",
    "abocetaras": "abocetar",
    "abocetarde": "abocetar",
    "abocetardes": "abocetar",
    "abocetare": "abocetar",
    "abocetarei": "abocetar",
    "abocetareis": "abocetar",
    "abocetarem": "abocetar",
    "abocetaremos": "abocetar",
    "abocetares": "abocetar",
    "abocetaria": "abocetar",
    "abocetariam": "abocetar",
    "abocetarias": "abocetar",
    "abocetarmo": "abocetar",
    "abocetarmos": "abocetar",
    "abocetará": "abocetar",
    "abocetarás": "abocetar",
    "abocetarão": "abocetar",
    "abocetaríamos": "abocetar",
    "abocetaríeis": "abocetar",
    "abocetas": "abocetar",
    "abocetasse": "abocetar",
    "abocetassem": "abocetar",
    "abocetasses": "abocetar",
    "abocetaste": "abocetar",
    "abocetastes": "abocetar",
    "abocetava": "abocetar",
    "abocetavam": "abocetar",
    "abocetavas": "abocetar",
    "abocete": "abocetar",
    "abocetei": "abocetar",
    "aboceteis": "abocetar",
    "abocetem": "abocetar",
    "abocetemo": "abocetar",
    "abocetemos": "abocetar",
    "abocetes": "abocetar",
    "aboceto": "abocetar",
    "abocetou": "abocetar",
    "abocetá": "abocetar",
    "abocetámo": "abocetar",
    "abocetámos": "abocetar",
    "abocetáramo": "abocetar",
    "abocetáramos": "abocetar",
    "abocetárei": "abocetar",
    "abocetáreis": "abocetar",
    "abocetásseis": "abocetar",
    "abocetássemos": "abocetar",
    "abocetávamo": "abocetar",
    "abocetávamos": "abocetar",
    "abocetávei": "abocetar",
    "abocetáveis": "abocetar",
    "abochorna": "abochornar",
    "abochornada": "abochornar",
    "abochornadas": "abochornar",
    "abochornado": "abochornar",
    "abochornados": "abochornar",
    "abochornai": "abochornar",
    "abochornais": "abochornar",
    "abochornam": "abochornar",
    "abochornamo": "abochornar",
    "abochornamos": "abochornar",
    "abochornando": "abochornar",
    "abochornara": "abochornar",
    "abochornaram": "abochornar",
    "abochornaras": "abochornar",
    "abochornarde": "abochornar",
    "abochornardes": "abochornar",
    "abochornare": "abochornar",
    "abochornarei": "abochornar",
    "abochornareis": "abochornar",
    "abochornarem": "abochornar",
    "abochornaremos": "abochornar",
    "abochornares": "abochornar",
    "abochornaria": "abochornar",
    "abochornariam": "abochornar",
    "abochornarias": "abochornar",
    "abochornarmo": "abochornar",
    "abochornarmos": "abochornar",
    "abochornará": "abochornar",
    "abochornarás": "abochornar",
    "abochornarão": "abochornar",
    "abochornaríamos": "abochornar",
    "abochornaríeis": "abochornar",
    "abochornas": "abochornar",
    "abochornasse": "abochornar",
    "abochornassem": "abochornar",
    "abochornasses": "abochornar",
    "abochornaste": "abochornar",
    "abochornastes": "abochornar",
    "abochornava": "abochornar",
    "abochornavam": "abochornar",
    "abochornavas": "abochornar",
    "abochorne": "abochornar",
    "abochornei": "abochornar",
    "abochorneis": "abochornar",
    "abochornem": "abochornar",
    "abochornemo": "abochornar",
    "abochornemos": "abochornar",
    "abochornes": "abochornar",
    "abochorno": "abochornar",
    "abochornou": "abochornar",
    "abochorná": "abochornar",
    "abochornámo": "abochornar",
    "abochornámos": "abochornar",
    "abochornáramo": "abochornar",
    "abochornáramos": "abochornar",
    "abochornárei": "abochornar",
    "abochornáreis": "abochornar",
    "abochornásseis": "abochornar",
    "abochornássemos": "abochornar",
    "abochornávamo": "abochornar",
    "abochornávamos": "abochornar",
    "abochornávei": "abochornar",
    "abochornáveis": "abochornar",
    "aboco": "abocar",
    "abocou": "abocar",
    "abocá": "abocar",
    "abocámo": "abocar",
    "abocámos": "abocar",
    "abocáramo": "abocar",
    "abocáramos": "abocar",
    "abocárei": "abocar",
    "abocáreis": "abocar",
    "abocásseis": "abocar",
    "abocássemos": "abocar",
    "abocávamo": "abocar",
    "abocávamos": "abocar",
    "abocávei": "abocar",
    "abocáveis": "abocar",
    "abodega": "abodegar",
    "abodegada": "abodegar",
    "abodegadas": "abodegar",
    "abodegado": "abodegar",
    "abodegados": "abodegar",
    "abodegai": "abodegar",
    "abodegais": "abodegar",
    "abodegam": "abodegar",
    "abodegamo": "abodegar",
    "abodegamos": "abodegar",
    "abodegando": "abodegar",
    "abodegara": "abodegar",
    "abodegaram": "abodegar",
    "abodegaras": "abodegar",
    "abodegarde": "abodegar",
    "abodegardes": "abodegar",
    "abodegare": "abodegar",
    "abodegarei": "abodegar",
    "abodegareis": "abodegar",
    "abodegarem": "abodegar",
    "abodegaremos": "abodegar",
    "abodegares": "abodegar",
    "abodegaria": "abodegar",
    "abodegariam": "abodegar",
    "abodegarias": "abodegar",
    "abodegarmo": "abodegar",
    "abodegarmos": "abodegar",
    "abodegará": "abodegar",
    "abodegarás": "abodegar",
    "abodegarão": "abodegar",
    "abodegaríamos": "abodegar",
    "abodegaríeis": "abodegar",
    "abodegas": "abodegar",
    "abodegasse": "abodegar",
    "abodegassem": "abodegar",
    "abodegasses": "abodegar",
    "abodegaste": "abodegar",
    "abodegastes": "abodegar",
    "abodegava": "abodegar",
    "abodegavam": "abodegar",
    "abodegavas": "abodegar",
    "abodego": "abodegar",
    "abodegou": "abodegar",
    "abodegue": "abodegar",
    "abodeguei": "abodegar",
    "abodegueis": "abodegar",
    "abodeguem": "abodegar",
    "abodeguemo": "abodegar",
    "abodeguemos": "abodegar",
    "abodegues": "abodegar",
    "abodegá": "abodegar",
    "abodegámo": "abodegar",
    "abodegámos": "abodegar",
    "abodegáramo": "abodegar",
    "abodegáramos": "abodegar",
    "abodegárei": "abodegar",
    "abodegáreis": "abodegar",
    "abodegásseis": "abodegar",
    "abodegássemos": "abodegar",
    "abodegávamo": "abodegar",
    "abodegávamos": "abodegar",
    "abodegávei": "abodegar",
    "abodegáveis": "abodegar",
    "aboe": "aboar",
    "aboei": "aboar",
    "aboeis": "aboar",
    "aboem": "aboar",
    "aboemo": "aboar",
    "aboemos": "aboar",
    "aboes": "aboar",
    "aboia": "aboiar",
    "aboiada": "aboiar",
    "aboiadas": "aboiar",
    "aboiado": "aboiar",
    "aboiados": "aboiar",
    "aboiai": "aboiar",
    "aboiais": "aboiar",
    "aboiam": "aboiar",
    "aboiamo": "aboiar",
    "aboiamos": "aboiar",
    "aboiando": "aboiar",
    "aboiara": "aboiar",
    "aboiaram": "aboiar",
    "aboiaras": "aboiar",
    "aboiarde": "aboiar",
    "aboiardes": "aboiar",
    "aboiare": "aboiar",
    "aboiarei": "aboiar",
    "aboiareis": "aboiar",
    "aboiarem": "aboiar",
    "aboiaremos": "aboiar",
    "aboiares": "aboiar",
    "aboiaria": "aboiar",
    "aboiariam": "aboiar",
    "aboiarias": "aboiar",
    "aboiarmo": "aboiar",
    "aboiarmos": "aboiar",
    "aboiará": "aboiar",
    "aboiarás": "aboiar",
    "aboiarão": "aboiar",
    "aboiaríamos": "aboiar",
    "aboiaríeis": "aboiar",
    "aboias": "aboiar",
    "aboiasse": "aboiar",
    "aboiassem": "aboiar",
    "aboiasses": "aboiar",
    "aboiaste": "aboiar",
    "aboiastes": "aboiar",
    "aboiava": "aboiar",
    "aboiavam": "aboiar",
    "aboiavas": "aboiar",
    "aboie": "aboiar",
    "aboiei": "aboiar",
    "aboieis": "aboiar",
    "aboiem": "aboiar",
    "aboiemo": "aboiar",
    "aboiemos": "aboiar",
    "aboies": "aboiar",
    "aboio": "aboiar",
    "aboios": "aboio",
    "aboiou": "aboiar",
    "aboizes": "aboiz",
    "aboiá": "aboiar",
    "aboiámo": "aboiar",
    "aboiámos": "aboiar",
    "aboiáramo": "aboiar",
    "aboiáramos": "aboiar",
    "aboiárei": "aboiar",
    "aboiáreis": "aboiar",
    "aboiásseis": "aboiar",
    "aboiássemos": "aboiar",
    "aboiávamo": "aboiar",
    "aboiávamos": "aboiar",
    "aboiávei": "aboiar",
    "aboiáveis": "aboiar",
    "aboja": "abojar",
    "abojada": "abojar",
    "abojadas": "abojar",
    "abojado": "abojar",
    "abojados": "abojar",
    "abojai": "abojar",
    "abojais": "abojar",
    "abojam": "abojar",
    "abojamo": "abojar",
    "abojamos": "abojar",
    "abojando": "abojar",
    "abojara": "abojar",
    "abojaram": "abojar",
    "abojaras": "abojar",
    "abojarde": "abojar",
    "abojardes": "abojar",
    "abojare": "abojar",
    "abojarei": "abojar",
    "abojareis": "abojar",
    "abojarem": "abojar",
    "abojaremos": "abojar",
    "abojares": "abojar",
    "abojaria": "abojar",
    "abojariam": "abojar",
    "abojarias": "abojar",
    "abojarmo": "abojar",
    "abojarmos": "abojar",
    "abojará": "abojar",
    "abojarás": "abojar",
    "abojarão": "abojar",
    "abojaríamos": "abojar",
    "abojaríeis": "abojar",
    "abojas": "abojar",
    "abojasse": "abojar",
    "abojassem": "abojar",
    "abojasses": "abojar",
    "abojaste": "abojar",
    "abojastes": "abojar",
    "abojava": "abojar",
    "abojavam": "abojar",
    "abojavas": "abojar",
    "aboje": "abojar",
    "abojei": "abojar",
    "abojeis": "abojar",
    "abojem": "abojar",
    "abojemo": "abojar",
    "abojemos": "abojar",
    "abojes": "abojar",
    "abojo": "abojar",
    "abojou": "abojar",
    "abojá": "abojar",
    "abojámo": "abojar",
    "abojámos": "abojar",
    "abojáramo": "abojar",
    "abojáramos": "abojar",
    "abojárei": "abojar",
    "abojáreis": "abojar",
    "abojásseis": "abojar",
    "abojássemos": "abojar",
    "abojávamo": "abojar",
    "abojávamos": "abojar",
    "abojávei": "abojar",
    "abojáveis": "abojar",
    "abola": "abolar",
    "abolacha": "abolachar",
    "abolachada": "abolachar",
    "abolachadas": "abolachar",
    "abolachado": "abolachar",
    "abolachados": "abolachar",
    "abolachai": "abolachar",
    "abolachais": "abolachar",
    "abolacham": "abolachar",
    "abolachamo": "abolachar",
    "abolachamos": "abolachar",
    "abolachando": "abolachar",
    "abolachara": "abolachar",
    "abolacharam": "abolachar",
    "abolacharas": "abolachar",
    "abolacharde": "abolachar",
    "abolachardes": "abolachar",
    "abolachare": "abolachar",
    "abolacharei": "abolachar",
    "abolachareis": "abolachar",
    "abolacharem": "abolachar",
    "abolacharemos": "abolachar",
    "abolachares": "abolachar",
    "abolacharia": "abolachar",
    "abolachariam": "abolachar",
    "abolacharias": "abolachar",
    "abolacharmo": "abolachar",
    "abolacharmos": "abolachar",
    "abolachará": "abolachar",
    "abolacharás": "abolachar",
    "abolacharão": "abolachar",
    "abolacharíamos": "abolachar",
    "abolacharíeis": "abolachar",
    "abolachas": "abolachar",
    "abolachasse": "abolachar",
    "abolachassem": "abolachar",
    "abolachasses": "abolachar",
    "abolachaste": "abolachar",
    "abolachastes": "abolachar",
    "abolachava": "abolachar",
    "abolachavam": "abolachar",
    "abolachavas": "abolachar",
    "abolache": "abolachar",
    "abolachei": "abolachar",
    "abolacheis": "abolachar",
    "abolachem": "abolachar",
    "abolachemo": "abolachar",
    "abolachemos": "abolachar",
    "abolaches": "abolachar",
    "abolacho": "abolachar",
    "abolachou": "abolachar",
    "abolachá": "abolachar",
    "abolachámo": "abolachar",
    "abolachámos": "abolachar",
    "abolacháramo": "abolachar",
    "abolacháramos": "abolachar",
    "abolachárei": "abolachar",
    "abolacháreis": "abolachar",
    "abolachásseis": "abolachar",
    "abolachássemos": "abolachar",
    "abolachávamo": "abolachar",
    "abolachávamos": "abolachar",
    "abolachávei": "abolachar",
    "abolacháveis": "abolachar",
    "abolada": "abolar",
    "aboladas": "abolar",
    "abolado": "abolar",
    "abolados": "abolar",
    "aboladuras": "aboladura",
    "abolai": "abolar",
    "abolais": "abolar",
    "abolam": "abolar",
    "abolamo": "abolar",
    "abolamos": "abolar",
    "abolando": "abolar",
    "abolara": "abolar",
    "abolaram": "abolar",
    "abolaras": "abolar",
    "abolarde": "abolar",
    "abolardes": "abolar",
    "abolare": "abolar",
    "abolarei": "abolar",
    "abolareis": "abolar",
    "abolarem": "abolar",
    "abolaremos": "abolar",
    "abolares": "abolar",
    "abolaria": "abolar",
    "abolariam": "abolar",
    "abolarias": "abolar",
    "abolarmo": "abolar",
    "abolarmos": "abolar",
    "abolará": "abolar",
    "abolarás": "abolar",
    "abolarão": "abolar",
    "abolaríamos": "abolar",
    "abolaríeis": "abolar",
    "abolas": "abolar",
    "abolasse": "abolar",
    "abolassem": "abolar",
    "abolasses": "abolar",
    "abolaste": "abolar",
    "abolastes": "abolar",
    "abolava": "abolar",
    "abolavam": "abolar",
    "abolavas": "abolar",
    "abolce": "abolçar",
    "abolcei": "abolçar",
    "abolceis": "abolçar",
    "abolcem": "abolçar",
    "abolcemo": "abolçar",
    "abolcemos": "abolçar",
    "abolces": "abolçar",
    "aboldria": "aboldriar",
    "aboldriada": "aboldriar",
    "aboldriadas": "aboldriar",
    "aboldriado": "aboldriar",
    "aboldriados": "aboldriar",
    "aboldriai": "aboldriar",
    "aboldriais": "aboldriar",
    "aboldriam": "aboldriar",
    "aboldriamo": "aboldriar",
    "aboldriamos": "aboldriar",
    "aboldriando": "aboldriar",
    "aboldriara": "aboldriar",
    "aboldriaram": "aboldriar",
    "aboldriaras": "aboldriar",
    "aboldriarde": "aboldriar",
    "aboldriardes": "aboldriar",
    "aboldriare": "aboldriar",
    "aboldriarei": "aboldriar",
    "aboldriareis": "aboldriar",
    "aboldriarem": "aboldriar",
    "aboldriaremos": "aboldriar",
    "aboldriares": "aboldriar",
    "aboldriaria": "aboldriar",
    "aboldriariam": "aboldriar",
    "aboldriarias": "aboldriar",
    "aboldriarmo": "aboldriar",
    "aboldriarmos": "aboldriar",
    "aboldriará": "aboldriar",
    "aboldriarás": "aboldriar",
    "aboldriarão": "aboldriar",
    "aboldriaríamos": "aboldriar",
    "aboldriaríeis": "aboldriar",
    "aboldrias": "aboldriar",
    "aboldriasse": "aboldriar",
    "aboldriassem": "aboldriar",
    "aboldriasses": "aboldriar",
    "aboldriaste": "aboldriar",
    "aboldriastes": "aboldriar",
    "aboldriava": "aboldriar",
    "aboldriavam": "aboldriar",
    "aboldriavas": "aboldriar",
    "aboldrie": "aboldriar",
    "aboldriei": "aboldriar",
    "aboldrieis": "aboldriar",
    "aboldriem": "aboldriar",
    "aboldriemo": "aboldriar",
    "aboldriemos": "aboldriar",
    "aboldries": "aboldriar",
    "aboldrio": "aboldriar",
    "aboldriou": "aboldriar",
    "aboldriá": "aboldriar",
    "aboldriámo": "aboldriar",
    "aboldriámos": "aboldriar",
    "aboldriáramo": "aboldriar",
    "aboldriáramos": "aboldriar",
    "aboldriárei": "aboldriar",
    "aboldriáreis": "aboldriar",
    "aboldriásseis": "aboldriar",
    "aboldriássemos": "aboldriar",
    "aboldriávamo": "aboldriar",
    "aboldriávamos": "aboldriar",
    "aboldriávei": "aboldriar",
    "aboldriáveis": "aboldriar",
    "abole": "abolir",
    "abolei": "abolar",
    "aboleima": "aboleimar",
    "aboleimada": "aboleimar",
    "aboleimadas": "aboleimar",
    "aboleimado": "aboleimar",
    "aboleimados": "aboleimar",
    "aboleimai": "aboleimar",
    "aboleimais": "aboleimar",
    "aboleimam": "aboleimar",
    "aboleimamo": "aboleimar",
    "aboleimamos": "aboleimar",
    "aboleimando": "aboleimar",
    "aboleimara": "aboleimar",
    "aboleimaram": "aboleimar",
    "aboleimaras": "aboleimar",
    "aboleimarde": "aboleimar",
    "aboleimardes": "aboleimar",
    "aboleimare": "aboleimar",
    "aboleimarei": "aboleimar",
    "aboleimareis": "aboleimar",
    "aboleimarem": "aboleimar",
    "aboleimaremos": "aboleimar",
    "aboleimares": "aboleimar",
    "aboleimaria": "aboleimar",
    "aboleimariam": "aboleimar",
    "aboleimarias": "aboleimar",
    "aboleimarmo": "aboleimar",
    "aboleimarmos": "aboleimar",
    "aboleimará": "aboleimar",
    "aboleimarás": "aboleimar",
    "aboleimarão": "aboleimar",
    "aboleimaríamos": "aboleimar",
    "aboleimaríeis": "aboleimar",
    "aboleimas": "aboleimar",
    "aboleimasse": "aboleimar",
    "aboleimassem": "aboleimar",
    "aboleimasses": "aboleimar",
    "aboleimaste": "aboleimar",
    "aboleimastes": "aboleimar",
    "aboleimava": "aboleimar",
    "aboleimavam": "aboleimar",
    "aboleimavas": "aboleimar",
    "aboleime": "aboleimar",
    "aboleimei": "aboleimar",
    "aboleimeis": "aboleimar",
    "aboleimem": "aboleimar",
    "aboleimemo": "aboleimar",
    "aboleimemos": "aboleimar",
    "aboleimes": "aboleimar",
    "aboleimo": "aboleimar",
    "aboleimou": "aboleimar",
    "aboleimá": "aboleimar",
    "aboleimámo": "aboleimar",
    "aboleimámos": "aboleimar",
    "aboleimáramo": "aboleimar",
    "aboleimáramos": "aboleimar",
    "aboleimárei": "aboleimar",
    "aboleimáreis": "aboleimar",
    "aboleimásseis": "aboleimar",
    "aboleimássemos": "aboleimar",
    "aboleimávamo": "aboleimar",
    "aboleimávamos": "aboleimar",
    "aboleimávei": "aboleimar",
    "aboleimáveis": "aboleimar",
    "aboleis": "abolar",
    "abolem": "abolir",
    "abolemo": "abolar",
    "abolemos": "abolar",
    "aboles": "abolir",
    "aboleta": "aboletar",
    "aboletada": "aboletar",
    "aboletadas": "aboletar",
    "aboletado": "aboletar",
    "aboletadora": "aboletador",
    "aboletadoras": "aboletador",
    "aboletadores": "aboletador",
    "aboletados": "aboletar",
    "aboletai": "aboletar",
    "aboletais": "aboletar",
    "aboletam": "aboletar",
    "aboletamentos": "aboletamento",
    "aboletamo": "aboletar",
    "aboletamos": "aboletar",
    "aboletando": "aboletar",
    "aboletara": "aboletar",
    "aboletaram": "aboletar",
    "aboletaras": "aboletar",
    "aboletarde": "aboletar",
    "aboletardes": "aboletar",
    "aboletare": "aboletar",
    "aboletarei": "aboletar",
    "aboletareis": "aboletar",
    "aboletarem": "aboletar",
    "aboletaremos": "aboletar",
    "aboletares": "aboletar",
    "aboletaria": "aboletar",
    "aboletariam": "aboletar",
    "aboletarias": "aboletar",
    "aboletarmo": "aboletar",
    "aboletarmos": "aboletar",
    "aboletará": "aboletar",
    "aboletarás": "aboletar",
    "aboletarão": "aboletar",
    "aboletaríamos": "aboletar",
    "aboletaríeis": "aboletar",
    "aboletas": "aboletar",
    "aboletasse": "aboletar",
    "aboletassem": "aboletar",
    "aboletasses": "aboletar",
    "aboletaste": "aboletar",
    "aboletastes": "aboletar",
    "aboletava": "aboletar",
    "aboletavam": "aboletar",
    "aboletavas": "aboletar",
    "abolete": "aboletar",
    "aboletei": "aboletar",
    "aboleteis": "aboletar",
    "aboletem": "aboletar",
    "aboletemo": "aboletar",
    "aboletemos": "aboletar",
    "aboletes": "aboletar",
    "aboleto": "aboletar",
    "aboletou": "aboletar",
    "aboletá": "aboletar",
    "aboletámo": "aboletar",
    "aboletámos": "aboletar",
    "aboletáramo": "aboletar",
    "aboletáramos": "aboletar",
    "aboletárei": "aboletar",
    "aboletáreis": "aboletar",
    "aboletásseis": "aboletar",
    "aboletássemos": "aboletar",
    "aboletávamo": "aboletar",
    "aboletávamos": "aboletar",
    "aboletávei": "aboletar",
    "aboletáveis": "aboletar",
    "aboli": "abolir",
    "abolia": "abolir",
    "aboliam": "abolir",
    "abolias": "abolir",
    "abolicionismos": "abolicionismo",
    "abolicionistas": "abolicionista",
    "abolida": "abolir",
    "abolidas": "abolir",
    "abolido": "abolir",
    "abolidora": "abolidor",
    "abolidoras": "abolidor",
    "abolidores": "abolidor",
    "abolidos": "abolir",
    "abolimentos": "abolimento",
    "abolimo": "abolir",
    "abolimos": "abolir",
    "abolina": "abolinar",
    "abolinada": "abolinar",
    "abolinadas": "abolinar",
    "abolinado": "abolinar",
    "abolinados": "abolinar",
    "abolinai": "abolinar",
    "abolinais": "abolinar",
    "abolinam": "abolinar",
    "abolinamo": "abolinar",
    "abolinamos": "abolinar",
    "abolinando": "abolinar",
    "abolinara": "abolinar",
    "abolinaram": "abolinar",
    "abolinaras": "abolinar",
    "abolinardes": "abolinar",
    "abolinarei": "abolinar",
    "abolinareis": "abolinar",
    "abolinarem": "abolinar",
    "abolinaremos": "abolinar",
    "abolinares": "abolinar",
    "abolinaria": "abolinar",
    "abolinariam": "abolinar",
    "abolinarias": "abolinar",
    "abolinarmo": "abolinar",
    "abolinarmos": "abolinar",
    "abolinará": "abolinar",
    "abolinarás": "abolinar",
    "abolinarão": "abolinar",
    "abolinaríamos": "abolinar",
    "abolinaríeis": "abolinar",
    "abolinas": "abolinar",
    "abolinasse": "abolinar",
    "abolinassem": "abolinar",
    "abolinasses": "abolinar",
    "abolinaste": "abolinar",
    "abolinastes": "abolinar",
    "abolinava": "abolinar",
    "abolinavam": "abolinar",
    "abolinavas": "abolinar",
    "abolindo": "abolir",
    "aboline": "abolinar",
    "abolinei": "abolinar",
    "abolineis": "abolinar",
    "abolinem": "abolinar",
    "abolinemo": "abolinar",
    "abolinemos": "abolinar",
    "abolines": "abolinar",
    "abolino": "abolinar",
    "abolinou": "abolinar",
    "abolinámo": "abolinar",
    "abolinámos": "abolinar",
    "abolináramo": "abolinar",
    "abolináramos": "abolinar",
    "abolináreis": "abolinar",
    "abolinásseis": "abolinar",
    "abolinássemos": "abolinar",
    "abolinávamo": "abolinar",
    "abolinávamos": "abolinar",
    "abolináveis": "abolinar",
    "abolira": "abolir",
    "aboliram": "abolir",
    "aboliras": "abolir",
    "abolirde": "abolir",
    "abolirdes": "abolir",
    "abolire": "abolir",
    "abolirei": "abolir",
    "abolireis": "abolir",
    "abolirem": "abolir",
    "aboliremos": "abolir",
    "abolires": "abolir",
    "aboliria": "abolir",
    "aboliriam": "abolir",
    "abolirias": "abolir",
    "abolirmo": "abolir",
    "abolirmos": "abolir",
    "abolirá": "abolir",
    "abolirás": "abolir",
    "abolirão": "abolir",
    "aboliríamos": "abolir",
    "aboliríeis": "abolir",
    "abolis": "abolir",
    "abolisse": "abolir",
    "abolissem": "abolir",
    "abolisses": "abolir",
    "aboliste": "abolir",
    "abolistes": "abolir",
    "abolitiva": "abolitivo",
    "abolitivas": "abolitivo",
    "abolitivos": "abolitivo",
    "aboliu": "abolir",
    "abolições": "abolição",
    "abolo": "abolar",
    "abolorece": "abolorecer",
    "abolorecei": "abolorecer",
    "aboloreceis": "abolorecer",
    "abolorecem": "abolorecer",
    "abolorecemo": "abolorecer",
    "abolorecemos": "abolorecer",
    "abolorecendo": "abolorecer",
    "abolorecera": "abolorecer",
    "aboloreceram": "abolorecer",
    "aboloreceras": "abolorecer",
    "abolorecerdes": "abolorecer",
    "abolorecerei": "abolorecer",
    "abolorecereis": "abolorecer",
    "abolorecerem": "abolorecer",
    "aboloreceremos": "abolorecer",
    "aboloreceres": "abolorecer",
    "aboloreceria": "abolorecer",
    "aboloreceriam": "abolorecer",
    "abolorecerias": "abolorecer",
    "abolorecermo": "abolorecer",
    "abolorecermos": "abolorecer",
    "abolorecerá": "abolorecer",
    "abolorecerás": "abolorecer",
    "abolorecerão": "abolorecer",
    "aboloreceríamos": "abolorecer",
    "aboloreceríeis": "abolorecer",
    "aboloreces": "abolorecer",
    "abolorecesse": "abolorecer",
    "abolorecessem": "abolorecer",
    "abolorecesses": "abolorecer",
    "aboloreceste": "abolorecer",
    "abolorecestes": "abolorecer",
    "aboloreceu": "abolorecer",
    "aboloreci": "abolorecer",
    "abolorecia": "abolorecer",
    "aboloreciam": "abolorecer",
    "abolorecias": "abolorecer",
    "abolorecida": "abolorecer",
    "abolorecidas": "abolorecer",
    "abolorecido": "abolorecer",
    "abolorecidos": "abolorecer",
    "abolorecimentos": "abolorecimento",
    "abolorecêramo": "abolorecer",
    "abolorecêramos": "abolorecer",
    "abolorecêreis": "abolorecer",
    "abolorecêsseis": "abolorecer",
    "abolorecêssemos": "abolorecer",
    "abolorecíamo": "abolorecer",
    "abolorecíamos": "abolorecer",
    "abolorecíeis": "abolorecer",
    "abolorenta": "abolorentar",
    "abolorentada": "abolorentar",
    "abolorentadas": "abolorentar",
    "abolorentado": "abolorentar",
    "abolorentados": "abolorentar",
    "abolorentai": "abolorentar",
    "abolorentais": "abolorentar",
    "abolorentam": "abolorentar",
    "abolorentamo": "abolorentar",
    "abolorentamos": "abolorentar",
    "abolorentando": "abolorentar",
    "abolorentara": "abolorentar",
    "abolorentaram": "abolorentar",
    "abolorentaras": "abolorentar",
    "abolorentarde": "abolorentar",
    "abolorentardes": "abolorentar",
    "abolorentare": "abolorentar",
    "abolorentarei": "abolorentar",
    "abolorentareis": "abolorentar",
    "abolorentarem": "abolorentar",
    "abolorentaremos": "abolorentar",
    "abolorentares": "abolorentar",
    "abolorentaria": "abolorentar",
    "abolorentariam": "abolorentar",
    "abolorentarias": "abolorentar",
    "abolorentarmo": "abolorentar",
    "abolorentarmos": "abolorentar",
    "abolorentará": "abolorentar",
    "abolorentarás": "abolorentar",
    "abolorentarão": "abolorentar",
    "abolorentaríamos": "abolorentar",
    "abolorentaríeis": "abolorentar",
    "abolorentas": "abolorentar",
    "abolorentasse": "abolorentar",
    "abolorentassem": "abolorentar",
    "abolorentasses": "abolorentar",
    "abolorentaste": "abolorentar",
    "abolorentastes": "abolorentar",
    "abolorentava": "abolorentar",
    "abolorentavam": "abolorentar",
    "abolorentavas": "abolorentar",
    "abolorente": "abolorentar",
    "abolorentei": "abolorentar",
    "abolorenteis": "abolorentar",
    "abolorentem": "abolorentar",
    "abolorentemo": "abolorentar",
    "abolorentemos": "abolorentar",
    "abolorentes": "abolorentar",
    "abolorento": "abolorentar",
    "abolorentou": "abolorentar",
    "abolorentá": "abolorentar",
    "abolorentámo": "abolorentar",
    "abolorentámos": "abolorentar",
    "abolorentáramo": "abolorentar",
    "abolorentáramos": "abolorentar",
    "abolorentárei": "abolorentar",
    "abolorentáreis": "abolorentar",
    "abolorentásseis": "abolorentar",
    "abolorentássemos": "abolorentar",
    "abolorentávamo": "abolorentar",
    "abolorentávamos": "abolorentar",
    "abolorentávei": "abolorentar",
    "abolorentáveis": "abolorentar",
    "aboloreça": "abolorecer",
    "aboloreçais": "abolorecer",
    "aboloreçam": "abolorecer",
    "aboloreçamo": "abolorecer",
    "aboloreçamos": "abolorecer",
    "aboloreças": "abolorecer",
    "aboloreço": "abolorecer",
    "abolou": "abolar",
    "abolsa": "abolsar",
    "abolsada": "abolsar",
    "abolsadas": "abolsar",
    "abolsado": "abolsar",
    "abolsados": "abolsar",
    "abolsai": "abolsar",
    "abolsais": "abolsar",
    "abolsam": "abolsar",
    "abolsamo": "abolsar",
    "abolsamos": "abolsar",
    "abolsando": "abolsar",
    "abolsara": "abolsar",
    "abolsaram": "abolsar",
    "abolsaras": "abolsar",
    "abolsardes": "abolsar",
    "abolsarei": "abolsar",
    "abolsareis": "abolsar",
    "abolsarem": "abolsar",
    "abolsaremos": "abolsar",
    "abolsares": "abolsar",
    "abolsaria": "abolsar",
    "abolsariam": "abolsar",
    "abolsarias": "abolsar",
    "abolsarmo": "abolsar",
    "abolsarmos": "abolsar",
    "abolsará": "abolsar",
    "abolsarás": "abolsar",
    "abolsarão": "abolsar",
    "abolsaríamos": "abolsar",
    "abolsaríeis": "abolsar",
    "abolsas": "abolsar",
    "abolsasse": "abolsar",
    "abolsassem": "abolsar",
    "abolsasses": "abolsar",
    "abolsaste": "abolsar",
    "abolsastes": "abolsar",
    "abolsava": "abolsar",
    "abolsavam": "abolsar",
    "abolsavas": "abolsar",
    "abolse": "abolsar",
    "abolsei": "abolsar",
    "abolseis": "abolsar",
    "abolsem": "abolsar",
    "abolsemo": "abolsar",
    "abolsemos": "abolsar",
    "abolses": "abolsar",
    "abolso": "abolsar",
    "abolsou": "abolsar",
    "abolsámo": "abolsar",
    "abolsámos": "abolsar",
    "abolsáramo": "abolsar",
    "abolsáramos": "abolsar",
    "abolsáreis": "abolsar",
    "abolsásseis": "abolsar",
    "abolsássemos": "abolsar",
    "abolsávamo": "abolsar",
    "abolsávamos": "abolsar",
    "abolsáveis": "abolsar",
    "abolá": "abolar",
    "abolámo": "abolar",
    "abolámos": "abolar",
    "aboláramo": "abolar",
    "aboláramos": "abolar",
    "abolárei": "abolar",
    "aboláreis": "abolar",
    "abolásseis": "abolar",
    "abolássemos": "abolar",
    "abolávamo": "abolar",
    "abolávamos": "abolar",
    "abolávei": "abolar",
    "aboláveis": "abolar",
    "abolça": "abolçar",
    "abolçada": "abolçar",
    "abolçadas": "abolçar",
    "abolçado": "abolçar",
    "abolçados": "abolçar",
    "abolçai": "abolçar",
    "abolçais": "abolçar",
    "abolçam": "abolçar",
    "abolçamo": "abolçar",
    "abolçamos": "abolçar",
    "abolçando": "abolçar",
    "abolçara": "abolçar",
    "abolçaram": "abolçar",
    "abolçaras": "abolçar",
    "abolçarde": "abolçar",
    "abolçardes": "abolçar",
    "abolçare": "abolçar",
    "abolçarei": "abolçar",
    "abolçareis": "abolçar",
    "abolçarem": "abolçar",
    "abolçaremos": "abolçar",
    "abolçares": "abolçar",
    "abolçaria": "abolçar",
    "abolçariam": "abolçar",
    "abolçarias": "abolçar",
    "abolçarmo": "abolçar",
    "abolçarmos": "abolçar",
    "abolçará": "abolçar",
    "abolçarás": "abolçar",
    "abolçarão": "abolçar",
    "abolçaríamos": "abolçar",
    "abolçaríeis": "abolçar",
    "abolças": "abolçar",
    "abolçasse": "abolçar",
    "abolçassem": "abolçar",
    "abolçasses": "abolçar",
    "abolçaste": "abolçar",
    "abolçastes": "abolçar",
    "abolçava": "abolçar",
    "abolçavam": "abolçar",
    "abolçavas": "abolçar",
    "abolço": "abolçar",
    "abolçou": "abolçar",
    "abolçá": "abolçar",
    "abolçámo": "abolçar",
    "abolçámos": "abolçar",
    "abolçáramo": "abolçar",
    "abolçáramos": "abolçar",
    "abolçárei": "abolçar",
    "abolçáreis": "abolçar",
    "abolçásseis": "abolçar",
    "abolçássemos": "abolçar",
    "abolçávamo": "abolçar",
    "abolçávamos": "abolçar",
    "abolçávei": "abolçar",
    "abolçáveis": "abolçar",
    "abolíamo": "abolir",
    "abolíamos": "abolir",
    "abolíei": "abolir",
    "abolíeis": "abolir",
    "abolíramo": "abolir",
    "abolíramos": "abolir",
    "abolírei": "abolir",
    "abolíreis": "abolir",
    "abolísseis": "abolir",
    "abolíssemos": "abolir",
    "abolíveis": "abolível",
    "abomasos": "abomaso",
    "abomina": "abominar",
    "abominada": "abominar",
    "abominadas": "abominar",
    "abominado": "abominar",
    "abominadora": "abominador",
    "abominadoras": "abominador",
    "abominadores": "abominador",
    "abominados": "abominar",
    "abominai": "abominar",
    "abominais": "abominar",
    "abominam": "abominar",
    "abominamo": "abominar",
    "abominamos": "abominar",
    "abominanda": "abominando",
    "abominandas": "abominando",
    "abominando": "abominar",
    "abominandos": "abominando",
    "abominara": "abominar",
    "abominaram": "abominar",
    "abominaras": "abominar",
    "abominarde": "abominar",
    "abominardes": "abominar",
    "abominare": "abominar",
    "abominarei": "abominar",
    "abominareis": "abominar",
    "abominarem": "abominar",
    "abominaremos": "abominar",
    "abominares": "abominar",
    "abominaria": "abominar",
    "abominariam": "abominar",
    "abominarias": "abominar",
    "abominarmo": "abominar",
    "abominarmos": "abominar",
    "abominará": "abominar",
    "abominarás": "abominar",
    "abominarão": "abominar",
    "abominaríamos": "abominar",
    "abominaríeis": "abominar",
    "abominas": "abominar",
    "abominasse": "abominar",
    "abominassem": "abominar",
    "abominasses": "abominar",
    "abominaste": "abominar",
    "abominastes": "abominar",
    "abominava": "abominar",
    "abominavam": "abominar",
    "abominavas": "abominar",
    "abominações": "abominação",
    "abomine": "abominar",
    "abominei": "abominar",
    "abomineis": "abominar",
    "abominem": "abominar",
    "abominemo": "abominar",
    "abominemos": "abominar",
    "abomines": "abominar",
    "abomino": "abominar",
    "abominosa": "abominoso",
    "abominosas": "abominoso",
    "abominosos": "abominoso",
    "abominou": "abominar",
    "abominá": "abominar",
    "abominámo": "abominar",
    "abominámos": "abominar",
    "abomináramo": "abominar",
    "abomináramos": "abominar",
    "abominárei": "abominar",
    "abomináreis": "abominar",
    "abominásseis": "abominar",
    "abominássemos": "abominar",
    "abominávamo": "abominar",
    "abominávamos": "abominar",
    "abominávei": "abominar",
    "abomináveis": "abominável",
    "abona": "abonar",
    "abonada": "abonar",
    "abonadas": "abonar",
    "abonado": "abonar",
    "abonadora": "abonador",
    "abonadoras": "abonador",
    "abonadores": "abonador",
    "abonados": "abonar",
    "abonadíssima": "abonado",
    "abonadíssimas": "abonado",
    "abonadíssimo": "abonado",
    "abonadíssimos": "abonado",
    "abonai": "abonar",
    "abonais": "abonar",
    "abonam": "abonar",
    "abonamo": "abonar",
    "abonamos": "abonar",
    "abonando": "abonar",
    "abonara": "abonar",
    "abonaram": "abonar",
    "abonaras": "abonar",
    "abonarde": "abonar",
    "abonardes": "abonar",
    "abonare": "abonar",
    "abonarei": "abonar",
    "abonareis": "abonar",
    "abonarem": "abonar",
    "abonaremos": "abonar",
    "abonares": "abonar",
    "abonaria": "abonar",
    "abonariam": "abonar",
    "abonarias": "abonar",
    "abonarmo": "abonar",
    "abonarmos": "abonar",
    "abonará": "abonar",
    "abonarás": "abonar",
    "abonarão": "abonar",
    "abonaríamos": "abonar",
    "abonaríeis": "abonar",
    "abonas": "abonar",
    "abonasse": "abonar",
    "abonassem": "abonar",
    "abonasses": "abonar",
    "abonaste": "abonar",
    "abonastes": "abonar",
    "abonatória": "abonatório",
    "abonatórias": "abonatório",
    "abonatórios": "abonatório",
    "abonava": "abonar",
    "abonavam": "abonar",
    "abonavas": "abonar",
    "abonações": "abonação",
    "abonda": "abondar",
    "abondada": "abondar",
    "abondadas": "abondar",
    "abondado": "abondar",
    "abondados": "abondar",
    "abondai": "abondar",
    "abondais": "abondar",
    "abondam": "abondar",
    "abondamo": "abondar",
    "abondamos": "abondar",
    "abondando": "abondar",
    "abondara": "abondar",
    "abondaram": "abondar",
    "abondaras": "abondar",
    "abondarde": "abondar",
    "abondardes": "abondar",
    "abondare": "abondar",
    "abondarei": "abondar",
    "abondareis": "abondar",
    "abondarem": "abondar",
    "abondaremos": "abondar",
    "abondares": "abondar",
    "abondaria": "abondar",
    "abondariam": "abondar",
    "abondarias": "abondar",
    "abondarmo": "abondar",
    "abondarmos": "abondar",
    "abondará": "abondar",
    "abondarás": "abondar",
    "abondarão": "abondar",
    "abondaríamos": "abondar",
    "abondaríeis": "abondar",
    "abondas": "abondar",
    "abondasse": "abondar",
    "abondassem": "abondar",
    "abondasses": "abondar",
    "abondaste": "abondar",
    "abondastes": "abondar",
    "abondava": "abondar",
    "abondavam": "abondar",
    "abondavas": "abondar",
    "abonde": "abondar",
    "abondei": "abondar",
    "abondeis": "abondar",
    "abondem": "abondar",
    "abondemo": "abondar",
    "abondemos": "abondar",
    "abondes": "abondar",
    "abondo": "abondar",
    "abondou": "abondar",
    "abondá": "abondar",
    "abondámo": "abondar",
    "abondámos": "abondar",
    "abondáramo": "abondar",
    "abondáramos": "abondar",
    "abondárei": "abondar",
    "abondáreis": "abondar",
    "abondásseis": "abondar",
    "abondássemos": "abondar",
    "abondávamo": "abondar",
    "abondávamos": "abondar",
    "abondávei": "abondar",
    "abondáveis": "abondar",
    "abone": "abonar",
    "aboneca": "abonecar",
    "abonecada": "abonecar",
    "abonecadas": "abonecar",
    "abonecado": "abonecar",
    "abonecados": "abonecar",
    "abonecai": "abonecar",
    "abonecais": "abonecar",
    "abonecam": "abonecar",
    "abonecamentos": "abonecamento",
    "abonecamo": "abonecar",
    "abonecamos": "abonecar",
    "abonecando": "abonecar",
    "abonecara": "abonecar",
    "abonecaram": "abonecar",
    "abonecaras": "abonecar",
    "abonecarde": "abonecar",
    "abonecardes": "abonecar",
    "abonecare": "abonecar",
    "abonecarei": "abonecar",
    "abonecareis": "abonecar",
    "abonecarem": "abonecar",
    "abonecaremos": "abonecar",
    "abonecares": "abonecar",
    "abonecaria": "abonecar",
    "abonecariam": "abonecar",
    "abonecarias": "abonecar",
    "abonecarmo": "abonecar",
    "abonecarmos": "abonecar",
    "abonecará": "abonecar",
    "abonecarás": "abonecar",
    "abonecarão": "abonecar",
    "abonecaríamos": "abonecar",
    "abonecaríeis": "abonecar",
    "abonecas": "abonecar",
    "abonecasse": "abonecar",
    "abonecassem": "abonecar",
    "abonecasses": "abonecar",
    "abonecaste": "abonecar",
    "abonecastes": "abonecar",
    "abonecava": "abonecar",
    "abonecavam": "abonecar",
    "abonecavas": "abonecar",
    "aboneco": "abonecar",
    "abonecou": "abonecar",
    "abonecá": "abonecar",
    "abonecámo": "abonecar",
    "abonecámos": "abonecar",
    "abonecáramo": "abonecar",
    "abonecáramos": "abonecar",
    "abonecárei": "abonecar",
    "abonecáreis": "abonecar",
    "abonecásseis": "abonecar",
    "abonecássemos": "abonecar",
    "abonecávamo": "abonecar",
    "abonecávamos": "abonecar",
    "abonecávei": "abonecar",
    "abonecáveis": "abonecar",
    "abonei": "abonar",
    "aboneis": "abonar",
    "abonem": "abonar",
    "abonemo": "abonar",
    "abonemos": "abonar",
    "aboneque": "abonecar",
    "abonequei": "abonecar",
    "abonequeis": "abonecar",
    "abonequem": "abonecar",
    "abonequemo": "abonecar",
    "abonequemos": "abonecar",
    "aboneques": "abonecar",
    "abones": "abonar",
    "abono": "abonar",
    "abonos": "abono",
    "abonou": "abonar",
    "aboná": "abonar",
    "abonámo": "abonar",
    "abonámos": "abonar",
    "abonáramo": "abonar",
    "abonáramos": "abonar",
    "abonárei": "abonar",
    "abonáreis": "abonar",
    "abonásseis": "abonar",
    "abonássemos": "abonar",
    "abonávamo": "abonar",
    "abonávamos": "abonar",
    "abonávei": "abonar",
    "abonáveis": "abonável",
    "aboo": "aboar",
    "aboou": "aboar",
    "aboque": "abocar",
    "aboquei": "abocar",
    "aboqueis": "abocar",
    "aboqueja": "aboquejar",
    "aboquejada": "aboquejar",
    "aboquejadas": "aboquejar",
    "aboquejado": "aboquejar",
    "aboquejados": "aboquejar",
    "aboquejai": "aboquejar",
    "aboquejais": "aboquejar",
    "aboquejam": "aboquejar",
    "aboquejamo": "aboquejar",
    "aboquejamos": "aboquejar",
    "aboquejando": "aboquejar",
    "aboquejara": "aboquejar",
    "aboquejaram": "aboquejar",
    "aboquejaras": "aboquejar",
    "aboquejarde": "aboquejar",
    "aboquejardes": "aboquejar",
    "aboquejare": "aboquejar",
    "aboquejarei": "aboquejar",
    "aboquejareis": "aboquejar",
    "aboquejarem": "aboquejar",
    "aboquejaremos": "aboquejar",
    "aboquejares": "aboquejar",
    "aboquejaria": "aboquejar",
    "aboquejariam": "aboquejar",
    "aboquejarias": "aboquejar",
    "aboquejarmo": "aboquejar",
    "aboquejarmos": "aboquejar",
    "aboquejará": "aboquejar",
    "aboquejarás": "aboquejar",
    "aboquejarão": "aboquejar",
    "aboquejaríamos": "aboquejar",
    "aboquejaríeis": "aboquejar",
    "aboquejas": "aboquejar",
    "aboquejasse": "aboquejar",
    "aboquejassem": "aboquejar",
    "aboquejasses": "aboquejar",
    "aboquejaste": "aboquejar",
    "aboquejastes": "aboquejar",
    "aboquejava": "aboquejar",
    "aboquejavam": "aboquejar",
    "aboquejavas": "aboquejar",
    "aboqueje": "aboquejar",
    "aboquejei": "aboquejar",
    "aboquejeis": "aboquejar",
    "aboquejem": "aboquejar",
    "aboquejemo": "aboquejar",
    "aboquejemos": "aboquejar",
    "aboquejes": "aboquejar",
    "aboquejo": "aboquejar",
    "aboquejos": "aboquejo",
    "aboquejou": "aboquejar",
    "aboquejá": "aboquejar",
    "aboquejámo": "aboquejar",
    "aboquejámos": "aboquejar",
    "aboquejáramo": "aboquejar",
    "aboquejáramos": "aboquejar",
    "aboquejárei": "aboquejar",
    "aboquejáreis": "aboquejar",
    "aboquejásseis": "aboquejar",
    "aboquejássemos": "aboquejar",
    "aboquejávamo": "aboquejar",
    "aboquejávamos": "aboquejar",
    "aboquejávei": "aboquejar",
    "aboquejáveis": "aboquejar",
    "aboquem": "abocar",
    "aboquemo": "abocar",
    "aboquemos": "abocar",
    "aboques": "abocar",
    "aborbulha": "aborbulhar",
    "aborbulhada": "aborbulhar",
    "aborbulhadas": "aborbulhar",
    "aborbulhado": "aborbulhar",
    "aborbulhados": "aborbulhar",
    "aborbulhai": "aborbulhar",
    "aborbulhais": "aborbulhar",
    "aborbulham": "aborbulhar",
    "aborbulhamo": "aborbulhar",
    "aborbulhamos": "aborbulhar",
    "aborbulhando": "aborbulhar",
    "aborbulhara": "aborbulhar",
    "aborbulharam": "aborbulhar",
    "aborbulharas": "aborbulhar",
    "aborbulhardes": "aborbulhar",
    "aborbulharei": "aborbulhar",
    "aborbulhareis": "aborbulhar",
    "aborbulharem": "aborbulhar",
    "aborbulharemos": "aborbulhar",
    "aborbulhares": "aborbulhar",
    "aborbulharia": "aborbulhar",
    "aborbulhariam": "aborbulhar",
    "aborbulharias": "aborbulhar",
    "aborbulharmo": "aborbulhar",
    "aborbulharmos": "aborbulhar",
    "aborbulhará": "aborbulhar",
    "aborbulharás": "aborbulhar",
    "aborbulharão": "aborbulhar",
    "aborbulharíamos": "aborbulhar",
    "aborbulharíeis": "aborbulhar",
    "aborbulhas": "aborbulhar",
    "aborbulhasse": "aborbulhar",
    "aborbulhassem": "aborbulhar",
    "aborbulhasses": "aborbulhar",
    "aborbulhaste": "aborbulhar",
    "aborbulhastes": "aborbulhar",
    "aborbulhava": "aborbulhar",
    "aborbulhavam": "aborbulhar",
    "aborbulhavas": "aborbulhar",
    "aborbulhe": "aborbulhar",
    "aborbulhei": "aborbulhar",
    "aborbulheis": "aborbulhar",
    "aborbulhem": "aborbulhar",
    "aborbulhemo": "aborbulhar",
    "aborbulhemos": "aborbulhar",
    "aborbulhes": "aborbulhar",
    "aborbulho": "aborbulhar",
    "aborbulhou": "aborbulhar",
    "aborbulhámo": "aborbulhar",
    "aborbulhámos": "aborbulhar",
    "aborbulháramo": "aborbulhar",
    "aborbulháramos": "aborbulhar",
    "aborbulháreis": "aborbulhar",
    "aborbulhásseis": "aborbulhar",
    "aborbulhássemos": "aborbulhar",
    "aborbulhávamo": "aborbulhar",
    "aborbulhávamos": "aborbulhar",
    "aborbulháveis": "aborbulhar",
    "aborda": "abordar",
    "abordada": "abordar",
    "abordadas": "abordar",
    "abordado": "abordar",
    "abordadora": "abordador",
    "abordadoras": "abordador",
    "abordadores": "abordador",
    "abordados": "abordar",
    "abordadíssima": "abordado",
    "abordadíssimas": "abordado",
    "abordadíssimo": "abordado",
    "abordadíssimos": "abordado",
    "abordagens": "abordagem",
    "abordai": "abordar",
    "abordais": "abordar",
    "abordam": "abordar",
    "abordamo": "abordar",
    "abordamos": "abordar",
    "abordando": "abordar",
    "abordara": "abordar",
    "abordaram": "abordar",
    "abordaras": "abordar",
    "abordarde": "abordar",
    "abordardes": "abordar",
    "abordare": "abordar",
    "abordarei": "abordar",
    "abordareis": "abordar",
    "abordarem": "abordar",
    "abordaremos": "abordar",
    "abordares": "abordar",
    "abordaria": "abordar",
    "abordariam": "abordar",
    "abordarias": "abordar",
    "abordarmo": "abordar",
    "abordarmos": "abordar",
    "abordará": "abordar",
    "abordarás": "abordar",
    "abordarão": "abordar",
    "abordaríamos": "abordar",
    "abordaríeis": "abordar",
    "abordas": "abordar",
    "abordasse": "abordar",
    "abordassem": "abordar",
    "abordasses": "abordar",
    "abordaste": "abordar",
    "abordastes": "abordar",
    "abordava": "abordar",
    "abordavam": "abordar",
    "abordavas": "abordar",
    "aborde": "abordar",
    "abordei": "abordar",
    "abordeis": "abordar",
    "abordem": "abordar",
    "abordemo": "abordar",
    "abordemos": "abordar",
    "abordes": "abordar",
    "abordo": "abordar",
    "abordoa": "abordoar",
    "abordoada": "abordoar",
    "abordoadas": "abordoar",
    "abordoado": "abordoar",
    "abordoados": "abordoar",
    "abordoai": "abordoar",
    "abordoais": "abordoar",
    "abordoam": "abordoar",
    "abordoamo": "abordoar",
    "abordoamos": "abordoar",
    "abordoando": "abordoar",
    "abordoara": "abordoar",
    "abordoaram": "abordoar",
    "abordoaras": "abordoar",
    "abordoarde": "abordoar",
    "abordoardes": "abordoar",
    "abordoare": "abordoar",
    "abordoarei": "abordoar",
    "abordoareis": "abordoar",
    "abordoarem": "abordoar",
    "abordoaremos": "abordoar",
    "abordoares": "abordoar",
    "abordoaria": "abordoar",
    "abordoariam": "abordoar",
    "abordoarias": "abordoar",
    "abordoarmo": "abordoar",
    "abordoarmos": "abordoar",
    "abordoará": "abordoar",
    "abordoarás": "abordoar",
    "abordoarão": "abordoar",
    "abordoaríamos": "abordoar",
    "abordoaríeis": "abordoar",
    "abordoas": "abordoar",
    "abordoasse": "abordoar",
    "abordoassem": "abordoar",
    "abordoasses": "abordoar",
    "abordoaste": "abordoar",
    "abordoastes": "abordoar",
    "abordoava": "abordoar",
    "abordoavam": "abordoar",
    "abordoavas": "abordoar",
    "abordoe": "abordoar",
    "abordoei": "abordoar",
    "abordoeis": "abordoar",
    "abordoem": "abordoar",
    "abordoemo": "abordoar",
    "abordoemos": "abordoar",
    "abordoes": "abordoar",
    "abordoo": "abordoar",
    "abordoou": "abordoar",
    "abordos": "abordo",
    "abordou": "abordar",
    "abordoá": "abordoar",
    "abordoámo": "abordoar",
    "abordoámos": "abordoar",
    "abordoáramo": "abordoar",
    "abordoáramos": "abordoar",
    "abordoárei": "abordoar",
    "abordoáreis": "abordoar",
    "abordoásseis": "abordoar",
    "abordoássemos": "abordoar",
    "abordoávamo": "abordoar",
    "abordoávamos": "abordoar",
    "abordoávei": "abordoar",
    "abordoáveis": "abordoar",
    "abordá": "abordar",
    "abordámo": "abordar",
    "abordámos": "abordar",
    "abordáramo": "abordar",
    "abordáramos": "abordar",
    "abordárei": "abordar",
    "abordáreis": "abordar",
    "abordásseis": "abordar",
    "abordássemos": "abordar",
    "abordávamo": "abordar",
    "abordávamos": "abordar",
    "abordávei": "abordar",
    "abordáveis": "abordável",
    "abornala": "abornalar",
    "abornalada": "abornalar",
    "abornaladas": "abornalar",
    "abornalado": "abornalar",
    "abornalados": "abornalar",
    "abornalai": "abornalar",
    "abornalais": "abornalar",
    "abornalam": "abornalar",
    "abornalamo": "abornalar",
    "abornalamos": "abornalar",
    "abornalando": "abornalar",
    "abornalara": "abornalar",
    "abornalaram": "abornalar",
    "abornalaras": "abornalar",
    "abornalarde": "abornalar",
    "abornalardes": "abornalar",
    "abornalare": "abornalar",
    "abornalarei": "abornalar",
    "abornalareis": "abornalar",
    "abornalarem": "abornalar",
    "abornalaremos": "abornalar",
    "abornalares": "abornalar",
    "abornalaria": "abornalar",
    "abornalariam": "abornalar",
    "abornalarias": "abornalar",
    "abornalarmo": "abornalar",
    "abornalarmos": "abornalar",
    "abornalará": "abornalar",
    "abornalarás": "abornalar",
    "abornalarão": "abornalar",
    "abornalaríamos": "abornalar",
    "abornalaríeis": "abornalar",
    "abornalas": "abornalar",
    "abornalasse": "abornalar",
    "abornalassem": "abornalar",
    "abornalasses": "abornalar",
    "abornalaste": "abornalar",
    "abornalastes": "abornalar",
    "abornalava": "abornalar",
    "abornalavam": "abornalar",
    "abornalavas": "abornalar",
    "abornale": "abornalar",
    "abornalei": "abornalar",
    "abornaleis": "abornalar",
    "abornalem": "abornalar",
    "abornalemo": "abornalar",
    "abornalemos": "abornalar",
    "abornales": "abornalar",
    "abornalo": "abornalar",
    "abornalou": "abornalar",
    "abornalá": "abornalar",
    "abornalámo": "abornalar",
    "abornalámos": "abornalar",
    "abornaláramo": "abornalar",
    "abornaláramos": "abornalar",
    "abornalárei": "abornalar",
    "abornaláreis": "abornalar",
    "abornalásseis": "abornalar",
    "abornalássemos": "abornalar",
    "abornalávamo": "abornalar",
    "abornalávamos": "abornalar",
    "abornalávei": "abornalar",
    "abornaláveis": "abornalar",
    "aborrasca": "aborrascar",
    "aborrascada": "aborrascar",
    "aborrascadas": "aborrascar",
    "aborrascado": "aborrascar",
    "aborrascados": "aborrascar",
    "aborrascai": "aborrascar",
    "aborrascais": "aborrascar",
    "aborrascam": "aborrascar",
    "aborrascamo": "aborrascar",
    "aborrascamos": "aborrascar",
    "aborrascando": "aborrascar",
    "aborrascara": "aborrascar",
    "aborrascaram": "aborrascar",
    "aborrascaras": "aborrascar",
    "aborrascarde": "aborrascar",
    "aborrascardes": "aborrascar",
    "aborrascare": "aborrascar",
    "aborrascarei": "aborrascar",
    "aborrascareis": "aborrascar",
    "aborrascarem": "aborrascar",
    "aborrascaremos": "aborrascar",
    "aborrascares": "aborrascar",
    "aborrascaria": "aborrascar",
    "aborrascariam": "aborrascar",
    "aborrascarias": "aborrascar",
    "aborrascarmo": "aborrascar",
    "aborrascarmos": "aborrascar",
    "aborrascará": "aborrascar",
    "aborrascarás": "aborrascar",
    "aborrascarão": "aborrascar",
    "aborrascaríamos": "aborrascar",
    "aborrascaríeis": "aborrascar",
    "aborrascas": "aborrascar",
    "aborrascasse": "aborrascar",
    "aborrascassem": "aborrascar",
    "aborrascasses": "aborrascar",
    "aborrascaste": "aborrascar",
    "aborrascastes": "aborrascar",
    "aborrascava": "aborrascar",
    "aborrascavam": "aborrascar",
    "aborrascavas": "aborrascar",
    "aborrasco": "aborrascar",
    "aborrascou": "aborrascar",
    "aborrascá": "aborrascar",
    "aborrascámo": "aborrascar",
    "aborrascámos": "aborrascar",
    "aborrascáramo": "aborrascar",
    "aborrascáramos": "aborrascar",
    "aborrascárei": "aborrascar",
    "aborrascáreis": "aborrascar",
    "aborrascásseis": "aborrascar",
    "aborrascássemos": "aborrascar",
    "aborrascávamo": "aborrascar",
    "aborrascávamos": "aborrascar",
    "aborrascávei": "aborrascar",
    "aborrascáveis": "aborrascar",
    "aborrasque": "aborrascar",
    "aborrasquei": "aborrascar",
    "aborrasqueis": "aborrascar",
    "aborrasquem": "aborrascar",
    "aborrasquemo": "aborrascar",
    "aborrasquemos": "aborrascar",
    "aborrasques": "aborrascar",
    "aborrece": "aborrecer",
    "aborrecedora": "aborrecedor",
    "aborrecedoras": "aborrecedor",
    "aborrecedores": "aborrecedor",
    "aborrecei": "aborrecer",
    "aborreceis": "aborrecer",
    "aborrecem": "aborrecer",
    "aborrecemo": "aborrecer",
    "aborrecemos": "aborrecer",
    "aborrecendo": "aborrecer",
    "aborrecera": "aborrecer",
    "aborreceram": "aborrecer",
    "aborreceras": "aborrecer",
    "aborrecerde": "aborrecer",
    "aborrecerdes": "aborrecer",
    "aborrecere": "aborrecer",
    "aborrecerei": "aborrecer",
    "aborrecereis": "aborrecer",
    "aborrecerem": "aborrecer",
    "aborreceremos": "aborrecer",
    "aborreceres": "aborrecer",
    "aborreceria": "aborrecer",
    "aborreceriam": "aborrecer",
    "aborrecerias": "aborrecer",
    "aborrecermo": "aborrecer",
    "aborrecermos": "aborrecer",
    "aborrecerá": "aborrecer",
    "aborrecerás": "aborrecer",
    "aborrecerão": "aborrecer",
    "aborreceríamos": "aborrecer",
    "aborreceríeis": "aborrecer",
    "aborreces": "aborrecer",
    "aborrecesse": "aborrecer",
    "aborrecessem": "aborrecer",
    "aborrecesses": "aborrecer",
    "aborreceste": "aborrecer",
    "aborrecestes": "aborrecer",
    "aborreceu": "aborrecer",
    "aborreci": "aborrecer",
    "aborrecia": "aborrecer",
    "aborreciam": "aborrecer",
    "aborrecias": "aborrecer",
    "aborrecida": "aborrecido",
    "aborrecidas": "aborrecido",
    "aborrecido": "aborrecer",
    "aborrecidos": "aborrecido",
    "aborrecidíssima": "aborrecido",
    "aborrecidíssimas": "aborrecido",
    "aborrecidíssimo": "aborrecido",
    "aborrecidíssimos": "aborrecido",
    "aborrecimentos": "aborrecimento",
    "aborrecê": "aborrecer",
    "aborrecêramo": "aborrecer",
    "aborrecêramos": "aborrecer",
    "aborrecêrei": "aborrecer",
    "aborrecêreis": "aborrecer",
    "aborrecêsseis": "aborrecer",
    "aborrecêssemos": "aborrecer",
    "aborrecíamo": "aborrecer",
    "aborrecíamos": "aborrecer",
    "aborrecíei": "aborrecer",
    "aborrecíeis": "aborrecer",
    "aborrecíveis": "aborrecível",
    "aborrega": "aborregar",
    "aborregada": "aborregar",
    "aborregadas": "aborregar",
    "aborregado": "aborregar",
    "aborregados": "aborregar",
    "aborregai": "aborregar",
    "aborregais": "aborregar",
    "aborregam": "aborregar",
    "aborregamo": "aborregar",
    "aborregamos": "aborregar",
    "aborregando": "aborregar",
    "aborregara": "aborregar",
    "aborregaram": "aborregar",
    "aborregaras": "aborregar",
    "aborregarde": "aborregar",
    "aborregardes": "aborregar",
    "aborregare": "aborregar",
    "aborregarei": "aborregar",
    "aborregareis": "aborregar",
    "aborregarem": "aborregar",
    "aborregaremos": "aborregar",
    "aborregares": "aborregar",
    "aborregaria": "aborregar",
    "aborregariam": "aborregar",
    "aborregarias": "aborregar",
    "aborregarmo": "aborregar",
    "aborregarmos": "aborregar",
    "aborregará": "aborregar",
    "aborregarás": "aborregar",
    "aborregarão": "aborregar",
    "aborregaríamos": "aborregar",
    "aborregaríeis": "aborregar",
    "aborregas": "aborregar",
    "aborregasse": "aborregar",
    "aborregassem": "aborregar",
    "aborregasses": "aborregar",
    "aborregaste": "aborregar",
    "aborregastes": "aborregar",
    "aborregava": "aborregar",
    "aborregavam": "aborregar",
    "aborregavas": "aborregar",
    "aborrego": "aborregar",
    "aborregou": "aborregar",
    "aborregue": "aborregar",
    "aborreguei": "aborregar",
    "aborregueis": "aborregar",
    "aborreguem": "aborregar",
    "aborreguemo": "aborregar",
    "aborreguemos": "aborregar",
    "aborregues": "aborregar",
    "aborregá": "aborregar",
    "aborregámo": "aborregar",
    "aborregámos": "aborregar",
    "aborregáramo": "aborregar",
    "aborregáramos": "aborregar",
    "aborregárei": "aborregar",
    "aborregáreis": "aborregar",
    "aborregásseis": "aborregar",
    "aborregássemos": "aborregar",
    "aborregávamo": "aborregar",
    "aborregávamos": "aborregar",
    "aborregávei": "aborregar",
    "aborregáveis": "aborregar",
    "aborreça": "aborrecer",
    "aborreçais": "aborrecer",
    "aborreçam": "aborrecer",
    "aborreçamo": "aborrecer",
    "aborreçamos": "aborrecer",
    "aborreças": "aborrecer",
    "aborreço": "aborrecer",
    "aborrida": "aborrido",
    "aborridas": "aborrido",
    "aborridos": "aborrido",
    "aborrimentos": "aborrimento",
    "aborta": "abortar",
    "abortada": "abortar",
    "abortadas": "abortar",
    "abortadeira": "abortador",
    "abortadeiras": "abortador",
    "abortado": "abortar",
    "abortadora": "abortador",
    "abortadoras": "abortador",
    "abortadores": "abortador",
    "abortados": "abortar",
    "abortai": "abortar",
    "abortais": "abortar",
    "abortam": "abortar",
    "abortamentos": "abortamento",
    "abortamo": "abortar",
    "abortamos": "abortar",
    "abortando": "abortar",
    "abortara": "abortar",
    "abortaram": "abortar",
    "abortaras": "abortar",
    "abortardes": "abortar",
    "abortarei": "abortar",
    "abortareis": "abortar",
    "abortarem": "abortar",
    "abortaremos": "abortar",
    "abortares": "abortar",
    "abortaria": "abortar",
    "abortariam": "abortar",
    "abortarias": "abortar",
    "abortarmo": "abortar",
    "abortarmos": "abortar",
    "abortará": "abortar",
    "abortarás": "abortar",
    "abortarão": "abortar",
    "abortaríamos": "abortar",
    "abortaríeis": "abortar",
    "abortas": "abortar",
    "abortasse": "abortar",
    "abortassem": "abortar",
    "abortasses": "abortar",
    "abortaste": "abortar",
    "abortastes": "abortar",
    "abortava": "abortar",
    "abortavam": "abortar",
    "abortavas": "abortar",
    "aborte": "abortar",
    "abortei": "abortar",
    "aborteira": "aborteiro",
    "aborteiras": "aborteiro",
    "aborteiros": "aborteiro",
    "aborteis": "abortar",
    "abortem": "abortar",
    "abortemo": "abortar",
    "abortemos": "abortar",
    "abortes": "abortar",
    "abortiva": "abortivo",
    "abortivas": "abortivo",
    "abortivos": "abortivo",
    "aborto": "abortar",
    "abortos": "aborto",
    "abortou": "abortar",
    "abortámo": "abortar",
    "abortámos": "abortar",
    "abortáramo": "abortar",
    "abortáramos": "abortar",
    "abortáreis": "abortar",
    "abortásseis": "abortar",
    "abortássemos": "abortar",
    "abortávamo": "abortar",
    "abortávamos": "abortar",
    "abortáveis": "abortar",
    "abortícia": "abortício",
    "abortícias": "abortício",
    "abortícios": "abortício",
    "aborígenes": "aborígene",
    "abostela": "abostelar",
    "abostelada": "abostelar",
    "abosteladas": "abostelar",
    "abostelado": "abostelar",
    "abostelados": "abostelar",
    "abostelai": "abostelar",
    "abostelais": "abostelar",
    "abostelam": "abostelar",
    "abostelamo": "abostelar",
    "abostelamos": "abostelar",
    "abostelando": "abostelar",
    "abostelara": "abostelar",
    "abostelaram": "abostelar",
    "abostelaras": "abostelar",
    "abostelardes": "abostelar",
    "abostelarei": "abostelar",
    "abostelareis": "abostelar",
    "abostelarem": "abostelar",
    "abostelaremos": "abostelar",
    "abostelares": "abostelar",
    "abostelaria": "abostelar",
    "abostelariam": "abostelar",
    "abostelarias": "abostelar",
    "abostelarmo": "abostelar",
    "abostelarmos": "abostelar",
    "abostelará": "abostelar",
    "abostelarás": "abostelar",
    "abostelarão": "abostelar",
    "abostelaríamos": "abostelar",
    "abostelaríeis": "abostelar",
    "abostelas": "abostelar",
    "abostelasse": "abostelar",
    "abostelassem": "abostelar",
    "abostelasses": "abostelar",
    "abostelaste": "abostelar",
    "abostelastes": "abostelar",
    "abostelava": "abostelar",
    "abostelavam": "abostelar",
    "abostelavas": "abostelar",
    "abostele": "abostelar",
    "abostelei": "abostelar",
    "abosteleis": "abostelar",
    "abostelem": "abostelar",
    "abostelemo": "abostelar",
    "abostelemos": "abostelar",
    "abosteles": "abostelar",
    "abostelo": "abostelar",
    "abostelou": "abostelar",
    "abostelámo": "abostelar",
    "abostelámos": "abostelar",
    "abosteláramo": "abostelar",
    "abosteláramos": "abostelar",
    "abosteláreis": "abostelar",
    "abostelásseis": "abostelar",
    "abostelássemos": "abostelar",
    "abostelávamo": "abostelar",
    "abostelávamos": "abostelar",
    "abosteláveis": "abostelar",
    "abotequina": "abotequinar",
    "abotequinada": "abotequinar",
    "abotequinadas": "abotequinar",
    "abotequinado": "abotequinar",
    "abotequinados": "abotequinar",
    "abotequinai": "abotequinar",
    "abotequinais": "abotequinar",
    "abotequinam": "abotequinar",
    "abotequinamo": "abotequinar",
    "abotequinamos": "abotequinar",
    "abotequinando": "abotequinar",
    "abotequinara": "abotequinar",
    "abotequinaram": "abotequinar",
    "abotequinaras": "abotequinar",
    "abotequinarde": "abotequinar",
    "abotequinardes": "abotequinar",
    "abotequinare": "abotequinar",
    "abotequinarei": "abotequinar",
    "abotequinareis": "abotequinar",
    "abotequinarem": "abotequinar",
    "abotequinaremos": "abotequinar",
    "abotequinares": "abotequinar",
    "abotequinaria": "abotequinar",
    "abotequinariam": "abotequinar",
    "abotequinarias": "abotequinar",
    "abotequinarmo": "abotequinar",
    "abotequinarmos": "abotequinar",
    "abotequinará": "abotequinar",
    "abotequinarás": "abotequinar",
    "abotequinarão": "abotequinar",
    "abotequinaríamos": "abotequinar",
    "abotequinaríeis": "abotequinar",
    "abotequinas": "abotequinar",
    "abotequinasse": "abotequinar",
    "abotequinassem": "abotequinar",
    "abotequinasses": "abotequinar",
    "abotequinaste": "abotequinar",
    "abotequinastes": "abotequinar",
    "abotequinava": "abotequinar",
    "abotequinavam": "abotequinar",
    "abotequinavas": "abotequinar",
    "abotequine": "abotequinar",
    "abotequinei": "abotequinar",
    "abotequineis": "abotequinar",
    "abotequinem": "abotequinar",
    "abotequinemo": "abotequinar",
    "abotequinemos": "abotequinar",
    "abotequines": "abotequinar",
    "abotequino": "abotequinar",
    "abotequinou": "abotequinar",
    "abotequiná": "abotequinar",
    "abotequinámo": "abotequinar",
    "abotequinámos": "abotequinar",
    "abotequináramo": "abotequinar",
    "abotequináramos": "abotequinar",
    "abotequinárei": "abotequinar",
    "abotequináreis": "abotequinar",
    "abotequinásseis": "abotequinar",
    "abotequinássemos": "abotequinar",
    "abotequinávamo": "abotequinar",
    "abotequinávamos": "abotequinar",
    "abotequinávei": "abotequinar",
    "abotequináveis": "abotequinar",
    "abotija": "abotijar",
    "abotijada": "abotijar",
    "abotijadas": "abotijar",
    "abotijado": "abotijar",
    "abotijados": "abotijar",
    "abotijai": "abotijar",
    "abotijais": "abotijar",
    "abotijam": "abotijar",
    "abotijamo": "abotijar",
    "abotijamos": "abotijar",
    "abotijando": "abotijar",
    "abotijara": "abotijar",
    "abotijaram": "abotijar",
    "abotijaras": "abotijar",
    "abotijarde": "abotijar",
    "abotijardes": "abotijar",
    "abotijare": "abotijar",
    "abotijarei": "abotijar",
    "abotijareis": "abotijar",
    "abotijarem": "abotijar",
    "abotijaremos": "abotijar",
    "abotijares": "abotijar",
    "abotijaria": "abotijar",
    "abotijariam": "abotijar",
    "abotijarias": "abotijar",
    "abotijarmo": "abotijar",
    "abotijarmos": "abotijar",
    "abotijará": "abotijar",
    "abotijarás": "abotijar",
    "abotijarão": "abotijar",
    "abotijaríamos": "abotijar",
    "abotijaríeis": "abotijar",
    "abotijas": "abotijar",
    "abotijasse": "abotijar",
    "abotijassem": "abotijar",
    "abotijasses": "abotijar",
    "abotijaste": "abotijar",
    "abotijastes": "abotijar",
    "abotijava": "abotijar",
    "abotijavam": "abotijar",
    "abotijavas": "abotijar",
    "abotije": "abotijar",
    "abotijei": "abotijar",
    "abotijeis": "abotijar",
    "abotijem": "abotijar",
    "abotijemo": "abotijar",
    "abotijemos": "abotijar",
    "abotijes": "abotijar",
    "abotijo": "abotijar",
    "abotijou": "abotijar",
    "abotijá": "abotijar",
    "abotijámo": "abotijar",
    "abotijámos": "abotijar",
    "abotijáramo": "abotijar",
    "abotijáramos": "abotijar",
    "abotijárei": "abotijar",
    "abotijáreis": "abotijar",
    "abotijásseis": "abotijar",
    "abotijássemos": "abotijar",
    "abotijávamo": "abotijar",
    "abotijávamos": "abotijar",
    "abotijávei": "abotijar",
    "abotijáveis": "abotijar",
    "abotina": "abotinar",
    "abotinada": "abotinar",
    "abotinadas": "abotinar",
    "abotinado": "abotinar",
    "abotinados": "abotinar",
    "abotinai": "abotinar",
    "abotinais": "abotinar",
    "abotinam": "abotinar",
    "abotinamo": "abotinar",
    "abotinamos": "abotinar",
    "abotinando": "abotinar",
    "abotinara": "abotinar",
    "abotinaram": "abotinar",
    "abotinaras": "abotinar",
    "abotinarde": "abotinar",
    "abotinardes": "abotinar",
    "abotinare": "abotinar",
    "abotinarei": "abotinar",
    "abotinareis": "abotinar",
    "abotinarem": "abotinar",
    "abotinaremos": "abotinar",
    "abotinares": "abotinar",
    "abotinaria": "abotinar",
    "abotinariam": "abotinar",
    "abotinarias": "abotinar",
    "abotinarmo": "abotinar",
    "abotinarmos": "abotinar",
    "abotinará": "abotinar",
    "abotinarás": "abotinar",
    "abotinarão": "abotinar",
    "abotinaríamos": "abotinar",
    "abotinaríeis": "abotinar",
    "abotinas": "abotinar",
    "abotinasse": "abotinar",
    "abotinassem": "abotinar",
    "abotinasses": "abotinar",
    "abotinaste": "abotinar",
    "abotinastes": "abotinar",
    "abotinava": "abotinar",
    "abotinavam": "abotinar",
    "abotinavas": "abotinar",
    "abotine": "abotinar",
    "abotinei": "abotinar",
    "abotineis": "abotinar",
    "abotinem": "abotinar",
    "abotinemo": "abotinar",
    "abotinemos": "abotinar",
    "abotines": "abotinar",
    "abotino": "abotinar",
    "abotinou": "abotinar",
    "abotiná": "abotinar",
    "abotinámo": "abotinar",
    "abotinámos": "abotinar",
    "abotináramo": "abotinar",
    "abotináramos": "abotinar",
    "abotinárei": "abotinar",
    "abotináreis": "abotinar",
    "abotinásseis": "abotinar",
    "abotinássemos": "abotinar",
    "abotinávamo": "abotinar",
    "abotinávamos": "abotinar",
    "abotinávei": "abotinar",
    "abotináveis": "abotinar",
    "abotoa": "abotoar",
    "abotoada": "abotoar",
    "abotoadas": "abotoar",
    "abotoadeira": "abotoador",
    "abotoadeiras": "abotoador",
    "abotoado": "abotoar",
    "abotoadora": "abotoador",
    "abotoadoras": "abotoador",
    "abotoadores": "abotoador",
    "abotoados": "abotoar",
    "abotoaduras": "abotoadura",
    "abotoai": "abotoar",
    "abotoais": "abotoar",
    "abotoam": "abotoar",
    "abotoamo": "abotoar",
    "abotoamos": "abotoar",
    "abotoando": "abotoar",
    "abotoara": "abotoar",
    "abotoaram": "abotoar",
    "abotoaras": "abotoar",
    "abotoarde": "abotoar",
    "abotoardes": "abotoar",
    "abotoare": "abotoar",
    "abotoarei": "abotoar",
    "abotoareis": "abotoar",
    "abotoarem": "abotoar",
    "abotoaremos": "abotoar",
    "abotoares": "abotoar",
    "abotoaria": "abotoar",
    "abotoariam": "abotoar",
    "abotoarias": "abotoar",
    "abotoarmo": "abotoar",
    "abotoarmos": "abotoar",
    "abotoará": "abotoar",
    "abotoarás": "abotoar",
    "abotoarão": "abotoar",
    "abotoaríamos": "abotoar",
    "abotoaríeis": "abotoar",
    "abotoas": "abotoar",
    "abotoasse": "abotoar",
    "abotoassem": "abotoar",
    "abotoasses": "abotoar",
    "abotoaste": "abotoar",
    "abotoastes": "abotoar",
    "abotoava": "abotoar",
    "abotoavam": "abotoar",
    "abotoavas": "abotoar",
    "abotoações": "abotoação",
    "abotoe": "abotoar",
    "abotoei": "abotoar",
    "abotoeis": "abotoar",
    "abotoem": "abotoar",
    "abotoemo": "abotoar",
    "abotoemos": "abotoar",
    "abotoes": "abotoar",
    "abotoo": "abotoar",
    "abotoou": "abotoar",
    "abotoá": "abotoar",
    "abotoámo": "abotoar",
    "abotoámos": "abotoar",
    "abotoáramo": "abotoar",
    "abotoáramos": "abotoar",
    "abotoárei": "abotoar",
    "abotoáreis": "abotoar",
    "abotoásseis": "abotoar",
    "abotoássemos": "abotoar",
    "abotoávamo": "abotoar",
    "abotoávamos": "abotoar",
    "abotoávei": "abotoar",
    "abotoáveis": "abotoar",
    "abou": "abar",
    "abouba": "aboubar",
    "aboubada": "aboubar",
    "aboubadas": "aboubar",
    "aboubado": "aboubar",
    "aboubados": "aboubar",
    "aboubai": "aboubar",
    "aboubais": "aboubar",
    "aboubam": "aboubar",
    "aboubamo": "aboubar",
    "aboubamos": "aboubar",
    "aboubando": "aboubar",
    "aboubara": "aboubar",
    "aboubaram": "aboubar",
    "aboubaras": "aboubar",
    "aboubarde": "aboubar",
    "aboubardes": "aboubar",
    "aboubare": "aboubar",
    "aboubarei": "aboubar",
    "aboubareis": "aboubar",
    "aboubarem": "aboubar",
    "aboubaremos": "aboubar",
    "aboubares": "aboubar",
    "aboubaria": "aboubar",
    "aboubariam": "aboubar",
    "aboubarias": "aboubar",
    "aboubarmo": "aboubar",
    "aboubarmos": "aboubar",
    "aboubará": "aboubar",
    "aboubarás": "aboubar",
    "aboubarão": "aboubar",
    "aboubaríamos": "aboubar",
    "aboubaríeis": "aboubar",
    "aboubas": "aboubar",
    "aboubasse": "aboubar",
    "aboubassem": "aboubar",
    "aboubasses": "aboubar",
    "aboubaste": "aboubar",
    "aboubastes": "aboubar",
    "aboubava": "aboubar",
    "aboubavam": "aboubar",
    "aboubavas": "aboubar",
    "aboube": "aboubar",
    "aboubei": "aboubar",
    "aboubeis": "aboubar",
    "aboubem": "aboubar",
    "aboubemo": "aboubar",
    "aboubemos": "aboubar",
    "aboubes": "aboubar",
    "aboubo": "aboubar",
    "aboubou": "aboubar",
    "aboubá": "aboubar",
    "aboubámo": "aboubar",
    "aboubámos": "aboubar",
    "aboubáramo": "aboubar",
    "aboubáramos": "aboubar",
    "aboubárei": "aboubar",
    "aboubáreis": "aboubar",
    "aboubásseis": "aboubar",
    "aboubássemos": "aboubar",
    "aboubávamo": "aboubar",
    "aboubávamos": "aboubar",
    "aboubávei": "aboubar",
    "aboubáveis": "aboubar",
    "abovina": "abovinar",
    "abovinada": "abovinar",
    "abovinadas": "abovinar",
    "abovinado": "abovinar",
    "abovinados": "abovinar",
    "abovinai": "abovinar",
    "abovinais": "abovinar",
    "abovinam": "abovinar",
    "abovinamo": "abovinar",
    "abovinamos": "abovinar",
    "abovinando": "abovinar",
    "abovinara": "abovinar",
    "abovinaram": "abovinar",
    "abovinaras": "abovinar",
    "abovinarde": "abovinar",
    "abovinardes": "abovinar",
    "abovinare": "abovinar",
    "abovinarei": "abovinar",
    "abovinareis": "abovinar",
    "abovinarem": "abovinar",
    "abovinaremos": "abovinar",
    "abovinares": "abovinar",
    "abovinaria": "abovinar",
    "abovinariam": "abovinar",
    "abovinarias": "abovinar",
    "abovinarmo": "abovinar",
    "abovinarmos": "abovinar",
    "abovinará": "abovinar",
    "abovinarás": "abovinar",
    "abovinarão": "abovinar",
    "abovinaríamos": "abovinar",
    "abovinaríeis": "abovinar",
    "abovinas": "abovinar",
    "abovinasse": "abovinar",
    "abovinassem": "abovinar",
    "abovinasses": "abovinar",
    "abovinaste": "abovinar",
    "abovinastes": "abovinar",
    "abovinava": "abovinar",
    "abovinavam": "abovinar",
    "abovinavas": "abovinar",
    "abovine": "abovinar",
    "abovinei": "abovinar",
    "abovineis": "abovinar",
    "abovinem": "abovinar",
    "abovinemo": "abovinar",
    "abovinemos": "abovinar",
    "abovines": "abovinar",
    "abovino": "abovinar",
    "abovinou": "abovinar",
    "aboviná": "abovinar",
    "abovinámo": "abovinar",
    "abovinámos": "abovinar",
    "abovináramo": "abovinar",
    "abovináramos": "abovinar",
    "abovinárei": "abovinar",
    "abovináreis": "abovinar",
    "abovinásseis": "abovinar",
    "abovinássemos": "abovinar",
    "abovinávamo": "abovinar",
    "abovinávamos": "abovinar",
    "abovinávei": "abovinar",
    "abovináveis": "abovinar",
    "aboámo": "aboar",
    "aboámos": "aboar",
    "aboáramo": "aboar",
    "aboáramos": "aboar",
    "aboáreis": "aboar",
    "aboásseis": "aboar",
    "aboássemos": "aboar",
    "aboávamo": "aboar",
    "aboávamos": "aboar",
    "aboáveis": "aboar",
    "aboça": "aboçar",
    "aboçada": "aboçar",
    "aboçadas": "aboçar",
    "aboçado": "aboçar",
    "aboçados": "aboçar",
    "aboçaduras": "aboçadura",
    "aboçai": "aboçar",
    "aboçais": "aboçar",
    "aboçam": "aboçar",
    "aboçamentos": "aboçamento",
    "aboçamo": "aboçar",
    "aboçamos": "aboçar",
    "aboçando": "aboçar",
    "aboçara": "aboçar",
    "aboçaram": "aboçar",
    "aboçaras": "aboçar",
    "aboçarde": "aboçar",
    "aboçardes": "aboçar",
    "aboçare": "aboçar",
    "aboçarei": "aboçar",
    "aboçareis": "aboçar",
    "aboçarem": "aboçar",
    "aboçaremos": "aboçar",
    "aboçares": "aboçar",
    "aboçaria": "aboçar",
    "aboçariam": "aboçar",
    "aboçarias": "aboçar",
    "aboçarmo": "aboçar",
    "aboçarmos": "aboçar",
    "aboçará": "aboçar",
    "aboçarás": "aboçar",
    "aboçarão": "aboçar",
    "aboçaríamos": "aboçar",
    "aboçaríeis": "aboçar",
    "aboças": "aboçar",
    "aboçasse": "aboçar",
    "aboçassem": "aboçar",
    "aboçasses": "aboçar",
    "aboçaste": "aboçar",
    "aboçastes": "aboçar",
    "aboçava": "aboçar",
    "aboçavam": "aboçar",
    "aboçavas": "aboçar",
    "aboço": "aboçar",
    "aboços": "aboço",
    "aboçou": "aboçar",
    "aboçá": "aboçar",
    "aboçámo": "aboçar",
    "aboçámos": "aboçar",
    "aboçáramo": "aboçar",
    "aboçáramos": "aboçar",
    "aboçárei": "aboçar",
    "aboçáreis": "aboçar",
    "aboçásseis": "aboçar",
    "aboçássemos": "aboçar",
    "aboçávamo": "aboçar",
    "aboçávamos": "aboçar",
    "aboçávei": "aboçar",
    "aboçáveis": "aboçar",
    "abra": "abrir",
    "abracadabrantes": "abracadabrante",
    "abracadabras": "abracadabra",
    "abracadabristas": "abracadabrista",
    "abrace": "abraçar",
    "abracei": "abraçar",
    "abraceis": "abraçar",
    "abracem": "abraçar",
    "abracemo": "abraçar",
    "abracemos": "abraçar",
    "abraces": "abraçar",
    "abracinho": "abraço",
    "abracinhos": "abraço",
    "abracito": "abraço",
    "abracitos": "abraço",
    "abrais": "abrir",
    "abram": "abrir",
    "abramo": "abrir",
    "abramos": "abrir",
    "abrancaçada": "abrancaçado",
    "abrancaçadas": "abrancaçado",
    "abrancaçados": "abrancaçado",
    "abranda": "abrandar",
    "abrandada": "abrandar",
    "abrandadas": "abrandar",
    "abrandado": "abrandar",
    "abrandados": "abrandar",
    "abrandai": "abrandar",
    "abrandais": "abrandar",
    "abrandam": "abrandar",
    "abrandamentos": "abrandamento",
    "abrandamo": "abrandar",
    "abrandamos": "abrandar",
    "abrandando": "abrandar",
    "abrandara": "abrandar",
    "abrandaram": "abrandar",
    "abrandaras": "abrandar",
    "abrandarde": "abrandar",
    "abrandardes": "abrandar",
    "abrandare": "abrandar",
    "abrandarei": "abrandar",
    "abrandareis": "abrandar",
    "abrandarem": "abrandar",
    "abrandaremos": "abrandar",
    "abrandares": "abrandar",
    "abrandaria": "abrandar",
    "abrandariam": "abrandar",
    "abrandarias": "abrandar",
    "abrandarmo": "abrandar",
    "abrandarmos": "abrandar",
    "abrandará": "abrandar",
    "abrandarás": "abrandar",
    "abrandarão": "abrandar",
    "abrandaríamos": "abrandar",
    "abrandaríeis": "abrandar",
    "abrandas": "abrandar",
    "abrandasse": "abrandar",
    "abrandassem": "abrandar",
    "abrandasses": "abrandar",
    "abrandaste": "abrandar",
    "abrandastes": "abrandar",
    "abrandava": "abrandar",
    "abrandavam": "abrandar",
    "abrandavas": "abrandar",
    "abrande": "abrandar",
    "abrandece": "abrandecer",
    "abrandecei": "abrandecer",
    "abrandeceis": "abrandecer",
    "abrandecem": "abrandecer",
    "abrandecemo": "abrandecer",
    "abrandecemos": "abrandecer",
    "abrandecendo": "abrandecer",
    "abrandecera": "abrandecer",
    "abrandeceram": "abrandecer",
    "abrandeceras": "abrandecer",
    "abrandecerde": "abrandecer",
    "abrandecerdes": "abrandecer",
    "abrandecere": "abrandecer",
    "abrandecerei": "abrandecer",
    "abrandecereis": "abrandecer",
    "abrandecerem": "abrandecer",
    "abrandeceremos": "abrandecer",
    "abrandeceres": "abrandecer",
    "abrandeceria": "abrandecer",
    "abrandeceriam": "abrandecer",
    "abrandecerias": "abrandecer",
    "abrandecermo": "abrandecer",
    "abrandecermos": "abrandecer",
    "abrandecerá": "abrandecer",
    "abrandecerás": "abrandecer",
    "abrandecerão": "abrandecer",
    "abrandeceríamos": "abrandecer",
    "abrandeceríeis": "abrandecer",
    "abrandeces": "abrandecer",
    "abrandecesse": "abrandecer",
    "abrandecessem": "abrandecer",
    "abrandecesses": "abrandecer",
    "abrandeceste": "abrandecer",
    "abrandecestes": "abrandecer",
    "abrandeceu": "abrandecer",
    "abrandeci": "abrandecer",
    "abrandecia": "abrandecer",
    "abrandeciam": "abrandecer",
    "abrandecias": "abrandecer",
    "abrandecida": "abrandecer",
    "abrandecidas": "abrandecer",
    "abrandecido": "abrandecer",
    "abrandecidos": "abrandecer",
    "abrandecê": "abrandecer",
    "abrandecêramo": "abrandecer",
    "abrandecêramos": "abrandecer",
    "abrandecêrei": "abrandecer",
    "abrandecêreis": "abrandecer",
    "abrandecêsseis": "abrandecer",
    "abrandecêssemos": "abrandecer",
    "abrandecíamo": "abrandecer",
    "abrandecíamos": "abrandecer",
    "abrandecíei": "abrandecer",
    "abrandecíeis": "abrandecer",
    "abrandei": "abrandar",
    "abrandeis": "abrandar",
    "abrandem": "abrandar",
    "abrandemo": "abrandar",
    "abrandemos": "abrandar",
    "abrandes": "abrandar",
    "abrandeça": "abrandecer",
    "abrandeçais": "abrandecer",
    "abrandeçam": "abrandecer",
    "abrandeçamo": "abrandecer",
    "abrandeçamos": "abrandecer",
    "abrandeças": "abrandecer",
    "abrandeço": "abrandecer",
    "abrando": "abrandar",
    "abrandou": "abrandar",
    "abrandá": "abrandar",
    "abrandámo": "abrandar",
    "abrandámos": "abrandar",
    "abrandáramo": "abrandar",
    "abrandáramos": "abrandar",
    "abrandárei": "abrandar",
    "abrandáreis": "abrandar",
    "abrandásseis": "abrandar",
    "abrandássemos": "abrandar",
    "abrandávamo": "abrandar",
    "abrandávamos": "abrandar",
    "abrandávei": "abrandar",
    "abrandáveis": "abrandável",
    "abrange": "abranger",
    "abrangei": "abranger",
    "abrangeis": "abranger",
    "abrangem": "abranger",
    "abrangemo": "abranger",
    "abrangemos": "abranger",
    "abrangendo": "abranger",
    "abrangentes": "abrangente",
    "abrangera": "abranger",
    "abrangeram": "abranger",
    "abrangeras": "abranger",
    "abrangerde": "abranger",
    "abrangerdes": "abranger",
    "abrangere": "abranger",
    "abrangerei": "abranger",
    "abrangereis": "abranger",
    "abrangerem": "abranger",
    "abrangeremos": "abranger",
    "abrangeres": "abranger",
    "abrangeria": "abranger",
    "abrangeriam": "abranger",
    "abrangerias": "abranger",
    "abrangermo": "abranger",
    "abrangermos": "abranger",
    "abrangerá": "abranger",
    "abrangerás": "abranger",
    "abrangerão": "abranger",
    "abrangeríamos": "abranger",
    "abrangeríeis": "abranger",
    "abranges": "abranger",
    "abrangesse": "abranger",
    "abrangessem": "abranger",
    "abrangesses": "abranger",
    "abrangeste": "abranger",
    "abrangestes": "abranger",
    "abrangeu": "abranger",
    "abrangi": "abranger",
    "abrangia": "abranger",
    "abrangiam": "abranger",
    "abrangias": "abranger",
    "abrangida": "abrangido",
    "abrangidas": "abrangido",
    "abrangido": "abranger",
    "abrangidos": "abrangido",
    "abrangê": "abranger",
    "abrangências": "abrangência",
    "abrangêramo": "abranger",
    "abrangêramos": "abranger",
    "abrangêrei": "abranger",
    "abrangêreis": "abranger",
    "abrangêsseis": "abranger",
    "abrangêssemos": "abranger",
    "abrangíamo": "abranger",
    "abrangíamos": "abranger",
    "abrangíei": "abranger",
    "abrangíeis": "abranger",
    "abrangíveis": "abrangível",
    "abranja": "abranger",
    "abranjais": "abranger",
    "abranjam": "abranger",
    "abranjamo": "abranger",
    "abranjamos": "abranger",
    "abranjas": "abranger",
    "abranjo": "abranger",
    "abrantinoa": "abrantinoo",
    "abrantinoas": "abrantinoo",
    "abrantinoos": "abrantinoo",
    "abraquias": "abraquia",
    "abras": "abrir",
    "abrasa": "abrasar",
    "abrasada": "abrasar",
    "abrasadas": "abrasar",
    "abrasado": "abrasar",
    "abrasadora": "abrasador",
    "abrasadoras": "abrasador",
    "abrasadores": "abrasador",
    "abrasados": "abrasar",
    "abrasadíssima": "abrasado",
    "abrasadíssimas": "abrasado",
    "abrasadíssimo": "abrasado",
    "abrasadíssimos": "abrasado",
    "abrasai": "abrasar",
    "abrasais": "abrasar",
    "abrasam": "abrasar",
    "abrasamentos": "abrasamento",
    "abrasamo": "abrasar",
    "abrasamos": "abrasar",
    "abrasando": "abrasar",
    "abrasantes": "abrasante",
    "abrasara": "abrasar",
    "abrasaram": "abrasar",
    "abrasaras": "abrasar",
    "abrasarde": "abrasar",
    "abrasardes": "abrasar",
    "abrasare": "abrasar",
    "abrasarei": "abrasar",
    "abrasareis": "abrasar",
    "abrasarem": "abrasar",
    "abrasaremos": "abrasar",
    "abrasares": "abrasar",
    "abrasaria": "abrasar",
    "abrasariam": "abrasar",
    "abrasarias": "abrasar",
    "abrasarmo": "abrasar",
    "abrasarmos": "abrasar",
    "abrasará": "abrasar",
    "abrasarás": "abrasar",
    "abrasarão": "abrasar",
    "abrasaríamos": "abrasar",
    "abrasaríeis": "abrasar",
    "abrasas": "abrasar",
    "abrasasse": "abrasar",
    "abrasassem": "abrasar",
    "abrasasses": "abrasar",
    "abrasaste": "abrasar",
    "abrasastes": "abrasar",
    "abrasava": "abrasar",
    "abrasavam": "abrasar",
    "abrasavas": "abrasar",
    "abrase": "abrasar",
    "abraseada": "abrasear",
    "abraseadas": "abrasear",
    "abraseado": "abrasear",
    "abraseados": "abrasear",
    "abraseai": "abrasear",
    "abraseais": "abrasear",
    "abraseamo": "abrasear",
    "abraseamos": "abrasear",
    "abraseando": "abrasear",
    "abraseara": "abrasear",
    "abrasearam": "abrasear",
    "abrasearas": "abrasear",
    "abrasearde": "abrasear",
    "abraseardes": "abrasear",
    "abraseare": "abrasear",
    "abrasearei": "abrasear",
    "abraseareis": "abrasear",
    "abrasearem": "abrasear",
    "abrasearemos": "abrasear",
    "abraseares": "abrasear",
    "abrasearia": "abrasear",
    "abraseariam": "abrasear",
    "abrasearias": "abrasear",
    "abrasearmo": "abrasear",
    "abrasearmos": "abrasear",
    "abraseará": "abrasear",
    "abrasearás": "abrasear",
    "abrasearão": "abrasear",
    "abrasearíamos": "abrasear",
    "abrasearíeis": "abrasear",
    "abraseasse": "abrasear",
    "abraseassem": "abrasear",
    "abraseasses": "abrasear",
    "abraseaste": "abrasear",
    "abraseastes": "abrasear",
    "abraseava": "abrasear",
    "abraseavam": "abrasear",
    "abraseavas": "abrasear",
    "abraseei": "abrasear",
    "abraseeis": "abrasear",
    "abraseemo": "abrasear",
    "abraseemos": "abrasear",
    "abrasei": "abrasar",
    "abraseia": "abrasear",
    "abraseiam": "abrasear",
    "abraseias": "abrasear",
    "abraseie": "abrasear",
    "abraseiem": "abrasear",
    "abraseies": "abrasear",
    "abraseio": "abrasear",
    "abraseis": "abrasar",
    "abrasem": "abrasar",
    "abrasemo": "abrasar",
    "abrasemos": "abrasar",
    "abraseou": "abrasear",
    "abrases": "abrasar",
    "abraseá": "abrasear",
    "abraseámo": "abrasear",
    "abraseámos": "abrasear",
    "abraseáramo": "abrasear",
    "abraseáramos": "abrasear",
    "abraseárei": "abrasear",
    "abraseáreis": "abrasear",
    "abraseásseis": "abrasear",
    "abraseássemos": "abrasear",
    "abraseávamo": "abrasear",
    "abraseávamos": "abrasear",
    "abraseávei": "abrasear",
    "abraseáveis": "abrasear",
    "abrasileira": "abrasileirar",
    "abrasileirada": "abrasileirar",
    "abrasileiradas": "abrasileirar",
    "abrasileirado": "abrasileirar",
    "abrasileirados": "abrasileirar",
    "abrasileirai": "abrasileirar",
    "abrasileirais": "abrasileirar",
    "abrasileiram": "abrasileirar",
    "abrasileiramentos": "abrasileiramento",
    "abrasileiramo": "abrasileirar",
    "abrasileiramos": "abrasileirar",
    "abrasileirando": "abrasileirar",
    "abrasileirara": "abrasileirar",
    "abrasileiraram": "abrasileirar",
    "abrasileiraras": "abrasileirar",
    "abrasileirarde": "abrasileirar",
    "abrasileirardes": "abrasileirar",
    "abrasileirare": "abrasileirar",
    "abrasileirarei": "abrasileirar",
    "abrasileirareis": "abrasileirar",
    "abrasileirarem": "abrasileirar",
    "abrasileiraremos": "abrasileirar",
    "abrasileirares": "abrasileirar",
    "abrasileiraria": "abrasileirar",
    "abrasileirariam": "abrasileirar",
    "abrasileirarias": "abrasileirar",
    "abrasileirarmo": "abrasileirar",
    "abrasileirarmos": "abrasileirar",
    "abrasileirará": "abrasileirar",
    "abrasileirarás": "abrasileirar",
    "abrasileirarão": "abrasileirar",
    "abrasileiraríamos": "abrasileirar",
    "abrasileiraríeis": "abrasileirar",
    "abrasileiras": "abrasileirar",
    "abrasileirasse": "abrasileirar",
    "abrasileirassem": "abrasileirar",
    "abrasileirasses": "abrasileirar",
    "abrasileiraste": "abrasileirar",
    "abrasileirastes": "abrasileirar",
    "abrasileirava": "abrasileirar",
    "abrasileiravam": "abrasileirar",
    "abrasileiravas": "abrasileirar",
    "abrasileire": "abrasileirar",
    "abrasileirei": "abrasileirar",
    "abrasileireis": "abrasileirar",
    "abrasileirem": "abrasileirar",
    "abrasileiremo": "abrasileirar",
    "abrasileiremos": "abrasileirar",
    "abrasileires": "abrasileirar",
    "abrasileiro": "abrasileirar",
    "abrasileirou": "abrasileirar",
    "abrasileirá": "abrasileirar",
    "abrasileirámo": "abrasileirar",
    "abrasileirámos": "abrasileirar",
    "abrasileiráramo": "abrasileirar",
    "abrasileiráramos": "abrasileirar",
    "abrasileirárei": "abrasileirar",
    "abrasileiráreis": "abrasileirar",
    "abrasileirásseis": "abrasileirar",
    "abrasileirássemos": "abrasileirar",
    "abrasileirávamo": "abrasileirar",
    "abrasileirávamos": "abrasileirar",
    "abrasileirávei": "abrasileirar",
    "abrasileiráveis": "abrasileirável",
    "abrasiva": "abrasivo",
    "abrasivas": "abrasivo",
    "abrasivos": "abrasivo",
    "abraso": "abrasar",
    "abrasoa": "abrasoar",
    "abrasoada": "abrasoar",
    "abrasoadas": "abrasoar",
    "abrasoado": "abrasoar",
    "abrasoados": "abrasoar",
    "abrasoai": "abrasoar",
    "abrasoais": "abrasoar",
    "abrasoam": "abrasoar",
    "abrasoamo": "abrasoar",
    "abrasoamos": "abrasoar",
    "abrasoando": "abrasoar",
    "abrasoara": "abrasoar",
    "abrasoaram": "abrasoar",
    "abrasoaras": "abrasoar",
    "abrasoarde": "abrasoar",
    "abrasoardes": "abrasoar",
    "abrasoare": "abrasoar",
    "abrasoarei": "abrasoar",
    "abrasoareis": "abrasoar",
    "abrasoarem": "abrasoar",
    "abrasoaremos": "abrasoar",
    "abrasoares": "abrasoar",
    "abrasoaria": "abrasoar",
    "abrasoariam": "abrasoar",
    "abrasoarias": "abrasoar",
    "abrasoarmo": "abrasoar",
    "abrasoarmos": "abrasoar",
    "abrasoará": "abrasoar",
    "abrasoarás": "abrasoar",
    "abrasoarão": "abrasoar",
    "abrasoaríamos": "abrasoar",
    "abrasoaríeis": "abrasoar",
    "abrasoas": "abrasoar",
    "abrasoasse": "abrasoar",
    "abrasoassem": "abrasoar",
    "abrasoasses": "abrasoar",
    "abrasoaste": "abrasoar",
    "abrasoastes": "abrasoar",
    "abrasoava": "abrasoar",
    "abrasoavam": "abrasoar",
    "abrasoavas": "abrasoar",
    "abrasoe": "abrasoar",
    "abrasoei": "abrasoar",
    "abrasoeis": "abrasoar",
    "abrasoem": "abrasoar",
    "abrasoemo": "abrasoar",
    "abrasoemos": "abrasoar",
    "abrasoes": "abrasoar",
    "abrasona": "abrasonar",
    "abrasonada": "abrasonar",
    "abrasonadas": "abrasonar",
    "abrasonado": "abrasonar",
    "abrasonados": "abrasonar",
    "abrasonai": "abrasonar",
    "abrasonais": "abrasonar",
    "abrasonam": "abrasonar",
    "abrasonamo": "abrasonar",
    "abrasonamos": "abrasonar",
    "abrasonando": "abrasonar",
    "abrasonara": "abrasonar",
    "abrasonaram": "abrasonar",
    "abrasonaras": "abrasonar",
    "abrasonarde": "abrasonar",
    "abrasonardes": "abrasonar",
    "abrasonare": "abrasonar",
    "abrasonarei": "abrasonar",
    "abrasonareis": "abrasonar",
    "abrasonarem": "abrasonar",
    "abrasonaremos": "abrasonar",
    "abrasonares": "abrasonar",
    "abrasonaria": "abrasonar",
    "abrasonariam": "abrasonar",
    "abrasonarias": "abrasonar",
    "abrasonarmo": "abrasonar",
    "abrasonarmos": "abrasonar",
    "abrasonará": "abrasonar",
    "abrasonarás": "abrasonar",
    "abrasonarão": "abrasonar",
    "abrasonaríamos": "abrasonar",
    "abrasonaríeis": "abrasonar",
    "abrasonas": "abrasonar",
    "abrasonasse": "abrasonar",
    "abrasonassem": "abrasonar",
    "abrasonasses": "abrasonar",
    "abrasonaste": "abrasonar",
    "abrasonastes": "abrasonar",
    "abrasonava": "abrasonar",
    "abrasonavam": "abrasonar",
    "abrasonavas": "abrasonar",
    "abrasone": "abrasonar",
    "abrasonei": "abrasonar",
    "abrasoneis": "abrasonar",
    "abrasonem": "abrasonar",
    "abrasonemo": "abrasonar",
    "abrasonemos": "abrasonar",
    "abrasones": "abrasonar",
    "abrasono": "abrasonar",
    "abrasonou": "abrasonar",
    "abrasoná": "abrasonar",
    "abrasonámo": "abrasonar",
    "abrasonámos": "abrasonar",
    "abrasonáramo": "abrasonar",
    "abrasonáramos": "abrasonar",
    "abrasonárei": "abrasonar",
    "abrasonáreis": "abrasonar",
    "abrasonásseis": "abrasonar",
    "abrasonássemos": "abrasonar",
    "abrasonávamo": "abrasonar",
    "abrasonávamos": "abrasonar",
    "abrasonávei": "abrasonar",
    "abrasonáveis": "abrasonar",
    "abrasoo": "abrasoar",
    "abrasoou": "abrasoar",
    "abrasou": "abrasar",
    "abrasoá": "abrasoar",
    "abrasoámo": "abrasoar",
    "abrasoámos": "abrasoar",
    "abrasoáramo": "abrasoar",
    "abrasoáramos": "abrasoar",
    "abrasoárei": "abrasoar",
    "abrasoáreis": "abrasoar",
    "abrasoásseis": "abrasoar",
    "abrasoássemos": "abrasoar",
    "abrasoávamo": "abrasoar",
    "abrasoávamos": "abrasoar",
    "abrasoávei": "abrasoar",
    "abrasoáveis": "abrasoar",
    "abrastóis": "abrastol",
    "abrasá": "abrasar",
    "abrasámo": "abrasar",
    "abrasámos": "abrasar",
    "abrasáramo": "abrasar",
    "abrasáramos": "abrasar",
    "abrasárei": "abrasar",
    "abrasáreis": "abrasar",
    "abrasásseis": "abrasar",
    "abrasássemos": "abrasar",
    "abrasávamo": "abrasar",
    "abrasávamos": "abrasar",
    "abrasávei": "abrasar",
    "abrasáveis": "abrasar",
    "abrasões": "abrasão",
    "abrazôs": "abrazô",
    "abraça": "abraçar",
    "abraçada": "abraçar",
    "abraçadas": "abraçar",
    "abraçadeira": "abraçador",
    "abraçadeiras": "abraçador",
    "abraçadinha": "abraçado",
    "abraçadinhas": "abraçado",
    "abraçadinho": "abraçado",
    "abraçadinhos": "abraçado",
    "abraçadita": "abraçado",
    "abraçaditas": "abraçado",
    "abraçadito": "abraçado",
    "abraçaditos": "abraçado",
    "abraçado": "abraçar",
    "abraçadora": "abraçador",
    "abraçadoras": "abraçador",
    "abraçadores": "abraçador",
    "abraçados": "abraçar",
    "abraçadíssima": "abraçado",
    "abraçadíssimas": "abraçado",
    "abraçadíssimo": "abraçado",
    "abraçadíssimos": "abraçado",
    "abraçai": "abraçar",
    "abraçais": "abraçar",
    "abraçam": "abraçar",
    "abraçamentos": "abraçamento",
    "abraçamo": "abraçar",
    "abraçamos": "abraçar",
    "abraçando": "abraçar",
    "abraçara": "abraçar",
    "abraçaram": "abraçar",
    "abraçaras": "abraçar",
    "abraçarde": "abraçar",
    "abraçardes": "abraçar",
    "abraçare": "abraçar",
    "abraçarei": "abraçar",
    "abraçareis": "abraçar",
    "abraçarem": "abraçar",
    "abraçaremos": "abraçar",
    "abraçares": "abraçar",
    "abraçaria": "abraçar",
    "abraçariam": "abraçar",
    "abraçarias": "abraçar",
    "abraçarmo": "abraçar",
    "abraçarmos": "abraçar",
    "abraçará": "abraçar",
    "abraçarás": "abraçar",
    "abraçarão": "abraçar",
    "abraçaríamos": "abraçar",
    "abraçaríeis": "abraçar",
    "abraças": "abraçar",
    "abraçasse": "abraçar",
    "abraçassem": "abraçar",
    "abraçasses": "abraçar",
    "abraçaste": "abraçar",
    "abraçastes": "abraçar",
    "abraçava": "abraçar",
    "abraçavam": "abraçar",
    "abraçavas": "abraçar",
    "abraço": "abraçar",
    "abraços": "abraço",
    "abraçou": "abraçar",
    "abraçá": "abraçar",
    "abraçámo": "abraçar",
    "abraçámos": "abraçar",
    "abraçáramo": "abraçar",
    "abraçáramos": "abraçar",
    "abraçárei": "abraçar",
    "abraçáreis": "abraçar",
    "abraçásseis": "abraçar",
    "abraçássemos": "abraçar",
    "abraçávamo": "abraçar",
    "abraçávamos": "abraçar",
    "abraçávei": "abraçar",
    "abraçáveis": "abraçar",
    "abre": "abrir",
    "abreja": "abrejar",
    "abrejada": "abrejar",
    "abrejadas": "abrejar",
    "abrejado": "abrejar",
    "abrejados": "abrejar",
    "abrejai": "abrejar",
    "abrejais": "abrejar",
    "abrejam": "abrejar",
    "abrejamo": "abrejar",
    "abrejamos": "abrejar",
    "abrejando": "abrejar",
    "abrejara": "abrejar",
    "abrejaram": "abrejar",
    "abrejaras": "abrejar",
    "abrejarde": "abrejar",
    "abrejardes": "abrejar",
    "abrejare": "abrejar",
    "abrejarei": "abrejar",
    "abrejareis": "abrejar",
    "abrejarem": "abrejar",
    "abrejaremos": "abrejar",
    "abrejares": "abrejar",
    "abrejaria": "abrejar",
    "abrejariam": "abrejar",
    "abrejarias": "abrejar",
    "abrejarmo": "abrejar",
    "abrejarmos": "abrejar",
    "abrejará": "abrejar",
    "abrejarás": "abrejar",
    "abrejarão": "abrejar",
    "abrejaríamos": "abrejar",
    "abrejaríeis": "abrejar",
    "abrejas": "abrejar",
    "abrejasse": "abrejar",
    "abrejassem": "abrejar",
    "abrejasses": "abrejar",
    "abrejaste": "abrejar",
    "abrejastes": "abrejar",
    "abrejava": "abrejar",
    "abrejavam": "abrejar",
    "abrejavas": "abrejar",
    "abreje": "abrejar",
    "abrejei": "abrejar",
    "abrejeira": "abrejeirar",
    "abrejeirada": "abrejeirar",
    "abrejeiradas": "abrejeirar",
    "abrejeirado": "abrejeirar",
    "abrejeirados": "abrejeirar",
    "abrejeirai": "abrejeirar",
    "abrejeirais": "abrejeirar",
    "abrejeiram": "abrejeirar",
    "abrejeiramo": "abrejeirar",
    "abrejeiramos": "abrejeirar",
    "abrejeirando": "abrejeirar",
    "abrejeirara": "abrejeirar",
    "abrejeiraram": "abrejeirar",
    "abrejeiraras": "abrejeirar",
    "abrejeirarde": "abrejeirar",
    "abrejeirardes": "abrejeirar",
    "abrejeirare": "abrejeirar",
    "abrejeirarei": "abrejeirar",
    "abrejeirareis": "abrejeirar",
    "abrejeirarem": "abrejeirar",
    "abrejeiraremos": "abrejeirar",
    "abrejeirares": "abrejeirar",
    "abrejeiraria": "abrejeirar",
    "abrejeirariam": "abrejeirar",
    "abrejeirarias": "abrejeirar",
    "abrejeirarmo": "abrejeirar",
    "abrejeirarmos": "abrejeirar",
    "abrejeirará": "abrejeirar",
    "abrejeirarás": "abrejeirar",
    "abrejeirarão": "abrejeirar",
    "abrejeiraríamos": "abrejeirar",
    "abrejeiraríeis": "abrejeirar",
    "abrejeiras": "abrejeirar",
    "abrejeirasse": "abrejeirar",
    "abrejeirassem": "abrejeirar",
    "abrejeirasses": "abrejeirar",
    "abrejeiraste": "abrejeirar",
    "abrejeirastes": "abrejeirar",
    "abrejeirava": "abrejeirar",
    "abrejeiravam": "abrejeirar",
    "abrejeiravas": "abrejeirar",
    "abrejeire": "abrejeirar",
    "abrejeirei": "abrejeirar",
    "abrejeireis": "abrejeirar",
    "abrejeirem": "abrejeirar",
    "abrejeiremo": "abrejeirar",
    "abrejeiremos": "abrejeirar",
    "abrejeires": "abrejeirar",
    "abrejeiro": "abrejeirar",
    "abrejeirou": "abrejeirar",
    "abrejeirá": "abrejeirar",
    "abrejeirámo": "abrejeirar",
    "abrejeirámos": "abrejeirar",
    "abrejeiráramo": "abrejeirar",
    "abrejeiráramos": "abrejeirar",
    "abrejeirárei": "abrejeirar",
    "abrejeiráreis": "abrejeirar",
    "abrejeirásseis": "abrejeirar",
    "abrejeirássemos": "abrejeirar",
    "abrejeirávamo": "abrejeirar",
    "abrejeirávamos": "abrejeirar",
    "abrejeirávei": "abrejeirar",
    "abrejeiráveis": "abrejeirar",
    "abrejeis": "abrejar",
    "abrejem": "abrejar",
    "abrejemo": "abrejar",
    "abrejemos": "abrejar",
    "abrejes": "abrejar",
    "abrejo": "abrejar",
    "abrejou": "abrejar",
    "abrejá": "abrejar",
    "abrejámo": "abrejar",
    "abrejámos": "abrejar",
    "abrejáramo": "abrejar",
    "abrejáramos": "abrejar",
    "abrejárei": "abrejar",
    "abrejáreis": "abrejar",
    "abrejásseis": "abrejar",
    "abrejássemos": "abrejar",
    "abrejávamo": "abrejar",
    "abrejávamos": "abrejar",
    "abrejávei": "abrejar",
    "abrejáveis": "abrejar",
    "abrem": "abrir",
    "abrenha": "abrenhar",
    "abrenhada": "abrenhar",
    "abrenhadas": "abrenhar",
    "abrenhado": "abrenhar",
    "abrenhados": "abrenhar",
    "abrenhai": "abrenhar",
    "abrenhais": "abrenhar",
    "abrenham": "abrenhar",
    "abrenhamo": "abrenhar",
    "abrenhamos": "abrenhar",
    "abrenhando": "abrenhar",
    "abrenhara": "abrenhar",
    "abrenharam": "abrenhar",
    "abrenharas": "abrenhar",
    "abrenharde": "abrenhar",
    "abrenhardes": "abrenhar",
    "abrenhare": "abrenhar",
    "abrenharei": "abrenhar",
    "abrenhareis": "abrenhar",
    "abrenharem": "abrenhar",
    "abrenharemos": "abrenhar",
    "abrenhares": "abrenhar",
    "abrenharia": "abrenhar",
    "abrenhariam": "abrenhar",
    "abrenharias": "abrenhar",
    "abrenharmo": "abrenhar",
    "abrenharmos": "abrenhar",
    "abrenhará": "abrenhar",
    "abrenharás": "abrenhar",
    "abrenharão": "abrenhar",
    "abrenharíamos": "abrenhar",
    "abrenharíeis": "abrenhar",
    "abrenhas": "abrenhar",
    "abrenhasse": "abrenhar",
    "abrenhassem": "abrenhar",
    "abrenhasses": "abrenhar",
    "abrenhaste": "abrenhar",
    "abrenhastes": "abrenhar",
    "abrenhava": "abrenhar",
    "abrenhavam": "abrenhar",
    "abrenhavas": "abrenhar",
    "abrenhe": "abrenhar",
    "abrenhei": "abrenhar",
    "abrenheis": "abrenhar",
    "abrenhem": "abrenhar",
    "abrenhemo": "abrenhar",
    "abrenhemos": "abrenhar",
    "abrenhes": "abrenhar",
    "abrenho": "abrenhar",
    "abrenhou": "abrenhar",
    "abrenhá": "abrenhar",
    "abrenhámo": "abrenhar",
    "abrenhámos": "abrenhar",
    "abrenháramo": "abrenhar",
    "abrenháramos": "abrenhar",
    "abrenhárei": "abrenhar",
    "abrenháreis": "abrenhar",
    "abrenhásseis": "abrenhar",
    "abrenhássemos": "abrenhar",
    "abrenhávamo": "abrenhar",
    "abrenhávamos": "abrenhar",
    "abrenhávei": "abrenhar",
    "abrenháveis": "abrenhar",
    "abrenuncia": "abrenunciar",
    "abrenunciada": "abrenunciar",
    "abrenunciadas": "abrenunciar",
    "abrenunciado": "abrenunciar",
    "abrenunciados": "abrenunciar",
    "abrenunciai": "abrenunciar",
    "abrenunciais": "abrenunciar",
    "abrenunciam": "abrenunciar",
    "abrenunciamo": "abrenunciar",
    "abrenunciamos": "abrenunciar",
    "abrenunciando": "abrenunciar",
    "abrenunciara": "abrenunciar",
    "abrenunciaram": "abrenunciar",
    "abrenunciaras": "abrenunciar",
    "abrenunciarde": "abrenunciar",
    "abrenunciardes": "abrenunciar",
    "abrenunciare": "abrenunciar",
    "abrenunciarei": "abrenunciar",
    "abrenunciareis": "abrenunciar",
    "abrenunciarem": "abrenunciar",
    "abrenunciaremos": "abrenunciar",
    "abrenunciares": "abrenunciar",
    "abrenunciaria": "abrenunciar",
    "abrenunciariam": "abrenunciar",
    "abrenunciarias": "abrenunciar",
    "abrenunciarmo": "abrenunciar",
    "abrenunciarmos": "abrenunciar",
    "abrenunciará": "abrenunciar",
    "abrenunciarás": "abrenunciar",
    "abrenunciarão": "abrenunciar",
    "abrenunciaríamos": "abrenunciar",
    "abrenunciaríeis": "abrenunciar",
    "abrenuncias": "abrenunciar",
    "abrenunciasse": "abrenunciar",
    "abrenunciassem": "abrenunciar",
    "abrenunciasses": "abrenunciar",
    "abrenunciaste": "abrenunciar",
    "abrenunciastes": "abrenunciar",
    "abrenunciava": "abrenunciar",
    "abrenunciavam": "abrenunciar",
    "abrenunciavas": "abrenunciar",
    "abrenunciações": "abrenunciação",
    "abrenuncie": "abrenunciar",
    "abrenunciei": "abrenunciar",
    "abrenuncieis": "abrenunciar",
    "abrenunciem": "abrenunciar",
    "abrenunciemo": "abrenunciar",
    "abrenunciemos": "abrenunciar",
    "abrenuncies": "abrenunciar",
    "abrenuncio": "abrenunciar",
    "abrenunciou": "abrenunciar",
    "abrenunciá": "abrenunciar",
    "abrenunciámo": "abrenunciar",
    "abrenunciámos": "abrenunciar",
    "abrenunciáramo": "abrenunciar",
    "abrenunciáramos": "abrenunciar",
    "abrenunciárei": "abrenunciar",
    "abrenunciáreis": "abrenunciar",
    "abrenunciásseis": "abrenunciar",
    "abrenunciássemos": "abrenunciar",
    "abrenunciávamo": "abrenunciar",
    "abrenunciávamos": "abrenunciar",
    "abrenunciávei": "abrenunciar",
    "abrenunciáveis": "abrenunciar",
    "abrenúncios": "abrenúncio",
    "abres": "abrir",
    "abretanhada": "abretanhado",
    "abretanhadas": "abretanhado",
    "abretanhados": "abretanhado",
    "abreugrafias": "abreugrafia",
    "abreus": "abreu",
    "abreva": "abrevar",
    "abrevada": "abrevar",
    "abrevadas": "abrevar",
    "abrevado": "abrevar",
    "abrevados": "abrevar",
    "abrevai": "abrevar",
    "abrevais": "abrevar",
    "abrevam": "abrevar",
    "abrevamo": "abrevar",
    "abrevamos": "abrevar",
    "abrevando": "abrevar",
    "abrevara": "abrevar",
    "abrevaram": "abrevar",
    "abrevaras": "abrevar",
    "abrevarde": "abrevar",
    "abrevardes": "abrevar",
    "abrevare": "abrevar",
    "abrevarei": "abrevar",
    "abrevareis": "abrevar",
    "abrevarem": "abrevar",
    "abrevaremos": "abrevar",
    "abrevares": "abrevar",
    "abrevaria": "abrevar",
    "abrevariam": "abrevar",
    "abrevarias": "abrevar",
    "abrevarmo": "abrevar",
    "abrevarmos": "abrevar",
    "abrevará": "abrevar",
    "abrevarás": "abrevar",
    "abrevarão": "abrevar",
    "abrevaríamos": "abrevar",
    "abrevaríeis": "abrevar",
    "abrevas": "abrevar",
    "abrevasse": "abrevar",
    "abrevassem": "abrevar",
    "abrevasses": "abrevar",
    "abrevaste": "abrevar",
    "abrevastes": "abrevar",
    "abrevava": "abrevar",
    "abrevavam": "abrevar",
    "abrevavas": "abrevar",
    "abreve": "abrevar",
    "abrevei": "abrevar",
    "abreveis": "abrevar",
    "abrevem": "abrevar",
    "abrevemo": "abrevar",
    "abrevemos": "abrevar",
    "abreves": "abrevar",
    "abrevia": "abreviar",
    "abreviada": "abreviar",
    "abreviadas": "abreviar",
    "abreviado": "abreviar",
    "abreviadora": "abreviador",
    "abreviadoras": "abreviador",
    "abreviadores": "abreviador",
    "abreviados": "abreviar",
    "abreviadíssima": "abreviado",
    "abreviadíssimas": "abreviado",
    "abreviadíssimo": "abreviado",
    "abreviadíssimos": "abreviado",
    "abreviai": "abreviar",
    "abreviais": "abreviar",
    "abreviam": "abreviar",
    "abreviamentos": "abreviamento",
    "abreviamo": "abreviar",
    "abreviamos": "abreviar",
    "abreviando": "abreviar",
    "abreviara": "abreviar",
    "abreviaram": "abreviar",
    "abreviaras": "abreviar",
    "abreviarde": "abreviar",
    "abreviardes": "abreviar",
    "abreviare": "abreviar",
    "abreviarei": "abreviar",
    "abreviareis": "abreviar",
    "abreviarem": "abreviar",
    "abreviaremos": "abreviar",
    "abreviares": "abreviar",
    "abreviaria": "abreviar",
    "abreviariam": "abreviar",
    "abreviarias": "abreviar",
    "abreviarmo": "abreviar",
    "abreviarmos": "abreviar",
    "abreviará": "abreviar",
    "abreviarás": "abreviar",
    "abreviarão": "abreviar",
    "abreviaríamos": "abreviar",
    "abreviaríeis": "abreviar",
    "abrevias": "abreviar",
    "abreviasse": "abreviar",
    "abreviassem": "abreviar",
    "abreviasses": "abreviar",
    "abreviaste": "abreviar",
    "abreviastes": "abreviar",
    "abreviativa": "abreviativo",
    "abreviativas": "abreviativo",
    "abreviativos": "abreviativo",
    "abreviaturas": "abreviatura",
    "abreviava": "abreviar",
    "abreviavam": "abreviar",
    "abreviavas": "abreviar",
    "abreviações": "abreviação",
    "abrevie": "abreviar",
    "abreviei": "abreviar",
    "abrevieis": "abreviar",
    "abreviem": "abreviar",
    "abreviemo": "abreviar",
    "abreviemos": "abreviar",
    "abrevies": "abreviar",
    "abrevio": "abreviar",
    "abreviou": "abreviar",
    "abreviá": "abreviar",
    "abreviámo": "abreviar",
    "abreviámos": "abreviar",
    "abreviáramo": "abreviar",
    "abreviáramos": "abreviar",
    "abreviárei": "abreviar",
    "abreviáreis": "abreviar",
    "abreviásseis": "abreviar",
    "abreviássemos": "abreviar",
    "abreviávamo": "abreviar",
    "abreviávamos": "abreviar",
    "abreviávei": "abreviar",
    "abreviáveis": "abreviável",
    "abrevo": "abrevar",
    "abrevou": "abrevar",
    "abrevá": "abrevar",
    "abrevámo": "abrevar",
    "abrevámos": "abrevar",
    "abreváramo": "abrevar",
    "abreváramos": "abrevar",
    "abrevárei": "abrevar",
    "abreváreis": "abrevar",
    "abrevásseis": "abrevar",
    "abrevássemos": "abrevar",
    "abrevávamo": "abrevar",
    "abrevávamos": "abrevar",
    "abrevávei": "abrevar",
    "abreváveis": "abrevar",
    "abri": "abrir",
    "abria": "abrir",
    "abriam": "abrir",
    "abrias": "abrir",
    "abricoques": "abricoque",
    "abricoteiros": "abricoteiro",
    "abricotes": "abricote",
    "abricozeiros": "abricozeiro",
    "abricós": "abricó",
    "abrida": "abrir",
    "abridas": "abrir",
    "abrideira": "abridor",
    "abrideiras": "abridor",
    "abridelas": "abridela",
    "abrido": "abrir",
    "abridora": "abridor",
    "abridoras": "abridor",
    "abridores": "abridor",
    "abridos": "abrir",
    "abriga": "abrigar",
    "abrigada": "abrigar",
    "abrigadas": "abrigar",
    "abrigadinha": "abrigado",
    "abrigadinhas": "abrigado",
    "abrigadinho": "abrigado",
    "abrigadinhos": "abrigado",
    "abrigadita": "abrigado",
    "abrigaditas": "abrigado",
    "abrigadito": "abrigado",
    "abrigaditos": "abrigado",
    "abrigado": "abrigar",
    "abrigadoiros": "abrigadoiro",
    "abrigadora": "abrigador",
    "abrigadoras": "abrigador",
    "abrigadores": "abrigador",
    "abrigados": "abrigar",
    "abrigadouros": "abrigadouro",
    "abrigadíssima": "abrigado",
    "abrigadíssimas": "abrigado",
    "abrigadíssimo": "abrigado",
    "abrigadíssimos": "abrigado",
    "abrigai": "abrigar",
    "abrigais": "abrigar",
    "abrigam": "abrigar",
    "abrigamo": "abrigar",
    "abrigamos": "abrigar",
    "abrigando": "abrigar",
    "abrigara": "abrigar",
    "abrigaram": "abrigar",
    "abrigaras": "abrigar",
    "abrigarde": "abrigar",
    "abrigardes": "abrigar",
    "abrigare": "abrigar",
    "abrigarei": "abrigar",
    "abrigareis": "abrigar",
    "abrigarem": "abrigar",
    "abrigaremos": "abrigar",
    "abrigares": "abrigar",
    "abrigaria": "abrigar",
    "abrigariam": "abrigar",
    "abrigarias": "abrigar",
    "abrigarmo": "abrigar",
    "abrigarmos": "abrigar",
    "abrigará": "abrigar",
    "abrigarás": "abrigar",
    "abrigarão": "abrigar",
    "abrigaríamos": "abrigar",
    "abrigaríeis": "abrigar",
    "abrigas": "abrigar",
    "abrigasse": "abrigar",
    "abrigassem": "abrigar",
    "abrigasses": "abrigar",
    "abrigaste": "abrigar",
    "abrigastes": "abrigar",
    "abrigava": "abrigar",
    "abrigavam": "abrigar",
    "abrigavas": "abrigar",
    "abrigo": "abrigar",
    "abrigos": "abrigo",
    "abrigou": "abrigar",
    "abrigue": "abrigar",
    "abriguei": "abrigar",
    "abrigueis": "abrigar",
    "abriguem": "abrigar",
    "abriguemo": "abrigar",
    "abriguemos": "abrigar",
    "abrigues": "abrigar",
    "abriguinho": "abrigo",
    "abriguinhos": "abrigo",
    "abriguito": "abrigo",
    "abriguitos": "abrigo",
    "abrigá": "abrigar",
    "abrigámo": "abrigar",
    "abrigámos": "abrigar",
    "abrigáramo": "abrigar",
    "abrigáramos": "abrigar",
    "abrigárei": "abrigar",
    "abrigáreis": "abrigar",
    "abrigásseis": "abrigar",
    "abrigássemos": "abrigar",
    "abrigávamo": "abrigar",
    "abrigávamos": "abrigar",
    "abrigávei": "abrigar",
    "abrigáveis": "abrigar",
    "abriladas": "abrilada",
    "abrilhanta": "abrilhantar",
    "abrilhantada": "abrilhantar",
    "abrilhantadas": "abrilhantar",
    "abrilhantado": "abrilhantar",
    "abrilhantados": "abrilhantar",
    "abrilhantadíssima": "abrilhantado",
    "abrilhantadíssimas": "abrilhantado",
    "abrilhantadíssimo": "abrilhantado",
    "abrilhantadíssimos": "abrilhantado",
    "abrilhantai": "abrilhantar",
    "abrilhantais": "abrilhantar",
    "abrilhantam": "abrilhantar",
    "abrilhantamo": "abrilhantar",
    "abrilhantamos": "abrilhantar",
    "abrilhantando": "abrilhantar",
    "abrilhantara": "abrilhantar",
    "abrilhantaram": "abrilhantar",
    "abrilhantaras": "abrilhantar",
    "abrilhantarde": "abrilhantar",
    "abrilhantardes": "abrilhantar",
    "abrilhantare": "abrilhantar",
    "abrilhantarei": "abrilhantar",
    "abrilhantareis": "abrilhantar",
    "abrilhantarem": "abrilhantar",
    "abrilhantaremos": "abrilhantar",
    "abrilhantares": "abrilhantar",
    "abrilhantaria": "abrilhantar",
    "abrilhantariam": "abrilhantar",
    "abrilhantarias": "abrilhantar",
    "abrilhantarmo": "abrilhantar",
    "abrilhantarmos": "abrilhantar",
    "abrilhantará": "abrilhantar",
    "abrilhantarás": "abrilhantar",
    "abrilhantarão": "abrilhantar",
    "abrilhantaríamos": "abrilhantar",
    "abrilhantaríeis": "abrilhantar",
    "abrilhantas": "abrilhantar",
    "abrilhantasse": "abrilhantar",
    "abrilhantassem": "abrilhantar",
    "abrilhantasses": "abrilhantar",
    "abrilhantaste": "abrilhantar",
    "abrilhantastes": "abrilhantar",
    "abrilhantava": "abrilhantar",
    "abrilhantavam": "abrilhantar",
    "abrilhantavas": "abrilhantar",
    "abrilhante": "abrilhantar",
    "abrilhantei": "abrilhantar",
    "abrilhanteis": "abrilhantar",
    "abrilhantem": "abrilhantar",
    "abrilhantemo": "abrilhantar",
    "abrilhantemos": "abrilhantar",
    "abrilhantes": "abrilhantar",
    "abrilhanto": "abrilhantar",
    "abrilhantou": "abrilhantar",
    "abrilhantá": "abrilhantar",
    "abrilhantámo": "abrilhantar",
    "abrilhantámos": "abrilhantar",
    "abrilhantáramo": "abrilhantar",
    "abrilhantáramos": "abrilhantar",
    "abrilhantárei": "abrilhantar",
    "abrilhantáreis": "abrilhantar",
    "abrilhantásseis": "abrilhantar",
    "abrilhantássemos": "abrilhantar",
    "abrilhantávamo": "abrilhantar",
    "abrilhantávamos": "abrilhantar",
    "abrilhantávei": "abrilhantar",
    "abrilhantáveis": "abrilhantar",
    "abrimentos": "abrimento",
    "abrimo": "abrir",
    "abrimos": "abrir",
    "abrindo": "abrir",
    "abrira": "abrir",
    "abriram": "abrir",
    "abriras": "abrir",
    "abrirde": "abrir",
    "abrirdes": "abrir",
    "abrire": "abrir",
    "abrirei": "abrir",
    "abrireis": "abrir",
    "abrirem": "abrir",
    "abriremos": "abrir",
    "abrires": "abrir",
    "abriria": "abrir",
    "abririam": "abrir",
    "abririas": "abrir",
    "abrirmo": "abrir",
    "abrirmos": "abrir",
    "abrirá": "abrir",
    "abrirás": "abrir",
    "abrirão": "abrir",
    "abriríamos": "abrir",
    "abriríeis": "abrir",
    "abris": "abrir",
    "abrisse": "abrir",
    "abrissem": "abrir",
    "abrisses": "abrir",
    "abriste": "abrir",
    "abristes": "abrir",
    "abriu": "abrir",
    "abro": "abrir",
    "abrocada": "abrocadar",
    "abrocadada": "abrocadar",
    "abrocadadas": "abrocadar",
    "abrocadado": "abrocadar",
    "abrocadados": "abrocadar",
    "abrocadai": "abrocadar",
    "abrocadais": "abrocadar",
    "abrocadam": "abrocadar",
    "abrocadamo": "abrocadar",
    "abrocadamos": "abrocadar",
    "abrocadando": "abrocadar",
    "abrocadara": "abrocadar",
    "abrocadaram": "abrocadar",
    "abrocadaras": "abrocadar",
    "abrocadarde": "abrocadar",
    "abrocadardes": "abrocadar",
    "abrocadare": "abrocadar",
    "abrocadarei": "abrocadar",
    "abrocadareis": "abrocadar",
    "abrocadarem": "abrocadar",
    "abrocadaremos": "abrocadar",
    "abrocadares": "abrocadar",
    "abrocadaria": "abrocadar",
    "abrocadariam": "abrocadar",
    "abrocadarias": "abrocadar",
    "abrocadarmo": "abrocadar",
    "abrocadarmos": "abrocadar",
    "abrocadará": "abrocadar",
    "abrocadarás": "abrocadar",
    "abrocadarão": "abrocadar",
    "abrocadaríamos": "abrocadar",
    "abrocadaríeis": "abrocadar",
    "abrocadas": "abrocadar",
    "abrocadasse": "abrocadar",
    "abrocadassem": "abrocadar",
    "abrocadasses": "abrocadar",
    "abrocadaste": "abrocadar",
    "abrocadastes": "abrocadar",
    "abrocadava": "abrocadar",
    "abrocadavam": "abrocadar",
    "abrocadavas": "abrocadar",
    "abrocade": "abrocadar",
    "abrocadei": "abrocadar",
    "abrocadeis": "abrocadar",
    "abrocadem": "abrocadar",
    "abrocademo": "abrocadar",
    "abrocademos": "abrocadar",
    "abrocades": "abrocadar",
    "abrocado": "abrocadar",
    "abrocadou": "abrocadar",
    "abrocadá": "abrocadar",
    "abrocadámo": "abrocadar",
    "abrocadámos": "abrocadar",
    "abrocadáramo": "abrocadar",
    "abrocadáramos": "abrocadar",
    "abrocadárei": "abrocadar",
    "abrocadáreis": "abrocadar",
    "abrocadásseis": "abrocadar",
    "abrocadássemos": "abrocadar",
    "abrocadávamo": "abrocadar",
    "abrocadávamos": "abrocadar",
    "abrocadávei": "abrocadar",
    "abrocadáveis": "abrocadar",
    "abrocha": "abrochar",
    "abrochada": "abrochar",
    "abrochadas": "abrochar",
    "abrochado": "abrochar",
    "abrochadora": "abrochador",
    "abrochadoras": "abrochador",
    "abrochadores": "abrochador",
    "abrochados": "abrochar",
    "abrochaduras": "abrochadura",
    "abrochai": "abrochar",
    "abrochais": "abrochar",
    "abrocham": "abrochar",
    "abrochamo": "abrochar",
    "abrochamos": "abrochar",
    "abrochando": "abrochar",
    "abrochara": "abrochar",
    "abrocharam": "abrochar",
    "abrocharas": "abrochar",
    "abrocharde": "abrochar",
    "abrochardes": "abrochar",
    "abrochare": "abrochar",
    "abrocharei": "abrochar",
    "abrochareis": "abrochar",
    "abrocharem": "abrochar",
    "abrocharemos": "abrochar",
    "abrochares": "abrochar",
    "abrocharia": "abrochar",
    "abrochariam": "abrochar",
    "abrocharias": "abrochar",
    "abrocharmo": "abrochar",
    "abrocharmos": "abrochar",
    "abrochará": "abrochar",
    "abrocharás": "abrochar",
    "abrocharão": "abrochar",
    "abrocharíamos": "abrochar",
    "abrocharíeis": "abrochar",
    "abrochas": "abrochar",
    "abrochasse": "abrochar",
    "abrochassem": "abrochar",
    "abrochasses": "abrochar",
    "abrochaste": "abrochar",
    "abrochastes": "abrochar",
    "abrochava": "abrochar",
    "abrochavam": "abrochar",
    "abrochavas": "abrochar",
    "abroche": "abrochar",
    "abrochei": "abrochar",
    "abrocheis": "abrochar",
    "abrochem": "abrochar",
    "abrochemo": "abrochar",
    "abrochemos": "abrochar",
    "abroches": "abrochar",
    "abrocho": "abrochar",
    "abrochou": "abrochar",
    "abrochá": "abrochar",
    "abrochámo": "abrochar",
    "abrochámos": "abrochar",
    "abrocháramo": "abrochar",
    "abrocháramos": "abrochar",
    "abrochárei": "abrochar",
    "abrocháreis": "abrochar",
    "abrochásseis": "abrochar",
    "abrochássemos": "abrochar",
    "abrochávamo": "abrochar",
    "abrochávamos": "abrochar",
    "abrochávei": "abrochar",
    "abrocháveis": "abrochar",
    "abrolha": "abrolhar",
    "abrolhada": "abrolhar",
    "abrolhadas": "abrolhar",
    "abrolhado": "abrolhar",
    "abrolhados": "abrolhar",
    "abrolhai": "abrolhar",
    "abrolhais": "abrolhar",
    "abrolham": "abrolhar",
    "abrolhamentos": "abrolhamento",
    "abrolhamo": "abrolhar",
    "abrolhamos": "abrolhar",
    "abrolhando": "abrolhar",
    "abrolhara": "abrolhar",
    "abrolharam": "abrolhar",
    "abrolharas": "abrolhar",
    "abrolhardes": "abrolhar",
    "abrolharei": "abrolhar",
    "abrolhareis": "abrolhar",
    "abrolharem": "abrolhar",
    "abrolharemos": "abrolhar",
    "abrolhares": "abrolhar",
    "abrolharia": "abrolhar",
    "abrolhariam": "abrolhar",
    "abrolharias": "abrolhar",
    "abrolharmo": "abrolhar",
    "abrolharmos": "abrolhar",
    "abrolhará": "abrolhar",
    "abrolharás": "abrolhar",
    "abrolharão": "abrolhar",
    "abrolharíamos": "abrolhar",
    "abrolharíeis": "abrolhar",
    "abrolhas": "abrolhar",
    "abrolhasse": "abrolhar",
    "abrolhassem": "abrolhar",
    "abrolhasses": "abrolhar",
    "abrolhaste": "abrolhar",
    "abrolhastes": "abrolhar",
    "abrolhava": "abrolhar",
    "abrolhavam": "abrolhar",
    "abrolhavas": "abrolhar",
    "abrolhe": "abrolhar",
    "abrolhei": "abrolhar",
    "abrolheis": "abrolhar",
    "abrolhem": "abrolhar",
    "abrolhemo": "abrolhar",
    "abrolhemos": "abrolhar",
    "abrolhes": "abrolhar",
    "abrolho": "abrolhar",
    "abrolhos": "abrolho",
    "abrolhosa": "abrolhoso",
    "abrolhosas": "abrolhoso",
    "abrolhosos": "abrolhoso",
    "abrolhou": "abrolhar",
    "abrolhámo": "abrolhar",
    "abrolhámos": "abrolhar",
    "abrolháramo": "abrolhar",
    "abrolháramos": "abrolhar",
    "abrolháreis": "abrolhar",
    "abrolhásseis": "abrolhar",
    "abrolhássemos": "abrolhar",
    "abrolhávamo": "abrolhar",
    "abrolhávamos": "abrolhar",
    "abrolháveis": "abrolhar",
    "abronzeada": "abronzear",
    "abronzeadas": "abronzear",
    "abronzeado": "abronzear",
    "abronzeados": "abronzear",
    "abronzeai": "abronzear",
    "abronzeais": "abronzear",
    "abronzeamo": "abronzear",
    "abronzeamos": "abronzear",
    "abronzeando": "abronzear",
    "abronzeara": "abronzear",
    "abronzearam": "abronzear",
    "abronzearas": "abronzear",
    "abronzearde": "abronzear",
    "abronzeardes": "abronzear",
    "abronzeare": "abronzear",
    "abronzearei": "abronzear",
    "abronzeareis": "abronzear",
    "abronzearem": "abronzear",
    "abronzearemos": "abronzear",
    "abronzeares": "abronzear",
    "abronzearia": "abronzear",
    "abronzeariam": "abronzear",
    "abronzearias": "abronzear",
    "abronzearmo": "abronzear",
    "abronzearmos": "abronzear",
    "abronzeará": "abronzear",
    "abronzearás": "abronzear",
    "abronzearão": "abronzear",
    "abronzearíamos": "abronzear",
    "abronzearíeis": "abronzear",
    "abronzeasse": "abronzear",
    "abronzeassem": "abronzear",
    "abronzeasses": "abronzear",
    "abronzeaste": "abronzear",
    "abronzeastes": "abronzear",
    "abronzeava": "abronzear",
    "abronzeavam": "abronzear",
    "abronzeavas": "abronzear",
    "abronzeei": "abronzear",
    "abronzeeis": "abronzear",
    "abronzeemo": "abronzear",
    "abronzeemos": "abronzear",
    "abronzeia": "abronzear",
    "abronzeiam": "abronzear",
    "abronzeias": "abronzear",
    "abronzeie": "abronzear",
    "abronzeiem": "abronzear",
    "abronzeies": "abronzear",
    "abronzeio": "abronzear",
    "abronzeou": "abronzear",
    "abronzeá": "abronzear",
    "abronzeámo": "abronzear",
    "abronzeámos": "abronzear",
    "abronzeáramo": "abronzear",
    "abronzeáramos": "abronzear",
    "abronzeárei": "abronzear",
    "abronzeáreis": "abronzear",
    "abronzeásseis": "abronzear",
    "abronzeássemos": "abronzear",
    "abronzeávamo": "abronzear",
    "abronzeávamos": "abronzear",
    "abronzeávei": "abronzear",
    "abronzeáveis": "abronzear",
    "abroquela": "abroquelar",
    "abroquelada": "abroquelar",
    "abroqueladas": "abroquelar",
    "abroquelado": "abroquelar",
    "abroquelados": "abroquelar",
    "abroquelai": "abroquelar",
    "abroquelais": "abroquelar",
    "abroquelam": "abroquelar",
    "abroquelamo": "abroquelar",
    "abroquelamos": "abroquelar",
    "abroquelando": "abroquelar",
    "abroquelara": "abroquelar",
    "abroquelaram": "abroquelar",
    "abroquelaras": "abroquelar",
    "abroquelarde": "abroquelar",
    "abroquelardes": "abroquelar",
    "abroquelare": "abroquelar",
    "abroquelarei": "abroquelar",
    "abroquelareis": "abroquelar",
    "abroquelarem": "abroquelar",
    "abroquelaremos": "abroquelar",
    "abroquelares": "abroquelar",
    "abroquelaria": "abroquelar",
    "abroquelariam": "abroquelar",
    "abroquelarias": "abroquelar",
    "abroquelarmo": "abroquelar",
    "abroquelarmos": "abroquelar",
    "abroquelará": "abroquelar",
    "abroquelarás": "abroquelar",
    "abroquelarão": "abroquelar",
    "abroquelaríamos": "abroquelar",
    "abroquelaríeis": "abroquelar",
    "abroquelas": "abroquelar",
    "abroquelasse": "abroquelar",
    "abroquelassem": "abroquelar",
    "abroquelasses": "abroquelar",
    "abroquelaste": "abroquelar",
    "abroquelastes": "abroquelar",
    "abroquelava": "abroquelar",
    "abroquelavam": "abroquelar",
    "abroquelavas": "abroquelar",
    "abroquele": "abroquelar",
    "abroquelei": "abroquelar",
    "abroqueleis": "abroquelar",
    "abroquelem": "abroquelar",
    "abroquelemo": "abroquelar",
    "abroquelemos": "abroquelar",
    "abroqueles": "abroquelar",
    "abroquelo": "abroquelar",
    "abroquelou": "abroquelar",
    "abroquelá": "abroquelar",
    "abroquelámo": "abroquelar",
    "abroquelámos": "abroquelar",
    "abroqueláramo": "abroquelar",
    "abroqueláramos": "abroquelar",
    "abroquelárei": "abroquelar",
    "abroqueláreis": "abroquelar",
    "abroquelásseis": "abroquelar",
    "abroquelássemos": "abroquelar",
    "abroquelávamo": "abroquelar",
    "abroquelávamos": "abroquelar",
    "abroquelávei": "abroquelar",
    "abroqueláveis": "abroquelar",
    "abrotais": "abrotal",
    "abroteais": "abroteal",
    "abruma": "abrumar",
    "abrumada": "abrumar",
    "abrumadas": "abrumar",
    "abrumado": "abrumar",
    "abrumados": "abrumar",
    "abrumadíssima": "abrumado",
    "abrumadíssimas": "abrumado",
    "abrumadíssimo": "abrumado",
    "abrumadíssimos": "abrumado",
    "abrumai": "abrumar",
    "abrumais": "abrumar",
    "abrumam": "abrumar",
    "abrumamo": "abrumar",
    "abrumamos": "abrumar",
    "abrumando": "abrumar",
    "abrumara": "abrumar",
    "abrumaram": "abrumar",
    "abrumaras": "abrumar",
    "abrumarde": "abrumar",
    "abrumardes": "abrumar",
    "abrumare": "abrumar",
    "abrumarei": "abrumar",
    "abrumareis": "abrumar",
    "abrumarem": "abrumar",
    "abrumaremos": "abrumar",
    "abrumares": "abrumar",
    "abrumaria": "abrumar",
    "abrumariam": "abrumar",
    "abrumarias": "abrumar",
    "abrumarmo": "abrumar",
    "abrumarmos": "abrumar",
    "abrumará": "abrumar",
    "abrumarás": "abrumar",
    "abrumarão": "abrumar",
    "abrumaríamos": "abrumar",
    "abrumaríeis": "abrumar",
    "abrumas": "abrumar",
    "abrumasse": "abrumar",
    "abrumassem": "abrumar",
    "abrumasses": "abrumar",
    "abrumaste": "abrumar",
    "abrumastes": "abrumar",
    "abrumava": "abrumar",
    "abrumavam": "abrumar",
    "abrumavas": "abrumar",
    "abrume": "abrumar",
    "abrumei": "abrumar",
    "abrumeis": "abrumar",
    "abrumem": "abrumar",
    "abrumemo": "abrumar",
    "abrumemos": "abrumar",
    "abrumes": "abrumar",
    "abrumo": "abrumar",
    "abrumou": "abrumar",
    "abrumá": "abrumar",
    "abrumámo": "abrumar",
    "abrumámos": "abrumar",
    "abrumáramo": "abrumar",
    "abrumáramos": "abrumar",
    "abrumárei": "abrumar",
    "abrumáreis": "abrumar",
    "abrumásseis": "abrumar",
    "abrumássemos": "abrumar",
    "abrumávamo": "abrumar",
    "abrumávamos": "abrumar",
    "abrumávei": "abrumar",
    "abrumáveis": "abrumar",
    "abrunhais": "abrunhal",
    "abrunheiros": "abrunheiro",
    "abrunhos": "abrunho",
    "abrupta": "abrupto",
    "abruptas": "abrupto",
    "abruptos": "abrupto",
    "abruta": "abrutar",
    "abrutada": "abrutar",
    "abrutadas": "abrutar",
    "abrutado": "abrutar",
    "abrutados": "abrutar",
    "abrutai": "abrutar",
    "abrutais": "abrutar",
    "abrutalha": "abrutalhar",
    "abrutalhada": "abrutalhar",
    "abrutalhadas": "abrutalhar",
    "abrutalhado": "abrutalhar",
    "abrutalhados": "abrutalhar",
    "abrutalhadíssima": "abrutalhado",
    "abrutalhadíssimas": "abrutalhado",
    "abrutalhadíssimo": "abrutalhado",
    "abrutalhadíssimos": "abrutalhado",
    "abrutalhai": "abrutalhar",
    "abrutalhais": "abrutalhar",
    "abrutalham": "abrutalhar",
    "abrutalhamo": "abrutalhar",
    "abrutalhamos": "abrutalhar",
    "abrutalhando": "abrutalhar",
    "abrutalhara": "abrutalhar",
    "abrutalharam": "abrutalhar",
    "abrutalharas": "abrutalhar",
    "abrutalharde": "abrutalhar",
    "abrutalhardes": "abrutalhar",
    "abrutalhare": "abrutalhar",
    "abrutalharei": "abrutalhar",
    "abrutalhareis": "abrutalhar",
    "abrutalharem": "abrutalhar",
    "abrutalharemos": "abrutalhar",
    "abrutalhares": "abrutalhar",
    "abrutalharia": "abrutalhar",
    "abrutalhariam": "abrutalhar",
    "abrutalharias": "abrutalhar",
    "abrutalharmo": "abrutalhar",
    "abrutalharmos": "abrutalhar",
    "abrutalhará": "abrutalhar",
    "abrutalharás": "abrutalhar",
    "abrutalharão": "abrutalhar",
    "abrutalharíamos": "abrutalhar",
    "abrutalharíeis": "abrutalhar",
    "abrutalhas": "abrutalhar",
    "abrutalhasse": "abrutalhar",
    "abrutalhassem": "abrutalhar",
    "abrutalhasses": "abrutalhar",
    "abrutalhaste": "abrutalhar",
    "abrutalhastes": "abrutalhar",
    "abrutalhava": "abrutalhar",
    "abrutalhavam": "abrutalhar",
    "abrutalhavas": "abrutalhar",
    "abrutalhe": "abrutalhar",
    "abrutalhei": "abrutalhar",
    "abrutalheis": "abrutalhar",
    "abrutalhem": "abrutalhar",
    "abrutalhemo": "abrutalhar",
    "abrutalhemos": "abrutalhar",
    "abrutalhes": "abrutalhar",
    "abrutalho": "abrutalhar",
    "abrutalhou": "abrutalhar",
    "abrutalhá": "abrutalhar",
    "abrutalhámo": "abrutalhar",
    "abrutalhámos": "abrutalhar",
    "abrutalháramo": "abrutalhar",
    "abrutalháramos": "abrutalhar",
    "abrutalhárei": "abrutalhar",
    "abrutalháreis": "abrutalhar",
    "abrutalhásseis": "abrutalhar",
    "abrutalhássemos": "abrutalhar",
    "abrutalhávamo": "abrutalhar",
    "abrutalhávamos": "abrutalhar",
    "abrutalhávei": "abrutalhar",
    "abrutalháveis": "abrutalhar",
    "abrutam": "abrutar",
    "abrutamo": "abrutar",
    "abrutamos": "abrutar",
    "abrutando": "abrutar",
    "abrutara": "abrutar",
    "abrutaram": "abrutar",
    "abrutaras": "abrutar",
    "abrutarde": "abrutar",
    "abrutardes": "abrutar",
    "abrutare": "abrutar",
    "abrutarei": "abrutar",
    "abrutareis": "abrutar",
    "abrutarem": "abrutar",
    "abrutaremos": "abrutar",
    "abrutares": "abrutar",
    "abrutaria": "abrutar",
    "abrutariam": "abrutar",
    "abrutarias": "abrutar",
    "abrutarmo": "abrutar",
    "abrutarmos": "abrutar",
    "abrutará": "abrutar",
    "abrutarás": "abrutar",
    "abrutarão": "abrutar",
    "abrutaríamos": "abrutar",
    "abrutaríeis": "abrutar",
    "abrutas": "abrutar",
    "abrutasse": "abrutar",
    "abrutassem": "abrutar",
    "abrutasses": "abrutar",
    "abrutaste": "abrutar",
    "abrutastes": "abrutar",
    "abrutava": "abrutar",
    "abrutavam": "abrutar",
    "abrutavas": "abrutar",
    "abrute": "abrutar",
    "abrutece": "abrutecer",
    "abrutecei": "abrutecer",
    "abruteceis": "abrutecer",
    "abrutecem": "abrutecer",
    "abrutecemo": "abrutecer",
    "abrutecemos": "abrutecer",
    "abrutecendo": "abrutecer",
    "abrutecera": "abrutecer",
    "abruteceram": "abrutecer",
    "abruteceras": "abrutecer",
    "abrutecerde": "abrutecer",
    "abrutecerdes": "abrutecer",
    "abrutecere": "abrutecer",
    "abrutecerei": "abrutecer",
    "abrutecereis": "abrutecer",
    "abrutecerem": "abrutecer",
    "abruteceremos": "abrutecer",
    "abruteceres": "abrutecer",
    "abruteceria": "abrutecer",
    "abruteceriam": "abrutecer",
    "abrutecerias": "abrutecer",
    "abrutecermo": "abrutecer",
    "abrutecermos": "abrutecer",
    "abrutecerá": "abrutecer",
    "abrutecerás": "abrutecer",
    "abrutecerão": "abrutecer",
    "abruteceríamos": "abrutecer",
    "abruteceríeis": "abrutecer",
    "abruteces": "abrutecer",
    "abrutecesse": "abrutecer",
    "abrutecessem": "abrutecer",
    "abrutecesses": "abrutecer",
    "abruteceste": "abrutecer",
    "abrutecestes": "abrutecer",
    "abruteceu": "abrutecer",
    "abruteci": "abrutecer",
    "abrutecia": "abrutecer",
    "abruteciam": "abrutecer",
    "abrutecias": "abrutecer",
    "abrutecida": "abrutecer",
    "abrutecidas": "abrutecer",
    "abrutecido": "abrutecer",
    "abrutecidos": "abrutecer",
    "abrutecê": "abrutecer",
    "abrutecêramo": "abrutecer",
    "abrutecêramos": "abrutecer",
    "abrutecêrei": "abrutecer",
    "abrutecêreis": "abrutecer",
    "abrutecêsseis": "abrutecer",
    "abrutecêssemos": "abrutecer",
    "abrutecíamo": "abrutecer",
    "abrutecíamos": "abrutecer",
    "abrutecíei": "abrutecer",
    "abrutecíeis": "abrutecer",
    "abrutei": "abrutar",
    "abruteis": "abrutar",
    "abrutem": "abrutar",
    "abrutemo": "abrutar",
    "abrutemos": "abrutar",
    "abrutes": "abrutar",
    "abruteça": "abrutecer",
    "abruteçais": "abrutecer",
    "abruteçam": "abrutecer",
    "abruteçamo": "abrutecer",
    "abruteçamos": "abrutecer",
    "abruteças": "abrutecer",
    "abruteço": "abrutecer",
    "abruto": "abrutar",
    "abrutou": "abrutar",
    "abrutá": "abrutar",
    "abrutámo": "abrutar",
    "abrutámos": "abrutar",
    "abrutáramo": "abrutar",
    "abrutáramos": "abrutar",
    "abrutárei": "abrutar",
    "abrutáreis": "abrutar",
    "abrutásseis": "abrutar",
    "abrutássemos": "abrutar",
    "abrutávamo": "abrutar",
    "abrutávamos": "abrutar",
    "abrutávei": "abrutar",
    "abrutáveis": "abrutar",
    "abráquia": "abráquio",
    "abráquias": "abráquio",
    "abráquios": "abráquio",
    "abríamo": "abrir",
    "abríamos": "abrir",
    "abríei": "abrir",
    "abríeis": "abrir",
    "abríramo": "abrir",
    "abríramos": "abrir",
    "abrírei": "abrir",
    "abríreis": "abrir",
    "abrísseis": "abrir",
    "abríssemos": "abrir",
    "abrótanos": "abrótano",
    "abróteas": "abrótea",
    "abrótegas": "abrótega",
    "absceda": "absceder",
    "abscedais": "absceder",
    "abscedam": "absceder",
    "abscedamo": "absceder",
    "abscedamos": "absceder",
    "abscedas": "absceder",
    "abscede": "absceder",
    "abscedei": "absceder",
    "abscedeis": "absceder",
    "abscedem": "absceder",
    "abscedemo": "absceder",
    "abscedemos": "absceder",
    "abscedendo": "absceder",
    "abscedera": "absceder",
    "abscederam": "absceder",
    "abscederas": "absceder",
    "abscederdes": "absceder",
    "abscederei": "absceder",
    "abscedereis": "absceder",
    "abscederem": "absceder",
    "abscederemos": "absceder",
    "abscederes": "absceder",
    "abscederia": "absceder",
    "abscederiam": "absceder",
    "abscederias": "absceder",
    "abscedermo": "absceder",
    "abscedermos": "absceder",
    "abscederá": "absceder",
    "abscederás": "absceder",
    "abscederão": "absceder",
    "abscederíamos": "absceder",
    "abscederíeis": "absceder",
    "abscedes": "absceder",
    "abscedesse": "absceder",
    "abscedessem": "absceder",
    "abscedesses": "absceder",
    "abscedeste": "absceder",
    "abscedestes": "absceder",
    "abscedeu": "absceder",
    "abscedi": "absceder",
    "abscedia": "absceder",
    "abscediam": "absceder",
    "abscedias": "absceder",
    "abscedida": "absceder",
    "abscedidas": "absceder",
    "abscedido": "absceder",
    "abscedidos": "absceder",
    "abscedo": "absceder",
    "abscedêramo": "absceder",
    "abscedêramos": "absceder",
    "abscedêreis": "absceder",
    "abscedêsseis": "absceder",
    "abscedêssemos": "absceder",
    "abscedíamo": "absceder",
    "abscedíamos": "absceder",
    "abscedíeis": "absceder",
    "abscessos": "abscesso",
    "abscissas": "abscissa",
    "abscisões": "abscisão",
    "absconda": "absconder",
    "abscondais": "absconder",
    "abscondam": "absconder",
    "abscondamo": "absconder",
    "abscondamos": "absconder",
    "abscondas": "absconder",
    "absconde": "absconder",
    "abscondei": "absconder",
    "abscondeis": "absconder",
    "abscondem": "absconder",
    "abscondemo": "absconder",
    "abscondemos": "absconder",
    "abscondendo": "absconder",
    "abscondera": "absconder",
    "absconderam": "absconder",
    "absconderas": "absconder",
    "absconderdes": "absconder",
    "absconderei": "absconder",
    "abscondereis": "absconder",
    "absconderem": "absconder",
    "absconderemos": "absconder",
    "absconderes": "absconder",
    "absconderia": "absconder",
    "absconderiam": "absconder",
    "absconderias": "absconder",
    "abscondermo": "absconder",
    "abscondermos": "absconder",
    "absconderá": "absconder",
    "absconderás": "absconder",
    "absconderão": "absconder",
    "absconderíamos": "absconder",
    "absconderíeis": "absconder",
    "abscondes": "absconder",
    "abscondesse": "absconder",
    "abscondessem": "absconder",
    "abscondesses": "absconder",
    "abscondeste": "absconder",
    "abscondestes": "absconder",
    "abscondeu": "absconder",
    "abscondi": "absconder",
    "abscondia": "absconder",
    "abscondiam": "absconder",
    "abscondias": "absconder",
    "abscondida": "abscondido",
    "abscondidas": "abscondido",
    "abscondido": "absconder",
    "abscondidos": "abscondido",
    "abscondo": "absconder",
    "abscondêramo": "absconder",
    "abscondêramos": "absconder",
    "abscondêreis": "absconder",
    "abscondêsseis": "absconder",
    "abscondêssemos": "absconder",
    "abscondíamo": "absconder",
    "abscondíamos": "absconder",
    "abscondíeis": "absconder",
    "absconsa": "absconso",
    "absconsas": "absconso",
    "absconsos": "absconso",
    "abscôndita": "abscôndito",
    "abscônditas": "abscôndito",
    "abscônditos": "abscôndito",
    "abscônsias": "abscônsia",
    "absenteístas": "absenteísta",
    "absentismos": "absentismo",
    "absentistas": "absentista",
    "absidais": "absidal",
    "absides": "abside",
    "absidíolas": "absidíola",
    "absidíolos": "absidíolo",
    "absintia": "absintiar",
    "absintiada": "absintiar",
    "absintiadas": "absintiar",
    "absintiado": "absintiar",
    "absintiados": "absintiar",
    "absintiai": "absintiar",
    "absintiais": "absintiar",
    "absintiam": "absintiar",
    "absintiamo": "absintiar",
    "absintiamos": "absintiar",
    "absintiando": "absintiar",
    "absintiara": "absintiar",
    "absintiaram": "absintiar",
    "absintiaras": "absintiar",
    "absintiarde": "absintiar",
    "absintiardes": "absintiar",
    "absintiare": "absintiar",
    "absintiarei": "absintiar",
    "absintiareis": "absintiar",
    "absintiarem": "absintiar",
    "absintiaremos": "absintiar",
    "absintiares": "absintiar",
    "absintiaria": "absintiar",
    "absintiariam": "absintiar",
    "absintiarias": "absintiar",
    "absintiarmo": "absintiar",
    "absintiarmos": "absintiar",
    "absintiará": "absintiar",
    "absintiarás": "absintiar",
    "absintiarão": "absintiar",
    "absintiaríamos": "absintiar",
    "absintiaríeis": "absintiar",
    "absintias": "absintiar",
    "absintiasse": "absintiar",
    "absintiassem": "absintiar",
    "absintiasses": "absintiar",
    "absintiaste": "absintiar",
    "absintiastes": "absintiar",
    "absintiava": "absintiar",
    "absintiavam": "absintiar",
    "absintiavas": "absintiar",
    "absintie": "absintiar",
    "absintiei": "absintiar",
    "absintieis": "absintiar",
    "absintiem": "absintiar",
    "absintiemo": "absintiar",
    "absintiemos": "absintiar",
    "absinties": "absintiar",
    "absintio": "absintiar",
    "absintiou": "absintiar",
    "absintismos": "absintismo",
    "absintiá": "absintiar",
    "absintiámo": "absintiar",
    "absintiámos": "absintiar",
    "absintiáramo": "absintiar",
    "absintiáramos": "absintiar",
    "absintiárei": "absintiar",
    "absintiáreis": "absintiar",
    "absintiásseis": "absintiar",
    "absintiássemos": "absintiar",
    "absintiávamo": "absintiar",
    "absintiávamos": "absintiar",
    "absintiávei": "absintiar",
    "absintiáveis": "absintiar",
    "absintos": "absinto",
    "absoluta": "absoluto",
    "absolutas": "absoluto",
    "absolutismos": "absolutismo",
    "absolutistas": "absolutista",
    "absolutizações": "absolutização",
    "absolutos": "absoluto",
    "absolutória": "absolutório",
    "absolutórias": "absolutório",
    "absolutórios": "absolutório",
    "absolva": "absolver",
    "absolvais": "absolver",
    "absolvam": "absolver",
    "absolvamo": "absolver",
    "absolvamos": "absolver",
    "absolvas": "absolver",
    "absolve": "absolver",
    "absolvei": "absolver",
    "absolveis": "absolver",
    "absolvem": "absolver",
    "absolvemo": "absolver",
    "absolvemos": "absolver",
    "absolvendo": "absolver",
    "absolvera": "absolver",
    "absolveram": "absolver",
    "absolveras": "absolver",
    "absolverde": "absolver",
    "absolverdes": "absolver",
    "absolvere": "absolver",
    "absolverei": "absolver",
    "absolvereis": "absolver",
    "absolverem": "absolver",
    "absolveremos": "absolver",
    "absolveres": "absolver",
    "absolveria": "absolver",
    "absolveriam": "absolver",
    "absolverias": "absolver",
    "absolvermo": "absolver",
    "absolvermos": "absolver",
    "absolverá": "absolver",
    "absolverás": "absolver",
    "absolverão": "absolver",
    "absolveríamos": "absolver",
    "absolveríeis": "absolver",
    "absolves": "absolver",
    "absolvesse": "absolver",
    "absolvessem": "absolver",
    "absolvesses": "absolver",
    "absolveste": "absolver",
    "absolvestes": "absolver",
    "absolveu": "absolver",
    "absolvi": "absolver",
    "absolvia": "absolver",
    "absolviam": "absolver",
    "absolvias": "absolver",
    "absolvida": "absolvido",
    "absolvidas": "absolvido",
    "absolvido": "absolver",
    "absolvidos": "absolvido",
    "absolvições": "absolvição",
    "absolvo": "absolver",
    "absolvê": "absolver",
    "absolvêramo": "absolver",
    "absolvêramos": "absolver",
    "absolvêrei": "absolver",
    "absolvêreis": "absolver",
    "absolvêsseis": "absolver",
    "absolvêssemos": "absolver",
    "absolvíamo": "absolver",
    "absolvíamos": "absolver",
    "absolvíei": "absolver",
    "absolvíeis": "absolver",
    "absolvíveis": "absolvível",
    "absorciometrias": "absorciometria",
    "absorciométrica": "absorciométrico",
    "absorciométricas": "absorciométrico",
    "absorciométricos": "absorciométrico",
    "absorciómetros": "absorciómetro",
    "absorta": "absorto",
    "absortas": "absorto",
    "absortiva": "absortivo",
    "absortivas": "absortivo",
    "absortividades": "absortividade",
    "absortivos": "absortivo",
    "absortos": "absorto",
    "absortâcias": "absortâcia",
    "absorva": "absorver",
    "absorvais": "absorver",
    "absorvam": "absorver",
    "absorvamo": "absorver",
    "absorvamos": "absorver",
    "absorvas": "absorver",
    "absorve": "absorver",
    "absorvedora": "absorvedor",
    "absorvedoras": "absorvedor",
    "absorvedores": "absorvedor",
    "absorvedouros": "absorvedouro",
    "absorvei": "absorver",
    "absorveis": "absorver",
    "absorvem": "absorver",
    "absorvemo": "absorver",
    "absorvemos": "absorver",
    "absorvendo": "absorver",
    "absorventes": "absorvente",
    "absorvera": "absorver",
    "absorveram": "absorver",
    "absorveras": "absorver",
    "absorverde": "absorver",
    "absorverdes": "absorver",
    "absorvere": "absorver",
    "absorverei": "absorver",
    "absorvereis": "absorver",
    "absorverem": "absorver",
    "absorveremos": "absorver",
    "absorveres": "absorver",
    "absorveria": "absorver",
    "absorveriam": "absorver",
    "absorverias": "absorver",
    "absorvermo": "absorver",
    "absorvermos": "absorver",
    "absorverá": "absorver",
    "absorverás": "absorver",
    "absorverão": "absorver",
    "absorveríamos": "absorver",
    "absorveríeis": "absorver",
    "absorves": "absorver",
    "absorvesse": "absorver",
    "absorvessem": "absorver",
    "absorvesses": "absorver",
    "absorveste": "absorver",
    "absorvestes": "absorver",
    "absorveu": "absorver",
    "absorvi": "absorver",
    "absorvia": "absorver",
    "absorviam": "absorver",
    "absorvias": "absorver",
    "absorvibilidades": "absorvibilidade",
    "absorvida": "absorvido",
    "absorvidades": "absorvidade",
    "absorvidas": "absorvido",
    "absorvido": "absorver",
    "absorvidos": "absorvido",
    "absorvidíssima": "absorvido",
    "absorvidíssimas": "absorvido",
    "absorvidíssimo": "absorvido",
    "absorvidíssimos": "absorvido",
    "absorvimentos": "absorvimento",
    "absorvo": "absorver",
    "absorvê": "absorver",
    "absorvências": "absorvência",
    "absorvêramo": "absorver",
    "absorvêramos": "absorver",
    "absorvêrei": "absorver",
    "absorvêreis": "absorver",
    "absorvêsseis": "absorver",
    "absorvêssemos": "absorver",
    "absorvíamo": "absorver",
    "absorvíamos": "absorver",
    "absorvíei": "absorver",
    "absorvíeis": "absorver",
    "absorvíveis": "absorvível",
    "absorções": "absorção",
    "abstemias": "abstemia",
    "abstemo": "abster",
    "abstemos": "abster",
    "abstencionismos": "abstencionismo",
    "abstencionistas": "abstencionista",
    "abstende": "abster",
    "abstendes": "abster",
    "abstendo": "abster",
    "abstenha": "abster",
    "abstenhais": "abster",
    "abstenham": "abster",
    "abstenhamo": "abster",
    "abstenhamos": "abster",
    "abstenhas": "abster",
    "abstenho": "abster",
    "abstenções": "abstenção",
    "absterde": "abster",
    "absterdes": "abster",
    "abstere": "abster",
    "absterei": "abster",
    "abstereis": "abster",
    "absterem": "abster",
    "absteremos": "abster",
    "absteres": "abster",
    "absterge": "absterger",
    "abstergei": "absterger",
    "abstergeis": "absterger",
    "abstergem": "absterger",
    "abstergemo": "absterger",
    "abstergemos": "absterger",
    "abstergendo": "absterger",
    "abstergentes": "abstergente",
    "abstergera": "absterger",
    "abstergeram": "absterger",
    "abstergeras": "absterger",
    "abstergerde": "absterger",
    "abstergerdes": "absterger",
    "abstergere": "absterger",
    "abstergerei": "absterger",
    "abstergereis": "absterger",
    "abstergerem": "absterger",
    "abstergeremos": "absterger",
    "abstergeres": "absterger",
    "abstergeria": "absterger",
    "abstergeriam": "absterger",
    "abstergerias": "absterger",
    "abstergermo": "absterger",
    "abstergermos": "absterger",
    "abstergerá": "absterger",
    "abstergerás": "absterger",
    "abstergerão": "absterger",
    "abstergeríamos": "absterger",
    "abstergeríeis": "absterger",
    "absterges": "absterger",
    "abstergesse": "absterger",
    "abstergessem": "absterger",
    "abstergesses": "absterger",
    "abstergeste": "absterger",
    "abstergestes": "absterger",
    "abstergeu": "absterger",
    "abstergi": "absterger",
    "abstergia": "absterger",
    "abstergiam": "absterger",
    "abstergias": "absterger",
    "abstergida": "abstergido",
    "abstergidas": "abstergido",
    "abstergido": "absterger",
    "abstergidos": "abstergido",
    "abstergidíssima": "abstergido",
    "abstergidíssimas": "abstergido",
    "abstergidíssimo": "abstergido",
    "abstergidíssimos": "abstergido",
    "abstergê": "absterger",
    "abstergências": "abstergência",
    "abstergêramo": "absterger",
    "abstergêramos": "absterger",
    "abstergêrei": "absterger",
    "abstergêreis": "absterger",
    "abstergêsseis": "absterger",
    "abstergêssemos": "absterger",
    "abstergíamo": "absterger",
    "abstergíamos": "absterger",
    "abstergíei": "absterger",
    "abstergíeis": "absterger",
    "absteria": "abster",
    "absteriam": "abster",
    "absterias": "abster",
    "absterja": "absterger",
    "absterjais": "absterger",
    "absterjam": "absterger",
    "absterjamo": "absterger",
    "absterjamos": "absterger",
    "absterjas": "absterger",
    "absterjo": "absterger",
    "abstermo": "abster",
    "abstermos": "abster",
    "abstersa": "absterso",
    "abstersas": "absterso",
    "abstersiva": "abstersivo",
    "abstersivas": "abstersivo",
    "abstersivos": "abstersivo",
    "abstersos": "absterso",
    "abstersões": "abstersão",
    "absterá": "abster",
    "absterás": "abster",
    "absterão": "abster",
    "absteríamos": "abster",
    "absteríeis": "abster",
    "absteve": "abster",
    "abstida": "abster",
    "abstidas": "abster",
    "abstido": "abster",
    "abstidos": "abster",
    "abstinentes": "abstinente",
    "abstinha": "abster",
    "abstinham": "abster",
    "abstinhas": "abster",
    "abstinências": "abstinência",
    "abstive": "abster",
    "abstivemo": "abster",
    "abstivemos": "abster",
    "abstiver": "abster",
    "abstivera": "abster",
    "abstiveram": "abster",
    "abstiveras": "abster",
    "abstiverdes": "abster",
    "abstiverem": "abster",
    "abstiveres": "abster",
    "abstivermos": "abster",
    "abstivesse": "abster",
    "abstivessem": "abster",
    "abstivesses": "abster",
    "abstiveste": "abster",
    "abstivestes": "abster",
    "abstivéramo": "abster",
    "abstivéramos": "abster",
    "abstivérei": "abster",
    "abstivéreis": "abster",
    "abstivésseis": "abster",
    "abstivéssemos": "abster",
    "abstraccionismos": "abstraccionismo",
    "abstraccionistas": "abstraccionista",
    "abstracta": "abstracto",
    "abstractas": "abstracto",
    "abstractiva": "abstractivo",
    "abstractivas": "abstractivo",
    "abstractivos": "abstractivo",
    "abstractos": "abstracto",
    "abstracções": "abstracção",
    "abstraem": "abstrair",
    "abstrai": "abstrair",
    "abstraia": "abstrair",
    "abstraiais": "abstrair",
    "abstraiam": "abstrair",
    "abstraiamo": "abstrair",
    "abstraiamos": "abstrair",
    "abstraias": "abstrair",
    "abstraindo": "abstrair",
    "abstraio": "abstrair",
    "abstrairde": "abstrair",
    "abstrairdes": "abstrair",
    "abstrairei": "abstrair",
    "abstraireis": "abstrair",
    "abstrairemos": "abstrair",
    "abstrairia": "abstrair",
    "abstrairiam": "abstrair",
    "abstrairias": "abstrair",
    "abstrairmo": "abstrair",
    "abstrairmos": "abstrair",
    "abstrairá": "abstrair",
    "abstrairás": "abstrair",
    "abstrairão": "abstrair",
    "abstrairíamos": "abstrair",
    "abstrairíeis": "abstrair",
    "abstrais": "abstrair",
    "abstraiu": "abstrair",
    "abstraí": "abstrair",
    "abstraía": "abstrair",
    "abstraíam": "abstrair",
    "abstraíamo": "abstrair",
    "abstraíamos": "abstrair",
    "abstraías": "abstrair",
    "abstraída": "abstrair",
    "abstraídas": "abstrair",
    "abstraído": "abstrair",
    "abstraídos": "abstrair",
    "abstraíei": "abstrair",
    "abstraíeis": "abstrair",
    "abstraímo": "abstrair",
    "abstraímos": "abstrair",
    "abstraíra": "abstrair",
    "abstraíram": "abstrair",
    "abstraíramo": "abstrair",
    "abstraíramos": "abstrair",
    "abstraíras": "abstrair",
    "abstraíre": "abstrair",
    "abstraírei": "abstrair",
    "abstraíreis": "abstrair",
    "abstraírem": "abstrair",
    "abstraíres": "abstrair",
    "abstraís": "abstrair",
    "abstraísse": "abstrair",
    "abstraísseis": "abstrair",
    "abstraíssem": "abstrair",
    "abstraíssemos": "abstrair",
    "abstraísses": "abstrair",
    "abstraíste": "abstrair",
    "abstraístes": "abstrair",
    "abstrua": "abstruir",
    "abstruais": "abstruir",
    "abstruam": "abstruir",
    "abstruamo": "abstruir",
    "abstruamos": "abstruir",
    "abstruas": "abstruir",
    "abstruem": "abstruir",
    "abstrui": "abstruir",
    "abstruindo": "abstruir",
    "abstruirde": "abstruir",
    "abstruirdes": "abstruir",
    "abstruirei": "abstruir",
    "abstruireis": "abstruir",
    "abstruiremos": "abstruir",
    "abstruiria": "abstruir",
    "abstruiriam": "abstruir",
    "abstruirias": "abstruir",
    "abstruirmo": "abstruir",
    "abstruirmos": "abstruir",
    "abstruirá": "abstruir",
    "abstruirás": "abstruir",
    "abstruirão": "abstruir",
    "abstruiríamos": "abstruir",
    "abstruiríeis": "abstruir",
    "abstruis": "abstruir",
    "abstruiu": "abstruir",
    "abstruo": "abstruir",
    "abstrusa": "abstruso",
    "abstrusas": "abstruso",
    "abstrusidades": "abstrusidade",
    "abstrusos": "abstruso",
    "abstruí": "abstruir",
    "abstruía": "abstruir",
    "abstruíam": "abstruir",
    "abstruíamo": "abstruir",
    "abstruíamos": "abstruir",
    "abstruías": "abstruir",
    "abstruída": "abstruir",
    "abstruídas": "abstruir",
    "abstruído": "abstruir",
    "abstruídos": "abstruir",
    "abstruíei": "abstruir",
    "abstruíeis": "abstruir",
    "abstruímo": "abstruir",
    "abstruímos": "abstruir",
    "abstruíra": "abstruir",
    "abstruíram": "abstruir",
    "abstruíramo": "abstruir",
    "abstruíramos": "abstruir",
    "abstruíras": "abstruir",
    "abstruíre": "abstruir",
    "abstruírei": "abstruir",
    "abstruíreis": "abstruir",
    "abstruírem": "abstruir",
    "abstruíres": "abstruir",
    "abstruís": "abstruir",
    "abstruísse": "abstruir",
    "abstruísseis": "abstruir",
    "abstruíssem": "abstruir",
    "abstruíssemos": "abstruir",
    "abstruísses": "abstruir",
    "abstruíste": "abstruir",
    "abstruístes": "abstruir",
    "abstém": "abster",
    "abstémia": "abstémio",
    "abstémias": "abstémio",
    "abstémica": "abstémico",
    "abstémicas": "abstémico",
    "abstémicos": "abstémico",
    "abstémios": "abstémio",
    "absténs": "abster",
    "abstê": "abster",
    "abstêm": "abster",
    "abstínhamo": "abster",
    "abstínhamos": "abster",
    "abstínhei": "abster",
    "abstínheis": "abster",
    "absurda": "absurdo",
    "absurdas": "absurdo",
    "absurdidades": "absurdidade",
    "absurdismos": "absurdismo",
    "absurdos": "absurdo",
    "absurdíssima": "absurdo",
    "absurdíssimas": "absurdo",
    "absurdíssimo": "absurdo",
    "absurdíssimos": "absurdo",
    "absíntica": "absíntico",
    "absínticas": "absíntico",
    "absínticos": "absíntico",
    "absíntios": "absíntio",
    "abula": "abular",
    "abulada": "abular",
    "abuladas": "abular",
    "abulado": "abular",
    "abulados": "abular",
    "abulai": "abular",
    "abulais": "abular",
    "abulam": "abular",
    "abulamo": "abular",
    "abulamos": "abular",
    "abulando": "abular",
    "abulara": "abular",
    "abularam": "abular",
    "abularas": "abular",
    "abularde": "abular",
    "abulardes": "abular",
    "abulare": "abular",
    "abularei": "abular",
    "abulareis": "abular",
    "abularem": "abular",
    "abularemos": "abular",
    "abulares": "abular",
    "abularia": "abular",
    "abulariam": "abular",
    "abularias": "abular",
    "abularmo": "abular",
    "abularmos": "abular",
    "abulará": "abular",
    "abularás": "abular",
    "abularão": "abular",
    "abularíamos": "abular",
    "abularíeis": "abular",
    "abulas": "abular",
    "abulasse": "abular",
    "abulassem": "abular",
    "abulasses": "abular",
    "abulaste": "abular",
    "abulastes": "abular",
    "abulava": "abular",
    "abulavam": "abular",
    "abulavas": "abular",
    "abule": "abular",
    "abulei": "abular",
    "abuleis": "abular",
    "abulem": "abular",
    "abulemo": "abular",
    "abulemos": "abular",
    "abules": "abular",
    "abuli": "abolir",
    "abulias": "abulia",
    "abulo": "abular",
    "abulou": "abular",
    "abulá": "abular",
    "abulámo": "abular",
    "abulámos": "abular",
    "abuláramo": "abular",
    "abuláramos": "abular",
    "abulárei": "abular",
    "abuláreis": "abular",
    "abulásseis": "abular",
    "abulássemos": "abular",
    "abulávamo": "abular",
    "abulávamos": "abular",
    "abulávei": "abular",
    "abuláveis": "abular",
    "abunas": "abuna",
    "abunda": "abundar",
    "abundada": "abundar",
    "abundadas": "abundar",
    "abundado": "abundar",
    "abundados": "abundar",
    "abundai": "abundar",
    "abundais": "abundar",
    "abundam": "abundar",
    "abundamo": "abundar",
    "abundamos": "abundar",
    "abundando": "abundar",
    "abundantes": "abundante",
    "abundantíssima": "abundante",
    "abundantíssimas": "abundante",
    "abundantíssimo": "abundante",
    "abundantíssimos": "abundante",
    "abundara": "abundar",
    "abundaram": "abundar",
    "abundaras": "abundar",
    "abundarde": "abundar",
    "abundardes": "abundar",
    "abundare": "abundar",
    "abundarei": "abundar",
    "abundareis": "abundar",
    "abundarem": "abundar",
    "abundaremos": "abundar",
    "abundares": "abundar",
    "abundaria": "abundar",
    "abundariam": "abundar",
    "abundarias": "abundar",
    "abundarmo": "abundar",
    "abundarmos": "abundar",
    "abundará": "abundar",
    "abundarás": "abundar",
    "abundarão": "abundar",
    "abundaríamos": "abundar",
    "abundaríeis": "abundar",
    "abundas": "abundar",
    "abundasse": "abundar",
    "abundassem": "abundar",
    "abundasses": "abundar",
    "abundaste": "abundar",
    "abundastes": "abundar",
    "abundava": "abundar",
    "abundavam": "abundar",
    "abundavas": "abundar",
    "abunde": "abundar",
    "abundei": "abundar",
    "abundeis": "abundar",
    "abundem": "abundar",
    "abundemo": "abundar",
    "abundemos": "abundar",
    "abundes": "abundar",
    "abundo": "abundar",
    "abundou": "abundar",
    "abundá": "abundar",
    "abundámo": "abundar",
    "abundámos": "abundar",
    "abundáramo": "abundar",
    "abundáramos": "abundar",
    "abundárei": "abundar",
    "abundáreis": "abundar",
    "abundásseis": "abundar",
    "abundássemos": "abundar",
    "abundávamo": "abundar",
    "abundávamos": "abundar",
    "abundávei": "abundar",
    "abundáveis": "abundar",
    "abundâncias": "abundância",
    "abunha": "abunhar",
    "abunhada": "abunhar",
    "abunhadas": "abunhar",
    "abunhadios": "abunhadio",
    "abunhado": "abunhar",
    "abunhados": "abunhar",
    "abunhai": "abunhar",
    "abunhais": "abunhar",
    "abunham": "abunhar",
    "abunhamo": "abunhar",
    "abunhamos": "abunhar",
    "abunhando": "abunhar",
    "abunhara": "abunhar",
    "abunharam": "abunhar",
    "abunharas": "abunhar",
    "abunhardes": "abunhar",
    "abunharei": "abunhar",
    "abunhareis": "abunhar",
    "abunharem": "abunhar",
    "abunharemos": "abunhar",
    "abunhares": "abunhar",
    "abunharia": "abunhar",
    "abunhariam": "abunhar",
    "abunharias": "abunhar",
    "abunharmo": "abunhar",
    "abunharmos": "abunhar",
    "abunhará": "abunhar",
    "abunharás": "abunhar",
    "abunharão": "abunhar",
    "abunharíamos": "abunhar",
    "abunharíeis": "abunhar",
    "abunhas": "abunhar",
    "abunhasse": "abunhar",
    "abunhassem": "abunhar",
    "abunhasses": "abunhar",
    "abunhaste": "abunhar",
    "abunhastes": "abunhar",
    "abunhava": "abunhar",
    "abunhavam": "abunhar",
    "abunhavas": "abunhar",
    "abunhe": "abunhar",
    "abunhei": "abunhar",
    "abunheis": "abunhar",
    "abunhem": "abunhar",
    "abunhemo": "abunhar",
    "abunhemos": "abunhar",
    "abunhes": "abunhar",
    "abunho": "abunhar",
    "abunhou": "abunhar",
    "abunhámo": "abunhar",
    "abunhámos": "abunhar",
    "abunháramo": "abunhar",
    "abunháramos": "abunhar",
    "abunháreis": "abunhar",
    "abunhásseis": "abunhar",
    "abunhássemos": "abunhar",
    "abunhávamo": "abunhar",
    "abunhávamos": "abunhar",
    "abunháveis": "abunhar",
    "abunãs": "abunã",
    "aburela": "aburelar",
    "aburelada": "aburelar",
    "abureladas": "aburelar",
    "aburelado": "aburelar",
    "aburelados": "aburelar",
    "aburelai": "aburelar",
    "aburelais": "aburelar",
    "aburelam": "aburelar",
    "aburelamo": "aburelar",
    "aburelamos": "aburelar",
    "aburelando": "aburelar",
    "aburelara": "aburelar",
    "aburelaram": "aburelar",
    "aburelaras": "aburelar",
    "aburelarde": "aburelar",
    "aburelardes": "aburelar",
    "aburelare": "aburelar",
    "aburelarei": "aburelar",
    "aburelareis": "aburelar",
    "aburelarem": "aburelar",
    "aburelaremos": "aburelar",
    "aburelares": "aburelar",
    "aburelaria": "aburelar",
    "aburelariam": "aburelar",
    "aburelarias": "aburelar",
    "aburelarmo": "aburelar",
    "aburelarmos": "aburelar",
    "aburelará": "aburelar",
    "aburelarás": "aburelar",
    "aburelarão": "aburelar",
    "aburelaríamos": "aburelar",
    "aburelaríeis": "aburelar",
    "aburelas": "aburelar",
    "aburelasse": "aburelar",
    "aburelassem": "aburelar",
    "aburelasses": "aburelar",
    "aburelaste": "aburelar",
    "aburelastes": "aburelar",
    "aburelava": "aburelar",
    "aburelavam": "aburelar",
    "aburelavas": "aburelar",
    "aburele": "aburelar",
    "aburelei": "aburelar",
    "abureleis": "aburelar",
    "aburelem": "aburelar",
    "aburelemo": "aburelar",
    "aburelemos": "aburelar",
    "abureles": "aburelar",
    "aburelo": "aburelar",
    "aburelou": "aburelar",
    "aburelá": "aburelar",
    "aburelámo": "aburelar",
    "aburelámos": "aburelar",
    "abureláramo": "aburelar",
    "abureláramos": "aburelar",
    "aburelárei": "aburelar",
    "abureláreis": "aburelar",
    "aburelásseis": "aburelar",
    "aburelássemos": "aburelar",
    "aburelávamo": "aburelar",
    "aburelávamos": "aburelar",
    "aburelávei": "aburelar",
    "abureláveis": "aburelar",
    "aburguesa": "aburguesar",
    "aburguesada": "aburguesar",
    "aburguesadas": "aburguesar",
    "aburguesado": "aburguesar",
    "aburguesados": "aburguesar",
    "aburguesadíssima": "aburguesado",
    "aburguesadíssimas": "aburguesado",
    "aburguesadíssimo": "aburguesado",
    "aburguesadíssimos": "aburguesado",
    "aburguesai": "aburguesar",
    "aburguesais": "aburguesar",
    "aburguesam": "aburguesar",
    "aburguesamentos": "aburguesamento",
    "aburguesamo": "aburguesar",
    "aburguesamos": "aburguesar",
    "aburguesando": "aburguesar",
    "aburguesara": "aburguesar",
    "aburguesaram": "aburguesar",
    "aburguesaras": "aburguesar",
    "aburguesarde": "aburguesar",
    "aburguesardes": "aburguesar",
    "aburguesare": "aburguesar",
    "aburguesarei": "aburguesar",
    "aburguesareis": "aburguesar",
    "aburguesarem": "aburguesar",
    "aburguesaremos": "aburguesar",
    "aburguesares": "aburguesar",
    "aburguesaria": "aburguesar",
    "aburguesariam": "aburguesar",
    "aburguesarias": "aburguesar",
    "aburguesarmo": "aburguesar",
    "aburguesarmos": "aburguesar",
    "aburguesará": "aburguesar",
    "aburguesarás": "aburguesar",
    "aburguesarão": "aburguesar",
    "aburguesaríamos": "aburguesar",
    "aburguesaríeis": "aburguesar",
    "aburguesas": "aburguesar",
    "aburguesasse": "aburguesar",
    "aburguesassem": "aburguesar",
    "aburguesasses": "aburguesar",
    "aburguesaste": "aburguesar",
    "aburguesastes": "aburguesar",
    "aburguesava": "aburguesar",
    "aburguesavam": "aburguesar",
    "aburguesavas": "aburguesar",
    "aburguese": "aburguesar",
    "aburguesei": "aburguesar",
    "aburgueseis": "aburguesar",
    "aburguesem": "aburguesar",
    "aburguesemo": "aburguesar",
    "aburguesemos": "aburguesar",
    "aburgueses": "aburguesar",
    "aburgueso": "aburguesar",
    "aburguesou": "aburguesar",
    "aburguesá": "aburguesar",
    "aburguesámo": "aburguesar",
    "aburguesámos": "aburguesar",
    "aburguesáramo": "aburguesar",
    "aburguesáramos": "aburguesar",
    "aburguesárei": "aburguesar",
    "aburguesáreis": "aburguesar",
    "aburguesásseis": "aburguesar",
    "aburguesássemos": "aburguesar",
    "aburguesávamo": "aburguesar",
    "aburguesávamos": "aburguesar",
    "aburguesávei": "aburguesar",
    "aburguesáveis": "aburguesar",
    "aburila": "aburilar",
    "aburilada": "aburilar",
    "aburiladas": "aburilar",
    "aburilado": "aburilar",
    "aburilados": "aburilar",
    "aburilai": "aburilar",
    "aburilais": "aburilar",
    "aburilam": "aburilar",
    "aburilamo": "aburilar",
    "aburilamos": "aburilar",
    "aburilando": "aburilar",
    "aburilara": "aburilar",
    "aburilaram": "aburilar",
    "aburilaras": "aburilar",
    "aburilarde": "aburilar",
    "aburilardes": "aburilar",
    "aburilare": "aburilar",
    "aburilarei": "aburilar",
    "aburilareis": "aburilar",
    "aburilarem": "aburilar",
    "aburilaremos": "aburilar",
    "aburilares": "aburilar",
    "aburilaria": "aburilar",
    "aburilariam": "aburilar",
    "aburilarias": "aburilar",
    "aburilarmo": "aburilar",
    "aburilarmos": "aburilar",
    "aburilará": "aburilar",
    "aburilarás": "aburilar",
    "aburilarão": "aburilar",
    "aburilaríamos": "aburilar",
    "aburilaríeis": "aburilar",
    "aburilas": "aburilar",
    "aburilasse": "aburilar",
    "aburilassem": "aburilar",
    "aburilasses": "aburilar",
    "aburilaste": "aburilar",
    "aburilastes": "aburilar",
    "aburilava": "aburilar",
    "aburilavam": "aburilar",
    "aburilavas": "aburilar",
    "aburile": "aburilar",
    "aburilei": "aburilar",
    "aburileis": "aburilar",
    "aburilem": "aburilar",
    "aburilemo": "aburilar",
    "aburilemos": "aburilar",
    "aburiles": "aburilar",
    "aburilo": "aburilar",
    "aburilou": "aburilar",
    "aburilá": "aburilar",
    "aburilámo": "aburilar",
    "aburilámos": "aburilar",
    "aburiláramo": "aburilar",
    "aburiláramos": "aburilar",
    "aburilárei": "aburilar",
    "aburiláreis": "aburilar",
    "aburilásseis": "aburilar",
    "aburilássemos": "aburilar",
    "aburilávamo": "aburilar",
    "aburilávamos": "aburilar",
    "aburilávei": "aburilar",
    "aburiláveis": "aburilar",
    "aburra": "aburrar",
    "aburrada": "aburrar",
    "aburradas": "aburrar",
    "aburrado": "aburrar",
    "aburrados": "aburrar",
    "aburrai": "aburrar",
    "aburrais": "aburrar",
    "aburram": "aburrar",
    "aburramo": "aburrar",
    "aburramos": "aburrar",
    "aburrando": "aburrar",
    "aburrara": "aburrar",
    "aburraram": "aburrar",
    "aburraras": "aburrar",
    "aburrardes": "aburrar",
    "aburrarei": "aburrar",
    "aburrareis": "aburrar",
    "aburrarem": "aburrar",
    "aburraremos": "aburrar",
    "aburrares": "aburrar",
    "aburraria": "aburrar",
    "aburrariam": "aburrar",
    "aburrarias": "aburrar",
    "aburrarmo": "aburrar",
    "aburrarmos": "aburrar",
    "aburrará": "aburrar",
    "aburrarás": "aburrar",
    "aburrarão": "aburrar",
    "aburraríamos": "aburrar",
    "aburraríeis": "aburrar",
    "aburras": "aburrar",
    "aburrasse": "aburrar",
    "aburrassem": "aburrar",
    "aburrasses": "aburrar",
    "aburraste": "aburrar",
    "aburrastes": "aburrar",
    "aburrava": "aburrar",
    "aburravam": "aburrar",
    "aburravas": "aburrar",
    "aburre": "aburrar",
    "aburrei": "aburrar",
    "aburreis": "aburrar",
    "aburrem": "aburrar",
    "aburremo": "aburrar",
    "aburremos": "aburrar",
    "aburres": "aburrar",
    "aburro": "aburrar",
    "aburrou": "aburrar",
    "aburrámo": "aburrar",
    "aburrámos": "aburrar",
    "aburráramo": "aburrar",
    "aburráramos": "aburrar",
    "aburráreis": "aburrar",
    "aburrásseis": "aburrar",
    "aburrássemos": "aburrar",
    "aburrávamo": "aburrar",
    "aburrávamos": "aburrar",
    "aburráveis": "aburrar",
    "abusa": "abusar",
    "abusada": "abusar",
    "abusadas": "abusar",
    "abusado": "abusar",
    "abusadora": "abusador",
    "abusadoras": "abusador",
    "abusadores": "abusador",
    "abusados": "abusar",
    "abusai": "abusar",
    "abusais": "abusar",
    "abusam": "abusar",
    "abusamo": "abusar",
    "abusamos": "abusar",
    "abusando": "abusar",
    "abusara": "abusar",
    "abusaram": "abusar",
    "abusaras": "abusar",
    "abusarde": "abusar",
    "abusardes": "abusar",
    "abusare": "abusar",
    "abusarei": "abusar",
    "abusareis": "abusar",
    "abusarem": "abusar",
    "abusaremos": "abusar",
    "abusares": "abusar",
    "abusaria": "abusar",
    "abusariam": "abusar",
    "abusarias": "abusar",
    "abusarmo": "abusar",
    "abusarmos": "abusar",
    "abusará": "abusar",
    "abusarás": "abusar",
    "abusarão": "abusar",
    "abusaríamos": "abusar",
    "abusaríeis": "abusar",
    "abusas": "abusar",
    "abusasse": "abusar",
    "abusassem": "abusar",
    "abusasses": "abusar",
    "abusaste": "abusar",
    "abusastes": "abusar",
    "abusava": "abusar",
    "abusavam": "abusar",
    "abusavas": "abusar",
    "abuse": "abusar",
    "abusei": "abusar",
    "abuseis": "abusar",
    "abusem": "abusar",
    "abusemo": "abusar",
    "abusemos": "abusar",
    "abuses": "abusar",
    "abusiva": "abusivo",
    "abusivas": "abusivo",
    "abusivos": "abusivo",
    "abuso": "abusar",
    "abusos": "abuso",
    "abusou": "abusar",
    "abusá": "abusar",
    "abusámo": "abusar",
    "abusámos": "abusar",
    "abusáramo": "abusar",
    "abusáramos": "abusar",
    "abusárei": "abusar",
    "abusáreis": "abusar",
    "abusásseis": "abusar",
    "abusássemos": "abusar",
    "abusávamo": "abusar",
    "abusávamos": "abusar",
    "abusávei": "abusar",
    "abusáveis": "abusar",
    "abusões": "abusão",
    "abutas": "abuta",
    "abutreira": "abutreiro",
    "abutreiras": "abutreiro",
    "abutreiros": "abutreiro",
    "abutres": "abutre",
    "abutuas": "abutua",
    "abuzina": "abuzinar",
    "abuzinada": "abuzinar",
    "abuzinadas": "abuzinar",
    "abuzinado": "abuzinar",
    "abuzinados": "abuzinar",
    "abuzinai": "abuzinar",
    "abuzinais": "abuzinar",
    "abuzinam": "abuzinar",
    "abuzinamo": "abuzinar",
    "abuzinamos": "abuzinar",
    "abuzinando": "abuzinar",
    "abuzinara": "abuzinar",
    "abuzinaram": "abuzinar",
    "abuzinaras": "abuzinar",
    "abuzinardes": "abuzinar",
    "abuzinarei": "abuzinar",
    "abuzinareis": "abuzinar",
    "abuzinarem": "abuzinar",
    "abuzinaremos": "abuzinar",
    "abuzinares": "abuzinar",
    "abuzinaria": "abuzinar",
    "abuzinariam": "abuzinar",
    "abuzinarias": "abuzinar",
    "abuzinarmo": "abuzinar",
    "abuzinarmos": "abuzinar",
    "abuzinará": "abuzinar",
    "abuzinarás": "abuzinar",
    "abuzinarão": "abuzinar",
    "abuzinaríamos": "abuzinar",
    "abuzinaríeis": "abuzinar",
    "abuzinas": "abuzinar",
    "abuzinasse": "abuzinar",
    "abuzinassem": "abuzinar",
    "abuzinasses": "abuzinar",
    "abuzinaste": "abuzinar",
    "abuzinastes": "abuzinar",
    "abuzinava": "abuzinar",
    "abuzinavam": "abuzinar",
    "abuzinavas": "abuzinar",
    "abuzine": "abuzinar",
    "abuzinei": "abuzinar",
    "abuzineis": "abuzinar",
    "abuzinem": "abuzinar",
    "abuzinemo": "abuzinar",
    "abuzinemos": "abuzinar",
    "abuzines": "abuzinar",
    "abuzino": "abuzinar",
    "abuzinou": "abuzinar",
    "abuzinámo": "abuzinar",
    "abuzinámos": "abuzinar",
    "abuzináramo": "abuzinar",
    "abuzináramos": "abuzinar",
    "abuzináreis": "abuzinar",
    "abuzinásseis": "abuzinar",
    "abuzinássemos": "abuzinar",
    "abuzinávamo": "abuzinar",
    "abuzinávamos": "abuzinar",
    "abuzináveis": "abuzinar",
    "abá": "abar",
    "abáculos": "abáculo",
    "abádidas": "abádida",
    "abámo": "abar",
    "abámos": "abar",
    "abáramo": "abar",
    "abáramos": "abar",
    "abárei": "abar",
    "abáreis": "abar",
    "abásseis": "abar",
    "abássemos": "abar",
    "abávamo": "abar",
    "abávamos": "abar",
    "abávei": "abar",
    "abáveis": "abar",
    "abéculas": "abécula",
    "abêberas": "abêbera",
    "abóbadas": "abóbada",
    "abóboras": "abóbora",
    "abúlica": "abúlico",
    "abúlicas": "abúlico",
    "abúlicos": "abúlico",
    "abútuas": "abútua",
    "acaba": "acabar",
    "acabace": "acabaçar",
    "acabacei": "acabaçar",
    "acabaceis": "acabaçar",
    "acabacem": "acabaçar",
    "acabacemo": "acabaçar",
    "acabacemos": "acabaçar",
    "acabaces": "acabaçar",
    "acabada": "acabar",
    "acabadas": "acabar",
    "acabadinha": "acabado",
    "acabadinhas": "acabado",
    "acabadinho": "acabado",
    "acabadinhos": "acabado",
    "acabadita": "acabado",
    "acabaditas": "acabado",
    "acabadito": "acabado",
    "acabaditos": "acabado",
    "acabado": "acabar",
    "acabadora": "acabador",
    "acabadoras": "acabador",
    "acabadores": "acabador",
    "acabados": "acabar",
    "acabadotes": "acabadote",
    "acabadíssima": "acabado",
    "acabadíssimas": "acabado",
    "acabadíssimo": "acabado",
    "acabadíssimos": "acabado",
    "acabai": "acabar",
    "acabais": "acabar",
    "acabam": "acabar",
    "acabamentos": "acabamento",
    "acabamo": "acabar",
    "acabamos": "acabar",
    "acabana": "acabanar",
    "acabanada": "acabanar",
    "acabanadas": "acabanar",
    "acabanado": "acabanar",
    "acabanados": "acabanar",
    "acabanai": "acabanar",
    "acabanais": "acabanar",
    "acabanam": "acabanar",
    "acabanamo": "acabanar",
    "acabanamos": "acabanar",
    "acabanando": "acabanar",
    "acabanara": "acabanar",
    "acabanaram": "acabanar",
    "acabanaras": "acabanar",
    "acabanarde": "acabanar",
    "acabanardes": "acabanar",
    "acabanare": "acabanar",
    "acabanarei": "acabanar",
    "acabanareis": "acabanar",
    "acabanarem": "acabanar",
    "acabanaremos": "acabanar",
    "acabanares": "acabanar",
    "acabanaria": "acabanar",
    "acabanariam": "acabanar",
    "acabanarias": "acabanar",
    "acabanarmo": "acabanar",
    "acabanarmos": "acabanar",
    "acabanará": "acabanar",
    "acabanarás": "acabanar",
    "acabanarão": "acabanar",
    "acabanaríamos": "acabanar",
    "acabanaríeis": "acabanar",
    "acabanas": "acabanar",
    "acabanasse": "acabanar",
    "acabanassem": "acabanar",
    "acabanasses": "acabanar",
    "acabanaste": "acabanar",
    "acabanastes": "acabanar",
    "acabanava": "acabanar",
    "acabanavam": "acabanar",
    "acabanavas": "acabanar",
    "acabando": "acabar",
    "acabane": "acabanar",
    "acabanei": "acabanar",
    "acabaneis": "acabanar",
    "acabanem": "acabanar",
    "acabanemo": "acabanar",
    "acabanemos": "acabanar",
    "acabanes": "acabanar",
    "acabano": "acabanar",
    "acabanou": "acabanar",
    "acabaná": "acabanar",
    "acabanámo": "acabanar",
    "acabanámos": "acabanar",
    "acabanáramo": "acabanar",
    "acabanáramos": "acabanar",
    "acabanárei": "acabanar",
    "acabanáreis": "acabanar",
    "acabanásseis": "acabanar",
    "acabanássemos": "acabanar",
    "acabanávamo": "acabanar",
    "acabanávamos": "acabanar",
    "acabanávei": "acabanar",
    "acabanáveis": "acabanar",
    "acabara": "acabar",
    "acabaram": "acabar",
    "acabaras": "acabar",
    "acabarde": "acabar",
    "acabardes": "acabar",
    "acabare": "acabar",
    "acabarei": "acabar",
    "acabareis": "acabar",
    "acabarem": "acabar",
    "acabaremos": "acabar",
    "acabares": "acabar",
    "acabaria": "acabar",
    "acabariam": "acabar",
    "acabarias": "acabar",
    "acabarmo": "acabar",
    "acabarmos": "acabar",
    "acabará": "acabar",
    "acabarás": "acabar",
    "acabarão": "acabar",
    "acabaríamos": "acabar",
    "acabaríeis": "acabar",
    "acabas": "acabar",
    "acabasse": "acabar",
    "acabassem": "acabar",
    "acabasses": "acabar",
    "acabaste": "acabar",
    "acabastes": "acabar",
    "acabava": "acabar",
    "acabavam": "acabar",
    "acabavas": "acabar",
    "acabaça": "acabaçar",
    "acabaçada": "acabaçar",
    "acabaçadas": "acabaçar",
    "acabaçado": "acabaçar",
    "acabaçados": "acabaçar",
    "acabaçai": "acabaçar",
    "acabaçais": "acabaçar",
    "acabaçam": "acabaçar",
    "acabaçamo": "acabaçar",
    "acabaçamos": "acabaçar",
    "acabaçando": "acabaçar",
    "acabaçara": "acabaçar",
    "acabaçaram": "acabaçar",
    "acabaçaras": "acabaçar",
    "acabaçarde": "acabaçar",
    "acabaçardes": "acabaçar",
    "acabaçare": "acabaçar",
    "acabaçarei": "acabaçar",
    "acabaçareis": "acabaçar",
    "acabaçarem": "acabaçar",
    "acabaçaremos": "acabaçar",
    "acabaçares": "acabaçar",
    "acabaçaria": "acabaçar",
    "acabaçariam": "acabaçar",
    "acabaçarias": "acabaçar",
    "acabaçarmo": "acabaçar",
    "acabaçarmos": "acabaçar",
    "acabaçará": "acabaçar",
    "acabaçarás": "acabaçar",
    "acabaçarão": "acabaçar",
    "acabaçaríamos": "acabaçar",
    "acabaçaríeis": "acabaçar",
    "acabaças": "acabaçar",
    "acabaçasse": "acabaçar",
    "acabaçassem": "acabaçar",
    "acabaçasses": "acabaçar",
    "acabaçaste": "acabaçar",
    "acabaçastes": "acabaçar",
    "acabaçava": "acabaçar",
    "acabaçavam": "acabaçar",
    "acabaçavas": "acabaçar",
    "acabaço": "acabaçar",
    "acabaçou": "acabaçar",
    "acabaçá": "acabaçar",
    "acabaçámo": "acabaçar",
    "acabaçámos": "acabaçar",
    "acabaçáramo": "acabaçar",
    "acabaçáramos": "acabaçar",
    "acabaçárei": "acabaçar",
    "acabaçáreis": "acabaçar",
    "acabaçásseis": "acabaçar",
    "acabaçássemos": "acabaçar",
    "acabaçávamo": "acabaçar",
    "acabaçávamos": "acabaçar",
    "acabaçávei": "acabaçar",
    "acabaçáveis": "acabaçar",
    "acabe": "acabar",
    "acabei": "acabar",
    "acabeis": "acabar",
    "acabela": "acabelar",
    "acabelada": "acabelar",
    "acabeladas": "acabelar",
    "acabelado": "acabelar",
    "acabelados": "acabelar",
    "acabelai": "acabelar",
    "acabelais": "acabelar",
    "acabelam": "acabelar",
    "acabelamo": "acabelar",
    "acabelamos": "acabelar",
    "acabelando": "acabelar",
    "acabelara": "acabelar",
    "acabelaram": "acabelar",
    "acabelaras": "acabelar",
    "acabelardes": "acabelar",
    "acabelarei": "acabelar",
    "acabelareis": "acabelar",
    "acabelarem": "acabelar",
    "acabelaremos": "acabelar",
    "acabelares": "acabelar",
    "acabelaria": "acabelar",
    "acabelariam": "acabelar",
    "acabelarias": "acabelar",
    "acabelarmo": "acabelar",
    "acabelarmos": "acabelar",
    "acabelará": "acabelar",
    "acabelarás": "acabelar",
    "acabelarão": "acabelar",
    "acabelaríamos": "acabelar",
    "acabelaríeis": "acabelar",
    "acabelas": "acabelar",
    "acabelasse": "acabelar",
    "acabelassem": "acabelar",
    "acabelasses": "acabelar",
    "acabelaste": "acabelar",
    "acabelastes": "acabelar",
    "acabelava": "acabelar",
    "acabelavam": "acabelar",
    "acabelavas": "acabelar",
    "acabele": "acabelar",
    "acabelei": "acabelar",
    "acabeleis": "acabelar",
    "acabelem": "acabelar",
    "acabelemo": "acabelar",
    "acabelemos": "acabelar",
    "acabeles": "acabelar",
    "acabelo": "acabelar",
    "acabelou": "acabelar",
    "acabelámo": "acabelar",
    "acabelámos": "acabelar",
    "acabeláramo": "acabelar",
    "acabeláramos": "acabelar",
    "acabeláreis": "acabelar",
    "acabelásseis": "acabelar",
    "acabelássemos": "acabelar",
    "acabelávamo": "acabelar",
    "acabelávamos": "acabelar",
    "acabeláveis": "acabelar",
    "acabem": "acabar",
    "acabemo": "acabar",
    "acabemos": "acabar",
    "acabes": "acabar",
    "acabo": "acabar",
    "acaboclada": "acaboclado",
    "acabocladas": "acaboclado",
    "acaboclados": "acaboclado",
    "acabou": "acabar",
    "acabrama": "acabramar",
    "acabramada": "acabramar",
    "acabramadas": "acabramar",
    "acabramado": "acabramar",
    "acabramados": "acabramar",
    "acabramai": "acabramar",
    "acabramais": "acabramar",
    "acabramam": "acabramar",
    "acabramamo": "acabramar",
    "acabramamos": "acabramar",
    "acabramando": "acabramar",
    "acabramara": "acabramar",
    "acabramaram": "acabramar",
    "acabramaras": "acabramar",
    "acabramarde": "acabramar",
    "acabramardes": "acabramar",
    "acabramare": "acabramar",
    "acabramarei": "acabramar",
    "acabramareis": "acabramar",
    "acabramarem": "acabramar",
    "acabramaremos": "acabramar",
    "acabramares": "acabramar",
    "acabramaria": "acabramar",
    "acabramariam": "acabramar",
    "acabramarias": "acabramar",
    "acabramarmo": "acabramar",
    "acabramarmos": "acabramar",
    "acabramará": "acabramar",
    "acabramarás": "acabramar",
    "acabramarão": "acabramar",
    "acabramaríamos": "acabramar",
    "acabramaríeis": "acabramar",
    "acabramas": "acabramar",
    "acabramasse": "acabramar",
    "acabramassem": "acabramar",
    "acabramasses": "acabramar",
    "acabramaste": "acabramar",
    "acabramastes": "acabramar",
    "acabramava": "acabramar",
    "acabramavam": "acabramar",
    "acabramavas": "acabramar",
    "acabrame": "acabramar",
    "acabramei": "acabramar",
    "acabrameis": "acabramar",
    "acabramem": "acabramar",
    "acabramemo": "acabramar",
    "acabramemos": "acabramar",
    "acabrames": "acabramar",
    "acabramo": "acabramar",
    "acabramos": "acabramo",
    "acabramou": "acabramar",
    "acabramá": "acabramar",
    "acabramámo": "acabramar",
    "acabramámos": "acabramar",
    "acabramáramo": "acabramar",
    "acabramáramos": "acabramar",
    "acabramárei": "acabramar",
    "acabramáreis": "acabramar",
    "acabramásseis": "acabramar",
    "acabramássemos": "acabramar",
    "acabramávamo": "acabramar",
    "acabramávamos": "acabramar",
    "acabramávei": "acabramar",
    "acabramáveis": "acabramar",
    "acabrunha": "acabrunhar",
    "acabrunhada": "acabrunhar",
    "acabrunhadas": "acabrunhar",
    "acabrunhado": "acabrunhar",
    "acabrunhadora": "acabrunhador",
    "acabrunhadoras": "acabrunhador",
    "acabrunhadores": "acabrunhador",
    "acabrunhados": "acabrunhar",
    "acabrunhadíssima": "acabrunhado",
    "acabrunhadíssimas": "acabrunhado",
    "acabrunhadíssimo": "acabrunhado",
    "acabrunhadíssimos": "acabrunhado",
    "acabrunhai": "acabrunhar",
    "acabrunhais": "acabrunhar",
    "acabrunham": "acabrunhar",
    "acabrunhamentos": "acabrunhamento",
    "acabrunhamo": "acabrunhar",
    "acabrunhamos": "acabrunhar",
    "acabrunhando": "acabrunhar",
    "acabrunhantes": "acabrunhante",
    "acabrunhara": "acabrunhar",
    "acabrunharam": "acabrunhar",
    "acabrunharas": "acabrunhar",
    "acabrunharde": "acabrunhar",
    "acabrunhardes": "acabrunhar",
    "acabrunhare": "acabrunhar",
    "acabrunharei": "acabrunhar",
    "acabrunhareis": "acabrunhar",
    "acabrunharem": "acabrunhar",
    "acabrunharemos": "acabrunhar",
    "acabrunhares": "acabrunhar",
    "acabrunharia": "acabrunhar",
    "acabrunhariam": "acabrunhar",
    "acabrunharias": "acabrunhar",
    "acabrunharmo": "acabrunhar",
    "acabrunharmos": "acabrunhar",
    "acabrunhará": "acabrunhar",
    "acabrunharás": "acabrunhar",
    "acabrunharão": "acabrunhar",
    "acabrunharíamos": "acabrunhar",
    "acabrunharíeis": "acabrunhar",
    "acabrunhas": "acabrunhar",
    "acabrunhasse": "acabrunhar",
    "acabrunhassem": "acabrunhar",
    "acabrunhasses": "acabrunhar",
    "acabrunhaste": "acabrunhar",
    "acabrunhastes": "acabrunhar",
    "acabrunhava": "acabrunhar",
    "acabrunhavam": "acabrunhar",
    "acabrunhavas": "acabrunhar",
    "acabrunhe": "acabrunhar",
    "acabrunhei": "acabrunhar",
    "acabrunheis": "acabrunhar",
    "acabrunhem": "acabrunhar",
    "acabrunhemo": "acabrunhar",
    "acabrunhemos": "acabrunhar",
    "acabrunhes": "acabrunhar",
    "acabrunho": "acabrunhar",
    "acabrunhou": "acabrunhar",
    "acabrunhá": "acabrunhar",
    "acabrunhámo": "acabrunhar",
    "acabrunhámos": "acabrunhar",
    "acabrunháramo": "acabrunhar",
    "acabrunháramos": "acabrunhar",
    "acabrunhárei": "acabrunhar",
    "acabrunháreis": "acabrunhar",
    "acabrunhásseis": "acabrunhar",
    "acabrunhássemos": "acabrunhar",
    "acabrunhávamo": "acabrunhar",
    "acabrunhávamos": "acabrunhar",
    "acabrunhávei": "acabrunhar",
    "acabrunháveis": "acabrunhar",
    "acabá": "acabar",
    "acabámo": "acabar",
    "acabámos": "acabar",
    "acabáramo": "acabar",
    "acabáramos": "acabar",
    "acabárei": "acabar",
    "acabáreis": "acabar",
    "acabásseis": "acabar",
    "acabássemos": "acabar",
    "acabávamo": "acabar",
    "acabávamos": "acabar",
    "acabávei": "acabar",
    "acabáveis": "acabar",
    "acachapa": "acachapar",
    "acachapada": "acachapar",
    "acachapadas": "acachapar",
    "acachapado": "acachapar",
    "acachapados": "acachapar",
    "acachapai": "acachapar",
    "acachapais": "acachapar",
    "acachapam": "acachapar",
    "acachapamo": "acachapar",
    "acachapamos": "acachapar",
    "acachapando": "acachapar",
    "acachapara": "acachapar",
    "acachaparam": "acachapar",
    "acachaparas": "acachapar",
    "acachaparde": "acachapar",
    "acachapardes": "acachapar",
    "acachapare": "acachapar",
    "acachaparei": "acachapar",
    "acachapareis": "acachapar",
    "acachaparem": "acachapar",
    "acachaparemos": "acachapar",
    "acachapares": "acachapar",
    "acachaparia": "acachapar",
    "acachapariam": "acachapar",
    "acachaparias": "acachapar",
    "acachaparmo": "acachapar",
    "acachaparmos": "acachapar",
    "acachapará": "acachapar",
    "acachaparás": "acachapar",
    "acachaparão": "acachapar",
    "acachaparíamos": "acachapar",
    "acachaparíeis": "acachapar",
    "acachapas": "acachapar",
    "acachapasse": "acachapar",
    "acachapassem": "acachapar",
    "acachapasses": "acachapar",
    "acachapaste": "acachapar",
    "acachapastes": "acachapar",
    "acachapava": "acachapar",
    "acachapavam": "acachapar",
    "acachapavas": "acachapar",
    "acachape": "acachapar",
    "acachapei": "acachapar",
    "acachapeis": "acachapar",
    "acachapem": "acachapar",
    "acachapemo": "acachapar",
    "acachapemos": "acachapar",
    "acachapes": "acachapar",
    "acachapo": "acachapar",
    "acachapou": "acachapar",
    "acachapá": "acachapar",
    "acachapámo": "acachapar",
    "acachapámos": "acachapar",
    "acachapáramo": "acachapar",
    "acachapáramos": "acachapar",
    "acachapárei": "acachapar",
    "acachapáreis": "acachapar",
    "acachapásseis": "acachapar",
    "acachapássemos": "acachapar",
    "acachapávamo": "acachapar",
    "acachapávamos": "acachapar",
    "acachapávei": "acachapar",
    "acachapáveis": "acachapar",
    "acachoa": "acachoar",
    "acachoada": "acachoar",
    "acachoadas": "acachoar",
    "acachoado": "acachoar",
    "acachoados": "acachoar",
    "acachoai": "acachoar",
    "acachoais": "acachoar",
    "acachoam": "acachoar",
    "acachoamo": "acachoar",
    "acachoamos": "acachoar",
    "acachoando": "acachoar",
    "acachoara": "acachoar",
    "acachoaram": "acachoar",
    "acachoaras": "acachoar",
    "acachoardes": "acachoar",
    "acachoarei": "acachoar",
    "acachoareis": "acachoar",
    "acachoarem": "acachoar",
    "acachoaremos": "acachoar",
    "acachoares": "acachoar",
    "acachoaria": "acachoar",
    "acachoariam": "acachoar",
    "acachoarias": "acachoar",
    "acachoarmo": "acachoar",
    "acachoarmos": "acachoar",
    "acachoará": "acachoar",
    "acachoarás": "acachoar",
    "acachoarão": "acachoar",
    "acachoaríamos": "acachoar",
    "acachoaríeis": "acachoar",
    "acachoas": "acachoar",
    "acachoasse": "acachoar",
    "acachoassem": "acachoar",
    "acachoasses": "acachoar",
    "acachoaste": "acachoar",
    "acachoastes": "acachoar",
    "acachoava": "acachoar",
    "acachoavam": "acachoar",
    "acachoavas": "acachoar",
    "acachoe": "acachoar",
    "acachoei": "acachoar",
    "acachoeis": "acachoar",
    "acachoem": "acachoar",
    "acachoemo": "acachoar",
    "acachoemos": "acachoar",
    "acachoes": "acachoar",
    "acachoo": "acachoar",
    "acachoou": "acachoar",
    "acachoámo": "acachoar",
    "acachoámos": "acachoar",
    "acachoáramo": "acachoar",
    "acachoáramos": "acachoar",
    "acachoáreis": "acachoar",
    "acachoásseis": "acachoar",
    "acachoássemos": "acachoar",
    "acachoávamo": "acachoar",
    "acachoávamos": "acachoar",
    "acachoáveis": "acachoar",
    "acaciana": "acaciano",
    "acacianas": "acaciano",
    "acacianos": "acaciano",
    "acacifa": "acacifar",
    "acacifada": "acacifar",
    "acacifadas": "acacifar",
    "acacifado": "acacifar",
    "acacifados": "acacifar",
    "acacifai": "acacifar",
    "acacifais": "acacifar",
    "acacifam": "acacifar",
    "acacifamo": "acacifar",
    "acacifamos": "acacifar",
    "acacifando": "acacifar",
    "acacifara": "acacifar",
    "acacifaram": "acacifar",
    "acacifaras": "acacifar",
    "acacifarde": "acacifar",
    "acacifardes": "acacifar",
    "acacifare": "acacifar",
    "acacifarei": "acacifar",
    "acacifareis": "acacifar",
    "acacifarem": "acacifar",
    "acacifaremos": "acacifar",
    "acacifares": "acacifar",
    "acacifaria": "acacifar",
    "acacifariam": "acacifar",
    "acacifarias": "acacifar",
    "acacifarmo": "acacifar",
    "acacifarmos": "acacifar",
    "acacifará": "acacifar",
    "acacifarás": "acacifar",
    "acacifarão": "acacifar",
    "acacifaríamos": "acacifar",
    "acacifaríeis": "acacifar",
    "acacifas": "acacifar",
    "acacifasse": "acacifar",
    "acacifassem": "acacifar",
    "acacifasses": "acacifar",
    "acacifaste": "acacifar",
    "acacifastes": "acacifar",
    "acacifava": "acacifar",
    "acacifavam": "acacifar",
    "acacifavas": "acacifar",
    "acacife": "acacifar",
    "acacifei": "acacifar",
    "acacifeis": "acacifar",
    "acacifem": "acacifar",
    "acacifemo": "acacifar",
    "acacifemos": "acacifar",
    "acacifes": "acacifar",
    "acacifo": "acacifar",
    "acacifou": "acacifar",
    "acacifá": "acacifar",
    "acacifámo": "acacifar",
    "acacifámos": "acacifar",
    "acacifáramo": "acacifar",
    "acacifáramos": "acacifar",
    "acacifárei": "acacifar",
    "acacifáreis": "acacifar",
    "acacifásseis": "acacifar",
    "acacifássemos": "acacifar",
    "acacifávamo": "acacifar",
    "acacifávamos": "acacifar",
    "acacifávei": "acacifar",
    "acacifáveis": "acacifar",
    "academia": "academiar",
    "academiada": "academiar",
    "academiadas": "academiar",
    "academiado": "academiar",
    "academiados": "academiar",
    "academiai": "academiar",
    "academiais": "academiar",
    "academiam": "academiar",
    "academiamo": "academiar",
    "academiamos": "academiar",
    "academiando": "academiar",
    "academiara": "academiar",
    "academiaram": "academiar",
    "academiaras": "academiar",
    "academiarde": "academiar",
    "academiardes": "academiar",
    "academiare": "academiar",
    "academiarei": "academiar",
    "academiareis": "academiar",
    "academiarem": "academiar",
    "academiaremos": "academiar",
    "academiares": "academiar",
    "academiaria": "academiar",
    "academiariam": "academiar",
    "academiarias": "academiar",
    "academiarmo": "academiar",
    "academiarmos": "academiar",
    "academiará": "academiar",
    "academiarás": "academiar",
    "academiarão": "academiar",
    "academiaríamos": "academiar",
    "academiaríeis": "academiar",
    "academias": "academiar",
    "academiasse": "academiar",
    "academiassem": "academiar",
    "academiasses": "academiar",
    "academiaste": "academiar",
    "academiastes": "academiar",
    "academiava": "academiar",
    "academiavam": "academiar",
    "academiavas": "academiar",
    "academicismos": "academicismo",
    "academie": "academiar",
    "academiei": "academiar",
    "academieis": "academiar",
    "academiem": "academiar",
    "academiemo": "academiar",
    "academiemos": "academiar",
    "academies": "academiar",
    "academio": "academiar",
    "academiou": "academiar",
    "academismos": "academismo",
    "academistas": "academista",
    "academiá": "academiar",
    "academiámo": "academiar",
    "academiámos": "academiar",
    "academiáramo": "academiar",
    "academiáramos": "academiar",
    "academiárei": "academiar",
    "academiáreis": "academiar",
    "academiásseis": "academiar",
    "academiássemos": "academiar",
    "academiávamo": "academiar",
    "academiávamos": "academiar",
    "academiávei": "academiar",
    "academiáveis": "academiar",
    "acadiana": "acadiano",
    "acadianas": "acadiano",
    "acadianos": "acadiano",
    "acadima": "acadimar",
    "acadimada": "acadimar",
    "acadimadas": "acadimar",
    "acadimado": "acadimar",
    "acadimados": "acadimar",
    "acadimai": "acadimar",
    "acadimais": "acadimar",
    "acadimam": "acadimar",
    "acadimamo": "acadimar",
    "acadimamos": "acadimar",
    "acadimando": "acadimar",
    "acadimara": "acadimar",
    "acadimaram": "acadimar",
    "acadimaras": "acadimar",
    "acadimarde": "acadimar",
    "acadimardes": "acadimar",
    "acadimare": "acadimar",
    "acadimarei": "acadimar",
    "acadimareis": "acadimar",
    "acadimarem": "acadimar",
    "acadimaremos": "acadimar",
    "acadimares": "acadimar",
    "acadimaria": "acadimar",
    "acadimariam": "acadimar",
    "acadimarias": "acadimar",
    "acadimarmo": "acadimar",
    "acadimarmos": "acadimar",
    "acadimará": "acadimar",
    "acadimarás": "acadimar",
    "acadimarão": "acadimar",
    "acadimaríamos": "acadimar",
    "acadimaríeis": "acadimar",
    "acadimas": "acadimar",
    "acadimasse": "acadimar",
    "acadimassem": "acadimar",
    "acadimasses": "acadimar",
    "acadimaste": "acadimar",
    "acadimastes": "acadimar",
    "acadimava": "acadimar",
    "acadimavam": "acadimar",
    "acadimavas": "acadimar",
    "acadime": "acadimar",
    "acadimei": "acadimar",
    "acadimeis": "acadimar",
    "acadimem": "acadimar",
    "acadimemo": "acadimar",
    "acadimemos": "acadimar",
    "acadimes": "acadimar",
    "acadimo": "acadimar",
    "acadimou": "acadimar",
    "acadimá": "acadimar",
    "acadimámo": "acadimar",
    "acadimámos": "acadimar",
    "acadimáramo": "acadimar",
    "acadimáramos": "acadimar",
    "acadimárei": "acadimar",
    "acadimáreis": "acadimar",
    "acadimásseis": "acadimar",
    "acadimássemos": "acadimar",
    "acadimávamo": "acadimar",
    "acadimávamos": "acadimar",
    "acadimávei": "acadimar",
    "acadimáveis": "acadimar",
    "académias": "académia",
    "académica": "académico",
    "académicas": "académico",
    "académicos": "académico",
    "acafajestamentos": "acafajestamento",
    "acafela": "acafelar",
    "acafelada": "acafelar",
    "acafeladas": "acafelar",
    "acafelado": "acafelar",
    "acafeladora": "acafelador",
    "acafeladoras": "acafelador",
    "acafeladores": "acafelador",
    "acafelados": "acafelar",
    "acafelai": "acafelar",
    "acafelais": "acafelar",
    "acafelam": "acafelar",
    "acafelamentos": "acafelamento",
    "acafelamo": "acafelar",
    "acafelamos": "acafelar",
    "acafelando": "acafelar",
    "acafelara": "acafelar",
    "acafelaram": "acafelar",
    "acafelaras": "acafelar",
    "acafelarde": "acafelar",
    "acafelardes": "acafelar",
    "acafelare": "acafelar",
    "acafelarei": "acafelar",
    "acafelareis": "acafelar",
    "acafelarem": "acafelar",
    "acafelaremos": "acafelar",
    "acafelares": "acafelar",
    "acafelaria": "acafelar",
    "acafelariam": "acafelar",
    "acafelarias": "acafelar",
    "acafelarmo": "acafelar",
    "acafelarmos": "acafelar",
    "acafelará": "acafelar",
    "acafelarás": "acafelar",
    "acafelarão": "acafelar",
    "acafelaríamos": "acafelar",
    "acafelaríeis": "acafelar",
    "acafelas": "acafelar",
    "acafelasse": "acafelar",
    "acafelassem": "acafelar",
    "acafelasses": "acafelar",
    "acafelaste": "acafelar",
    "acafelastes": "acafelar",
    "acafelava": "acafelar",
    "acafelavam": "acafelar",
    "acafelavas": "acafelar",
    "acafele": "acafelar",
    "acafelei": "acafelar",
    "acafeleis": "acafelar",
    "acafelem": "acafelar",
    "acafelemo": "acafelar",
    "acafelemos": "acafelar",
    "acafeles": "acafelar",
    "acafelo": "acafelar",
    "acafelou": "acafelar",
    "acafelá": "acafelar",
    "acafelámo": "acafelar",
    "acafelámos": "acafelar",
    "acafeláramo": "acafelar",
    "acafeláramos": "acafelar",
    "acafelárei": "acafelar",
    "acafeláreis": "acafelar",
    "acafelásseis": "acafelar",
    "acafelássemos": "acafelar",
    "acafelávamo": "acafelar",
    "acafelávamos": "acafelar",
    "acafelávei": "acafelar",
    "acafeláveis": "acafelar",
    "acafeta": "acafetar",
    "acafetada": "acafetar",
    "acafetadas": "acafetar",
    "acafetado": "acafetar",
    "acafetados": "acafetar",
    "acafetai": "acafetar",
    "acafetais": "acafetar",
    "acafetam": "acafetar",
    "acafetamo": "acafetar",
    "acafetamos": "acafetar",
    "acafetando": "acafetar",
    "acafetara": "acafetar",
    "acafetaram": "acafetar",
    "acafetaras": "acafetar",
    "acafetarde": "acafetar",
    "acafetardes": "acafetar",
    "acafetare": "acafetar",
    "acafetarei": "acafetar",
    "acafetareis": "acafetar",
    "acafetarem": "acafetar",
    "acafetaremos": "acafetar",
    "acafetares": "acafetar",
    "acafetaria": "acafetar",
    "acafetariam": "acafetar",
    "acafetarias": "acafetar",
    "acafetarmo": "acafetar",
    "acafetarmos": "acafetar",
    "acafetará": "acafetar",
    "acafetarás": "acafetar",
    "acafetarão": "acafetar",
    "acafetaríamos": "acafetar",
    "acafetaríeis": "acafetar",
    "acafetas": "acafetar",
    "acafetasse": "acafetar",
    "acafetassem": "acafetar",
    "acafetasses": "acafetar",
    "acafetaste": "acafetar",
    "acafetastes": "acafetar",
    "acafetava": "acafetar",
    "acafetavam": "acafetar",
    "acafetavas": "acafetar",
    "acafete": "acafetar",
    "acafetei": "acafetar",
    "acafeteis": "acafetar",
    "acafetem": "acafetar",
    "acafetemo": "acafetar",
    "acafetemos": "acafetar",
    "acafetes": "acafetar",
    "acafeto": "acafetar",
    "acafetou": "acafetar",
    "acafetá": "acafetar",
    "acafetámo": "acafetar",
    "acafetámos": "acafetar",
    "acafetáramo": "acafetar",
    "acafetáramos": "acafetar",
    "acafetárei": "acafetar",
    "acafetáreis": "acafetar",
    "acafetásseis": "acafetar",
    "acafetássemos": "acafetar",
    "acafetávamo": "acafetar",
    "acafetávamos": "acafetar",
    "acafetávei": "acafetar",
    "acafetáveis": "acafetar",
    "acagace": "acagaçar",
    "acagacei": "acagaçar",
    "acagaceis": "acagaçar",
    "acagacem": "acagaçar",
    "acagacemo": "acagaçar",
    "acagacemos": "acagaçar",
    "acagaces": "acagaçar",
    "acagaça": "acagaçar",
    "acagaçada": "acagaçar",
    "acagaçadas": "acagaçar",
    "acagaçado": "acagaçar",
    "acagaçados": "acagaçar",
    "acagaçai": "acagaçar",
    "acagaçais": "acagaçar",
    "acagaçam": "acagaçar",
    "acagaçamo": "acagaçar",
    "acagaçamos": "acagaçar",
    "acagaçando": "acagaçar",
    "acagaçara": "acagaçar",
    "acagaçaram": "acagaçar",
    "acagaçaras": "acagaçar",
    "acagaçarde": "acagaçar",
    "acagaçardes": "acagaçar",
    "acagaçare": "acagaçar",
    "acagaçarei": "acagaçar",
    "acagaçareis": "acagaçar",
    "acagaçarem": "acagaçar",
    "acagaçaremos": "acagaçar",
    "acagaçares": "acagaçar",
    "acagaçaria": "acagaçar",
    "acagaçariam": "acagaçar",
    "acagaçarias": "acagaçar",
    "acagaçarmo": "acagaçar",
    "acagaçarmos": "acagaçar",
    "acagaçará": "acagaçar",
    "acagaçarás": "acagaçar",
    "acagaçarão": "acagaçar",
    "acagaçaríamos": "acagaçar",
    "acagaçaríeis": "acagaçar",
    "acagaças": "acagaçar",
    "acagaçasse": "acagaçar",
    "acagaçassem": "acagaçar",
    "acagaçasses": "acagaçar",
    "acagaçaste": "acagaçar",
    "acagaçastes": "acagaçar",
    "acagaçava": "acagaçar",
    "acagaçavam": "acagaçar",
    "acagaçavas": "acagaçar",
    "acagaço": "acagaçar",
    "acagaçou": "acagaçar",
    "acagaçá": "acagaçar",
    "acagaçámo": "acagaçar",
    "acagaçámos": "acagaçar",
    "acagaçáramo": "acagaçar",
    "acagaçáramos": "acagaçar",
    "acagaçárei": "acagaçar",
    "acagaçáreis": "acagaçar",
    "acagaçásseis": "acagaçar",
    "acagaçássemos": "acagaçar",
    "acagaçávamo": "acagaçar",
    "acagaçávamos": "acagaçar",
    "acagaçávei": "acagaçar",
    "acagaçáveis": "acagaçar",
    "acaica": "acaico",
    "acaicas": "acaico",
    "acaicos": "acaico",
    "acairela": "acairelar",
    "acairelada": "acairelar",
    "acaireladas": "acairelar",
    "acairelado": "acairelar",
    "acaireladora": "acairelador",
    "acaireladoras": "acairelador",
    "acaireladores": "acairelador",
    "acairelados": "acairelar",
    "acairelai": "acairelar",
    "acairelais": "acairelar",
    "acairelam": "acairelar",
    "acairelamentos": "acairelamento",
    "acairelamo": "acairelar",
    "acairelamos": "acairelar",
    "acairelando": "acairelar",
    "acairelara": "acairelar",
    "acairelaram": "acairelar",
    "acairelaras": "acairelar",
    "acairelarde": "acairelar",
    "acairelardes": "acairelar",
    "acairelare": "acairelar",
    "acairelarei": "acairelar",
    "acairelareis": "acairelar",
    "acairelarem": "acairelar",
    "acairelaremos": "acairelar",
    "acairelares": "acairelar",
    "acairelaria": "acairelar",
    "acairelariam": "acairelar",
    "acairelarias": "acairelar",
    "acairelarmo": "acairelar",
    "acairelarmos": "acairelar",
    "acairelará": "acairelar",
    "acairelarás": "acairelar",
    "acairelarão": "acairelar",
    "acairelaríamos": "acairelar",
    "acairelaríeis": "acairelar",
    "acairelas": "acairelar",
    "acairelasse": "acairelar",
    "acairelassem": "acairelar",
    "acairelasses": "acairelar",
    "acairelaste": "acairelar",
    "acairelastes": "acairelar",
    "acairelava": "acairelar",
    "acairelavam": "acairelar",
    "acairelavas": "acairelar",
    "acairele": "acairelar",
    "acairelei": "acairelar",
    "acaireleis": "acairelar",
    "acairelem": "acairelar",
    "acairelemo": "acairelar",
    "acairelemos": "acairelar",
    "acaireles": "acairelar",
    "acairelo": "acairelar",
    "acairelou": "acairelar",
    "acairelá": "acairelar",
    "acairelámo": "acairelar",
    "acairelámos": "acairelar",
    "acaireláramo": "acairelar",
    "acaireláramos": "acairelar",
    "acairelárei": "acairelar",
    "acaireláreis": "acairelar",
    "acairelásseis": "acairelar",
    "acairelássemos": "acairelar",
    "acairelávamo": "acairelar",
    "acairelávamos": "acairelar",
    "acairelávei": "acairelar",
    "acaireláveis": "acairelar",
    "acajada": "acajadar",
    "acajadada": "acajadar",
    "acajadadas": "acajadar",
    "acajadado": "acajadar",
    "acajadados": "acajadar",
    "acajadai": "acajadar",
    "acajadais": "acajadar",
    "acajadam": "acajadar",
    "acajadamo": "acajadar",
    "acajadamos": "acajadar",
    "acajadando": "acajadar",
    "acajadara": "acajadar",
    "acajadaram": "acajadar",
    "acajadaras": "acajadar",
    "acajadarde": "acajadar",
    "acajadardes": "acajadar",
    "acajadare": "acajadar",
    "acajadarei": "acajadar",
    "acajadareis": "acajadar",
    "acajadarem": "acajadar",
    "acajadaremos": "acajadar",
    "acajadares": "acajadar",
    "acajadaria": "acajadar",
    "acajadariam": "acajadar",
    "acajadarias": "acajadar",
    "acajadarmo": "acajadar",
    "acajadarmos": "acajadar",
    "acajadará": "acajadar",
    "acajadarás": "acajadar",
    "acajadarão": "acajadar",
    "acajadaríamos": "acajadar",
    "acajadaríeis": "acajadar",
    "acajadas": "acajadar",
    "acajadasse": "acajadar",
    "acajadassem": "acajadar",
    "acajadasses": "acajadar",
    "acajadaste": "acajadar",
    "acajadastes": "acajadar",
    "acajadava": "acajadar",
    "acajadavam": "acajadar",
    "acajadavas": "acajadar",
    "acajade": "acajadar",
    "acajadei": "acajadar",
    "acajadeis": "acajadar",
    "acajadem": "acajadar",
    "acajademo": "acajadar",
    "acajademos": "acajadar",
    "acajades": "acajadar",
    "acajado": "acajadar",
    "acajadou": "acajadar",
    "acajadá": "acajadar",
    "acajadámo": "acajadar",
    "acajadámos": "acajadar",
    "acajadáramo": "acajadar",
    "acajadáramos": "acajadar",
    "acajadárei": "acajadar",
    "acajadáreis": "acajadar",
    "acajadásseis": "acajadar",
    "acajadássemos": "acajadar",
    "acajadávamo": "acajadar",
    "acajadávamos": "acajadar",
    "acajadávei": "acajadar",
    "acajadáveis": "acajadar",
    "acajueiros": "acajueiro",
    "acajus": "acaju",
    "acalanta": "acalantar",
    "acalantada": "acalantar",
    "acalantadas": "acalantar",
    "acalantado": "acalantar",
    "acalantados": "acalantar",
    "acalantai": "acalantar",
    "acalantais": "acalantar",
    "acalantam": "acalantar",
    "acalantamo": "acalantar",
    "acalantamos": "acalantar",
    "acalantando": "acalantar",
    "acalantara": "acalantar",
    "acalantaram": "acalantar",
    "acalantaras": "acalantar",
    "acalantarde": "acalantar",
    "acalantardes": "acalantar",
    "acalantare": "acalantar",
    "acalantarei": "acalantar",
    "acalantareis": "acalantar",
    "acalantarem": "acalantar",
    "acalantaremos": "acalantar",
    "acalantares": "acalantar",
    "acalantaria": "acalantar",
    "acalantariam": "acalantar",
    "acalantarias": "acalantar",
    "acalantarmo": "acalantar",
    "acalantarmos": "acalantar",
    "acalantará": "acalantar",
    "acalantarás": "acalantar",
    "acalantarão": "acalantar",
    "acalantaríamos": "acalantar",
    "acalantaríeis": "acalantar",
    "acalantas": "acalantar",
    "acalantasse": "acalantar",
    "acalantassem": "acalantar",
    "acalantasses": "acalantar",
    "acalantaste": "acalantar",
    "acalantastes": "acalantar",
    "acalantava": "acalantar",
    "acalantavam": "acalantar",
    "acalantavas": "acalantar",
    "acalante": "acalantar",
    "acalantei": "acalantar",
    "acalanteis": "acalantar",
    "acalantem": "acalantar",
    "acalantemo": "acalantar",
    "acalantemos": "acalantar",
    "acalantes": "acalantar",
    "acalanto": "acalantar",
    "acalantos": "acalanto",
    "acalantou": "acalantar",
    "acalantá": "acalantar",
    "acalantámo": "acalantar",
    "acalantámos": "acalantar",
    "acalantáramo": "acalantar",
    "acalantáramos": "acalantar",
    "acalantárei": "acalantar",
    "acalantáreis": "acalantar",
    "acalantásseis": "acalantar",
    "acalantássemos": "acalantar",
    "acalantávamo": "acalantar",
    "acalantávamos": "acalantar",
    "acalantávei": "acalantar",
    "acalantáveis": "acalantar",
    "acalca": "acalcar",
    "acalcada": "acalcar",
    "acalcadas": "acalcar",
    "acalcado": "acalcar",
    "acalcados": "acalcar",
    "acalcai": "acalcar",
    "acalcais": "acalcar",
    "acalcam": "acalcar",
    "acalcamo": "acalcar",
    "acalcamos": "acalcar",
    "acalcando": "acalcar",
    "acalcanha": "acalcanhar",
    "acalcanhada": "acalcanhar",
    "acalcanhadas": "acalcanhar",
    "acalcanhado": "acalcanhar",
    "acalcanhados": "acalcanhar",
    "acalcanhai": "acalcanhar",
    "acalcanhais": "acalcanhar",
    "acalcanham": "acalcanhar",
    "acalcanhamentos": "acalcanhamento",
    "acalcanhamo": "acalcanhar",
    "acalcanhamos": "acalcanhar",
    "acalcanhando": "acalcanhar",
    "acalcanhara": "acalcanhar",
    "acalcanharam": "acalcanhar",
    "acalcanharas": "acalcanhar",
    "acalcanharde": "acalcanhar",
    "acalcanhardes": "acalcanhar",
    "acalcanhare": "acalcanhar",
    "acalcanharei": "acalcanhar",
    "acalcanhareis": "acalcanhar",
    "acalcanharem": "acalcanhar",
    "acalcanharemos": "acalcanhar",
    "acalcanhares": "acalcanhar",
    "acalcanharia": "acalcanhar",
    "acalcanhariam": "acalcanhar",
    "acalcanharias": "acalcanhar",
    "acalcanharmo": "acalcanhar",
    "acalcanharmos": "acalcanhar",
    "acalcanhará": "acalcanhar",
    "acalcanharás": "acalcanhar",
    "acalcanharão": "acalcanhar",
    "acalcanharíamos": "acalcanhar",
    "acalcanharíeis": "acalcanhar",
    "acalcanhas": "acalcanhar",
    "acalcanhasse": "acalcanhar",
    "acalcanhassem": "acalcanhar",
    "acalcanhasses": "acalcanhar",
    "acalcanhaste": "acalcanhar",
    "acalcanhastes": "acalcanhar",
    "acalcanhava": "acalcanhar",
    "acalcanhavam": "acalcanhar",
    "acalcanhavas": "acalcanhar",
    "acalcanhe": "acalcanhar",
    "acalcanhei": "acalcanhar",
    "acalcanheis": "acalcanhar",
    "acalcanhem": "acalcanhar",
    "acalcanhemo": "acalcanhar",
    "acalcanhemos": "acalcanhar",
    "acalcanhes": "acalcanhar",
    "acalcanho": "acalcanhar",
    "acalcanhou": "acalcanhar",
    "acalcanhá": "acalcanhar",
    "acalcanhámo": "acalcanhar",
    "acalcanhámos": "acalcanhar",
    "acalcanháramo": "acalcanhar",
    "acalcanháramos": "acalcanhar",
    "acalcanhárei": "acalcanhar",
    "acalcanháreis": "acalcanhar",
    "acalcanhásseis": "acalcanhar",
    "acalcanhássemos": "acalcanhar",
    "acalcanhávamo": "acalcanhar",
    "acalcanhávamos": "acalcanhar",
    "acalcanhávei": "acalcanhar",
    "acalcanháveis": "acalcanhar",
    "acalcara": "acalcar",
    "acalcaram": "acalcar",
    "acalcaras": "acalcar",
    "acalcarde": "acalcar",
    "acalcardes": "acalcar",
    "acalcare": "acalcar",
    "acalcarei": "acalcar",
    "acalcareis": "acalcar",
    "acalcarem": "acalcar",
    "acalcaremos": "acalcar",
    "acalcares": "acalcar",
    "acalcaria": "acalcar",
    "acalcariam": "acalcar",
    "acalcarias": "acalcar",
    "acalcarmo": "acalcar",
    "acalcarmos": "acalcar",
    "acalcará": "acalcar",
    "acalcarás": "acalcar",
    "acalcarão": "acalcar",
    "acalcaríamos": "acalcar",
    "acalcaríeis": "acalcar",
    "acalcas": "acalcar",
    "acalcasse": "acalcar",
    "acalcassem": "acalcar",
    "acalcasses": "acalcar",
    "acalcaste": "acalcar",
    "acalcastes": "acalcar",
    "acalcava": "acalcar",
    "acalcavam": "acalcar",
    "acalcavas": "acalcar",
    "acalce": "acalçar",
    "acalcei": "acalçar",
    "acalceis": "acalçar",
    "acalcem": "acalçar",
    "acalcemo": "acalçar",
    "acalcemos": "acalçar",
    "acalces": "acalçar",
    "acalco": "acalcar",
    "acalcou": "acalcar",
    "acalcá": "acalcar",
    "acalcámo": "acalcar",
    "acalcámos": "acalcar",
    "acalcáramo": "acalcar",
    "acalcáramos": "acalcar",
    "acalcárei": "acalcar",
    "acalcáreis": "acalcar",
    "acalcária": "acalcário",
    "acalcárias": "acalcário",
    "acalcários": "acalcário",
    "acalcásseis": "acalcar",
    "acalcássemos": "acalcar",
    "acalcávamo": "acalcar",
    "acalcávamos": "acalcar",
    "acalcávei": "acalcar",
    "acalcáveis": "acalcar",
    "acalefa": "acalefo",
    "acalefas": "acalefo",
    "acalefos": "acalefo",
    "acalenta": "acalentar",
    "acalentada": "acalentar",
    "acalentadas": "acalentar",
    "acalentadeira": "acalentador",
    "acalentadeiras": "acalentador",
    "acalentado": "acalentar",
    "acalentadora": "acalentador",
    "acalentadoras": "acalentador",
    "acalentadores": "acalentador",
    "acalentados": "acalentar",
    "acalentai": "acalentar",
    "acalentais": "acalentar",
    "acalentam": "acalentar",
    "acalentamentos": "acalentamento",
    "acalentamo": "acalentar",
    "acalentamos": "acalentar",
    "acalentando": "acalentar",
    "acalentara": "acalentar",
    "acalentaram": "acalentar",
    "acalentaras": "acalentar",
    "acalentarde": "acalentar",
    "acalentardes": "acalentar",
    "acalentare": "acalentar",
    "acalentarei": "acalentar",
    "acalentareis": "acalentar",
    "acalentarem": "acalentar",
    "acalentaremos": "acalentar",
    "acalentares": "acalentar",
    "acalentaria": "acalentar",
    "acalentariam": "acalentar",
    "acalentarias": "acalentar",
    "acalentarmo": "acalentar",
    "acalentarmos": "acalentar",
    "acalentará": "acalentar",
    "acalentarás": "acalentar",
    "acalentarão": "acalentar",
    "acalentaríamos": "acalentar",
    "acalentaríeis": "acalentar",
    "acalentas": "acalentar",
    "acalentasse": "acalentar",
    "acalentassem": "acalentar",
    "acalentasses": "acalentar",
    "acalentaste": "acalentar",
    "acalentastes": "acalentar",
    "acalentava": "acalentar",
    "acalentavam": "acalentar",
    "acalentavas": "acalentar",
    "acalente": "acalentar",
    "acalentei": "acalentar",
    "acalenteis": "acalentar",
    "acalentem": "acalentar",
    "acalentemo": "acalentar",
    "acalentemos": "acalentar",
    "acalentes": "acalentar",
    "acalento": "acalentar",
    "acalentos": "acalento",
    "acalentou": "acalentar",
    "acalentá": "acalentar",
    "acalentámo": "acalentar",
    "acalentámos": "acalentar",
    "acalentáramo": "acalentar",
    "acalentáramos": "acalentar",
    "acalentárei": "acalentar",
    "acalentáreis": "acalentar",
    "acalentásseis": "acalentar",
    "acalentássemos": "acalentar",
    "acalentávamo": "acalentar",
    "acalentávamos": "acalentar",
    "acalentávei": "acalentar",
    "acalentáveis": "acalentável",
    "acalhoa": "acalhoar",
    "acalhoada": "acalhoar",
    "acalhoadas": "acalhoar",
    "acalhoado": "acalhoar",
    "acalhoados": "acalhoar",
    "acalhoai": "acalhoar",
    "acalhoais": "acalhoar",
    "acalhoam": "acalhoar",
    "acalhoamo": "acalhoar",
    "acalhoamos": "acalhoar",
    "acalhoando": "acalhoar",
    "acalhoara": "acalhoar",
    "acalhoaram": "acalhoar",
    "acalhoaras": "acalhoar",
    "acalhoarde": "acalhoar",
    "acalhoardes": "acalhoar",
    "acalhoare": "acalhoar",
    "acalhoarei": "acalhoar",
    "acalhoareis": "acalhoar",
    "acalhoarem": "acalhoar",
    "acalhoaremos": "acalhoar",
    "acalhoares": "acalhoar",
    "acalhoaria": "acalhoar",
    "acalhoariam": "acalhoar",
    "acalhoarias": "acalhoar",
    "acalhoarmo": "acalhoar",
    "acalhoarmos": "acalhoar",
    "acalhoará": "acalhoar",
    "acalhoarás": "acalhoar",
    "acalhoarão": "acalhoar",
    "acalhoaríamos": "acalhoar",
    "acalhoaríeis": "acalhoar",
    "acalhoas": "acalhoar",
    "acalhoasse": "acalhoar",
    "acalhoassem": "acalhoar",
    "acalhoasses": "acalhoar",
    "acalhoaste": "acalhoar",
    "acalhoastes": "acalhoar",
    "acalhoava": "acalhoar",
    "acalhoavam": "acalhoar",
    "acalhoavas": "acalhoar",
    "acalhoe": "acalhoar",
    "acalhoei": "acalhoar",
    "acalhoeis": "acalhoar",
    "acalhoem": "acalhoar",
    "acalhoemo": "acalhoar",
    "acalhoemos": "acalhoar",
    "acalhoes": "acalhoar",
    "acalhoo": "acalhoar",
    "acalhoou": "acalhoar",
    "acalhoá": "acalhoar",
    "acalhoámo": "acalhoar",
    "acalhoámos": "acalhoar",
    "acalhoáramo": "acalhoar",
    "acalhoáramos": "acalhoar",
    "acalhoárei": "acalhoar",
    "acalhoáreis": "acalhoar",
    "acalhoásseis": "acalhoar",
    "acalhoássemos": "acalhoar",
    "acalhoávamo": "acalhoar",
    "acalhoávamos": "acalhoar",
    "acalhoávei": "acalhoar",
    "acalhoáveis": "acalhoar",
    "acalifas": "acalifa",
    "acalma": "acalmar",
    "acalmada": "acalmar",
    "acalmadas": "acalmar",
    "acalmado": "acalmar",
    "acalmados": "acalmar",
    "acalmadíssima": "acalmado",
    "acalmadíssimas": "acalmado",
    "acalmadíssimo": "acalmado",
    "acalmadíssimos": "acalmado",
    "acalmai": "acalmar",
    "acalmais": "acalmar",
    "acalmam": "acalmar",
    "acalmamentos": "acalmamento",
    "acalmamo": "acalmar",
    "acalmamos": "acalmar",
    "acalmando": "acalmar",
    "acalmara": "acalmar",
    "acalmaram": "acalmar",
    "acalmaras": "acalmar",
    "acalmarde": "acalmar",
    "acalmardes": "acalmar",
    "acalmare": "acalmar",
    "acalmarei": "acalmar",
    "acalmareis": "acalmar",
    "acalmarem": "acalmar",
    "acalmaremos": "acalmar",
    "acalmares": "acalmar",
    "acalmaria": "acalmar",
    "acalmariam": "acalmar",
    "acalmarias": "acalmar",
    "acalmarmo": "acalmar",
    "acalmarmos": "acalmar",
    "acalmará": "acalmar",
    "acalmarás": "acalmar",
    "acalmarão": "acalmar",
    "acalmaríamos": "acalmar",
    "acalmaríeis": "acalmar",
    "acalmas": "acalmar",
    "acalmasse": "acalmar",
    "acalmassem": "acalmar",
    "acalmasses": "acalmar",
    "acalmaste": "acalmar",
    "acalmastes": "acalmar",
    "acalmava": "acalmar",
    "acalmavam": "acalmar",
    "acalmavas": "acalmar",
    "acalmações": "acalmação",
    "acalme": "acalmar",
    "acalmei": "acalmar",
    "acalmeis": "acalmar",
    "acalmem": "acalmar",
    "acalmemo": "acalmar",
    "acalmemos": "acalmar",
    "acalmes": "acalmar",
    "acalmias": "acalmia",
    "acalmo": "acalmar",
    "acalmou": "acalmar",
    "acalmá": "acalmar",
    "acalmámo": "acalmar",
    "acalmámos": "acalmar",
    "acalmáramo": "acalmar",
    "acalmáramos": "acalmar",
    "acalmárei": "acalmar",
    "acalmáreis": "acalmar",
    "acalmásseis": "acalmar",
    "acalmássemos": "acalmar",
    "acalmávamo": "acalmar",
    "acalmávamos": "acalmar",
    "acalmávei": "acalmar",
    "acalmáveis": "acalmar",
    "acalora": "acalorar",
    "acalorada": "acalorar",
    "acaloradas": "acalorar",
    "acalorado": "acalorar",
    "acalorados": "acalorar",
    "acaloradíssima": "acalorado",
    "acaloradíssimas": "acalorado",
    "acaloradíssimo": "acalorado",
    "acaloradíssimos": "acalorado",
    "acalorai": "acalorar",
    "acalorais": "acalorar",
    "acaloram": "acalorar",
    "acaloramo": "acalorar",
    "acaloramos": "acalorar",
    "acalorando": "acalorar",
    "acalorara": "acalorar",
    "acaloraram": "acalorar",
    "acaloraras": "acalorar",
    "acalorarde": "acalorar",
    "acalorardes": "acalorar",
    "acalorare": "acalorar",
    "acalorarei": "acalorar",
    "acalorareis": "acalorar",
    "acalorarem": "acalorar",
    "acaloraremos": "acalorar",
    "acalorares": "acalorar",
    "acaloraria": "acalorar",
    "acalorariam": "acalorar",
    "acalorarias": "acalorar",
    "acalorarmo": "acalorar",
    "acalorarmos": "acalorar",
    "acalorará": "acalorar",
    "acalorarás": "acalorar",
    "acalorarão": "acalorar",
    "acaloraríamos": "acalorar",
    "acaloraríeis": "acalorar",
    "acaloras": "acalorar",
    "acalorasse": "acalorar",
    "acalorassem": "acalorar",
    "acalorasses": "acalorar",
    "acaloraste": "acalorar",
    "acalorastes": "acalorar",
    "acalorava": "acalorar",
    "acaloravam": "acalorar",
    "acaloravas": "acalorar",
    "acalore": "acalorar",
    "acalorei": "acalorar",
    "acaloreis": "acalorar",
    "acalorem": "acalorar",
    "acaloremo": "acalorar",
    "acaloremos": "acalorar",
    "acalores": "acalorar",
    "acaloro": "acalorar",
    "acalorou": "acalorar",
    "acalorá": "acalorar",
    "acalorámo": "acalorar",
    "acalorámos": "acalorar",
    "acaloráramo": "acalorar",
    "acaloráramos": "acalorar",
    "acalorárei": "acalorar",
    "acaloráreis": "acalorar",
    "acalorásseis": "acalorar",
    "acalorássemos": "acalorar",
    "acalorávamo": "acalorar",
    "acalorávamos": "acalorar",
    "acalorávei": "acalorar",
    "acaloráveis": "acalorar",
    "acalque": "acalcar",
    "acalquei": "acalcar",
    "acalqueis": "acalcar",
    "acalquem": "acalcar",
    "acalquemo": "acalcar",
    "acalquemos": "acalcar",
    "acalques": "acalcar",
    "acalça": "acalçar",
    "acalçada": "acalçar",
    "acalçadas": "acalçar",
    "acalçado": "acalçar",
    "acalçados": "acalçar",
    "acalçai": "acalçar",
    "acalçais": "acalçar",
    "acalçam": "acalçar",
    "acalçamo": "acalçar",
    "acalçamos": "acalçar",
    "acalçando": "acalçar",
    "acalçara": "acalçar",
    "acalçaram": "acalçar",
    "acalçaras": "acalçar",
    "acalçarde": "acalçar",
    "acalçardes": "acalçar",
    "acalçare": "acalçar",
    "acalçarei": "acalçar",
    "acalçareis": "acalçar",
    "acalçarem": "acalçar",
    "acalçaremos": "acalçar",
    "acalçares": "acalçar",
    "acalçaria": "acalçar",
    "acalçariam": "acalçar",
    "acalçarias": "acalçar",
    "acalçarmo": "acalçar",
    "acalçarmos": "acalçar",
    "acalçará": "acalçar",
    "acalçarás": "acalçar",
    "acalçarão": "acalçar",
    "acalçaríamos": "acalçar",
    "acalçaríeis": "acalçar",
    "acalças": "acalçar",
    "acalçasse": "acalçar",
    "acalçassem": "acalçar",
    "acalçasses": "acalçar",
    "acalçaste": "acalçar",
    "acalçastes": "acalçar",
    "acalçava": "acalçar",
    "acalçavam": "acalçar",
    "acalçavas": "acalçar",
    "acalço": "acalçar",
    "acalçou": "acalçar",
    "acalçá": "acalçar",
    "acalçámo": "acalçar",
    "acalçámos": "acalçar",
    "acalçáramo": "acalçar",
    "acalçáramos": "acalçar",
    "acalçárei": "acalçar",
    "acalçáreis": "acalçar",
    "acalçásseis": "acalçar",
    "acalçássemos": "acalçar",
    "acalçávamo": "acalçar",
    "acalçávamos": "acalçar",
    "acalçávei": "acalçar",
    "acalçáveis": "acalçar",
    "acama": "acamar",
    "acamada": "acamar",
    "acamadas": "acamar",
    "acamado": "acamar",
    "acamados": "acamar",
    "acamai": "acamar",
    "acamais": "acamar",
    "acamam": "acamar",
    "acamamentos": "acamamento",
    "acamamo": "acamar",
    "acamamos": "acamar",
    "acamando": "acamar",
    "acamara": "acamar",
    "acamarada": "acamaradar",
    "acamaradada": "acamaradar",
    "acamaradadas": "acamaradar",
    "acamaradado": "acamaradar",
    "acamaradados": "acamaradar",
    "acamaradai": "acamaradar",
    "acamaradais": "acamaradar",
    "acamaradam": "acamaradar",
    "acamaradamo": "acamaradar",
    "acamaradamos": "acamaradar",
    "acamaradando": "acamaradar",
    "acamaradara": "acamaradar",
    "acamaradaram": "acamaradar",
    "acamaradaras": "acamaradar",
    "acamaradarde": "acamaradar",
    "acamaradardes": "acamaradar",
    "acamaradare": "acamaradar",
    "acamaradarei": "acamaradar",
    "acamaradareis": "acamaradar",
    "acamaradarem": "acamaradar",
    "acamaradaremos": "acamaradar",
    "acamaradares": "acamaradar",
    "acamaradaria": "acamaradar",
    "acamaradariam": "acamaradar",
    "acamaradarias": "acamaradar",
    "acamaradarmo": "acamaradar",
    "acamaradarmos": "acamaradar",
    "acamaradará": "acamaradar",
    "acamaradarás": "acamaradar",
    "acamaradarão": "acamaradar",
    "acamaradaríamos": "acamaradar",
    "acamaradaríeis": "acamaradar",
    "acamaradas": "acamaradar",
    "acamaradasse": "acamaradar",
    "acamaradassem": "acamaradar",
    "acamaradasses": "acamaradar",
    "acamaradaste": "acamaradar",
    "acamaradastes": "acamaradar",
    "acamaradava": "acamaradar",
    "acamaradavam": "acamaradar",
    "acamaradavas": "acamaradar",
    "acamarade": "acamaradar",
    "acamaradei": "acamaradar",
    "acamaradeis": "acamaradar",
    "acamaradem": "acamaradar",
    "acamarademo": "acamaradar",
    "acamarademos": "acamaradar",
    "acamarades": "acamaradar",
    "acamarado": "acamaradar",
    "acamaradou": "acamaradar",
    "acamaradá": "acamaradar",
    "acamaradámo": "acamaradar",
    "acamaradámos": "acamaradar",
    "acamaradáramo": "acamaradar",
    "acamaradáramos": "acamaradar",
    "acamaradárei": "acamaradar",
    "acamaradáreis": "acamaradar",
    "acamaradásseis": "acamaradar",
    "acamaradássemos": "acamaradar",
    "acamaradávamo": "acamaradar",
    "acamaradávamos": "acamaradar",
    "acamaradávei": "acamaradar",
    "acamaradáveis": "acamaradar",
    "acamaram": "acamar",
    "acamaras": "acamar",
    "acamarde": "acamar",
    "acamardes": "acamar",
    "acamare": "acamar",
    "acamarei": "acamar",
    "acamareis": "acamar",
    "acamarem": "acamar",
    "acamaremos": "acamar",
    "acamares": "acamar",
    "acamaria": "acamar",
    "acamariam": "acamar",
    "acamarias": "acamar",
    "acamarmo": "acamar",
    "acamarmos": "acamar",
    "acamará": "acamar",
    "acamarás": "acamar",
    "acamarão": "acamar",
    "acamaríamos": "acamar",
    "acamaríeis": "acamar",
    "acamas": "acamar",
    "acamasse": "acamar",
    "acamassem": "acamar",
    "acamasses": "acamar",
    "acamaste": "acamar",
    "acamastes": "acamar",
    "acamava": "acamar",
    "acamavam": "acamar",
    "acamavas": "acamar",
    "acamações": "acamação",
    "acamboa": "acamboar",
    "acamboada": "acamboar",
    "acamboadas": "acamboar",
    "acamboado": "acamboar",
    "acamboados": "acamboar",
    "acamboai": "acamboar",
    "acamboais": "acamboar",
    "acamboam": "acamboar",
    "acamboamo": "acamboar",
    "acamboamos": "acamboar",
    "acamboando": "acamboar",
    "acamboara": "acamboar",
    "acamboaram": "acamboar",
    "acamboaras": "acamboar",
    "acamboarde": "acamboar",
    "acamboardes": "acamboar",
    "acamboare": "acamboar",
    "acamboarei": "acamboar",
    "acamboareis": "acamboar",
    "acamboarem": "acamboar",
    "acamboaremos": "acamboar",
    "acamboares": "acamboar",
    "acamboaria": "acamboar",
    "acamboariam": "acamboar",
    "acamboarias": "acamboar",
    "acamboarmo": "acamboar",
    "acamboarmos": "acamboar",
    "acamboará": "acamboar",
    "acamboarás": "acamboar",
    "acamboarão": "acamboar",
    "acamboaríamos": "acamboar",
    "acamboaríeis": "acamboar",
    "acamboas": "acamboar",
    "acamboasse": "acamboar",
    "acamboassem": "acamboar",
    "acamboasses": "acamboar",
    "acamboaste": "acamboar",
    "acamboastes": "acamboar",
    "acamboava": "acamboar",
    "acamboavam": "acamboar",
    "acamboavas": "acamboar",
    "acamboe": "acamboar",
    "acamboei": "acamboar",
    "acamboeis": "acamboar",
    "acamboem": "acamboar",
    "acamboemo": "acamboar",
    "acamboemos": "acamboar",
    "acamboes": "acamboar",
    "acamboo": "acamboar",
    "acamboou": "acamboar",
    "acamboá": "acamboar",
    "acamboámo": "acamboar",
    "acamboámos": "acamboar",
    "acamboáramo": "acamboar",
    "acamboáramos": "acamboar",
    "acamboárei": "acamboar",
    "acamboáreis": "acamboar",
    "acamboásseis": "acamboar",
    "acamboássemos": "acamboar",
    "acamboávamo": "acamboar",
    "acamboávamos": "acamboar",
    "acamboávei": "acamboar",
    "acamboáveis": "acamboar",
    "acambulha": "acambulhar",
    "acambulhada": "acambulhar",
    "acambulhadas": "acambulhar",
    "acambulhado": "acambulhar",
    "acambulhados": "acambulhar",
    "acambulhai": "acambulhar",
    "acambulhais": "acambulhar",
    "acambulham": "acambulhar",
    "acambulhamo": "acambulhar",
    "acambulhamos": "acambulhar",
    "acambulhando": "acambulhar",
    "acambulhara": "acambulhar",
    "acambulharam": "acambulhar",
    "acambulharas": "acambulhar",
    "acambulharde": "acambulhar",
    "acambulhardes": "acambulhar",
    "acambulhare": "acambulhar",
    "acambulharei": "acambulhar",
    "acambulhareis": "acambulhar",
    "acambulharem": "acambulhar",
    "acambulharemos": "acambulhar",
    "acambulhares": "acambulhar",
    "acambulharia": "acambulhar",
    "acambulhariam": "acambulhar",
    "acambulharias": "acambulhar",
    "acambulharmo": "acambulhar",
    "acambulharmos": "acambulhar",
    "acambulhará": "acambulhar",
    "acambulharás": "acambulhar",
    "acambulharão": "acambulhar",
    "acambulharíamos": "acambulhar",
    "acambulharíeis": "acambulhar",
    "acambulhas": "acambulhar",
    "acambulhasse": "acambulhar",
    "acambulhassem": "acambulhar",
    "acambulhasses": "acambulhar",
    "acambulhaste": "acambulhar",
    "acambulhastes": "acambulhar",
    "acambulhava": "acambulhar",
    "acambulhavam": "acambulhar",
    "acambulhavas": "acambulhar",
    "acambulhe": "acambulhar",
    "acambulhei": "acambulhar",
    "acambulheis": "acambulhar",
    "acambulhem": "acambulhar",
    "acambulhemo": "acambulhar",
    "acambulhemos": "acambulhar",
    "acambulhes": "acambulhar",
    "acambulho": "acambulhar",
    "acambulhou": "acambulhar",
    "acambulhá": "acambulhar",
    "acambulhámo": "acambulhar",
    "acambulhámos": "acambulhar",
    "acambulháramo": "acambulhar",
    "acambulháramos": "acambulhar",
    "acambulhárei": "acambulhar",
    "acambulháreis": "acambulhar",
    "acambulhásseis": "acambulhar",
    "acambulhássemos": "acambulhar",
    "acambulhávamo": "acambulhar",
    "acambulhávamos": "acambulhar",
    "acambulhávei": "acambulhar",
    "acambulháveis": "acambulhar",
    "acame": "acamar",
    "acamei": "acamar",
    "acameis": "acamar",
    "acamem": "acamar",
    "acamemo": "acamar",
    "acamemos": "acamar",
    "acames": "acamar",
    "acamo": "acamar",
    "acamou": "acamar",
    "acampa": "acampar",
    "acampada": "acampar",
    "acampadas": "acampar",
    "acampado": "acampar",
    "acampados": "acampar",
    "acampai": "acampar",
    "acampainha": "acampainhar",
    "acampainhada": "acampainhar",
    "acampainhadas": "acampainhar",
    "acampainhado": "acampainhar",
    "acampainhados": "acampainhar",
    "acampainhai": "acampainhar",
    "acampainhais": "acampainhar",
    "acampainham": "acampainhar",
    "acampainhamo": "acampainhar",
    "acampainhamos": "acampainhar",
    "acampainhando": "acampainhar",
    "acampainhara": "acampainhar",
    "acampainharam": "acampainhar",
    "acampainharas": "acampainhar",
    "acampainharde": "acampainhar",
    "acampainhardes": "acampainhar",
    "acampainhare": "acampainhar",
    "acampainharei": "acampainhar",
    "acampainhareis": "acampainhar",
    "acampainharem": "acampainhar",
    "acampainharemos": "acampainhar",
    "acampainhares": "acampainhar",
    "acampainharia": "acampainhar",
    "acampainhariam": "acampainhar",
    "acampainharias": "acampainhar",
    "acampainharmo": "acampainhar",
    "acampainharmos": "acampainhar",
    "acampainhará": "acampainhar",
    "acampainharás": "acampainhar",
    "acampainharão": "acampainhar",
    "acampainharíamos": "acampainhar",
    "acampainharíeis": "acampainhar",
    "acampainhas": "acampainhar",
    "acampainhasse": "acampainhar",
    "acampainhassem": "acampainhar",
    "acampainhasses": "acampainhar",
    "acampainhaste": "acampainhar",
    "acampainhastes": "acampainhar",
    "acampainhava": "acampainhar",
    "acampainhavam": "acampainhar",
    "acampainhavas": "acampainhar",
    "acampainhe": "acampainhar",
    "acampainhei": "acampainhar",
    "acampainheis": "acampainhar",
    "acampainhem": "acampainhar",
    "acampainhemo": "acampainhar",
    "acampainhemos": "acampainhar",
    "acampainhes": "acampainhar",
    "acampainho": "acampainhar",
    "acampainhou": "acampainhar",
    "acampainhá": "acampainhar",
    "acampainhámo": "acampainhar",
    "acampainhámos": "acampainhar",
    "acampainháramo": "acampainhar",
    "acampainháramos": "acampainhar",
    "acampainhárei": "acampainhar",
    "acampainháreis": "acampainhar",
    "acampainhásseis": "acampainhar",
    "acampainhássemos": "acampainhar",
    "acampainhávamo": "acampainhar",
    "acampainhávamos": "acampainhar",
    "acampainhávei": "acampainhar",
    "acampainháveis": "acampainhar",
    "acampais": "acampar",
    "acampam": "acampar",
    "acampamentos": "acampamento",
    "acampamo": "acampar",
    "acampamos": "acampar",
    "acampando": "acampar",
    "acampara": "acampar",
    "acamparam": "acampar",
    "acamparas": "acampar",
    "acampardes": "acampar",
    "acamparei": "acampar",
    "acampareis": "acampar",
    "acamparem": "acampar",
    "acamparemos": "acampar",
    "acampares": "acampar",
    "acamparia": "acampar",
    "acampariam": "acampar",
    "acamparias": "acampar",
    "acamparmo": "acampar",
    "acamparmos": "acampar",
    "acampará": "acampar",
    "acamparás": "acampar",
    "acamparão": "acampar",
    "acamparíamos": "acampar",
    "acamparíeis": "acampar",
    "acampas": "acampar",
    "acampasse": "acampar",
    "acampassem": "acampar",
    "acampasses": "acampar",
    "acampaste": "acampar",
    "acampastes": "acampar",
    "acampava": "acampar",
    "acampavam": "acampar",
    "acampavas": "acampar",
    "acampe": "acampar",
    "acampei": "acampar",
    "acampeis": "acampar",
    "acampem": "acampar",
    "acampemo": "acampar",
    "acampemos": "acampar",
    "acampes": "acampar",
    "acampo": "acampar",
    "acampou": "acampar",
    "acampta": "acampto",
    "acamptas": "acampto",
    "acamptos": "acampto",
    "acampámo": "acampar",
    "acampámos": "acampar",
    "acampáramo": "acampar",
    "acampáramos": "acampar",
    "acampáreis": "acampar",
    "acampásseis": "acampar",
    "acampássemos": "acampar",
    "acampávamo": "acampar",
    "acampávamos": "acampar",
    "acampáveis": "acampar",
    "acamurce": "acamurçar",
    "acamurcei": "acamurçar",
    "acamurceis": "acamurçar",
    "acamurcem": "acamurçar",
    "acamurcemo": "acamurçar",
    "acamurcemos": "acamurçar",
    "acamurces": "acamurçar",
    "acamurça": "acamurçar",
    "acamurçada": "acamurçar",
    "acamurçadas": "acamurçar",
    "acamurçado": "acamurçar",
    "acamurçados": "acamurçar",
    "acamurçai": "acamurçar",
    "acamurçais": "acamurçar",
    "acamurçam": "acamurçar",
    "acamurçamo": "acamurçar",
    "acamurçamos": "acamurçar",
    "acamurçando": "acamurçar",
    "acamurçara": "acamurçar",
    "acamurçaram": "acamurçar",
    "acamurçaras": "acamurçar",
    "acamurçarde": "acamurçar",
    "acamurçardes": "acamurçar",
    "acamurçare": "acamurçar",
    "acamurçarei": "acamurçar",
    "acamurçareis": "acamurçar",
    "acamurçarem": "acamurçar",
    "acamurçaremos": "acamurçar",
    "acamurçares": "acamurçar",
    "acamurçaria": "acamurçar",
    "acamurçariam": "acamurçar",
    "acamurçarias": "acamurçar",
    "acamurçarmo": "acamurçar",
    "acamurçarmos": "acamurçar",
    "acamurçará": "acamurçar",
    "acamurçarás": "acamurçar",
    "acamurçarão": "acamurçar",
    "acamurçaríamos": "acamurçar",
    "acamurçaríeis": "acamurçar",
    "acamurças": "acamurçar",
    "acamurçasse": "acamurçar",
    "acamurçassem": "acamurçar",
    "acamurçasses": "acamurçar",
    "acamurçaste": "acamurçar",
    "acamurçastes": "acamurçar",
    "acamurçava": "acamurçar",
    "acamurçavam": "acamurçar",
    "acamurçavas": "acamurçar",
    "acamurço": "acamurçar",
    "acamurçou": "acamurçar",
    "acamurçá": "acamurçar",
    "acamurçámo": "acamurçar",
    "acamurçámos": "acamurçar",
    "acamurçáramo": "acamurçar",
    "acamurçáramos": "acamurçar",
    "acamurçárei": "acamurçar",
    "acamurçáreis": "acamurçar",
    "acamurçásseis": "acamurçar",
    "acamurçássemos": "acamurçar",
    "acamurçávamo": "acamurçar",
    "acamurçávamos": "acamurçar",
    "acamurçávei": "acamurçar",
    "acamurçáveis": "acamurçar",
    "acamá": "acamar",
    "acamámo": "acamar",
    "acamámos": "acamar",
    "acamáramo": "acamar",
    "acamáramos": "acamar",
    "acamárei": "acamar",
    "acamáreis": "acamar",
    "acamásseis": "acamar",
    "acamássemos": "acamar",
    "acamávamo": "acamar",
    "acamávamos": "acamar",
    "acamávei": "acamar",
    "acamáveis": "acamar",
    "acanaladeira": "acanalador",
    "acanaladeiras": "acanalador",
    "acanaladora": "acanalador",
    "acanaladoras": "acanalador",
    "acanaladores": "acanalador",
    "acanaladuras": "acanaladura",
    "acanalha": "acanalhar",
    "acanalhada": "acanalhar",
    "acanalhadas": "acanalhar",
    "acanalhado": "acanalhar",
    "acanalhados": "acanalhar",
    "acanalhai": "acanalhar",
    "acanalhais": "acanalhar",
    "acanalham": "acanalhar",
    "acanalhamentos": "acanalhamento",
    "acanalhamo": "acanalhar",
    "acanalhamos": "acanalhar",
    "acanalhando": "acanalhar",
    "acanalhara": "acanalhar",
    "acanalharam": "acanalhar",
    "acanalharas": "acanalhar",
    "acanalharde": "acanalhar",
    "acanalhardes": "acanalhar",
    "acanalhare": "acanalhar",
    "acanalharei": "acanalhar",
    "acanalhareis": "acanalhar",
    "acanalharem": "acanalhar",
    "acanalharemos": "acanalhar",
    "acanalhares": "acanalhar",
    "acanalharia": "acanalhar",
    "acanalhariam": "acanalhar",
    "acanalharias": "acanalhar",
    "acanalharmo": "acanalhar",
    "acanalharmos": "acanalhar",
    "acanalhará": "acanalhar",
    "acanalharás": "acanalhar",
    "acanalharão": "acanalhar",
    "acanalharíamos": "acanalhar",
    "acanalharíeis": "acanalhar",
    "acanalhas": "acanalhar",
    "acanalhasse": "acanalhar",
    "acanalhassem": "acanalhar",
    "acanalhasses": "acanalhar",
    "acanalhaste": "acanalhar",
    "acanalhastes": "acanalhar",
    "acanalhava": "acanalhar",
    "acanalhavam": "acanalhar",
    "acanalhavas": "acanalhar",
    "acanalhe": "acanalhar",
    "acanalhei": "acanalhar",
    "acanalheis": "acanalhar",
    "acanalhem": "acanalhar",
    "acanalhemo": "acanalhar",
    "acanalhemos": "acanalhar",
    "acanalhes": "acanalhar",
    "acanalho": "acanalhar",
    "acanalhou": "acanalhar",
    "acanalhá": "acanalhar",
    "acanalhámo": "acanalhar",
    "acanalhámos": "acanalhar",
    "acanalháramo": "acanalhar",
    "acanalháramos": "acanalhar",
    "acanalhárei": "acanalhar",
    "acanalháreis": "acanalhar",
    "acanalhásseis": "acanalhar",
    "acanalhássemos": "acanalhar",
    "acanalhávamo": "acanalhar",
    "acanalhávamos": "acanalhar",
    "acanalhávei": "acanalhar",
    "acanalháveis": "acanalhar",
    "acanastra": "acanastrar",
    "acanastrada": "acanastrar",
    "acanastradas": "acanastrar",
    "acanastrado": "acanastrar",
    "acanastrados": "acanastrar",
    "acanastrai": "acanastrar",
    "acanastrais": "acanastrar",
    "acanastram": "acanastrar",
    "acanastramo": "acanastrar",
    "acanastramos": "acanastrar",
    "acanastrando": "acanastrar",
    "acanastrara": "acanastrar",
    "acanastraram": "acanastrar",
    "acanastraras": "acanastrar",
    "acanastrarde": "acanastrar",
    "acanastrardes": "acanastrar",
    "acanastrare": "acanastrar",
    "acanastrarei": "acanastrar",
    "acanastrareis": "acanastrar",
    "acanastrarem": "acanastrar",
    "acanastraremos": "acanastrar",
    "acanastrares": "acanastrar",
    "acanastraria": "acanastrar",
    "acanastrariam": "acanastrar",
    "acanastrarias": "acanastrar",
    "acanastrarmo": "acanastrar",
    "acanastrarmos": "acanastrar",
    "acanastrará": "acanastrar",
    "acanastrarás": "acanastrar",
    "acanastrarão": "acanastrar",
    "acanastraríamos": "acanastrar",
    "acanastraríeis": "acanastrar",
    "acanastras": "acanastrar",
    "acanastrasse": "acanastrar",
    "acanastrassem": "acanastrar",
    "acanastrasses": "acanastrar",
    "acanastraste": "acanastrar",
    "acanastrastes": "acanastrar",
    "acanastrava": "acanastrar",
    "acanastravam": "acanastrar",
    "acanastravas": "acanastrar",
    "acanastre": "acanastrar",
    "acanastrei": "acanastrar",
    "acanastreis": "acanastrar",
    "acanastrem": "acanastrar",
    "acanastremo": "acanastrar",
    "acanastremos": "acanastrar",
    "acanastres": "acanastrar",
    "acanastro": "acanastrar",
    "acanastrou": "acanastrar",
    "acanastrá": "acanastrar",
    "acanastrámo": "acanastrar",
    "acanastrámos": "acanastrar",
    "acanastráramo": "acanastrar",
    "acanastráramos": "acanastrar",
    "acanastrárei": "acanastrar",
    "acanastráreis": "acanastrar",
    "acanastrásseis": "acanastrar",
    "acanastrássemos": "acanastrar",
    "acanastrávamo": "acanastrar",
    "acanastrávamos": "acanastrar",
    "acanastrávei": "acanastrar",
    "acanastráveis": "acanastrar",
    "acanaveada": "acanavear",
    "acanaveadas": "acanavear",
    "acanaveado": "acanavear",
    "acanaveados": "acanavear",
    "acanaveaduras": "acanaveadura",
    "acanaveai": "acanavear",
    "acanaveais": "acanavear",
    "acanaveamo": "acanavear",
    "acanaveamos": "acanavear",
    "acanaveando": "acanavear",
    "acanaveara": "acanavear",
    "acanavearam": "acanavear",
    "acanavearas": "acanavear",
    "acanavearde": "acanavear",
    "acanaveardes": "acanavear",
    "acanaveare": "acanavear",
    "acanavearei": "acanavear",
    "acanaveareis": "acanavear",
    "acanavearem": "acanavear",
    "acanavearemos": "acanavear",
    "acanaveares": "acanavear",
    "acanavearia": "acanavear",
    "acanaveariam": "acanavear",
    "acanavearias": "acanavear",
    "acanavearmo": "acanavear",
    "acanavearmos": "acanavear",
    "acanaveará": "acanavear",
    "acanavearás": "acanavear",
    "acanavearão": "acanavear",
    "acanavearíamos": "acanavear",
    "acanavearíeis": "acanavear",
    "acanaveasse": "acanavear",
    "acanaveassem": "acanavear",
    "acanaveasses": "acanavear",
    "acanaveaste": "acanavear",
    "acanaveastes": "acanavear",
    "acanaveava": "acanavear",
    "acanaveavam": "acanavear",
    "acanaveavas": "acanavear",
    "acanaveei": "acanavear",
    "acanaveeis": "acanavear",
    "acanaveemo": "acanavear",
    "acanaveemos": "acanavear",
    "acanaveia": "acanavear",
    "acanaveiam": "acanavear",
    "acanaveias": "acanavear",
    "acanaveie": "acanavear",
    "acanaveiem": "acanavear",
    "acanaveies": "acanavear",
    "acanaveio": "acanavear",
    "acanaveou": "acanavear",
    "acanaveá": "acanavear",
    "acanaveámo": "acanavear",
    "acanaveámos": "acanavear",
    "acanaveáramo": "acanavear",
    "acanaveáramos": "acanavear",
    "acanaveárei": "acanavear",
    "acanaveáreis": "acanavear",
    "acanaveásseis": "acanavear",
    "acanaveássemos": "acanavear",
    "acanaveávamo": "acanavear",
    "acanaveávamos": "acanavear",
    "acanaveávei": "acanavear",
    "acanaveáveis": "acanavear",
    "acancela": "acancelar",
    "acancelada": "acancelar",
    "acanceladas": "acancelar",
    "acancelado": "acancelar",
    "acancelados": "acancelar",
    "acancelai": "acancelar",
    "acancelais": "acancelar",
    "acancelam": "acancelar",
    "acancelamo": "acancelar",
    "acancelamos": "acancelar",
    "acancelando": "acancelar",
    "acancelara": "acancelar",
    "acancelaram": "acancelar",
    "acancelaras": "acancelar",
    "acancelarde": "acancelar",
    "acancelardes": "acancelar",
    "acancelare": "acancelar",
    "acancelarei": "acancelar",
    "acancelareis": "acancelar",
    "acancelarem": "acancelar",
    "acancelaremos": "acancelar",
    "acancelares": "acancelar",
    "acancelaria": "acancelar",
    "acancelariam": "acancelar",
    "acancelarias": "acancelar",
    "acancelarmo": "acancelar",
    "acancelarmos": "acancelar",
    "acancelará": "acancelar",
    "acancelarás": "acancelar",
    "acancelarão": "acancelar",
    "acancelaríamos": "acancelar",
    "acancelaríeis": "acancelar",
    "acancelas": "acancelar",
    "acancelasse": "acancelar",
    "acancelassem": "acancelar",
    "acancelasses": "acancelar",
    "acancelaste": "acancelar",
    "acancelastes": "acancelar",
    "acancelava": "acancelar",
    "acancelavam": "acancelar",
    "acancelavas": "acancelar",
    "acancele": "acancelar",
    "acancelei": "acancelar",
    "acanceleis": "acancelar",
    "acancelem": "acancelar",
    "acancelemo": "acancelar",
    "acancelemos": "acancelar",
    "acanceles": "acancelar",
    "acancelo": "acancelar",
    "acancelou": "acancelar",
    "acancelá": "acancelar",
    "acancelámo": "acancelar",
    "acancelámos": "acancelar",
    "acanceláramo": "acancelar",
    "acanceláramos": "acancelar",
    "acancelárei": "acancelar",
    "acanceláreis": "acancelar",
    "acancelásseis": "acancelar",
    "acancelássemos": "acancelar",
    "acancelávamo": "acancelar",
    "acancelávamos": "acancelar",
    "acancelávei": "acancelar",
    "acanceláveis": "acancelar",
    "acanela": "acanelar",
    "acanelada": "acanelar",
    "acaneladas": "acanelar",
    "acanelado": "acanelar",
    "acanelados": "acanelar",
    "acaneladuras": "acaneladura",
    "acanelai": "acanelar",
    "acanelais": "acanelar",
    "acanelam": "acanelar",
    "acanelamo": "acanelar",
    "acanelamos": "acanelar",
    "acanelando": "acanelar",
    "acanelara": "acanelar",
    "acanelaram": "acanelar",
    "acanelaras": "acanelar",
    "acanelarde": "acanelar",
    "acanelardes": "acanelar",
    "acanelare": "acanelar",
    "acanelarei": "acanelar",
    "acanelareis": "acanelar",
    "acanelarem": "acanelar",
    "acanelaremos": "acanelar",
    "acanelares": "acanelar",
    "acanelaria": "acanelar",
    "acanelariam": "acanelar",
    "acanelarias": "acanelar",
    "acanelarmo": "acanelar",
    "acanelarmos": "acanelar",
    "acanelará": "acanelar",
    "acanelarás": "acanelar",
    "acanelarão": "acanelar",
    "acanelaríamos": "acanelar",
    "acanelaríeis": "acanelar",
    "acanelas": "acanelar",
    "acanelasse": "acanelar",
    "acanelassem": "acanelar",
    "acanelasses": "acanelar",
    "acanelaste": "acanelar",
    "acanelastes": "acanelar",
    "acanelava": "acanelar",
    "acanelavam": "acanelar",
    "acanelavas": "acanelar",
    "acanele": "acanelar",
    "acanelei": "acanelar",
    "acaneleis": "acanelar",
    "acanelem": "acanelar",
    "acanelemo": "acanelar",
    "acanelemos": "acanelar",
    "acaneles": "acanelar",
    "acanelo": "acanelar",
    "acanelou": "acanelar",
    "acanelá": "acanelar",
    "acanelámo": "acanelar",
    "acanelámos": "acanelar",
    "acaneláramo": "acanelar",
    "acaneláramos": "acanelar",
    "acanelárei": "acanelar",
    "acaneláreis": "acanelar",
    "acanelásseis": "acanelar",
    "acanelássemos": "acanelar",
    "acanelávamo": "acanelar",
    "acanelávamos": "acanelar",
    "acanelávei": "acanelar",
    "acaneláveis": "acanelar",
    "acangaparas": "acangapara",
    "acanguçus": "acanguçu",
    "acanha": "acanhar",
    "acanhada": "acanhar",
    "acanhadas": "acanhar",
    "acanhadazinha": "acanhado",
    "acanhadazinhas": "acanhado",
    "acanhadazita": "acanhado",
    "acanhadazitas": "acanhado",
    "acanhadinha": "acanhado",
    "acanhadinhas": "acanhado",
    "acanhadinho": "acanhado",
    "acanhadinhos": "acanhado",
    "acanhadita": "acanhado",
    "acanhaditas": "acanhado",
    "acanhadito": "acanhado",
    "acanhaditos": "acanhado",
    "acanhado": "acanhar",
    "acanhadona": "acanhadão",
    "acanhadonas": "acanhadão",
    "acanhadora": "acanhador",
    "acanhadoras": "acanhador",
    "acanhadores": "acanhador",
    "acanhados": "acanhar",
    "acanhadozinho": "acanhado",
    "acanhadozinhos": "acanhado",
    "acanhadozito": "acanhado",
    "acanhadozitos": "acanhado",
    "acanhadíssima": "acanhado",
    "acanhadíssimas": "acanhado",
    "acanhadíssimo": "acanhado",
    "acanhadíssimos": "acanhado",
    "acanhadões": "acanhadão",
    "acanhai": "acanhar",
    "acanhais": "acanhar",
    "acanham": "acanhar",
    "acanhamentos": "acanhamento",
    "acanhamo": "acanhar",
    "acanhamos": "acanhar",
    "acanhando": "acanhar",
    "acanhara": "acanhar",
    "acanharam": "acanhar",
    "acanharas": "acanhar",
    "acanharde": "acanhar",
    "acanhardes": "acanhar",
    "acanhare": "acanhar",
    "acanharei": "acanhar",
    "acanhareis": "acanhar",
    "acanharem": "acanhar",
    "acanharemos": "acanhar",
    "acanhares": "acanhar",
    "acanharia": "acanhar",
    "acanhariam": "acanhar",
    "acanharias": "acanhar",
    "acanharmo": "acanhar",
    "acanharmos": "acanhar",
    "acanhará": "acanhar",
    "acanharás": "acanhar",
    "acanharão": "acanhar",
    "acanharíamos": "acanhar",
    "acanharíeis": "acanhar",
    "acanhas": "acanhar",
    "acanhasse": "acanhar",
    "acanhassem": "acanhar",
    "acanhasses": "acanhar",
    "acanhaste": "acanhar",
    "acanhastes": "acanhar",
    "acanhava": "acanhar",
    "acanhavam": "acanhar",
    "acanhavas": "acanhar",
    "acanhe": "acanhar",
    "acanhei": "acanhar",
    "acanheis": "acanhar",
    "acanhem": "acanhar",
    "acanhemo": "acanhar",
    "acanhemos": "acanhar",
    "acanhes": "acanhar",
    "acanho": "acanhar",
    "acanhoa": "acanhoar",
    "acanhoada": "acanhoar",
    "acanhoadas": "acanhoar",
    "acanhoado": "acanhoar",
    "acanhoados": "acanhoar",
    "acanhoai": "acanhoar",
    "acanhoais": "acanhoar",
    "acanhoam": "acanhoar",
    "acanhoamo": "acanhoar",
    "acanhoamos": "acanhoar",
    "acanhoando": "acanhoar",
    "acanhoara": "acanhoar",
    "acanhoaram": "acanhoar",
    "acanhoaras": "acanhoar",
    "acanhoarde": "acanhoar",
    "acanhoardes": "acanhoar",
    "acanhoare": "acanhoar",
    "acanhoarei": "acanhoar",
    "acanhoareis": "acanhoar",
    "acanhoarem": "acanhoar",
    "acanhoaremos": "acanhoar",
    "acanhoares": "acanhoar",
    "acanhoaria": "acanhoar",
    "acanhoariam": "acanhoar",
    "acanhoarias": "acanhoar",
    "acanhoarmo": "acanhoar",
    "acanhoarmos": "acanhoar",
    "acanhoará": "acanhoar",
    "acanhoarás": "acanhoar",
    "acanhoarão": "acanhoar",
    "acanhoaríamos": "acanhoar",
    "acanhoaríeis": "acanhoar",
    "acanhoas": "acanhoar",
    "acanhoasse": "acanhoar",
    "acanhoassem": "acanhoar",
    "acanhoasses": "acanhoar",
    "acanhoaste": "acanhoar",
    "acanhoastes": "acanhoar",
    "acanhoava": "acanhoar",
    "acanhoavam": "acanhoar",
    "acanhoavas": "acanhoar",
    "acanhoe": "acanhoar",
    "acanhoei": "acanhoar",
    "acanhoeis": "acanhoar",
    "acanhoem": "acanhoar",
    "acanhoemo": "acanhoar",
    "acanhoemos": "acanhoar",
    "acanhoes": "acanhoar",
    "acanhoneada": "acanhonear",
    "acanhoneadas": "acanhonear",
    "acanhoneado": "acanhonear",
    "acanhoneados": "acanhonear",
    "acanhoneai": "acanhonear",
    "acanhoneais": "acanhonear",
    "acanhoneamo": "acanhonear",
    "acanhoneamos": "acanhonear",
    "acanhoneando": "acanhonear",
    "acanhoneara": "acanhonear",
    "acanhonearam": "acanhonear",
    "acanhonearas": "acanhonear",
    "acanhonearde": "acanhonear",
    "acanhoneardes": "acanhonear",
    "acanhoneare": "acanhonear",
    "acanhonearei": "acanhonear",
    "acanhoneareis": "acanhonear",
    "acanhonearem": "acanhonear",
    "acanhonearemos": "acanhonear",
    "acanhoneares": "acanhonear",
    "acanhonearia": "acanhonear",
    "acanhoneariam": "acanhonear",
    "acanhonearias": "acanhonear",
    "acanhonearmo": "acanhonear",
    "acanhonearmos": "acanhonear",
    "acanhoneará": "acanhonear",
    "acanhonearás": "acanhonear",
    "acanhonearão": "acanhonear",
    "acanhonearíamos": "acanhonear",
    "acanhonearíeis": "acanhonear",
    "acanhoneasse": "acanhonear",
    "acanhoneassem": "acanhonear",
    "acanhoneasses": "acanhonear",
    "acanhoneaste": "acanhonear",
    "acanhoneastes": "acanhonear",
    "acanhoneava": "acanhonear",
    "acanhoneavam": "acanhonear",
    "acanhoneavas": "acanhonear",
    "acanhoneei": "acanhonear",
    "acanhoneeis": "acanhonear",
    "acanhoneemo": "acanhonear",
    "acanhoneemos": "acanhonear",
    "acanhoneia": "acanhonear",
    "acanhoneiam": "acanhonear",
    "acanhoneias": "acanhonear",
    "acanhoneie": "acanhonear",
    "acanhoneiem": "acanhonear",
    "acanhoneies": "acanhonear",
    "acanhoneio": "acanhonear",
    "acanhoneou": "acanhonear",
    "acanhoneá": "acanhonear",
    "acanhoneámo": "acanhonear",
    "acanhoneámos": "acanhonear",
    "acanhoneáramo": "acanhonear",
    "acanhoneáramos": "acanhonear",
    "acanhoneárei": "acanhonear",
    "acanhoneáreis": "acanhonear",
    "acanhoneásseis": "acanhonear",
    "acanhoneássemos": "acanhonear",
    "acanhoneávamo": "acanhonear",
    "acanhoneávamos": "acanhonear",
    "acanhoneávei": "acanhonear",
    "acanhoneáveis": "acanhonear",
    "acanhoo": "acanhoar",
    "acanhoou": "acanhoar",
    "acanhos": "acanho",
    "acanhotada": "acanhotado",
    "acanhotadas": "acanhotado",
    "acanhotadazinha": "acanhotado",
    "acanhotadazinhas": "acanhotado",
    "acanhotadazita": "acanhotado",
    "acanhotadazitas": "acanhotado",
    "acanhotadinha": "acanhotado",
    "acanhotadinhas": "acanhotado",
    "acanhotadinho": "acanhotado",
    "acanhotadinhos": "acanhotado",
    "acanhotadita": "acanhotado",
    "acanhotaditas": "acanhotado",
    "acanhotadito": "acanhotado",
    "acanhotaditos": "acanhotado",
    "acanhotados": "acanhotado",
    "acanhotadozinho": "acanhotado",
    "acanhotadozinhos": "acanhotado",
    "acanhotadozito": "acanhotado",
    "acanhotadozitos": "acanhotado",
    "acanhou": "acanhar",
    "acanhoá": "acanhoar",
    "acanhoámo": "acanhoar",
    "acanhoámos": "acanhoar",
    "acanhoáramo": "acanhoar",
    "acanhoáramos": "acanhoar",
    "acanhoárei": "acanhoar",
    "acanhoáreis": "acanhoar",
    "acanhoásseis": "acanhoar",
    "acanhoássemos": "acanhoar",
    "acanhoávamo": "acanhoar",
    "acanhoávamos": "acanhoar",
    "acanhoávei": "acanhoar",
    "acanhoáveis": "acanhoar",
    "acanhá": "acanhar",
    "acanhámo": "acanhar",
    "acanhámos": "acanhar",
    "acanháramo": "acanhar",
    "acanháramos": "acanhar",
    "acanhárei": "acanhar",
    "acanháreis": "acanhar",
    "acanhásseis": "acanhar",
    "acanhássemos": "acanhar",
    "acanhávamo": "acanhar",
    "acanhávamos": "acanhar",
    "acanhávei": "acanhar",
    "acanháveis": "acanhar",
    "acanonistas": "acanonista",
    "acanteira": "acanteirar",
    "acanteirada": "acanteirar",
    "acanteiradas": "acanteirar",
    "acanteirado": "acanteirar",
    "acanteirados": "acanteirar",
    "acanteirai": "acanteirar",
    "acanteirais": "acanteirar",
    "acanteiram": "acanteirar",
    "acanteiramo": "acanteirar",
    "acanteiramos": "acanteirar",
    "acanteirando": "acanteirar",
    "acanteirara": "acanteirar",
    "acanteiraram": "acanteirar",
    "acanteiraras": "acanteirar",
    "acanteirarde": "acanteirar",
    "acanteirardes": "acanteirar",
    "acanteirare": "acanteirar",
    "acanteirarei": "acanteirar",
    "acanteirareis": "acanteirar",
    "acanteirarem": "acanteirar",
    "acanteiraremos": "acanteirar",
    "acanteirares": "acanteirar",
    "acanteiraria": "acanteirar",
    "acanteirariam": "acanteirar",
    "acanteirarias": "acanteirar",
    "acanteirarmo": "acanteirar",
    "acanteirarmos": "acanteirar",
    "acanteirará": "acanteirar",
    "acanteirarás": "acanteirar",
    "acanteirarão": "acanteirar",
    "acanteiraríamos": "acanteirar",
    "acanteiraríeis": "acanteirar",
    "acanteiras": "acanteirar",
    "acanteirasse": "acanteirar",
    "acanteirassem": "acanteirar",
    "acanteirasses": "acanteirar",
    "acanteiraste": "acanteirar",
    "acanteirastes": "acanteirar",
    "acanteirava": "acanteirar",
    "acanteiravam": "acanteirar",
    "acanteiravas": "acanteirar",
    "acanteire": "acanteirar",
    "acanteirei": "acanteirar",
    "acanteireis": "acanteirar",
    "acanteirem": "acanteirar",
    "acanteiremo": "acanteirar",
    "acanteiremos": "acanteirar",
    "acanteires": "acanteirar",
    "acanteiro": "acanteirar",
    "acanteirou": "acanteirar",
    "acanteirá": "acanteirar",
    "acanteirámo": "acanteirar",
    "acanteirámos": "acanteirar",
    "acanteiráramo": "acanteirar",
    "acanteiráramos": "acanteirar",
    "acanteirárei": "acanteirar",
    "acanteiráreis": "acanteirar",
    "acanteirásseis": "acanteirar",
    "acanteirássemos": "acanteirar",
    "acanteirávamo": "acanteirar",
    "acanteirávamos": "acanteirar",
    "acanteirávei": "acanteirar",
    "acanteiráveis": "acanteirar",
    "acantelas": "acantela",
    "acantinas": "acantina",
    "acantites": "acantite",
    "acantoa": "acantoar",
    "acantoada": "acantoar",
    "acantoadas": "acantoar",
    "acantoado": "acantoar",
    "acantoados": "acantoar",
    "acantoai": "acantoar",
    "acantoais": "acantoar",
    "acantoam": "acantoar",
    "acantoamo": "acantoar",
    "acantoamos": "acantoar",
    "acantoando": "acantoar",
    "acantoara": "acantoar",
    "acantoaram": "acantoar",
    "acantoaras": "acantoar",
    "acantoarde": "acantoar",
    "acantoardes": "acantoar",
    "acantoare": "acantoar",
    "acantoarei": "acantoar",
    "acantoareis": "acantoar",
    "acantoarem": "acantoar",
    "acantoaremos": "acantoar",
    "acantoares": "acantoar",
    "acantoaria": "acantoar",
    "acantoariam": "acantoar",
    "acantoarias": "acantoar",
    "acantoarmo": "acantoar",
    "acantoarmos": "acantoar",
    "acantoará": "acantoar",
    "acantoarás": "acantoar",
    "acantoarão": "acantoar",
    "acantoaríamos": "acantoar",
    "acantoaríeis": "acantoar",
    "acantoas": "acantoar",
    "acantoasse": "acantoar",
    "acantoassem": "acantoar",
    "acantoasses": "acantoar",
    "acantoaste": "acantoar",
    "acantoastes": "acantoar",
    "acantoava": "acantoar",
    "acantoavam": "acantoar",
    "acantoavas": "acantoar",
    "acantocarpa": "acantocarpo",
    "acantocarpas": "acantocarpo",
    "acantocarpos": "acantocarpo",
    "acantoceratídea": "acantoceratídeo",
    "acantoceratídeas": "acantoceratídeo",
    "acantoceratídeos": "acantoceratídeo",
    "acantocárpia": "acantocárpio",
    "acantocárpias": "acantocárpio",
    "acantocárpios": "acantocárpio",
    "acantocéfala": "acantocéfalo",
    "acantocéfalas": "acantocéfalo",
    "acantocéfalos": "acantocéfalo",
    "acantodáctila": "acantodáctilo",
    "acantodáctilas": "acantodáctilo",
    "acantodáctilos": "acantodáctilo",
    "acantoe": "acantoar",
    "acantoei": "acantoar",
    "acantoeis": "acantoar",
    "acantoem": "acantoar",
    "acantoemo": "acantoar",
    "acantoemos": "acantoar",
    "acantoes": "acantoar",
    "acantona": "acantonar",
    "acantonada": "acantonar",
    "acantonadas": "acantonar",
    "acantonado": "acantonar",
    "acantonados": "acantonar",
    "acantonai": "acantonar",
    "acantonais": "acantonar",
    "acantonam": "acantonar",
    "acantonamentos": "acantonamento",
    "acantonamo": "acantonar",
    "acantonamos": "acantonar",
    "acantonando": "acantonar",
    "acantonara": "acantonar",
    "acantonaram": "acantonar",
    "acantonaras": "acantonar",
    "acantonarde": "acantonar",
    "acantonardes": "acantonar",
    "acantonare": "acantonar",
    "acantonarei": "acantonar",
    "acantonareis": "acantonar",
    "acantonarem": "acantonar",
    "acantonaremos": "acantonar",
    "acantonares": "acantonar",
    "acantonaria": "acantonar",
    "acantonariam": "acantonar",
    "acantonarias": "acantonar",
    "acantonarmo": "acantonar",
    "acantonarmos": "acantonar",
    "acantonará": "acantonar",
    "acantonarás": "acantonar",
    "acantonarão": "acantonar",
    "acantonaríamos": "acantonar",
    "acantonaríeis": "acantonar",
    "acantonas": "acantonar",
    "acantonasse": "acantonar",
    "acantonassem": "acantonar",
    "acantonasses": "acantonar",
    "acantonaste": "acantonar",
    "acantonastes": "acantonar",
    "acantonava": "acantonar",
    "acantonavam": "acantonar",
    "acantonavas": "acantonar",
    "acantone": "acantonar",
    "acantonei": "acantonar",
    "acantoneis": "acantonar",
    "acantonem": "acantonar",
    "acantonemo": "acantonar",
    "acantonemos": "acantonar",
    "acantones": "acantonar",
    "acantono": "acantonar",
    "acantonou": "acantonar",
    "acantoná": "acantonar",
    "acantonámo": "acantonar",
    "acantonámos": "acantonar",
    "acantonáramo": "acantonar",
    "acantonáramos": "acantonar",
    "acantonárei": "acantonar",
    "acantonáreis": "acantonar",
    "acantonásseis": "acantonar",
    "acantonássemos": "acantonar",
    "acantonávamo": "acantonar",
    "acantonávamos": "acantonar",
    "acantonávei": "acantonar",
    "acantonáveis": "acantonar",
    "acantoo": "acantoar",
    "acantoou": "acantoar",
    "acantoperígia": "acantoperígio",
    "acantoperígias": "acantoperígio",
    "acantoperígios": "acantoperígio",
    "acantopterígios": "acantopterígio",
    "acantos": "acanto",
    "acantoses": "acantose",
    "acantosóides": "acantosóide",
    "acantoá": "acantoar",
    "acantoámo": "acantoar",
    "acantoámos": "acantoar",
    "acantoáramo": "acantoar",
    "acantoáramos": "acantoar",
    "acantoárei": "acantoar",
    "acantoáreis": "acantoar",
    "acantoásseis": "acantoar",
    "acantoássemos": "acantoar",
    "acantoávamo": "acantoar",
    "acantoávamos": "acantoar",
    "acantoávei": "acantoar",
    "acantoáveis": "acantoar",
    "acantácea": "acantáceo",
    "acantáceas": "acantáceo",
    "acantáceos": "acantáceo",
    "acantófaga": "acantófago",
    "acantófagas": "acantófago",
    "acantófagos": "acantófago",
    "acantóptera": "acantóptero",
    "acantópteras": "acantóptero",
    "acantópteros": "acantóptero",
    "acantósperos": "acantóspero",
    "acanuda": "acanudar",
    "acanudada": "acanudar",
    "acanudadas": "acanudar",
    "acanudado": "acanudar",
    "acanudados": "acanudar",
    "acanudai": "acanudar",
    "acanudais": "acanudar",
    "acanudam": "acanudar",
    "acanudamo": "acanudar",
    "acanudamos": "acanudar",
    "acanudando": "acanudar",
    "acanudara": "acanudar",
    "acanudaram": "acanudar",
    "acanudaras": "acanudar",
    "acanudarde": "acanudar",
    "acanudardes": "acanudar",
    "acanudare": "acanudar",
    "acanudarei": "acanudar",
    "acanudareis": "acanudar",
    "acanudarem": "acanudar",
    "acanudaremos": "acanudar",
    "acanudares": "acanudar",
    "acanudaria": "acanudar",
    "acanudariam": "acanudar",
    "acanudarias": "acanudar",
    "acanudarmo": "acanudar",
    "acanudarmos": "acanudar",
    "acanudará": "acanudar",
    "acanudarás": "acanudar",
    "acanudarão": "acanudar",
    "acanudaríamos": "acanudar",
    "acanudaríeis": "acanudar",
    "acanudas": "acanudar",
    "acanudasse": "acanudar",
    "acanudassem": "acanudar",
    "acanudasses": "acanudar",
    "acanudaste": "acanudar",
    "acanudastes": "acanudar",
    "acanudava": "acanudar",
    "acanudavam": "acanudar",
    "acanudavas": "acanudar",
    "acanude": "acanudar",
    "acanudei": "acanudar",
    "acanudeis": "acanudar",
    "acanudem": "acanudar",
    "acanudemo": "acanudar",
    "acanudemos": "acanudar",
    "acanudes": "acanudar",
    "acanudo": "acanudar",
    "acanudou": "acanudar",
    "acanudá": "acanudar",
    "acanudámo": "acanudar",
    "acanudámos": "acanudar",
    "acanudáramo": "acanudar",
    "acanudáramos": "acanudar",
    "acanudárei": "acanudar",
    "acanudáreis": "acanudar",
    "acanudásseis": "acanudar",
    "acanudássemos": "acanudar",
    "acanudávamo": "acanudar",
    "acanudávamos": "acanudar",
    "acanudávei": "acanudar",
    "acanudáveis": "acanudar",
    "acanula": "acanular",
    "acanulada": "acanular",
    "acanuladas": "acanular",
    "acanulado": "acanular",
    "acanulados": "acanular",
    "acanulai": "acanular",
    "acanulais": "acanular",
    "acanulam": "acanular",
    "acanulamo": "acanular",
    "acanulamos": "acanular",
    "acanulando": "acanular",
    "acanulara": "acanular",
    "acanularam": "acanular",
    "acanularas": "acanular",
    "acanularde": "acanular",
    "acanulardes": "acanular",
    "acanulare": "acanular",
    "acanularei": "acanular",
    "acanulareis": "acanular",
    "acanularem": "acanular",
    "acanularemos": "acanular",
    "acanulares": "acanular",
    "acanularia": "acanular",
    "acanulariam": "acanular",
    "acanularias": "acanular",
    "acanularmo": "acanular",
    "acanularmos": "acanular",
    "acanulará": "acanular",
    "acanularás": "acanular",
    "acanularão": "acanular",
    "acanularíamos": "acanular",
    "acanularíeis": "acanular",
    "acanulas": "acanular",
    "acanulasse": "acanular",
    "acanulassem": "acanular",
    "acanulasses": "acanular",
    "acanulaste": "acanular",
    "acanulastes": "acanular",
    "acanulava": "acanular",
    "acanulavam": "acanular",
    "acanulavas": "acanular",
    "acanule": "acanular",
    "acanulei": "acanular",
    "acanuleis": "acanular",
    "acanulem": "acanular",
    "acanulemo": "acanular",
    "acanulemos": "acanular",
    "acanules": "acanular",
    "acanulo": "acanular",
    "acanulou": "acanular",
    "acanulá": "acanular",
    "acanulámo": "acanular",
    "acanulámos": "acanular",
    "acanuláramo": "acanular",
    "acanuláramos": "acanular",
    "acanulárei": "acanular",
    "acanuláreis": "acanular",
    "acanulásseis": "acanular",
    "acanulássemos": "acanular",
    "acanulávamo": "acanular",
    "acanulávamos": "acanular",
    "acanulávei": "acanular",
    "acanuláveis": "acanular",
    "acanónica": "acanónico",
    "acanónicas": "acanónico",
    "acanónicos": "acanónico",
    "acapacha": "acapachar",
    "acapachada": "acapachar",
    "acapachadas": "acapachar",
    "acapachado": "acapachar",
    "acapachados": "acapachar",
    "acapachai": "acapachar",
    "acapachais": "acapachar",
    "acapacham": "acapachar",
    "acapachamo": "acapachar",
    "acapachamos": "acapachar",
    "acapachando": "acapachar",
    "acapachara": "acapachar",
    "acapacharam": "acapachar",
    "acapacharas": "acapachar",
    "acapacharde": "acapachar",
    "acapachardes": "acapachar",
    "acapachare": "acapachar",
    "acapacharei": "acapachar",
    "acapachareis": "acapachar",
    "acapacharem": "acapachar",
    "acapacharemos": "acapachar",
    "acapachares": "acapachar",
    "acapacharia": "acapachar",
    "acapachariam": "acapachar",
    "acapacharias": "acapachar",
    "acapacharmo": "acapachar",
    "acapacharmos": "acapachar",
    "acapachará": "acapachar",
    "acapacharás": "acapachar",
    "acapacharão": "acapachar",
    "acapacharíamos": "acapachar",
    "acapacharíeis": "acapachar",
    "acapachas": "acapachar",
    "acapachasse": "acapachar",
    "acapachassem": "acapachar",
    "acapachasses": "acapachar",
    "acapachaste": "acapachar",
    "acapachastes": "acapachar",
    "acapachava": "acapachar",
    "acapachavam": "acapachar",
    "acapachavas": "acapachar",
    "acapache": "acapachar",
    "acapachei": "acapachar",
    "acapacheis": "acapachar",
    "acapachem": "acapachar",
    "acapachemo": "acapachar",
    "acapachemos": "acapachar",
    "acapaches": "acapachar",
    "acapacho": "acapachar",
    "acapachou": "acapachar",
    "acapachá": "acapachar",
    "acapachámo": "acapachar",
    "acapachámos": "acapachar",
    "acapacháramo": "acapachar",
    "acapacháramos": "acapachar",
    "acapachárei": "acapachar",
    "acapacháreis": "acapachar",
    "acapachásseis": "acapachar",
    "acapachássemos": "acapachar",
    "acapachávamo": "acapachar",
    "acapachávamos": "acapachar",
    "acapachávei": "acapachar",
    "acapacháveis": "acapachar",
    "acaparada": "acaparado",
    "acaparadas": "acaparado",
    "acaparados": "acaparado",
    "acapela": "acapelar",
    "acapelada": "acapelar",
    "acapeladas": "acapelar",
    "acapelado": "acapelar",
    "acapelados": "acapelar",
    "acapelai": "acapelar",
    "acapelais": "acapelar",
    "acapelam": "acapelar",
    "acapelamo": "acapelar",
    "acapelamos": "acapelar",
    "acapelando": "acapelar",
    "acapelara": "acapelar",
    "acapelaram": "acapelar",
    "acapelaras": "acapelar",
    "acapelarde": "acapelar",
    "acapelardes": "acapelar",
    "acapelare": "acapelar",
    "acapelarei": "acapelar",
    "acapelareis": "acapelar",
    "acapelarem": "acapelar",
    "acapelaremos": "acapelar",
    "acapelares": "acapelar",
    "acapelaria": "acapelar",
    "acapelariam": "acapelar",
    "acapelarias": "acapelar",
    "acapelarmo": "acapelar",
    "acapelarmos": "acapelar",
    "acapelará": "acapelar",
    "acapelarás": "acapelar",
    "acapelarão": "acapelar",
    "acapelaríamos": "acapelar",
    "acapelaríeis": "acapelar",
    "acapelas": "acapelar",
    "acapelasse": "acapelar",
    "acapelassem": "acapelar",
    "acapelasses": "acapelar",
    "acapelaste": "acapelar",
    "acapelastes": "acapelar",
    "acapelava": "acapelar",
    "acapelavam": "acapelar",
    "acapelavas": "acapelar",
    "acapele": "acapelar",
    "acapelei": "acapelar",
    "acapeleis": "acapelar",
    "acapelem": "acapelar",
    "acapelemo": "acapelar",
    "acapelemos": "acapelar",
    "acapeles": "acapelar",
    "acapelo": "acapelar",
    "acapelou": "acapelar",
    "acapelá": "acapelar",
    "acapelámo": "acapelar",
    "acapelámos": "acapelar",
    "acapeláramo": "acapelar",
    "acapeláramos": "acapelar",
    "acapelárei": "acapelar",
    "acapeláreis": "acapelar",
    "acapelásseis": "acapelar",
    "acapelássemos": "acapelar",
    "acapelávamo": "acapelar",
    "acapelávamos": "acapelar",
    "acapelávei": "acapelar",
    "acapeláveis": "acapelar",
    "acapitula": "acapitular",
    "acapitulada": "acapitular",
    "acapituladas": "acapitular",
    "acapitulado": "acapitular",
    "acapitulados": "acapitular",
    "acapitulai": "acapitular",
    "acapitulais": "acapitular",
    "acapitulam": "acapitular",
    "acapitulamo": "acapitular",
    "acapitulamos": "acapitular",
    "acapitulando": "acapitular",
    "acapitulara": "acapitular",
    "acapitularam": "acapitular",
    "acapitularas": "acapitular",
    "acapitularde": "acapitular",
    "acapitulardes": "acapitular",
    "acapitulare": "acapitular",
    "acapitularei": "acapitular",
    "acapitulareis": "acapitular",
    "acapitularem": "acapitular",
    "acapitularemos": "acapitular",
    "acapitulares": "acapitular",
    "acapitularia": "acapitular",
    "acapitulariam": "acapitular",
    "acapitularias": "acapitular",
    "acapitularmo": "acapitular",
    "acapitularmos": "acapitular",
    "acapitulará": "acapitular",
    "acapitularás": "acapitular",
    "acapitularão": "acapitular",
    "acapitularíamos": "acapitular",
    "acapitularíeis": "acapitular",
    "acapitulas": "acapitular",
    "acapitulasse": "acapitular",
    "acapitulassem": "acapitular",
    "acapitulasses": "acapitular",
    "acapitulaste": "acapitular",
    "acapitulastes": "acapitular",
    "acapitulava": "acapitular",
    "acapitulavam": "acapitular",
    "acapitulavas": "acapitular",
    "acapitule": "acapitular",
    "acapitulei": "acapitular",
    "acapituleis": "acapitular",
    "acapitulem": "acapitular",
    "acapitulemo": "acapitular",
    "acapitulemos": "acapitular",
    "acapitules": "acapitular",
    "acapitulo": "acapitular",
    "acapitulou": "acapitular",
    "acapitulá": "acapitular",
    "acapitulámo": "acapitular",
    "acapitulámos": "acapitular",
    "acapituláramo": "acapitular",
    "acapituláramos": "acapitular",
    "acapitulárei": "acapitular",
    "acapituláreis": "acapitular",
    "acapitulásseis": "acapitular",
    "acapitulássemos": "acapitular",
    "acapitulávamo": "acapitular",
    "acapitulávamos": "acapitular",
    "acapitulávei": "acapitular",
    "acapituláveis": "acapitular",
    "acapna": "acapno",
    "acapnas": "acapno",
    "acapnos": "acapno",
    "acapuranas": "acapurana",
    "acapus": "acapu",
    "acara": "acarar",
    "acarada": "acarar",
    "acaradas": "acarar",
    "acarado": "acarar",
    "acaradolas": "acaradola",
    "acarados": "acarar",
    "acarai": "acarar",
    "acaraienses": "acaraiense",
    "acarais": "acarar",
    "acarajés": "acarajé",
    "acaram": "acarar",
    "acaramela": "acaramelar",
    "acaramelada": "acaramelar",
    "acarameladas": "acaramelar",
    "acaramelado": "acaramelar",
    "acaramelados": "acaramelar",
    "acaramelai": "acaramelar",
    "acaramelais": "acaramelar",
    "acaramelam": "acaramelar",
    "acaramelamo": "acaramelar",
    "acaramelamos": "acaramelar",
    "acaramelando": "acaramelar",
    "acaramelara": "acaramelar",
    "acaramelaram": "acaramelar",
    "acaramelaras": "acaramelar",
    "acaramelarde": "acaramelar",
    "acaramelardes": "acaramelar",
    "acaramelare": "acaramelar",
    "acaramelarei": "acaramelar",
    "acaramelareis": "acaramelar",
    "acaramelarem": "acaramelar",
    "acaramelaremos": "acaramelar",
    "acaramelares": "acaramelar",
    "acaramelaria": "acaramelar",
    "acaramelariam": "acaramelar",
    "acaramelarias": "acaramelar",
    "acaramelarmo": "acaramelar",
    "acaramelarmos": "acaramelar",
    "acaramelará": "acaramelar",
    "acaramelarás": "acaramelar",
    "acaramelarão": "acaramelar",
    "acaramelaríamos": "acaramelar",
    "acaramelaríeis": "acaramelar",
    "acaramelas": "acaramelar",
    "acaramelasse": "acaramelar",
    "acaramelassem": "acaramelar",
    "acaramelasses": "acaramelar",
    "acaramelaste": "acaramelar",
    "acaramelastes": "acaramelar",
    "acaramelava": "acaramelar",
    "acaramelavam": "acaramelar",
    "acaramelavas": "acaramelar",
    "acaramele": "acaramelar",
    "acaramelei": "acaramelar",
    "acarameleis": "acaramelar",
    "acaramelem": "acaramelar",
    "acaramelemo": "acaramelar",
    "acaramelemos": "acaramelar",
    "acarameles": "acaramelar",
    "acaramelo": "acaramelar",
    "acaramelou": "acaramelar",
    "acaramelá": "acaramelar",
    "acaramelámo": "acaramelar",
    "acaramelámos": "acaramelar",
    "acarameláramo": "acaramelar",
    "acarameláramos": "acaramelar",
    "acaramelárei": "acaramelar",
    "acarameláreis": "acaramelar",
    "acaramelásseis": "acaramelar",
    "acaramelássemos": "acaramelar",
    "acaramelávamo": "acaramelar",
    "acaramelávamos": "acaramelar",
    "acaramelávei": "acaramelar",
    "acarameláveis": "acaramelar",
    "acaramo": "acarar",
    "acaramos": "acarar",
    "acaramula": "acaramular",
    "acaramulada": "acaramular",
    "acaramuladas": "acaramular",
    "acaramulado": "acaramular",
    "acaramulados": "acaramular",
    "acaramulai": "acaramular",
    "acaramulais": "acaramular",
    "acaramulam": "acaramular",
    "acaramulamo": "acaramular",
    "acaramulamos": "acaramular",
    "acaramulando": "acaramular",
    "acaramulara": "acaramular",
    "acaramularam": "acaramular",
    "acaramularas": "acaramular",
    "acaramularde": "acaramular",
    "acaramulardes": "acaramular",
    "acaramulare": "acaramular",
    "acaramularei": "acaramular",
    "acaramulareis": "acaramular",
    "acaramularem": "acaramular",
    "acaramularemos": "acaramular",
    "acaramulares": "acaramular",
    "acaramularia": "acaramular",
    "acaramulariam": "acaramular",
    "acaramularias": "acaramular",
    "acaramularmo": "acaramular",
    "acaramularmos": "acaramular",
    "acaramulará": "acaramular",
    "acaramularás": "acaramular",
    "acaramularão": "acaramular",
    "acaramularíamos": "acaramular",
    "acaramularíeis": "acaramular",
    "acaramulas": "acaramular",
    "acaramulasse": "acaramular",
    "acaramulassem": "acaramular",
    "acaramulasses": "acaramular",
    "acaramulaste": "acaramular",
    "acaramulastes": "acaramular",
    "acaramulava": "acaramular",
    "acaramulavam": "acaramular",
    "acaramulavas": "acaramular",
    "acaramule": "acaramular",
    "acaramulei": "acaramular",
    "acaramuleis": "acaramular",
    "acaramulem": "acaramular",
    "acaramulemo": "acaramular",
    "acaramulemos": "acaramular",
    "acaramules": "acaramular",
    "acaramulo": "acaramular",
    "acaramulou": "acaramular",
    "acaramulá": "acaramular",
    "acaramulámo": "acaramular",
    "acaramulámos": "acaramular",
    "acaramuláramo": "acaramular",
    "acaramuláramos": "acaramular",
    "acaramulárei": "acaramular",
    "acaramuláreis": "acaramular",
    "acaramulásseis": "acaramular",
    "acaramulássemos": "acaramular",
    "acaramulávamo": "acaramular",
    "acaramulávamos": "acaramular",
    "acaramulávei": "acaramular",
    "acaramuláveis": "acaramular",
    "acarando": "acarar",
    "acarapinha": "acarapinhar",
    "acarapinhada": "acarapinhar",
    "acarapinhadas": "acarapinhar",
    "acarapinhado": "acarapinhar",
    "acarapinhados": "acarapinhar",
    "acarapinhai": "acarapinhar",
    "acarapinhais": "acarapinhar",
    "acarapinham": "acarapinhar",
    "acarapinhamo": "acarapinhar",
    "acarapinhamos": "acarapinhar",
    "acarapinhando": "acarapinhar",
    "acarapinhara": "acarapinhar",
    "acarapinharam": "acarapinhar",
    "acarapinharas": "acarapinhar",
    "acarapinharde": "acarapinhar",
    "acarapinhardes": "acarapinhar",
    "acarapinhare": "acarapinhar",
    "acarapinharei": "acarapinhar",
    "acarapinhareis": "acarapinhar",
    "acarapinharem": "acarapinhar",
    "acarapinharemos": "acarapinhar",
    "acarapinhares": "acarapinhar",
    "acarapinharia": "acarapinhar",
    "acarapinhariam": "acarapinhar",
    "acarapinharias": "acarapinhar",
    "acarapinharmo": "acarapinhar",
    "acarapinharmos": "acarapinhar",
    "acarapinhará": "acarapinhar",
    "acarapinharás": "acarapinhar",
    "acarapinharão": "acarapinhar",
    "acarapinharíamos": "acarapinhar",
    "acarapinharíeis": "acarapinhar",
    "acarapinhas": "acarapinhar",
    "acarapinhasse": "acarapinhar",
    "acarapinhassem": "acarapinhar",
    "acarapinhasses": "acarapinhar",
    "acarapinhaste": "acarapinhar",
    "acarapinhastes": "acarapinhar",
    "acarapinhava": "acarapinhar",
    "acarapinhavam": "acarapinhar",
    "acarapinhavas": "acarapinhar",
    "acarapinhe": "acarapinhar",
    "acarapinhei": "acarapinhar",
    "acarapinheis": "acarapinhar",
    "acarapinhem": "acarapinhar",
    "acarapinhemo": "acarapinhar",
    "acarapinhemos": "acarapinhar",
    "acarapinhes": "acarapinhar",
    "acarapinho": "acarapinhar",
    "acarapinhou": "acarapinhar",
    "acarapinhá": "acarapinhar",
    "acarapinhámo": "acarapinhar",
    "acarapinhámos": "acarapinhar",
    "acarapinháramo": "acarapinhar",
    "acarapinháramos": "acarapinhar",
    "acarapinhárei": "acarapinhar",
    "acarapinháreis": "acarapinhar",
    "acarapinhásseis": "acarapinhar",
    "acarapinhássemos": "acarapinhar",
    "acarapinhávamo": "acarapinhar",
    "acarapinhávamos": "acarapinhar",
    "acarapinhávei": "acarapinhar",
    "acarapinháveis": "acarapinhar",
    "acarapis": "acarapi",
    "acarapixunas": "acarapixuna",
    "acarapuce": "acarapuçar",
    "acarapucei": "acarapuçar",
    "acarapuceis": "acarapuçar",
    "acarapucem": "acarapuçar",
    "acarapucemo": "acarapuçar",
    "acarapucemos": "acarapuçar",
    "acarapuces": "acarapuçar",
    "acarapuça": "acarapuçar",
    "acarapuçada": "acarapuçar",
    "acarapuçadas": "acarapuçar",
    "acarapuçado": "acarapuçar",
    "acarapuçados": "acarapuçar",
    "acarapuçai": "acarapuçar",
    "acarapuçais": "acarapuçar",
    "acarapuçam": "acarapuçar",
    "acarapuçamo": "acarapuçar",
    "acarapuçamos": "acarapuçar",
    "acarapuçando": "acarapuçar",
    "acarapuçara": "acarapuçar",
    "acarapuçaram": "acarapuçar",
    "acarapuçaras": "acarapuçar",
    "acarapuçarde": "acarapuçar",
    "acarapuçardes": "acarapuçar",
    "acarapuçare": "acarapuçar",
    "acarapuçarei": "acarapuçar",
    "acarapuçareis": "acarapuçar",
    "acarapuçarem": "acarapuçar",
    "acarapuçaremos": "acarapuçar",
    "acarapuçares": "acarapuçar",
    "acarapuçaria": "acarapuçar",
    "acarapuçariam": "acarapuçar",
    "acarapuçarias": "acarapuçar",
    "acarapuçarmo": "acarapuçar",
    "acarapuçarmos": "acarapuçar",
    "acarapuçará": "acarapuçar",
    "acarapuçarás": "acarapuçar",
    "acarapuçarão": "acarapuçar",
    "acarapuçaríamos": "acarapuçar",
    "acarapuçaríeis": "acarapuçar",
    "acarapuças": "acarapuçar",
    "acarapuçasse": "acarapuçar",
    "acarapuçassem": "acarapuçar",
    "acarapuçasses": "acarapuçar",
    "acarapuçaste": "acarapuçar",
    "acarapuçastes": "acarapuçar",
    "acarapuçava": "acarapuçar",
    "acarapuçavam": "acarapuçar",
    "acarapuçavas": "acarapuçar",
    "acarapuço": "acarapuçar",
    "acarapuçou": "acarapuçar",
    "acarapuçá": "acarapuçar",
    "acarapuçámo": "acarapuçar",
    "acarapuçámos": "acarapuçar",
    "acarapuçáramo": "acarapuçar",
    "acarapuçáramos": "acarapuçar",
    "acarapuçárei": "acarapuçar",
    "acarapuçáreis": "acarapuçar",
    "acarapuçásseis": "acarapuçar",
    "acarapuçássemos": "acarapuçar",
    "acarapuçávamo": "acarapuçar",
    "acarapuçávamos": "acarapuçar",
    "acarapuçávei": "acarapuçar",
    "acarapuçáveis": "acarapuçar",
    "acarara": "acarar",
    "acararam": "acarar",
    "acararas": "acarar",
    "acararde": "acarar",
    "acarardes": "acarar",
    "acarare": "acarar",
    "acararei": "acarar",
    "acarareis": "acarar",
    "acararem": "acarar",
    "acararemos": "acarar",
    "acarares": "acarar",
    "acararia": "acarar",
    "acarariam": "acarar",
    "acararias": "acarar",
    "acararmo": "acarar",
    "acararmos": "acarar",
    "acarará": "acarar",
    "acararás": "acarar",
    "acararão": "acarar",
    "acararíamos": "acarar",
    "acararíeis": "acarar",
    "acaras": "acarar",
    "acarasse": "acarar",
    "acarassem": "acarar",
    "acarasses": "acarar",
    "acaraste": "acarar",
    "acarastes": "acarar",
    "acarauaçus": "acarauaçu",
    "acarava": "acarar",
    "acaravam": "acarar",
    "acaravas": "acarar",
    "acaraúaçus": "acaraúaçu",
    "acardias": "acardia",
    "acarduma": "acardumar",
    "acardumada": "acardumar",
    "acardumadas": "acardumar",
    "acardumado": "acardumar",
    "acardumados": "acardumar",
    "acardumai": "acardumar",
    "acardumais": "acardumar",
    "acardumam": "acardumar",
    "acardumamo": "acardumar",
    "acardumamos": "acardumar",
    "acardumando": "acardumar",
    "acardumara": "acardumar",
    "acardumaram": "acardumar",
    "acardumaras": "acardumar",
    "acardumarde": "acardumar",
    "acardumardes": "acardumar",
    "acardumare": "acardumar",
    "acardumarei": "acardumar",
    "acardumareis": "acardumar",
    "acardumarem": "acardumar",
    "acardumaremos": "acardumar",
    "acardumares": "acardumar",
    "acardumaria": "acardumar",
    "acardumariam": "acardumar",
    "acardumarias": "acardumar",
    "acardumarmo": "acardumar",
    "acardumarmos": "acardumar",
    "acardumará": "acardumar",
    "acardumarás": "acardumar",
    "acardumarão": "acardumar",
    "acardumaríamos": "acardumar",
    "acardumaríeis": "acardumar",
    "acardumas": "acardumar",
    "acardumasse": "acardumar",
    "acardumassem": "acardumar",
    "acardumasses": "acardumar",
    "acardumaste": "acardumar",
    "acardumastes": "acardumar",
    "acardumava": "acardumar",
    "acardumavam": "acardumar",
    "acardumavas": "acardumar",
    "acardume": "acardumar",
    "acardumei": "acardumar",
    "acardumeis": "acardumar",
    "acardumem": "acardumar",
    "acardumemo": "acardumar",
    "acardumemos": "acardumar",
    "acardumes": "acardumar",
    "acardumo": "acardumar",
    "acardumou": "acardumar",
    "acardumá": "acardumar",
    "acardumámo": "acardumar",
    "acardumámos": "acardumar",
    "acardumáramo": "acardumar",
    "acardumáramos": "acardumar",
    "acardumárei": "acardumar",
    "acardumáreis": "acardumar",
    "acardumásseis": "acardumar",
    "acardumássemos": "acardumar",
    "acardumávamo": "acardumar",
    "acardumávamos": "acardumar",
    "acardumávei": "acardumar",
    "acardumáveis": "acardumar",
    "acare": "acarar",
    "acareada": "acarear",
    "acareadas": "acarear",
    "acareado": "acarear",
    "acareados": "acarear",
    "acareai": "acarear",
    "acareais": "acarear",
    "acareamentos": "acareamento",
    "acareamo": "acarear",
    "acareamos": "acarear",
    "acareando": "acarear",
    "acareara": "acarear",
    "acarearam": "acarear",
    "acarearas": "acarear",
    "acarearde": "acarear",
    "acareardes": "acarear",
    "acareare": "acarear",
    "acarearei": "acarear",
    "acareareis": "acarear",
    "acarearem": "acarear",
    "acarearemos": "acarear",
    "acareares": "acarear",
    "acarearia": "acarear",
    "acareariam": "acarear",
    "acarearias": "acarear",
    "acarearmo": "acarear",
    "acarearmos": "acarear",
    "acareará": "acarear",
    "acarearás": "acarear",
    "acarearão": "acarear",
    "acarearíamos": "acarear",
    "acarearíeis": "acarear",
    "acareasse": "acarear",
    "acareassem": "acarear",
    "acareasses": "acarear",
    "acareaste": "acarear",
    "acareastes": "acarear",
    "acareava": "acarear",
    "acareavam": "acarear",
    "acareavas": "acarear",
    "acareações": "acareação",
    "acareei": "acarear",
    "acareeis": "acarear",
    "acareemo": "acarear",
    "acareemos": "acarear",
    "acarei": "acarar",
    "acareia": "acarear",
    "acareiam": "acarear",
    "acareias": "acarear",
    "acareie": "acarear",
    "acareiem": "acarear",
    "acareies": "acarear",
    "acareio": "acarear",
    "acareis": "acarar",
    "acarem": "acarar",
    "acaremo": "acarar",
    "acaremos": "acarar",
    "acareou": "acarear",
    "acares": "acarar",
    "acareá": "acarear",
    "acareámo": "acarear",
    "acareámos": "acarear",
    "acareáramo": "acarear",
    "acareáramos": "acarear",
    "acareárei": "acarear",
    "acareáreis": "acarear",
    "acareásseis": "acarear",
    "acareássemos": "acarear",
    "acareávamo": "acarear",
    "acareávamos": "acarear",
    "acareávei": "acarear",
    "acareáveis": "acarear",
    "acariaçus": "acariaçu",
    "acaricia": "acariciar",
    "acariciada": "acariciar",
    "acariciadas": "acariciar",
    "acariciadeira": "acariciador",
    "acariciadeiras": "acariciador",
    "acariciado": "acariciar",
    "acariciadora": "acariciador",
    "acariciadoras": "acariciador",
    "acariciadores": "acariciador",
    "acariciados": "acariciar",
    "acariciai": "acariciar",
    "acariciais": "acariciar",
    "acariciam": "acariciar",
    "acariciamo": "acariciar",
    "acariciamos": "acariciar",
    "acariciando": "acariciar",
    "acariciantes": "acariciante",
    "acariciara": "acariciar",
    "acariciaram": "acariciar",
    "acariciaras": "acariciar",
    "acariciarde": "acariciar",
    "acariciardes": "acariciar",
    "acariciare": "acariciar",
    "acariciarei": "acariciar",
    "acariciareis": "acariciar",
    "acariciarem": "acariciar",
    "acariciaremos": "acariciar",
    "acariciares": "acariciar",
    "acariciaria": "acariciar",
    "acariciariam": "acariciar",
    "acariciarias": "acariciar",
    "acariciarmo": "acariciar",
    "acariciarmos": "acariciar",
    "acariciará": "acariciar",
    "acariciarás": "acariciar",
    "acariciarão": "acariciar",
    "acariciaríamos": "acariciar",
    "acariciaríeis": "acariciar",
    "acaricias": "acariciar",
    "acariciasse": "acariciar",
    "acariciassem": "acariciar",
    "acariciasses": "acariciar",
    "acariciaste": "acariciar",
    "acariciastes": "acariciar",
    "acariciativa": "acariciativo",
    "acariciativas": "acariciativo",
    "acariciativos": "acariciativo",
    "acariciava": "acariciar",
    "acariciavam": "acariciar",
    "acariciavas": "acariciar",
    "acaricidas": "acaricida",
    "acaricie": "acariciar",
    "acariciei": "acariciar",
    "acaricieis": "acariciar",
    "acariciem": "acariciar",
    "acariciemo": "acariciar",
    "acariciemos": "acariciar",
    "acaricies": "acariciar",
    "acaricio": "acariciar",
    "acariciou": "acariciar",
    "acariciá": "acariciar",
    "acariciámo": "acariciar",
    "acariciámos": "acariciar",
    "acariciáramo": "acariciar",
    "acariciáramos": "acariciar",
    "acariciárei": "acariciar",
    "acariciáreis": "acariciar",
    "acariciásseis": "acariciar",
    "acariciássemos": "acariciar",
    "acariciávamo": "acariciar",
    "acariciávamos": "acariciar",
    "acariciávei": "acariciar",
    "acariciáveis": "acariciável",
    "acarida": "acaridar",
    "acaridada": "acaridar",
    "acaridadas": "acaridar",
    "acaridado": "acaridar",
    "acaridados": "acaridar",
    "acaridai": "acaridar",
    "acaridais": "acaridar",
    "acaridam": "acaridar",
    "acaridamo": "acaridar",
    "acaridamos": "acaridar",
    "acaridando": "acaridar",
    "acaridara": "acaridar",
    "acaridaram": "acaridar",
    "acaridaras": "acaridar",
    "acaridarde": "acaridar",
    "acaridardes": "acaridar",
    "acaridare": "acaridar",
    "acaridarei": "acaridar",
    "acaridareis": "acaridar",
    "acaridarem": "acaridar",
    "acaridaremos": "acaridar",
    "acaridares": "acaridar",
    "acaridaria": "acaridar",
    "acaridariam": "acaridar",
    "acaridarias": "acaridar",
    "acaridarmo": "acaridar",
    "acaridarmos": "acaridar",
    "acaridará": "acaridar",
    "acaridarás": "acaridar",
    "acaridarão": "acaridar",
    "acaridaríamos": "acaridar",
    "acaridaríeis": "acaridar",
    "acaridas": "acaridar",
    "acaridasse": "acaridar",
    "acaridassem": "acaridar",
    "acaridasses": "acaridar",
    "acaridaste": "acaridar",
    "acaridastes": "acaridar",
    "acaridava": "acaridar",
    "acaridavam": "acaridar",
    "acaridavas": "acaridar",
    "acaride": "acaridar",
    "acaridei": "acaridar",
    "acarideis": "acaridar",
    "acaridem": "acaridar",
    "acaridemo": "acaridar",
    "acaridemos": "acaridar",
    "acarides": "acaridar",
    "acarido": "acaridar",
    "acaridou": "acaridar",
    "acaridá": "acaridar",
    "acaridámo": "acaridar",
    "acaridámos": "acaridar",
    "acaridáramo": "acaridar",
    "acaridáramos": "acaridar",
    "acaridárei": "acaridar",
    "acaridáreis": "acaridar",
    "acaridásseis": "acaridar",
    "acaridássemos": "acaridar",
    "acaridávamo": "acaridar",
    "acaridávamos": "acaridar",
    "acaridávei": "acaridar",
    "acaridáveis": "acaridar",
    "acarimas": "acarima",
    "acarina": "acarino",
    "acarinas": "acarino",
    "acarinha": "acarinhar",
    "acarinhada": "acarinhar",
    "acarinhadas": "acarinhar",
    "acarinhado": "acarinhar",
    "acarinhados": "acarinhar",
    "acarinhai": "acarinhar",
    "acarinhais": "acarinhar",
    "acarinham": "acarinhar",
    "acarinhamo": "acarinhar",
    "acarinhamos": "acarinhar",
    "acarinhando": "acarinhar",
    "acarinhara": "acarinhar",
    "acarinharam": "acarinhar",
    "acarinharas": "acarinhar",
    "acarinharde": "acarinhar",
    "acarinhardes": "acarinhar",
    "acarinhare": "acarinhar",
    "acarinharei": "acarinhar",
    "acarinhareis": "acarinhar",
    "acarinharem": "acarinhar",
    "acarinharemos": "acarinhar",
    "acarinhares": "acarinhar",
    "acarinharia": "acarinhar",
    "acarinhariam": "acarinhar",
    "acarinharias": "acarinhar",
    "acarinharmo": "acarinhar",
    "acarinharmos": "acarinhar",
    "acarinhará": "acarinhar",
    "acarinharás": "acarinhar",
    "acarinharão": "acarinhar",
    "acarinharíamos": "acarinhar",
    "acarinharíeis": "acarinhar",
    "acarinhas": "acarinhar",
    "acarinhasse": "acarinhar",
    "acarinhassem": "acarinhar",
    "acarinhasses": "acarinhar",
    "acarinhaste": "acarinhar",
    "acarinhastes": "acarinhar",
    "acarinhava": "acarinhar",
    "acarinhavam": "acarinhar",
    "acarinhavas": "acarinhar",
    "acarinhe": "acarinhar",
    "acarinhei": "acarinhar",
    "acarinheis": "acarinhar",
    "acarinhem": "acarinhar",
    "acarinhemo": "acarinhar",
    "acarinhemos": "acarinhar",
    "acarinhes": "acarinhar",
    "acarinho": "acarinhar",
    "acarinhou": "acarinhar",
    "acarinhá": "acarinhar",
    "acarinhámo": "acarinhar",
    "acarinhámos": "acarinhar",
    "acarinháramo": "acarinhar",
    "acarinháramos": "acarinhar",
    "acarinhárei": "acarinhar",
    "acarinháreis": "acarinhar",
    "acarinhásseis": "acarinhar",
    "acarinhássemos": "acarinhar",
    "acarinhávamo": "acarinhar",
    "acarinhávamos": "acarinhar",
    "acarinhávei": "acarinhar",
    "acarinháveis": "acarinhar",
    "acarinos": "acarino",
    "acaris": "acari",
    "acarmina": "acarminar",
    "acarminada": "acarminar",
    "acarminadas": "acarminar",
    "acarminado": "acarminar",
    "acarminados": "acarminar",
    "acarminai": "acarminar",
    "acarminais": "acarminar",
    "acarminam": "acarminar",
    "acarminamo": "acarminar",
    "acarminamos": "acarminar",
    "acarminando": "acarminar",
    "acarminara": "acarminar",
    "acarminaram": "acarminar",
    "acarminaras": "acarminar",
    "acarminarde": "acarminar",
    "acarminardes": "acarminar",
    "acarminare": "acarminar",
    "acarminarei": "acarminar",
    "acarminareis": "acarminar",
    "acarminarem": "acarminar",
    "acarminaremos": "acarminar",
    "acarminares": "acarminar",
    "acarminaria": "acarminar",
    "acarminariam": "acarminar",
    "acarminarias": "acarminar",
    "acarminarmo": "acarminar",
    "acarminarmos": "acarminar",
    "acarminará": "acarminar",
    "acarminarás": "acarminar",
    "acarminarão": "acarminar",
    "acarminaríamos": "acarminar",
    "acarminaríeis": "acarminar",
    "acarminas": "acarminar",
    "acarminasse": "acarminar",
    "acarminassem": "acarminar",
    "acarminasses": "acarminar",
    "acarminaste": "acarminar",
    "acarminastes": "acarminar",
    "acarminava": "acarminar",
    "acarminavam": "acarminar",
    "acarminavas": "acarminar",
    "acarmine": "acarminar",
    "acarminei": "acarminar",
    "acarmineis": "acarminar",
    "acarminem": "acarminar",
    "acarminemo": "acarminar",
    "acarminemos": "acarminar",
    "acarmines": "acarminar",
    "acarmino": "acarminar",
    "acarminou": "acarminar",
    "acarminá": "acarminar",
    "acarminámo": "acarminar",
    "acarminámos": "acarminar",
    "acarmináramo": "acarminar",
    "acarmináramos": "acarminar",
    "acarminárei": "acarminar",
    "acarmináreis": "acarminar",
    "acarminásseis": "acarminar",
    "acarminássemos": "acarminar",
    "acarminávamo": "acarminar",
    "acarminávamos": "acarminar",
    "acarminávei": "acarminar",
    "acarmináveis": "acarminar",
    "acarneira": "acarneirar",
    "acarneirada": "acarneirar",
    "acarneiradas": "acarneirar",
    "acarneirado": "acarneirar",
    "acarneirados": "acarneirar",
    "acarneirai": "acarneirar",
    "acarneirais": "acarneirar",
    "acarneiram": "acarneirar",
    "acarneiramo": "acarneirar",
    "acarneiramos": "acarneirar",
    "acarneirando": "acarneirar",
    "acarneirara": "acarneirar",
    "acarneiraram": "acarneirar",
    "acarneiraras": "acarneirar",
    "acarneirarde": "acarneirar",
    "acarneirardes": "acarneirar",
    "acarneirare": "acarneirar",
    "acarneirarei": "acarneirar",
    "acarneirareis": "acarneirar",
    "acarneirarem": "acarneirar",
    "acarneiraremos": "acarneirar",
    "acarneirares": "acarneirar",
    "acarneiraria": "acarneirar",
    "acarneirariam": "acarneirar",
    "acarneirarias": "acarneirar",
    "acarneirarmo": "acarneirar",
    "acarneirarmos": "acarneirar",
    "acarneirará": "acarneirar",
    "acarneirarás": "acarneirar",
    "acarneirarão": "acarneirar",
    "acarneiraríamos": "acarneirar",
    "acarneiraríeis": "acarneirar",
    "acarneiras": "acarneirar",
    "acarneirasse": "acarneirar",
    "acarneirassem": "acarneirar",
    "acarneirasses": "acarneirar",
    "acarneiraste": "acarneirar",
    "acarneirastes": "acarneirar",
    "acarneirava": "acarneirar",
    "acarneiravam": "acarneirar",
    "acarneiravas": "acarneirar",
    "acarneire": "acarneirar",
    "acarneirei": "acarneirar",
    "acarneireis": "acarneirar",
    "acarneirem": "acarneirar",
    "acarneiremo": "acarneirar",
    "acarneiremos": "acarneirar",
    "acarneires": "acarneirar",
    "acarneiro": "acarneirar",
    "acarneirou": "acarneirar",
    "acarneirá": "acarneirar",
    "acarneirámo": "acarneirar",
    "acarneirámos": "acarneirar",
    "acarneiráramo": "acarneirar",
    "acarneiráramos": "acarneirar",
    "acarneirárei": "acarneirar",
    "acarneiráreis": "acarneirar",
    "acarneirásseis": "acarneirar",
    "acarneirássemos": "acarneirar",
    "acarneirávamo": "acarneirar",
    "acarneirávamos": "acarneirar",
    "acarneirávei": "acarneirar",
    "acarneiráveis": "acarneirar",
    "acaro": "acarar",
    "acarochada": "acarochado",
    "acarochadas": "acarochado",
    "acarochados": "acarochado",
    "acarofobias": "acarofobia",
    "acarou": "acarar",
    "acarpa": "acarpo",
    "acarpas": "acarpo",
    "acarpelada": "acarpelado",
    "acarpeladas": "acarpelado",
    "acarpelados": "acarpelado",
    "acarpias": "acarpia",
    "acarpos": "acarpo",
    "acarra": "acarrar",
    "acarrace": "acarraçar",
    "acarracei": "acarraçar",
    "acarraceis": "acarraçar",
    "acarracem": "acarraçar",
    "acarracemo": "acarraçar",
    "acarracemos": "acarraçar",
    "acarraces": "acarraçar",
    "acarrada": "acarrar",
    "acarradas": "acarrar",
    "acarrado": "acarrar",
    "acarradoiros": "acarradoiro",
    "acarrados": "acarrar",
    "acarradouros": "acarradouro",
    "acarrai": "acarrar",
    "acarrais": "acarrar",
    "acarram": "acarrar",
    "acarramo": "acarrar",
    "acarramos": "acarrar",
    "acarranca": "acarrancar",
    "acarrancada": "acarrancar",
    "acarrancadas": "acarrancar",
    "acarrancado": "acarrancar",
    "acarrancados": "acarrancar",
    "acarrancai": "acarrancar",
    "acarrancais": "acarrancar",
    "acarrancam": "acarrancar",
    "acarrancamo": "acarrancar",
    "acarrancamos": "acarrancar",
    "acarrancando": "acarrancar",
    "acarrancara": "acarrancar",
    "acarrancaram": "acarrancar",
    "acarrancaras": "acarrancar",
    "acarrancarde": "acarrancar",
    "acarrancardes": "acarrancar",
    "acarrancare": "acarrancar",
    "acarrancarei": "acarrancar",
    "acarrancareis": "acarrancar",
    "acarrancarem": "acarrancar",
    "acarrancaremos": "acarrancar",
    "acarrancares": "acarrancar",
    "acarrancaria": "acarrancar",
    "acarrancariam": "acarrancar",
    "acarrancarias": "acarrancar",
    "acarrancarmo": "acarrancar",
    "acarrancarmos": "acarrancar",
    "acarrancará": "acarrancar",
    "acarrancarás": "acarrancar",
    "acarrancarão": "acarrancar",
    "acarrancaríamos": "acarrancar",
    "acarrancaríeis": "acarrancar",
    "acarrancas": "acarrancar",
    "acarrancasse": "acarrancar",
    "acarrancassem": "acarrancar",
    "acarrancasses": "acarrancar",
    "acarrancaste": "acarrancar",
    "acarrancastes": "acarrancar",
    "acarrancava": "acarrancar",
    "acarrancavam": "acarrancar",
    "acarrancavas": "acarrancar",
    "acarranco": "acarrancar",
    "acarrancou": "acarrancar",
    "acarrancá": "acarrancar",
    "acarrancámo": "acarrancar",
    "acarrancámos": "acarrancar",
    "acarrancáramo": "acarrancar",
    "acarrancáramos": "acarrancar",
    "acarrancárei": "acarrancar",
    "acarrancáreis": "acarrancar",
    "acarrancásseis": "acarrancar",
    "acarrancássemos": "acarrancar",
    "acarrancávamo": "acarrancar",
    "acarrancávamos": "acarrancar",
    "acarrancávei": "acarrancar",
    "acarrancáveis": "acarrancar",
    "acarrando": "acarrar",
    "acarranque": "acarrancar",
    "acarranquei": "acarrancar",
    "acarranqueis": "acarrancar",
    "acarranquem": "acarrancar",
    "acarranquemo": "acarrancar",
    "acarranquemos": "acarrancar",
    "acarranques": "acarrancar",
    "acarrapata": "acarrapatar",
    "acarrapatada": "acarrapatar",
    "acarrapatadas": "acarrapatar",
    "acarrapatado": "acarrapatar",
    "acarrapatados": "acarrapatar",
    "acarrapatai": "acarrapatar",
    "acarrapatais": "acarrapatar",
    "acarrapatam": "acarrapatar",
    "acarrapatamo": "acarrapatar",
    "acarrapatamos": "acarrapatar",
    "acarrapatando": "acarrapatar",
    "acarrapatara": "acarrapatar",
    "acarrapataram": "acarrapatar",
    "acarrapataras": "acarrapatar",
    "acarrapatarde": "acarrapatar",
    "acarrapatardes": "acarrapatar",
    "acarrapatare": "acarrapatar",
    "acarrapatarei": "acarrapatar",
    "acarrapatareis": "acarrapatar",
    "acarrapatarem": "acarrapatar",
    "acarrapataremos": "acarrapatar",
    "acarrapatares": "acarrapatar",
    "acarrapataria": "acarrapatar",
    "acarrapatariam": "acarrapatar",
    "acarrapatarias": "acarrapatar",
    "acarrapatarmo": "acarrapatar",
    "acarrapatarmos": "acarrapatar",
    "acarrapatará": "acarrapatar",
    "acarrapatarás": "acarrapatar",
    "acarrapatarão": "acarrapatar",
    "acarrapataríamos": "acarrapatar",
    "acarrapataríeis": "acarrapatar",
    "acarrapatas": "acarrapatar",
    "acarrapatasse": "acarrapatar",
    "acarrapatassem": "acarrapatar",
    "acarrapatasses": "acarrapatar",
    "acarrapataste": "acarrapatar",
    "acarrapatastes": "acarrapatar",
    "acarrapatava": "acarrapatar",
    "acarrapatavam": "acarrapatar",
    "acarrapatavas": "acarrapatar",
    "acarrapate": "acarrapatar",
    "acarrapatei": "acarrapatar",
    "acarrapateis": "acarrapatar",
    "acarrapatem": "acarrapatar",
    "acarrapatemo": "acarrapatar",
    "acarrapatemos": "acarrapatar",
    "acarrapates": "acarrapatar",
    "acarrapato": "acarrapatar",
    "acarrapatou": "acarrapatar",
    "acarrapatá": "acarrapatar",
    "acarrapatámo": "acarrapatar",
    "acarrapatámos": "acarrapatar",
    "acarrapatáramo": "acarrapatar",
    "acarrapatáramos": "acarrapatar",
    "acarrapatárei": "acarrapatar",
    "acarrapatáreis": "acarrapatar",
    "acarrapatásseis": "acarrapatar",
    "acarrapatássemos": "acarrapatar",
    "acarrapatávamo": "acarrapatar",
    "acarrapatávamos": "acarrapatar",
    "acarrapatávei": "acarrapatar",
    "acarrapatáveis": "acarrapatar",
    "acarrara": "acarrar",
    "acarraram": "acarrar",
    "acarraras": "acarrar",
    "acarrardes": "acarrar",
    "acarrarei": "acarrar",
    "acarrareis": "acarrar",
    "acarrarem": "acarrar",
    "acarraremos": "acarrar",
    "acarrares": "acarrar",
    "acarraria": "acarrar",
    "acarrariam": "acarrar",
    "acarrarias": "acarrar",
    "acarrarmo": "acarrar",
    "acarrarmos": "acarrar",
    "acarrará": "acarrar",
    "acarrarás": "acarrar",
    "acarrarão": "acarrar",
    "acarraríamos": "acarrar",
    "acarraríeis": "acarrar",
    "acarras": "acarrar",
    "acarrasse": "acarrar",
    "acarrassem": "acarrar",
    "acarrasses": "acarrar",
    "acarraste": "acarrar",
    "acarrastes": "acarrar",
    "acarrava": "acarrar",
    "acarravam": "acarrar",
    "acarravas": "acarrar",
    "acarraça": "acarraçar",
    "acarraçada": "acarraçar",
    "acarraçadas": "acarraçar",
    "acarraçado": "acarraçar",
    "acarraçados": "acarraçar",
    "acarraçai": "acarraçar",
    "acarraçais": "acarraçar",
    "acarraçam": "acarraçar",
    "acarraçamo": "acarraçar",
    "acarraçamos": "acarraçar",
    "acarraçando": "acarraçar",
    "acarraçara": "acarraçar",
    "acarraçaram": "acarraçar",
    "acarraçaras": "acarraçar",
    "acarraçarde": "acarraçar",
    "acarraçardes": "acarraçar",
    "acarraçare": "acarraçar",
    "acarraçarei": "acarraçar",
    "acarraçareis": "acarraçar",
    "acarraçarem": "acarraçar",
    "acarraçaremos": "acarraçar",
    "acarraçares": "acarraçar",
    "acarraçaria": "acarraçar",
    "acarraçariam": "acarraçar",
    "acarraçarias": "acarraçar",
    "acarraçarmo": "acarraçar",
    "acarraçarmos": "acarraçar",
    "acarraçará": "acarraçar",
    "acarraçarás": "acarraçar",
    "acarraçarão": "acarraçar",
    "acarraçaríamos": "acarraçar",
    "acarraçaríeis": "acarraçar",
    "acarraças": "acarraçar",
    "acarraçasse": "acarraçar",
    "acarraçassem": "acarraçar",
    "acarraçasses": "acarraçar",
    "acarraçaste": "acarraçar",
    "acarraçastes": "acarraçar",
    "acarraçava": "acarraçar",
    "acarraçavam": "acarraçar",
    "acarraçavas": "acarraçar",
    "acarraço": "acarraçar",
    "acarraçou": "acarraçar",
    "acarraçá": "acarraçar",
    "acarraçámo": "acarraçar",
    "acarraçámos": "acarraçar",
    "acarraçáramo": "acarraçar",
    "acarraçáramos": "acarraçar",
    "acarraçárei": "acarraçar",
    "acarraçáreis": "acarraçar",
    "acarraçásseis": "acarraçar",
    "acarraçássemos": "acarraçar",
    "acarraçávamo": "acarraçar",
    "acarraçávamos": "acarraçar",
    "acarraçávei": "acarraçar",
    "acarraçáveis": "acarraçar",
    "acarrações": "acarração",
    "acarre": "acarrar",
    "acarreada": "acarrear",
    "acarreadas": "acarrear",
    "acarreado": "acarrear",
    "acarreados": "acarrear",
    "acarreai": "acarrear",
    "acarreais": "acarrear",
    "acarreamo": "acarrear",
    "acarreamos": "acarrear",
    "acarreando": "acarrear",
    "acarreara": "acarrear",
    "acarrearam": "acarrear",
    "acarrearas": "acarrear",
    "acarrearde": "acarrear",
    "acarreardes": "acarrear",
    "acarreare": "acarrear",
    "acarrearei": "acarrear",
    "acarreareis": "acarrear",
    "acarrearem": "acarrear",
    "acarrearemos": "acarrear",
    "acarreares": "acarrear",
    "acarrearia": "acarrear",
    "acarreariam": "acarrear",
    "acarrearias": "acarrear",
    "acarrearmo": "acarrear",
    "acarrearmos": "acarrear",
    "acarreará": "acarrear",
    "acarrearás": "acarrear",
    "acarrearão": "acarrear",
    "acarrearíamos": "acarrear",
    "acarrearíeis": "acarrear",
    "acarreasse": "acarrear",
    "acarreassem": "acarrear",
    "acarreasses": "acarrear",
    "acarreaste": "acarrear",
    "acarreastes": "acarrear",
    "acarreava": "acarrear",
    "acarreavam": "acarrear",
    "acarreavas": "acarrear",
    "acarreei": "acarrear",
    "acarreeis": "acarrear",
    "acarreemo": "acarrear",
    "acarreemos": "acarrear",
    "acarrei": "acarrar",
    "acarreia": "acarrear",
    "acarreiam": "acarrear",
    "acarreias": "acarrear",
    "acarreie": "acarrear",
    "acarreiem": "acarrear",
    "acarreies": "acarrear",
    "acarreio": "acarrear",
    "acarreios": "acarreio",
    "acarreis": "acarrar",
    "acarreja": "acarrejar",
    "acarrejada": "acarrejar",
    "acarrejadas": "acarrejar",
    "acarrejado": "acarrejar",
    "acarrejados": "acarrejar",
    "acarrejai": "acarrejar",
    "acarrejais": "acarrejar",
    "acarrejam": "acarrejar",
    "acarrejamo": "acarrejar",
    "acarrejamos": "acarrejar",
    "acarrejando": "acarrejar",
    "acarrejara": "acarrejar",
    "acarrejaram": "acarrejar",
    "acarrejaras": "acarrejar",
    "acarrejarde": "acarrejar",
    "acarrejardes": "acarrejar",
    "acarrejare": "acarrejar",
    "acarrejarei": "acarrejar",
    "acarrejareis": "acarrejar",
    "acarrejarem": "acarrejar",
    "acarrejaremos": "acarrejar",
    "acarrejares": "acarrejar",
    "acarrejaria": "acarrejar",
    "acarrejariam": "acarrejar",
    "acarrejarias": "acarrejar",
    "acarrejarmo": "acarrejar",
    "acarrejarmos": "acarrejar",
    "acarrejará": "acarrejar",
    "acarrejarás": "acarrejar",
    "acarrejarão": "acarrejar",
    "acarrejaríamos": "acarrejar",
    "acarrejaríeis": "acarrejar",
    "acarrejas": "acarrejar",
    "acarrejasse": "acarrejar",
    "acarrejassem": "acarrejar",
    "acarrejasses": "acarrejar",
    "acarrejaste": "acarrejar",
    "acarrejastes": "acarrejar",
    "acarrejava": "acarrejar",
    "acarrejavam": "acarrejar",
    "acarrejavas": "acarrejar",
    "acarreje": "acarrejar",
    "acarrejei": "acarrejar",
    "acarrejeis": "acarrejar",
    "acarrejem": "acarrejar",
    "acarrejemo": "acarrejar",
    "acarrejemos": "acarrejar",
    "acarrejes": "acarrejar",
    "acarrejo": "acarrejar",
    "acarrejou": "acarrejar",
    "acarrejá": "acarrejar",
    "acarrejámo": "acarrejar",
    "acarrejámos": "acarrejar",
    "acarrejáramo": "acarrejar",
    "acarrejáramos": "acarrejar",
    "acarrejárei": "acarrejar",
    "acarrejáreis": "acarrejar",
    "acarrejásseis": "acarrejar",
    "acarrejássemos": "acarrejar",
    "acarrejávamo": "acarrejar",
    "acarrejávamos": "acarrejar",
    "acarrejávei": "acarrejar",
    "acarrejáveis": "acarrejar",
    "acarrem": "acarrar",
    "acarremo": "acarrar",
    "acarremos": "acarrar",
    "acarreou": "acarrear",
    "acarres": "acarrar",
    "acarreta": "acarretar",
    "acarretada": "acarretar",
    "acarretadas": "acarretar",
    "acarretadeira": "acarretador",
    "acarretadeiras": "acarretador",
    "acarretado": "acarretar",
    "acarretadores": "acarretador",
    "acarretados": "acarretar",
    "acarretai": "acarretar",
    "acarretais": "acarretar",
    "acarretam": "acarretar",
    "acarretamentos": "acarretamento",
    "acarretamo": "acarretar",
    "acarretamos": "acarretar",
    "acarretando": "acarretar",
    "acarretara": "acarretar",
    "acarretaram": "acarretar",
    "acarretaras": "acarretar",
    "acarretarde": "acarretar",
    "acarretardes": "acarretar",
    "acarretare": "acarretar",
    "acarretarei": "acarretar",
    "acarretareis": "acarretar",
    "acarretarem": "acarretar",
    "acarretaremos": "acarretar",
    "acarretares": "acarretar",
    "acarretaria": "acarretar",
    "acarretariam": "acarretar",
    "acarretarias": "acarretar",
    "acarretarmo": "acarretar",
    "acarretarmos": "acarretar",
    "acarretará": "acarretar",
    "acarretarás": "acarretar",
    "acarretarão": "acarretar",
    "acarretaríamos": "acarretar",
    "acarretaríeis": "acarretar",
    "acarretas": "acarretar",
    "acarretasse": "acarretar",
    "acarretassem": "acarretar",
    "acarretasses": "acarretar",
    "acarretaste": "acarretar",
    "acarretastes": "acarretar",
    "acarretava": "acarretar",
    "acarretavam": "acarretar",
    "acarretavas": "acarretar",
    "acarrete": "acarretar",
    "acarretei": "acarretar",
    "acarreteis": "acarretar",
    "acarretem": "acarretar",
    "acarretemo": "acarretar",
    "acarretemos": "acarretar",
    "acarretes": "acarretar",
    "acarreto": "acarretar",
    "acarretos": "acarreto",
    "acarretou": "acarretar",
    "acarretá": "acarretar",
    "acarretámo": "acarretar",
    "acarretámos": "acarretar",
    "acarretáramo": "acarretar",
    "acarretáramos": "acarretar",
    "acarretárei": "acarretar",
    "acarretáreis": "acarretar",
    "acarretásseis": "acarretar",
    "acarretássemos": "acarretar",
    "acarretávamo": "acarretar",
    "acarretávamos": "acarretar",
    "acarretávei": "acarretar",
    "acarretáveis": "acarretar",
    "acarreá": "acarrear",
    "acarreámo": "acarrear",
    "acarreámos": "acarrear",
    "acarreáramo": "acarrear",
    "acarreáramos": "acarrear",
    "acarreárei": "acarrear",
    "acarreáreis": "acarrear",
    "acarreásseis": "acarrear",
    "acarreássemos": "acarrear",
    "acarreávamo": "acarrear",
    "acarreávamos": "acarrear",
    "acarreávei": "acarrear",
    "acarreáveis": "acarrear",
    "acarro": "acarrar",
    "acarros": "acarro",
    "acarrou": "acarrar",
    "acarrámo": "acarrar",
    "acarrámos": "acarrar",
    "acarráramo": "acarrar",
    "acarráramos": "acarrar",
    "acarráreis": "acarrar",
    "acarrásseis": "acarrar",
    "acarrássemos": "acarrar",
    "acarrávamo": "acarrar",
    "acarrávamos": "acarrar",
    "acarráveis": "acarrar",
    "acarta": "acartar",
    "acartada": "acartar",
    "acartadas": "acartar",
    "acartado": "acartar",
    "acartados": "acartar",
    "acartai": "acartar",
    "acartais": "acartar",
    "acartam": "acartar",
    "acartamentos": "acartamento",
    "acartamo": "acartar",
    "acartamos": "acartar",
    "acartando": "acartar",
    "acartara": "acartar",
    "acartaram": "acartar",
    "acartaras": "acartar",
    "acartarde": "acartar",
    "acartardes": "acartar",
    "acartare": "acartar",
    "acartarei": "acartar",
    "acartareis": "acartar",
    "acartarem": "acartar",
    "acartaremos": "acartar",
    "acartares": "acartar",
    "acartaria": "acartar",
    "acartariam": "acartar",
    "acartarias": "acartar",
    "acartarmo": "acartar",
    "acartarmos": "acartar",
    "acartará": "acartar",
    "acartarás": "acartar",
    "acartarão": "acartar",
    "acartaríamos": "acartar",
    "acartaríeis": "acartar",
    "acartas": "acartar",
    "acartasse": "acartar",
    "acartassem": "acartar",
    "acartasses": "acartar",
    "acartaste": "acartar",
    "acartastes": "acartar",
    "acartava": "acartar",
    "acartavam": "acartar",
    "acartavas": "acartar",
    "acarte": "acartar",
    "acartei": "acartar",
    "acarteis": "acartar",
    "acartem": "acartar",
    "acartemo": "acartar",
    "acartemos": "acartar",
    "acartes": "acartar",
    "acarto": "acartar",
    "acartola": "acartolar",
    "acartolada": "acartolar",
    "acartoladas": "acartolar",
    "acartolado": "acartolar",
    "acartolados": "acartolar",
    "acartolai": "acartolar",
    "acartolais": "acartolar",
    "acartolam": "acartolar",
    "acartolamo": "acartolar",
    "acartolamos": "acartolar",
    "acartolando": "acartolar",
    "acartolara": "acartolar",
    "acartolaram": "acartolar",
    "acartolaras": "acartolar",
    "acartolarde": "acartolar",
    "acartolardes": "acartolar",
    "acartolare": "acartolar",
    "acartolarei": "acartolar",
    "acartolareis": "acartolar",
    "acartolarem": "acartolar",
    "acartolaremos": "acartolar",
    "acartolares": "acartolar",
    "acartolaria": "acartolar",
    "acartolariam": "acartolar",
    "acartolarias": "acartolar",
    "acartolarmo": "acartolar",
    "acartolarmos": "acartolar",
    "acartolará": "acartolar",
    "acartolarás": "acartolar",
    "acartolarão": "acartolar",
    "acartolaríamos": "acartolar",
    "acartolaríeis": "acartolar",
    "acartolas": "acartolar",
    "acartolasse": "acartolar",
    "acartolassem": "acartolar",
    "acartolasses": "acartolar",
    "acartolaste": "acartolar",
    "acartolastes": "acartolar",
    "acartolava": "acartolar",
    "acartolavam": "acartolar",
    "acartolavas": "acartolar",
    "acartole": "acartolar",
    "acartolei": "acartolar",
    "acartoleis": "acartolar",
    "acartolem": "acartolar",
    "acartolemo": "acartolar",
    "acartolemos": "acartolar",
    "acartoles": "acartolar",
    "acartolo": "acartolar",
    "acartolou": "acartolar",
    "acartolá": "acartolar",
    "acartolámo": "acartolar",
    "acartolámos": "acartolar",
    "acartoláramo": "acartolar",
    "acartoláramos": "acartolar",
    "acartolárei": "acartolar",
    "acartoláreis": "acartolar",
    "acartolásseis": "acartolar",
    "acartolássemos": "acartolar",
    "acartolávamo": "acartolar",
    "acartolávamos": "acartolar",
    "acartolávei": "acartolar",
    "acartoláveis": "acartolar",
    "acartona": "acartonar",
    "acartonada": "acartonar",
    "acartonadas": "acartonar",
    "acartonado": "acartonar",
    "acartonados": "acartonar",
    "acartonai": "acartonar",
    "acartonais": "acartonar",
    "acartonam": "acartonar",
    "acartonamo": "acartonar",
    "acartonamos": "acartonar",
    "acartonando": "acartonar",
    "acartonara": "acartonar",
    "acartonaram": "acartonar",
    "acartonaras": "acartonar",
    "acartonarde": "acartonar",
    "acartonardes": "acartonar",
    "acartonare": "acartonar",
    "acartonarei": "acartonar",
    "acartonareis": "acartonar",
    "acartonarem": "acartonar",
    "acartonaremos": "acartonar",
    "acartonares": "acartonar",
    "acartonaria": "acartonar",
    "acartonariam": "acartonar",
    "acartonarias": "acartonar",
    "acartonarmo": "acartonar",
    "acartonarmos": "acartonar",
    "acartonará": "acartonar",
    "acartonarás": "acartonar",
    "acartonarão": "acartonar",
    "acartonaríamos": "acartonar",
    "acartonaríeis": "acartonar",
    "acartonas": "acartonar",
    "acartonasse": "acartonar",
    "acartonassem": "acartonar",
    "acartonasses": "acartonar",
    "acartonaste": "acartonar",
    "acartonastes": "acartonar",
    "acartonava": "acartonar",
    "acartonavam": "acartonar",
    "acartonavas": "acartonar",
    "acartone": "acartonar",
    "acartonei": "acartonar",
    "acartoneis": "acartonar",
    "acartonem": "acartonar",
    "acartonemo": "acartonar",
    "acartonemos": "acartonar",
    "acartones": "acartonar",
    "acartono": "acartonar",
    "acartonou": "acartonar",
    "acartoná": "acartonar",
    "acartonámo": "acartonar",
    "acartonámos": "acartonar",
    "acartonáramo": "acartonar",
    "acartonáramos": "acartonar",
    "acartonárei": "acartonar",
    "acartonáreis": "acartonar",
    "acartonásseis": "acartonar",
    "acartonássemos": "acartonar",
    "acartonávamo": "acartonar",
    "acartonávamos": "acartonar",
    "acartonávei": "acartonar",
    "acartonáveis": "acartonar",
    "acartou": "acartar",
    "acartucha": "acartuchar",
    "acartuchada": "acartuchar",
    "acartuchadas": "acartuchar",
    "acartuchado": "acartuchar",
    "acartuchados": "acartuchar",
    "acartuchai": "acartuchar",
    "acartuchais": "acartuchar",
    "acartucham": "acartuchar",
    "acartuchamo": "acartuchar",
    "acartuchamos": "acartuchar",
    "acartuchando": "acartuchar",
    "acartuchara": "acartuchar",
    "acartucharam": "acartuchar",
    "acartucharas": "acartuchar",
    "acartucharde": "acartuchar",
    "acartuchardes": "acartuchar",
    "acartuchare": "acartuchar",
    "acartucharei": "acartuchar",
    "acartuchareis": "acartuchar",
    "acartucharem": "acartuchar",
    "acartucharemos": "acartuchar",
    "acartuchares": "acartuchar",
    "acartucharia": "acartuchar",
    "acartuchariam": "acartuchar",
    "acartucharias": "acartuchar",
    "acartucharmo": "acartuchar",
    "acartucharmos": "acartuchar",
    "acartuchará": "acartuchar",
    "acartucharás": "acartuchar",
    "acartucharão": "acartuchar",
    "acartucharíamos": "acartuchar",
    "acartucharíeis": "acartuchar",
    "acartuchas": "acartuchar",
    "acartuchasse": "acartuchar",
    "acartuchassem": "acartuchar",
    "acartuchasses": "acartuchar",
    "acartuchaste": "acartuchar",
    "acartuchastes": "acartuchar",
    "acartuchava": "acartuchar",
    "acartuchavam": "acartuchar",
    "acartuchavas": "acartuchar",
    "acartuche": "acartuchar",
    "acartuchei": "acartuchar",
    "acartucheis": "acartuchar",
    "acartuchem": "acartuchar",
    "acartuchemo": "acartuchar",
    "acartuchemos": "acartuchar",
    "acartuches": "acartuchar",
    "acartucho": "acartuchar",
    "acartuchou": "acartuchar",
    "acartuchá": "acartuchar",
    "acartuchámo": "acartuchar",
    "acartuchámos": "acartuchar",
    "acartucháramo": "acartuchar",
    "acartucháramos": "acartuchar",
    "acartuchárei": "acartuchar",
    "acartucháreis": "acartuchar",
    "acartuchásseis": "acartuchar",
    "acartuchássemos": "acartuchar",
    "acartuchávamo": "acartuchar",
    "acartuchávamos": "acartuchar",
    "acartuchávei": "acartuchar",
    "acartucháveis": "acartuchar",
    "acartá": "acartar",
    "acartámo": "acartar",
    "acartámos": "acartar",
    "acartáramo": "acartar",
    "acartáramos": "acartar",
    "acartárei": "acartar",
    "acartáreis": "acartar",
    "acartásseis": "acartar",
    "acartássemos": "acartar",
    "acartávamo": "acartar",
    "acartávamos": "acartar",
    "acartávei": "acartar",
    "acartáveis": "acartar",
    "acará": "acarar",
    "acarámo": "acarar",
    "acarámos": "acarar",
    "acaráramo": "acarar",
    "acaráramos": "acarar",
    "acarárei": "acarar",
    "acaráreis": "acarar",
    "acarás": "acará",
    "acarásseis": "acarar",
    "acarássemos": "acarar",
    "acarávamo": "acarar",
    "acarávamos": "acarar",
    "acarávei": "acarar",
    "acaráveis": "acarar",
    "acaríases": "acaríase",
    "acarídea": "acarídeo",
    "acarídeas": "acarídeo",
    "acarídeos": "acarídeo",
    "acaróides": "acaróide",
    "acasaca": "acasacar",
    "acasacada": "acasacar",
    "acasacadas": "acasacar",
    "acasacado": "acasacar",
    "acasacados": "acasacar",
    "acasacai": "acasacar",
    "acasacais": "acasacar",
    "acasacam": "acasacar",
    "acasacamo": "acasacar",
    "acasacamos": "acasacar",
    "acasacando": "acasacar",
    "acasacara": "acasacar",
    "acasacaram": "acasacar",
    "acasacaras": "acasacar",
    "acasacarde": "acasacar",
    "acasacardes": "acasacar",
    "acasacare": "acasacar",
    "acasacarei": "acasacar",
    "acasacareis": "acasacar",
    "acasacarem": "acasacar",
    "acasacaremos": "acasacar",
    "acasacares": "acasacar",
    "acasacaria": "acasacar",
    "acasacariam": "acasacar",
    "acasacarias": "acasacar",
    "acasacarmo": "acasacar",
    "acasacarmos": "acasacar",
    "acasacará": "acasacar",
    "acasacarás": "acasacar",
    "acasacarão": "acasacar",
    "acasacaríamos": "acasacar",
    "acasacaríeis": "acasacar",
    "acasacas": "acasacar",
    "acasacasse": "acasacar",
    "acasacassem": "acasacar",
    "acasacasses": "acasacar",
    "acasacaste": "acasacar",
    "acasacastes": "acasacar",
    "acasacava": "acasacar",
    "acasacavam": "acasacar",
    "acasacavas": "acasacar",
    "acasaco": "acasacar",
    "acasacou": "acasacar",
    "acasacá": "acasacar",
    "acasacámo": "acasacar",
    "acasacámos": "acasacar",
    "acasacáramo": "acasacar",
    "acasacáramos": "acasacar",
    "acasacárei": "acasacar",
    "acasacáreis": "acasacar",
    "acasacásseis": "acasacar",
    "acasacássemos": "acasacar",
    "acasacávamo": "acasacar",
    "acasacávamos": "acasacar",
    "acasacávei": "acasacar",
    "acasacáveis": "acasacar",
    "acasala": "acasalar",
    "acasalada": "acasalar",
    "acasaladas": "acasalar",
    "acasalado": "acasalar",
    "acasalados": "acasalar",
    "acasalai": "acasalar",
    "acasalais": "acasalar",
    "acasalam": "acasalar",
    "acasalamentos": "acasalamento",
    "acasalamo": "acasalar",
    "acasalamos": "acasalar",
    "acasalando": "acasalar",
    "acasalara": "acasalar",
    "acasalaram": "acasalar",
    "acasalaras": "acasalar",
    "acasalarde": "acasalar",
    "acasalardes": "acasalar",
    "acasalare": "acasalar",
    "acasalarei": "acasalar",
    "acasalareis": "acasalar",
    "acasalarem": "acasalar",
    "acasalaremos": "acasalar",
    "acasalares": "acasalar",
    "acasalaria": "acasalar",
    "acasalariam": "acasalar",
    "acasalarias": "acasalar",
    "acasalarmo": "acasalar",
    "acasalarmos": "acasalar",
    "acasalará": "acasalar",
    "acasalarás": "acasalar",
    "acasalarão": "acasalar",
    "acasalaríamos": "acasalar",
    "acasalaríeis": "acasalar",
    "acasalas": "acasalar",
    "acasalasse": "acasalar",
    "acasalassem": "acasalar",
    "acasalasses": "acasalar",
    "acasalaste": "acasalar",
    "acasalastes": "acasalar",
    "acasalava": "acasalar",
    "acasalavam": "acasalar",
    "acasalavas": "acasalar",
    "acasalações": "acasalação",
    "acasale": "acasalar",
    "acasalei": "acasalar",
    "acasaleis": "acasalar",
    "acasalem": "acasalar",
    "acasalemo": "acasalar",
    "acasalemos": "acasalar",
    "acasales": "acasalar",
    "acasalo": "acasalar",
    "acasalou": "acasalar",
    "acasalá": "acasalar",
    "acasalámo": "acasalar",
    "acasalámos": "acasalar",
    "acasaláramo": "acasalar",
    "acasaláramos": "acasalar",
    "acasalárei": "acasalar",
    "acasaláreis": "acasalar",
    "acasalásseis": "acasalar",
    "acasalássemos": "acasalar",
    "acasalávamo": "acasalar",
    "acasalávamos": "acasalar",
    "acasalávei": "acasalar",
    "acasaláveis": "acasalar",
    "acasamata": "acasamatar",
    "acasamatada": "acasamatar",
    "acasamatadas": "acasamatar",
    "acasamatado": "acasamatar",
    "acasamatados": "acasamatar",
    "acasamatai": "acasamatar",
    "acasamatais": "acasamatar",
    "acasamatam": "acasamatar",
    "acasamatamo": "acasamatar",
    "acasamatamos": "acasamatar",
    "acasamatando": "acasamatar",
    "acasamatara": "acasamatar",
    "acasamataram": "acasamatar",
    "acasamataras": "acasamatar",
    "acasamatarde": "acasamatar",
    "acasamatardes": "acasamatar",
    "acasamatare": "acasamatar",
    "acasamatarei": "acasamatar",
    "acasamatareis": "acasamatar",
    "acasamatarem": "acasamatar",
    "acasamataremos": "acasamatar",
    "acasamatares": "acasamatar",
    "acasamataria": "acasamatar",
    "acasamatariam": "acasamatar",
    "acasamatarias": "acasamatar",
    "acasamatarmo": "acasamatar",
    "acasamatarmos": "acasamatar",
    "acasamatará": "acasamatar",
    "acasamatarás": "acasamatar",
    "acasamatarão": "acasamatar",
    "acasamataríamos": "acasamatar",
    "acasamataríeis": "acasamatar",
    "acasamatas": "acasamatar",
    "acasamatasse": "acasamatar",
    "acasamatassem": "acasamatar",
    "acasamatasses": "acasamatar",
    "acasamataste": "acasamatar",
    "acasamatastes": "acasamatar",
    "acasamatava": "acasamatar",
    "acasamatavam": "acasamatar",
    "acasamatavas": "acasamatar",
    "acasamate": "acasamatar",
    "acasamatei": "acasamatar",
    "acasamateis": "acasamatar",
    "acasamatem": "acasamatar",
    "acasamatemo": "acasamatar",
    "acasamatemos": "acasamatar",
    "acasamates": "acasamatar",
    "acasamato": "acasamatar",
    "acasamatou": "acasamatar",
    "acasamatá": "acasamatar",
    "acasamatámo": "acasamatar",
    "acasamatámos": "acasamatar",
    "acasamatáramo": "acasamatar",
    "acasamatáramos": "acasamatar",
    "acasamatárei": "acasamatar",
    "acasamatáreis": "acasamatar",
    "acasamatásseis": "acasamatar",
    "acasamatássemos": "acasamatar",
    "acasamatávamo": "acasamatar",
    "acasamatávamos": "acasamatar",
    "acasamatávei": "acasamatar",
    "acasamatáveis": "acasamatar",
    "acasaque": "acasacar",
    "acasaquei": "acasacar",
    "acasaqueis": "acasacar",
    "acasaquem": "acasacar",
    "acasaquemo": "acasacar",
    "acasaquemos": "acasacar",
    "acasaques": "acasacar",
    "acascarrilhada": "acascarrilhado",
    "acascarrilhadas": "acascarrilhado",
    "acascarrilhados": "acascarrilhado",
    "acaserna": "acasernar",
    "acasernada": "acasernar",
    "acasernadas": "acasernar",
    "acasernado": "acasernar",
    "acasernados": "acasernar",
    "acasernai": "acasernar",
    "acasernais": "acasernar",
    "acasernam": "acasernar",
    "acasernamo": "acasernar",
    "acasernamos": "acasernar",
    "acasernando": "acasernar",
    "acasernara": "acasernar",
    "acasernaram": "acasernar",
    "acasernaras": "acasernar",
    "acasernarde": "acasernar",
    "acasernardes": "acasernar",
    "acasernare": "acasernar",
    "acasernarei": "acasernar",
    "acasernareis": "acasernar",
    "acasernarem": "acasernar",
    "acasernaremos": "acasernar",
    "acasernares": "acasernar",
    "acasernaria": "acasernar",
    "acasernariam": "acasernar",
    "acasernarias": "acasernar",
    "acasernarmo": "acasernar",
    "acasernarmos": "acasernar",
    "acasernará": "acasernar",
    "acasernarás": "acasernar",
    "acasernarão": "acasernar",
    "acasernaríamos": "acasernar",
    "acasernaríeis": "acasernar",
    "acasernas": "acasernar",
    "acasernasse": "acasernar",
    "acasernassem": "acasernar",
    "acasernasses": "acasernar",
    "acasernaste": "acasernar",
    "acasernastes": "acasernar",
    "acasernava": "acasernar",
    "acasernavam": "acasernar",
    "acasernavas": "acasernar",
    "acaserne": "acasernar",
    "acasernei": "acasernar",
    "acaserneis": "acasernar",
    "acasernem": "acasernar",
    "acasernemo": "acasernar",
    "acasernemos": "acasernar",
    "acasernes": "acasernar",
    "acaserno": "acasernar",
    "acasernou": "acasernar",
    "acaserná": "acasernar",
    "acasernámo": "acasernar",
    "acasernámos": "acasernar",
    "acasernáramo": "acasernar",
    "acasernáramos": "acasernar",
    "acasernárei": "acasernar",
    "acasernáreis": "acasernar",
    "acasernásseis": "acasernar",
    "acasernássemos": "acasernar",
    "acasernávamo": "acasernar",
    "acasernávamos": "acasernar",
    "acasernávei": "acasernar",
    "acasernáveis": "acasernar",
    "acasmurra": "acasmurrar",
    "acasmurrada": "acasmurrar",
    "acasmurradas": "acasmurrar",
    "acasmurrado": "acasmurrar",
    "acasmurrados": "acasmurrar",
    "acasmurrai": "acasmurrar",
    "acasmurrais": "acasmurrar",
    "acasmurram": "acasmurrar",
    "acasmurramo": "acasmurrar",
    "acasmurramos": "acasmurrar",
    "acasmurrando": "acasmurrar",
    "acasmurrara": "acasmurrar",
    "acasmurraram": "acasmurrar",
    "acasmurraras": "acasmurrar",
    "acasmurrarde": "acasmurrar",
    "acasmurrardes": "acasmurrar",
    "acasmurrare": "acasmurrar",
    "acasmurrarei": "acasmurrar",
    "acasmurrareis": "acasmurrar",
    "acasmurrarem": "acasmurrar",
    "acasmurraremos": "acasmurrar",
    "acasmurrares": "acasmurrar",
    "acasmurraria": "acasmurrar",
    "acasmurrariam": "acasmurrar",
    "acasmurrarias": "acasmurrar",
    "acasmurrarmo": "acasmurrar",
    "acasmurrarmos": "acasmurrar",
    "acasmurrará": "acasmurrar",
    "acasmurrarás": "acasmurrar",
    "acasmurrarão": "acasmurrar",
    "acasmurraríamos": "acasmurrar",
    "acasmurraríeis": "acasmurrar",
    "acasmurras": "acasmurrar",
    "acasmurrasse": "acasmurrar",
    "acasmurrassem": "acasmurrar",
    "acasmurrasses": "acasmurrar",
    "acasmurraste": "acasmurrar",
    "acasmurrastes": "acasmurrar",
    "acasmurrava": "acasmurrar",
    "acasmurravam": "acasmurrar",
    "acasmurravas": "acasmurrar",
    "acasmurre": "acasmurrar",
    "acasmurrei": "acasmurrar",
    "acasmurreis": "acasmurrar",
    "acasmurrem": "acasmurrar",
    "acasmurremo": "acasmurrar",
    "acasmurremos": "acasmurrar",
    "acasmurres": "acasmurrar",
    "acasmurro": "acasmurrar",
    "acasmurrou": "acasmurrar",
    "acasmurrá": "acasmurrar",
    "acasmurrámo": "acasmurrar",
    "acasmurrámos": "acasmurrar",
    "acasmurráramo": "acasmurrar",
    "acasmurráramos": "acasmurrar",
    "acasmurrárei": "acasmurrar",
    "acasmurráreis": "acasmurrar",
    "acasmurrásseis": "acasmurrar",
    "acasmurrássemos": "acasmurrar",
    "acasmurrávamo": "acasmurrar",
    "acasmurrávamos": "acasmurrar",
    "acasmurrávei": "acasmurrar",
    "acasmurráveis": "acasmurrar",
    "acasos": "acaso",
    "acasquilha": "acasquilhar",
    "acasquilhada": "acasquilhar",
    "acasquilhadas": "acasquilhar",
    "acasquilhado": "acasquilhar",
    "acasquilhados": "acasquilhar",
    "acasquilhai": "acasquilhar",
    "acasquilhais": "acasquilhar",
    "acasquilham": "acasquilhar",
    "acasquilhamo": "acasquilhar",
    "acasquilhamos": "acasquilhar",
    "acasquilhando": "acasquilhar",
    "acasquilhara": "acasquilhar",
    "acasquilharam": "acasquilhar",
    "acasquilharas": "acasquilhar",
    "acasquilharde": "acasquilhar",
    "acasquilhardes": "acasquilhar",
    "acasquilhare": "acasquilhar",
    "acasquilharei": "acasquilhar",
    "acasquilhareis": "acasquilhar",
    "acasquilharem": "acasquilhar",
    "acasquilharemos": "acasquilhar",
    "acasquilhares": "acasquilhar",
    "acasquilharia": "acasquilhar",
    "acasquilhariam": "acasquilhar",
    "acasquilharias": "acasquilhar",
    "acasquilharmo": "acasquilhar",
    "acasquilharmos": "acasquilhar",
    "acasquilhará": "acasquilhar",
    "acasquilharás": "acasquilhar",
    "acasquilharão": "acasquilhar",
    "acasquilharíamos": "acasquilhar",
    "acasquilharíeis": "acasquilhar",
    "acasquilhas": "acasquilhar",
    "acasquilhasse": "acasquilhar",
    "acasquilhassem": "acasquilhar",
    "acasquilhasses": "acasquilhar",
    "acasquilhaste": "acasquilhar",
    "acasquilhastes": "acasquilhar",
    "acasquilhava": "acasquilhar",
    "acasquilhavam": "acasquilhar",
    "acasquilhavas": "acasquilhar",
    "acasquilhe": "acasquilhar",
    "acasquilhei": "acasquilhar",
    "acasquilheis": "acasquilhar",
    "acasquilhem": "acasquilhar",
    "acasquilhemo": "acasquilhar",
    "acasquilhemos": "acasquilhar",
    "acasquilhes": "acasquilhar",
    "acasquilho": "acasquilhar",
    "acasquilhou": "acasquilhar",
    "acasquilhá": "acasquilhar",
    "acasquilhámo": "acasquilhar",
    "acasquilhámos": "acasquilhar",
    "acasquilháramo": "acasquilhar",
    "acasquilháramos": "acasquilhar",
    "acasquilhárei": "acasquilhar",
    "acasquilháreis": "acasquilhar",
    "acasquilhásseis": "acasquilhar",
    "acasquilhássemos": "acasquilhar",
    "acasquilhávamo": "acasquilhar",
    "acasquilhávamos": "acasquilhar",
    "acasquilhávei": "acasquilhar",
    "acasquilháveis": "acasquilhar",
    "acastanhada": "acastanhado",
    "acastanhadas": "acastanhado",
    "acastanhados": "acastanhado",
    "acastela": "acastelar",
    "acastelada": "acastelar",
    "acasteladas": "acastelar",
    "acastelado": "acastelar",
    "acastelados": "acastelar",
    "acastelai": "acastelar",
    "acastelais": "acastelar",
    "acastelam": "acastelar",
    "acastelamentos": "acastelamento",
    "acastelamo": "acastelar",
    "acastelamos": "acastelar",
    "acastelando": "acastelar",
    "acastelara": "acastelar",
    "acastelaram": "acastelar",
    "acastelaras": "acastelar",
    "acastelarde": "acastelar",
    "acastelardes": "acastelar",
    "acastelare": "acastelar",
    "acastelarei": "acastelar",
    "acastelareis": "acastelar",
    "acastelarem": "acastelar",
    "acastelaremos": "acastelar",
    "acastelares": "acastelar",
    "acastelaria": "acastelar",
    "acastelariam": "acastelar",
    "acastelarias": "acastelar",
    "acastelarmo": "acastelar",
    "acastelarmos": "acastelar",
    "acastelará": "acastelar",
    "acastelarás": "acastelar",
    "acastelarão": "acastelar",
    "acastelaríamos": "acastelar",
    "acastelaríeis": "acastelar",
    "acastelas": "acastelar",
    "acastelasse": "acastelar",
    "acastelassem": "acastelar",
    "acastelasses": "acastelar",
    "acastelaste": "acastelar",
    "acastelastes": "acastelar",
    "acastelava": "acastelar",
    "acastelavam": "acastelar",
    "acastelavas": "acastelar",
    "acastele": "acastelar",
    "acastelei": "acastelar",
    "acasteleis": "acastelar",
    "acastelem": "acastelar",
    "acastelemo": "acastelar",
    "acastelemos": "acastelar",
    "acasteles": "acastelar",
    "acastelhana": "acastelhanar",
    "acastelhanada": "acastelhanar",
    "acastelhanadas": "acastelhanar",
    "acastelhanado": "acastelhanar",
    "acastelhanados": "acastelhanar",
    "acastelhanai": "acastelhanar",
    "acastelhanais": "acastelhanar",
    "acastelhanam": "acastelhanar",
    "acastelhanamo": "acastelhanar",
    "acastelhanamos": "acastelhanar",
    "acastelhanando": "acastelhanar",
    "acastelhanara": "acastelhanar",
    "acastelhanaram": "acastelhanar",
    "acastelhanaras": "acastelhanar",
    "acastelhanarde": "acastelhanar",
    "acastelhanardes": "acastelhanar",
    "acastelhanare": "acastelhanar",
    "acastelhanarei": "acastelhanar",
    "acastelhanareis": "acastelhanar",
    "acastelhanarem": "acastelhanar",
    "acastelhanaremos": "acastelhanar",
    "acastelhanares": "acastelhanar",
    "acastelhanaria": "acastelhanar",
    "acastelhanariam": "acastelhanar",
    "acastelhanarias": "acastelhanar",
    "acastelhanarmo": "acastelhanar",
    "acastelhanarmos": "acastelhanar",
    "acastelhanará": "acastelhanar",
    "acastelhanarás": "acastelhanar",
    "acastelhanarão": "acastelhanar",
    "acastelhanaríamos": "acastelhanar",
    "acastelhanaríeis": "acastelhanar",
    "acastelhanas": "acastelhanar",
    "acastelhanasse": "acastelhanar",
    "acastelhanassem": "acastelhanar",
    "acastelhanasses": "acastelhanar",
    "acastelhanaste": "acastelhanar",
    "acastelhanastes": "acastelhanar",
    "acastelhanava": "acastelhanar",
    "acastelhanavam": "acastelhanar",
    "acastelhanavas": "acastelhanar",
    "acastelhane": "acastelhanar",
    "acastelhanei": "acastelhanar",
    "acastelhaneis": "acastelhanar",
    "acastelhanem": "acastelhanar",
    "acastelhanemo": "acastelhanar",
    "acastelhanemos": "acastelhanar",
    "acastelhanes": "acastelhanar",
    "acastelhano": "acastelhanar",
    "acastelhanou": "acastelhanar",
    "acastelhaná": "acastelhanar",
    "acastelhanámo": "acastelhanar",
    "acastelhanámos": "acastelhanar",
    "acastelhanáramo": "acastelhanar",
    "acastelhanáramos": "acastelhanar",
    "acastelhanárei": "acastelhanar",
    "acastelhanáreis": "acastelhanar",
    "acastelhanásseis": "acastelhanar",
    "acastelhanássemos": "acastelhanar",
    "acastelhanávamo": "acastelhanar",
    "acastelhanávamos": "acastelhanar",
    "acastelhanávei": "acastelhanar",
    "acastelhanáveis": "acastelhanável",
    "acastelo": "acastelar",
    "acastelou": "acastelar",
    "acastelá": "acastelar",
    "acastelámo": "acastelar",
    "acastelámos": "acastelar",
    "acasteláramo": "acastelar",
    "acasteláramos": "acastelar",
    "acastelárei": "acastelar",
    "acasteláreis": "acastelar",
    "acastelásseis": "acastelar",
    "acastelássemos": "acastelar",
    "acastelávamo": "acastelar",
    "acastelávamos": "acastelar",
    "acastelávei": "acastelar",
    "acasteláveis": "acastelar",
    "acastice": "acastiçar",
    "acasticei": "acastiçar",
    "acasticeis": "acastiçar",
    "acasticem": "acastiçar",
    "acasticemo": "acastiçar",
    "acasticemos": "acastiçar",
    "acastices": "acastiçar",
    "acastiça": "acastiçar",
    "acastiçada": "acastiçar",
    "acastiçadas": "acastiçar",
    "acastiçado": "acastiçar",
    "acastiçados": "acastiçar",
    "acastiçai": "acastiçar",
    "acastiçais": "acastiçar",
    "acastiçam": "acastiçar",
    "acastiçamo": "acastiçar",
    "acastiçamos": "acastiçar",
    "acastiçando": "acastiçar",
    "acastiçara": "acastiçar",
    "acastiçaram": "acastiçar",
    "acastiçaras": "acastiçar",
    "acastiçarde": "acastiçar",
    "acastiçardes": "acastiçar",
    "acastiçare": "acastiçar",
    "acastiçarei": "acastiçar",
    "acastiçareis": "acastiçar",
    "acastiçarem": "acastiçar",
    "acastiçaremos": "acastiçar",
    "acastiçares": "acastiçar",
    "acastiçaria": "acastiçar",
    "acastiçariam": "acastiçar",
    "acastiçarias": "acastiçar",
    "acastiçarmo": "acastiçar",
    "acastiçarmos": "acastiçar",
    "acastiçará": "acastiçar",
    "acastiçarás": "acastiçar",
    "acastiçarão": "acastiçar",
    "acastiçaríamos": "acastiçar",
    "acastiçaríeis": "acastiçar",
    "acastiças": "acastiçar",
    "acastiçasse": "acastiçar",
    "acastiçassem": "acastiçar",
    "acastiçasses": "acastiçar",
    "acastiçaste": "acastiçar",
    "acastiçastes": "acastiçar",
    "acastiçava": "acastiçar",
    "acastiçavam": "acastiçar",
    "acastiçavas": "acastiçar",
    "acastiço": "acastiçar",
    "acastiçou": "acastiçar",
    "acastiçá": "acastiçar",
    "acastiçámo": "acastiçar",
    "acastiçámos": "acastiçar",
    "acastiçáramo": "acastiçar",
    "acastiçáramos": "acastiçar",
    "acastiçárei": "acastiçar",
    "acastiçáreis": "acastiçar",
    "acastiçásseis": "acastiçar",
    "acastiçássemos": "acastiçar",
    "acastiçávamo": "acastiçar",
    "acastiçávamos": "acastiçar",
    "acastiçávei": "acastiçar",
    "acastiçáveis": "acastiçar",
    "acastoa": "acastoar",
    "acastoada": "acastoar",
    "acastoadas": "acastoar",
    "acastoado": "acastoar",
    "acastoados": "acastoar",
    "acastoai": "acastoar",
    "acastoais": "acastoar",
    "acastoam": "acastoar",
    "acastoamo": "acastoar",
    "acastoamos": "acastoar",
    "acastoando": "acastoar",
    "acastoara": "acastoar",
    "acastoaram": "acastoar",
    "acastoaras": "acastoar",
    "acastoarde": "acastoar",
    "acastoardes": "acastoar",
    "acastoare": "acastoar",
    "acastoarei": "acastoar",
    "acastoareis": "acastoar",
    "acastoarem": "acastoar",
    "acastoaremos": "acastoar",
    "acastoares": "acastoar",
    "acastoaria": "acastoar",
    "acastoariam": "acastoar",
    "acastoarias": "acastoar",
    "acastoarmo": "acastoar",
    "acastoarmos": "acastoar",
    "acastoará": "acastoar",
    "acastoarás": "acastoar",
    "acastoarão": "acastoar",
    "acastoaríamos": "acastoar",
    "acastoaríeis": "acastoar",
    "acastoas": "acastoar",
    "acastoasse": "acastoar",
    "acastoassem": "acastoar",
    "acastoasses": "acastoar",
    "acastoaste": "acastoar",
    "acastoastes": "acastoar",
    "acastoava": "acastoar",
    "acastoavam": "acastoar",
    "acastoavas": "acastoar",
    "acastoe": "acastoar",
    "acastoei": "acastoar",
    "acastoeis": "acastoar",
    "acastoem": "acastoar",
    "acastoemo": "acastoar",
    "acastoemos": "acastoar",
    "acastoes": "acastoar",
    "acastoo": "acastoar",
    "acastoou": "acastoar",
    "acastorada": "acastorado",
    "acastoradas": "acastorado",
    "acastorados": "acastorado",
    "acastoá": "acastoar",
    "acastoámo": "acastoar",
    "acastoámos": "acastoar",
    "acastoáramo": "acastoar",
    "acastoáramos": "acastoar",
    "acastoárei": "acastoar",
    "acastoáreis": "acastoar",
    "acastoásseis": "acastoar",
    "acastoássemos": "acastoar",
    "acastoávamo": "acastoar",
    "acastoávamos": "acastoar",
    "acastoávei": "acastoar",
    "acastoáveis": "acastoar",
    "acasula": "acasular",
    "acasulada": "acasular",
    "acasuladas": "acasular",
    "acasulado": "acasular",
    "acasulados": "acasular",
    "acasulai": "acasular",
    "acasulais": "acasular",
    "acasulam": "acasular",
    "acasulamo": "acasular",
    "acasulamos": "acasular",
    "acasulando": "acasular",
    "acasulara": "acasular",
    "acasularam": "acasular",
    "acasularas": "acasular",
    "acasularde": "acasular",
    "acasulardes": "acasular",
    "acasulare": "acasular",
    "acasularei": "acasular",
    "acasulareis": "acasular",
    "acasularem": "acasular",
    "acasularemos": "acasular",
    "acasulares": "acasular",
    "acasularia": "acasular",
    "acasulariam": "acasular",
    "acasularias": "acasular",
    "acasularmo": "acasular",
    "acasularmos": "acasular",
    "acasulará": "acasular",
    "acasularás": "acasular",
    "acasularão": "acasular",
    "acasularíamos": "acasular",
    "acasularíeis": "acasular",
    "acasulas": "acasular",
    "acasulasse": "acasular",
    "acasulassem": "acasular",
    "acasulasses": "acasular",
    "acasulaste": "acasular",
    "acasulastes": "acasular",
    "acasulava": "acasular",
    "acasulavam": "acasular",
    "acasulavas": "acasular",
    "acasule": "acasular",
    "acasulei": "acasular",
    "acasuleis": "acasular",
    "acasulem": "acasular",
    "acasulemo": "acasular",
    "acasulemos": "acasular",
    "acasules": "acasular",
    "acasulo": "acasular",
    "acasulou": "acasular",
    "acasulá": "acasular",
    "acasulámo": "acasular",
    "acasulámos": "acasular",
    "acasuláramo": "acasular",
    "acasuláramos": "acasular",
    "acasulárei": "acasular",
    "acasuláreis": "acasular",
    "acasulásseis": "acasular",
    "acasulássemos": "acasular",
    "acasulávamo": "acasular",
    "acasulávamos": "acasular",
    "acasulávei": "acasular",
    "acasuláveis": "acasular",
    "acata": "acatar",
    "acatada": "acatar",
    "acatadas": "acatar",
    "acatadeira": "acatador",
    "acatadeiras": "acatador",
    "acatado": "acatar",
    "acatadora": "acatador",
    "acatadoras": "acatador",
    "acatadores": "acatador",
    "acatados": "acatar",
    "acataduras": "acatadura",
    "acatai": "acatar",
    "acatais": "acatar",
    "acatalepsias": "acatalepsia",
    "acataléctica": "acataléctico",
    "acatalécticas": "acataléctico",
    "acatalécticos": "acataléctico",
    "acataléptica": "acataléptico",
    "acatalépticas": "acataléptico",
    "acatalépticos": "acataléptico",
    "acatam": "acatar",
    "acatamentos": "acatamento",
    "acatamo": "acatar",
    "acatamos": "acatar",
    "acatando": "acatar",
    "acatara": "acatar",
    "acataram": "acatar",
    "acataras": "acatar",
    "acatarde": "acatar",
    "acatardes": "acatar",
    "acatare": "acatar",
    "acatarei": "acatar",
    "acatareis": "acatar",
    "acatarem": "acatar",
    "acataremos": "acatar",
    "acatares": "acatar",
    "acataria": "acatar",
    "acatariam": "acatar",
    "acatarias": "acatar",
    "acatarmo": "acatar",
    "acatarmos": "acatar",
    "acatarrada": "acatarrado",
    "acatarradas": "acatarrado",
    "acatarrados": "acatarrado",
    "acatarroada": "acatarroado",
    "acatarroadas": "acatarroado",
    "acatarroados": "acatarroado",
    "acatará": "acatar",
    "acatarás": "acatar",
    "acatarão": "acatar",
    "acataríamos": "acatar",
    "acataríeis": "acatar",
    "acatas": "acatar",
    "acatasse": "acatar",
    "acatassem": "acatar",
    "acatasses": "acatar",
    "acatassolada": "acatassolado",
    "acatassoladas": "acatassolado",
    "acatassolados": "acatassolado",
    "acataste": "acatar",
    "acatastes": "acatar",
    "acatastática": "acatastático",
    "acatastáticas": "acatastático",
    "acatastáticos": "acatastático",
    "acatava": "acatar",
    "acatavam": "acatar",
    "acatavas": "acatar",
    "acate": "acatar",
    "acatei": "acatar",
    "acateis": "acatar",
    "acatem": "acatar",
    "acatemo": "acatar",
    "acatemos": "acatar",
    "acates": "acatar",
    "acatingados": "acatingado",
    "acatisias": "acatisia",
    "acatistos": "acatisto",
    "acatita": "acatitar",
    "acatitada": "acatitar",
    "acatitadas": "acatitar",
    "acatitado": "acatitar",
    "acatitados": "acatitar",
    "acatitai": "acatitar",
    "acatitais": "acatitar",
    "acatitam": "acatitar",
    "acatitamo": "acatitar",
    "acatitamos": "acatitar",
    "acatitando": "acatitar",
    "acatitara": "acatitar",
    "acatitaram": "acatitar",
    "acatitaras": "acatitar",
    "acatitarde": "acatitar",
    "acatitardes": "acatitar",
    "acatitare": "acatitar",
    "acatitarei": "acatitar",
    "acatitareis": "acatitar",
    "acatitarem": "acatitar",
    "acatitaremos": "acatitar",
    "acatitares": "acatitar",
    "acatitaria": "acatitar",
    "acatitariam": "acatitar",
    "acatitarias": "acatitar",
    "acatitarmo": "acatitar",
    "acatitarmos": "acatitar",
    "acatitará": "acatitar",
    "acatitarás": "acatitar",
    "acatitarão": "acatitar",
    "acatitaríamos": "acatitar",
    "acatitaríeis": "acatitar",
    "acatitas": "acatitar",
    "acatitasse": "acatitar",
    "acatitassem": "acatitar",
    "acatitasses": "acatitar",
    "acatitaste": "acatitar",
    "acatitastes": "acatitar",
    "acatitava": "acatitar",
    "acatitavam": "acatitar",
    "acatitavas": "acatitar",
    "acatite": "acatitar",
    "acatitei": "acatitar",
    "acatiteis": "acatitar",
    "acatitem": "acatitar",
    "acatitemo": "acatitar",
    "acatitemos": "acatitar",
    "acatites": "acatitar",
    "acatito": "acatitar",
    "acatitou": "acatitar",
    "acatitá": "acatitar",
    "acatitámo": "acatitar",
    "acatitámos": "acatitar",
    "acatitáramo": "acatitar",
    "acatitáramos": "acatitar",
    "acatitárei": "acatitar",
    "acatitáreis": "acatitar",
    "acatitásseis": "acatitar",
    "acatitássemos": "acatitar",
    "acatitávamo": "acatitar",
    "acatitávamos": "acatitar",
    "acatitávei": "acatitar",
    "acatitáveis": "acatitar",
    "acato": "acatar",
    "acatos": "acato",
    "acatou": "acatar",
    "acatá": "acatar",
    "acatámo": "acatar",
    "acatámos": "acatar",
    "acatáramo": "acatar",
    "acatáramos": "acatar",
    "acatárei": "acatar",
    "acatáreis": "acatar",
    "acatásseis": "acatar",
    "acatássemos": "acatar",
    "acatávamo": "acatar",
    "acatávamos": "acatar",
    "acatávei": "acatar",
    "acatáveis": "acatável",
    "acatólica": "acatólico",
    "acatólicas": "acatólico",
    "acatólicos": "acatólico",
    "acaudala": "acaudalar",
    "acaudalada": "acaudalar",
    "acaudaladas": "acaudalar",
    "acaudalado": "acaudalar",
    "acaudalados": "acaudalar",
    "acaudalai": "acaudalar",
    "acaudalais": "acaudalar",
    "acaudalam": "acaudalar",
    "acaudalamo": "acaudalar",
    "acaudalamos": "acaudalar",
    "acaudalando": "acaudalar",
    "acaudalara": "acaudalar",
    "acaudalaram": "acaudalar",
    "acaudalaras": "acaudalar",
    "acaudalarde": "acaudalar",
    "acaudalardes": "acaudalar",
    "acaudalare": "acaudalar",
    "acaudalarei": "acaudalar",
    "acaudalareis": "acaudalar",
    "acaudalarem": "acaudalar",
    "acaudalaremos": "acaudalar",
    "acaudalares": "acaudalar",
    "acaudalaria": "acaudalar",
    "acaudalariam": "acaudalar",
    "acaudalarias": "acaudalar",
    "acaudalarmo": "acaudalar",
    "acaudalarmos": "acaudalar",
    "acaudalará": "acaudalar",
    "acaudalarás": "acaudalar",
    "acaudalarão": "acaudalar",
    "acaudalaríamos": "acaudalar",
    "acaudalaríeis": "acaudalar",
    "acaudalas": "acaudalar",
    "acaudalasse": "acaudalar",
    "acaudalassem": "acaudalar",
    "acaudalasses": "acaudalar",
    "acaudalaste": "acaudalar",
    "acaudalastes": "acaudalar",
    "acaudalava": "acaudalar",
    "acaudalavam": "acaudalar",
    "acaudalavas": "acaudalar",
    "acaudale": "acaudalar",
    "acaudalei": "acaudalar",
    "acaudaleis": "acaudalar",
    "acaudalem": "acaudalar",
    "acaudalemo": "acaudalar",
    "acaudalemos": "acaudalar",
    "acaudales": "acaudalar",
    "acaudalo": "acaudalar",
    "acaudalou": "acaudalar",
    "acaudalá": "acaudalar",
    "acaudalámo": "acaudalar",
    "acaudalámos": "acaudalar",
    "acaudaláramo": "acaudalar",
    "acaudaláramos": "acaudalar",
    "acaudalárei": "acaudalar",
    "acaudaláreis": "acaudalar",
    "acaudalásseis": "acaudalar",
    "acaudalássemos": "acaudalar",
    "acaudalávamo": "acaudalar",
    "acaudalávamos": "acaudalar",
    "acaudalávei": "acaudalar",
    "acaudaláveis": "acaudalar",
    "acaudata": "acaudatar",
    "acaudatada": "acaudatar",
    "acaudatadas": "acaudatar",
    "acaudatado": "acaudatar",
    "acaudatados": "acaudatar",
    "acaudatai": "acaudatar",
    "acaudatais": "acaudatar",
    "acaudatam": "acaudatar",
    "acaudatamo": "acaudatar",
    "acaudatamos": "acaudatar",
    "acaudatando": "acaudatar",
    "acaudatara": "acaudatar",
    "acaudataram": "acaudatar",
    "acaudataras": "acaudatar",
    "acaudatarde": "acaudatar",
    "acaudatardes": "acaudatar",
    "acaudatare": "acaudatar",
    "acaudatarei": "acaudatar",
    "acaudatareis": "acaudatar",
    "acaudatarem": "acaudatar",
    "acaudataremos": "acaudatar",
    "acaudatares": "acaudatar",
    "acaudataria": "acaudatar",
    "acaudatariam": "acaudatar",
    "acaudatarias": "acaudatar",
    "acaudatarmo": "acaudatar",
    "acaudatarmos": "acaudatar",
    "acaudatará": "acaudatar",
    "acaudatarás": "acaudatar",
    "acaudatarão": "acaudatar",
    "acaudataríamos": "acaudatar",
    "acaudataríeis": "acaudatar",
    "acaudatas": "acaudatar",
    "acaudatasse": "acaudatar",
    "acaudatassem": "acaudatar",
    "acaudatasses": "acaudatar",
    "acaudataste": "acaudatar",
    "acaudatastes": "acaudatar",
    "acaudatava": "acaudatar",
    "acaudatavam": "acaudatar",
    "acaudatavas": "acaudatar",
    "acaudate": "acaudatar",
    "acaudatei": "acaudatar",
    "acaudateis": "acaudatar",
    "acaudatem": "acaudatar",
    "acaudatemo": "acaudatar",
    "acaudatemos": "acaudatar",
    "acaudates": "acaudatar",
    "acaudato": "acaudatar",
    "acaudatou": "acaudatar",
    "acaudatá": "acaudatar",
    "acaudatámo": "acaudatar",
    "acaudatámos": "acaudatar",
    "acaudatáramo": "acaudatar",
    "acaudatáramos": "acaudatar",
    "acaudatárei": "acaudatar",
    "acaudatáreis": "acaudatar",
    "acaudatásseis": "acaudatar",
    "acaudatássemos": "acaudatar",
    "acaudatávamo": "acaudatar",
    "acaudatávamos": "acaudatar",
    "acaudatávei": "acaudatar",
    "acaudatáveis": "acaudatar",
    "acaudela": "acaudelar",
    "acaudelada": "acaudelar",
    "acaudeladas": "acaudelar",
    "acaudelado": "acaudelar",
    "acaudelados": "acaudelar",
    "acaudelai": "acaudelar",
    "acaudelais": "acaudelar",
    "acaudelam": "acaudelar",
    "acaudelamo": "acaudelar",
    "acaudelamos": "acaudelar",
    "acaudelando": "acaudelar",
    "acaudelara": "acaudelar",
    "acaudelaram": "acaudelar",
    "acaudelaras": "acaudelar",
    "acaudelarde": "acaudelar",
    "acaudelardes": "acaudelar",
    "acaudelare": "acaudelar",
    "acaudelarei": "acaudelar",
    "acaudelareis": "acaudelar",
    "acaudelarem": "acaudelar",
    "acaudelaremos": "acaudelar",
    "acaudelares": "acaudelar",
    "acaudelaria": "acaudelar",
    "acaudelariam": "acaudelar",
    "acaudelarias": "acaudelar",
    "acaudelarmo": "acaudelar",
    "acaudelarmos": "acaudelar",
    "acaudelará": "acaudelar",
    "acaudelarás": "acaudelar",
    "acaudelarão": "acaudelar",
    "acaudelaríamos": "acaudelar",
    "acaudelaríeis": "acaudelar",
    "acaudelas": "acaudelar",
    "acaudelasse": "acaudelar",
    "acaudelassem": "acaudelar",
    "acaudelasses": "acaudelar",
    "acaudelaste": "acaudelar",
    "acaudelastes": "acaudelar",
    "acaudelava": "acaudelar",
    "acaudelavam": "acaudelar",
    "acaudelavas": "acaudelar",
    "acaudele": "acaudelar",
    "acaudelei": "acaudelar",
    "acaudeleis": "acaudelar",
    "acaudelem": "acaudelar",
    "acaudelemo": "acaudelar",
    "acaudelemos": "acaudelar",
    "acaudeles": "acaudelar",
    "acaudelo": "acaudelar",
    "acaudelou": "acaudelar",
    "acaudelá": "acaudelar",
    "acaudelámo": "acaudelar",
    "acaudelámos": "acaudelar",
    "acaudeláramo": "acaudelar",
    "acaudeláramos": "acaudelar",
    "acaudelárei": "acaudelar",
    "acaudeláreis": "acaudelar",
    "acaudelásseis": "acaudelar",
    "acaudelássemos": "acaudelar",
    "acaudelávamo": "acaudelar",
    "acaudelávamos": "acaudelar",
    "acaudelávei": "acaudelar",
    "acaudeláveis": "acaudelar",
    "acaudilha": "acaudilhar",
    "acaudilhada": "acaudilhar",
    "acaudilhadas": "acaudilhar",
    "acaudilhado": "acaudilhar",
    "acaudilhados": "acaudilhar",
    "acaudilhai": "acaudilhar",
    "acaudilhais": "acaudilhar",
    "acaudilham": "acaudilhar",
    "acaudilhamo": "acaudilhar",
    "acaudilhamos": "acaudilhar",
    "acaudilhando": "acaudilhar",
    "acaudilhara": "acaudilhar",
    "acaudilharam": "acaudilhar",
    "acaudilharas": "acaudilhar",
    "acaudilharde": "acaudilhar",
    "acaudilhardes": "acaudilhar",
    "acaudilhare": "acaudilhar",
    "acaudilharei": "acaudilhar",
    "acaudilhareis": "acaudilhar",
    "acaudilharem": "acaudilhar",
    "acaudilharemos": "acaudilhar",
    "acaudilhares": "acaudilhar",
    "acaudilharia": "acaudilhar",
    "acaudilhariam": "acaudilhar",
    "acaudilharias": "acaudilhar",
    "acaudilharmo": "acaudilhar",
    "acaudilharmos": "acaudilhar",
    "acaudilhará": "acaudilhar",
    "acaudilharás": "acaudilhar",
    "acaudilharão": "acaudilhar",
    "acaudilharíamos": "acaudilhar",
    "acaudilharíeis": "acaudilhar",
    "acaudilhas": "acaudilhar",
    "acaudilhasse": "acaudilhar",
    "acaudilhassem": "acaudilhar",
    "acaudilhasses": "acaudilhar",
    "acaudilhaste": "acaudilhar",
    "acaudilhastes": "acaudilhar",
    "acaudilhava": "acaudilhar",
    "acaudilhavam": "acaudilhar",
    "acaudilhavas": "acaudilhar",
    "acaudilhe": "acaudilhar",
    "acaudilhei": "acaudilhar",
    "acaudilheis": "acaudilhar",
    "acaudilhem": "acaudilhar",
    "acaudilhemo": "acaudilhar",
    "acaudilhemos": "acaudilhar",
    "acaudilhes": "acaudilhar",
    "acaudilho": "acaudilhar",
    "acaudilhou": "acaudilhar",
    "acaudilhá": "acaudilhar",
    "acaudilhámo": "acaudilhar",
    "acaudilhámos": "acaudilhar",
    "acaudilháramo": "acaudilhar",
    "acaudilháramos": "acaudilhar",
    "acaudilhárei": "acaudilhar",
    "acaudilháreis": "acaudilhar",
    "acaudilhásseis": "acaudilhar",
    "acaudilhássemos": "acaudilhar",
    "acaudilhávamo": "acaudilhar",
    "acaudilhávamos": "acaudilhar",
    "acaudilhávei": "acaudilhar",
    "acaudilháveis": "acaudilhar",
    "acaules": "acaule",
    "acaulescentes": "acaulescente",
    "acaulescências": "acaulescência",
    "acaustobiólitos": "acaustobiólito",
    "acautela": "acautelar",
    "acautelada": "acautelar",
    "acauteladas": "acautelar",
    "acautelado": "acautelar",
    "acautelados": "acautelar",
    "acautelai": "acautelar",
    "acautelais": "acautelar",
    "acautelam": "acautelar",
    "acautelamentos": "acautelamento",
    "acautelamo": "acautelar",
    "acautelamos": "acautelar",
    "acautelando": "acautelar",
    "acautelara": "acautelar",
    "acautelaram": "acautelar",
    "acautelaras": "acautelar",
    "acautelarde": "acautelar",
    "acautelardes": "acautelar",
    "acautelare": "acautelar",
    "acautelarei": "acautelar",
    "acautelareis": "acautelar",
    "acautelarem": "acautelar",
    "acautelaremos": "acautelar",
    "acautelares": "acautelar",
    "acautelaria": "acautelar",
    "acautelariam": "acautelar",
    "acautelarias": "acautelar",
    "acautelarmo": "acautelar",
    "acautelarmos": "acautelar",
    "acautelará": "acautelar",
    "acautelarás": "acautelar",
    "acautelarão": "acautelar",
    "acautelaríamos": "acautelar",
    "acautelaríeis": "acautelar",
    "acautelas": "acautelar",
    "acautelasse": "acautelar",
    "acautelassem": "acautelar",
    "acautelasses": "acautelar",
    "acautelaste": "acautelar",
    "acautelastes": "acautelar",
    "acautelava": "acautelar",
    "acautelavam": "acautelar",
    "acautelavas": "acautelar",
    "acautele": "acautelar",
    "acautelei": "acautelar",
    "acauteleis": "acautelar",
    "acautelem": "acautelar",
    "acautelemo": "acautelar",
    "acautelemos": "acautelar",
    "acauteles": "acautelar",
    "acautelo": "acautelar",
    "acautelou": "acautelar",
    "acautelá": "acautelar",
    "acautelámo": "acautelar",
    "acautelámos": "acautelar",
    "acauteláramo": "acautelar",
    "acauteláramos": "acautelar",
    "acautelárei": "acautelar",
    "acauteláreis": "acautelar",
    "acautelásseis": "acautelar",
    "acautelássemos": "acautelar",
    "acautelávamo": "acautelar",
    "acautelávamos": "acautelar",
    "acautelávei": "acautelar",
    "acauteláveis": "acautelar",
    "acauás": "acauá",
    "acauãs": "acauã",
    "acavala": "acavalar",
    "acavalada": "acavalar",
    "acavaladas": "acavalar",
    "acavalado": "acavalar",
    "acavalados": "acavalar",
    "acavalai": "acavalar",
    "acavalais": "acavalar",
    "acavalam": "acavalar",
    "acavalamo": "acavalar",
    "acavalamos": "acavalar",
    "acavalando": "acavalar",
    "acavalara": "acavalar",
    "acavalaram": "acavalar",
    "acavalaras": "acavalar",
    "acavalarde": "acavalar",
    "acavalardes": "acavalar",
    "acavalare": "acavalar",
    "acavalarei": "acavalar",
    "acavalareis": "acavalar",
    "acavalarem": "acavalar",
    "acavalaremos": "acavalar",
    "acavalares": "acavalar",
    "acavalaria": "acavalar",
    "acavalariam": "acavalar",
    "acavalarias": "acavalar",
    "acavalarmo": "acavalar",
    "acavalarmos": "acavalar",
    "acavalará": "acavalar",
    "acavalarás": "acavalar",
    "acavalarão": "acavalar",
    "acavalaríamos": "acavalar",
    "acavalaríeis": "acavalar",
    "acavalas": "acavalar",
    "acavalasse": "acavalar",
    "acavalassem": "acavalar",
    "acavalasses": "acavalar",
    "acavalaste": "acavalar",
    "acavalastes": "acavalar",
    "acavalava": "acavalar",
    "acavalavam": "acavalar",
    "acavalavas": "acavalar",
    "acavale": "acavalar",
    "acavalei": "acavalar",
    "acavaleira": "acavaleirar",
    "acavaleirada": "acavaleirar",
    "acavaleiradas": "acavaleirar",
    "acavaleirado": "acavaleirar",
    "acavaleirados": "acavaleirar",
    "acavaleirai": "acavaleirar",
    "acavaleirais": "acavaleirar",
    "acavaleiram": "acavaleirar",
    "acavaleiramo": "acavaleirar",
    "acavaleiramos": "acavaleirar",
    "acavaleirando": "acavaleirar",
    "acavaleirara": "acavaleirar",
    "acavaleiraram": "acavaleirar",
    "acavaleiraras": "acavaleirar",
    "acavaleirarde": "acavaleirar",
    "acavaleirardes": "acavaleirar",
    "acavaleirare": "acavaleirar",
    "acavaleirarei": "acavaleirar",
    "acavaleirareis": "acavaleirar",
    "acavaleirarem": "acavaleirar",
    "acavaleiraremos": "acavaleirar",
    "acavaleirares": "acavaleirar",
    "acavaleiraria": "acavaleirar",
    "acavaleirariam": "acavaleirar",
    "acavaleirarias": "acavaleirar",
    "acavaleirarmo": "acavaleirar",
    "acavaleirarmos": "acavaleirar",
    "acavaleirará": "acavaleirar",
    "acavaleirarás": "acavaleirar",
    "acavaleirarão": "acavaleirar",
    "acavaleiraríamos": "acavaleirar",
    "acavaleiraríeis": "acavaleirar",
    "acavaleiras": "acavaleirar",
    "acavaleirasse": "acavaleirar",
    "acavaleirassem": "acavaleirar",
    "acavaleirasses": "acavaleirar",
    "acavaleiraste": "acavaleirar",
    "acavaleirastes": "acavaleirar",
    "acavaleirava": "acavaleirar",
    "acavaleiravam": "acavaleirar",
    "acavaleiravas": "acavaleirar",
    "acavaleire": "acavaleirar",
    "acavaleirei": "acavaleirar",
    "acavaleireis": "acavaleirar",
    "acavaleirem": "acavaleirar",
    "acavaleiremo": "acavaleirar",
    "acavaleiremos": "acavaleirar",
    "acavaleires": "acavaleirar",
    "acavaleiro": "acavaleirar",
    "acavaleirou": "acavaleirar",
    "acavaleirá": "acavaleirar",
    "acavaleirámo": "acavaleirar",
    "acavaleirámos": "acavaleirar",
    "acavaleiráramo": "acavaleirar",
    "acavaleiráramos": "acavaleirar",
    "acavaleirárei": "acavaleirar",
    "acavaleiráreis": "acavaleirar",
    "acavaleirásseis": "acavaleirar",
    "acavaleirássemos": "acavaleirar",
    "acavaleirávamo": "acavaleirar",
    "acavaleirávamos": "acavaleirar",
    "acavaleirávei": "acavaleirar",
    "acavaleiráveis": "acavaleirar",
    "acavaleis": "acavalar",
    "acavalem": "acavalar",
    "acavalemo": "acavalar",
    "acavalemos": "acavalar",
    "acavales": "acavalar",
    "acavaleta": "acavaletar",
    "acavaletada": "acavaletar",
    "acavaletadas": "acavaletar",
    "acavaletado": "acavaletar",
    "acavaletados": "acavaletar",
    "acavaletai": "acavaletar",
    "acavaletais": "acavaletar",
    "acavaletam": "acavaletar",
    "acavaletamo": "acavaletar",
    "acavaletamos": "acavaletar",
    "acavaletando": "acavaletar",
    "acavaletara": "acavaletar",
    "acavaletaram": "acavaletar",
    "acavaletaras": "acavaletar",
    "acavaletarde": "acavaletar",
    "acavaletardes": "acavaletar",
    "acavaletare": "acavaletar",
    "acavaletarei": "acavaletar",
    "acavaletareis": "acavaletar",
    "acavaletarem": "acavaletar",
    "acavaletaremos": "acavaletar",
    "acavaletares": "acavaletar",
    "acavaletaria": "acavaletar",
    "acavaletariam": "acavaletar",
    "acavaletarias": "acavaletar",
    "acavaletarmo": "acavaletar",
    "acavaletarmos": "acavaletar",
    "acavaletará": "acavaletar",
    "acavaletarás": "acavaletar",
    "acavaletarão": "acavaletar",
    "acavaletaríamos": "acavaletar",
    "acavaletaríeis": "acavaletar",
    "acavaletas": "acavaletar",
    "acavaletasse": "acavaletar",
    "acavaletassem": "acavaletar",
    "acavaletasses": "acavaletar",
    "acavaletaste": "acavaletar",
    "acavaletastes": "acavaletar",
    "acavaletava": "acavaletar",
    "acavaletavam": "acavaletar",
    "acavaletavas": "acavaletar",
    "acavalete": "acavaletar",
    "acavaletei": "acavaletar",
    "acavaleteis": "acavaletar",
    "acavaletem": "acavaletar",
    "acavaletemo": "acavaletar",
    "acavaletemos": "acavaletar",
    "acavaletes": "acavaletar",
    "acavaleto": "acavaletar",
    "acavaletou": "acavaletar",
    "acavaletá": "acavaletar",
    "acavaletámo": "acavaletar",
    "acavaletámos": "acavaletar",
    "acavaletáramo": "acavaletar",
    "acavaletáramos": "acavaletar",
    "acavaletárei": "acavaletar",
    "acavaletáreis": "acavaletar",
    "acavaletásseis": "acavaletar",
    "acavaletássemos": "acavaletar",
    "acavaletávamo": "acavaletar",
    "acavaletávamos": "acavaletar",
    "acavaletávei": "acavaletar",
    "acavaletáveis": "acavaletar",
    "acavalo": "acavalar",
    "acavalou": "acavalar",
    "acavalá": "acavalar",
    "acavalámo": "acavalar",
    "acavalámos": "acavalar",
    "acavaláramo": "acavalar",
    "acavaláramos": "acavalar",
    "acavalárei": "acavalar",
    "acavaláreis": "acavalar",
    "acavalásseis": "acavalar",
    "acavalássemos": "acavalar",
    "acavalávamo": "acavalar",
    "acavalávamos": "acavalar",
    "acavalávei": "acavalar",
    "acavaláveis": "acavalar",
    "acaveirada": "acaveirado",
    "acaveiradas": "acaveirado",
    "acaveirados": "acaveirado",
    "acaçapa": "apar",
    "acaçapada": "acaçapar",
    "acaçapadas": "acaçapar",
    "acaçapado": "acaçapar",
    "acaçapados": "acaçapar",
    "acaçapai": "acaçapar",
    "acaçapais": "acaçapar",
    "acaçapam": "acaçapar",
    "acaçapamo": "acaçapar",
    "acaçapamos": "acaçapar",
    "acaçapando": "acaçapar",
    "acaçapar": "apar",
    "acaçapara": "apar",
    "acaçaparam": "apar",
    "acaçaparas": "acaçapar",
    "acaçaparde": "acaçapar",
    "acaçapardes": "acaçapar",
    "acaçapare": "acaçapar",
    "acaçaparei": "acaçapar",
    "acaçapareis": "acaçapar",
    "acaçaparem": "apar",
    "acaçaparemos": "acaçapar",
    "acaçapares": "acaçapar",
    "acaçaparia": "apar",
    "acaçapariam": "acaçapar",
    "acaçaparias": "acaçapar",
    "acaçaparmo": "acaçapar",
    "acaçaparmos": "acaçapar",
    "acaçapará": "acaçapar",
    "acaçaparás": "acaçapar",
    "acaçaparão": "acaçapar",
    "acaçaparíamos": "acaçapar",
    "acaçaparíeis": "acaçapar",
    "acaçapas": "acaçapar",
    "acaçapasse": "apar",
    "acaçapassem": "acaçapar",
    "acaçapasses": "acaçapar",
    "acaçapaste": "acaçapar",
    "acaçapastes": "acaçapar",
    "acaçapava": "apar",
    "acaçapavam": "acaçapar",
    "acaçapavas": "acaçapar",
    "acaçape": "apar",
    "acaçapei": "acaçapar",
    "acaçapeis": "acaçapar",
    "acaçapem": "apar",
    "acaçapemo": "acaçapar",
    "acaçapemos": "acaçapar",
    "acaçapes": "acaçapar",
    "acaçapo": "acaçapar",
    "acaçapou": "acaçapar",
    "acaçapá": "apar",
    "acaçapámo": "acaçapar",
    "acaçapámos": "acaçapar",
    "acaçapáramo": "acaçapar",
    "acaçapáramos": "acaçapar",
    "acaçapárei": "acaçapar",
    "acaçapáreis": "acaçapar",
    "acaçapásseis": "acaçapar",
    "acaçapássemos": "acaçapar",
    "acaçapávamo": "acaçapar",
    "acaçapávamos": "acaçapar",
    "acaçapávei": "acaçapar",
    "acaçapáveis": "acaçapar",
    "acciona": "accionar",
    "accionada": "accionar",
    "accionadas": "accionar",
    "accionado": "accionar",
    "accionadora": "accionador",
    "accionadoras": "accionador",
    "accionadores": "accionador",
    "accionados": "accionar",
    "accionai": "accionar",
    "accionais": "accionar",
    "accionam": "accionar",
    "accionamo": "accionar",
    "accionamos": "accionar",
    "accionando": "accionar",
    "accionara": "accionar",
    "accionaram": "accionar",
    "accionaras": "accionar",
    "accionarde": "accionar",
    "accionardes": "accionar",
    "accionare": "accionar",
    "accionarei": "accionar",
    "accionareis": "accionar",
    "accionarem": "accionar",
    "accionaremos": "accionar",
    "accionares": "accionar",
    "accionaria": "accionar",
    "accionariam": "accionar",
    "accionarias": "accionar",
    "accionarmo": "accionar",
    "accionarmos": "accionar",
    "accionará": "accionar",
    "accionarás": "accionar",
    "accionarão": "accionar",
    "accionaríamos": "accionar",
    "accionaríeis": "accionar",
    "accionas": "accionar",
    "accionasse": "accionar",
    "accionassem": "accionar",
    "accionasses": "accionar",
    "accionaste": "accionar",
    "accionastes": "accionar",
    "accionava": "accionar",
    "accionavam": "accionar",
    "accionavas": "accionar",
    "accione": "accionar",
    "accionei": "accionar",
    "accioneis": "accionar",
    "accionem": "accionar",
    "accionemo": "accionar",
    "accionemos": "accionar",
    "acciones": "accionar",
    "accionistas": "accionista",
    "acciono": "accionar",
    "accionou": "accionar",
    "accioná": "accionar",
    "accionámo": "accionar",
    "accionámos": "accionar",
    "accionáramo": "accionar",
    "accionáramos": "accionar",
    "accionárei": "accionar",
    "accionáreis": "accionar",
    "accionária": "accionário",
    "accionárias": "accionário",
    "accionários": "accionário",
    "accionásseis": "accionar",
    "accionássemos": "accionar",
    "accionávamo": "accionar",
    "accionávamos": "accionar",
    "accionávei": "accionar",
    "accionáveis": "accionável",
    "accipitriformes": "accipitriforme",
    "accipitrários": "accipitrário",
    "accipitrídios": "accipitrídio",
    "acebolada": "acebolado",
    "aceboladas": "acebolado",
    "acebolados": "acebolado",
    "aceda": "aceder",
    "acedais": "aceder",
    "acedam": "aceder",
    "acedamo": "aceder",
    "acedamos": "aceder",
    "acedas": "aceder",
    "acede": "aceder",
    "acedei": "aceder",
    "acedeis": "aceder",
    "acedem": "aceder",
    "acedemo": "aceder",
    "acedemos": "aceder",
    "acedendo": "aceder",
    "acedentes": "acedente",
    "acedera": "aceder",
    "acederam": "aceder",
    "acederas": "aceder",
    "acederdes": "aceder",
    "acederei": "aceder",
    "acedereis": "aceder",
    "acederem": "aceder",
    "acederemos": "aceder",
    "acederes": "aceder",
    "acederia": "aceder",
    "acederiam": "aceder",
    "acederias": "aceder",
    "acedermo": "aceder",
    "acedermos": "aceder",
    "acederá": "aceder",
    "acederás": "aceder",
    "acederão": "aceder",
    "acederíamos": "aceder",
    "acederíeis": "aceder",
    "acedes": "aceder",
    "acedesse": "aceder",
    "acedessem": "aceder",
    "acedesses": "aceder",
    "acedeste": "aceder",
    "acedestes": "aceder",
    "acedeu": "aceder",
    "acedi": "aceder",
    "acedia": "aceder",
    "acediam": "aceder",
    "acedias": "acedia",
    "acedida": "aceder",
    "acedidas": "aceder",
    "acedido": "aceder",
    "acedidos": "aceder",
    "acediosa": "acedioso",
    "acediosas": "acedioso",
    "acediosos": "acedioso",
    "acedo": "aceder",
    "acedências": "acedência",
    "acedêramo": "aceder",
    "acedêramos": "aceder",
    "acedêreis": "aceder",
    "acedêsseis": "aceder",
    "acedêssemos": "aceder",
    "acedíamo": "aceder",
    "acedíamos": "aceder",
    "acedíeis": "aceder",
    "acedíveis": "acedível",
    "acefalias": "acefalia",
    "acefalitas": "acefalita",
    "acefalobraquias": "acefalobraquia",
    "acefalocistos": "acefalocisto",
    "acefaloforos": "acefaloforo",
    "acefalopodias": "acefalopodia",
    "acefalópodes": "acefalópode",
    "acefálica": "acefálico",
    "acefálicas": "acefálico",
    "acefálicos": "acefálico",
    "aceira": "aceiro",
    "aceirada": "aceirar",
    "aceiradas": "aceirar",
    "aceirado": "aceirar",
    "aceirados": "aceirar",
    "aceirai": "aceirar",
    "aceirais": "aceirar",
    "aceiram": "aceirar",
    "aceiramentos": "aceiramento",
    "aceiramo": "aceirar",
    "aceiramos": "aceirar",
    "aceirando": "aceirar",
    "aceirara": "aceirar",
    "aceiraram": "aceirar",
    "aceiraras": "aceirar",
    "aceirarde": "aceirar",
    "aceirardes": "aceirar",
    "aceirare": "aceirar",
    "aceirarei": "aceirar",
    "aceirareis": "aceirar",
    "aceirarem": "aceirar",
    "aceiraremos": "aceirar",
    "aceirares": "aceirar",
    "aceiraria": "aceirar",
    "aceirariam": "aceirar",
    "aceirarias": "aceiraria",
    "aceirarmo": "aceirar",
    "aceirarmos": "aceirar",
    "aceirará": "aceirar",
    "aceirarás": "aceirar",
    "aceirarão": "aceirar",
    "aceiraríamos": "aceirar",
    "aceiraríeis": "aceirar",
    "aceiras": "aceiro",
    "aceirasse": "aceirar",
    "aceirassem": "aceirar",
    "aceirasses": "aceirar",
    "aceiraste": "aceirar",
    "aceirastes": "aceirar",
    "aceirava": "aceirar",
    "aceiravam": "aceirar",
    "aceiravas": "aceirar",
    "aceirações": "aceiração",
    "aceire": "aceirar",
    "aceirei": "aceirar",
    "aceireis": "aceirar",
    "aceirem": "aceirar",
    "aceiremo": "aceirar",
    "aceiremos": "aceirar",
    "aceires": "aceirar",
    "aceiro": "aceirar",
    "aceiros": "aceiro",
    "aceirou": "aceirar",
    "aceirá": "aceirar",
    "aceirámo": "aceirar",
    "aceirámos": "aceirar",
    "aceiráramo": "aceirar",
    "aceiráramos": "aceirar",
    "aceirárei": "aceirar",
    "aceiráreis": "aceirar",
    "aceirásseis": "aceirar",
    "aceirássemos": "aceirar",
    "aceirávamo": "aceirar",
    "aceirávamos": "aceirar",
    "aceirávei": "aceirar",
    "aceiráveis": "aceirar",
    "aceita": "aceito",
    "aceitabilidades": "aceitabilidade",
    "aceitada": "aceitar",
    "aceitadas": "aceitar",
    "aceitado": "aceitar",
    "aceitadora": "aceitador",
    "aceitadoras": "aceitador",
    "aceitadores": "aceitador",
    "aceitados": "aceitar",
    "aceitai": "aceitar",
    "aceitais": "aceitar",
    "aceitam": "aceitar",
    "aceitamo": "aceitar",
    "aceitamos": "aceitar",
    "aceitando": "aceitar",
    "aceitantes": "aceitante",
    "aceitara": "aceitar",
    "aceitaram": "aceitar",
    "aceitaras": "aceitar",
    "aceitarde": "aceitar",
    "aceitardes": "aceitar",
    "aceitare": "aceitar",
    "aceitarei": "aceitar",
    "aceitareis": "aceitar",
    "aceitarem": "aceitar",
    "aceitaremos": "aceitar",
    "aceitares": "aceitar",
    "aceitaria": "aceitar",
    "aceitariam": "aceitar",
    "aceitarias": "aceitar",
    "aceitarmo": "aceitar",
    "aceitarmos": "aceitar",
    "aceitará": "aceitar",
    "aceitarás": "aceitar",
    "aceitarão": "aceitar",
    "aceitaríamos": "aceitar",
    "aceitaríeis": "aceitar",
    "aceitas": "aceito",
    "aceitasse": "aceitar",
    "aceitassem": "aceitar",
    "aceitasses": "aceitar",
    "aceitaste": "aceitar",
    "aceitastes": "aceitar",
    "aceitava": "aceitar",
    "aceitavam": "aceitar",
    "aceitavas": "aceitar",
    "aceitações": "aceitação",
    "aceite": "aceitar",
    "aceitei": "aceitar",
    "aceiteis": "aceitar",
    "aceitem": "aceitar",
    "aceitemo": "aceitar",
    "aceitemos": "aceitar",
    "aceites": "aceite",
    "aceito": "aceitar",
    "aceitos": "aceito",
    "aceitosa": "aceitoso",
    "aceitosas": "aceitoso",
    "aceitosos": "aceitoso",
    "aceitou": "aceitar",
    "aceitá": "aceitar",
    "aceitámo": "aceitar",
    "aceitámos": "aceitar",
    "aceitáramo": "aceitar",
    "aceitáramos": "aceitar",
    "aceitárei": "aceitar",
    "aceitáreis": "aceitar",
    "aceitásseis": "aceitar",
    "aceitássemos": "aceitar",
    "aceitávamo": "aceitar",
    "aceitávamos": "aceitar",
    "aceitávei": "aceitar",
    "aceitáveis": "aceitável",
    "aceleira": "aceleirar",
    "aceleirada": "aceleirar",
    "aceleiradas": "aceleirar",
    "aceleirado": "aceleirar",
    "aceleirados": "aceleirar",
    "aceleirai": "aceleirar",
    "aceleirais": "aceleirar",
    "aceleiram": "aceleirar",
    "aceleiramo": "aceleirar",
    "aceleiramos": "aceleirar",
    "aceleirando": "aceleirar",
    "aceleirara": "aceleirar",
    "aceleiraram": "aceleirar",
    "aceleiraras": "aceleirar",
    "aceleirarde": "aceleirar",
    "aceleirardes": "aceleirar",
    "aceleirare": "aceleirar",
    "aceleirarei": "aceleirar",
    "aceleirareis": "aceleirar",
    "aceleirarem": "aceleirar",
    "aceleiraremos": "aceleirar",
    "aceleirares": "aceleirar",
    "aceleiraria": "aceleirar",
    "aceleirariam": "aceleirar",
    "aceleirarias": "aceleirar",
    "aceleirarmo": "aceleirar",
    "aceleirarmos": "aceleirar",
    "aceleirará": "aceleirar",
    "aceleirarás": "aceleirar",
    "aceleirarão": "aceleirar",
    "aceleiraríamos": "aceleirar",
    "aceleiraríeis": "aceleirar",
    "aceleiras": "aceleirar",
    "aceleirasse": "aceleirar",
    "aceleirassem": "aceleirar",
    "aceleirasses": "aceleirar",
    "aceleiraste": "aceleirar",
    "aceleirastes": "aceleirar",
    "aceleirava": "aceleirar",
    "aceleiravam": "aceleirar",
    "aceleiravas": "aceleirar",
    "aceleire": "aceleirar",
    "aceleirei": "aceleirar",
    "aceleireis": "aceleirar",
    "aceleirem": "aceleirar",
    "aceleiremo": "aceleirar",
    "aceleiremos": "aceleirar",
    "aceleires": "aceleirar",
    "aceleiro": "aceleirar",
    "aceleirou": "aceleirar",
    "aceleirá": "aceleirar",
    "aceleirámo": "aceleirar",
    "aceleirámos": "aceleirar",
    "aceleiráramo": "aceleirar",
    "aceleiráramos": "aceleirar",
    "aceleirárei": "aceleirar",
    "aceleiráreis": "aceleirar",
    "aceleirásseis": "aceleirar",
    "aceleirássemos": "aceleirar",
    "aceleirávamo": "aceleirar",
    "aceleirávamos": "aceleirar",
    "aceleirávei": "aceleirar",
    "aceleiráveis": "aceleirar",
    "acelera": "acelerar",
    "acelerada": "acelerar",
    "aceleradas": "acelerar",
    "aceleradelas": "aceleradela",
    "acelerado": "acelerar",
    "aceleradora": "acelerador",
    "aceleradoras": "acelerador",
    "aceleradores": "acelerador",
    "acelerados": "acelerar",
    "aceleradíssima": "acelerado",
    "aceleradíssimas": "acelerado",
    "aceleradíssimo": "acelerado",
    "aceleradíssimos": "acelerado",
    "acelerai": "acelerar",
    "acelerais": "acelerar",
    "aceleram": "acelerar",
    "aceleramentos": "aceleramento",
    "aceleramo": "acelerar",
    "aceleramos": "acelerar",
    "acelerando": "acelerar",
    "acelerantes": "acelerante",
    "acelerara": "acelerar",
    "aceleraram": "acelerar",
    "aceleraras": "acelerar",
    "acelerarde": "acelerar",
    "acelerardes": "acelerar",
    "acelerare": "acelerar",
    "acelerarei": "acelerar",
    "acelerareis": "acelerar",
    "acelerarem": "acelerar",
    "aceleraremos": "acelerar",
    "acelerares": "acelerar",
    "aceleraria": "acelerar",
    "acelerariam": "acelerar",
    "acelerarias": "acelerar",
    "acelerarmo": "acelerar",
    "acelerarmos": "acelerar",
    "acelerará": "acelerar",
    "acelerarás": "acelerar",
    "acelerarão": "acelerar",
    "aceleraríamos": "acelerar",
    "aceleraríeis": "acelerar",
    "aceleras": "acelerar",
    "acelerasse": "acelerar",
    "acelerassem": "acelerar",
    "acelerasses": "acelerar",
    "aceleraste": "acelerar",
    "acelerastes": "acelerar",
    "acelerativa": "acelerativo",
    "acelerativas": "acelerativo",
    "acelerativos": "acelerativo",
    "acelerava": "acelerar",
    "aceleravam": "acelerar",
    "aceleravas": "acelerar",
    "acelerações": "aceleração",
    "acelere": "acelerar",
    "acelerei": "acelerar",
    "acelereis": "acelerar",
    "acelerem": "acelerar",
    "aceleremo": "acelerar",
    "aceleremos": "acelerar",
    "aceleres": "acelerar",
    "acelero": "acelerar",
    "acelerou": "acelerar",
    "acelerá": "acelerar",
    "acelerámo": "acelerar",
    "acelerámos": "acelerar",
    "aceleráramo": "acelerar",
    "aceleráramos": "acelerar",
    "acelerárei": "acelerar",
    "aceleráreis": "acelerar",
    "acelerásseis": "acelerar",
    "acelerássemos": "acelerar",
    "acelerávamo": "acelerar",
    "acelerávamos": "acelerar",
    "acelerávei": "acelerar",
    "aceleráveis": "acelerar",
    "acelerógrafos": "acelerógrafo",
    "acelerómetros": "acelerómetro",
    "aceleuma": "aceleumar",
    "aceleumada": "aceleumar",
    "aceleumadas": "aceleumar",
    "aceleumado": "aceleumar",
    "aceleumados": "aceleumar",
    "aceleumai": "aceleumar",
    "aceleumais": "aceleumar",
    "aceleumam": "aceleumar",
    "aceleumamo": "aceleumar",
    "aceleumamos": "aceleumar",
    "aceleumando": "aceleumar",
    "aceleumara": "aceleumar",
    "aceleumaram": "aceleumar",
    "aceleumaras": "aceleumar",
    "aceleumarde": "aceleumar",
    "aceleumardes": "aceleumar",
    "aceleumare": "aceleumar",
    "aceleumarei": "aceleumar",
    "aceleumareis": "aceleumar",
    "aceleumarem": "aceleumar",
    "aceleumaremos": "aceleumar",
    "aceleumares": "aceleumar",
    "aceleumaria": "aceleumar",
    "aceleumariam": "aceleumar",
    "aceleumarias": "aceleumar",
    "aceleumarmo": "aceleumar",
    "aceleumarmos": "aceleumar",
    "aceleumará": "aceleumar",
    "aceleumarás": "aceleumar",
    "aceleumarão": "aceleumar",
    "aceleumaríamos": "aceleumar",
    "aceleumaríeis": "aceleumar",
    "aceleumas": "aceleumar",
    "aceleumasse": "aceleumar",
    "aceleumassem": "aceleumar",
    "aceleumasses": "aceleumar",
    "aceleumaste": "aceleumar",
    "aceleumastes": "aceleumar",
    "aceleumava": "aceleumar",
    "aceleumavam": "aceleumar",
    "aceleumavas": "aceleumar",
    "aceleume": "aceleumar",
    "aceleumei": "aceleumar",
    "aceleumeis": "aceleumar",
    "aceleumem": "aceleumar",
    "aceleumemo": "aceleumar",
    "aceleumemos": "aceleumar",
    "aceleumes": "aceleumar",
    "aceleumo": "aceleumar",
    "aceleumou": "aceleumar",
    "aceleumá": "aceleumar",
    "aceleumámo": "aceleumar",
    "aceleumámos": "aceleumar",
    "aceleumáramo": "aceleumar",
    "aceleumáramos": "aceleumar",
    "aceleumárei": "aceleumar",
    "aceleumáreis": "aceleumar",
    "aceleumásseis": "aceleumar",
    "aceleumássemos": "aceleumar",
    "aceleumávamo": "aceleumar",
    "aceleumávamos": "aceleumar",
    "aceleumávei": "aceleumar",
    "aceleumáveis": "aceleumar",
    "acelgas": "acelga",
    "acelomada": "acelomado",
    "acelomadas": "acelomado",
    "acelomados": "acelomado",
    "acelomatas": "acelomata",
    "acemistas": "acemista",
    "acena": "acenar",
    "acenada": "acenar",
    "acenadas": "acenar",
    "acenado": "acenar",
    "acenados": "acenar",
    "acenai": "acenar",
    "acenais": "acenar",
    "acenam": "acenar",
    "acenamentos": "acenamento",
    "acenamo": "acenar",
    "acenamos": "acenar",
    "acenando": "acenar",
    "acenara": "acenar",
    "acenaram": "acenar",
    "acenaras": "acenar",
    "acenardes": "acenar",
    "acenarei": "acenar",
    "acenareis": "acenar",
    "acenarem": "acenar",
    "acenaremos": "acenar",
    "acenares": "acenar",
    "acenaria": "acenar",
    "acenariam": "acenar",
    "acenarias": "acenar",
    "acenarmo": "acenar",
    "acenarmos": "acenar",
    "acenará": "acenar",
    "acenarás": "acenar",
    "acenarão": "acenar",
    "acenaríamos": "acenar",
    "acenaríeis": "acenar",
    "acenas": "acenar",
    "acenasse": "acenar",
    "acenassem": "acenar",
    "acenasses": "acenar",
    "acenaste": "acenar",
    "acenastes": "acenar",
    "acenava": "acenar",
    "acenavam": "acenar",
    "acenavas": "acenar",
    "acenda": "acender",
    "acendais": "acender",
    "acendalhas": "acendalha",
    "acendam": "acender",
    "acendamo": "acender",
    "acendamos": "acender",
    "acendas": "acender",
    "acende": "acender",
    "acendedeira": "acendedor",
    "acendedeiras": "acendedor",
    "acendedora": "acendedor",
    "acendedoras": "acendedor",
    "acendedores": "acendedor",
    "acendei": "acender",
    "acendeis": "acender",
    "acendem": "acender",
    "acendemo": "acender",
    "acendemos": "acender",
    "acendendo": "acender",
    "acendera": "acender",
    "acenderam": "acender",
    "acenderas": "acender",
    "acenderde": "acender",
    "acenderdes": "acender",
    "acendere": "acender",
    "acenderei": "acender",
    "acendereis": "acender",
    "acenderem": "acender",
    "acenderemos": "acender",
    "acenderes": "acender",
    "acenderia": "acender",
    "acenderiam": "acender",
    "acenderias": "acender",
    "acendermo": "acender",
    "acendermos": "acender",
    "acenderá": "acender",
    "acenderás": "acender",
    "acenderão": "acender",
    "acenderíamos": "acender",
    "acenderíeis": "acender",
    "acendes": "acender",
    "acendesse": "acender",
    "acendessem": "acender",
    "acendesses": "acender",
    "acendeste": "acender",
    "acendestes": "acender",
    "acendeu": "acender",
    "acendi": "acender",
    "acendia": "acender",
    "acendiam": "acender",
    "acendias": "acender",
    "acendida": "acendido",
    "acendidas": "acendido",
    "acendido": "acender",
    "acendidos": "acendido",
    "acendimentos": "acendimento",
    "acendo": "acender",
    "acendra": "acendrar",
    "acendrada": "acendrar",
    "acendradas": "acendrar",
    "acendradeira": "acendrador",
    "acendradeiras": "acendrador",
    "acendrado": "acendrar",
    "acendradora": "acendrador",
    "acendradoras": "acendrador",
    "acendradores": "acendrador",
    "acendrados": "acendrar",
    "acendrai": "acendrar",
    "acendrais": "acendrar",
    "acendram": "acendrar",
    "acendramentos": "acendramento",
    "acendramo": "acendrar",
    "acendramos": "acendrar",
    "acendrando": "acendrar",
    "acendrara": "acendrar",
    "acendraram": "acendrar",
    "acendraras": "acendrar",
    "acendrarde": "acendrar",
    "acendrardes": "acendrar",
    "acendrare": "acendrar",
    "acendrarei": "acendrar",
    "acendrareis": "acendrar",
    "acendrarem": "acendrar",
    "acendraremos": "acendrar",
    "acendrares": "acendrar",
    "acendraria": "acendrar",
    "acendrariam": "acendrar",
    "acendrarias": "acendrar",
    "acendrarmo": "acendrar",
    "acendrarmos": "acendrar",
    "acendrará": "acendrar",
    "acendrarás": "acendrar",
    "acendrarão": "acendrar",
    "acendraríamos": "acendrar",
    "acendraríeis": "acendrar",
    "acendras": "acendrar",
    "acendrasse": "acendrar",
    "acendrassem": "acendrar",
    "acendrasses": "acendrar",
    "acendraste": "acendrar",
    "acendrastes": "acendrar",
    "acendrava": "acendrar",
    "acendravam": "acendrar",
    "acendravas": "acendrar",
    "acendre": "acendrar",
    "acendrei": "acendrar",
    "acendreis": "acendrar",
    "acendrem": "acendrar",
    "acendremo": "acendrar",
    "acendremos": "acendrar",
    "acendres": "acendrar",
    "acendro": "acendrar",
    "acendrou": "acendrar",
    "acendrá": "acendrar",
    "acendrámo": "acendrar",
    "acendrámos": "acendrar",
    "acendráramo": "acendrar",
    "acendráramos": "acendrar",
    "acendrárei": "acendrar",
    "acendráreis": "acendrar",
    "acendrásseis": "acendrar",
    "acendrássemos": "acendrar",
    "acendrávamo": "acendrar",
    "acendrávamos": "acendrar",
    "acendrávei": "acendrar",
    "acendráveis": "acendrar",
    "acendê": "acender",
    "acendêramo": "acender",
    "acendêramos": "acender",
    "acendêrei": "acender",
    "acendêreis": "acender",
    "acendêsseis": "acender",
    "acendêssemos": "acender",
    "acendíamo": "acender",
    "acendíamos": "acender",
    "acendíei": "acender",
    "acendíeis": "acender",
    "acendíveis": "acendível",
    "acene": "acenar",
    "acenei": "acenar",
    "aceneis": "acenar",
    "acenem": "acenar",
    "acenemo": "acenar",
    "acenemos": "acenar",
    "acenes": "acenar",
    "acenestesias": "acenestesia",
    "aceno": "acenar",
    "acenos": "aceno",
    "acenosa": "acenoso",
    "acenosas": "acenoso",
    "acenosos": "acenoso",
    "acenou": "acenar",
    "acenozinho": "aceno",
    "acenozinhos": "aceno",
    "acenozito": "aceno",
    "acenozitos": "aceno",
    "acensos": "acenso",
    "acensões": "acensão",
    "acentos": "acento",
    "acentua": "acentuar",
    "acentuada": "acentuar",
    "acentuadas": "acentuar",
    "acentuado": "acentuar",
    "acentuados": "acentuar",
    "acentuadíssima": "acentuado",
    "acentuadíssimas": "acentuado",
    "acentuadíssimo": "acentuado",
    "acentuadíssimos": "acentuado",
    "acentuai": "acentuar",
    "acentuais": "acentuar",
    "acentuam": "acentuar",
    "acentuamo": "acentuar",
    "acentuamos": "acentuar",
    "acentuando": "acentuar",
    "acentuara": "acentuar",
    "acentuaram": "acentuar",
    "acentuaras": "acentuar",
    "acentuarde": "acentuar",
    "acentuardes": "acentuar",
    "acentuare": "acentuar",
    "acentuarei": "acentuar",
    "acentuareis": "acentuar",
    "acentuarem": "acentuar",
    "acentuaremos": "acentuar",
    "acentuares": "acentuar",
    "acentuaria": "acentuar",
    "acentuariam": "acentuar",
    "acentuarias": "acentuar",
    "acentuarmo": "acentuar",
    "acentuarmos": "acentuar",
    "acentuará": "acentuar",
    "acentuarás": "acentuar",
    "acentuarão": "acentuar",
    "acentuaríamos": "acentuar",
    "acentuaríeis": "acentuar",
    "acentuas": "acentuar",
    "acentuasse": "acentuar",
    "acentuassem": "acentuar",
    "acentuasses": "acentuar",
    "acentuaste": "acentuar",
    "acentuastes": "acentuar",
    "acentuava": "acentuar",
    "acentuavam": "acentuar",
    "acentuavas": "acentuar",
    "acentuações": "acentuação",
    "acentue": "acentuar",
    "acentuei": "acentuar",
    "acentueis": "acentuar",
    "acentuem": "acentuar",
    "acentuemo": "acentuar",
    "acentuemos": "acentuar",
    "acentues": "acentuar",
    "acentuo": "acentuar",
    "acentuou": "acentuar",
    "acentuá": "acentuar",
    "acentuámo": "acentuar",
    "acentuámos": "acentuar",
    "acentuáramo": "acentuar",
    "acentuáramos": "acentuar",
    "acentuárei": "acentuar",
    "acentuáreis": "acentuar",
    "acentuásseis": "acentuar",
    "acentuássemos": "acentuar",
    "acentuávamo": "acentuar",
    "acentuávamos": "acentuar",
    "acentuávei": "acentuar",
    "acentuáveis": "acentuar",
    "acenámo": "acenar",
    "acenámos": "acenar",
    "acenáramo": "acenar",
    "acenáramos": "acenar",
    "acenáreis": "acenar",
    "acenásseis": "acenar",
    "acenássemos": "acenar",
    "acenávamo": "acenar",
    "acenávamos": "acenar",
    "acenáveis": "acenar",
    "acepilha": "acepilhar",
    "acepilhada": "acepilhar",
    "acepilhadas": "acepilhar",
    "acepilhado": "acepilhar",
    "acepilhados": "acepilhar",
    "acepilhai": "acepilhar",
    "acepilhais": "acepilhar",
    "acepilham": "acepilhar",
    "acepilhamo": "acepilhar",
    "acepilhamos": "acepilhar",
    "acepilhando": "acepilhar",
    "acepilhara": "acepilhar",
    "acepilharam": "acepilhar",
    "acepilharas": "acepilhar",
    "acepilharde": "acepilhar",
    "acepilhardes": "acepilhar",
    "acepilhare": "acepilhar",
    "acepilharei": "acepilhar",
    "acepilhareis": "acepilhar",
    "acepilharem": "acepilhar",
    "acepilharemos": "acepilhar",
    "acepilhares": "acepilhar",
    "acepilharia": "acepilhar",
    "acepilhariam": "acepilhar",
    "acepilharias": "acepilhar",
    "acepilharmo": "acepilhar",
    "acepilharmos": "acepilhar",
    "acepilhará": "acepilhar",
    "acepilharás": "acepilhar",
    "acepilharão": "acepilhar",
    "acepilharíamos": "acepilhar",
    "acepilharíeis": "acepilhar",
    "acepilhas": "acepilhar",
    "acepilhasse": "acepilhar",
    "acepilhassem": "acepilhar",
    "acepilhasses": "acepilhar",
    "acepilhaste": "acepilhar",
    "acepilhastes": "acepilhar",
    "acepilhava": "acepilhar",
    "acepilhavam": "acepilhar",
    "acepilhavas": "acepilhar",
    "acepilhe": "acepilhar",
    "acepilhei": "acepilhar",
    "acepilheis": "acepilhar",
    "acepilhem": "acepilhar",
    "acepilhemo": "acepilhar",
    "acepilhemos": "acepilhar",
    "acepilhes": "acepilhar",
    "acepilho": "acepilhar",
    "acepilhou": "acepilhar",
    "acepilhá": "acepilhar",
    "acepilhámo": "acepilhar",
    "acepilhámos": "acepilhar",
    "acepilháramo": "acepilhar",
    "acepilháramos": "acepilhar",
    "acepilhárei": "acepilhar",
    "acepilháreis": "acepilhar",
    "acepilhásseis": "acepilhar",
    "acepilhássemos": "acepilhar",
    "acepilhávamo": "acepilhar",
    "acepilhávamos": "acepilhar",
    "acepilhávei": "acepilhar",
    "acepilháveis": "acepilhar",
    "acepipa": "acepipar",
    "acepipada": "acepipar",
    "acepipadas": "acepipar",
    "acepipado": "acepipar",
    "acepipados": "acepipar",
    "acepipai": "acepipar",
    "acepipais": "acepipar",
    "acepipam": "acepipar",
    "acepipamo": "acepipar",
    "acepipamos": "acepipar",
    "acepipando": "acepipar",
    "acepipara": "acepipar",
    "acepiparam": "acepipar",
    "acepiparas": "acepipar",
    "acepiparde": "acepipar",
    "acepipardes": "acepipar",
    "acepipare": "acepipar",
    "acepiparei": "acepipar",
    "acepipareis": "acepipar",
    "acepiparem": "acepipar",
    "acepiparemos": "acepipar",
    "acepipares": "acepipar",
    "acepiparia": "acepipar",
    "acepipariam": "acepipar",
    "acepiparias": "acepipar",
    "acepiparmo": "acepipar",
    "acepiparmos": "acepipar",
    "acepipará": "acepipar",
    "acepiparás": "acepipar",
    "acepiparão": "acepipar",
    "acepiparíamos": "acepipar",
    "acepiparíeis": "acepipar",
    "acepipas": "acepipar",
    "acepipasse": "acepipar",
    "acepipassem": "acepipar",
    "acepipasses": "acepipar",
    "acepipaste": "acepipar",
    "acepipastes": "acepipar",
    "acepipava": "acepipar",
    "acepipavam": "acepipar",
    "acepipavas": "acepipar",
    "acepipe": "acepipar",
    "acepipei": "acepipar",
    "acepipeis": "acepipar",
    "acepipem": "acepipar",
    "acepipemo": "acepipar",
    "acepipemos": "acepipar",
    "acepipes": "acepipe",
    "acepipo": "acepipar",
    "acepipou": "acepipar",
    "acepipá": "acepipar",
    "acepipámo": "acepipar",
    "acepipámos": "acepipar",
    "acepipáramo": "acepipar",
    "acepipáramos": "acepipar",
    "acepipárei": "acepipar",
    "acepipáreis": "acepipar",
    "acepipásseis": "acepipar",
    "acepipássemos": "acepipar",
    "acepipávamo": "acepipar",
    "acepipávamos": "acepipar",
    "acepipávei": "acepipar",
    "acepipáveis": "acepipar",
    "aceptilações": "aceptilação",
    "acepções": "acepção",
    "acera": "acerar",
    "acerada": "acerar",
    "aceradas": "acerar",
    "acerado": "acerar",
    "acerados": "acerar",
    "aceragens": "aceragem",
    "acerai": "acerar",
    "acerais": "acerar",
    "aceram": "acerar",
    "aceramentos": "aceramento",
    "aceramo": "acerar",
    "aceramos": "acerar",
    "acerando": "acerar",
    "acerantes": "acerante",
    "acerara": "acerar",
    "aceraram": "acerar",
    "aceraras": "acerar",
    "acerarde": "acerar",
    "acerardes": "acerar",
    "acerare": "acerar",
    "acerarei": "acerar",
    "acerareis": "acerar",
    "acerarem": "acerar",
    "aceraremos": "acerar",
    "acerares": "acerar",
    "aceraria": "acerar",
    "acerariam": "acerar",
    "acerarias": "aceraria",
    "acerarmo": "acerar",
    "acerarmos": "acerar",
    "acerará": "acerar",
    "acerarás": "acerar",
    "acerarão": "acerar",
    "aceraríamos": "acerar",
    "aceraríeis": "acerar",
    "aceras": "acerar",
    "acerasse": "acerar",
    "acerassem": "acerar",
    "acerasses": "acerar",
    "aceraste": "acerar",
    "acerastes": "acerar",
    "aceratérios": "aceratério",
    "acerava": "acerar",
    "aceravam": "acerar",
    "aceravas": "acerar",
    "acerações": "aceração",
    "acerba": "acerbo",
    "acerbada": "acerbar",
    "acerbadas": "acerbar",
    "acerbado": "acerbar",
    "acerbados": "acerbar",
    "acerbadíssima": "acerbado",
    "acerbadíssimas": "acerbado",
    "acerbadíssimo": "acerbado",
    "acerbadíssimos": "acerbado",
    "acerbai": "acerbar",
    "acerbais": "acerbar",
    "acerbam": "acerbar",
    "acerbamo": "acerbar",
    "acerbamos": "acerbar",
    "acerbando": "acerbar",
    "acerbara": "acerbar",
    "acerbaram": "acerbar",
    "acerbaras": "acerbar",
    "acerbarde": "acerbar",
    "acerbardes": "acerbar",
    "acerbare": "acerbar",
    "acerbarei": "acerbar",
    "acerbareis": "acerbar",
    "acerbarem": "acerbar",
    "acerbaremos": "acerbar",
    "acerbares": "acerbar",
    "acerbaria": "acerbar",
    "acerbariam": "acerbar",
    "acerbarias": "acerbar",
    "acerbarmo": "acerbar",
    "acerbarmos": "acerbar",
    "acerbará": "acerbar",
    "acerbarás": "acerbar",
    "acerbarão": "acerbar",
    "acerbaríamos": "acerbar",
    "acerbaríeis": "acerbar",
    "acerbas": "acerbo",
    "acerbasse": "acerbar",
    "acerbassem": "acerbar",
    "acerbasses": "acerbar",
    "acerbaste": "acerbar",
    "acerbastes": "acerbar",
    "acerbava": "acerbar",
    "acerbavam": "acerbar",
    "acerbavas": "acerbar",
    "acerbe": "acerbar",
    "acerbei": "acerbar",
    "acerbeis": "acerbar",
    "acerbem": "acerbar",
    "acerbemo": "acerbar",
    "acerbemos": "acerbar",
    "acerbes": "acerbar",
    "acerbidades": "acerbidade",
    "acerbo": "acerbar",
    "acerbos": "acerbo",
    "acerbou": "acerbar",
    "acerbá": "acerbar",
    "acerbámo": "acerbar",
    "acerbámos": "acerbar",
    "acerbáramo": "acerbar",
    "acerbáramos": "acerbar",
    "acerbárei": "acerbar",
    "acerbáreis": "acerbar",
    "acerbásseis": "acerbar",
    "acerbássemos": "acerbar",
    "acerbávamo": "acerbar",
    "acerbávamos": "acerbar",
    "acerbávei": "acerbar",
    "acerbáveis": "acerbar",
    "acerca": "acercar",
    "acercada": "acercar",
    "acercadas": "acercar",
    "acercado": "acercar",
    "acercados": "acercar",
    "acercai": "acercar",
    "acercais": "acercar",
    "acercam": "acercar",
    "acercamentos": "acercamento",
    "acercamo": "acercar",
    "acercamos": "acercar",
    "acercando": "acercar",
    "acercara": "acercar",
    "acercaram": "acercar",
    "acercaras": "acercar",
    "acercarde": "acercar",
    "acercardes": "acercar",
    "acercare": "acercar",
    "acercarei": "acercar",
    "acercareis": "acercar",
    "acercarem": "acercar",
    "acercaremos": "acercar",
    "acercares": "acercar",
    "acercaria": "acercar",
    "acercariam": "acercar",
    "acercarias": "acercar",
    "acercarmo": "acercar",
    "acercarmos": "acercar",
    "acercará": "acercar",
    "acercarás": "acercar",
    "acercarão": "acercar",
    "acercaríamos": "acercar",
    "acercaríeis": "acercar",
    "acercas": "acercar",
    "acercasse": "acercar",
    "acercassem": "acercar",
    "acercasses": "acercar",
    "acercaste": "acercar",
    "acercastes": "acercar",
    "acercava": "acercar",
    "acercavam": "acercar",
    "acercavas": "acercar",
    "acerco": "acercar",
    "acercou": "acercar",
    "acercá": "acercar",
    "acercámo": "acercar",
    "acercámos": "acercar",
    "acercáramo": "acercar",
    "acercáramos": "acercar",
    "acercárei": "acercar",
    "acercáreis": "acercar",
    "acercásseis": "acercar",
    "acercássemos": "acercar",
    "acercávamo": "acercar",
    "acercávamos": "acercar",
    "acercávei": "acercar",
    "acercáveis": "acercar",
    "acere": "acerar",
    "acerei": "acerar",
    "acereis": "acerar",
    "acereja": "acerejar",
    "acerejada": "acerejar",
    "acerejadas": "acerejar",
    "acerejado": "acerejar",
    "acerejados": "acerejar",
    "acerejai": "acerejar",
    "acerejais": "acerejar",
    "acerejam": "acerejar",
    "acerejamo": "acerejar",
    "acerejamos": "acerejar",
    "acerejando": "acerejar",
    "acerejara": "acerejar",
    "acerejaram": "acerejar",
    "acerejaras": "acerejar",
    "acerejarde": "acerejar",
    "acerejardes": "acerejar",
    "acerejare": "acerejar",
    "acerejarei": "acerejar",
    "acerejareis": "acerejar",
    "acerejarem": "acerejar",
    "acerejaremos": "acerejar",
    "acerejares": "acerejar",
    "acerejaria": "acerejar",
    "acerejariam": "acerejar",
    "acerejarias": "acerejar",
    "acerejarmo": "acerejar",
    "acerejarmos": "acerejar",
    "acerejará": "acerejar",
    "acerejarás": "acerejar",
    "acerejarão": "acerejar",
    "acerejaríamos": "acerejar",
    "acerejaríeis": "acerejar",
    "acerejas": "acerejar",
    "acerejasse": "acerejar",
    "acerejassem": "acerejar",
    "acerejasses": "acerejar",
    "acerejaste": "acerejar",
    "acerejastes": "acerejar",
    "acerejava": "acerejar",
    "acerejavam": "acerejar",
    "acerejavas": "acerejar",
    "acereje": "acerejar",
    "acerejei": "acerejar",
    "acerejeis": "acerejar",
    "acerejem": "acerejar",
    "acerejemo": "acerejar",
    "acerejemos": "acerejar",
    "acerejes": "acerejar",
    "acerejo": "acerejar",
    "acerejou": "acerejar",
    "acerejá": "acerejar",
    "acerejámo": "acerejar",
    "acerejámos": "acerejar",
    "acerejáramo": "acerejar",
    "acerejáramos": "acerejar",
    "acerejárei": "acerejar",
    "acerejáreis": "acerejar",
    "acerejásseis": "acerejar",
    "acerejássemos": "acerejar",
    "acerejávamo": "acerejar",
    "acerejávamos": "acerejar",
    "acerejávei": "acerejar",
    "acerejáveis": "acerejar",
    "acerem": "acerar",
    "aceremo": "acerar",
    "aceremos": "acerar",
    "aceres": "acerar",
    "acerias": "aceria",
    "acero": "acerar",
    "acerolas": "acerola",
    "acerosa": "aceroso",
    "acerosas": "aceroso",
    "acerosos": "aceroso",
    "acerou": "acerar",
    "acerque": "acercar",
    "acerquei": "acercar",
    "acerqueis": "acercar",
    "acerquem": "acercar",
    "acerquemo": "acercar",
    "acerquemos": "acercar",
    "acerques": "acercar",
    "acerta": "acertar",
    "acertada": "acertar",
    "acertadas": "acertar",
    "acertadazinha": "acertado",
    "acertadazinhas": "acertado",
    "acertadazita": "acertado",
    "acertadazitas": "acertado",
    "acertadinha": "acertado",
    "acertadinhas": "acertado",
    "acertadinho": "acertado",
    "acertadinhos": "acertado",
    "acertadita": "acertado",
    "acertaditas": "acertado",
    "acertadito": "acertado",
    "acertaditos": "acertado",
    "acertado": "acertar",
    "acertados": "acertar",
    "acertadozinho": "acertado",
    "acertadozinhos": "acertado",
    "acertadozito": "acertado",
    "acertadozitos": "acertado",
    "acertadíssima": "acertado",
    "acertadíssimas": "acertado",
    "acertadíssimo": "acertado",
    "acertadíssimos": "acertado",
    "acertai": "acertar",
    "acertais": "acertar",
    "acertam": "acertar",
    "acertamo": "acertar",
    "acertamos": "acertar",
    "acertando": "acertar",
    "acertara": "acertar",
    "acertaram": "acertar",
    "acertaras": "acertar",
    "acertarde": "acertar",
    "acertardes": "acertar",
    "acertare": "acertar",
    "acertarei": "acertar",
    "acertareis": "acertar",
    "acertarem": "acertar",
    "acertaremos": "acertar",
    "acertares": "acertar",
    "acertaria": "acertar",
    "acertariam": "acertar",
    "acertarias": "acertar",
    "acertarmo": "acertar",
    "acertarmos": "acertar",
    "acertará": "acertar",
    "acertarás": "acertar",
    "acertarão": "acertar",
    "acertaríamos": "acertar",
    "acertaríeis": "acertar",
    "acertas": "acertar",
    "acertasse": "acertar",
    "acertassem": "acertar",
    "acertasses": "acertar",
    "acertaste": "acertar",
    "acertastes": "acertar",
    "acertava": "acertar",
    "acertavam": "acertar",
    "acertavas": "acertar",
    "acerte": "acertar",
    "acertei": "acertar",
    "acerteis": "acertar",
    "acertem": "acertar",
    "acertemo": "acertar",
    "acertemos": "acertar",
    "acertes": "acertar",
    "acerto": "acertar",
    "acertos": "acerto",
    "acertou": "acertar",
    "acertá": "acertar",
    "acertámo": "acertar",
    "acertámos": "acertar",
    "acertáramo": "acertar",
    "acertáramos": "acertar",
    "acertárei": "acertar",
    "acertáreis": "acertar",
    "acertásseis": "acertar",
    "acertássemos": "acertar",
    "acertávamo": "acertar",
    "acertávamos": "acertar",
    "acertávei": "acertar",
    "acertáveis": "acertar",
    "acerva": "acervar",
    "acervada": "acervar",
    "acervadas": "acervar",
    "acervado": "acervar",
    "acervados": "acervar",
    "acervai": "acervar",
    "acervais": "acervar",
    "acervam": "acervar",
    "acervamo": "acervar",
    "acervamos": "acervar",
    "acervando": "acervar",
    "acervara": "acervar",
    "acervaram": "acervar",
    "acervaras": "acervar",
    "acervarde": "acervar",
    "acervardes": "acervar",
    "acervare": "acervar",
    "acervarei": "acervar",
    "acervareis": "acervar",
    "acervarem": "acervar",
    "acervaremos": "acervar",
    "acervares": "acervar",
    "acervaria": "acervar",
    "acervariam": "acervar",
    "acervarias": "acervar",
    "acervarmo": "acervar",
    "acervarmos": "acervar",
    "acervará": "acervar",
    "acervarás": "acervar",
    "acervarão": "acervar",
    "acervaríamos": "acervar",
    "acervaríeis": "acervar",
    "acervas": "acervar",
    "acervasse": "acervar",
    "acervassem": "acervar",
    "acervasses": "acervar",
    "acervaste": "acervar",
    "acervastes": "acervar",
    "acervava": "acervar",
    "acervavam": "acervar",
    "acervavas": "acervar",
    "acervações": "acervação",
    "acerve": "acervar",
    "acervei": "acervar",
    "acerveis": "acervar",
    "acervejada": "acervejado",
    "acervejadas": "acervejado",
    "acervejados": "acervejado",
    "acervem": "acervar",
    "acervemo": "acervar",
    "acervemos": "acervar",
    "acerves": "acervar",
    "acervo": "acervar",
    "acervos": "acervo",
    "acervou": "acervar",
    "acervá": "acervar",
    "acervámo": "acervar",
    "acervámos": "acervar",
    "acerváramo": "acervar",
    "acerváramos": "acervar",
    "acervárei": "acervar",
    "acerváreis": "acervar",
    "acervásseis": "acervar",
    "acervássemos": "acervar",
    "acervávamo": "acervar",
    "acervávamos": "acervar",
    "acervávei": "acervar",
    "acerváveis": "acervar",
    "acerá": "acerar",
    "acerácea": "aceráceo",
    "aceráceas": "aceráceo",
    "aceráceos": "aceráceo",
    "acerámo": "acerar",
    "acerámos": "acerar",
    "aceráramo": "acerar",
    "aceráramos": "acerar",
    "acerárei": "acerar",
    "aceráreis": "acerar",
    "acerásseis": "acerar",
    "acerássemos": "acerar",
    "acerávamo": "acerar",
    "acerávamos": "acerar",
    "acerávei": "acerar",
    "aceráveis": "acerar",
    "acerífera": "acerífero",
    "aceríferas": "acerífero",
    "aceríferos": "acerífero",
    "acerínea": "aceríneo",
    "aceríneas": "aceríneo",
    "aceríneos": "aceríneo",
    "acesa": "aceso",
    "acesas": "aceso",
    "acescentes": "acescente",
    "acescências": "acescência",
    "acesoa": "acesoar",
    "acesoada": "acesoar",
    "acesoadas": "acesoar",
    "acesoado": "acesoar",
    "acesoados": "acesoar",
    "acesoai": "acesoar",
    "acesoais": "acesoar",
    "acesoam": "acesoar",
    "acesoamo": "acesoar",
    "acesoamos": "acesoar",
    "acesoando": "acesoar",
    "acesoara": "acesoar",
    "acesoaram": "acesoar",
    "acesoaras": "acesoar",
    "acesoarde": "acesoar",
    "acesoardes": "acesoar",
    "acesoare": "acesoar",
    "acesoarei": "acesoar",
    "acesoareis": "acesoar",
    "acesoarem": "acesoar",
    "acesoaremos": "acesoar",
    "acesoares": "acesoar",
    "acesoaria": "acesoar",
    "acesoariam": "acesoar",
    "acesoarias": "acesoar",
    "acesoarmo": "acesoar",
    "acesoarmos": "acesoar",
    "acesoará": "acesoar",
    "acesoarás": "acesoar",
    "acesoarão": "acesoar",
    "acesoaríamos": "acesoar",
    "acesoaríeis": "acesoar",
    "acesoas": "acesoar",
    "acesoasse": "acesoar",
    "acesoassem": "acesoar",
    "acesoasses": "acesoar",
    "acesoaste": "acesoar",
    "acesoastes": "acesoar",
    "acesoava": "acesoar",
    "acesoavam": "acesoar",
    "acesoavas": "acesoar",
    "acesoe": "acesoar",
    "acesoei": "acesoar",
    "acesoeis": "acesoar",
    "acesoem": "acesoar",
    "acesoemo": "acesoar",
    "acesoemos": "acesoar",
    "acesoes": "acesoar",
    "acesoo": "acesoar",
    "acesoou": "acesoar",
    "acesos": "aceso",
    "acesoá": "acesoar",
    "acesoámo": "acesoar",
    "acesoámos": "acesoar",
    "acesoáramo": "acesoar",
    "acesoáramos": "acesoar",
    "acesoárei": "acesoar",
    "acesoáreis": "acesoar",
    "acesoásseis": "acesoar",
    "acesoássemos": "acesoar",
    "acesoávamo": "acesoar",
    "acesoávamos": "acesoar",
    "acesoávei": "acesoar",
    "acesoáveis": "acesoar",
    "acessibilidades": "acessibilidade",
    "acessionais": "acessional",
    "acessorada": "acessorado",
    "acessoradas": "acessorado",
    "acessorados": "acessorado",
    "acessoristas": "acessorista",
    "acessos": "acesso",
    "acessíveis": "acessível",
    "acessória": "acessório",
    "acessórias": "acessório",
    "acessórios": "acessório",
    "acessões": "acessão",
    "acesumes": "acesume",
    "aceta": "acetar",
    "acetabulárias": "acetabulária",
    "acetabulífera": "acetabulífero",
    "acetabulíferas": "acetabulífero",
    "acetabulíferos": "acetabulífero",
    "acetada": "acetar",
    "acetadas": "acetar",
    "acetado": "acetar",
    "acetados": "acetar",
    "acetai": "acetar",
    "acetais": "acetar",
    "acetam": "acetar",
    "acetamidas": "acetamida",
    "acetamo": "acetar",
    "acetamos": "acetar",
    "acetando": "acetar",
    "acetara": "acetar",
    "acetaram": "acetar",
    "acetaras": "acetar",
    "acetarde": "acetar",
    "acetardes": "acetar",
    "acetare": "acetar",
    "acetarei": "acetar",
    "acetareis": "acetar",
    "acetarem": "acetar",
    "acetaremos": "acetar",
    "acetares": "acetar",
    "acetaria": "acetar",
    "acetariam": "acetar",
    "acetarias": "acetar",
    "acetarmo": "acetar",
    "acetarmos": "acetar",
    "acetará": "acetar",
    "acetarás": "acetar",
    "acetarão": "acetar",
    "acetaríamos": "acetar",
    "acetaríeis": "acetar",
    "acetas": "acetar",
    "acetasse": "acetar",
    "acetassem": "acetar",
    "acetasses": "acetar",
    "acetaste": "acetar",
    "acetastes": "acetar",
    "acetatos": "acetato",
    "acetava": "acetar",
    "acetavam": "acetar",
    "acetavas": "acetar",
    "acete": "acetar",
    "acetei": "acetar",
    "aceteis": "acetar",
    "acetem": "acetar",
    "acetemo": "acetar",
    "acetemos": "acetar",
    "acetes": "acetar",
    "acetidinas": "acetidina",
    "acetifica": "acetificar",
    "acetificada": "acetificar",
    "acetificadas": "acetificar",
    "acetificado": "acetificar",
    "acetificadora": "acetificador",
    "acetificadoras": "acetificador",
    "acetificadores": "acetificador",
    "acetificados": "acetificar",
    "acetificai": "acetificar",
    "acetificais": "acetificar",
    "acetificam": "acetificar",
    "acetificamo": "acetificar",
    "acetificamos": "acetificar",
    "acetificando": "acetificar",
    "acetificara": "acetificar",
    "acetificaram": "acetificar",
    "acetificaras": "acetificar",
    "acetificarde": "acetificar",
    "acetificardes": "acetificar",
    "acetificare": "acetificar",
    "acetificarei": "acetificar",
    "acetificareis": "acetificar",
    "acetificarem": "acetificar",
    "acetificaremos": "acetificar",
    "acetificares": "acetificar",
    "acetificaria": "acetificar",
    "acetificariam": "acetificar",
    "acetificarias": "acetificar",
    "acetificarmo": "acetificar",
    "acetificarmos": "acetificar",
    "acetificará": "acetificar",
    "acetificarás": "acetificar",
    "acetificarão": "acetificar",
    "acetificaríamos": "acetificar",
    "acetificaríeis": "acetificar",
    "acetificas": "acetificar",
    "acetificasse": "acetificar",
    "acetificassem": "acetificar",
    "acetificasses": "acetificar",
    "acetificaste": "acetificar",
    "acetificastes": "acetificar",
    "acetificava": "acetificar",
    "acetificavam": "acetificar",
    "acetificavas": "acetificar",
    "acetificações": "acetificação",
    "acetifico": "acetificar",
    "acetificou": "acetificar",
    "acetificá": "acetificar",
    "acetificámo": "acetificar",
    "acetificámos": "acetificar",
    "acetificáramo": "acetificar",
    "acetificáramos": "acetificar",
    "acetificárei": "acetificar",
    "acetificáreis": "acetificar",
    "acetificásseis": "acetificar",
    "acetificássemos": "acetificar",
    "acetificávamo": "acetificar",
    "acetificávamos": "acetificar",
    "acetificávei": "acetificar",
    "acetificáveis": "acetificar",
    "acetifique": "acetificar",
    "acetifiquei": "acetificar",
    "acetifiqueis": "acetificar",
    "acetifiquem": "acetificar",
    "acetifiquemo": "acetificar",
    "acetifiquemos": "acetificar",
    "acetifiques": "acetificar",
    "acetilenos": "acetileno",
    "acetiletos": "acetileto",
    "acetilsalicilatos": "acetilsalicilato",
    "acetilsalicílicos": "acetilsalicílico",
    "acetilénica": "acetilénico",
    "acetilénicas": "acetilénico",
    "acetilénicos": "acetilénico",
    "acetimétricos": "acetimétrico",
    "acetina": "acetinar",
    "acetinada": "acetinar",
    "acetinadas": "acetinar",
    "acetinado": "acetinar",
    "acetinadora": "acetinador",
    "acetinadoras": "acetinador",
    "acetinadores": "acetinador",
    "acetinados": "acetinar",
    "acetinagens": "acetinagem",
    "acetinai": "acetinar",
    "acetinais": "acetinar",
    "acetinam": "acetinar",
    "acetinamo": "acetinar",
    "acetinamos": "acetinar",
    "acetinando": "acetinar",
    "acetinara": "acetinar",
    "acetinaram": "acetinar",
    "acetinaras": "acetinar",
    "acetinarde": "acetinar",
    "acetinardes": "acetinar",
    "acetinare": "acetinar",
    "acetinarei": "acetinar",
    "acetinareis": "acetinar",
    "acetinarem": "acetinar",
    "acetinaremos": "acetinar",
    "acetinares": "acetinar",
    "acetinaria": "acetinar",
    "acetinariam": "acetinar",
    "acetinarias": "acetinar",
    "acetinarmo": "acetinar",
    "acetinarmos": "acetinar",
    "acetinará": "acetinar",
    "acetinarás": "acetinar",
    "acetinarão": "acetinar",
    "acetinaríamos": "acetinar",
    "acetinaríeis": "acetinar",
    "acetinas": "acetinar",
    "acetinasse": "acetinar",
    "acetinassem": "acetinar",
    "acetinasses": "acetinar",
    "acetinaste": "acetinar",
    "acetinastes": "acetinar",
    "acetinava": "acetinar",
    "acetinavam": "acetinar",
    "acetinavas": "acetinar",
    "acetinações": "acetinação",
    "acetine": "acetinar",
    "acetinei": "acetinar",
    "acetineis": "acetinar",
    "acetinem": "acetinar",
    "acetinemo": "acetinar",
    "acetinemos": "acetinar",
    "acetines": "acetinar",
    "acetino": "acetinar",
    "acetinou": "acetinar",
    "acetiná": "acetinar",
    "acetinámo": "acetinar",
    "acetinámos": "acetinar",
    "acetináramo": "acetinar",
    "acetináramos": "acetinar",
    "acetinárei": "acetinar",
    "acetináreis": "acetinar",
    "acetinásseis": "acetinar",
    "acetinássemos": "acetinar",
    "acetinávamo": "acetinar",
    "acetinávamos": "acetinar",
    "acetinávei": "acetinar",
    "acetináveis": "acetinar",
    "aceto": "acetar",
    "acetonas": "acetona",
    "acetonemias": "acetonemia",
    "acetonitrilos": "acetonitrilo",
    "acetonúrias": "acetonúria",
    "acetosa": "acetoso",
    "acetosas": "acetoso",
    "acetosidades": "acetosidade",
    "acetosos": "acetoso",
    "acetou": "acetar",
    "acetoxídases": "acetoxídase",
    "acetá": "acetar",
    "acetábuliformes": "acetábuliforme",
    "acetábulos": "acetábulo",
    "acetámo": "acetar",
    "acetámos": "acetar",
    "acetáramo": "acetar",
    "acetáramos": "acetar",
    "acetárei": "acetar",
    "acetáreis": "acetar",
    "acetásseis": "acetar",
    "acetássemos": "acetar",
    "acetávamo": "acetar",
    "acetávamos": "acetar",
    "acetávei": "acetar",
    "acetáveis": "acetar",
    "acetímetros": "acetímetro",
    "acetóis": "acetol",
    "acetómetros": "acetómetro",
    "acevada": "acevadar",
    "acevadada": "acevadar",
    "acevadadas": "acevadar",
    "acevadado": "acevadar",
    "acevadados": "acevadar",
    "acevadai": "acevadar",
    "acevadais": "acevadar",
    "acevadam": "acevadar",
    "acevadamo": "acevadar",
    "acevadamos": "acevadar",
    "acevadando": "acevadar",
    "acevadara": "acevadar",
    "acevadaram": "acevadar",
    "acevadaras": "acevadar",
    "acevadarde": "acevadar",
    "acevadardes": "acevadar",
    "acevadare": "acevadar",
    "acevadarei": "acevadar",
    "acevadareis": "acevadar",
    "acevadarem": "acevadar",
    "acevadaremos": "acevadar",
    "acevadares": "acevadar",
    "acevadaria": "acevadar",
    "acevadariam": "acevadar",
    "acevadarias": "acevadar",
    "acevadarmo": "acevadar",
    "acevadarmos": "acevadar",
    "acevadará": "acevadar",
    "acevadarás": "acevadar",
    "acevadarão": "acevadar",
    "acevadaríamos": "acevadar",
    "acevadaríeis": "acevadar",
    "acevadas": "acevadar",
    "acevadasse": "acevadar",
    "acevadassem": "acevadar",
    "acevadasses": "acevadar",
    "acevadaste": "acevadar",
    "acevadastes": "acevadar",
    "acevadava": "acevadar",
    "acevadavam": "acevadar",
    "acevadavas": "acevadar",
    "acevade": "acevadar",
    "acevadei": "acevadar",
    "acevadeis": "acevadar",
    "acevadem": "acevadar",
    "acevademo": "acevadar",
    "acevademos": "acevadar",
    "acevades": "acevadar",
    "acevado": "acevadar",
    "acevadou": "acevadar",
    "acevadá": "acevadar",
    "acevadámo": "acevadar",
    "acevadámos": "acevadar",
    "acevadáramo": "acevadar",
    "acevadáramos": "acevadar",
    "acevadárei": "acevadar",
    "acevadáreis": "acevadar",
    "acevadásseis": "acevadar",
    "acevadássemos": "acevadar",
    "acevadávamo": "acevadar",
    "acevadávamos": "acevadar",
    "acevadávei": "acevadar",
    "acevadáveis": "acevadar",
    "acha": "achar",
    "achaboucada": "achaboucado",
    "achaboucadas": "achaboucado",
    "achaboucados": "achaboucado",
    "achaca": "achacar",
    "achacada": "achacar",
    "achacadas": "achacar",
    "achacadiça": "achacadiço",
    "achacadiças": "achacadiço",
    "achacadiços": "achacadiço",
    "achacado": "achacar",
    "achacados": "achacar",
    "achacadíssima": "achacado",
    "achacadíssimas": "achacado",
    "achacadíssimo": "achacado",
    "achacadíssimos": "achacado",
    "achacai": "achacar",
    "achacais": "achacar",
    "achacam": "achacar",
    "achacamo": "achacar",
    "achacamos": "achacar",
    "achacando": "achacar",
    "achacara": "achacar",
    "achacaram": "achacar",
    "achacaras": "achacar",
    "achacarde": "achacar",
    "achacardes": "achacar",
    "achacare": "achacar",
    "achacarei": "achacar",
    "achacareis": "achacar",
    "achacarem": "achacar",
    "achacaremos": "achacar",
    "achacares": "achacar",
    "achacaria": "achacar",
    "achacariam": "achacar",
    "achacarias": "achacar",
    "achacarmo": "achacar",
    "achacarmos": "achacar",
    "achacará": "achacar",
    "achacarás": "achacar",
    "achacarão": "achacar",
    "achacaríamos": "achacar",
    "achacaríeis": "achacar",
    "achacas": "achacar",
    "achacasse": "achacar",
    "achacassem": "achacar",
    "achacasses": "achacar",
    "achacaste": "achacar",
    "achacastes": "achacar",
    "achacava": "achacar",
    "achacavam": "achacar",
    "achacavas": "achacar",
    "achaco": "achacar",
    "achacosa": "achacoso",
    "achacosas": "achacoso",
    "achacosos": "achacoso",
    "achacou": "achacar",
    "achacá": "achacar",
    "achacámo": "achacar",
    "achacámos": "achacar",
    "achacáramo": "achacar",
    "achacáramos": "achacar",
    "achacárei": "achacar",
    "achacáreis": "achacar",
    "achacásseis": "achacar",
    "achacássemos": "achacar",
    "achacávamo": "achacar",
    "achacávamos": "achacar",
    "achacávei": "achacar",
    "achacáveis": "achacar",
    "achada": "achar",
    "achadas": "achar",
    "achadiça": "achadiço",
    "achadiças": "achadiço",
    "achadiços": "achadiço",
    "achado": "achar",
    "achadoiros": "achadoiro",
    "achadora": "achador",
    "achadoras": "achador",
    "achadores": "achador",
    "achados": "achar",
    "achadouros": "achadouro",
    "achadões": "achadão",
    "achai": "achar",
    "achais": "achar",
    "achalezada": "achalezado",
    "achalezadas": "achalezado",
    "achalezados": "achalezado",
    "acham": "achar",
    "achamalotada": "achamalotado",
    "achamalotadas": "achamalotado",
    "achamalotados": "achamalotado",
    "achamboa": "achamboar",
    "achamboada": "achamboar",
    "achamboadas": "achamboar",
    "achamboado": "achamboar",
    "achamboados": "achamboar",
    "achamboai": "achamboar",
    "achamboais": "achamboar",
    "achamboam": "achamboar",
    "achamboamo": "achamboar",
    "achamboamos": "achamboar",
    "achamboando": "achamboar",
    "achamboara": "achamboar",
    "achamboaram": "achamboar",
    "achamboaras": "achamboar",
    "achamboarde": "achamboar",
    "achamboardes": "achamboar",
    "achamboare": "achamboar",
    "achamboarei": "achamboar",
    "achamboareis": "achamboar",
    "achamboarem": "achamboar",
    "achamboaremos": "achamboar",
    "achamboares": "achamboar",
    "achamboaria": "achamboar",
    "achamboariam": "achamboar",
    "achamboarias": "achamboar",
    "achamboarmo": "achamboar",
    "achamboarmos": "achamboar",
    "achamboará": "achamboar",
    "achamboarás": "achamboar",
    "achamboarão": "achamboar",
    "achamboaríamos": "achamboar",
    "achamboaríeis": "achamboar",
    "achamboas": "achamboar",
    "achamboasse": "achamboar",
    "achamboassem": "achamboar",
    "achamboasses": "achamboar",
    "achamboaste": "achamboar",
    "achamboastes": "achamboar",
    "achamboava": "achamboar",
    "achamboavam": "achamboar",
    "achamboavas": "achamboar",
    "achamboe": "achamboar",
    "achamboei": "achamboar",
    "achamboeis": "achamboar",
    "achamboem": "achamboar",
    "achamboemo": "achamboar",
    "achamboemos": "achamboar",
    "achamboes": "achamboar",
    "achamboo": "achamboar",
    "achamboou": "achamboar",
    "achamboá": "achamboar",
    "achamboámo": "achamboar",
    "achamboámos": "achamboar",
    "achamboáramo": "achamboar",
    "achamboáramos": "achamboar",
    "achamboárei": "achamboar",
    "achamboáreis": "achamboar",
    "achamboásseis": "achamboar",
    "achamboássemos": "achamboar",
    "achamboávamo": "achamboar",
    "achamboávamos": "achamboar",
    "achamboávei": "achamboar",
    "achamboáveis": "achamboar",
    "achamentos": "achamento",
    "achamo": "achar",
    "achamorrada": "achamorrado",
    "achamorradas": "achamorrado",
    "achamorrados": "achamorrado",
    "achamos": "achar",
    "achana": "achanar",
    "achanada": "achanar",
    "achanadas": "achanar",
    "achanado": "achanar",
    "achanados": "achanar",
    "achanai": "achanar",
    "achanais": "achanar",
    "achanam": "achanar",
    "achanamo": "achanar",
    "achanamos": "achanar",
    "achanando": "achanar",
    "achanara": "achanar",
    "achanaram": "achanar",
    "achanaras": "achanar",
    "achanarde": "achanar",
    "achanardes": "achanar",
    "achanare": "achanar",
    "achanarei": "achanar",
    "achanareis": "achanar",
    "achanarem": "achanar",
    "achanaremos": "achanar",
    "achanares": "achanar",
    "achanaria": "achanar",
    "achanariam": "achanar",
    "achanarias": "achanar",
    "achanarmo": "achanar",
    "achanarmos": "achanar",
    "achanará": "achanar",
    "achanarás": "achanar",
    "achanarão": "achanar",
    "achanaríamos": "achanar",
    "achanaríeis": "achanar",
    "achanas": "achanar",
    "achanasse": "achanar",
    "achanassem": "achanar",
    "achanasses": "achanar",
    "achanaste": "achanar",
    "achanastes": "achanar",
    "achanava": "achanar",
    "achanavam": "achanar",
    "achanavas": "achanar",
    "achando": "achar",
    "achane": "achanar",
    "achanei": "achanar",
    "achaneis": "achanar",
    "achanem": "achanar",
    "achanemo": "achanar",
    "achanemos": "achanar",
    "achanes": "achanar",
    "achano": "achanar",
    "achanou": "achanar",
    "achaná": "achanar",
    "achanámo": "achanar",
    "achanámos": "achanar",
    "achanáramo": "achanar",
    "achanáramos": "achanar",
    "achanárei": "achanar",
    "achanáreis": "achanar",
    "achanásseis": "achanar",
    "achanássemos": "achanar",
    "achanávamo": "achanar",
    "achanávamos": "achanar",
    "achanávei": "achanar",
    "achanáveis": "achanar",
    "achaparados": "achaparado",
    "achaparra": "achaparrar",
    "achaparrada": "achaparrar",
    "achaparradas": "achaparrar",
    "achaparrado": "achaparrar",
    "achaparrados": "achaparrar",
    "achaparrai": "achaparrar",
    "achaparrais": "achaparrar",
    "achaparram": "achaparrar",
    "achaparramo": "achaparrar",
    "achaparramos": "achaparrar",
    "achaparrando": "achaparrar",
    "achaparrara": "achaparrar",
    "achaparraram": "achaparrar",
    "achaparraras": "achaparrar",
    "achaparrarde": "achaparrar",
    "achaparrardes": "achaparrar",
    "achaparrare": "achaparrar",
    "achaparrarei": "achaparrar",
    "achaparrareis": "achaparrar",
    "achaparrarem": "achaparrar",
    "achaparraremos": "achaparrar",
    "achaparrares": "achaparrar",
    "achaparraria": "achaparrar",
    "achaparrariam": "achaparrar",
    "achaparrarias": "achaparrar",
    "achaparrarmo": "achaparrar",
    "achaparrarmos": "achaparrar",
    "achaparrará": "achaparrar",
    "achaparrarás": "achaparrar",
    "achaparrarão": "achaparrar",
    "achaparraríamos": "achaparrar",
    "achaparraríeis": "achaparrar",
    "achaparras": "achaparrar",
    "achaparrasse": "achaparrar",
    "achaparrassem": "achaparrar",
    "achaparrasses": "achaparrar",
    "achaparraste": "achaparrar",
    "achaparrastes": "achaparrar",
    "achaparrava": "achaparrar",
    "achaparravam": "achaparrar",
    "achaparravas": "achaparrar",
    "achaparre": "achaparrar",
    "achaparrei": "achaparrar",
    "achaparreis": "achaparrar",
    "achaparrem": "achaparrar",
    "achaparremo": "achaparrar",
    "achaparremos": "achaparrar",
    "achaparres": "achaparrar",
    "achaparro": "achaparrar",
    "achaparrou": "achaparrar",
    "achaparrá": "achaparrar",
    "achaparrámo": "achaparrar",
    "achaparrámos": "achaparrar",
    "achaparráramo": "achaparrar",
    "achaparráramos": "achaparrar",
    "achaparrárei": "achaparrar",
    "achaparráreis": "achaparrar",
    "achaparrásseis": "achaparrar",
    "achaparrássemos": "achaparrar",
    "achaparrávamo": "achaparrar",
    "achaparrávamos": "achaparrar",
    "achaparrávei": "achaparrar",
    "achaparráveis": "achaparrar",
    "achaque": "achacar",
    "achaquei": "achacar",
    "achaqueiras": "achaqueira",
    "achaqueis": "achacar",
    "achaquem": "achacar",
    "achaquemo": "achacar",
    "achaquemos": "achacar",
    "achaquenta": "achaquento",
    "achaquentas": "achaquento",
    "achaquentos": "achaquento",
    "achaques": "achaque",
    "achaquilhos": "achaquilho",
    "achara": "achar",
    "acharam": "achar",
    "acharas": "achar",
    "acharde": "achar",
    "achardes": "achar",
    "achare": "achar",
    "acharei": "achar",
    "achareis": "achar",
    "acharem": "achar",
    "acharemos": "achar",
    "achares": "achar",
    "acharia": "achar",
    "achariam": "achar",
    "acharias": "achar",
    "acharmo": "achar",
    "acharmos": "achar",
    "acharoa": "acharoar",
    "acharoada": "acharoar",
    "acharoadas": "acharoar",
    "acharoado": "acharoar",
    "acharoados": "acharoar",
    "acharoai": "acharoar",
    "acharoais": "acharoar",
    "acharoam": "acharoar",
    "acharoamo": "acharoar",
    "acharoamos": "acharoar",
    "acharoando": "acharoar",
    "acharoara": "acharoar",
    "acharoaram": "acharoar",
    "acharoaras": "acharoar",
    "acharoarde": "acharoar",
    "acharoardes": "acharoar",
    "acharoare": "acharoar",
    "acharoarei": "acharoar",
    "acharoareis": "acharoar",
    "acharoarem": "acharoar",
    "acharoaremos": "acharoar",
    "acharoares": "acharoar",
    "acharoaria": "acharoar",
    "acharoariam": "acharoar",
    "acharoarias": "acharoar",
    "acharoarmo": "acharoar",
    "acharoarmos": "acharoar",
    "acharoará": "acharoar",
    "acharoarás": "acharoar",
    "acharoarão": "acharoar",
    "acharoaríamos": "acharoar",
    "acharoaríeis": "acharoar",
    "acharoas": "acharoar",
    "acharoasse": "acharoar",
    "acharoassem": "acharoar",
    "acharoasses": "acharoar",
    "acharoaste": "acharoar",
    "acharoastes": "acharoar",
    "acharoava": "acharoar",
    "acharoavam": "acharoar",
    "acharoavas": "acharoar",
    "acharoe": "acharoar",
    "acharoei": "acharoar",
    "acharoeis": "acharoar",
    "acharoem": "acharoar",
    "acharoemo": "acharoar",
    "acharoemos": "acharoar",
    "acharoes": "acharoar",
    "acharoo": "acharoar",
    "acharoou": "acharoar",
    "acharoá": "acharoar",
    "acharoámo": "acharoar",
    "acharoámos": "acharoar",
    "acharoáramo": "acharoar",
    "acharoáramos": "acharoar",
    "acharoárei": "acharoar",
    "acharoáreis": "acharoar",
    "acharoásseis": "acharoar",
    "acharoássemos": "acharoar",
    "acharoávamo": "acharoar",
    "acharoávamos": "acharoar",
    "acharoávei": "acharoar",
    "acharoáveis": "acharoar",
    "achará": "achar",
    "acharás": "achar",
    "acharão": "achar",
    "acharíamos": "achar",
    "acharíeis": "achar",
    "achas": "achar",
    "achasse": "achar",
    "achassem": "achar",
    "achasses": "achar",
    "achaste": "achar",
    "achastes": "achar",
    "achata": "achatar",
    "achatada": "achatar",
    "achatadas": "achatar",
    "achatadelas": "achatadela",
    "achatado": "achatar",
    "achatados": "achatar",
    "achataduras": "achatadura",
    "achatai": "achatar",
    "achatais": "achatar",
    "achatam": "achatar",
    "achatamentos": "achatamento",
    "achatamo": "achatar",
    "achatamos": "achatar",
    "achatando": "achatar",
    "achatara": "achatar",
    "achataram": "achatar",
    "achataras": "achatar",
    "achatarde": "achatar",
    "achatardes": "achatar",
    "achatare": "achatar",
    "achatarei": "achatar",
    "achatareis": "achatar",
    "achatarem": "achatar",
    "achataremos": "achatar",
    "achatares": "achatar",
    "achataria": "achatar",
    "achatariam": "achatar",
    "achatarias": "achatar",
    "achatarmo": "achatar",
    "achatarmos": "achatar",
    "achatará": "achatar",
    "achatarás": "achatar",
    "achatarão": "achatar",
    "achataríamos": "achatar",
    "achataríeis": "achatar",
    "achatas": "achatar",
    "achatasse": "achatar",
    "achatassem": "achatar",
    "achatasses": "achatar",
    "achataste": "achatar",
    "achatastes": "achatar",
    "achatava": "achatar",
    "achatavam": "achatar",
    "achatavas": "achatar",
    "achate": "achatar",
    "achatei": "achatar",
    "achateis": "achatar",
    "achatem": "achatar",
    "achatemo": "achatar",
    "achatemos": "achatar",
    "achates": "achatar",
    "achato": "achatar",
    "achatou": "achatar",
    "achatá": "achatar",
    "achatámo": "achatar",
    "achatámos": "achatar",
    "achatáramo": "achatar",
    "achatáramos": "achatar",
    "achatárei": "achatar",
    "achatáreis": "achatar",
    "achatásseis": "achatar",
    "achatássemos": "achatar",
    "achatávamo": "achatar",
    "achatávamos": "achatar",
    "achatávei": "achatar",
    "achatáveis": "achatar",
    "achava": "achar",
    "achavam": "achar",
    "achavas": "achar",
    "achavasca": "achavascar",
    "achavascada": "achavascar",
    "achavascadas": "achavascar",
    "achavascadazinha": "achavascado",
    "achavascadazinhas": "achavascado",
    "achavascadazita": "achavascado",
    "achavascadazitas": "achavascado",
    "achavascadinha": "achavascado",
    "achavascadinhas": "achavascado",
    "achavascadinho": "achavascado",
    "achavascadinhos": "achavascado",
    "achavascadita": "achavascado",
    "achavascaditas": "achavascado",
    "achavascadito": "achavascado",
    "achavascaditos": "achavascado",
    "achavascado": "achavascar",
    "achavascados": "achavascar",
    "achavascadozinho": "achavascado",
    "achavascadozinhos": "achavascado",
    "achavascadozito": "achavascado",
    "achavascadozitos": "achavascado",
    "achavascai": "achavascar",
    "achavascais": "achavascar",
    "achavascam": "achavascar",
    "achavascamo": "achavascar",
    "achavascamos": "achavascar",
    "achavascando": "achavascar",
    "achavascara": "achavascar",
    "achavascaram": "achavascar",
    "achavascaras": "achavascar",
    "achavascarde": "achavascar",
    "achavascardes": "achavascar",
    "achavascare": "achavascar",
    "achavascarei": "achavascar",
    "achavascareis": "achavascar",
    "achavascarem": "achavascar",
    "achavascaremos": "achavascar",
    "achavascares": "achavascar",
    "achavascaria": "achavascar",
    "achavascariam": "achavascar",
    "achavascarias": "achavascar",
    "achavascarmo": "achavascar",
    "achavascarmos": "achavascar",
    "achavascará": "achavascar",
    "achavascarás": "achavascar",
    "achavascarão": "achavascar",
    "achavascaríamos": "achavascar",
    "achavascaríeis": "achavascar",
    "achavascas": "achavascar",
    "achavascasse": "achavascar",
    "achavascassem": "achavascar",
    "achavascasses": "achavascar",
    "achavascaste": "achavascar",
    "achavascastes": "achavascar",
    "achavascava": "achavascar",
    "achavascavam": "achavascar",
    "achavascavas": "achavascar",
    "achavasco": "achavascar",
    "achavascou": "achavascar",
    "achavascá": "achavascar",
    "achavascámo": "achavascar",
    "achavascámos": "achavascar",
    "achavascáramo": "achavascar",
    "achavascáramos": "achavascar",
    "achavascárei": "achavascar",
    "achavascáreis": "achavascar",
    "achavascásseis": "achavascar",
    "achavascássemos": "achavascar",
    "achavascávamo": "achavascar",
    "achavascávamos": "achavascar",
    "achavascávei": "achavascar",
    "achavascáveis": "achavascar",
    "achavasque": "achavascar",
    "achavasquei": "achavascar",
    "achavasqueis": "achavascar",
    "achavasquem": "achavascar",
    "achavasquemo": "achavascar",
    "achavasquemos": "achavascar",
    "achavasques": "achavascar",
    "ache": "achar",
    "achega": "achegar",
    "achegada": "achegar",
    "achegadas": "achegar",
    "achegadazinha": "achegado",
    "achegadazinhas": "achegado",
    "achegadazita": "achegado",
    "achegadazitas": "achegado",
    "achegadeiras": "achegadeira",
    "achegadinha": "achegado",
    "achegadinhas": "achegado",
    "achegadinho": "achegado",
    "achegadinhos": "achegado",
    "achegadita": "achegado",
    "achegaditas": "achegado",
    "achegadito": "achegado",
    "achegaditos": "achegado",
    "achegado": "achegar",
    "achegadora": "achegador",
    "achegadoras": "achegador",
    "achegadores": "achegador",
    "achegados": "achegar",
    "achegadozinho": "achegado",
    "achegadozinhos": "achegado",
    "achegadozito": "achegado",
    "achegadozitos": "achegado",
    "achegai": "achegar",
    "achegais": "achegar",
    "achegam": "achegar",
    "achegamentos": "achegamento",
    "achegamo": "achegar",
    "achegamos": "achegar",
    "achegando": "achegar",
    "achegara": "achegar",
    "achegaram": "achegar",
    "achegaras": "achegar",
    "achegarde": "achegar",
    "achegardes": "achegar",
    "achegare": "achegar",
    "achegarei": "achegar",
    "achegareis": "achegar",
    "achegarem": "achegar",
    "achegaremos": "achegar",
    "achegares": "achegar",
    "achegaria": "achegar",
    "achegariam": "achegar",
    "achegarias": "achegar",
    "achegarmo": "achegar",
    "achegarmos": "achegar",
    "achegará": "achegar",
    "achegarás": "achegar",
    "achegarão": "achegar",
    "achegaríamos": "achegar",
    "achegaríeis": "achegar",
    "achegas": "achegar",
    "achegasse": "achegar",
    "achegassem": "achegar",
    "achegasses": "achegar",
    "achegaste": "achegar",
    "achegastes": "achegar",
    "achegava": "achegar",
    "achegavam": "achegar",
    "achegavas": "achegar",
    "achego": "achegar",
    "achegos": "achego",
    "achegou": "achegar",
    "achegue": "achegar",
    "acheguei": "achegar",
    "achegueis": "achegar",
    "acheguem": "achegar",
    "acheguemo": "achegar",
    "acheguemos": "achegar",
    "achegues": "achegar",
    "acheguilhos": "acheguilho",
    "achegá": "achegar",
    "achegámo": "achegar",
    "achegámos": "achegar",
    "achegáramo": "achegar",
    "achegáramos": "achegar",
    "achegárei": "achegar",
    "achegáreis": "achegar",
    "achegásseis": "achegar",
    "achegássemos": "achegar",
    "achegávamo": "achegar",
    "achegávamos": "achegar",
    "achegávei": "achegar",
    "achegáveis": "achegar",
    "achei": "achar",
    "acheis": "achar",
    "achem": "achar",
    "achemo": "achar",
    "achemos": "achar",
    "aches": "ache",
    "achibanta": "achibantar",
    "achibantada": "achibantar",
    "achibantadas": "achibantar",
    "achibantado": "achibantar",
    "achibantados": "achibantar",
    "achibantai": "achibantar",
    "achibantais": "achibantar",
    "achibantam": "achibantar",
    "achibantamo": "achibantar",
    "achibantamos": "achibantar",
    "achibantando": "achibantar",
    "achibantara": "achibantar",
    "achibantaram": "achibantar",
    "achibantaras": "achibantar",
    "achibantarde": "achibantar",
    "achibantardes": "achibantar",
    "achibantare": "achibantar",
    "achibantarei": "achibantar",
    "achibantareis": "achibantar",
    "achibantarem": "achibantar",
    "achibantaremos": "achibantar",
    "achibantares": "achibantar",
    "achibantaria": "achibantar",
    "achibantariam": "achibantar",
    "achibantarias": "achibantar",
    "achibantarmo": "achibantar",
    "achibantarmos": "achibantar",
    "achibantará": "achibantar",
    "achibantarás": "achibantar",
    "achibantarão": "achibantar",
    "achibantaríamos": "achibantar",
    "achibantaríeis": "achibantar",
    "achibantas": "achibantar",
    "achibantasse": "achibantar",
    "achibantassem": "achibantar",
    "achibantasses": "achibantar",
    "achibantaste": "achibantar",
    "achibantastes": "achibantar",
    "achibantava": "achibantar",
    "achibantavam": "achibantar",
    "achibantavas": "achibantar",
    "achibante": "achibantar",
    "achibantei": "achibantar",
    "achibanteis": "achibantar",
    "achibantem": "achibantar",
    "achibantemo": "achibantar",
    "achibantemos": "achibantar",
    "achibantes": "achibantar",
    "achibanto": "achibantar",
    "achibantou": "achibantar",
    "achibantá": "achibantar",
    "achibantámo": "achibantar",
    "achibantámos": "achibantar",
    "achibantáramo": "achibantar",
    "achibantáramos": "achibantar",
    "achibantárei": "achibantar",
    "achibantáreis": "achibantar",
    "achibantásseis": "achibantar",
    "achibantássemos": "achibantar",
    "achibantávamo": "achibantar",
    "achibantávamos": "achibantar",
    "achibantávei": "achibantar",
    "achibantáveis": "achibantar",
    "achica": "achicar",
    "achicada": "achicar",
    "achicadas": "achicar",
    "achicado": "achicar",
    "achicadora": "achicador",
    "achicadoras": "achicador",
    "achicadores": "achicador",
    "achicados": "achicar",
    "achicaduras": "achicadura",
    "achicai": "achicar",
    "achicais": "achicar",
    "achicam": "achicar",
    "achicamo": "achicar",
    "achicamos": "achicar",
    "achicana": "achicanar",
    "achicanada": "achicanar",
    "achicanadas": "achicanar",
    "achicanado": "achicanar",
    "achicanados": "achicanar",
    "achicanai": "achicanar",
    "achicanais": "achicanar",
    "achicanam": "achicanar",
    "achicanamo": "achicanar",
    "achicanamos": "achicanar",
    "achicanando": "achicanar",
    "achicanara": "achicanar",
    "achicanaram": "achicanar",
    "achicanaras": "achicanar",
    "achicanarde": "achicanar",
    "achicanardes": "achicanar",
    "achicanare": "achicanar",
    "achicanarei": "achicanar",
    "achicanareis": "achicanar",
    "achicanarem": "achicanar",
    "achicanaremos": "achicanar",
    "achicanares": "achicanar",
    "achicanaria": "achicanar",
    "achicanariam": "achicanar",
    "achicanarias": "achicanar",
    "achicanarmo": "achicanar",
    "achicanarmos": "achicanar",
    "achicanará": "achicanar",
    "achicanarás": "achicanar",
    "achicanarão": "achicanar",
    "achicanaríamos": "achicanar",
    "achicanaríeis": "achicanar",
    "achicanas": "achicanar",
    "achicanasse": "achicanar",
    "achicanassem": "achicanar",
    "achicanasses": "achicanar",
    "achicanaste": "achicanar",
    "achicanastes": "achicanar",
    "achicanava": "achicanar",
    "achicanavam": "achicanar",
    "achicanavas": "achicanar",
    "achicando": "achicar",
    "achicane": "achicanar",
    "achicanei": "achicanar",
    "achicaneis": "achicanar",
    "achicanem": "achicanar",
    "achicanemo": "achicanar",
    "achicanemos": "achicanar",
    "achicanes": "achicanar",
    "achicano": "achicanar",
    "achicanou": "achicanar",
    "achicaná": "achicanar",
    "achicanámo": "achicanar",
    "achicanámos": "achicanar",
    "achicanáramo": "achicanar",
    "achicanáramos": "achicanar",
    "achicanárei": "achicanar",
    "achicanáreis": "achicanar",
    "achicanásseis": "achicanar",
    "achicanássemos": "achicanar",
    "achicanávamo": "achicanar",
    "achicanávamos": "achicanar",
    "achicanávei": "achicanar",
    "achicanáveis": "achicanar",
    "achicara": "achicar",
    "achicaram": "achicar",
    "achicaras": "achicar",
    "achicarde": "achicar",
    "achicardes": "achicar",
    "achicare": "achicar",
    "achicarei": "achicar",
    "achicareis": "achicar",
    "achicarem": "achicar",
    "achicaremos": "achicar",
    "achicares": "achicar",
    "achicaria": "achicar",
    "achicariam": "achicar",
    "achicarias": "achicar",
    "achicarmo": "achicar",
    "achicarmos": "achicar",
    "achicará": "achicar",
    "achicarás": "achicar",
    "achicarão": "achicar",
    "achicaríamos": "achicar",
    "achicaríeis": "achicar",
    "achicas": "achicar",
    "achicasse": "achicar",
    "achicassem": "achicar",
    "achicasses": "achicar",
    "achicaste": "achicar",
    "achicastes": "achicar",
    "achicava": "achicar",
    "achicavam": "achicar",
    "achicavas": "achicar",
    "achico": "achicar",
    "achicou": "achicar",
    "achicá": "achicar",
    "achicámo": "achicar",
    "achicámos": "achicar",
    "achicáramo": "achicar",
    "achicáramos": "achicar",
    "achicárei": "achicar",
    "achicáreis": "achicar",
    "achicásseis": "achicar",
    "achicássemos": "achicar",
    "achicávamo": "achicar",
    "achicávamos": "achicar",
    "achicávei": "achicar",
    "achicáveis": "achicar",
    "achina": "achinar",
    "achinada": "achinar",
    "achinadas": "achinar",
    "achinado": "achinar",
    "achinados": "achinar",
    "achinai": "achinar",
    "achinais": "achinar",
    "achinam": "achinar",
    "achinamo": "achinar",
    "achinamos": "achinar",
    "achinando": "achinar",
    "achinara": "achinar",
    "achinaram": "achinar",
    "achinaras": "achinar",
    "achinarde": "achinar",
    "achinardes": "achinar",
    "achinare": "achinar",
    "achinarei": "achinar",
    "achinareis": "achinar",
    "achinarem": "achinar",
    "achinaremos": "achinar",
    "achinares": "achinar",
    "achinaria": "achinar",
    "achinariam": "achinar",
    "achinarias": "achinar",
    "achinarmo": "achinar",
    "achinarmos": "achinar",
    "achinará": "achinar",
    "achinarás": "achinar",
    "achinarão": "achinar",
    "achinaríamos": "achinar",
    "achinaríeis": "achinar",
    "achinas": "achinar",
    "achinasse": "achinar",
    "achinassem": "achinar",
    "achinasses": "achinar",
    "achinaste": "achinar",
    "achinastes": "achinar",
    "achinava": "achinar",
    "achinavam": "achinar",
    "achinavas": "achinar",
    "achincalha": "achincalhar",
    "achincalhada": "achincalhar",
    "achincalhadas": "achincalhar",
    "achincalhado": "achincalhar",
    "achincalhadora": "achincalhador",
    "achincalhadoras": "achincalhador",
    "achincalhadores": "achincalhador",
    "achincalhados": "achincalhar",
    "achincalhadíssima": "achincalhado",
    "achincalhadíssimas": "achincalhado",
    "achincalhadíssimo": "achincalhado",
    "achincalhadíssimos": "achincalhado",
    "achincalhai": "achincalhar",
    "achincalhais": "achincalhar",
    "achincalham": "achincalhar",
    "achincalhamentos": "achincalhamento",
    "achincalhamo": "achincalhar",
    "achincalhamos": "achincalhar",
    "achincalhando": "achincalhar",
    "achincalhara": "achincalhar",
    "achincalharam": "achincalhar",
    "achincalharas": "achincalhar",
    "achincalharde": "achincalhar",
    "achincalhardes": "achincalhar",
    "achincalhare": "achincalhar",
    "achincalharei": "achincalhar",
    "achincalhareis": "achincalhar",
    "achincalharem": "achincalhar",
    "achincalharemos": "achincalhar",
    "achincalhares": "achincalhar",
    "achincalharia": "achincalhar",
    "achincalhariam": "achincalhar",
    "achincalharias": "achincalhar",
    "achincalharmo": "achincalhar",
    "achincalharmos": "achincalhar",
    "achincalhará": "achincalhar",
    "achincalharás": "achincalhar",
    "achincalharão": "achincalhar",
    "achincalharíamos": "achincalhar",
    "achincalharíeis": "achincalhar",
    "achincalhas": "achincalhar",
    "achincalhasse": "achincalhar",
    "achincalhassem": "achincalhar",
    "achincalhasses": "achincalhar",
    "achincalhaste": "achincalhar",
    "achincalhastes": "achincalhar",
    "achincalhava": "achincalhar",
    "achincalhavam": "achincalhar",
    "achincalhavas": "achincalhar",
    "achincalhações": "achincalhação",
    "achincalhe": "achincalhar",
    "achincalhei": "achincalhar",
    "achincalheis": "achincalhar",
    "achincalhem": "achincalhar",
    "achincalhemo": "achincalhar",
    "achincalhemos": "achincalhar",
    "achincalhes": "achincalhe",
    "achincalho": "achincalhar",
    "achincalhos": "achincalho",
    "achincalhou": "achincalhar",
    "achincalhá": "achincalhar",
    "achincalhámo": "achincalhar",
    "achincalhámos": "achincalhar",
    "achincalháramo": "achincalhar",
    "achincalháramos": "achincalhar",
    "achincalhárei": "achincalhar",
    "achincalháreis": "achincalhar",
    "achincalhásseis": "achincalhar",
    "achincalhássemos": "achincalhar",
    "achincalhávamo": "achincalhar",
    "achincalhávamos": "achincalhar",
    "achincalhávei": "achincalhar",
    "achincalháveis": "achincalhar",
    "achine": "achinar",
    "achinei": "achinar",
    "achineis": "achinar",
    "achinela": "achinelar",
    "achinelada": "achinelar",
    "achineladas": "achinelar",
    "achinelado": "achinelar",
    "achinelados": "achinelar",
    "achinelai": "achinelar",
    "achinelais": "achinelar",
    "achinelam": "achinelar",
    "achinelamo": "achinelar",
    "achinelamos": "achinelar",
    "achinelando": "achinelar",
    "achinelara": "achinelar",
    "achinelaram": "achinelar",
    "achinelaras": "achinelar",
    "achinelarde": "achinelar",
    "achinelardes": "achinelar",
    "achinelare": "achinelar",
    "achinelarei": "achinelar",
    "achinelareis": "achinelar",
    "achinelarem": "achinelar",
    "achinelaremos": "achinelar",
    "achinelares": "achinelar",
    "achinelaria": "achinelar",
    "achinelariam": "achinelar",
    "achinelarias": "achinelar",
    "achinelarmo": "achinelar",
    "achinelarmos": "achinelar",
    "achinelará": "achinelar",
    "achinelarás": "achinelar",
    "achinelarão": "achinelar",
    "achinelaríamos": "achinelar",
    "achinelaríeis": "achinelar",
    "achinelas": "achinelar",
    "achinelasse": "achinelar",
    "achinelassem": "achinelar",
    "achinelasses": "achinelar",
    "achinelaste": "achinelar",
    "achinelastes": "achinelar",
    "achinelava": "achinelar",
    "achinelavam": "achinelar",
    "achinelavas": "achinelar",
    "achinele": "achinelar",
    "achinelei": "achinelar",
    "achineleis": "achinelar",
    "achinelem": "achinelar",
    "achinelemo": "achinelar",
    "achinelemos": "achinelar",
    "achineles": "achinelar",
    "achinelo": "achinelar",
    "achinelou": "achinelar",
    "achinelá": "achinelar",
    "achinelámo": "achinelar",
    "achinelámos": "achinelar",
    "achineláramo": "achinelar",
    "achineláramos": "achinelar",
    "achinelárei": "achinelar",
    "achineláreis": "achinelar",
    "achinelásseis": "achinelar",
    "achinelássemos": "achinelar",
    "achinelávamo": "achinelar",
    "achinelávamos": "achinelar",
    "achinelávei": "achinelar",
    "achineláveis": "achinelar",
    "achinem": "achinar",
    "achinemo": "achinar",
    "achinemos": "achinar",
    "achines": "achinar",
    "achinesa": "achinesar",
    "achinesada": "achinesar",
    "achinesadas": "achinesar",
    "achinesado": "achinesar",
    "achinesados": "achinesar",
    "achinesai": "achinesar",
    "achinesais": "achinesar",
    "achinesam": "achinesar",
    "achinesamo": "achinesar",
    "achinesamos": "achinesar",
    "achinesando": "achinesar",
    "achinesara": "achinesar",
    "achinesaram": "achinesar",
    "achinesaras": "achinesar",
    "achinesarde": "achinesar",
    "achinesardes": "achinesar",
    "achinesare": "achinesar",
    "achinesarei": "achinesar",
    "achinesareis": "achinesar",
    "achinesarem": "achinesar",
    "achinesaremos": "achinesar",
    "achinesares": "achinesar",
    "achinesaria": "achinesar",
    "achinesariam": "achinesar",
    "achinesarias": "achinesar",
    "achinesarmo": "achinesar",
    "achinesarmos": "achinesar",
    "achinesará": "achinesar",
    "achinesarás": "achinesar",
    "achinesarão": "achinesar",
    "achinesaríamos": "achinesar",
    "achinesaríeis": "achinesar",
    "achinesas": "achinesar",
    "achinesasse": "achinesar",
    "achinesassem": "achinesar",
    "achinesasses": "achinesar",
    "achinesaste": "achinesar",
    "achinesastes": "achinesar",
    "achinesava": "achinesar",
    "achinesavam": "achinesar",
    "achinesavas": "achinesar",
    "achinese": "achinesar",
    "achinesei": "achinesar",
    "achineseis": "achinesar",
    "achinesem": "achinesar",
    "achinesemo": "achinesar",
    "achinesemos": "achinesar",
    "achineses": "achinesar",
    "achineso": "achinesar",
    "achinesou": "achinesar",
    "achinesá": "achinesar",
    "achinesámo": "achinesar",
    "achinesámos": "achinesar",
    "achinesáramo": "achinesar",
    "achinesáramos": "achinesar",
    "achinesárei": "achinesar",
    "achinesáreis": "achinesar",
    "achinesásseis": "achinesar",
    "achinesássemos": "achinesar",
    "achinesávamo": "achinesar",
    "achinesávamos": "achinesar",
    "achinesávei": "achinesar",
    "achinesáveis": "achinesar",
    "achinfrina": "achinfrinar",
    "achinfrinada": "achinfrinar",
    "achinfrinadas": "achinfrinar",
    "achinfrinado": "achinfrinar",
    "achinfrinados": "achinfrinar",
    "achinfrinai": "achinfrinar",
    "achinfrinais": "achinfrinar",
    "achinfrinam": "achinfrinar",
    "achinfrinamo": "achinfrinar",
    "achinfrinamos": "achinfrinar",
    "achinfrinando": "achinfrinar",
    "achinfrinara": "achinfrinar",
    "achinfrinaram": "achinfrinar",
    "achinfrinaras": "achinfrinar",
    "achinfrinarde": "achinfrinar",
    "achinfrinardes": "achinfrinar",
    "achinfrinare": "achinfrinar",
    "achinfrinarei": "achinfrinar",
    "achinfrinareis": "achinfrinar",
    "achinfrinarem": "achinfrinar",
    "achinfrinaremos": "achinfrinar",
    "achinfrinares": "achinfrinar",
    "achinfrinaria": "achinfrinar",
    "achinfrinariam": "achinfrinar",
    "achinfrinarias": "achinfrinar",
    "achinfrinarmo": "achinfrinar",
    "achinfrinarmos": "achinfrinar",
    "achinfrinará": "achinfrinar",
    "achinfrinarás": "achinfrinar",
    "achinfrinarão": "achinfrinar",
    "achinfrinaríamos": "achinfrinar",
    "achinfrinaríeis": "achinfrinar",
    "achinfrinas": "achinfrinar",
    "achinfrinasse": "achinfrinar",
    "achinfrinassem": "achinfrinar",
    "achinfrinasses": "achinfrinar",
    "achinfrinaste": "achinfrinar",
    "achinfrinastes": "achinfrinar",
    "achinfrinava": "achinfrinar",
    "achinfrinavam": "achinfrinar",
    "achinfrinavas": "achinfrinar",
    "achinfrine": "achinfrinar",
    "achinfrinei": "achinfrinar",
    "achinfrineis": "achinfrinar",
    "achinfrinem": "achinfrinar",
    "achinfrinemo": "achinfrinar",
    "achinfrinemos": "achinfrinar",
    "achinfrines": "achinfrinar",
    "achinfrino": "achinfrinar",
    "achinfrinou": "achinfrinar",
    "achinfriná": "achinfrinar",
    "achinfrinámo": "achinfrinar",
    "achinfrinámos": "achinfrinar",
    "achinfrináramo": "achinfrinar",
    "achinfrináramos": "achinfrinar",
    "achinfrinárei": "achinfrinar",
    "achinfrináreis": "achinfrinar",
    "achinfrinásseis": "achinfrinar",
    "achinfrinássemos": "achinfrinar",
    "achinfrinávamo": "achinfrinar",
    "achinfrinávamos": "achinfrinar",
    "achinfrinávei": "achinfrinar",
    "achinfrináveis": "achinfrinar",
    "achinha": "acha",
    "achinhas": "acha",
    "achino": "achinar",
    "achinou": "achinar",
    "achiná": "achinar",
    "achinámo": "achinar",
    "achinámos": "achinar",
    "achináramo": "achinar",
    "achináramos": "achinar",
    "achinárei": "achinar",
    "achináreis": "achinar",
    "achinásseis": "achinar",
    "achinássemos": "achinar",
    "achinávamo": "achinar",
    "achinávamos": "achinar",
    "achinávei": "achinar",
    "achináveis": "achinar",
    "achique": "achicar",
    "achiquei": "achicar",
    "achiqueis": "achicar",
    "achiquem": "achicar",
    "achiquemo": "achicar",
    "achiquemos": "achicar",
    "achiques": "achicar",
    "achita": "acha",
    "achitas": "acha",
    "acho": "achar",
    "achocalha": "achocalhar",
    "achocalhada": "achocalhar",
    "achocalhadas": "achocalhar",
    "achocalhado": "achocalhar",
    "achocalhados": "achocalhar",
    "achocalhai": "achocalhar",
    "achocalhais": "achocalhar",
    "achocalham": "achocalhar",
    "achocalhamo": "achocalhar",
    "achocalhamos": "achocalhar",
    "achocalhando": "achocalhar",
    "achocalhara": "achocalhar",
    "achocalharam": "achocalhar",
    "achocalharas": "achocalhar",
    "achocalharde": "achocalhar",
    "achocalhardes": "achocalhar",
    "achocalhare": "achocalhar",
    "achocalharei": "achocalhar",
    "achocalhareis": "achocalhar",
    "achocalharem": "achocalhar",
    "achocalharemos": "achocalhar",
    "achocalhares": "achocalhar",
    "achocalharia": "achocalhar",
    "achocalhariam": "achocalhar",
    "achocalharias": "achocalhar",
    "achocalharmo": "achocalhar",
    "achocalharmos": "achocalhar",
    "achocalhará": "achocalhar",
    "achocalharás": "achocalhar",
    "achocalharão": "achocalhar",
    "achocalharíamos": "achocalhar",
    "achocalharíeis": "achocalhar",
    "achocalhas": "achocalhar",
    "achocalhasse": "achocalhar",
    "achocalhassem": "achocalhar",
    "achocalhasses": "achocalhar",
    "achocalhaste": "achocalhar",
    "achocalhastes": "achocalhar",
    "achocalhava": "achocalhar",
    "achocalhavam": "achocalhar",
    "achocalhavas": "achocalhar",
    "achocalhe": "achocalhar",
    "achocalhei": "achocalhar",
    "achocalheis": "achocalhar",
    "achocalhem": "achocalhar",
    "achocalhemo": "achocalhar",
    "achocalhemos": "achocalhar",
    "achocalhes": "achocalhar",
    "achocalho": "achocalhar",
    "achocalhou": "achocalhar",
    "achocalhá": "achocalhar",
    "achocalhámo": "achocalhar",
    "achocalhámos": "achocalhar",
    "achocalháramo": "achocalhar",
    "achocalháramos": "achocalhar",
    "achocalhárei": "achocalhar",
    "achocalháreis": "achocalhar",
    "achocalhásseis": "achocalhar",
    "achocalhássemos": "achocalhar",
    "achocalhávamo": "achocalhar",
    "achocalhávamos": "achocalhar",
    "achocalhávei": "achocalhar",
    "achocalháveis": "achocalhar",
    "achocolata": "achocolatar",
    "achocolatada": "achocolatar",
    "achocolatadas": "achocolatar",
    "achocolatado": "achocolatar",
    "achocolatados": "achocolatar",
    "achocolatai": "achocolatar",
    "achocolatais": "achocolatar",
    "achocolatam": "achocolatar",
    "achocolatamo": "achocolatar",
    "achocolatamos": "achocolatar",
    "achocolatando": "achocolatar",
    "achocolatara": "achocolatar",
    "achocolataram": "achocolatar",
    "achocolataras": "achocolatar",
    "achocolatarde": "achocolatar",
    "achocolatardes": "achocolatar",
    "achocolatare": "achocolatar",
    "achocolatarei": "achocolatar",
    "achocolatareis": "achocolatar",
    "achocolatarem": "achocolatar",
    "achocolataremos": "achocolatar",
    "achocolatares": "achocolatar",
    "achocolataria": "achocolatar",
    "achocolatariam": "achocolatar",
    "achocolatarias": "achocolatar",
    "achocolatarmo": "achocolatar",
    "achocolatarmos": "achocolatar",
    "achocolatará": "achocolatar",
    "achocolatarás": "achocolatar",
    "achocolatarão": "achocolatar",
    "achocolataríamos": "achocolatar",
    "achocolataríeis": "achocolatar",
    "achocolatas": "achocolatar",
    "achocolatasse": "achocolatar",
    "achocolatassem": "achocolatar",
    "achocolatasses": "achocolatar",
    "achocolataste": "achocolatar",
    "achocolatastes": "achocolatar",
    "achocolatava": "achocolatar",
    "achocolatavam": "achocolatar",
    "achocolatavas": "achocolatar",
    "achocolate": "achocolatar",
    "achocolatei": "achocolatar",
    "achocolateis": "achocolatar",
    "achocolatem": "achocolatar",
    "achocolatemo": "achocolatar",
    "achocolatemos": "achocolatar",
    "achocolates": "achocolatar",
    "achocolato": "achocolatar",
    "achocolatou": "achocolatar",
    "achocolatá": "achocolatar",
    "achocolatámo": "achocolatar",
    "achocolatámos": "achocolatar",
    "achocolatáramo": "achocolatar",
    "achocolatáramos": "achocolatar",
    "achocolatárei": "achocolatar",
    "achocolatáreis": "achocolatar",
    "achocolatásseis": "achocolatar",
    "achocolatássemos": "achocolatar",
    "achocolatávamo": "achocolatar",
    "achocolatávamos": "achocolatar",
    "achocolatávei": "achocolatar",
    "achocolatáveis": "achocolatar",
    "achou": "achar",
    "achoupanada": "achoupanado",
    "achoupanadas": "achoupanado",
    "achoupanados": "achoupanado",
    "achourice": "achouriçar",
    "achouricei": "achouriçar",
    "achouriceis": "achouriçar",
    "achouricem": "achouriçar",
    "achouricemo": "achouriçar",
    "achouricemos": "achouriçar",
    "achourices": "achouriçar",
    "achouriça": "achouriçar",
    "achouriçada": "achouriçar",
    "achouriçadas": "achouriçar",
    "achouriçado": "achouriçar",
    "achouriçados": "achouriçar",
    "achouriçai": "achouriçar",
    "achouriçais": "achouriçar",
    "achouriçam": "achouriçar",
    "achouriçamo": "achouriçar",
    "achouriçamos": "achouriçar",
    "achouriçando": "achouriçar",
    "achouriçara": "achouriçar",
    "achouriçaram": "achouriçar",
    "achouriçaras": "achouriçar",
    "achouriçarde": "achouriçar",
    "achouriçardes": "achouriçar",
    "achouriçare": "achouriçar",
    "achouriçarei": "achouriçar",
    "achouriçareis": "achouriçar",
    "achouriçarem": "achouriçar",
    "achouriçaremos": "achouriçar",
    "achouriçares": "achouriçar",
    "achouriçaria": "achouriçar",
    "achouriçariam": "achouriçar",
    "achouriçarias": "achouriçar",
    "achouriçarmo": "achouriçar",
    "achouriçarmos": "achouriçar",
    "achouriçará": "achouriçar",
    "achouriçarás": "achouriçar",
    "achouriçarão": "achouriçar",
    "achouriçaríamos": "achouriçar",
    "achouriçaríeis": "achouriçar",
    "achouriças": "achouriçar",
    "achouriçasse": "achouriçar",
    "achouriçassem": "achouriçar",
    "achouriçasses": "achouriçar",
    "achouriçaste": "achouriçar",
    "achouriçastes": "achouriçar",
    "achouriçava": "achouriçar",
    "achouriçavam": "achouriçar",
    "achouriçavas": "achouriçar",
    "achouriço": "achouriçar",
    "achouriçou": "achouriçar",
    "achouriçá": "achouriçar",
    "achouriçámo": "achouriçar",
    "achouriçámos": "achouriçar",
    "achouriçáramo": "achouriçar",
    "achouriçáramos": "achouriçar",
    "achouriçárei": "achouriçar",
    "achouriçáreis": "achouriçar",
    "achouriçásseis": "achouriçar",
    "achouriçássemos": "achouriçar",
    "achouriçávamo": "achouriçar",
    "achouriçávamos": "achouriçar",
    "achouriçávei": "achouriçar",
    "achouriçáveis": "achouriçar",
    "achumace": "achumaçar",
    "achumacei": "achumaçar",
    "achumaceis": "achumaçar",
    "achumacem": "achumaçar",
    "achumacemo": "achumaçar",
    "achumacemos": "achumaçar",
    "achumaces": "achumaçar",
    "achumaça": "achumaçar",
    "achumaçada": "achumaçar",
    "achumaçadas": "achumaçar",
    "achumaçado": "achumaçar",
    "achumaçados": "achumaçar",
    "achumaçai": "achumaçar",
    "achumaçais": "achumaçar",
    "achumaçam": "achumaçar",
    "achumaçamo": "achumaçar",
    "achumaçamos": "achumaçar",
    "achumaçando": "achumaçar",
    "achumaçara": "achumaçar",
    "achumaçaram": "achumaçar",
    "achumaçaras": "achumaçar",
    "achumaçarde": "achumaçar",
    "achumaçardes": "achumaçar",
    "achumaçare": "achumaçar",
    "achumaçarei": "achumaçar",
    "achumaçareis": "achumaçar",
    "achumaçarem": "achumaçar",
    "achumaçaremos": "achumaçar",
    "achumaçares": "achumaçar",
    "achumaçaria": "achumaçar",
    "achumaçariam": "achumaçar",
    "achumaçarias": "achumaçar",
    "achumaçarmo": "achumaçar",
    "achumaçarmos": "achumaçar",
    "achumaçará": "achumaçar",
    "achumaçarás": "achumaçar",
    "achumaçarão": "achumaçar",
    "achumaçaríamos": "achumaçar",
    "achumaçaríeis": "achumaçar",
    "achumaças": "achumaçar",
    "achumaçasse": "achumaçar",
    "achumaçassem": "achumaçar",
    "achumaçasses": "achumaçar",
    "achumaçaste": "achumaçar",
    "achumaçastes": "achumaçar",
    "achumaçava": "achumaçar",
    "achumaçavam": "achumaçar",
    "achumaçavas": "achumaçar",
    "achumaço": "achumaçar",
    "achumaçou": "achumaçar",
    "achumaçá": "achumaçar",
    "achumaçámo": "achumaçar",
    "achumaçámos": "achumaçar",
    "achumaçáramo": "achumaçar",
    "achumaçáramos": "achumaçar",
    "achumaçárei": "achumaçar",
    "achumaçáreis": "achumaçar",
    "achumaçásseis": "achumaçar",
    "achumaçássemos": "achumaçar",
    "achumaçávamo": "achumaçar",
    "achumaçávamos": "achumaçar",
    "achumaçávei": "achumaçar",
    "achumaçáveis": "achumaçar",
    "achumba": "achumbar",
    "achumbada": "achumbar",
    "achumbadas": "achumbar",
    "achumbado": "achumbar",
    "achumbados": "achumbar",
    "achumbai": "achumbar",
    "achumbais": "achumbar",
    "achumbam": "achumbar",
    "achumbamo": "achumbar",
    "achumbamos": "achumbar",
    "achumbando": "achumbar",
    "achumbara": "achumbar",
    "achumbaram": "achumbar",
    "achumbaras": "achumbar",
    "achumbarde": "achumbar",
    "achumbardes": "achumbar",
    "achumbare": "achumbar",
    "achumbarei": "achumbar",
    "achumbareis": "achumbar",
    "achumbarem": "achumbar",
    "achumbaremos": "achumbar",
    "achumbares": "achumbar",
    "achumbaria": "achumbar",
    "achumbariam": "achumbar",
    "achumbarias": "achumbar",
    "achumbarmo": "achumbar",
    "achumbarmos": "achumbar",
    "achumbará": "achumbar",
    "achumbarás": "achumbar",
    "achumbarão": "achumbar",
    "achumbaríamos": "achumbar",
    "achumbaríeis": "achumbar",
    "achumbas": "achumbar",
    "achumbasse": "achumbar",
    "achumbassem": "achumbar",
    "achumbasses": "achumbar",
    "achumbaste": "achumbar",
    "achumbastes": "achumbar",
    "achumbava": "achumbar",
    "achumbavam": "achumbar",
    "achumbavas": "achumbar",
    "achumbe": "achumbar",
    "achumbei": "achumbar",
    "achumbeis": "achumbar",
    "achumbem": "achumbar",
    "achumbemo": "achumbar",
    "achumbemos": "achumbar",
    "achumbes": "achumbar",
    "achumbo": "achumbar",
    "achumbou": "achumbar",
    "achumbá": "achumbar",
    "achumbámo": "achumbar",
    "achumbámos": "achumbar",
    "achumbáramo": "achumbar",
    "achumbáramos": "achumbar",
    "achumbárei": "achumbar",
    "achumbáreis": "achumbar",
    "achumbásseis": "achumbar",
    "achumbássemos": "achumbar",
    "achumbávamo": "achumbar",
    "achumbávamos": "achumbar",
    "achumbávei": "achumbar",
    "achumbáveis": "achumbar",
    "achá": "achar",
    "achádegos": "achádego",
    "achámo": "achar",
    "achámos": "achar",
    "acháramo": "achar",
    "acháramos": "achar",
    "achárei": "achar",
    "acháreis": "achar",
    "achásseis": "achar",
    "achássemos": "achar",
    "achávamo": "achar",
    "achávamos": "achar",
    "achávei": "achar",
    "acháveis": "achar",
    "acicas": "acica",
    "acicata": "acicatar",
    "acicatada": "acicatar",
    "acicatadas": "acicatar",
    "acicatado": "acicatar",
    "acicatados": "acicatar",
    "acicatai": "acicatar",
    "acicatais": "acicatar",
    "acicatam": "acicatar",
    "acicatamo": "acicatar",
    "acicatamos": "acicatar",
    "acicatando": "acicatar",
    "acicatara": "acicatar",
    "acicataram": "acicatar",
    "acicataras": "acicatar",
    "acicatarde": "acicatar",
    "acicatardes": "acicatar",
    "acicatare": "acicatar",
    "acicatarei": "acicatar",
    "acicatareis": "acicatar",
    "acicatarem": "acicatar",
    "acicataremos": "acicatar",
    "acicatares": "acicatar",
    "acicataria": "acicatar",
    "acicatariam": "acicatar",
    "acicatarias": "acicatar",
    "acicatarmo": "acicatar",
    "acicatarmos": "acicatar",
    "acicatará": "acicatar",
    "acicatarás": "acicatar",
    "acicatarão": "acicatar",
    "acicataríamos": "acicatar",
    "acicataríeis": "acicatar",
    "acicatas": "acicatar",
    "acicatasse": "acicatar",
    "acicatassem": "acicatar",
    "acicatasses": "acicatar",
    "acicataste": "acicatar",
    "acicatastes": "acicatar",
    "acicatava": "acicatar",
    "acicatavam": "acicatar",
    "acicatavas": "acicatar",
    "acicate": "acicatar",
    "acicatei": "acicatar",
    "acicateis": "acicatar",
    "acicatem": "acicatar",
    "acicatemo": "acicatar",
    "acicatemos": "acicatar",
    "acicates": "acicate",
    "acicato": "acicatar",
    "acicatou": "acicatar",
    "acicaturas": "acicatura",
    "acicatá": "acicatar",
    "acicatámo": "acicatar",
    "acicatámos": "acicatar",
    "acicatáramo": "acicatar",
    "acicatáramos": "acicatar",
    "acicatárei": "acicatar",
    "acicatáreis": "acicatar",
    "acicatásseis": "acicatar",
    "acicatássemos": "acicatar",
    "acicatávamo": "acicatar",
    "acicatávamos": "acicatar",
    "acicatávei": "acicatar",
    "acicatáveis": "acicatar",
    "aciculada": "aciculado",
    "aciculadas": "aciculado",
    "aciculados": "aciculado",
    "aciculares": "acicular",
    "acida": "acidar",
    "acidada": "acidar",
    "acidadas": "acidar",
    "acidado": "acidar",
    "acidados": "acidar",
    "acidai": "acidar",
    "acidais": "acidar",
    "acidam": "acidar",
    "acidamo": "acidar",
    "acidamos": "acidar",
    "acidando": "acidar",
    "acidara": "acidar",
    "acidaram": "acidar",
    "acidaras": "acidar",
    "acidarde": "acidar",
    "acidardes": "acidar",
    "acidare": "acidar",
    "acidarei": "acidar",
    "acidareis": "acidar",
    "acidarem": "acidar",
    "acidaremos": "acidar",
    "acidares": "acidar",
    "acidaria": "acidar",
    "acidariam": "acidar",
    "acidarias": "acidar",
    "acidarmo": "acidar",
    "acidarmos": "acidar",
    "acidará": "acidar",
    "acidarás": "acidar",
    "acidarão": "acidar",
    "acidaríamos": "acidar",
    "acidaríeis": "acidar",
    "acidas": "acidar",
    "acidasse": "acidar",
    "acidassem": "acidar",
    "acidasses": "acidar",
    "acidaste": "acidar",
    "acidastes": "acidar",
    "acidava": "acidar",
    "acidavam": "acidar",
    "acidavas": "acidar",
    "acidações": "acidação",
    "acide": "acidar",
    "acidei": "acidar",
    "acideis": "acidar",
    "acidem": "acidar",
    "acidemo": "acidar",
    "acidemos": "acidar",
    "acidenta": "acidentar",
    "acidentada": "acidentar",
    "acidentadas": "acidentar",
    "acidentado": "acidentar",
    "acidentados": "acidentar",
    "acidentai": "acidentar",
    "acidentais": "acidentar",
    "acidentalidades": "acidentalidade",
    "acidentalizações": "acidentalização",
    "acidentam": "acidentar",
    "acidentamo": "acidentar",
    "acidentamos": "acidentar",
    "acidentando": "acidentar",
    "acidentara": "acidentar",
    "acidentaram": "acidentar",
    "acidentaras": "acidentar",
    "acidentarde": "acidentar",
    "acidentardes": "acidentar",
    "acidentare": "acidentar",
    "acidentarei": "acidentar",
    "acidentareis": "acidentar",
    "acidentarem": "acidentar",
    "acidentaremos": "acidentar",
    "acidentares": "acidentar",
    "acidentaria": "acidentar",
    "acidentariam": "acidentar",
    "acidentarias": "acidentar",
    "acidentarmo": "acidentar",
    "acidentarmos": "acidentar",
    "acidentará": "acidentar",
    "acidentarás": "acidentar",
    "acidentarão": "acidentar",
    "acidentaríamos": "acidentar",
    "acidentaríeis": "acidentar",
    "acidentas": "acidentar",
    "acidentasse": "acidentar",
    "acidentassem": "acidentar",
    "acidentasses": "acidentar",
    "acidentaste": "acidentar",
    "acidentastes": "acidentar",
    "acidentava": "acidentar",
    "acidentavam": "acidentar",
    "acidentavas": "acidentar",
    "acidentações": "acidentação",
    "acidente": "acidentar",
    "acidentei": "acidentar",
    "acidenteis": "acidentar",
    "acidentem": "acidentar",
    "acidentemo": "acidentar",
    "acidentemos": "acidentar",
    "acidentes": "acidente",
    "acidento": "acidentar",
    "acidentou": "acidentar",
    "acidentá": "acidentar",
    "acidentámo": "acidentar",
    "acidentámos": "acidentar",
    "acidentáramo": "acidentar",
    "acidentáramos": "acidentar",
    "acidentárei": "acidentar",
    "acidentáreis": "acidentar",
    "acidentásseis": "acidentar",
    "acidentássemos": "acidentar",
    "acidentávamo": "acidentar",
    "acidentávamos": "acidentar",
    "acidentávei": "acidentar",
    "acidentáveis": "acidentável",
    "acides": "acidar",
    "acidifica": "acidificar",
    "acidificada": "acidificar",
    "acidificadas": "acidificar",
    "acidificado": "acidificar",
    "acidificados": "acidificar",
    "acidificais": "acidificar",
    "acidificam": "acidificar",
    "acidificamo": "acidificar",
    "acidificamos": "acidificar",
    "acidificando": "acidificar",
    "acidificantes": "acidificante",
    "acidificara": "acidificar",
    "acidificaram": "acidificar",
    "acidificaras": "acidificar",
    "acidificardes": "acidificar",
    "acidificarei": "acidificar",
    "acidificareis": "acidificar",
    "acidificarem": "acidificar",
    "acidificaremos": "acidificar",
    "acidificares": "acidificar",
    "acidificaria": "acidificar",
    "acidificariam": "acidificar",
    "acidificarias": "acidificar",
    "acidificarmo": "acidificar",
    "acidificarmos": "acidificar",
    "acidificará": "acidificar",
    "acidificarás": "acidificar",
    "acidificarão": "acidificar",
    "acidificaríamos": "acidificar",
    "acidificaríeis": "acidificar",
    "acidificas": "acidificar",
    "acidificasse": "acidificar",
    "acidificassem": "acidificar",
    "acidificasses": "acidificar",
    "acidificaste": "acidificar",
    "acidificastes": "acidificar",
    "acidificava": "acidificar",
    "acidificavam": "acidificar",
    "acidificavas": "acidificar",
    "acidificações": "acidificação",
    "acidifico": "acidificar",
    "acidificou": "acidificar",
    "acidificámo": "acidificar",
    "acidificámos": "acidificar",
    "acidificáramo": "acidificar",
    "acidificáramos": "acidificar",
    "acidificáreis": "acidificar",
    "acidificásseis": "acidificar",
    "acidificássemos": "acidificar",
    "acidificávamo": "acidificar",
    "acidificávamos": "acidificar",
    "acidificáveis": "acidificável",
    "acidifique": "acidificar",
    "acidifiquei": "acidificar",
    "acidifiqueis": "acidificar",
    "acidifiquem": "acidificar",
    "acidifiquemos": "acidificar",
    "acidifiques": "acidificar",
    "acidimetrias": "acidimetria",
    "acidiosa": "acidioso",
    "acidiosas": "acidioso",
    "acidiosos": "acidioso",
    "acido": "acidar",
    "acidoses": "acidose",
    "acidou": "acidar",
    "acidra": "acidrar",
    "acidrada": "acidrar",
    "acidradas": "acidrar",
    "acidrado": "acidrar",
    "acidrados": "acidrar",
    "acidrai": "acidrar",
    "acidrais": "acidrar",
    "acidram": "acidrar",
    "acidramo": "acidrar",
    "acidramos": "acidrar",
    "acidrando": "acidrar",
    "acidrara": "acidrar",
    "acidraram": "acidrar",
    "acidraras": "acidrar",
    "acidrarde": "acidrar",
    "acidrardes": "acidrar",
    "acidrare": "acidrar",
    "acidrarei": "acidrar",
    "acidrareis": "acidrar",
    "acidrarem": "acidrar",
    "acidraremos": "acidrar",
    "acidrares": "acidrar",
    "acidraria": "acidrar",
    "acidrariam": "acidrar",
    "acidrarias": "acidrar",
    "acidrarmo": "acidrar",
    "acidrarmos": "acidrar",
    "acidrará": "acidrar",
    "acidrarás": "acidrar",
    "acidrarão": "acidrar",
    "acidraríamos": "acidrar",
    "acidraríeis": "acidrar",
    "acidras": "acidrar",
    "acidrasse": "acidrar",
    "acidrassem": "acidrar",
    "acidrasses": "acidrar",
    "acidraste": "acidrar",
    "acidrastes": "acidrar",
    "acidrava": "acidrar",
    "acidravam": "acidrar",
    "acidravas": "acidrar",
    "acidre": "acidrar",
    "acidrei": "acidrar",
    "acidreis": "acidrar",
    "acidrem": "acidrar",
    "acidremo": "acidrar",
    "acidremos": "acidrar",
    "acidres": "acidrar",
    "acidro": "acidrar",
    "acidrou": "acidrar",
    "acidrá": "acidrar",
    "acidrámo": "acidrar",
    "acidrámos": "acidrar",
    "acidráramo": "acidrar",
    "acidráramos": "acidrar",
    "acidrárei": "acidrar",
    "acidráreis": "acidrar",
    "acidrásseis": "acidrar",
    "acidrássemos": "acidrar",
    "acidrávamo": "acidrar",
    "acidrávamos": "acidrar",
    "acidrávei": "acidrar",
    "acidráveis": "acidrar",
    "acidula": "acidular",
    "acidulada": "acidular",
    "aciduladas": "acidular",
    "acidulado": "acidular",
    "acidulados": "acidular",
    "acidulai": "acidular",
    "acidulais": "acidular",
    "acidulam": "acidular",
    "acidulamo": "acidular",
    "acidulamos": "acidular",
    "acidulando": "acidular",
    "acidulantes": "acidulante",
    "acidulara": "acidular",
    "acidularam": "acidular",
    "acidularas": "acidular",
    "acidularde": "acidular",
    "acidulardes": "acidular",
    "acidulare": "acidular",
    "acidularei": "acidular",
    "acidulareis": "acidular",
    "acidularem": "acidular",
    "acidularemos": "acidular",
    "acidulares": "acidular",
    "acidularia": "acidular",
    "acidulariam": "acidular",
    "acidularias": "acidular",
    "acidularmo": "acidular",
    "acidularmos": "acidular",
    "acidulará": "acidular",
    "acidularás": "acidular",
    "acidularão": "acidular",
    "acidularíamos": "acidular",
    "acidularíeis": "acidular",
    "acidulas": "acidular",
    "acidulasse": "acidular",
    "acidulassem": "acidular",
    "acidulasses": "acidular",
    "acidulaste": "acidular",
    "acidulastes": "acidular",
    "acidulava": "acidular",
    "acidulavam": "acidular",
    "acidulavas": "acidular",
    "acidulações": "acidulação",
    "acidule": "acidular",
    "acidulei": "acidular",
    "aciduleis": "acidular",
    "acidulem": "acidular",
    "acidulemo": "acidular",
    "acidulemos": "acidular",
    "acidules": "acidular",
    "acidulo": "acidular",
    "acidulou": "acidular",
    "acidulá": "acidular",
    "acidulámo": "acidular",
    "acidulámos": "acidular",
    "aciduláramo": "acidular",
    "aciduláramos": "acidular",
    "acidulárei": "acidular",
    "aciduláreis": "acidular",
    "acidulásseis": "acidular",
    "acidulássemos": "acidular",
    "acidulávamo": "acidular",
    "acidulávamos": "acidular",
    "acidulávei": "acidular",
    "aciduláveis": "acidular",
    "acidá": "acidar",
    "acidámo": "acidar",
    "acidámos": "acidar",
    "acidáramo": "acidar",
    "acidáramos": "acidar",
    "acidárei": "acidar",
    "acidáreis": "acidar",
    "acidásseis": "acidar",
    "acidássemos": "acidar",
    "acidávamo": "acidar",
    "acidávamos": "acidar",
    "acidávei": "acidar",
    "acidáveis": "acidável",
    "acidências": "acidência",
    "acidífera": "acidífero",
    "acidíferas": "acidífero",
    "acidíferos": "acidífero",
    "acidímetros": "acidímetro",
    "acidófila": "acidófilo",
    "acidófilas": "acidófilo",
    "acidófilos": "acidófilo",
    "aciformes": "aciforme",
    "acigana": "aciganar",
    "aciganada": "aciganar",
    "aciganadas": "aciganar",
    "aciganado": "aciganar",
    "aciganados": "aciganar",
    "aciganai": "aciganar",
    "aciganais": "aciganar",
    "aciganam": "aciganar",
    "aciganamo": "aciganar",
    "aciganamos": "aciganar",
    "aciganando": "aciganar",
    "aciganara": "aciganar",
    "aciganaram": "aciganar",
    "aciganaras": "aciganar",
    "aciganarde": "aciganar",
    "aciganardes": "aciganar",
    "aciganare": "aciganar",
    "aciganarei": "aciganar",
    "aciganareis": "aciganar",
    "aciganarem": "aciganar",
    "aciganaremos": "aciganar",
    "aciganares": "aciganar",
    "aciganaria": "aciganar",
    "aciganariam": "aciganar",
    "aciganarias": "aciganar",
    "aciganarmo": "aciganar",
    "aciganarmos": "aciganar",
    "aciganará": "aciganar",
    "aciganarás": "aciganar",
    "aciganarão": "aciganar",
    "aciganaríamos": "aciganar",
    "aciganaríeis": "aciganar",
    "aciganas": "aciganar",
    "aciganasse": "aciganar",
    "aciganassem": "aciganar",
    "aciganasses": "aciganar",
    "aciganaste": "aciganar",
    "aciganastes": "aciganar",
    "aciganava": "aciganar",
    "aciganavam": "aciganar",
    "aciganavas": "aciganar",
    "acigane": "aciganar",
    "aciganei": "aciganar",
    "aciganeis": "aciganar",
    "aciganem": "aciganar",
    "aciganemo": "aciganar",
    "aciganemos": "aciganar",
    "aciganes": "aciganar",
    "acigano": "aciganar",
    "aciganou": "aciganar",
    "aciganá": "aciganar",
    "aciganámo": "aciganar",
    "aciganámos": "aciganar",
    "aciganáramo": "aciganar",
    "aciganáramos": "aciganar",
    "aciganárei": "aciganar",
    "aciganáreis": "aciganar",
    "aciganásseis": "aciganar",
    "aciganássemos": "aciganar",
    "aciganávamo": "aciganar",
    "aciganávamos": "aciganar",
    "aciganávei": "aciganar",
    "aciganáveis": "aciganar",
    "acilas": "acila",
    "acilias": "acilia",
    "acilos": "acilo",
    "acimenta": "acimentar",
    "acimentada": "acimentar",
    "acimentadas": "acimentar",
    "acimentado": "acimentar",
    "acimentados": "acimentar",
    "acimentai": "acimentar",
    "acimentais": "acimentar",
    "acimentam": "acimentar",
    "acimentamo": "acimentar",
    "acimentamos": "acimentar",
    "acimentando": "acimentar",
    "acimentara": "acimentar",
    "acimentaram": "acimentar",
    "acimentaras": "acimentar",
    "acimentarde": "acimentar",
    "acimentardes": "acimentar",
    "acimentare": "acimentar",
    "acimentarei": "acimentar",
    "acimentareis": "acimentar",
    "acimentarem": "acimentar",
    "acimentaremos": "acimentar",
    "acimentares": "acimentar",
    "acimentaria": "acimentar",
    "acimentariam": "acimentar",
    "acimentarias": "acimentar",
    "acimentarmo": "acimentar",
    "acimentarmos": "acimentar",
    "acimentará": "acimentar",
    "acimentarás": "acimentar",
    "acimentarão": "acimentar",
    "acimentaríamos": "acimentar",
    "acimentaríeis": "acimentar",
    "acimentas": "acimentar",
    "acimentasse": "acimentar",
    "acimentassem": "acimentar",
    "acimentasses": "acimentar",
    "acimentaste": "acimentar",
    "acimentastes": "acimentar",
    "acimentava": "acimentar",
    "acimentavam": "acimentar",
    "acimentavas": "acimentar",
    "acimente": "acimentar",
    "acimentei": "acimentar",
    "acimenteis": "acimentar",
    "acimentem": "acimentar",
    "acimentemo": "acimentar",
    "acimentemos": "acimentar",
    "acimentes": "acimentar",
    "acimento": "acimentar",
    "acimentou": "acimentar",
    "acimentá": "acimentar",
    "acimentámo": "acimentar",
    "acimentámos": "acimentar",
    "acimentáramo": "acimentar",
    "acimentáramos": "acimentar",
    "acimentárei": "acimentar",
    "acimentáreis": "acimentar",
    "acimentásseis": "acimentar",
    "acimentássemos": "acimentar",
    "acimentávamo": "acimentar",
    "acimentávamos": "acimentar",
    "acimentávei": "acimentar",
    "acimentáveis": "acimentar",
    "acinaciformes": "acinaciforme",
    "acinchos": "acincho",
    "acineses": "acinese",
    "acinesias": "acinesia",
    "acinetideos": "acinetideo",
    "acinetina": "acinetino",
    "acinetinas": "acinetino",
    "acinetinos": "acinetino",
    "acinetos": "acineto",
    "aciniformes": "aciniforme",
    "acinosa": "acinoso",
    "acinosas": "acinoso",
    "acinosos": "acinoso",
    "acintes": "acinte",
    "acintosa": "acintoso",
    "acintosas": "acintoso",
    "acintosos": "acintoso",
    "acinza": "acinzar",
    "acinzada": "acinzar",
    "acinzadas": "acinzar",
    "acinzado": "acinzar",
    "acinzados": "acinzar",
    "acinzai": "acinzar",
    "acinzais": "acinzar",
    "acinzam": "acinzar",
    "acinzamentos": "acinzamento",
    "acinzamo": "acinzar",
    "acinzamos": "acinzar",
    "acinzando": "acinzar",
    "acinzara": "acinzar",
    "acinzaram": "acinzar",
    "acinzaras": "acinzar",
    "acinzarde": "acinzar",
    "acinzardes": "acinzar",
    "acinzare": "acinzar",
    "acinzarei": "acinzar",
    "acinzareis": "acinzar",
    "acinzarem": "acinzar",
    "acinzaremos": "acinzar",
    "acinzares": "acinzar",
    "acinzaria": "acinzar",
    "acinzariam": "acinzar",
    "acinzarias": "acinzar",
    "acinzarmo": "acinzar",
    "acinzarmos": "acinzar",
    "acinzará": "acinzar",
    "acinzarás": "acinzar",
    "acinzarão": "acinzar",
    "acinzaríamos": "acinzar",
    "acinzaríeis": "acinzar",
    "acinzas": "acinzar",
    "acinzasse": "acinzar",
    "acinzassem": "acinzar",
    "acinzasses": "acinzar",
    "acinzaste": "acinzar",
    "acinzastes": "acinzar",
    "acinzava": "acinzar",
    "acinzavam": "acinzar",
    "acinzavas": "acinzar",
    "acinze": "acinzar",
    "acinzei": "acinzar",
    "acinzeis": "acinzar",
    "acinzem": "acinzar",
    "acinzemo": "acinzar",
    "acinzemos": "acinzar",
    "acinzentada": "acinzentado",
    "acinzentadas": "acinzentado",
    "acinzentados": "acinzentado",
    "acinzes": "acinzar",
    "acinzo": "acinzar",
    "acinzou": "acinzar",
    "acinzá": "acinzar",
    "acinzámo": "acinzar",
    "acinzámos": "acinzar",
    "acinzáramo": "acinzar",
    "acinzáramos": "acinzar",
    "acinzárei": "acinzar",
    "acinzáreis": "acinzar",
    "acinzásseis": "acinzar",
    "acinzássemos": "acinzar",
    "acinzávamo": "acinzar",
    "acinzávamos": "acinzar",
    "acinzávei": "acinzar",
    "acinzáveis": "acinzar",
    "acinácea": "acináceo",
    "acináceas": "acináceo",
    "acináceos": "acináceo",
    "acinésica": "acinésico",
    "acinésicas": "acinésico",
    "acinésicos": "acinésico",
    "acinética": "acinético",
    "acinéticas": "acinético",
    "acinéticos": "acinético",
    "aciolismos": "aciolismo",
    "aciprestes": "acipreste",
    "aciranda": "acirandar",
    "acirandada": "acirandar",
    "acirandadas": "acirandar",
    "acirandado": "acirandar",
    "acirandados": "acirandar",
    "acirandai": "acirandar",
    "acirandais": "acirandar",
    "acirandam": "acirandar",
    "acirandamo": "acirandar",
    "acirandamos": "acirandar",
    "acirandando": "acirandar",
    "acirandara": "acirandar",
    "acirandaram": "acirandar",
    "acirandaras": "acirandar",
    "acirandarde": "acirandar",
    "acirandardes": "acirandar",
    "acirandare": "acirandar",
    "acirandarei": "acirandar",
    "acirandareis": "acirandar",
    "acirandarem": "acirandar",
    "acirandaremos": "acirandar",
    "acirandares": "acirandar",
    "acirandaria": "acirandar",
    "acirandariam": "acirandar",
    "acirandarias": "acirandar",
    "acirandarmo": "acirandar",
    "acirandarmos": "acirandar",
    "acirandará": "acirandar",
    "acirandarás": "acirandar",
    "acirandarão": "acirandar",
    "acirandaríamos": "acirandar",
    "acirandaríeis": "acirandar",
    "acirandas": "acirandar",
    "acirandasse": "acirandar",
    "acirandassem": "acirandar",
    "acirandasses": "acirandar",
    "acirandaste": "acirandar",
    "acirandastes": "acirandar",
    "acirandava": "acirandar",
    "acirandavam": "acirandar",
    "acirandavas": "acirandar",
    "acirande": "acirandar",
    "acirandei": "acirandar",
    "acirandeis": "acirandar",
    "acirandem": "acirandar",
    "acirandemo": "acirandar",
    "acirandemos": "acirandar",
    "acirandes": "acirandar",
    "acirando": "acirandar",
    "acirandou": "acirandar",
    "acirandá": "acirandar",
    "acirandámo": "acirandar",
    "acirandámos": "acirandar",
    "acirandáramo": "acirandar",
    "acirandáramos": "acirandar",
    "acirandárei": "acirandar",
    "acirandáreis": "acirandar",
    "acirandásseis": "acirandar",
    "acirandássemos": "acirandar",
    "acirandávamo": "acirandar",
    "acirandávamos": "acirandar",
    "acirandávei": "acirandar",
    "acirandáveis": "acirandar",
    "acirologias": "acirologia",
    "acirra": "acirrar",
    "acirrada": "acirrar",
    "acirradas": "acirrar",
    "acirrado": "acirrar",
    "acirrados": "acirrar",
    "acirrai": "acirrar",
    "acirrais": "acirrar",
    "acirram": "acirrar",
    "acirramentos": "acirramento",
    "acirramo": "acirrar",
    "acirramos": "acirrar",
    "acirrando": "acirrar",
    "acirrantes": "acirrante",
    "acirrara": "acirrar",
    "acirraram": "acirrar",
    "acirraras": "acirrar",
    "acirrarde": "acirrar",
    "acirrardes": "acirrar",
    "acirrare": "acirrar",
    "acirrarei": "acirrar",
    "acirrareis": "acirrar",
    "acirrarem": "acirrar",
    "acirraremos": "acirrar",
    "acirrares": "acirrar",
    "acirraria": "acirrar",
    "acirrariam": "acirrar",
    "acirrarias": "acirrar",
    "acirrarmo": "acirrar",
    "acirrarmos": "acirrar",
    "acirrará": "acirrar",
    "acirrarás": "acirrar",
    "acirrarão": "acirrar",
    "acirraríamos": "acirrar",
    "acirraríeis": "acirrar",
    "acirras": "acirrar",
    "acirrasse": "acirrar",
    "acirrassem": "acirrar",
    "acirrasses": "acirrar",
    "acirraste": "acirrar",
    "acirrastes": "acirrar",
    "acirrava": "acirrar",
    "acirravam": "acirrar",
    "acirravas": "acirrar",
    "acirre": "acirrar",
    "acirrei": "acirrar",
    "acirreis": "acirrar",
    "acirrem": "acirrar",
    "acirremo": "acirrar",
    "acirremos": "acirrar",
    "acirres": "acirrar",
    "acirro": "acirrar",
    "acirrou": "acirrar",
    "acirrá": "acirrar",
    "acirrámo": "acirrar",
    "acirrámos": "acirrar",
    "acirráramo": "acirrar",
    "acirráramos": "acirrar",
    "acirrárei": "acirrar",
    "acirráreis": "acirrar",
    "acirrásseis": "acirrar",
    "acirrássemos": "acirrar",
    "acirrávamo": "acirrar",
    "acirrávamos": "acirrar",
    "acirrávei": "acirrar",
    "acirráveis": "acirrar",
    "acistias": "acistia",
    "acitaras": "acitara",
    "acitrina": "acitrinar",
    "acitrinada": "acitrinar",
    "acitrinadas": "acitrinar",
    "acitrinado": "acitrinar",
    "acitrinados": "acitrinar",
    "acitrinai": "acitrinar",
    "acitrinais": "acitrinar",
    "acitrinam": "acitrinar",
    "acitrinamo": "acitrinar",
    "acitrinamos": "acitrinar",
    "acitrinando": "acitrinar",
    "acitrinara": "acitrinar",
    "acitrinaram": "acitrinar",
    "acitrinaras": "acitrinar",
    "acitrinarde": "acitrinar",
    "acitrinardes": "acitrinar",
    "acitrinare": "acitrinar",
    "acitrinarei": "acitrinar",
    "acitrinareis": "acitrinar",
    "acitrinarem": "acitrinar",
    "acitrinaremos": "acitrinar",
    "acitrinares": "acitrinar",
    "acitrinaria": "acitrinar",
    "acitrinariam": "acitrinar",
    "acitrinarias": "acitrinar",
    "acitrinarmo": "acitrinar",
    "acitrinarmos": "acitrinar",
    "acitrinará": "acitrinar",
    "acitrinarás": "acitrinar",
    "acitrinarão": "acitrinar",
    "acitrinaríamos": "acitrinar",
    "acitrinaríeis": "acitrinar",
    "acitrinas": "acitrinar",
    "acitrinasse": "acitrinar",
    "acitrinassem": "acitrinar",
    "acitrinasses": "acitrinar",
    "acitrinaste": "acitrinar",
    "acitrinastes": "acitrinar",
    "acitrinava": "acitrinar",
    "acitrinavam": "acitrinar",
    "acitrinavas": "acitrinar",
    "acitrine": "acitrinar",
    "acitrinei": "acitrinar",
    "acitrineis": "acitrinar",
    "acitrinem": "acitrinar",
    "acitrinemo": "acitrinar",
    "acitrinemos": "acitrinar",
    "acitrines": "acitrinar",
    "acitrino": "acitrinar",
    "acitrinou": "acitrinar",
    "acitriná": "acitrinar",
    "acitrinámo": "acitrinar",
    "acitrinámos": "acitrinar",
    "acitrináramo": "acitrinar",
    "acitrináramos": "acitrinar",
    "acitrinárei": "acitrinar",
    "acitrináreis": "acitrinar",
    "acitrinásseis": "acitrinar",
    "acitrinássemos": "acitrinar",
    "acitrinávamo": "acitrinar",
    "acitrinávamos": "acitrinar",
    "acitrinávei": "acitrinar",
    "acitrináveis": "acitrinar",
    "acizenta": "acizentar",
    "acizentada": "acizentar",
    "acizentadas": "acizentar",
    "acizentado": "acizentar",
    "acizentados": "acizentar",
    "acizentai": "acizentar",
    "acizentais": "acizentar",
    "acizentam": "acizentar",
    "acizentamo": "acizentar",
    "acizentamos": "acizentar",
    "acizentando": "acizentar",
    "acizentara": "acizentar",
    "acizentaram": "acizentar",
    "acizentaras": "acizentar",
    "acizentarde": "acizentar",
    "acizentardes": "acizentar",
    "acizentare": "acizentar",
    "acizentarei": "acizentar",
    "acizentareis": "acizentar",
    "acizentarem": "acizentar",
    "acizentaremos": "acizentar",
    "acizentares": "acizentar",
    "acizentaria": "acizentar",
    "acizentariam": "acizentar",
    "acizentarias": "acizentar",
    "acizentarmo": "acizentar",
    "acizentarmos": "acizentar",
    "acizentará": "acizentar",
    "acizentarás": "acizentar",
    "acizentarão": "acizentar",
    "acizentaríamos": "acizentar",
    "acizentaríeis": "acizentar",
    "acizentas": "acizentar",
    "acizentasse": "acizentar",
    "acizentassem": "acizentar",
    "acizentasses": "acizentar",
    "acizentaste": "acizentar",
    "acizentastes": "acizentar",
    "acizentava": "acizentar",
    "acizentavam": "acizentar",
    "acizentavas": "acizentar",
    "acizente": "acizentar",
    "acizentei": "acizentar",
    "acizenteis": "acizentar",
    "acizentem": "acizentar",
    "acizentemo": "acizentar",
    "acizentemos": "acizentar",
    "acizentes": "acizentar",
    "acizento": "acizentar",
    "acizentou": "acizentar",
    "acizentá": "acizentar",
    "acizentámo": "acizentar",
    "acizentámos": "acizentar",
    "acizentáramo": "acizentar",
    "acizentáramos": "acizentar",
    "acizentárei": "acizentar",
    "acizentáreis": "acizentar",
    "acizentásseis": "acizentar",
    "acizentássemos": "acizentar",
    "acizentávamo": "acizentar",
    "acizentávamos": "acizentar",
    "acizentávei": "acizentar",
    "acizentáveis": "acizentar",
    "aclama": "aclamar",
    "aclamada": "aclamar",
    "aclamadas": "aclamar",
    "aclamado": "aclamar",
    "aclamadora": "aclamador",
    "aclamadoras": "aclamador",
    "aclamadores": "aclamador",
    "aclamados": "aclamar",
    "aclamadíssima": "aclamado",
    "aclamadíssimas": "aclamado",
    "aclamadíssimo": "aclamado",
    "aclamadíssimos": "aclamado",
    "aclamai": "aclamar",
    "aclamais": "aclamar",
    "aclamam": "aclamar",
    "aclamamo": "aclamar",
    "aclamamos": "aclamar",
    "aclamando": "aclamar",
    "aclamara": "aclamar",
    "aclamaram": "aclamar",
    "aclamaras": "aclamar",
    "aclamarde": "aclamar",
    "aclamardes": "aclamar",
    "aclamare": "aclamar",
    "aclamarei": "aclamar",
    "aclamareis": "aclamar",
    "aclamarem": "aclamar",
    "aclamaremos": "aclamar",
    "aclamares": "aclamar",
    "aclamaria": "aclamar",
    "aclamariam": "aclamar",
    "aclamarias": "aclamar",
    "aclamarmo": "aclamar",
    "aclamarmos": "aclamar",
    "aclamará": "aclamar",
    "aclamarás": "aclamar",
    "aclamarão": "aclamar",
    "aclamaríamos": "aclamar",
    "aclamaríeis": "aclamar",
    "aclamas": "aclamar",
    "aclamasse": "aclamar",
    "aclamassem": "aclamar",
    "aclamasses": "aclamar",
    "aclamaste": "aclamar",
    "aclamastes": "aclamar",
    "aclamativa": "aclamativo",
    "aclamativas": "aclamativo",
    "aclamativos": "aclamativo",
    "aclamava": "aclamar",
    "aclamavam": "aclamar",
    "aclamavas": "aclamar",
    "aclamações": "aclamação",
    "aclame": "aclamar",
    "aclamei": "aclamar",
    "aclameis": "aclamar",
    "aclamem": "aclamar",
    "aclamemo": "aclamar",
    "aclamemos": "aclamar",
    "aclames": "aclamar",
    "aclamo": "aclamar",
    "aclamou": "aclamar",
    "aclamá": "aclamar",
    "aclamámo": "aclamar",
    "aclamámos": "aclamar",
    "aclamáramo": "aclamar",
    "aclamáramos": "aclamar",
    "aclamárei": "aclamar",
    "aclamáreis": "aclamar",
    "aclamásseis": "aclamar",
    "aclamássemos": "aclamar",
    "aclamávamo": "aclamar",
    "aclamávamos": "aclamar",
    "aclamávei": "aclamar",
    "aclamáveis": "aclamável",
    "aclara": "aclarar",
    "aclarada": "aclarar",
    "aclaradas": "aclarar",
    "aclarado": "aclarar",
    "aclarados": "aclarar",
    "aclarai": "aclarar",
    "aclarais": "aclarar",
    "aclaram": "aclarar",
    "aclaramo": "aclarar",
    "aclaramos": "aclarar",
    "aclarando": "aclarar",
    "aclarara": "aclarar",
    "aclararam": "aclarar",
    "aclararas": "aclarar",
    "aclararde": "aclarar",
    "aclarardes": "aclarar",
    "aclarare": "aclarar",
    "aclararei": "aclarar",
    "aclarareis": "aclarar",
    "aclararem": "aclarar",
    "aclararemos": "aclarar",
    "aclarares": "aclarar",
    "aclararia": "aclarar",
    "aclarariam": "aclarar",
    "aclararias": "aclarar",
    "aclararmo": "aclarar",
    "aclararmos": "aclarar",
    "aclarará": "aclarar",
    "aclararás": "aclarar",
    "aclararão": "aclarar",
    "aclararíamos": "aclarar",
    "aclararíeis": "aclarar",
    "aclaras": "aclarar",
    "aclarasse": "aclarar",
    "aclarassem": "aclarar",
    "aclarasses": "aclarar",
    "aclaraste": "aclarar",
    "aclarastes": "aclarar",
    "aclarava": "aclarar",
    "aclaravam": "aclarar",
    "aclaravas": "aclarar",
    "aclarações": "aclaração",
    "aclare": "aclarar",
    "aclarei": "aclarar",
    "aclareis": "aclarar",
    "aclarem": "aclarar",
    "aclaremo": "aclarar",
    "aclaremos": "aclarar",
    "aclares": "aclarar",
    "aclaro": "aclarar",
    "aclarou": "aclarar",
    "aclará": "aclarar",
    "aclarámo": "aclarar",
    "aclarámos": "aclarar",
    "aclaráramo": "aclarar",
    "aclaráramos": "aclarar",
    "aclarárei": "aclarar",
    "aclaráreis": "aclarar",
    "aclarásseis": "aclarar",
    "aclarássemos": "aclarar",
    "aclarávamo": "aclarar",
    "aclarávamos": "aclarar",
    "aclarávei": "aclarar",
    "aclaráveis": "aclarar",
    "aclasta": "aclasto",
    "aclastas": "aclasto",
    "aclastos": "aclasto",
    "aclavada": "aclavado",
    "aclavadas": "aclavado",
    "aclavados": "aclavado",
    "acleriza": "aclerizar",
    "aclerizada": "aclerizar",
    "aclerizadas": "aclerizar",
    "aclerizado": "aclerizar",
    "aclerizados": "aclerizar",
    "aclerizai": "aclerizar",
    "aclerizais": "aclerizar",
    "aclerizam": "aclerizar",
    "aclerizamo": "aclerizar",
    "aclerizamos": "aclerizar",
    "aclerizando": "aclerizar",
    "aclerizara": "aclerizar",
    "aclerizaram": "aclerizar",
    "aclerizaras": "aclerizar",
    "aclerizarde": "aclerizar",
    "aclerizardes": "aclerizar",
    "aclerizare": "aclerizar",
    "aclerizarei": "aclerizar",
    "aclerizareis": "aclerizar",
    "aclerizarem": "aclerizar",
    "aclerizaremos": "aclerizar",
    "aclerizares": "aclerizar",
    "aclerizaria": "aclerizar",
    "aclerizariam": "aclerizar",
    "aclerizarias": "aclerizar",
    "aclerizarmo": "aclerizar",
    "aclerizarmos": "aclerizar",
    "aclerizará": "aclerizar",
    "aclerizarás": "aclerizar",
    "aclerizarão": "aclerizar",
    "aclerizaríamos": "aclerizar",
    "aclerizaríeis": "aclerizar",
    "aclerizas": "aclerizar",
    "aclerizasse": "aclerizar",
    "aclerizassem": "aclerizar",
    "aclerizasses": "aclerizar",
    "aclerizaste": "aclerizar",
    "aclerizastes": "aclerizar",
    "aclerizava": "aclerizar",
    "aclerizavam": "aclerizar",
    "aclerizavas": "aclerizar",
    "aclerize": "aclerizar",
    "aclerizei": "aclerizar",
    "aclerizeis": "aclerizar",
    "aclerizem": "aclerizar",
    "aclerizemo": "aclerizar",
    "aclerizemos": "aclerizar",
    "aclerizes": "aclerizar",
    "aclerizo": "aclerizar",
    "aclerizou": "aclerizar",
    "aclerizá": "aclerizar",
    "aclerizámo": "aclerizar",
    "aclerizámos": "aclerizar",
    "aclerizáramo": "aclerizar",
    "aclerizáramos": "aclerizar",
    "aclerizárei": "aclerizar",
    "aclerizáreis": "aclerizar",
    "aclerizásseis": "aclerizar",
    "aclerizássemos": "aclerizar",
    "aclerizávamo": "aclerizar",
    "aclerizávamos": "aclerizar",
    "aclerizávei": "aclerizar",
    "aclerizáveis": "aclerizar",
    "aclima": "aclimar",
    "aclimada": "aclimar",
    "aclimadas": "aclimar",
    "aclimado": "aclimar",
    "aclimados": "aclimar",
    "aclimai": "aclimar",
    "aclimais": "aclimar",
    "aclimam": "aclimar",
    "aclimamo": "aclimar",
    "aclimamos": "aclimar",
    "aclimando": "aclimar",
    "aclimara": "aclimar",
    "aclimaram": "aclimar",
    "aclimaras": "aclimar",
    "aclimarde": "aclimar",
    "aclimardes": "aclimar",
    "aclimare": "aclimar",
    "aclimarei": "aclimar",
    "aclimareis": "aclimar",
    "aclimarem": "aclimar",
    "aclimaremos": "aclimar",
    "aclimares": "aclimar",
    "aclimaria": "aclimar",
    "aclimariam": "aclimar",
    "aclimarias": "aclimar",
    "aclimarmo": "aclimar",
    "aclimarmos": "aclimar",
    "aclimará": "aclimar",
    "aclimarás": "aclimar",
    "aclimarão": "aclimar",
    "aclimaríamos": "aclimar",
    "aclimaríeis": "aclimar",
    "aclimas": "aclimar",
    "aclimasse": "aclimar",
    "aclimassem": "aclimar",
    "aclimasses": "aclimar",
    "aclimaste": "aclimar",
    "aclimastes": "aclimar",
    "aclimata": "aclimatar",
    "aclimatada": "aclimatar",
    "aclimatadas": "aclimatar",
    "aclimatado": "aclimatar",
    "aclimatados": "aclimatar",
    "aclimatai": "aclimatar",
    "aclimatais": "aclimatar",
    "aclimatam": "aclimatar",
    "aclimatamo": "aclimatar",
    "aclimatamos": "aclimatar",
    "aclimatando": "aclimatar",
    "aclimatara": "aclimatar",
    "aclimataram": "aclimatar",
    "aclimataras": "aclimatar",
    "aclimatardes": "aclimatar",
    "aclimatarei": "aclimatar",
    "aclimatareis": "aclimatar",
    "aclimatarem": "aclimatar",
    "aclimataremos": "aclimatar",
    "aclimatares": "aclimatar",
    "aclimataria": "aclimatar",
    "aclimatariam": "aclimatar",
    "aclimatarias": "aclimatar",
    "aclimatarmo": "aclimatar",
    "aclimatarmos": "aclimatar",
    "aclimatará": "aclimatar",
    "aclimatarás": "aclimatar",
    "aclimatarão": "aclimatar",
    "aclimataríamos": "aclimatar",
    "aclimataríeis": "aclimatar",
    "aclimatas": "aclimatar",
    "aclimatasse": "aclimatar",
    "aclimatassem": "aclimatar",
    "aclimatasses": "aclimatar",
    "aclimataste": "aclimatar",
    "aclimatastes": "aclimatar",
    "aclimatava": "aclimatar",
    "aclimatavam": "aclimatar",
    "aclimatavas": "aclimatar",
    "aclimatações": "aclimatação",
    "aclimate": "aclimatar",
    "aclimatei": "aclimatar",
    "aclimateis": "aclimatar",
    "aclimatem": "aclimatar",
    "aclimatemo": "aclimatar",
    "aclimatemos": "aclimatar",
    "aclimates": "aclimatar",
    "aclimatiza": "aclimatizar",
    "aclimatizada": "aclimatizar",
    "aclimatizadas": "aclimatizar",
    "aclimatizado": "aclimatizar",
    "aclimatizados": "aclimatizar",
    "aclimatizai": "aclimatizar",
    "aclimatizais": "aclimatizar",
    "aclimatizam": "aclimatizar",
    "aclimatizamo": "aclimatizar",
    "aclimatizamos": "aclimatizar",
    "aclimatizando": "aclimatizar",
    "aclimatizara": "aclimatizar",
    "aclimatizaram": "aclimatizar",
    "aclimatizaras": "aclimatizar",
    "aclimatizarde": "aclimatizar",
    "aclimatizardes": "aclimatizar",
    "aclimatizare": "aclimatizar",
    "aclimatizarei": "aclimatizar",
    "aclimatizareis": "aclimatizar",
    "aclimatizarem": "aclimatizar",
    "aclimatizaremos": "aclimatizar",
    "aclimatizares": "aclimatizar",
    "aclimatizaria": "aclimatizar",
    "aclimatizariam": "aclimatizar",
    "aclimatizarias": "aclimatizar",
    "aclimatizarmo": "aclimatizar",
    "aclimatizarmos": "aclimatizar",
    "aclimatizará": "aclimatizar",
    "aclimatizarás": "aclimatizar",
    "aclimatizarão": "aclimatizar",
    "aclimatizaríamos": "aclimatizar",
    "aclimatizaríeis": "aclimatizar",
    "aclimatizas": "aclimatizar",
    "aclimatizasse": "aclimatizar",
    "aclimatizassem": "aclimatizar",
    "aclimatizasses": "aclimatizar",
    "aclimatizaste": "aclimatizar",
    "aclimatizastes": "aclimatizar",
    "aclimatizava": "aclimatizar",
    "aclimatizavam": "aclimatizar",
    "aclimatizavas": "aclimatizar",
    "aclimatize": "aclimatizar",
    "aclimatizei": "aclimatizar",
    "aclimatizeis": "aclimatizar",
    "aclimatizem": "aclimatizar",
    "aclimatizemo": "aclimatizar",
    "aclimatizemos": "aclimatizar",
    "aclimatizes": "aclimatizar",
    "aclimatizo": "aclimatizar",
    "aclimatizou": "aclimatizar",
    "aclimatizá": "aclimatizar",
    "aclimatizámo": "aclimatizar",
    "aclimatizámos": "aclimatizar",
    "aclimatizáramo": "aclimatizar",
    "aclimatizáramos": "aclimatizar",
    "aclimatizárei": "aclimatizar",
    "aclimatizáreis": "aclimatizar",
    "aclimatizásseis": "aclimatizar",
    "aclimatizássemos": "aclimatizar",
    "aclimatizávamo": "aclimatizar",
    "aclimatizávamos": "aclimatizar",
    "aclimatizávei": "aclimatizar",
    "aclimatizáveis": "aclimatizar",
    "aclimato": "aclimatar",
    "aclimatou": "aclimatar",
    "aclimatámo": "aclimatar",
    "aclimatámos": "aclimatar",
    "aclimatáramo": "aclimatar",
    "aclimatáramos": "aclimatar",
    "aclimatáreis": "aclimatar",
    "aclimatásseis": "aclimatar",
    "aclimatássemos": "aclimatar",
    "aclimatávamo": "aclimatar",
    "aclimatávamos": "aclimatar",
    "aclimatáveis": "aclimatar",
    "aclimava": "aclimar",
    "aclimavam": "aclimar",
    "aclimavas": "aclimar",
    "aclimações": "aclimação",
    "aclime": "aclimar",
    "aclimei": "aclimar",
    "aclimeis": "aclimar",
    "aclimem": "aclimar",
    "aclimemo": "aclimar",
    "aclimemos": "aclimar",
    "aclimes": "aclimar",
    "aclimo": "aclimar",
    "aclimou": "aclimar",
    "aclimá": "aclimar",
    "aclimámo": "aclimar",
    "aclimámos": "aclimar",
    "aclimáramo": "aclimar",
    "aclimáramos": "aclimar",
    "aclimárei": "aclimar",
    "aclimáreis": "aclimar",
    "aclimásseis": "aclimar",
    "aclimássemos": "aclimar",
    "aclimávamo": "aclimar",
    "aclimávamos": "aclimar",
    "aclimávei": "aclimar",
    "aclimáveis": "aclimar",
    "aclives": "aclive",
    "acloroblepsias": "acloroblepsia",
    "aclástica": "aclástico",
    "aclásticas": "aclástico",
    "aclásticos": "aclástico",
    "aclínica": "aclínico",
    "aclínicas": "aclínico",
    "aclínicos": "aclínico",
    "acmes": "acme",
    "acmástica": "acmástico",
    "acmásticas": "acmástico",
    "acmásticos": "acmástico",
    "acnas": "acna",
    "acnes": "acne",
    "acnidária": "acnidário",
    "acnidárias": "acnidário",
    "acnidários": "acnidário",
    "acoalha": "acoalhar",
    "acoalhada": "acoalhar",
    "acoalhadas": "acoalhar",
    "acoalhado": "acoalhar",
    "acoalhados": "acoalhar",
    "acoalhai": "acoalhar",
    "acoalhais": "acoalhar",
    "acoalham": "acoalhar",
    "acoalhamo": "acoalhar",
    "acoalhamos": "acoalhar",
    "acoalhando": "acoalhar",
    "acoalhara": "acoalhar",
    "acoalharam": "acoalhar",
    "acoalharas": "acoalhar",
    "acoalharde": "acoalhar",
    "acoalhardes": "acoalhar",
    "acoalhare": "acoalhar",
    "acoalharei": "acoalhar",
    "acoalhareis": "acoalhar",
    "acoalharem": "acoalhar",
    "acoalharemos": "acoalhar",
    "acoalhares": "acoalhar",
    "acoalharia": "acoalhar",
    "acoalhariam": "acoalhar",
    "acoalharias": "acoalhar",
    "acoalharmo": "acoalhar",
    "acoalharmos": "acoalhar",
    "acoalhará": "acoalhar",
    "acoalharás": "acoalhar",
    "acoalharão": "acoalhar",
    "acoalharíamos": "acoalhar",
    "acoalharíeis": "acoalhar",
    "acoalhas": "acoalhar",
    "acoalhasse": "acoalhar",
    "acoalhassem": "acoalhar",
    "acoalhasses": "acoalhar",
    "acoalhaste": "acoalhar",
    "acoalhastes": "acoalhar",
    "acoalhava": "acoalhar",
    "acoalhavam": "acoalhar",
    "acoalhavas": "acoalhar",
    "acoalhe": "acoalhar",
    "acoalhei": "acoalhar",
    "acoalheis": "acoalhar",
    "acoalhem": "acoalhar",
    "acoalhemo": "acoalhar",
    "acoalhemos": "acoalhar",
    "acoalhes": "acoalhar",
    "acoalho": "acoalhar",
    "acoalhou": "acoalhar",
    "acoalhá": "acoalhar",
    "acoalhámo": "acoalhar",
    "acoalhámos": "acoalhar",
    "acoalháramo": "acoalhar",
    "acoalháramos": "acoalhar",
    "acoalhárei": "acoalhar",
    "acoalháreis": "acoalhar",
    "acoalhásseis": "acoalhar",
    "acoalhássemos": "acoalhar",
    "acoalhávamo": "acoalhar",
    "acoalhávamos": "acoalhar",
    "acoalhávei": "acoalhar",
    "acoalháveis": "acoalhar",
    "acoaramurus": "acoaramuru",
    "acobarda": "acobardar",
    "acobardada": "acobardar",
    "acobardadas": "acobardar",
    "acobardado": "acobardar",
    "acobardados": "acobardar",
    "acobardadíssima": "acobardado",
    "acobardadíssimas": "acobardado",
    "acobardadíssimo": "acobardado",
    "acobardadíssimos": "acobardado",
    "acobardai": "acobardar",
    "acobardais": "acobardar",
    "acobardam": "acobardar",
    "acobardamentos": "acobardamento",
    "acobardamo": "acobardar",
    "acobardamos": "acobardar",
    "acobardando": "acobardar",
    "acobardara": "acobardar",
    "acobardaram": "acobardar",
    "acobardaras": "acobardar",
    "acobardarde": "acobardar",
    "acobardardes": "acobardar",
    "acobardare": "acobardar",
    "acobardarei": "acobardar",
    "acobardareis": "acobardar",
    "acobardarem": "acobardar",
    "acobardaremos": "acobardar",
    "acobardares": "acobardar",
    "acobardaria": "acobardar",
    "acobardariam": "acobardar",
    "acobardarias": "acobardar",
    "acobardarmo": "acobardar",
    "acobardarmos": "acobardar",
    "acobardará": "acobardar",
    "acobardarás": "acobardar",
    "acobardarão": "acobardar",
    "acobardaríamos": "acobardar",
    "acobardaríeis": "acobardar",
    "acobardas": "acobardar",
    "acobardasse": "acobardar",
    "acobardassem": "acobardar",
    "acobardasses": "acobardar",
    "acobardaste": "acobardar",
    "acobardastes": "acobardar",
    "acobardava": "acobardar",
    "acobardavam": "acobardar",
    "acobardavas": "acobardar",
    "acobarde": "acobardar",
    "acobardei": "acobardar",
    "acobardeis": "acobardar",
    "acobardem": "acobardar",
    "acobardemo": "acobardar",
    "acobardemos": "acobardar",
    "acobardes": "acobardar",
    "acobardo": "acobardar",
    "acobardou": "acobardar",
    "acobardá": "acobardar",
    "acobardámo": "acobardar",
    "acobardámos": "acobardar",
    "acobardáramo": "acobardar",
    "acobardáramos": "acobardar",
    "acobardárei": "acobardar",
    "acobardáreis": "acobardar",
    "acobardásseis": "acobardar",
    "acobardássemos": "acobardar",
    "acobardávamo": "acobardar",
    "acobardávamos": "acobardar",
    "acobardávei": "acobardar",
    "acobardáveis": "acobardar",
    "acoberta": "acobertar",
    "acobertada": "acobertar",
    "acobertadas": "acobertar",
    "acobertado": "acobertar",
    "acobertados": "acobertar",
    "acobertai": "acobertar",
    "acobertais": "acobertar",
    "acobertam": "acobertar",
    "acobertamo": "acobertar",
    "acobertamos": "acobertar",
    "acobertando": "acobertar",
    "acobertara": "acobertar",
    "acobertaram": "acobertar",
    "acobertaras": "acobertar",
    "acobertarde": "acobertar",
    "acobertardes": "acobertar",
    "acobertare": "acobertar",
    "acobertarei": "acobertar",
    "acobertareis": "acobertar",
    "acobertarem": "acobertar",
    "acobertaremos": "acobertar",
    "acobertares": "acobertar",
    "acobertaria": "acobertar",
    "acobertariam": "acobertar",
    "acobertarias": "acobertar",
    "acobertarmo": "acobertar",
    "acobertarmos": "acobertar",
    "acobertará": "acobertar",
    "acobertarás": "acobertar",
    "acobertarão": "acobertar",
    "acobertaríamos": "acobertar",
    "acobertaríeis": "acobertar",
    "acobertas": "acobertar",
    "acobertasse": "acobertar",
    "acobertassem": "acobertar",
    "acobertasses": "acobertar",
    "acobertaste": "acobertar",
    "acobertastes": "acobertar",
    "acobertava": "acobertar",
    "acobertavam": "acobertar",
    "acobertavas": "acobertar",
    "acoberte": "acobertar",
    "acobertei": "acobertar",
    "acoberteis": "acobertar",
    "acobertem": "acobertar",
    "acobertemo": "acobertar",
    "acobertemos": "acobertar",
    "acobertes": "acobertar",
    "acoberto": "acobertar",
    "acobertou": "acobertar",
    "acobertá": "acobertar",
    "acobertámo": "acobertar",
    "acobertámos": "acobertar",
    "acobertáramo": "acobertar",
    "acobertáramos": "acobertar",
    "acobertárei": "acobertar",
    "acobertáreis": "acobertar",
    "acobertásseis": "acobertar",
    "acobertássemos": "acobertar",
    "acobertávamo": "acobertar",
    "acobertávamos": "acobertar",
    "acobertávei": "acobertar",
    "acobertáveis": "acobertar",
    "acobreada": "acobrear",
    "acobreadas": "acobrear",
    "acobreado": "acobrear",
    "acobreados": "acobrear",
    "acobreai": "acobrear",
    "acobreais": "acobrear",
    "acobreamo": "acobrear",
    "acobreamos": "acobrear",
    "acobreando": "acobrear",
    "acobreara": "acobrear",
    "acobrearam": "acobrear",
    "acobrearas": "acobrear",
    "acobrearde": "acobrear",
    "acobreardes": "acobrear",
    "acobreare": "acobrear",
    "acobrearei": "acobrear",
    "acobreareis": "acobrear",
    "acobrearem": "acobrear",
    "acobrearemos": "acobrear",
    "acobreares": "acobrear",
    "acobrearia": "acobrear",
    "acobreariam": "acobrear",
    "acobrearias": "acobrear",
    "acobrearmo": "acobrear",
    "acobrearmos": "acobrear",
    "acobreará": "acobrear",
    "acobrearás": "acobrear",
    "acobrearão": "acobrear",
    "acobrearíamos": "acobrear",
    "acobrearíeis": "acobrear",
    "acobreasse": "acobrear",
    "acobreassem": "acobrear",
    "acobreasses": "acobrear",
    "acobreaste": "acobrear",
    "acobreastes": "acobrear",
    "acobreava": "acobrear",
    "acobreavam": "acobrear",
    "acobreavas": "acobrear",
    "acobreei": "acobrear",
    "acobreeis": "acobrear",
    "acobreemo": "acobrear",
    "acobreemos": "acobrear",
    "acobreia": "acobrear",
    "acobreiam": "acobrear",
    "acobreias": "acobrear",
    "acobreie": "acobrear",
    "acobreiem": "acobrear",
    "acobreies": "acobrear",
    "acobreio": "acobrear",
    "acobreou": "acobrear",
    "acobreá": "acobrear",
    "acobreámo": "acobrear",
    "acobreámos": "acobrear",
    "acobreáramo": "acobrear",
    "acobreáramos": "acobrear",
    "acobreárei": "acobrear",
    "acobreáreis": "acobrear",
    "acobreásseis": "acobrear",
    "acobreássemos": "acobrear",
    "acobreávamo": "acobrear",
    "acobreávamos": "acobrear",
    "acobreávei": "acobrear",
    "acobreáveis": "acobreável",
    "acocada": "acocado",
    "acocadas": "acocado",
    "acocadazinha": "acocado",
    "acocadazinhas": "acocado",
    "acocadazita": "acocado",
    "acocadazitas": "acocado",
    "acocadinha": "acocado",
    "acocadinhas": "acocado",
    "acocadinho": "acocado",
    "acocadinhos": "acocado",
    "acocadita": "acocado",
    "acocaditas": "acocado",
    "acocadito": "acocado",
    "acocaditos": "acocado",
    "acocados": "acocado",
    "acocadozinho": "acocado",
    "acocadozinhos": "acocado",
    "acocadozito": "acocado",
    "acocadozitos": "acocado",
    "acocações": "acocação",
    "acocha": "acochar",
    "acochada": "acochar",
    "acochadas": "acochar",
    "acochado": "acochar",
    "acochados": "acochar",
    "acochai": "acochar",
    "acochais": "acochar",
    "acocham": "acochar",
    "acochamo": "acochar",
    "acochamos": "acochar",
    "acochando": "acochar",
    "acochara": "acochar",
    "acocharam": "acochar",
    "acocharas": "acochar",
    "acocharde": "acochar",
    "acochardes": "acochar",
    "acochare": "acochar",
    "acocharei": "acochar",
    "acochareis": "acochar",
    "acocharem": "acochar",
    "acocharemos": "acochar",
    "acochares": "acochar",
    "acocharia": "acochar",
    "acochariam": "acochar",
    "acocharias": "acochar",
    "acocharmo": "acochar",
    "acocharmos": "acochar",
    "acochará": "acochar",
    "acocharás": "acochar",
    "acocharão": "acochar",
    "acocharíamos": "acochar",
    "acocharíeis": "acochar",
    "acochas": "acochar",
    "acochasse": "acochar",
    "acochassem": "acochar",
    "acochasses": "acochar",
    "acochaste": "acochar",
    "acochastes": "acochar",
    "acochava": "acochar",
    "acochavam": "acochar",
    "acochavas": "acochar",
    "acoche": "acochar",
    "acochei": "acochar",
    "acocheis": "acochar",
    "acochem": "acochar",
    "acochemo": "acochar",
    "acochemos": "acochar",
    "acoches": "acochar",
    "acochicha": "acochichar",
    "acochichada": "acochichar",
    "acochichadas": "acochichar",
    "acochichado": "acochichar",
    "acochichados": "acochichar",
    "acochichai": "acochichar",
    "acochichais": "acochichar",
    "acochicham": "acochichar",
    "acochichamo": "acochichar",
    "acochichamos": "acochichar",
    "acochichando": "acochichar",
    "acochichara": "acochichar",
    "acochicharam": "acochichar",
    "acochicharas": "acochichar",
    "acochicharde": "acochichar",
    "acochichardes": "acochichar",
    "acochichare": "acochichar",
    "acochicharei": "acochichar",
    "acochichareis": "acochichar",
    "acochicharem": "acochichar",
    "acochicharemos": "acochichar",
    "acochichares": "acochichar",
    "acochicharia": "acochichar",
    "acochichariam": "acochichar",
    "acochicharias": "acochichar",
    "acochicharmo": "acochichar",
    "acochicharmos": "acochichar",
    "acochichará": "acochichar",
    "acochicharás": "acochichar",
    "acochicharão": "acochichar",
    "acochicharíamos": "acochichar",
    "acochicharíeis": "acochichar",
    "acochichas": "acochichar",
    "acochichasse": "acochichar",
    "acochichassem": "acochichar",
    "acochichasses": "acochichar",
    "acochichaste": "acochichar",
    "acochichastes": "acochichar",
    "acochichava": "acochichar",
    "acochichavam": "acochichar",
    "acochichavas": "acochichar",
    "acochiche": "acochichar",
    "acochichei": "acochichar",
    "acochicheis": "acochichar",
    "acochichem": "acochichar",
    "acochichemo": "acochichar",
    "acochichemos": "acochichar",
    "acochiches": "acochichar",
    "acochicho": "acochichar",
    "acochichou": "acochichar",
    "acochichá": "acochichar",
    "acochichámo": "acochichar",
    "acochichámos": "acochichar",
    "acochicháramo": "acochichar",
    "acochicháramos": "acochichar",
    "acochichárei": "acochichar",
    "acochicháreis": "acochichar",
    "acochichásseis": "acochichar",
    "acochichássemos": "acochichar",
    "acochichávamo": "acochichar",
    "acochichávamos": "acochichar",
    "acochichávei": "acochichar",
    "acochicháveis": "acochichar",
    "acocho": "acochar",
    "acochos": "acocho",
    "acochou": "acochar",
    "acochá": "acochar",
    "acochámo": "acochar",
    "acochámos": "acochar",
    "acocháramo": "acochar",
    "acocháramos": "acochar",
    "acochárei": "acochar",
    "acocháreis": "acochar",
    "acochásseis": "acochar",
    "acochássemos": "acochar",
    "acochávamo": "acochar",
    "acochávamos": "acochar",
    "acochávei": "acochar",
    "acocháveis": "acochar",
    "acocora": "acocorar",
    "acocorada": "acocorar",
    "acocoradas": "acocorar",
    "acocorado": "acocorar",
    "acocorados": "acocorar",
    "acocorai": "acocorar",
    "acocorais": "acocorar",
    "acocoram": "acocorar",
    "acocoramentos": "acocoramento",
    "acocoramo": "acocorar",
    "acocoramos": "acocorar",
    "acocorando": "acocorar",
    "acocorara": "acocorar",
    "acocoraram": "acocorar",
    "acocoraras": "acocorar",
    "acocorarde": "acocorar",
    "acocorardes": "acocorar",
    "acocorare": "acocorar",
    "acocorarei": "acocorar",
    "acocorareis": "acocorar",
    "acocorarem": "acocorar",
    "acocoraremos": "acocorar",
    "acocorares": "acocorar",
    "acocoraria": "acocorar",
    "acocorariam": "acocorar",
    "acocorarias": "acocorar",
    "acocorarmo": "acocorar",
    "acocorarmos": "acocorar",
    "acocorará": "acocorar",
    "acocorarás": "acocorar",
    "acocorarão": "acocorar",
    "acocoraríamos": "acocorar",
    "acocoraríeis": "acocorar",
    "acocoras": "acocorar",
    "acocorasse": "acocorar",
    "acocorassem": "acocorar",
    "acocorasses": "acocorar",
    "acocoraste": "acocorar",
    "acocorastes": "acocorar",
    "acocorava": "acocorar",
    "acocoravam": "acocorar",
    "acocoravas": "acocorar",
    "acocorações": "acocoração",
    "acocore": "acocorar",
    "acocorei": "acocorar",
    "acocoreis": "acocorar",
    "acocorem": "acocorar",
    "acocoremo": "acocorar",
    "acocoremos": "acocorar",
    "acocores": "acocorar",
    "acocoro": "acocorar",
    "acocorou": "acocorar",
    "acocorá": "acocorar",
    "acocorámo": "acocorar",
    "acocorámos": "acocorar",
    "acocoráramo": "acocorar",
    "acocoráramos": "acocorar",
    "acocorárei": "acocorar",
    "acocoráreis": "acocorar",
    "acocorásseis": "acocorar",
    "acocorássemos": "acocorar",
    "acocorávamo": "acocorar",
    "acocorávamos": "acocorar",
    "acocorávei": "acocorar",
    "acocoráveis": "acocorar",
    "acode": "acudir",
    "acodem": "acudir",
    "acodes": "acudir",
    "acognosias": "acognosia",
    "acogoladuras": "acogoladura",
    "acogombrada": "acogombrado",
    "acogombradas": "acogombrado",
    "acogombrados": "acogombrado",
    "acogula": "acogular",
    "acogulada": "acogular",
    "acoguladas": "acogular",
    "acogulado": "acogular",
    "acogulados": "acogular",
    "acogulai": "acogular",
    "acogulais": "acogular",
    "acogulam": "acogular",
    "acogulamo": "acogular",
    "acogulamos": "acogular",
    "acogulando": "acogular",
    "acogulara": "acogular",
    "acogularam": "acogular",
    "acogularas": "acogular",
    "acogularde": "acogular",
    "acogulardes": "acogular",
    "acogulare": "acogular",
    "acogularei": "acogular",
    "acogulareis": "acogular",
    "acogularem": "acogular",
    "acogularemos": "acogular",
    "acogulares": "acogular",
    "acogularia": "acogular",
    "acogulariam": "acogular",
    "acogularias": "acogular",
    "acogularmo": "acogular",
    "acogularmos": "acogular",
    "acogulará": "acogular",
    "acogularás": "acogular",
    "acogularão": "acogular",
    "acogularíamos": "acogular",
    "acogularíeis": "acogular",
    "acogulas": "acogular",
    "acogulasse": "acogular",
    "acogulassem": "acogular",
    "acogulasses": "acogular",
    "acogulaste": "acogular",
    "acogulastes": "acogular",
    "acogulava": "acogular",
    "acogulavam": "acogular",
    "acogulavas": "acogular",
    "acogule": "acogular",
    "acogulei": "acogular",
    "acoguleis": "acogular",
    "acogulem": "acogular",
    "acogulemo": "acogular",
    "acogulemos": "acogular",
    "acogules": "acogular",
    "acogulo": "acogular",
    "acogulou": "acogular",
    "acogulá": "acogular",
    "acogulámo": "acogular",
    "acogulámos": "acogular",
    "acoguláramo": "acogular",
    "acoguláramos": "acogular",
    "acogulárei": "acogular",
    "acoguláreis": "acogular",
    "acogulásseis": "acogular",
    "acogulássemos": "acogular",
    "acogulávamo": "acogular",
    "acogulávamos": "acogular",
    "acogulávei": "acogular",
    "acoguláveis": "acogular",
    "acoima": "acoimar",
    "acoimada": "acoimar",
    "acoimadas": "acoimar",
    "acoimadeira": "acoimador",
    "acoimadeiras": "acoimador",
    "acoimado": "acoimar",
    "acoimadora": "acoimador",
    "acoimadoras": "acoimador",
    "acoimadores": "acoimador",
    "acoimados": "acoimar",
    "acoimai": "acoimar",
    "acoimais": "acoimar",
    "acoimam": "acoimar",
    "acoimamo": "acoimar",
    "acoimamos": "acoimar",
    "acoimando": "acoimar",
    "acoimara": "acoimar",
    "acoimaram": "acoimar",
    "acoimaras": "acoimar",
    "acoimarde": "acoimar",
    "acoimardes": "acoimar",
    "acoimare": "acoimar",
    "acoimarei": "acoimar",
    "acoimareis": "acoimar",
    "acoimarem": "acoimar",
    "acoimaremos": "acoimar",
    "acoimares": "acoimar",
    "acoimaria": "acoimar",
    "acoimariam": "acoimar",
    "acoimarias": "acoimar",
    "acoimarmo": "acoimar",
    "acoimarmos": "acoimar",
    "acoimará": "acoimar",
    "acoimarás": "acoimar",
    "acoimarão": "acoimar",
    "acoimaríamos": "acoimar",
    "acoimaríeis": "acoimar",
    "acoimas": "acoimar",
    "acoimasse": "acoimar",
    "acoimassem": "acoimar",
    "acoimasses": "acoimar",
    "acoimaste": "acoimar",
    "acoimastes": "acoimar",
    "acoimava": "acoimar",
    "acoimavam": "acoimar",
    "acoimavas": "acoimar",
    "acoime": "acoimar",
    "acoimei": "acoimar",
    "acoimeis": "acoimar",
    "acoimem": "acoimar",
    "acoimemo": "acoimar",
    "acoimemos": "acoimar",
    "acoimes": "acoimar",
    "acoimo": "acoimar",
    "acoimou": "acoimar",
    "acoimá": "acoimar",
    "acoimámo": "acoimar",
    "acoimámos": "acoimar",
    "acoimáramo": "acoimar",
    "acoimáramos": "acoimar",
    "acoimárei": "acoimar",
    "acoimáreis": "acoimar",
    "acoimásseis": "acoimar",
    "acoimássemos": "acoimar",
    "acoimávamo": "acoimar",
    "acoimávamos": "acoimar",
    "acoimávei": "acoimar",
    "acoimáveis": "acoimar",
    "acoirela": "acoirelar",
    "acoirelada": "acoirelar",
    "acoireladas": "acoirelar",
    "acoirelado": "acoirelar",
    "acoirelados": "acoirelar",
    "acoirelai": "acoirelar",
    "acoirelais": "acoirelar",
    "acoirelam": "acoirelar",
    "acoirelamentos": "acoirelamento",
    "acoirelamo": "acoirelar",
    "acoirelamos": "acoirelar",
    "acoirelando": "acoirelar",
    "acoirelara": "acoirelar",
    "acoirelaram": "acoirelar",
    "acoirelaras": "acoirelar",
    "acoirelarde": "acoirelar",
    "acoirelardes": "acoirelar",
    "acoirelare": "acoirelar",
    "acoirelarei": "acoirelar",
    "acoirelareis": "acoirelar",
    "acoirelarem": "acoirelar",
    "acoirelaremos": "acoirelar",
    "acoirelares": "acoirelar",
    "acoirelaria": "acoirelar",
    "acoirelariam": "acoirelar",
    "acoirelarias": "acoirelar",
    "acoirelarmo": "acoirelar",
    "acoirelarmos": "acoirelar",
    "acoirelará": "acoirelar",
    "acoirelarás": "acoirelar",
    "acoirelarão": "acoirelar",
    "acoirelaríamos": "acoirelar",
    "acoirelaríeis": "acoirelar",
    "acoirelas": "acoirelar",
    "acoirelasse": "acoirelar",
    "acoirelassem": "acoirelar",
    "acoirelasses": "acoirelar",
    "acoirelaste": "acoirelar",
    "acoirelastes": "acoirelar",
    "acoirelava": "acoirelar",
    "acoirelavam": "acoirelar",
    "acoirelavas": "acoirelar",
    "acoirele": "acoirelar",
    "acoirelei": "acoirelar",
    "acoireleis": "acoirelar",
    "acoirelem": "acoirelar",
    "acoirelemo": "acoirelar",
    "acoirelemos": "acoirelar",
    "acoireles": "acoirelar",
    "acoirelo": "acoirelar",
    "acoirelou": "acoirelar",
    "acoirelá": "acoirelar",
    "acoirelámo": "acoirelar",
    "acoirelámos": "acoirelar",
    "acoireláramo": "acoirelar",
    "acoireláramos": "acoirelar",
    "acoirelárei": "acoirelar",
    "acoireláreis": "acoirelar",
    "acoirelásseis": "acoirelar",
    "acoirelássemos": "acoirelar",
    "acoirelávamo": "acoirelar",
    "acoirelávamos": "acoirelar",
    "acoirelávei": "acoirelar",
    "acoireláveis": "acoirelar",
    "acoita": "acoitar",
    "acoitada": "acoitar",
    "acoitadas": "acoitar",
    "acoitado": "acoitar",
    "acoitadora": "acoitador",
    "acoitadoras": "acoitador",
    "acoitadores": "acoitador",
    "acoitados": "acoitar",
    "acoitai": "acoitar",
    "acoitais": "acoitar",
    "acoitam": "acoitar",
    "acoitamentos": "acoitamento",
    "acoitamo": "acoitar",
    "acoitamos": "acoitar",
    "acoitando": "acoitar",
    "acoitara": "acoitar",
    "acoitaram": "acoitar",
    "acoitaras": "acoitar",
    "acoitarde": "acoitar",
    "acoitardes": "acoitar",
    "acoitare": "acoitar",
    "acoitarei": "acoitar",
    "acoitareis": "acoitar",
    "acoitarem": "acoitar",
    "acoitaremos": "acoitar",
    "acoitares": "acoitar",
    "acoitaria": "acoitar",
    "acoitariam": "acoitar",
    "acoitarias": "acoitar",
    "acoitarmo": "acoitar",
    "acoitarmos": "acoitar",
    "acoitará": "acoitar",
    "acoitarás": "acoitar",
    "acoitarão": "acoitar",
    "acoitaríamos": "acoitar",
    "acoitaríeis": "acoitar",
    "acoitas": "acoitar",
    "acoitasse": "acoitar",
    "acoitassem": "acoitar",
    "acoitasses": "acoitar",
    "acoitaste": "acoitar",
    "acoitastes": "acoitar",
    "acoitava": "acoitar",
    "acoitavam": "acoitar",
    "acoitavas": "acoitar",
    "acoite": "acoitar",
    "acoitei": "acoitar",
    "acoiteis": "acoitar",
    "acoitem": "acoitar",
    "acoitemo": "acoitar",
    "acoitemos": "acoitar",
    "acoites": "acoitar",
    "acoito": "acoitar",
    "acoitos": "acoito",
    "acoitou": "acoitar",
    "acoitá": "acoitar",
    "acoitámo": "acoitar",
    "acoitámos": "acoitar",
    "acoitáramo": "acoitar",
    "acoitáramos": "acoitar",
    "acoitárei": "acoitar",
    "acoitáreis": "acoitar",
    "acoitásseis": "acoitar",
    "acoitássemos": "acoitar",
    "acoitávamo": "acoitar",
    "acoitávamos": "acoitar",
    "acoitávei": "acoitar",
    "acoitáveis": "acoitar",
    "acolcheta": "acolchetar",
    "acolchetada": "acolchetar",
    "acolchetadas": "acolchetar",
    "acolchetadeira": "acolchetador",
    "acolchetadeiras": "acolchetador",
    "acolchetado": "acolchetar",
    "acolchetadora": "acolchetador",
    "acolchetadoras": "acolchetador",
    "acolchetadores": "acolchetador",
    "acolchetados": "acolchetar",
    "acolchetai": "acolchetar",
    "acolchetais": "acolchetar",
    "acolchetam": "acolchetar",
    "acolchetamentos": "acolchetamento",
    "acolchetamo": "acolchetar",
    "acolchetamos": "acolchetar",
    "acolchetando": "acolchetar",
    "acolchetara": "acolchetar",
    "acolchetaram": "acolchetar",
    "acolchetaras": "acolchetar",
    "acolchetarde": "acolchetar",
    "acolchetardes": "acolchetar",
    "acolchetare": "acolchetar",
    "acolchetarei": "acolchetar",
    "acolchetareis": "acolchetar",
    "acolchetarem": "acolchetar",
    "acolchetaremos": "acolchetar",
    "acolchetares": "acolchetar",
    "acolchetaria": "acolchetar",
    "acolchetariam": "acolchetar",
    "acolchetarias": "acolchetar",
    "acolchetarmo": "acolchetar",
    "acolchetarmos": "acolchetar",
    "acolchetará": "acolchetar",
    "acolchetarás": "acolchetar",
    "acolchetarão": "acolchetar",
    "acolchetaríamos": "acolchetar",
    "acolchetaríeis": "acolchetar",
    "acolchetas": "acolchetar",
    "acolchetasse": "acolchetar",
    "acolchetassem": "acolchetar",
    "acolchetasses": "acolchetar",
    "acolchetaste": "acolchetar",
    "acolchetastes": "acolchetar",
    "acolchetava": "acolchetar",
    "acolchetavam": "acolchetar",
    "acolchetavas": "acolchetar",
    "acolchete": "acolchetar",
    "acolchetei": "acolchetar",
    "acolcheteis": "acolchetar",
    "acolchetem": "acolchetar",
    "acolchetemo": "acolchetar",
    "acolchetemos": "acolchetar",
    "acolchetes": "acolchetar",
    "acolcheto": "acolchetar",
    "acolchetou": "acolchetar",
    "acolchetá": "acolchetar",
    "acolchetámo": "acolchetar",
    "acolchetámos": "acolchetar",
    "acolchetáramo": "acolchetar",
    "acolchetáramos": "acolchetar",
    "acolchetárei": "acolchetar",
    "acolchetáreis": "acolchetar",
    "acolchetásseis": "acolchetar",
    "acolchetássemos": "acolchetar",
    "acolchetávamo": "acolchetar",
    "acolchetávamos": "acolchetar",
    "acolchetávei": "acolchetar",
    "acolchetáveis": "acolchetar",
    "acolchoa": "acolchoar",
    "acolchoada": "acolchoar",
    "acolchoadas": "acolchoar",
    "acolchoadazinha": "acolchoado",
    "acolchoadazinhas": "acolchoado",
    "acolchoadazita": "acolchoado",
    "acolchoadazitas": "acolchoado",
    "acolchoadeiras": "acolchoadeira",
    "acolchoadinha": "acolchoado",
    "acolchoadinhas": "acolchoado",
    "acolchoadinho": "acolchoado",
    "acolchoadinhos": "acolchoado",
    "acolchoadita": "acolchoado",
    "acolchoaditas": "acolchoado",
    "acolchoadito": "acolchoado",
    "acolchoaditos": "acolchoado",
    "acolchoado": "acolchoar",
    "acolchoados": "acolchoar",
    "acolchoadozinho": "acolchoado",
    "acolchoadozinhos": "acolchoado",
    "acolchoadozito": "acolchoado",
    "acolchoadozitos": "acolchoado",
    "acolchoai": "acolchoar",
    "acolchoais": "acolchoar",
    "acolchoam": "acolchoar",
    "acolchoamentos": "acolchoamento",
    "acolchoamo": "acolchoar",
    "acolchoamos": "acolchoar",
    "acolchoando": "acolchoar",
    "acolchoara": "acolchoar",
    "acolchoaram": "acolchoar",
    "acolchoaras": "acolchoar",
    "acolchoarde": "acolchoar",
    "acolchoardes": "acolchoar",
    "acolchoare": "acolchoar",
    "acolchoarei": "acolchoar",
    "acolchoareis": "acolchoar",
    "acolchoarem": "acolchoar",
    "acolchoaremos": "acolchoar",
    "acolchoares": "acolchoar",
    "acolchoaria": "acolchoar",
    "acolchoariam": "acolchoar",
    "acolchoarias": "acolchoar",
    "acolchoarmo": "acolchoar",
    "acolchoarmos": "acolchoar",
    "acolchoará": "acolchoar",
    "acolchoarás": "acolchoar",
    "acolchoarão": "acolchoar",
    "acolchoaríamos": "acolchoar",
    "acolchoaríeis": "acolchoar",
    "acolchoas": "acolchoar",
    "acolchoasse": "acolchoar",
    "acolchoassem": "acolchoar",
    "acolchoasses": "acolchoar",
    "acolchoaste": "acolchoar",
    "acolchoastes": "acolchoar",
    "acolchoava": "acolchoar",
    "acolchoavam": "acolchoar",
    "acolchoavas": "acolchoar",
    "acolchoe": "acolchoar",
    "acolchoei": "acolchoar",
    "acolchoeis": "acolchoar",
    "acolchoem": "acolchoar",
    "acolchoemo": "acolchoar",
    "acolchoemos": "acolchoar",
    "acolchoes": "acolchoar",
    "acolchoo": "acolchoar",
    "acolchoou": "acolchoar",
    "acolchoá": "acolchoar",
    "acolchoámo": "acolchoar",
    "acolchoámos": "acolchoar",
    "acolchoáramo": "acolchoar",
    "acolchoáramos": "acolchoar",
    "acolchoárei": "acolchoar",
    "acolchoáreis": "acolchoar",
    "acolchoásseis": "acolchoar",
    "acolchoássemos": "acolchoar",
    "acolchoávamo": "acolchoar",
    "acolchoávamos": "acolchoar",
    "acolchoávei": "acolchoar",
    "acolchoáveis": "acolchoar",
    "acoletada": "acoletado",
    "acoletadas": "acoletado",
    "acoletados": "acoletado",
    "acolha": "acolher",
    "acolhais": "acolher",
    "acolham": "acolher",
    "acolhamo": "acolher",
    "acolhamos": "acolher",
    "acolhas": "acolher",
    "acolhe": "acolher",
    "acolhedora": "acolhedor",
    "acolhedoras": "acolhedor",
    "acolhedores": "acolhedor",
    "acolhei": "acolher",
    "acolheis": "acolher",
    "acolheitas": "acolheita",
    "acolhem": "acolher",
    "acolhemo": "acolher",
    "acolhemos": "acolher",
    "acolhendo": "acolher",
    "acolhera": "acolherar",
    "acolherada": "acolherar",
    "acolheradas": "acolherar",
    "acolherado": "acolherar",
    "acolherados": "acolherar",
    "acolherai": "acolherar",
    "acolherais": "acolherar",
    "acolheram": "acolherar",
    "acolheramo": "acolherar",
    "acolheramos": "acolherar",
    "acolherando": "acolherar",
    "acolherara": "acolherar",
    "acolheraram": "acolherar",
    "acolheraras": "acolherar",
    "acolherarde": "acolherar",
    "acolherardes": "acolherar",
    "acolherare": "acolherar",
    "acolherarei": "acolherar",
    "acolherareis": "acolherar",
    "acolherarem": "acolherar",
    "acolheraremos": "acolherar",
    "acolherares": "acolherar",
    "acolheraria": "acolherar",
    "acolherariam": "acolherar",
    "acolherarias": "acolherar",
    "acolherarmo": "acolherar",
    "acolherarmos": "acolherar",
    "acolherará": "acolherar",
    "acolherarás": "acolherar",
    "acolherarão": "acolherar",
    "acolheraríamos": "acolherar",
    "acolheraríeis": "acolherar",
    "acolheras": "acolherar",
    "acolherasse": "acolherar",
    "acolherassem": "acolherar",
    "acolherasses": "acolherar",
    "acolheraste": "acolherar",
    "acolherastes": "acolherar",
    "acolherava": "acolherar",
    "acolheravam": "acolherar",
    "acolheravas": "acolherar",
    "acolherde": "acolher",
    "acolherdes": "acolher",
    "acolhere": "acolherar",
    "acolherei": "acolherar",
    "acolhereis": "acolherar",
    "acolherem": "acolherar",
    "acolheremo": "acolherar",
    "acolheremos": "acolherar",
    "acolheres": "acolherar",
    "acolheria": "acolher",
    "acolheriam": "acolher",
    "acolherias": "acolher",
    "acolhermo": "acolher",
    "acolhermos": "acolher",
    "acolhero": "acolherar",
    "acolherou": "acolherar",
    "acolherá": "acolherar",
    "acolherámo": "acolherar",
    "acolherámos": "acolherar",
    "acolheráramo": "acolherar",
    "acolheráramos": "acolherar",
    "acolherárei": "acolherar",
    "acolheráreis": "acolherar",
    "acolherás": "acolher",
    "acolherásseis": "acolherar",
    "acolherássemos": "acolherar",
    "acolherávamo": "acolherar",
    "acolherávamos": "acolherar",
    "acolherávei": "acolherar",
    "acolheráveis": "acolherar",
    "acolherão": "acolher",
    "acolheríamos": "acolher",
    "acolheríeis": "acolher",
    "acolhes": "acolher",
    "acolhesse": "acolher",
    "acolhessem": "acolher",
    "acolhesses": "acolher",
    "acolheste": "acolher",
    "acolhestes": "acolher",
    "acolheu": "acolher",
    "acolhi": "acolher",
    "acolhia": "acolher",
    "acolhiam": "acolher",
    "acolhias": "acolher",
    "acolhida": "acolhido",
    "acolhidas": "acolhido",
    "acolhido": "acolher",
    "acolhidos": "acolhido",
    "acolhimentos": "acolhimento",
    "acolho": "acolher",
    "acolhê": "acolher",
    "acolhêramo": "acolher",
    "acolhêramos": "acolher",
    "acolhêrei": "acolher",
    "acolhêreis": "acolher",
    "acolhêsseis": "acolher",
    "acolhêssemos": "acolher",
    "acolhíamo": "acolher",
    "acolhíamos": "acolher",
    "acolhíei": "acolher",
    "acolhíeis": "acolher",
    "acolhíveis": "acolhível",
    "acolias": "acolia",
    "acolita": "acolitar",
    "acolitada": "acolitar",
    "acolitadas": "acolitar",
    "acolitado": "acolitar",
    "acolitados": "acolitar",
    "acolitai": "acolitar",
    "acolitais": "acolitar",
    "acolitam": "acolitar",
    "acolitamo": "acolitar",
    "acolitamos": "acolitar",
    "acolitando": "acolitar",
    "acolitara": "acolitar",
    "acolitaram": "acolitar",
    "acolitaras": "acolitar",
    "acolitarde": "acolitar",
    "acolitardes": "acolitar",
    "acolitare": "acolitar",
    "acolitarei": "acolitar",
    "acolitareis": "acolitar",
    "acolitarem": "acolitar",
    "acolitaremos": "acolitar",
    "acolitares": "acolitar",
    "acolitaria": "acolitar",
    "acolitariam": "acolitar",
    "acolitarias": "acolitar",
    "acolitarmo": "acolitar",
    "acolitarmos": "acolitar",
    "acolitará": "acolitar",
    "acolitarás": "acolitar",
    "acolitarão": "acolitar",
    "acolitaríamos": "acolitar",
    "acolitaríeis": "acolitar",
    "acolitas": "acolitar",
    "acolitasse": "acolitar",
    "acolitassem": "acolitar",
    "acolitasses": "acolitar",
    "acolitaste": "acolitar",
    "acolitastes": "acolitar",
    "acolitava": "acolitar",
    "acolitavam": "acolitar",
    "acolitavas": "acolitar",
    "acolite": "acolitar",
    "acolitei": "acolitar",
    "acoliteis": "acolitar",
    "acolitem": "acolitar",
    "acolitemo": "acolitar",
    "acolitemos": "acolitar",
    "acolites": "acolitar",
    "acolito": "acolitar",
    "acolitou": "acolitar",
    "acolitá": "acolitar",
    "acolitámo": "acolitar",
    "acolitámos": "acolitar",
    "acolitáramo": "acolitar",
    "acolitáramos": "acolitar",
    "acolitárei": "acolitar",
    "acolitáreis": "acolitar",
    "acolitásseis": "acolitar",
    "acolitássemos": "acolitar",
    "acolitávamo": "acolitar",
    "acolitávamos": "acolitar",
    "acolitávei": "acolitar",
    "acolitáveis": "acolitar",
    "acologias": "acologia",
    "acomadra": "acomadrar",
    "acomadrada": "acomadrar",
    "acomadradas": "acomadrar",
    "acomadrado": "acomadrar",
    "acomadrados": "acomadrar",
    "acomadrai": "acomadrar",
    "acomadrais": "acomadrar",
    "acomadram": "acomadrar",
    "acomadramo": "acomadrar",
    "acomadramos": "acomadrar",
    "acomadrando": "acomadrar",
    "acomadrara": "acomadrar",
    "acomadraram": "acomadrar",
    "acomadraras": "acomadrar",
    "acomadrarde": "acomadrar",
    "acomadrardes": "acomadrar",
    "acomadrare": "acomadrar",
    "acomadrarei": "acomadrar",
    "acomadrareis": "acomadrar",
    "acomadrarem": "acomadrar",
    "acomadraremos": "acomadrar",
    "acomadrares": "acomadrar",
    "acomadraria": "acomadrar",
    "acomadrariam": "acomadrar",
    "acomadrarias": "acomadrar",
    "acomadrarmo": "acomadrar",
    "acomadrarmos": "acomadrar",
    "acomadrará": "acomadrar",
    "acomadrarás": "acomadrar",
    "acomadrarão": "acomadrar",
    "acomadraríamos": "acomadrar",
    "acomadraríeis": "acomadrar",
    "acomadras": "acomadrar",
    "acomadrasse": "acomadrar",
    "acomadrassem": "acomadrar",
    "acomadrasses": "acomadrar",
    "acomadraste": "acomadrar",
    "acomadrastes": "acomadrar",
    "acomadrava": "acomadrar",
    "acomadravam": "acomadrar",
    "acomadravas": "acomadrar",
    "acomadre": "acomadrar",
    "acomadrei": "acomadrar",
    "acomadreis": "acomadrar",
    "acomadrem": "acomadrar",
    "acomadremo": "acomadrar",
    "acomadremos": "acomadrar",
    "acomadres": "acomadrar",
    "acomadro": "acomadrar",
    "acomadrou": "acomadrar",
    "acomadrá": "acomadrar",
    "acomadrámo": "acomadrar",
    "acomadrámos": "acomadrar",
    "acomadráramo": "acomadrar",
    "acomadráramos": "acomadrar",
    "acomadrárei": "acomadrar",
    "acomadráreis": "acomadrar",
    "acomadrásseis": "acomadrar",
    "acomadrássemos": "acomadrar",
    "acomadrávamo": "acomadrar",
    "acomadrávamos": "acomadrar",
    "acomadrávei": "acomadrar",
    "acomadráveis": "acomadrar",
    "acometa": "acometer",
    "acometais": "acometer",
    "acometam": "acometer",
    "acometamo": "acometer",
    "acometamos": "acometer",
    "acometas": "acometer",
    "acomete": "acometer",
    "acometedora": "acometedor",
    "acometedoras": "acometedor",
    "acometedores": "acometedor",
    "acometei": "acometer",
    "acometeis": "acometer",
    "acometem": "acometer",
    "acometemo": "acometer",
    "acometemos": "acometer",
    "acometendo": "acometer",
    "acometera": "acometer",
    "acometeram": "acometer",
    "acometeras": "acometer",
    "acometerdes": "acometer",
    "acometerei": "acometer",
    "acometereis": "acometer",
    "acometerem": "acometer",
    "acometeremos": "acometer",
    "acometeres": "acometer",
    "acometeria": "acometer",
    "acometeriam": "acometer",
    "acometerias": "acometer",
    "acometermo": "acometer",
    "acometermos": "acometer",
    "acometerá": "acometer",
    "acometerás": "acometer",
    "acometerão": "acometer",
    "acometeríamos": "acometer",
    "acometeríeis": "acometer",
    "acometes": "acometer",
    "acometesse": "acometer",
    "acometessem": "acometer",
    "acometesses": "acometer",
    "acometeste": "acometer",
    "acometestes": "acometer",
    "acometeu": "acometer",
    "acometi": "acometer",
    "acometia": "acometer",
    "acometiam": "acometer",
    "acometias": "acometer",
    "acometida": "acometer",
    "acometidas": "acometida",
    "acometido": "acometer",
    "acometidos": "acometer",
    "acometimentos": "acometimento",
    "acometo": "acometer",
    "acometêramo": "acometer",
    "acometêramos": "acometer",
    "acometêreis": "acometer",
    "acometêsseis": "acometer",
    "acometêssemos": "acometer",
    "acometíamo": "acometer",
    "acometíamos": "acometer",
    "acometíeis": "acometer",
    "acometíveis": "acometível",
    "acomias": "acomia",
    "acomoda": "acomodar",
    "acomodada": "acomodar",
    "acomodadas": "acomodar",
    "acomodadiça": "acomodadiço",
    "acomodadiças": "acomodadiço",
    "acomodadiços": "acomodadiço",
    "acomodado": "acomodar",
    "acomodadora": "acomodador",
    "acomodadoras": "acomodador",
    "acomodadores": "acomodador",
    "acomodados": "acomodar",
    "acomodadíssima": "acomodado",
    "acomodadíssimas": "acomodado",
    "acomodadíssimo": "acomodado",
    "acomodadíssimos": "acomodado",
    "acomodai": "acomodar",
    "acomodais": "acomodar",
    "acomodam": "acomodar",
    "acomodamentos": "acomodamento",
    "acomodamo": "acomodar",
    "acomodamos": "acomodar",
    "acomodando": "acomodar",
    "acomodara": "acomodar",
    "acomodaram": "acomodar",
    "acomodaras": "acomodar",
    "acomodarde": "acomodar",
    "acomodardes": "acomodar",
    "acomodare": "acomodar",
    "acomodarei": "acomodar",
    "acomodareis": "acomodar",
    "acomodarem": "acomodar",
    "acomodaremos": "acomodar",
    "acomodares": "acomodar",
    "acomodaria": "acomodar",
    "acomodariam": "acomodar",
    "acomodarias": "acomodar",
    "acomodarmo": "acomodar",
    "acomodarmos": "acomodar",
    "acomodará": "acomodar",
    "acomodarás": "acomodar",
    "acomodarão": "acomodar",
    "acomodaríamos": "acomodar",
    "acomodaríeis": "acomodar",
    "acomodas": "acomodar",
    "acomodasse": "acomodar",
    "acomodassem": "acomodar",
    "acomodasses": "acomodar",
    "acomodaste": "acomodar",
    "acomodastes": "acomodar",
    "acomodatícia": "acomodatício",
    "acomodatícias": "acomodatício",
    "acomodatícios": "acomodatício",
    "acomodava": "acomodar",
    "acomodavam": "acomodar",
    "acomodavas": "acomodar",
    "acomodações": "acomodação",
    "acomode": "acomodar",
    "acomodei": "acomodar",
    "acomodeis": "acomodar",
    "acomodem": "acomodar",
    "acomodemo": "acomodar",
    "acomodemos": "acomodar",
    "acomodes": "acomodar",
    "acomodo": "acomodar",
    "acomodou": "acomodar",
    "acomodá": "acomodar",
    "acomodámo": "acomodar",
    "acomodámos": "acomodar",
    "acomodáramo": "acomodar",
    "acomodáramos": "acomodar",
    "acomodárei": "acomodar",
    "acomodáreis": "acomodar",
    "acomodásseis": "acomodar",
    "acomodássemos": "acomodar",
    "acomodávamo": "acomodar",
    "acomodávamos": "acomodar",
    "acomodávei": "acomodar",
    "acomodáveis": "acomodável",
    "acompadra": "acompadrar",
    "acompadrada": "acompadrar",
    "acompadradas": "acompadrar",
    "acompadrado": "acompadrar",
    "acompadrados": "acompadrar",
    "acompadrai": "acompadrar",
    "acompadrais": "acompadrar",
    "acompadram": "acompadrar",
    "acompadramo": "acompadrar",
    "acompadramos": "acompadrar",
    "acompadrando": "acompadrar",
    "acompadrara": "acompadrar",
    "acompadraram": "acompadrar",
    "acompadraras": "acompadrar",
    "acompadrarde": "acompadrar",
    "acompadrardes": "acompadrar",
    "acompadrare": "acompadrar",
    "acompadrarei": "acompadrar",
    "acompadrareis": "acompadrar",
    "acompadrarem": "acompadrar",
    "acompadraremos": "acompadrar",
    "acompadrares": "acompadrar",
    "acompadraria": "acompadrar",
    "acompadrariam": "acompadrar",
    "acompadrarias": "acompadrar",
    "acompadrarmo": "acompadrar",
    "acompadrarmos": "acompadrar",
    "acompadrará": "acompadrar",
    "acompadrarás": "acompadrar",
    "acompadrarão": "acompadrar",
    "acompadraríamos": "acompadrar",
    "acompadraríeis": "acompadrar",
    "acompadras": "acompadrar",
    "acompadrasse": "acompadrar",
    "acompadrassem": "acompadrar",
    "acompadrasses": "acompadrar",
    "acompadraste": "acompadrar",
    "acompadrastes": "acompadrar",
    "acompadrava": "acompadrar",
    "acompadravam": "acompadrar",
    "acompadravas": "acompadrar",
    "acompadre": "acompadrar",
    "acompadrei": "acompadrar",
    "acompadreis": "acompadrar",
    "acompadrem": "acompadrar",
    "acompadremo": "acompadrar",
    "acompadremos": "acompadrar",
    "acompadres": "acompadrar",
    "acompadro": "acompadrar",
    "acompadrou": "acompadrar",
    "acompadrá": "acompadrar",
    "acompadrámo": "acompadrar",
    "acompadrámos": "acompadrar",
    "acompadráramo": "acompadrar",
    "acompadráramos": "acompadrar",
    "acompadrárei": "acompadrar",
    "acompadráreis": "acompadrar",
    "acompadrásseis": "acompadrar",
    "acompadrássemos": "acompadrar",
    "acompadrávamo": "acompadrar",
    "acompadrávamos": "acompadrar",
    "acompadrávei": "acompadrar",
    "acompadráveis": "acompadrar",
    "acompanha": "acompanhar",
    "acompanhada": "acompanhar",
    "acompanhadas": "acompanhar",
    "acompanhadeira": "acompanhador",
    "acompanhadeiras": "acompanhador",
    "acompanhado": "acompanhar",
    "acompanhadora": "acompanhador",
    "acompanhadoras": "acompanhador",
    "acompanhadores": "acompanhador",
    "acompanhados": "acompanhar",
    "acompanhai": "acompanhar",
    "acompanhais": "acompanhar",
    "acompanham": "acompanhar",
    "acompanhamentos": "acompanhamento",
    "acompanhamo": "acompanhar",
    "acompanhamos": "acompanhar",
    "acompanhando": "acompanhar",
    "acompanhantes": "acompanhante",
    "acompanhara": "acompanhar",
    "acompanharam": "acompanhar",
    "acompanharas": "acompanhar",
    "acompanharde": "acompanhar",
    "acompanhardes": "acompanhar",
    "acompanhare": "acompanhar",
    "acompanharei": "acompanhar",
    "acompanhareis": "acompanhar",
    "acompanharem": "acompanhar",
    "acompanharemos": "acompanhar",
    "acompanhares": "acompanhar",
    "acompanharia": "acompanhar",
    "acompanhariam": "acompanhar",
    "acompanharias": "acompanhar",
    "acompanharmo": "acompanhar",
    "acompanharmos": "acompanhar",
    "acompanhará": "acompanhar",
    "acompanharás": "acompanhar",
    "acompanharão": "acompanhar",
    "acompanharíamos": "acompanhar",
    "acompanharíeis": "acompanhar",
    "acompanhas": "acompanhar",
    "acompanhasse": "acompanhar",
    "acompanhassem": "acompanhar",
    "acompanhasses": "acompanhar",
    "acompanhaste": "acompanhar",
    "acompanhastes": "acompanhar",
    "acompanhava": "acompanhar",
    "acompanhavam": "acompanhar",
    "acompanhavas": "acompanhar",
    "acompanhe": "acompanhar",
    "acompanhei": "acompanhar",
    "acompanheis": "acompanhar",
    "acompanhem": "acompanhar",
    "acompanhemo": "acompanhar",
    "acompanhemos": "acompanhar",
    "acompanhes": "acompanhar",
    "acompanho": "acompanhar",
    "acompanhou": "acompanhar",
    "acompanhá": "acompanhar",
    "acompanhámo": "acompanhar",
    "acompanhámos": "acompanhar",
    "acompanháramo": "acompanhar",
    "acompanháramos": "acompanhar",
    "acompanhárei": "acompanhar",
    "acompanháreis": "acompanhar",
    "acompanhásseis": "acompanhar",
    "acompanhássemos": "acompanhar",
    "acompanhávamo": "acompanhar",
    "acompanhávamos": "acompanhar",
    "acompanhávei": "acompanhar",
    "acompanháveis": "acompanhar",
    "acompassa": "acompassar",
    "acompassada": "acompassar",
    "acompassadas": "acompassar",
    "acompassado": "acompassar",
    "acompassados": "acompassar",
    "acompassai": "acompassar",
    "acompassais": "acompassar",
    "acompassam": "acompassar",
    "acompassamo": "acompassar",
    "acompassamos": "acompassar",
    "acompassando": "acompassar",
    "acompassara": "acompassar",
    "acompassaram": "acompassar",
    "acompassaras": "acompassar",
    "acompassarde": "acompassar",
    "acompassardes": "acompassar",
    "acompassare": "acompassar",
    "acompassarei": "acompassar",
    "acompassareis": "acompassar",
    "acompassarem": "acompassar",
    "acompassaremos": "acompassar",
    "acompassares": "acompassar",
    "acompassaria": "acompassar",
    "acompassariam": "acompassar",
    "acompassarias": "acompassar",
    "acompassarmo": "acompassar",
    "acompassarmos": "acompassar",
    "acompassará": "acompassar",
    "acompassarás": "acompassar",
    "acompassarão": "acompassar",
    "acompassaríamos": "acompassar",
    "acompassaríeis": "acompassar",
    "acompassas": "acompassar",
    "acompassasse": "acompassar",
    "acompassassem": "acompassar",
    "acompassasses": "acompassar",
    "acompassaste": "acompassar",
    "acompassastes": "acompassar",
    "acompassava": "acompassar",
    "acompassavam": "acompassar",
    "acompassavas": "acompassar",
    "acompasse": "acompassar",
    "acompassei": "acompassar",
    "acompasseis": "acompassar",
    "acompassem": "acompassar",
    "acompassemo": "acompassar",
    "acompassemos": "acompassar",
    "acompasses": "acompassar",
    "acompasso": "acompassar",
    "acompassou": "acompassar",
    "acompassá": "acompassar",
    "acompassámo": "acompassar",
    "acompassámos": "acompassar",
    "acompassáramo": "acompassar",
    "acompassáramos": "acompassar",
    "acompassárei": "acompassar",
    "acompassáreis": "acompassar",
    "acompassásseis": "acompassar",
    "acompassássemos": "acompassar",
    "acompassávamo": "acompassar",
    "acompassávamos": "acompassar",
    "acompassávei": "acompassar",
    "acompassáveis": "acompassar",
    "acomprida": "acompridar",
    "acompridada": "acompridar",
    "acompridadas": "acompridar",
    "acompridado": "acompridar",
    "acompridados": "acompridar",
    "acompridai": "acompridar",
    "acompridais": "acompridar",
    "acompridam": "acompridar",
    "acompridamo": "acompridar",
    "acompridamos": "acompridar",
    "acompridando": "acompridar",
    "acompridara": "acompridar",
    "acompridaram": "acompridar",
    "acompridaras": "acompridar",
    "acompridarde": "acompridar",
    "acompridardes": "acompridar",
    "acompridare": "acompridar",
    "acompridarei": "acompridar",
    "acompridareis": "acompridar",
    "acompridarem": "acompridar",
    "acompridaremos": "acompridar",
    "acompridares": "acompridar",
    "acompridaria": "acompridar",
    "acompridariam": "acompridar",
    "acompridarias": "acompridar",
    "acompridarmo": "acompridar",
    "acompridarmos": "acompridar",
    "acompridará": "acompridar",
    "acompridarás": "acompridar",
    "acompridarão": "acompridar",
    "acompridaríamos": "acompridar",
    "acompridaríeis": "acompridar",
    "acompridas": "acompridar",
    "acompridasse": "acompridar",
    "acompridassem": "acompridar",
    "acompridasses": "acompridar",
    "acompridaste": "acompridar",
    "acompridastes": "acompridar",
    "acompridava": "acompridar",
    "acompridavam": "acompridar",
    "acompridavas": "acompridar",
    "acompride": "acompridar",
    "acompridei": "acompridar",
    "acomprideis": "acompridar",
    "acompridem": "acompridar",
    "acompridemo": "acompridar",
    "acompridemos": "acompridar",
    "acomprides": "acompridar",
    "acomprido": "acompridar",
    "acompridou": "acompridar",
    "acompridá": "acompridar",
    "acompridámo": "acompridar",
    "acompridámos": "acompridar",
    "acompridáramo": "acompridar",
    "acompridáramos": "acompridar",
    "acompridárei": "acompridar",
    "acompridáreis": "acompridar",
    "acompridásseis": "acompridar",
    "acompridássemos": "acompridar",
    "acompridávamo": "acompridar",
    "acompridávamos": "acompridar",
    "acompridávei": "acompridar",
    "acompridáveis": "acompridar",
    "acomuna": "acomunar",
    "acomunada": "acomunar",
    "acomunadas": "acomunar",
    "acomunado": "acomunar",
    "acomunados": "acomunar",
    "acomunai": "acomunar",
    "acomunais": "acomunar",
    "acomunam": "acomunar",
    "acomunamo": "acomunar",
    "acomunamos": "acomunar",
    "acomunando": "acomunar",
    "acomunara": "acomunar",
    "acomunaram": "acomunar",
    "acomunaras": "acomunar",
    "acomunarde": "acomunar",
    "acomunardes": "acomunar",
    "acomunare": "acomunar",
    "acomunarei": "acomunar",
    "acomunareis": "acomunar",
    "acomunarem": "acomunar",
    "acomunaremos": "acomunar",
    "acomunares": "acomunar",
    "acomunaria": "acomunar",
    "acomunariam": "acomunar",
    "acomunarias": "acomunar",
    "acomunarmo": "acomunar",
    "acomunarmos": "acomunar",
    "acomunará": "acomunar",
    "acomunarás": "acomunar",
    "acomunarão": "acomunar",
    "acomunaríamos": "acomunar",
    "acomunaríeis": "acomunar",
    "acomunas": "acomunar",
    "acomunasse": "acomunar",
    "acomunassem": "acomunar",
    "acomunasses": "acomunar",
    "acomunaste": "acomunar",
    "acomunastes": "acomunar",
    "acomunava": "acomunar",
    "acomunavam": "acomunar",
    "acomunavas": "acomunar",
    "acomune": "acomunar",
    "acomunei": "acomunar",
    "acomuneis": "acomunar",
    "acomunem": "acomunar",
    "acomunemo": "acomunar",
    "acomunemos": "acomunar",
    "acomunes": "acomunar",
    "acomuno": "acomunar",
    "acomunou": "acomunar",
    "acomuná": "acomunar",
    "acomunámo": "acomunar",
    "acomunámos": "acomunar",
    "acomunáramo": "acomunar",
    "acomunáramos": "acomunar",
    "acomunárei": "acomunar",
    "acomunáreis": "acomunar",
    "acomunásseis": "acomunar",
    "acomunássemos": "acomunar",
    "acomunávamo": "acomunar",
    "acomunávamos": "acomunar",
    "acomunávei": "acomunar",
    "acomunáveis": "acomunar",
    "aconchega": "aconchegar",
    "aconchegada": "aconchegar",
    "aconchegadas": "aconchegar",
    "aconchegadinha": "aconchegado",
    "aconchegadinhas": "aconchegado",
    "aconchegadinho": "aconchegado",
    "aconchegadinhos": "aconchegado",
    "aconchegadita": "aconchegado",
    "aconchegaditas": "aconchegado",
    "aconchegadito": "aconchegado",
    "aconchegaditos": "aconchegado",
    "aconchegado": "aconchegar",
    "aconchegados": "aconchegar",
    "aconchegadíssima": "aconchegado",
    "aconchegadíssimas": "aconchegado",
    "aconchegadíssimo": "aconchegado",
    "aconchegadíssimos": "aconchegado",
    "aconchegai": "aconchegar",
    "aconchegais": "aconchegar",
    "aconchegam": "aconchegar",
    "aconchegamo": "aconchegar",
    "aconchegamos": "aconchegar",
    "aconchegando": "aconchegar",
    "aconchegantes": "aconchegante",
    "aconchegara": "aconchegar",
    "aconchegaram": "aconchegar",
    "aconchegaras": "aconchegar",
    "aconchegarde": "aconchegar",
    "aconchegardes": "aconchegar",
    "aconchegare": "aconchegar",
    "aconchegarei": "aconchegar",
    "aconchegareis": "aconchegar",
    "aconchegarem": "aconchegar",
    "aconchegaremos": "aconchegar",
    "aconchegares": "aconchegar",
    "aconchegaria": "aconchegar",
    "aconchegariam": "aconchegar",
    "aconchegarias": "aconchegar",
    "aconchegarmo": "aconchegar",
    "aconchegarmos": "aconchegar",
    "aconchegará": "aconchegar",
    "aconchegarás": "aconchegar",
    "aconchegarão": "aconchegar",
    "aconchegaríamos": "aconchegar",
    "aconchegaríeis": "aconchegar",
    "aconchegas": "aconchegar",
    "aconchegasse": "aconchegar",
    "aconchegassem": "aconchegar",
    "aconchegasses": "aconchegar",
    "aconchegaste": "aconchegar",
    "aconchegastes": "aconchegar",
    "aconchegava": "aconchegar",
    "aconchegavam": "aconchegar",
    "aconchegavas": "aconchegar",
    "aconchego": "aconchegar",
    "aconchegos": "aconchego",
    "aconchegou": "aconchegar",
    "aconchegue": "aconchegar",
    "aconcheguei": "aconchegar",
    "aconchegueis": "aconchegar",
    "aconcheguem": "aconchegar",
    "aconcheguemo": "aconchegar",
    "aconcheguemos": "aconchegar",
    "aconchegues": "aconchegar",
    "aconchegá": "aconchegar",
    "aconchegámo": "aconchegar",
    "aconchegámos": "aconchegar",
    "aconchegáramo": "aconchegar",
    "aconchegáramos": "aconchegar",
    "aconchegárei": "aconchegar",
    "aconchegáreis": "aconchegar",
    "aconchegásseis": "aconchegar",
    "aconchegássemos": "aconchegar",
    "aconchegávamo": "aconchegar",
    "aconchegávamos": "aconchegar",
    "aconchegávei": "aconchegar",
    "aconchegáveis": "aconchegável",
    "acondiciona": "acondicionar",
    "acondicionada": "acondicionar",
    "acondicionadas": "acondicionar",
    "acondicionadinha": "acondicionado",
    "acondicionadinhas": "acondicionado",
    "acondicionadinho": "acondicionado",
    "acondicionadinhos": "acondicionado",
    "acondicionadita": "acondicionado",
    "acondicionaditas": "acondicionado",
    "acondicionadito": "acondicionado",
    "acondicionaditos": "acondicionado",
    "acondicionado": "acondicionar",
    "acondicionados": "acondicionar",
    "acondicionadíssima": "acondicionado",
    "acondicionadíssimas": "acondicionado",
    "acondicionadíssimo": "acondicionado",
    "acondicionadíssimos": "acondicionado",
    "acondicionai": "acondicionar",
    "acondicionais": "acondicionar",
    "acondicionam": "acondicionar",
    "acondicionamentos": "acondicionamento",
    "acondicionamo": "acondicionar",
    "acondicionamos": "acondicionar",
    "acondicionando": "acondicionar",
    "acondicionara": "acondicionar",
    "acondicionaram": "acondicionar",
    "acondicionaras": "acondicionar",
    "acondicionarde": "acondicionar",
    "acondicionardes": "acondicionar",
    "acondicionare": "acondicionar",
    "acondicionarei": "acondicionar",
    "acondicionareis": "acondicionar",
    "acondicionarem": "acondicionar",
    "acondicionaremos": "acondicionar",
    "acondicionares": "acondicionar",
    "acondicionaria": "acondicionar",
    "acondicionariam": "acondicionar",
    "acondicionarias": "acondicionar",
    "acondicionarmo": "acondicionar",
    "acondicionarmos": "acondicionar",
    "acondicionará": "acondicionar",
    "acondicionarás": "acondicionar",
    "acondicionarão": "acondicionar",
    "acondicionaríamos": "acondicionar",
    "acondicionaríeis": "acondicionar",
    "acondicionas": "acondicionar",
    "acondicionasse": "acondicionar",
    "acondicionassem": "acondicionar",
    "acondicionasses": "acondicionar",
    "acondicionaste": "acondicionar",
    "acondicionastes": "acondicionar",
    "acondicionava": "acondicionar",
    "acondicionavam": "acondicionar",
    "acondicionavas": "acondicionar",
    "acondicionações": "acondicionação",
    "acondicione": "acondicionar",
    "acondicionei": "acondicionar",
    "acondicioneis": "acondicionar",
    "acondicionem": "acondicionar",
    "acondicionemo": "acondicionar",
    "acondicionemos": "acondicionar",
    "acondiciones": "acondicionar",
    "acondiciono": "acondicionar",
    "acondicionou": "acondicionar",
    "acondicioná": "acondicionar",
    "acondicionámo": "acondicionar",
    "acondicionámos": "acondicionar",
    "acondicionáramo": "acondicionar",
    "acondicionáramos": "acondicionar",
    "acondicionárei": "acondicionar",
    "acondicionáreis": "acondicionar",
    "acondicionásseis": "acondicionar",
    "acondicionássemos": "acondicionar",
    "acondicionávamo": "acondicionar",
    "acondicionávamos": "acondicionar",
    "acondicionávei": "acondicionar",
    "acondicionáveis": "acondicionar",
    "acondimenta": "acondimentar",
    "acondimentada": "acondimentar",
    "acondimentadas": "acondimentar",
    "acondimentado": "acondimentar",
    "acondimentados": "acondimentar",
    "acondimentai": "acondimentar",
    "acondimentais": "acondimentar",
    "acondimentam": "acondimentar",
    "acondimentamo": "acondimentar",
    "acondimentamos": "acondimentar",
    "acondimentando": "acondimentar",
    "acondimentara": "acondimentar",
    "acondimentaram": "acondimentar",
    "acondimentaras": "acondimentar",
    "acondimentarde": "acondimentar",
    "acondimentardes": "acondimentar",
    "acondimentare": "acondimentar",
    "acondimentarei": "acondimentar",
    "acondimentareis": "acondimentar",
    "acondimentarem": "acondimentar",
    "acondimentaremos": "acondimentar",
    "acondimentares": "acondimentar",
    "acondimentaria": "acondimentar",
    "acondimentariam": "acondimentar",
    "acondimentarias": "acondimentar",
    "acondimentarmo": "acondimentar",
    "acondimentarmos": "acondimentar",
    "acondimentará": "acondimentar",
    "acondimentarás": "acondimentar",
    "acondimentarão": "acondimentar",
    "acondimentaríamos": "acondimentar",
    "acondimentaríeis": "acondimentar",
    "acondimentas": "acondimentar",
    "acondimentasse": "acondimentar",
    "acondimentassem": "acondimentar",
    "acondimentasses": "acondimentar",
    "acondimentaste": "acondimentar",
    "acondimentastes": "acondimentar",
    "acondimentava": "acondimentar",
    "acondimentavam": "acondimentar",
    "acondimentavas": "acondimentar",
    "acondimente": "acondimentar",
    "acondimentei": "acondimentar",
    "acondimenteis": "acondimentar",
    "acondimentem": "acondimentar",
    "acondimentemo": "acondimentar",
    "acondimentemos": "acondimentar",
    "acondimentes": "acondimentar",
    "acondimento": "acondimentar",
    "acondimentou": "acondimentar",
    "acondimentá": "acondimentar",
    "acondimentámo": "acondimentar",
    "acondimentámos": "acondimentar",
    "acondimentáramo": "acondimentar",
    "acondimentáramos": "acondimentar",
    "acondimentárei": "acondimentar",
    "acondimentáreis": "acondimentar",
    "acondimentásseis": "acondimentar",
    "acondimentássemos": "acondimentar",
    "acondimentávamo": "acondimentar",
    "acondimentávamos": "acondimentar",
    "acondimentávei": "acondimentar",
    "acondimentáveis": "acondimentar",
    "acondiçoa": "acondiçoar",
    "acondiçoada": "acondiçoar",
    "acondiçoadas": "acondiçoar",
    "acondiçoado": "acondiçoar",
    "acondiçoados": "acondiçoar",
    "acondiçoai": "acondiçoar",
    "acondiçoais": "acondiçoar",
    "acondiçoam": "acondiçoar",
    "acondiçoamo": "acondiçoar",
    "acondiçoamos": "acondiçoar",
    "acondiçoando": "acondiçoar",
    "acondiçoara": "acondiçoar",
    "acondiçoaram": "acondiçoar",
    "acondiçoaras": "acondiçoar",
    "acondiçoarde": "acondiçoar",
    "acondiçoardes": "acondiçoar",
    "acondiçoare": "acondiçoar",
    "acondiçoarei": "acondiçoar",
    "acondiçoareis": "acondiçoar",
    "acondiçoarem": "acondiçoar",
    "acondiçoaremos": "acondiçoar",
    "acondiçoares": "acondiçoar",
    "acondiçoaria": "acondiçoar",
    "acondiçoariam": "acondiçoar",
    "acondiçoarias": "acondiçoar",
    "acondiçoarmo": "acondiçoar",
    "acondiçoarmos": "acondiçoar",
    "acondiçoará": "acondiçoar",
    "acondiçoarás": "acondiçoar",
    "acondiçoarão": "acondiçoar",
    "acondiçoaríamos": "acondiçoar",
    "acondiçoaríeis": "acondiçoar",
    "acondiçoas": "acondiçoar",
    "acondiçoasse": "acondiçoar",
    "acondiçoassem": "acondiçoar",
    "acondiçoasses": "acondiçoar",
    "acondiçoaste": "acondiçoar",
    "acondiçoastes": "acondiçoar",
    "acondiçoava": "acondiçoar",
    "acondiçoavam": "acondiçoar",
    "acondiçoavas": "acondiçoar",
    "acondiçoe": "acondiçoar",
    "acondiçoei": "acondiçoar",
    "acondiçoeis": "acondiçoar",
    "acondiçoem": "acondiçoar",
    "acondiçoemo": "acondiçoar",
    "acondiçoemos": "acondiçoar",
    "acondiçoes": "acondiçoar",
    "acondiçoo": "acondiçoar",
    "acondiçoou": "acondiçoar",
    "acondiçoá": "acondiçoar",
    "acondiçoámo": "acondiçoar",
    "acondiçoámos": "acondiçoar",
    "acondiçoáramo": "acondiçoar",
    "acondiçoáramos": "acondiçoar",
    "acondiçoárei": "acondiçoar",
    "acondiçoáreis": "acondiçoar",
    "acondiçoásseis": "acondiçoar",
    "acondiçoássemos": "acondiçoar",
    "acondiçoávamo": "acondiçoar",
    "acondiçoávamos": "acondiçoar",
    "acondiçoávei": "acondiçoar",
    "acondiçoáveis": "acondiçoar",
    "acondritos": "acondrito",
    "aconfeita": "aconfeitar",
    "aconfeitada": "aconfeitar",
    "aconfeitadas": "aconfeitar",
    "aconfeitado": "aconfeitar",
    "aconfeitados": "aconfeitar",
    "aconfeitai": "aconfeitar",
    "aconfeitais": "aconfeitar",
    "aconfeitam": "aconfeitar",
    "aconfeitamo": "aconfeitar",
    "aconfeitamos": "aconfeitar",
    "aconfeitando": "aconfeitar",
    "aconfeitara": "aconfeitar",
    "aconfeitaram": "aconfeitar",
    "aconfeitaras": "aconfeitar",
    "aconfeitarde": "aconfeitar",
    "aconfeitardes": "aconfeitar",
    "aconfeitare": "aconfeitar",
    "aconfeitarei": "aconfeitar",
    "aconfeitareis": "aconfeitar",
    "aconfeitarem": "aconfeitar",
    "aconfeitaremos": "aconfeitar",
    "aconfeitares": "aconfeitar",
    "aconfeitaria": "aconfeitar",
    "aconfeitariam": "aconfeitar",
    "aconfeitarias": "aconfeitar",
    "aconfeitarmo": "aconfeitar",
    "aconfeitarmos": "aconfeitar",
    "aconfeitará": "aconfeitar",
    "aconfeitarás": "aconfeitar",
    "aconfeitarão": "aconfeitar",
    "aconfeitaríamos": "aconfeitar",
    "aconfeitaríeis": "aconfeitar",
    "aconfeitas": "aconfeitar",
    "aconfeitasse": "aconfeitar",
    "aconfeitassem": "aconfeitar",
    "aconfeitasses": "aconfeitar",
    "aconfeitaste": "aconfeitar",
    "aconfeitastes": "aconfeitar",
    "aconfeitava": "aconfeitar",
    "aconfeitavam": "aconfeitar",
    "aconfeitavas": "aconfeitar",
    "aconfeite": "aconfeitar",
    "aconfeitei": "aconfeitar",
    "aconfeiteis": "aconfeitar",
    "aconfeitem": "aconfeitar",
    "aconfeitemo": "aconfeitar",
    "aconfeitemos": "aconfeitar",
    "aconfeites": "aconfeitar",
    "aconfeito": "aconfeitar",
    "aconfeitou": "aconfeitar",
    "aconfeitá": "aconfeitar",
    "aconfeitámo": "aconfeitar",
    "aconfeitámos": "aconfeitar",
    "aconfeitáramo": "aconfeitar",
    "aconfeitáramos": "aconfeitar",
    "aconfeitárei": "aconfeitar",
    "aconfeitáreis": "aconfeitar",
    "aconfeitásseis": "aconfeitar",
    "aconfeitássemos": "aconfeitar",
    "aconfeitávamo": "aconfeitar",
    "aconfeitávamos": "aconfeitar",
    "aconfeitávei": "aconfeitar",
    "aconfeitáveis": "aconfeitar",
    "aconfessionais": "aconfessional",
    "aconfrada": "aconfradar",
    "aconfradada": "aconfradar",
    "aconfradadas": "aconfradar",
    "aconfradado": "aconfradar",
    "aconfradados": "aconfradar",
    "aconfradai": "aconfradar",
    "aconfradais": "aconfradar",
    "aconfradam": "aconfradar",
    "aconfradamo": "aconfradar",
    "aconfradamos": "aconfradar",
    "aconfradando": "aconfradar",
    "aconfradara": "aconfradar",
    "aconfradaram": "aconfradar",
    "aconfradaras": "aconfradar",
    "aconfradarde": "aconfradar",
    "aconfradardes": "aconfradar",
    "aconfradare": "aconfradar",
    "aconfradarei": "aconfradar",
    "aconfradareis": "aconfradar",
    "aconfradarem": "aconfradar",
    "aconfradaremos": "aconfradar",
    "aconfradares": "aconfradar",
    "aconfradaria": "aconfradar",
    "aconfradariam": "aconfradar",
    "aconfradarias": "aconfradar",
    "aconfradarmo": "aconfradar",
    "aconfradarmos": "aconfradar",
    "aconfradará": "aconfradar",
    "aconfradarás": "aconfradar",
    "aconfradarão": "aconfradar",
    "aconfradaríamos": "aconfradar",
    "aconfradaríeis": "aconfradar",
    "aconfradas": "aconfradar",
    "aconfradasse": "aconfradar",
    "aconfradassem": "aconfradar",
    "aconfradasses": "aconfradar",
    "aconfradaste": "aconfradar",
    "aconfradastes": "aconfradar",
    "aconfradava": "aconfradar",
    "aconfradavam": "aconfradar",
    "aconfradavas": "aconfradar",
    "aconfrade": "aconfradar",
    "aconfradei": "aconfradar",
    "aconfradeis": "aconfradar",
    "aconfradem": "aconfradar",
    "aconfrademo": "aconfradar",
    "aconfrademos": "aconfradar",
    "aconfrades": "aconfradar",
    "aconfrado": "aconfradar",
    "aconfradou": "aconfradar",
    "aconfradá": "aconfradar",
    "aconfradámo": "aconfradar",
    "aconfradámos": "aconfradar",
    "aconfradáramo": "aconfradar",
    "aconfradáramos": "aconfradar",
    "aconfradárei": "aconfradar",
    "aconfradáreis": "aconfradar",
    "aconfradásseis": "aconfradar",
    "aconfradássemos": "aconfradar",
    "aconfradávamo": "aconfradar",
    "aconfradávamos": "aconfradar",
    "aconfradávei": "aconfradar",
    "aconfradáveis": "aconfradar",
    "aconitatos": "aconitato",
    "aconitinas": "aconitina",
    "aconselha": "aconselhar",
    "aconselhada": "aconselhar",
    "aconselhadas": "aconselhar",
    "aconselhado": "aconselhar",
    "aconselhadora": "aconselhador",
    "aconselhadoras": "aconselhador",
    "aconselhadores": "aconselhador",
    "aconselhados": "aconselhar",
    "aconselhai": "aconselhar",
    "aconselhais": "aconselhar",
    "aconselham": "aconselhar",
    "aconselhamentos": "aconselhamento",
    "aconselhamo": "aconselhar",
    "aconselhamos": "aconselhar",
    "aconselhando": "aconselhar",
    "aconselhara": "aconselhar",
    "aconselharam": "aconselhar",
    "aconselharas": "aconselhar",
    "aconselharde": "aconselhar",
    "aconselhardes": "aconselhar",
    "aconselhare": "aconselhar",
    "aconselharei": "aconselhar",
    "aconselhareis": "aconselhar",
    "aconselharem": "aconselhar",
    "aconselharemos": "aconselhar",
    "aconselhares": "aconselhar",
    "aconselharia": "aconselhar",
    "aconselhariam": "aconselhar",
    "aconselharias": "aconselhar",
    "aconselharmo": "aconselhar",
    "aconselharmos": "aconselhar",
    "aconselhará": "aconselhar",
    "aconselharás": "aconselhar",
    "aconselharão": "aconselhar",
    "aconselharíamos": "aconselhar",
    "aconselharíeis": "aconselhar",
    "aconselhas": "aconselhar",
    "aconselhasse": "aconselhar",
    "aconselhassem": "aconselhar",
    "aconselhasses": "aconselhar",
    "aconselhaste": "aconselhar",
    "aconselhastes": "aconselhar",
    "aconselhava": "aconselhar",
    "aconselhavam": "aconselhar",
    "aconselhavas": "aconselhar",
    "aconselhe": "aconselhar",
    "aconselhei": "aconselhar",
    "aconselheis": "aconselhar",
    "aconselhem": "aconselhar",
    "aconselhemo": "aconselhar",
    "aconselhemos": "aconselhar",
    "aconselhes": "aconselhar",
    "aconselho": "aconselhar",
    "aconselhou": "aconselhar",
    "aconselhá": "aconselhar",
    "aconselhámo": "aconselhar",
    "aconselhámos": "aconselhar",
    "aconselháramo": "aconselhar",
    "aconselháramos": "aconselhar",
    "aconselhárei": "aconselhar",
    "aconselháreis": "aconselhar",
    "aconselhásseis": "aconselhar",
    "aconselhássemos": "aconselhar",
    "aconselhávamo": "aconselhar",
    "aconselhávamos": "aconselhar",
    "aconselhávei": "aconselhar",
    "aconselháveis": "aconselhável",
    "aconsoanta": "aconsoantar",
    "aconsoantada": "aconsoantar",
    "aconsoantadas": "aconsoantar",
    "aconsoantado": "aconsoantar",
    "aconsoantados": "aconsoantar",
    "aconsoantai": "aconsoantar",
    "aconsoantais": "aconsoantar",
    "aconsoantam": "aconsoantar",
    "aconsoantamo": "aconsoantar",
    "aconsoantamos": "aconsoantar",
    "aconsoantando": "aconsoantar",
    "aconsoantara": "aconsoantar",
    "aconsoantaram": "aconsoantar",
    "aconsoantaras": "aconsoantar",
    "aconsoantarde": "aconsoantar",
    "aconsoantardes": "aconsoantar",
    "aconsoantare": "aconsoantar",
    "aconsoantarei": "aconsoantar",
    "aconsoantareis": "aconsoantar",
    "aconsoantarem": "aconsoantar",
    "aconsoantaremos": "aconsoantar",
    "aconsoantares": "aconsoantar",
    "aconsoantaria": "aconsoantar",
    "aconsoantariam": "aconsoantar",
    "aconsoantarias": "aconsoantar",
    "aconsoantarmo": "aconsoantar",
    "aconsoantarmos": "aconsoantar",
    "aconsoantará": "aconsoantar",
    "aconsoantarás": "aconsoantar",
    "aconsoantarão": "aconsoantar",
    "aconsoantaríamos": "aconsoantar",
    "aconsoantaríeis": "aconsoantar",
    "aconsoantas": "aconsoantar",
    "aconsoantasse": "aconsoantar",
    "aconsoantassem": "aconsoantar",
    "aconsoantasses": "aconsoantar",
    "aconsoantaste": "aconsoantar",
    "aconsoantastes": "aconsoantar",
    "aconsoantava": "aconsoantar",
    "aconsoantavam": "aconsoantar",
    "aconsoantavas": "aconsoantar",
    "aconsoante": "aconsoantar",
    "aconsoantei": "aconsoantar",
    "aconsoanteis": "aconsoantar",
    "aconsoantem": "aconsoantar",
    "aconsoantemo": "aconsoantar",
    "aconsoantemos": "aconsoantar",
    "aconsoantes": "aconsoantar",
    "aconsoanto": "aconsoantar",
    "aconsoantou": "aconsoantar",
    "aconsoantá": "aconsoantar",
    "aconsoantámo": "aconsoantar",
    "aconsoantámos": "aconsoantar",
    "aconsoantáramo": "aconsoantar",
    "aconsoantáramos": "aconsoantar",
    "aconsoantárei": "aconsoantar",
    "aconsoantáreis": "aconsoantar",
    "aconsoantásseis": "aconsoantar",
    "aconsoantássemos": "aconsoantar",
    "aconsoantávamo": "aconsoantar",
    "aconsoantávamos": "aconsoantar",
    "aconsoantávei": "aconsoantar",
    "aconsoantáveis": "aconsoantar",
    "acontece": "acontecer",
    "acontecei": "acontecer",
    "aconteceis": "acontecer",
    "acontecem": "acontecer",
    "acontecemo": "acontecer",
    "acontecemos": "acontecer",
    "acontecendo": "acontecer",
    "acontecera": "acontecer",
    "aconteceram": "acontecer",
    "aconteceras": "acontecer",
    "acontecerdes": "acontecer",
    "acontecerei": "acontecer",
    "acontecereis": "acontecer",
    "acontecerem": "acontecer",
    "aconteceremos": "acontecer",
    "aconteceres": "acontecer",
    "aconteceria": "acontecer",
    "aconteceriam": "acontecer",
    "acontecerias": "acontecer",
    "acontecermo": "acontecer",
    "acontecermos": "acontecer",
    "acontecerá": "acontecer",
    "acontecerás": "acontecer",
    "acontecerão": "acontecer",
    "aconteceríamos": "acontecer",
    "aconteceríeis": "acontecer",
    "aconteces": "acontecer",
    "acontecesse": "acontecer",
    "acontecessem": "acontecer",
    "acontecesses": "acontecer",
    "aconteceste": "acontecer",
    "acontecestes": "acontecer",
    "aconteceu": "acontecer",
    "aconteci": "acontecer",
    "acontecia": "acontecer",
    "aconteciam": "acontecer",
    "acontecias": "acontecer",
    "acontecida": "acontecido",
    "acontecidas": "acontecido",
    "acontecido": "acontecer",
    "acontecidos": "acontecido",
    "acontecimentos": "acontecimento",
    "acontecêramo": "acontecer",
    "acontecêramos": "acontecer",
    "acontecêreis": "acontecer",
    "acontecêsseis": "acontecer",
    "acontecêssemos": "acontecer",
    "acontecíamo": "acontecer",
    "acontecíamos": "acontecer",
    "acontecíeis": "acontecer",
    "aconteça": "acontecer",
    "aconteçais": "acontecer",
    "aconteçam": "acontecer",
    "aconteçamo": "acontecer",
    "aconteçamos": "acontecer",
    "aconteças": "acontecer",
    "aconteço": "acontecer",
    "aconítica": "aconítico",
    "aconíticas": "aconítico",
    "aconíticos": "aconítico",
    "acoplada": "acoplado",
    "acopladas": "acoplado",
    "acopladores": "acoplador",
    "acoplados": "acoplado",
    "acoplamentos": "acoplamento",
    "acorcova": "acorcovar",
    "acorcovada": "acorcovar",
    "acorcovadas": "acorcovar",
    "acorcovado": "acorcovar",
    "acorcovados": "acorcovar",
    "acorcovai": "acorcovar",
    "acorcovais": "acorcovar",
    "acorcovam": "acorcovar",
    "acorcovamo": "acorcovar",
    "acorcovamos": "acorcovar",
    "acorcovando": "acorcovar",
    "acorcovara": "acorcovar",
    "acorcovaram": "acorcovar",
    "acorcovaras": "acorcovar",
    "acorcovarde": "acorcovar",
    "acorcovardes": "acorcovar",
    "acorcovare": "acorcovar",
    "acorcovarei": "acorcovar",
    "acorcovareis": "acorcovar",
    "acorcovarem": "acorcovar",
    "acorcovaremos": "acorcovar",
    "acorcovares": "acorcovar",
    "acorcovaria": "acorcovar",
    "acorcovariam": "acorcovar",
    "acorcovarias": "acorcovar",
    "acorcovarmo": "acorcovar",
    "acorcovarmos": "acorcovar",
    "acorcovará": "acorcovar",
    "acorcovarás": "acorcovar",
    "acorcovarão": "acorcovar",
    "acorcovaríamos": "acorcovar",
    "acorcovaríeis": "acorcovar",
    "acorcovas": "acorcovar",
    "acorcovasse": "acorcovar",
    "acorcovassem": "acorcovar",
    "acorcovasses": "acorcovar",
    "acorcovaste": "acorcovar",
    "acorcovastes": "acorcovar",
    "acorcovava": "acorcovar",
    "acorcovavam": "acorcovar",
    "acorcovavas": "acorcovar",
    "acorcove": "acorcovar",
    "acorcovei": "acorcovar",
    "acorcoveis": "acorcovar",
    "acorcovem": "acorcovar",
    "acorcovemo": "acorcovar",
    "acorcovemos": "acorcovar",
    "acorcoves": "acorcovar",
    "acorcovo": "acorcovar",
    "acorcovou": "acorcovar",
    "acorcová": "acorcovar",
    "acorcovámo": "acorcovar",
    "acorcovámos": "acorcovar",
    "acorcováramo": "acorcovar",
    "acorcováramos": "acorcovar",
    "acorcovárei": "acorcovar",
    "acorcováreis": "acorcovar",
    "acorcovásseis": "acorcovar",
    "acorcovássemos": "acorcovar",
    "acorcovávamo": "acorcovar",
    "acorcovávamos": "acorcovar",
    "acorcovávei": "acorcovar",
    "acorcováveis": "acorcovar",
    "acorda": "acordar",
    "acordada": "acordar",
    "acordadas": "acordar",
    "acordadinha": "acordado",
    "acordadinhas": "acordado",
    "acordadinho": "acordado",
    "acordadinhos": "acordado",
    "acordadita": "acordado",
    "acordaditas": "acordado",
    "acordadito": "acordado",
    "acordaditos": "acordado",
    "acordado": "acordar",
    "acordados": "acordar",
    "acordadíssima": "acordado",
    "acordadíssimas": "acordado",
    "acordadíssimo": "acordado",
    "acordadíssimos": "acordado",
    "acordai": "acordar",
    "acordais": "acordar",
    "acordam": "acordar",
    "acordamo": "acordar",
    "acordamos": "acordar",
    "acordando": "acordar",
    "acordantes": "acordante",
    "acordara": "acordar",
    "acordaram": "acordar",
    "acordaras": "acordar",
    "acordarde": "acordar",
    "acordardes": "acordar",
    "acordare": "acordar",
    "acordarei": "acordar",
    "acordareis": "acordar",
    "acordarem": "acordar",
    "acordaremos": "acordar",
    "acordares": "acordar",
    "acordaria": "acordar",
    "acordariam": "acordar",
    "acordarias": "acordar",
    "acordarmo": "acordar",
    "acordarmos": "acordar",
    "acordará": "acordar",
    "acordarás": "acordar",
    "acordarão": "acordar",
    "acordaríamos": "acordar",
    "acordaríeis": "acordar",
    "acordas": "acordar",
    "acordasse": "acordar",
    "acordassem": "acordar",
    "acordasses": "acordar",
    "acordaste": "acordar",
    "acordastes": "acordar",
    "acordava": "acordar",
    "acordavam": "acordar",
    "acordavas": "acordar",
    "acorde": "acordar",
    "acordei": "acordar",
    "acordeis": "acordar",
    "acordem": "acordar",
    "acordemo": "acordar",
    "acordemos": "acordar",
    "acordeonistas": "acordeonista",
    "acordes": "acorde",
    "acordeões": "acordeão",
    "acordo": "acordar",
    "acordoa": "acordoar",
    "acordoada": "acordoar",
    "acordoadas": "acordoar",
    "acordoado": "acordoar",
    "acordoados": "acordoar",
    "acordoai": "acordoar",
    "acordoais": "acordoar",
    "acordoam": "acordoar",
    "acordoamo": "acordoar",
    "acordoamos": "acordoar",
    "acordoando": "acordoar",
    "acordoara": "acordoar",
    "acordoaram": "acordoar",
    "acordoaras": "acordoar",
    "acordoarde": "acordoar",
    "acordoardes": "acordoar",
    "acordoare": "acordoar",
    "acordoarei": "acordoar",
    "acordoareis": "acordoar",
    "acordoarem": "acordoar",
    "acordoaremos": "acordoar",
    "acordoares": "acordoar",
    "acordoaria": "acordoar",
    "acordoariam": "acordoar",
    "acordoarias": "acordoar",
    "acordoarmo": "acordoar",
    "acordoarmos": "acordoar",
    "acordoará": "acordoar",
    "acordoarás": "acordoar",
    "acordoarão": "acordoar",
    "acordoaríamos": "acordoar",
    "acordoaríeis": "acordoar",
    "acordoas": "acordoar",
    "acordoasse": "acordoar",
    "acordoassem": "acordoar",
    "acordoasses": "acordoar",
    "acordoaste": "acordoar",
    "acordoastes": "acordoar",
    "acordoava": "acordoar",
    "acordoavam": "acordoar",
    "acordoavas": "acordoar",
    "acordoe": "acordoar",
    "acordoei": "acordoar",
    "acordoeis": "acordoar",
    "acordoem": "acordoar",
    "acordoemo": "acordoar",
    "acordoemos": "acordoar",
    "acordoes": "acordoar",
    "acordoo": "acordoar",
    "acordoou": "acordoar",
    "acordos": "acordo",
    "acordou": "acordar",
    "acordoá": "acordoar",
    "acordoámo": "acordoar",
    "acordoámos": "acordoar",
    "acordoáramo": "acordoar",
    "acordoáramos": "acordoar",
    "acordoárei": "acordoar",
    "acordoáreis": "acordoar",
    "acordoásseis": "acordoar",
    "acordoássemos": "acordoar",
    "acordoávamo": "acordoar",
    "acordoávamos": "acordoar",
    "acordoávei": "acordoar",
    "acordoáveis": "acordoar",
    "acordá": "acordar",
    "acordámo": "acordar",
    "acordámos": "acordar",
    "acordáramo": "acordar",
    "acordáramos": "acordar",
    "acordárei": "acordar",
    "acordáreis": "acordar",
    "acordásseis": "acordar",
    "acordássemos": "acordar",
    "acordávamo": "acordar",
    "acordávamos": "acordar",
    "acordávei": "acordar",
    "acordáveis": "acordar",
    "acorias": "acoria",
    "acorna": "acornar",
    "acornada": "acornar",
    "acornadas": "acornar",
    "acornado": "acornar",
    "acornados": "acornar",
    "acornai": "acornar",
    "acornais": "acornar",
    "acornam": "acornar",
    "acornamo": "acornar",
    "acornamos": "acornar",
    "acornando": "acornar",
    "acornara": "acornar",
    "acornaram": "acornar",
    "acornaras": "acornar",
    "acornarde": "acornar",
    "acornardes": "acornar",
    "acornare": "acornar",
    "acornarei": "acornar",
    "acornareis": "acornar",
    "acornarem": "acornar",
    "acornaremos": "acornar",
    "acornares": "acornar",
    "acornaria": "acornar",
    "acornariam": "acornar",
    "acornarias": "acornar",
    "acornarmo": "acornar",
    "acornarmos": "acornar",
    "acornará": "acornar",
    "acornarás": "acornar",
    "acornarão": "acornar",
    "acornaríamos": "acornar",
    "acornaríeis": "acornar",
    "acornas": "acornar",
    "acornasse": "acornar",
    "acornassem": "acornar",
    "acornasses": "acornar",
    "acornaste": "acornar",
    "acornastes": "acornar",
    "acornava": "acornar",
    "acornavam": "acornar",
    "acornavas": "acornar",
    "acorne": "acornar",
    "acornei": "acornar",
    "acorneis": "acornar",
    "acornem": "acornar",
    "acornemo": "acornar",
    "acornemos": "acornar",
    "acornes": "acornar",
    "acorno": "acornar",
    "acornou": "acornar",
    "acorná": "acornar",
    "acornámo": "acornar",
    "acornámos": "acornar",
    "acornáramo": "acornar",
    "acornáramos": "acornar",
    "acornárei": "acornar",
    "acornáreis": "acornar",
    "acornásseis": "acornar",
    "acornássemos": "acornar",
    "acornávamo": "acornar",
    "acornávamos": "acornar",
    "acornávei": "acornar",
    "acornáveis": "acornar",
    "acoronha": "acoronhar",
    "acoronhada": "acoronhar",
    "acoronhadas": "acoronhar",
    "acoronhado": "acoronhar",
    "acoronhados": "acoronhar",
    "acoronhai": "acoronhar",
    "acoronhais": "acoronhar",
    "acoronham": "acoronhar",
    "acoronhamo": "acoronhar",
    "acoronhamos": "acoronhar",
    "acoronhando": "acoronhar",
    "acoronhara": "acoronhar",
    "acoronharam": "acoronhar",
    "acoronharas": "acoronhar",
    "acoronharde": "acoronhar",
    "acoronhardes": "acoronhar",
    "acoronhare": "acoronhar",
    "acoronharei": "acoronhar",
    "acoronhareis": "acoronhar",
    "acoronharem": "acoronhar",
    "acoronharemos": "acoronhar",
    "acoronhares": "acoronhar",
    "acoronharia": "acoronhar",
    "acoronhariam": "acoronhar",
    "acoronharias": "acoronhar",
    "acoronharmo": "acoronhar",
    "acoronharmos": "acoronhar",
    "acoronhará": "acoronhar",
    "acoronharás": "acoronhar",
    "acoronharão": "acoronhar",
    "acoronharíamos": "acoronhar",
    "acoronharíeis": "acoronhar",
    "acoronhas": "acoronhar",
    "acoronhasse": "acoronhar",
    "acoronhassem": "acoronhar",
    "acoronhasses": "acoronhar",
    "acoronhaste": "acoronhar",
    "acoronhastes": "acoronhar",
    "acoronhava": "acoronhar",
    "acoronhavam": "acoronhar",
    "acoronhavas": "acoronhar",
    "acoronhe": "acoronhar",
    "acoronhei": "acoronhar",
    "acoronheis": "acoronhar",
    "acoronhem": "acoronhar",
    "acoronhemo": "acoronhar",
    "acoronhemos": "acoronhar",
    "acoronhes": "acoronhar",
    "acoronho": "acoronhar",
    "acoronhou": "acoronhar",
    "acoronhá": "acoronhar",
    "acoronhámo": "acoronhar",
    "acoronhámos": "acoronhar",
    "acoronháramo": "acoronhar",
    "acoronháramos": "acoronhar",
    "acoronhárei": "acoronhar",
    "acoronháreis": "acoronhar",
    "acoronhásseis": "acoronhar",
    "acoronhássemos": "acoronhar",
    "acoronhávamo": "acoronhar",
    "acoronhávamos": "acoronhar",
    "acoronhávei": "acoronhar",
    "acoronháveis": "acoronhar",
    "acoroçoa": "acoroçoar",
    "acoroçoada": "acoroçoar",
    "acoroçoadas": "acoroçoar",
    "acoroçoado": "acoroçoar",
    "acoroçoados": "acoroçoar",
    "acoroçoai": "acoroçoar",
    "acoroçoais": "acoroçoar",
    "acoroçoam": "acoroçoar",
    "acoroçoamentos": "acoroçoamento",
    "acoroçoamo": "acoroçoar",
    "acoroçoamos": "acoroçoar",
    "acoroçoando": "acoroçoar",
    "acoroçoara": "acoroçoar",
    "acoroçoaram": "acoroçoar",
    "acoroçoaras": "acoroçoar",
    "acoroçoarde": "acoroçoar",
    "acoroçoardes": "acoroçoar",
    "acoroçoare": "acoroçoar",
    "acoroçoarei": "acoroçoar",
    "acoroçoareis": "acoroçoar",
    "acoroçoarem": "acoroçoar",
    "acoroçoaremos": "acoroçoar",
    "acoroçoares": "acoroçoar",
    "acoroçoaria": "acoroçoar",
    "acoroçoariam": "acoroçoar",
    "acoroçoarias": "acoroçoar",
    "acoroçoarmo": "acoroçoar",
    "acoroçoarmos": "acoroçoar",
    "acoroçoará": "acoroçoar",
    "acoroçoarás": "acoroçoar",
    "acoroçoarão": "acoroçoar",
    "acoroçoaríamos": "acoroçoar",
    "acoroçoaríeis": "acoroçoar",
    "acoroçoas": "acoroçoar",
    "acoroçoasse": "acoroçoar",
    "acoroçoassem": "acoroçoar",
    "acoroçoasses": "acoroçoar",
    "acoroçoaste": "acoroçoar",
    "acoroçoastes": "acoroçoar",
    "acoroçoava": "acoroçoar",
    "acoroçoavam": "acoroçoar",
    "acoroçoavas": "acoroçoar",
    "acoroçoe": "acoroçoar",
    "acoroçoei": "acoroçoar",
    "acoroçoeis": "acoroçoar",
    "acoroçoem": "acoroçoar",
    "acoroçoemo": "acoroçoar",
    "acoroçoemos": "acoroçoar",
    "acoroçoes": "acoroçoar",
    "acoroçoo": "acoroçoar",
    "acoroçoou": "acoroçoar",
    "acoroçoá": "acoroçoar",
    "acoroçoámo": "acoroçoar",
    "acoroçoámos": "acoroçoar",
    "acoroçoáramo": "acoroçoar",
    "acoroçoáramos": "acoroçoar",
    "acoroçoárei": "acoroçoar",
    "acoroçoáreis": "acoroçoar",
    "acoroçoásseis": "acoroçoar",
    "acoroçoássemos": "acoroçoar",
    "acoroçoávamo": "acoroçoar",
    "acoroçoávamos": "acoroçoar",
    "acoroçoávei": "acoroçoar",
    "acoroçoáveis": "acoroçoar",
    "acorra": "acorrer",
    "acorrais": "acorrer",
    "acorram": "acorrer",
    "acorramo": "acorrer",
    "acorramos": "acorrer",
    "acorras": "acorrer",
    "acorre": "acorrer",
    "acorrei": "acorrer",
    "acorreis": "acorrer",
    "acorrem": "acorrer",
    "acorremo": "acorrer",
    "acorremos": "acorrer",
    "acorrendo": "acorrer",
    "acorrenta": "acorrentar",
    "acorrentada": "acorrentar",
    "acorrentadas": "acorrentar",
    "acorrentado": "acorrentar",
    "acorrentados": "acorrentar",
    "acorrentai": "acorrentar",
    "acorrentais": "acorrentar",
    "acorrentam": "acorrentar",
    "acorrentamentos": "acorrentamento",
    "acorrentamo": "acorrentar",
    "acorrentamos": "acorrentar",
    "acorrentando": "acorrentar",
    "acorrentara": "acorrentar",
    "acorrentaram": "acorrentar",
    "acorrentaras": "acorrentar",
    "acorrentarde": "acorrentar",
    "acorrentardes": "acorrentar",
    "acorrentare": "acorrentar",
    "acorrentarei": "acorrentar",
    "acorrentareis": "acorrentar",
    "acorrentarem": "acorrentar",
    "acorrentaremos": "acorrentar",
    "acorrentares": "acorrentar",
    "acorrentaria": "acorrentar",
    "acorrentariam": "acorrentar",
    "acorrentarias": "acorrentar",
    "acorrentarmo": "acorrentar",
    "acorrentarmos": "acorrentar",
    "acorrentará": "acorrentar",
    "acorrentarás": "acorrentar",
    "acorrentarão": "acorrentar",
    "acorrentaríamos": "acorrentar",
    "acorrentaríeis": "acorrentar",
    "acorrentas": "acorrentar",
    "acorrentasse": "acorrentar",
    "acorrentassem": "acorrentar",
    "acorrentasses": "acorrentar",
    "acorrentaste": "acorrentar",
    "acorrentastes": "acorrentar",
    "acorrentava": "acorrentar",
    "acorrentavam": "acorrentar",
    "acorrentavas": "acorrentar",
    "acorrente": "acorrentar",
    "acorrentei": "acorrentar",
    "acorrenteis": "acorrentar",
    "acorrentem": "acorrentar",
    "acorrentemo": "acorrentar",
    "acorrentemos": "acorrentar",
    "acorrentes": "acorrentar",
    "acorrento": "acorrentar",
    "acorrentou": "acorrentar",
    "acorrentá": "acorrentar",
    "acorrentámo": "acorrentar",
    "acorrentámos": "acorrentar",
    "acorrentáramo": "acorrentar",
    "acorrentáramos": "acorrentar",
    "acorrentárei": "acorrentar",
    "acorrentáreis": "acorrentar",
    "acorrentásseis": "acorrentar",
    "acorrentássemos": "acorrentar",
    "acorrentávamo": "acorrentar",
    "acorrentávamos": "acorrentar",
    "acorrentávei": "acorrentar",
    "acorrentáveis": "acorrentar",
    "acorrera": "acorrer",
    "acorreram": "acorrer",
    "acorreras": "acorrer",
    "acorrerdes": "acorrer",
    "acorrerei": "acorrer",
    "acorrereis": "acorrer",
    "acorrerem": "acorrer",
    "acorreremos": "acorrer",
    "acorreres": "acorrer",
    "acorreria": "acorrer",
    "acorreriam": "acorrer",
    "acorrerias": "acorrer",
    "acorrermo": "acorrer",
    "acorrermos": "acorrer",
    "acorrerá": "acorrer",
    "acorrerás": "acorrer",
    "acorrerão": "acorrer",
    "acorreríamos": "acorrer",
    "acorreríeis": "acorrer",
    "acorres": "acorrer",
    "acorresse": "acorrer",
    "acorressem": "acorrer",
    "acorresses": "acorrer",
    "acorreste": "acorrer",
    "acorrestes": "acorrer",
    "acorreu": "acorrer",
    "acorri": "acorrer",
    "acorria": "acorrer",
    "acorriam": "acorrer",
    "acorrias": "acorrer",
    "acorrida": "acorrer",
    "acorridas": "acorrer",
    "acorrido": "acorrer",
    "acorridos": "acorrer",
    "acorrilha": "acorrilhar",
    "acorrilhada": "acorrilhar",
    "acorrilhadas": "acorrilhar",
    "acorrilhado": "acorrilhar",
    "acorrilhados": "acorrilhar",
    "acorrilhai": "acorrilhar",
    "acorrilhais": "acorrilhar",
    "acorrilham": "acorrilhar",
    "acorrilhamo": "acorrilhar",
    "acorrilhamos": "acorrilhar",
    "acorrilhando": "acorrilhar",
    "acorrilhara": "acorrilhar",
    "acorrilharam": "acorrilhar",
    "acorrilharas": "acorrilhar",
    "acorrilharde": "acorrilhar",
    "acorrilhardes": "acorrilhar",
    "acorrilhare": "acorrilhar",
    "acorrilharei": "acorrilhar",
    "acorrilhareis": "acorrilhar",
    "acorrilharem": "acorrilhar",
    "acorrilharemos": "acorrilhar",
    "acorrilhares": "acorrilhar",
    "acorrilharia": "acorrilhar",
    "acorrilhariam": "acorrilhar",
    "acorrilharias": "acorrilhar",
    "acorrilharmo": "acorrilhar",
    "acorrilharmos": "acorrilhar",
    "acorrilhará": "acorrilhar",
    "acorrilharás": "acorrilhar",
    "acorrilharão": "acorrilhar",
    "acorrilharíamos": "acorrilhar",
    "acorrilharíeis": "acorrilhar",
    "acorrilhas": "acorrilhar",
    "acorrilhasse": "acorrilhar",
    "acorrilhassem": "acorrilhar",
    "acorrilhasses": "acorrilhar",
    "acorrilhaste": "acorrilhar",
    "acorrilhastes": "acorrilhar",
    "acorrilhava": "acorrilhar",
    "acorrilhavam": "acorrilhar",
    "acorrilhavas": "acorrilhar",
    "acorrilhe": "acorrilhar",
    "acorrilhei": "acorrilhar",
    "acorrilheis": "acorrilhar",
    "acorrilhem": "acorrilhar",
    "acorrilhemo": "acorrilhar",
    "acorrilhemos": "acorrilhar",
    "acorrilhes": "acorrilhar",
    "acorrilho": "acorrilhar",
    "acorrilhou": "acorrilhar",
    "acorrilhá": "acorrilhar",
    "acorrilhámo": "acorrilhar",
    "acorrilhámos": "acorrilhar",
    "acorrilháramo": "acorrilhar",
    "acorrilháramos": "acorrilhar",
    "acorrilhárei": "acorrilhar",
    "acorrilháreis": "acorrilhar",
    "acorrilhásseis": "acorrilhar",
    "acorrilhássemos": "acorrilhar",
    "acorrilhávamo": "acorrilhar",
    "acorrilhávamos": "acorrilhar",
    "acorrilhávei": "acorrilhar",
    "acorrilháveis": "acorrilhar",
    "acorrimentos": "acorrimento",
    "acorro": "acorrer",
    "acorrêramo": "acorrer",
    "acorrêramos": "acorrer",
    "acorrêreis": "acorrer",
    "acorrêsseis": "acorrer",
    "acorrêssemos": "acorrer",
    "acorríamo": "acorrer",
    "acorríamos": "acorrer",
    "acorríeis": "acorrer",
    "acortina": "acortinar",
    "acortinada": "acortinar",
    "acortinadas": "acortinar",
    "acortinado": "acortinar",
    "acortinados": "acortinar",
    "acortinai": "acortinar",
    "acortinais": "acortinar",
    "acortinam": "acortinar",
    "acortinamo": "acortinar",
    "acortinamos": "acortinar",
    "acortinando": "acortinar",
    "acortinara": "acortinar",
    "acortinaram": "acortinar",
    "acortinaras": "acortinar",
    "acortinarde": "acortinar",
    "acortinardes": "acortinar",
    "acortinare": "acortinar",
    "acortinarei": "acortinar",
    "acortinareis": "acortinar",
    "acortinarem": "acortinar",
    "acortinaremos": "acortinar",
    "acortinares": "acortinar",
    "acortinaria": "acortinar",
    "acortinariam": "acortinar",
    "acortinarias": "acortinar",
    "acortinarmo": "acortinar",
    "acortinarmos": "acortinar",
    "acortinará": "acortinar",
    "acortinarás": "acortinar",
    "acortinarão": "acortinar",
    "acortinaríamos": "acortinar",
    "acortinaríeis": "acortinar",
    "acortinas": "acortinar",
    "acortinasse": "acortinar",
    "acortinassem": "acortinar",
    "acortinasses": "acortinar",
    "acortinaste": "acortinar",
    "acortinastes": "acortinar",
    "acortinava": "acortinar",
    "acortinavam": "acortinar",
    "acortinavas": "acortinar",
    "acortine": "acortinar",
    "acortinei": "acortinar",
    "acortineis": "acortinar",
    "acortinem": "acortinar",
    "acortinemo": "acortinar",
    "acortinemos": "acortinar",
    "acortines": "acortinar",
    "acortino": "acortinar",
    "acortinou": "acortinar",
    "acortiná": "acortinar",
    "acortinámo": "acortinar",
    "acortinámos": "acortinar",
    "acortináramo": "acortinar",
    "acortináramos": "acortinar",
    "acortinárei": "acortinar",
    "acortináreis": "acortinar",
    "acortinásseis": "acortinar",
    "acortinássemos": "acortinar",
    "acortinávamo": "acortinar",
    "acortinávamos": "acortinar",
    "acortinávei": "acortinar",
    "acortináveis": "acortinar",
    "acorucha": "acoruchar",
    "acoruchada": "acoruchar",
    "acoruchadas": "acoruchar",
    "acoruchado": "acoruchar",
    "acoruchados": "acoruchar",
    "acoruchai": "acoruchar",
    "acoruchais": "acoruchar",
    "acorucham": "acoruchar",
    "acoruchamo": "acoruchar",
    "acoruchamos": "acoruchar",
    "acoruchando": "acoruchar",
    "acoruchara": "acoruchar",
    "acorucharam": "acoruchar",
    "acorucharas": "acoruchar",
    "acorucharde": "acoruchar",
    "acoruchardes": "acoruchar",
    "acoruchare": "acoruchar",
    "acorucharei": "acoruchar",
    "acoruchareis": "acoruchar",
    "acorucharem": "acoruchar",
    "acorucharemos": "acoruchar",
    "acoruchares": "acoruchar",
    "acorucharia": "acoruchar",
    "acoruchariam": "acoruchar",
    "acorucharias": "acoruchar",
    "acorucharmo": "acoruchar",
    "acorucharmos": "acoruchar",
    "acoruchará": "acoruchar",
    "acorucharás": "acoruchar",
    "acorucharão": "acoruchar",
    "acorucharíamos": "acoruchar",
    "acorucharíeis": "acoruchar",
    "acoruchas": "acoruchar",
    "acoruchasse": "acoruchar",
    "acoruchassem": "acoruchar",
    "acoruchasses": "acoruchar",
    "acoruchaste": "acoruchar",
    "acoruchastes": "acoruchar",
    "acoruchava": "acoruchar",
    "acoruchavam": "acoruchar",
    "acoruchavas": "acoruchar",
    "acoruche": "acoruchar",
    "acoruchei": "acoruchar",
    "acorucheis": "acoruchar",
    "acoruchem": "acoruchar",
    "acoruchemo": "acoruchar",
    "acoruchemos": "acoruchar",
    "acoruches": "acoruchar",
    "acorucho": "acoruchar",
    "acoruchou": "acoruchar",
    "acoruchá": "acoruchar",
    "acoruchámo": "acoruchar",
    "acoruchámos": "acoruchar",
    "acorucháramo": "acoruchar",
    "acorucháramos": "acoruchar",
    "acoruchárei": "acoruchar",
    "acorucháreis": "acoruchar",
    "acoruchásseis": "acoruchar",
    "acoruchássemos": "acoruchar",
    "acoruchávamo": "acoruchar",
    "acoruchávamos": "acoruchar",
    "acoruchávei": "acoruchar",
    "acorucháveis": "acoruchar",
    "acorçoada": "acorçoado",
    "acorçoadas": "acorçoado",
    "acorçoados": "acorçoado",
    "acosmias": "acosmia",
    "acosmismos": "acosmismo",
    "acossa": "acossar",
    "acossada": "acossar",
    "acossadas": "acossar",
    "acossado": "acossar",
    "acossadora": "acossador",
    "acossadoras": "acossador",
    "acossadores": "acossador",
    "acossados": "acossar",
    "acossai": "acossar",
    "acossais": "acossar",
    "acossam": "acossar",
    "acossamo": "acossar",
    "acossamos": "acossar",
    "acossando": "acossar",
    "acossara": "acossar",
    "acossaram": "acossar",
    "acossaras": "acossar",
    "acossarde": "acossar",
    "acossardes": "acossar",
    "acossare": "acossar",
    "acossarei": "acossar",
    "acossareis": "acossar",
    "acossarem": "acossar",
    "acossaremos": "acossar",
    "acossares": "acossar",
    "acossaria": "acossar",
    "acossariam": "acossar",
    "acossarias": "acossar",
    "acossarmo": "acossar",
    "acossarmos": "acossar",
    "acossará": "acossar",
    "acossarás": "acossar",
    "acossarão": "acossar",
    "acossaríamos": "acossar",
    "acossaríeis": "acossar",
    "acossas": "acossar",
    "acossasse": "acossar",
    "acossassem": "acossar",
    "acossasses": "acossar",
    "acossaste": "acossar",
    "acossastes": "acossar",
    "acossava": "acossar",
    "acossavam": "acossar",
    "acossavas": "acossar",
    "acosse": "acossar",
    "acossei": "acossar",
    "acosseis": "acossar",
    "acossem": "acossar",
    "acossemo": "acossar",
    "acossemos": "acossar",
    "acosses": "acossar",
    "acosso": "acossar",
    "acossou": "acossar",
    "acossá": "acossar",
    "acossámo": "acossar",
    "acossámos": "acossar",
    "acossáramo": "acossar",
    "acossáramos": "acossar",
    "acossárei": "acossar",
    "acossáreis": "acossar",
    "acossásseis": "acossar",
    "acossássemos": "acossar",
    "acossávamo": "acossar",
    "acossávamos": "acossar",
    "acossávei": "acossar",
    "acossáveis": "acossar",
    "acosta": "acostar",
    "acostada": "acostar",
    "acostadas": "acostar",
    "acostadazinha": "acostado",
    "acostadazinhas": "acostado",
    "acostadazita": "acostado",
    "acostadazitas": "acostado",
    "acostadinha": "acostado",
    "acostadinhas": "acostado",
    "acostadinho": "acostado",
    "acostadinhos": "acostado",
    "acostadita": "acostado",
    "acostaditas": "acostado",
    "acostadito": "acostado",
    "acostaditos": "acostado",
    "acostado": "acostar",
    "acostados": "acostar",
    "acostadozinho": "acostado",
    "acostadozinhos": "acostado",
    "acostadozito": "acostado",
    "acostadozitos": "acostado",
    "acostagens": "acostagem",
    "acostai": "acostar",
    "acostais": "acostar",
    "acostam": "acostar",
    "acostamentos": "acostamento",
    "acostamo": "acostar",
    "acostamos": "acostar",
    "acostando": "acostar",
    "acostara": "acostar",
    "acostaram": "acostar",
    "acostaras": "acostar",
    "acostardes": "acostar",
    "acostarei": "acostar",
    "acostareis": "acostar",
    "acostarem": "acostar",
    "acostaremos": "acostar",
    "acostares": "acostar",
    "acostaria": "acostar",
    "acostariam": "acostar",
    "acostarias": "acostar",
    "acostarmo": "acostar",
    "acostarmos": "acostar",
    "acostará": "acostar",
    "acostarás": "acostar",
    "acostarão": "acostar",
    "acostaríamos": "acostar",
    "acostaríeis": "acostar",
    "acostas": "acostar",
    "acostasse": "acostar",
    "acostassem": "acostar",
    "acostasses": "acostar",
    "acostaste": "acostar",
    "acostastes": "acostar",
    "acostava": "acostar",
    "acostavam": "acostar",
    "acostavas": "acostar",
    "acoste": "acostar",
    "acostei": "acostar",
    "acosteis": "acostar",
    "acostem": "acostar",
    "acostemo": "acostar",
    "acostemos": "acostar",
    "acostes": "acostar",
    "acosto": "acostar",
    "acostos": "acosto",
    "acostou": "acostar",
    "acostuma": "acostumar",
    "acostumada": "acostumar",
    "acostumadas": "acostumar",
    "acostumado": "acostumar",
    "acostumados": "acostumar",
    "acostumadíssima": "acostumado",
    "acostumadíssimas": "acostumado",
    "acostumadíssimo": "acostumado",
    "acostumadíssimos": "acostumado",
    "acostumai": "acostumar",
    "acostumais": "acostumar",
    "acostumam": "acostumar",
    "acostumamo": "acostumar",
    "acostumamos": "acostumar",
    "acostumando": "acostumar",
    "acostumara": "acostumar",
    "acostumaram": "acostumar",
    "acostumaras": "acostumar",
    "acostumarde": "acostumar",
    "acostumardes": "acostumar",
    "acostumare": "acostumar",
    "acostumarei": "acostumar",
    "acostumareis": "acostumar",
    "acostumarem": "acostumar",
    "acostumaremos": "acostumar",
    "acostumares": "acostumar",
    "acostumaria": "acostumar",
    "acostumariam": "acostumar",
    "acostumarias": "acostumar",
    "acostumarmo": "acostumar",
    "acostumarmos": "acostumar",
    "acostumará": "acostumar",
    "acostumarás": "acostumar",
    "acostumarão": "acostumar",
    "acostumaríamos": "acostumar",
    "acostumaríeis": "acostumar",
    "acostumas": "acostumar",
    "acostumasse": "acostumar",
    "acostumassem": "acostumar",
    "acostumasses": "acostumar",
    "acostumaste": "acostumar",
    "acostumastes": "acostumar",
    "acostumava": "acostumar",
    "acostumavam": "acostumar",
    "acostumavas": "acostumar",
    "acostume": "acostumar",
    "acostumei": "acostumar",
    "acostumeis": "acostumar",
    "acostumem": "acostumar",
    "acostumemo": "acostumar",
    "acostumemos": "acostumar",
    "acostumes": "acostumar",
    "acostumo": "acostumar",
    "acostumou": "acostumar",
    "acostumá": "acostumar",
    "acostumámo": "acostumar",
    "acostumámos": "acostumar",
    "acostumáramo": "acostumar",
    "acostumáramos": "acostumar",
    "acostumárei": "acostumar",
    "acostumáreis": "acostumar",
    "acostumásseis": "acostumar",
    "acostumássemos": "acostumar",
    "acostumávamo": "acostumar",
    "acostumávamos": "acostumar",
    "acostumávei": "acostumar",
    "acostumáveis": "acostumar",
    "acostámo": "acostar",
    "acostámos": "acostar",
    "acostáramo": "acostar",
    "acostáramos": "acostar",
    "acostáreis": "acostar",
    "acostásseis": "acostar",
    "acostássemos": "acostar",
    "acostávamo": "acostar",
    "acostávamos": "acostar",
    "acostáveis": "acostável",
    "acotia": "acotiar",
    "acotiada": "acotiar",
    "acotiadas": "acotiar",
    "acotiado": "acotiar",
    "acotiados": "acotiar",
    "acotiai": "acotiar",
    "acotiais": "acotiar",
    "acotiam": "acotiar",
    "acotiamo": "acotiar",
    "acotiamos": "acotiar",
    "acotiando": "acotiar",
    "acotiara": "acotiar",
    "acotiaram": "acotiar",
    "acotiaras": "acotiar",
    "acotiarde": "acotiar",
    "acotiardes": "acotiar",
    "acotiare": "acotiar",
    "acotiarei": "acotiar",
    "acotiareis": "acotiar",
    "acotiarem": "acotiar",
    "acotiaremos": "acotiar",
    "acotiares": "acotiar",
    "acotiaria": "acotiar",
    "acotiariam": "acotiar",
    "acotiarias": "acotiar",
    "acotiarmo": "acotiar",
    "acotiarmos": "acotiar",
    "acotiará": "acotiar",
    "acotiarás": "acotiar",
    "acotiarão": "acotiar",
    "acotiaríamos": "acotiar",
    "acotiaríeis": "acotiar",
    "acotias": "acotiar",
    "acotiasse": "acotiar",
    "acotiassem": "acotiar",
    "acotiasses": "acotiar",
    "acotiaste": "acotiar",
    "acotiastes": "acotiar",
    "acotiava": "acotiar",
    "acotiavam": "acotiar",
    "acotiavas": "acotiar",
    "acotie": "acotiar",
    "acotiei": "acotiar",
    "acotieis": "acotiar",
    "acotiem": "acotiar",
    "acotiemo": "acotiar",
    "acotiemos": "acotiar",
    "acoties": "acotiar",
    "acotiledónea": "acotiledóneo",
    "acotiledóneas": "acotiledóneo",
    "acotiledóneos": "acotiledóneo",
    "acotilédones": "acotilédone",
    "acotio": "acotiar",
    "acotiou": "acotiar",
    "acotiá": "acotiar",
    "acotiámo": "acotiar",
    "acotiámos": "acotiar",
    "acotiáramo": "acotiar",
    "acotiáramos": "acotiar",
    "acotiárei": "acotiar",
    "acotiáreis": "acotiar",
    "acotiásseis": "acotiar",
    "acotiássemos": "acotiar",
    "acotiávamo": "acotiar",
    "acotiávamos": "acotiar",
    "acotiávei": "acotiar",
    "acotiáveis": "acotiar",
    "acotoa": "acotoar",
    "acotoada": "acotoar",
    "acotoadas": "acotoar",
    "acotoado": "acotoar",
    "acotoados": "acotoar",
    "acotoai": "acotoar",
    "acotoais": "acotoar",
    "acotoam": "acotoar",
    "acotoamo": "acotoar",
    "acotoamos": "acotoar",
    "acotoando": "acotoar",
    "acotoara": "acotoar",
    "acotoaram": "acotoar",
    "acotoaras": "acotoar",
    "acotoarde": "acotoar",
    "acotoardes": "acotoar",
    "acotoare": "acotoar",
    "acotoarei": "acotoar",
    "acotoareis": "acotoar",
    "acotoarem": "acotoar",
    "acotoaremos": "acotoar",
    "acotoares": "acotoar",
    "acotoaria": "acotoar",
    "acotoariam": "acotoar",
    "acotoarias": "acotoar",
    "acotoarmo": "acotoar",
    "acotoarmos": "acotoar",
    "acotoará": "acotoar",
    "acotoarás": "acotoar",
    "acotoarão": "acotoar",
    "acotoaríamos": "acotoar",
    "acotoaríeis": "acotoar",
    "acotoas": "acotoar",
    "acotoasse": "acotoar",
    "acotoassem": "acotoar",
    "acotoasses": "acotoar",
    "acotoaste": "acotoar",
    "acotoastes": "acotoar",
    "acotoava": "acotoar",
    "acotoavam": "acotoar",
    "acotoavas": "acotoar",
    "acotoe": "acotoar",
    "acotoei": "acotoar",
    "acotoeis": "acotoar",
    "acotoem": "acotoar",
    "acotoemo": "acotoar",
    "acotoemos": "acotoar",
    "acotoes": "acotoar",
    "acotoo": "acotoar",
    "acotoou": "acotoar",
    "acotovela": "acotovelar",
    "acotovelada": "acotovelar",
    "acotoveladas": "acotovelar",
    "acotovelado": "acotovelar",
    "acotovelados": "acotovelar",
    "acotovelai": "acotovelar",
    "acotovelais": "acotovelar",
    "acotovelam": "acotovelar",
    "acotovelamentos": "acotovelamento",
    "acotovelamo": "acotovelar",
    "acotovelamos": "acotovelar",
    "acotovelando": "acotovelar",
    "acotovelara": "acotovelar",
    "acotovelaram": "acotovelar",
    "acotovelaras": "acotovelar",
    "acotovelarde": "acotovelar",
    "acotovelardes": "acotovelar",
    "acotovelare": "acotovelar",
    "acotovelarei": "acotovelar",
    "acotovelareis": "acotovelar",
    "acotovelarem": "acotovelar",
    "acotovelaremos": "acotovelar",
    "acotovelares": "acotovelar",
    "acotovelaria": "acotovelar",
    "acotovelariam": "acotovelar",
    "acotovelarias": "acotovelar",
    "acotovelarmo": "acotovelar",
    "acotovelarmos": "acotovelar",
    "acotovelará": "acotovelar",
    "acotovelarás": "acotovelar",
    "acotovelarão": "acotovelar",
    "acotovelaríamos": "acotovelar",
    "acotovelaríeis": "acotovelar",
    "acotovelas": "acotovelar",
    "acotovelasse": "acotovelar",
    "acotovelassem": "acotovelar",
    "acotovelasses": "acotovelar",
    "acotovelaste": "acotovelar",
    "acotovelastes": "acotovelar",
    "acotovelava": "acotovelar",
    "acotovelavam": "acotovelar",
    "acotovelavas": "acotovelar",
    "acotovele": "acotovelar",
    "acotovelei": "acotovelar",
    "acotoveleis": "acotovelar",
    "acotovelem": "acotovelar",
    "acotovelemo": "acotovelar",
    "acotovelemos": "acotovelar",
    "acotoveles": "acotovelar",
    "acotovelo": "acotovelar",
    "acotovelou": "acotovelar",
    "acotovelá": "acotovelar",
    "acotovelámo": "acotovelar",
    "acotovelámos": "acotovelar",
    "acotoveláramo": "acotovelar",
    "acotoveláramos": "acotovelar",
    "acotovelárei": "acotovelar",
    "acotoveláreis": "acotovelar",
    "acotovelásseis": "acotovelar",
    "acotovelássemos": "acotovelar",
    "acotovelávamo": "acotovelar",
    "acotovelávamos": "acotovelar",
    "acotovelávei": "acotovelar",
    "acotoveláveis": "acotovelar",
    "acotoá": "acotoar",
    "acotoámo": "acotoar",
    "acotoámos": "acotoar",
    "acotoáramo": "acotoar",
    "acotoáramos": "acotoar",
    "acotoárei": "acotoar",
    "acotoáreis": "acotoar",
    "acotoásseis": "acotoar",
    "acotoássemos": "acotoar",
    "acotoávamo": "acotoar",
    "acotoávamos": "acotoar",
    "acotoávei": "acotoar",
    "acotoáveis": "acotoar",
    "acourela": "acourelar",
    "acourelada": "acourelar",
    "acoureladas": "acourelar",
    "acourelado": "acourelar",
    "acourelados": "acourelar",
    "acourelai": "acourelar",
    "acourelais": "acourelar",
    "acourelam": "acourelar",
    "acourelamentos": "acourelamento",
    "acourelamo": "acourelar",
    "acourelamos": "acourelar",
    "acourelando": "acourelar",
    "acourelara": "acourelar",
    "acourelaram": "acourelar",
    "acourelaras": "acourelar",
    "acourelarde": "acourelar",
    "acourelardes": "acourelar",
    "acourelare": "acourelar",
    "acourelarei": "acourelar",
    "acourelareis": "acourelar",
    "acourelarem": "acourelar",
    "acourelaremos": "acourelar",
    "acourelares": "acourelar",
    "acourelaria": "acourelar",
    "acourelariam": "acourelar",
    "acourelarias": "acourelar",
    "acourelarmo": "acourelar",
    "acourelarmos": "acourelar",
    "acourelará": "acourelar",
    "acourelarás": "acourelar",
    "acourelarão": "acourelar",
    "acourelaríamos": "acourelar",
    "acourelaríeis": "acourelar",
    "acourelas": "acourelar",
    "acourelasse": "acourelar",
    "acourelassem": "acourelar",
    "acourelasses": "acourelar",
    "acourelaste": "acourelar",
    "acourelastes": "acourelar",
    "acourelava": "acourelar",
    "acourelavam": "acourelar",
    "acourelavas": "acourelar",
    "acourele": "acourelar",
    "acourelei": "acourelar",
    "acoureleis": "acourelar",
    "acourelem": "acourelar",
    "acourelemo": "acourelar",
    "acourelemos": "acourelar",
    "acoureles": "acourelar",
    "acourelo": "acourelar",
    "acourelou": "acourelar",
    "acourelá": "acourelar",
    "acourelámo": "acourelar",
    "acourelámos": "acourelar",
    "acoureláramo": "acourelar",
    "acoureláramos": "acourelar",
    "acourelárei": "acourelar",
    "acoureláreis": "acourelar",
    "acourelásseis": "acourelar",
    "acourelássemos": "acourelar",
    "acourelávamo": "acourelar",
    "acourelávamos": "acourelar",
    "acourelávei": "acourelar",
    "acoureláveis": "acourelar",
    "acouta": "acoutar",
    "acoutada": "acoutar",
    "acoutadas": "acoutar",
    "acoutado": "acoutar",
    "acoutadora": "acoutador",
    "acoutadoras": "acoutador",
    "acoutadores": "acoutador",
    "acoutados": "acoutar",
    "acoutai": "acoutar",
    "acoutais": "acoutar",
    "acoutam": "acoutar",
    "acoutamo": "acoutar",
    "acoutamos": "acoutar",
    "acoutando": "acoutar",
    "acoutara": "acoutar",
    "acoutaram": "acoutar",
    "acoutaras": "acoutar",
    "acoutarde": "acoutar",
    "acoutardes": "acoutar",
    "acoutare": "acoutar",
    "acoutarei": "acoutar",
    "acoutareis": "acoutar",
    "acoutarem": "acoutar",
    "acoutaremos": "acoutar",
    "acoutares": "acoutar",
    "acoutaria": "acoutar",
    "acoutariam": "acoutar",
    "acoutarias": "acoutar",
    "acoutarmo": "acoutar",
    "acoutarmos": "acoutar",
    "acoutará": "acoutar",
    "acoutarás": "acoutar",
    "acoutarão": "acoutar",
    "acoutaríamos": "acoutar",
    "acoutaríeis": "acoutar",
    "acoutas": "acoutar",
    "acoutasse": "acoutar",
    "acoutassem": "acoutar",
    "acoutasses": "acoutar",
    "acoutaste": "acoutar",
    "acoutastes": "acoutar",
    "acoutava": "acoutar",
    "acoutavam": "acoutar",
    "acoutavas": "acoutar",
    "acoute": "acoutar",
    "acoutei": "acoutar",
    "acouteis": "acoutar",
    "acoutem": "acoutar",
    "acoutemo": "acoutar",
    "acoutemos": "acoutar",
    "acoutes": "acoutar",
    "acouto": "acoutar",
    "acoutou": "acoutar",
    "acoutá": "acoutar",
    "acoutámo": "acoutar",
    "acoutámos": "acoutar",
    "acoutáramo": "acoutar",
    "acoutáramos": "acoutar",
    "acoutárei": "acoutar",
    "acoutáreis": "acoutar",
    "acoutásseis": "acoutar",
    "acoutássemos": "acoutar",
    "acoutávamo": "acoutar",
    "acoutávamos": "acoutar",
    "acoutávei": "acoutar",
    "acoutáveis": "acoutar",
    "acova": "acovar",
    "acovada": "acovar",
    "acovadas": "acovar",
    "acovado": "acovar",
    "acovados": "acovar",
    "acovai": "acovar",
    "acovais": "acovar",
    "acovam": "acovar",
    "acovamo": "acovar",
    "acovamos": "acovar",
    "acovando": "acovar",
    "acovara": "acovar",
    "acovaram": "acovar",
    "acovaras": "acovar",
    "acovarda": "acovardar",
    "acovardada": "acovardar",
    "acovardadas": "acovardar",
    "acovardado": "acovardar",
    "acovardados": "acovardar",
    "acovardai": "acovardar",
    "acovardais": "acovardar",
    "acovardam": "acovardar",
    "acovardamentos": "acovardamento",
    "acovardamo": "acovardar",
    "acovardamos": "acovardar",
    "acovardando": "acovardar",
    "acovardara": "acovardar",
    "acovardaram": "acovardar",
    "acovardaras": "acovardar",
    "acovardarde": "acovardar",
    "acovardardes": "acovardar",
    "acovardare": "acovardar",
    "acovardarei": "acovardar",
    "acovardareis": "acovardar",
    "acovardarem": "acovardar",
    "acovardaremos": "acovardar",
    "acovardares": "acovardar",
    "acovardaria": "acovardar",
    "acovardariam": "acovardar",
    "acovardarias": "acovardar",
    "acovardarmo": "acovardar",
    "acovardarmos": "acovardar",
    "acovardará": "acovardar",
    "acovardarás": "acovardar",
    "acovardarão": "acovardar",
    "acovardaríamos": "acovardar",
    "acovardaríeis": "acovardar",
    "acovardas": "acovardar",
    "acovardasse": "acovardar",
    "acovardassem": "acovardar",
    "acovardasses": "acovardar",
    "acovardaste": "acovardar",
    "acovardastes": "acovardar",
    "acovardava": "acovardar",
    "acovardavam": "acovardar",
    "acovardavas": "acovardar",
    "acovarde": "acovardar",
    "acovardei": "acovardar",
    "acovardeis": "acovardar",
    "acovardem": "acovardar",
    "acovardemo": "acovardar",
    "acovardemos": "acovardar",
    "acovardes": "acovardar",
    "acovardo": "acovardar",
    "acovardou": "acovardar",
    "acovardá": "acovardar",
    "acovardámo": "acovardar",
    "acovardámos": "acovardar",
    "acovardáramo": "acovardar",
    "acovardáramos": "acovardar",
    "acovardárei": "acovardar",
    "acovardáreis": "acovardar",
    "acovardásseis": "acovardar",
    "acovardássemos": "acovardar",
    "acovardávamo": "acovardar",
    "acovardávamos": "acovardar",
    "acovardávei": "acovardar",
    "acovardáveis": "acovardar",
    "acovare": "acovar",
    "acovarei": "acovar",
    "acovareis": "acovar",
    "acovarem": "acovar",
    "acovaremos": "acovar",
    "acovares": "acovar",
    "acovaria": "acovar",
    "acovariam": "acovar",
    "acovarias": "acovar",
    "acovarmo": "acovar",
    "acovarmos": "acovar",
    "acovará": "acovar",
    "acovarás": "acovar",
    "acovarão": "acovar",
    "acovaríamos": "acovar",
    "acovaríeis": "acovar",
    "acovas": "acovar",
    "acovasse": "acovar",
    "acovassem": "acovar",
    "acovasses": "acovar",
    "acovaste": "acovar",
    "acovastes": "acovar",
    "acovava": "acovar",
    "acovavam": "acovar",
    "acovavas": "acovar",
    "acove": "acovar",
    "acovei": "acovar",
    "acoveis": "acovar",
    "acovem": "acovar",
    "acovemo": "acovar",
    "acovemos": "acovar",
    "acoves": "acovar",
    "acovilha": "acovilhar",
    "acovilhada": "acovilhar",
    "acovilhadas": "acovilhar",
    "acovilhado": "acovilhar",
    "acovilhados": "acovilhar",
    "acovilhai": "acovilhar",
    "acovilhais": "acovilhar",
    "acovilham": "acovilhar",
    "acovilhamo": "acovilhar",
    "acovilhamos": "acovilhar",
    "acovilhando": "acovilhar",
    "acovilhara": "acovilhar",
    "acovilharam": "acovilhar",
    "acovilharas": "acovilhar",
    "acovilharde": "acovilhar",
    "acovilhardes": "acovilhar",
    "acovilhare": "acovilhar",
    "acovilharei": "acovilhar",
    "acovilhareis": "acovilhar",
    "acovilharem": "acovilhar",
    "acovilharemos": "acovilhar",
    "acovilhares": "acovilhar",
    "acovilharia": "acovilhar",
    "acovilhariam": "acovilhar",
    "acovilharias": "acovilhar",
    "acovilharmo": "acovilhar",
    "acovilharmos": "acovilhar",
    "acovilhará": "acovilhar",
    "acovilharás": "acovilhar",
    "acovilharão": "acovilhar",
    "acovilharíamos": "acovilhar",
    "acovilharíeis": "acovilhar",
    "acovilhas": "acovilhar",
    "acovilhasse": "acovilhar",
    "acovilhassem": "acovilhar",
    "acovilhasses": "acovilhar",
    "acovilhaste": "acovilhar",
    "acovilhastes": "acovilhar",
    "acovilhava": "acovilhar",
    "acovilhavam": "acovilhar",
    "acovilhavas": "acovilhar",
    "acovilhe": "acovilhar",
    "acovilhei": "acovilhar",
    "acovilheis": "acovilhar",
    "acovilhem": "acovilhar",
    "acovilhemo": "acovilhar",
    "acovilhemos": "acovilhar",
    "acovilhes": "acovilhar",
    "acovilho": "acovilhar",
    "acovilhou": "acovilhar",
    "acovilhá": "acovilhar",
    "acovilhámo": "acovilhar",
    "acovilhámos": "acovilhar",
    "acovilháramo": "acovilhar",
    "acovilháramos": "acovilhar",
    "acovilhárei": "acovilhar",
    "acovilháreis": "acovilhar",
    "acovilhásseis": "acovilhar",
    "acovilhássemos": "acovilhar",
    "acovilhávamo": "acovilhar",
    "acovilhávamos": "acovilhar",
    "acovilhávei": "acovilhar",
    "acovilháveis": "acovilhar",
    "acovo": "acovar",
    "acovou": "acovar",
    "acová": "acovar",
    "acovámo": "acovar",
    "acovámos": "acovar",
    "acováramo": "acovar",
    "acováramos": "acovar",
    "acovárei": "acovar",
    "acováreis": "acovar",
    "acovásseis": "acovar",
    "acovássemos": "acovar",
    "acovávamo": "acovar",
    "acovávamos": "acovar",
    "acovávei": "acovar",
    "acováveis": "acovar",
    "acpalôs": "acpalô",
    "acra": "acro",
    "acracias": "acracia",
    "acraniana": "acraniano",
    "acranianas": "acraniano",
    "acranianos": "acraniano",
    "acranias": "acrania",
    "acraniotas": "acraniota",
    "acras": "acro",
    "acrasias": "acrasia",
    "acrata": "acrato",
    "acratas": "acrato",
    "acratismos": "acratismo",
    "acratos": "acrato",
    "acratóforos": "acratóforo",
    "acrava": "acravar",
    "acravada": "acravar",
    "acravadas": "acravar",
    "acravado": "acravar",
    "acravados": "acravar",
    "acravai": "acravar",
    "acravais": "acravar",
    "acravam": "acravar",
    "acravamo": "acravar",
    "acravamos": "acravar",
    "acravando": "acravar",
    "acravara": "acravar",
    "acravaram": "acravar",
    "acravaras": "acravar",
    "acravarde": "acravar",
    "acravardes": "acravar",
    "acravare": "acravar",
    "acravarei": "acravar",
    "acravareis": "acravar",
    "acravarem": "acravar",
    "acravaremos": "acravar",
    "acravares": "acravar",
    "acravaria": "acravar",
    "acravariam": "acravar",
    "acravarias": "acravar",
    "acravarmo": "acravar",
    "acravarmos": "acravar",
    "acravará": "acravar",
    "acravarás": "acravar",
    "acravarão": "acravar",
    "acravaríamos": "acravar",
    "acravaríeis": "acravar",
    "acravas": "acravar",
    "acravasse": "acravar",
    "acravassem": "acravar",
    "acravasses": "acravar",
    "acravaste": "acravar",
    "acravastes": "acravar",
    "acravava": "acravar",
    "acravavam": "acravar",
    "acravavas": "acravar",
    "acrave": "acravar",
    "acravei": "acravar",
    "acraveis": "acravar",
    "acravelha": "acravelhar",
    "acravelhada": "acravelhar",
    "acravelhadas": "acravelhar",
    "acravelhado": "acravelhar",
    "acravelhados": "acravelhar",
    "acravelhai": "acravelhar",
    "acravelhais": "acravelhar",
    "acravelham": "acravelhar",
    "acravelhamo": "acravelhar",
    "acravelhamos": "acravelhar",
    "acravelhando": "acravelhar",
    "acravelhara": "acravelhar",
    "acravelharam": "acravelhar",
    "acravelharas": "acravelhar",
    "acravelharde": "acravelhar",
    "acravelhardes": "acravelhar",
    "acravelhare": "acravelhar",
    "acravelharei": "acravelhar",
    "acravelhareis": "acravelhar",
    "acravelharem": "acravelhar",
    "acravelharemos": "acravelhar",
    "acravelhares": "acravelhar",
    "acravelharia": "acravelhar",
    "acravelhariam": "acravelhar",
    "acravelharias": "acravelhar",
    "acravelharmo": "acravelhar",
    "acravelharmos": "acravelhar",
    "acravelhará": "acravelhar",
    "acravelharás": "acravelhar",
    "acravelharão": "acravelhar",
    "acravelharíamos": "acravelhar",
    "acravelharíeis": "acravelhar",
    "acravelhas": "acravelhar",
    "acravelhasse": "acravelhar",
    "acravelhassem": "acravelhar",
    "acravelhasses": "acravelhar",
    "acravelhaste": "acravelhar",
    "acravelhastes": "acravelhar",
    "acravelhava": "acravelhar",
    "acravelhavam": "acravelhar",
    "acravelhavas": "acravelhar",
    "acravelhe": "acravelhar",
    "acravelhei": "acravelhar",
    "acravelheis": "acravelhar",
    "acravelhem": "acravelhar",
    "acravelhemo": "acravelhar",
    "acravelhemos": "acravelhar",
    "acravelhes": "acravelhar",
    "acravelho": "acravelhar",
    "acravelhou": "acravelhar",
    "acravelhá": "acravelhar",
    "acravelhámo": "acravelhar",
    "acravelhámos": "acravelhar",
    "acravelháramo": "acravelhar",
    "acravelháramos": "acravelhar",
    "acravelhárei": "acravelhar",
    "acravelháreis": "acravelhar",
    "acravelhásseis": "acravelhar",
    "acravelhássemos": "acravelhar",
    "acravelhávamo": "acravelhar",
    "acravelhávamos": "acravelhar",
    "acravelhávei": "acravelhar",
    "acravelháveis": "acravelhar",
    "acravem": "acravar",
    "acravemo": "acravar",
    "acravemos": "acravar",
    "acraves": "acravar",
    "acravo": "acravar",
    "acravou": "acravar",
    "acravá": "acravar",
    "acravámo": "acravar",
    "acravámos": "acravar",
    "acraváramo": "acravar",
    "acraváramos": "acravar",
    "acravárei": "acravar",
    "acraváreis": "acravar",
    "acravásseis": "acravar",
    "acravássemos": "acravar",
    "acravávamo": "acravar",
    "acravávamos": "acravar",
    "acravávei": "acravar",
    "acraváveis": "acravar",
    "acrazinha": "acro",
    "acrazinhas": "acro",
    "acrazita": "acro",
    "acrazitas": "acro",
    "acredita": "acreditar",
    "acreditada": "acreditar",
    "acreditadas": "acreditar",
    "acreditado": "acreditar",
    "acreditadora": "acreditador",
    "acreditadoras": "acreditador",
    "acreditadores": "acreditador",
    "acreditados": "acreditar",
    "acreditai": "acreditar",
    "acreditais": "acreditar",
    "acreditam": "acreditar",
    "acreditamo": "acreditar",
    "acreditamos": "acreditar",
    "acreditando": "acreditar",
    "acreditara": "acreditar",
    "acreditaram": "acreditar",
    "acreditaras": "acreditar",
    "acreditarde": "acreditar",
    "acreditardes": "acreditar",
    "acreditare": "acreditar",
    "acreditarei": "acreditar",
    "acreditareis": "acreditar",
    "acreditarem": "acreditar",
    "acreditaremos": "acreditar",
    "acreditares": "acreditar",
    "acreditaria": "acreditar",
    "acreditariam": "acreditar",
    "acreditarias": "acreditar",
    "acreditarmo": "acreditar",
    "acreditarmos": "acreditar",
    "acreditará": "acreditar",
    "acreditarás": "acreditar",
    "acreditarão": "acreditar",
    "acreditaríamos": "acreditar",
    "acreditaríeis": "acreditar",
    "acreditas": "acreditar",
    "acreditasse": "acreditar",
    "acreditassem": "acreditar",
    "acreditasses": "acreditar",
    "acreditaste": "acreditar",
    "acreditastes": "acreditar",
    "acreditava": "acreditar",
    "acreditavam": "acreditar",
    "acreditavas": "acreditar",
    "acreditações": "acreditação",
    "acredite": "acreditar",
    "acreditei": "acreditar",
    "acrediteis": "acreditar",
    "acreditem": "acreditar",
    "acreditemo": "acreditar",
    "acreditemos": "acreditar",
    "acredites": "acreditar",
    "acredito": "acreditar",
    "acreditou": "acreditar",
    "acreditá": "acreditar",
    "acreditámo": "acreditar",
    "acreditámos": "acreditar",
    "acreditáramo": "acreditar",
    "acreditáramos": "acreditar",
    "acreditárei": "acreditar",
    "acreditáreis": "acreditar",
    "acreditásseis": "acreditar",
    "acreditássemos": "acreditar",
    "acreditávamo": "acreditar",
    "acreditávamos": "acreditar",
    "acreditávei": "acreditar",
    "acreditáveis": "acreditável",
    "acres": "acre",
    "acresce": "acrescer",
    "acrescei": "acrescer",
    "acresceis": "acrescer",
    "acrescem": "acrescer",
    "acrescemo": "acrescer",
    "acrescemos": "acrescer",
    "acrescendo": "acrescer",
    "acrescenta": "acrescentar",
    "acrescentada": "acrescentar",
    "acrescentadas": "acrescentar",
    "acrescentado": "acrescentar",
    "acrescentados": "acrescentar",
    "acrescentai": "acrescentar",
    "acrescentais": "acrescentar",
    "acrescentam": "acrescentar",
    "acrescentamentos": "acrescentamento",
    "acrescentamo": "acrescentar",
    "acrescentamos": "acrescentar",
    "acrescentando": "acrescentar",
    "acrescentara": "acrescentar",
    "acrescentaram": "acrescentar",
    "acrescentaras": "acrescentar",
    "acrescentarde": "acrescentar",
    "acrescentardes": "acrescentar",
    "acrescentare": "acrescentar",
    "acrescentarei": "acrescentar",
    "acrescentareis": "acrescentar",
    "acrescentarem": "acrescentar",
    "acrescentaremos": "acrescentar",
    "acrescentares": "acrescentar",
    "acrescentaria": "acrescentar",
    "acrescentariam": "acrescentar",
    "acrescentarias": "acrescentar",
    "acrescentarmo": "acrescentar",
    "acrescentarmos": "acrescentar",
    "acrescentará": "acrescentar",
    "acrescentarás": "acrescentar",
    "acrescentarão": "acrescentar",
    "acrescentaríamos": "acrescentar",
    "acrescentaríeis": "acrescentar",
    "acrescentas": "acrescentar",
    "acrescentasse": "acrescentar",
    "acrescentassem": "acrescentar",
    "acrescentasses": "acrescentar",
    "acrescentaste": "acrescentar",
    "acrescentastes": "acrescentar",
    "acrescentava": "acrescentar",
    "acrescentavam": "acrescentar",
    "acrescentavas": "acrescentar",
    "acrescente": "acrescentar",
    "acrescentei": "acrescentar",
    "acrescenteis": "acrescentar",
    "acrescentem": "acrescentar",
    "acrescentemo": "acrescentar",
    "acrescentemos": "acrescentar",
    "acrescentes": "acrescente",
    "acrescento": "acrescentar",
    "acrescentos": "acrescento",
    "acrescentou": "acrescentar",
    "acrescentá": "acrescentar",
    "acrescentámo": "acrescentar",
    "acrescentámos": "acrescentar",
    "acrescentáramo": "acrescentar",
    "acrescentáramos": "acrescentar",
    "acrescentárei": "acrescentar",
    "acrescentáreis": "acrescentar",
    "acrescentásseis": "acrescentar",
    "acrescentássemos": "acrescentar",
    "acrescentávamo": "acrescentar",
    "acrescentávamos": "acrescentar",
    "acrescentávei": "acrescentar",
    "acrescentáveis": "acrescentável",
    "acrescera": "acrescer",
    "acresceram": "acrescer",
    "acresceras": "acrescer",
    "acrescerdes": "acrescer",
    "acrescerei": "acrescer",
    "acrescereis": "acrescer",
    "acrescerem": "acrescer",
    "acresceremos": "acrescer",
    "acresceres": "acrescer",
    "acresceria": "acrescer",
    "acresceriam": "acrescer",
    "acrescerias": "acrescer",
    "acrescermo": "acrescer",
    "acrescermos": "acrescer",
    "acrescerá": "acrescer",
    "acrescerás": "acrescer",
    "acrescerão": "acrescer",
    "acresceríamos": "acrescer",
    "acresceríeis": "acrescer",
    "acresces": "acrescer",
    "acrescesse": "acrescer",
    "acrescessem": "acrescer",
    "acrescesses": "acrescer",
    "acresceste": "acrescer",
    "acrescestes": "acrescer",
    "acresceu": "acrescer",
    "acresci": "acrescer",
    "acrescia": "acrescer",
    "acresciam": "acrescer",
    "acrescias": "acrescer",
    "acrescida": "acrescido",
    "acrescidas": "acrescido",
    "acrescido": "acrescer",
    "acrescidos": "acrescido",
    "acrescimentos": "acrescimento",
    "acrescências": "acrescência",
    "acrescêramo": "acrescer",
    "acrescêramos": "acrescer",
    "acrescêreis": "acrescer",
    "acrescêsseis": "acrescer",
    "acrescêssemos": "acrescer",
    "acrescíamo": "acrescer",
    "acrescíamos": "acrescer",
    "acrescíeis": "acrescer",
    "acresça": "acrescer",
    "acresçais": "acrescer",
    "acresçam": "acrescer",
    "acresçamo": "acrescer",
    "acresçamos": "acrescer",
    "acresças": "acrescer",
    "acresço": "acrescer",
    "acriance": "acriançar",
    "acriancei": "acriançar",
    "acrianceis": "acriançar",
    "acriancem": "acriançar",
    "acriancemo": "acriançar",
    "acriancemos": "acriançar",
    "acriances": "acriançar",
    "acriança": "acriançar",
    "acriançada": "acriançar",
    "acriançadas": "acriançar",
    "acriançado": "acriançar",
    "acriançados": "acriançar",
    "acriançai": "acriançar",
    "acriançais": "acriançar",
    "acriançam": "acriançar",
    "acriançamo": "acriançar",
    "acriançamos": "acriançar",
    "acriançando": "acriançar",
    "acriançara": "acriançar",
    "acriançaram": "acriançar",
    "acriançaras": "acriançar",
    "acriançarde": "acriançar",
    "acriançardes": "acriançar",
    "acriançare": "acriançar",
    "acriançarei": "acriançar",
    "acriançareis": "acriançar",
    "acriançarem": "acriançar",
    "acriançaremos": "acriançar",
    "acriançares": "acriançar",
    "acriançaria": "acriançar",
    "acriançariam": "acriançar",
    "acriançarias": "acriançar",
    "acriançarmo": "acriançar",
    "acriançarmos": "acriançar",
    "acriançará": "acriançar",
    "acriançarás": "acriançar",
    "acriançarão": "acriançar",
    "acriançaríamos": "acriançar",
    "acriançaríeis": "acriançar",
    "acrianças": "acriançar",
    "acriançasse": "acriançar",
    "acriançassem": "acriançar",
    "acriançasses": "acriançar",
    "acriançaste": "acriançar",
    "acriançastes": "acriançar",
    "acriançava": "acriançar",
    "acriançavam": "acriançar",
    "acriançavas": "acriançar",
    "acrianço": "acriançar",
    "acriançou": "acriançar",
    "acriançá": "acriançar",
    "acriançámo": "acriançar",
    "acriançámos": "acriançar",
    "acriançáramo": "acriançar",
    "acriançáramos": "acriançar",
    "acriançárei": "acriançar",
    "acriançáreis": "acriançar",
    "acriançásseis": "acriançar",
    "acriançássemos": "acriançar",
    "acriançávamo": "acriançar",
    "acriançávamos": "acriançar",
    "acriançávei": "acriançar",
    "acriançáveis": "acriançar",
    "acribias": "acribia",
    "acribologias": "acribologia",
    "acridiana": "acridiano",
    "acridianas": "acridiano",
    "acridianos": "acridiano",
    "acridofagias": "acridofagia",
    "acridófaga": "acridófago",
    "acridófagas": "acridófago",
    "acridófagos": "acridófago",
    "acrimancias": "acrimancia",
    "acrimantes": "acrimante",
    "acrimoniosa": "acrimonioso",
    "acrimoniosas": "acrimonioso",
    "acrimoniosos": "acrimonioso",
    "acrimónias": "acrimónia",
    "acrinias": "acrinia",
    "acrisias": "acrisia",
    "acrisola": "acrisolar",
    "acrisolada": "acrisolar",
    "acrisoladas": "acrisolar",
    "acrisolado": "acrisolar",
    "acrisoladora": "acrisolador",
    "acrisoladoras": "acrisolador",
    "acrisoladores": "acrisolador",
    "acrisolados": "acrisolar",
    "acrisolai": "acrisolar",
    "acrisolais": "acrisolar",
    "acrisolam": "acrisolar",
    "acrisolamo": "acrisolar",
    "acrisolamos": "acrisolar",
    "acrisolando": "acrisolar",
    "acrisolara": "acrisolar",
    "acrisolaram": "acrisolar",
    "acrisolaras": "acrisolar",
    "acrisolarde": "acrisolar",
    "acrisolardes": "acrisolar",
    "acrisolare": "acrisolar",
    "acrisolarei": "acrisolar",
    "acrisolareis": "acrisolar",
    "acrisolarem": "acrisolar",
    "acrisolaremos": "acrisolar",
    "acrisolares": "acrisolar",
    "acrisolaria": "acrisolar",
    "acrisolariam": "acrisolar",
    "acrisolarias": "acrisolar",
    "acrisolarmo": "acrisolar",
    "acrisolarmos": "acrisolar",
    "acrisolará": "acrisolar",
    "acrisolarás": "acrisolar",
    "acrisolarão": "acrisolar",
    "acrisolaríamos": "acrisolar",
    "acrisolaríeis": "acrisolar",
    "acrisolas": "acrisolar",
    "acrisolasse": "acrisolar",
    "acrisolassem": "acrisolar",
    "acrisolasses": "acrisolar",
    "acrisolaste": "acrisolar",
    "acrisolastes": "acrisolar",
    "acrisolava": "acrisolar",
    "acrisolavam": "acrisolar",
    "acrisolavas": "acrisolar",
    "acrisole": "acrisolar",
    "acrisolei": "acrisolar",
    "acrisoleis": "acrisolar",
    "acrisolem": "acrisolar",
    "acrisolemo": "acrisolar",
    "acrisolemos": "acrisolar",
    "acrisoles": "acrisolar",
    "acrisolo": "acrisolar",
    "acrisolou": "acrisolar",
    "acrisolá": "acrisolar",
    "acrisolámo": "acrisolar",
    "acrisolámos": "acrisolar",
    "acrisoláramo": "acrisolar",
    "acrisoláramos": "acrisolar",
    "acrisolárei": "acrisolar",
    "acrisoláreis": "acrisolar",
    "acrisolásseis": "acrisolar",
    "acrisolássemos": "acrisolar",
    "acrisolávamo": "acrisolar",
    "acrisolávamos": "acrisolar",
    "acrisolávei": "acrisolar",
    "acrisoláveis": "acrisolar",
    "acritudes": "acritude",
    "acroamas": "acroama",
    "acroamática": "acroamático",
    "acroamáticas": "acroamático",
    "acroamáticos": "acroamático",
    "acroases": "acroase",
    "acrobacias": "acrobacia",
    "acrobatas": "acrobata",
    "acrobatismos": "acrobatismo",
    "acrobática": "acrobático",
    "acrobáticas": "acrobático",
    "acrobáticos": "acrobático",
    "acrocianoses": "acrocianose",
    "acrodinias": "acrodinia",
    "acrofobias": "acrofobia",
    "acrofonias": "acrofonia",
    "acrogramas": "acrograma",
    "acroleínas": "acroleína",
    "acrologias": "acrologia",
    "acroma": "acromo",
    "acromanias": "acromania",
    "acromas": "acromo",
    "acromasias": "acromasia",
    "acromatinas": "acromatina",
    "acromatismos": "acromatismo",
    "acromatiza": "acromatizar",
    "acromatizada": "acromatizar",
    "acromatizadas": "acromatizar",
    "acromatizado": "acromatizar",
    "acromatizados": "acromatizar",
    "acromatizai": "acromatizar",
    "acromatizais": "acromatizar",
    "acromatizam": "acromatizar",
    "acromatizamo": "acromatizar",
    "acromatizamos": "acromatizar",
    "acromatizando": "acromatizar",
    "acromatizara": "acromatizar",
    "acromatizaram": "acromatizar",
    "acromatizaras": "acromatizar",
    "acromatizarde": "acromatizar",
    "acromatizardes": "acromatizar",
    "acromatizare": "acromatizar",
    "acromatizarei": "acromatizar",
    "acromatizareis": "acromatizar",
    "acromatizarem": "acromatizar",
    "acromatizaremos": "acromatizar",
    "acromatizares": "acromatizar",
    "acromatizaria": "acromatizar",
    "acromatizariam": "acromatizar",
    "acromatizarias": "acromatizar",
    "acromatizarmo": "acromatizar",
    "acromatizarmos": "acromatizar",
    "acromatizará": "acromatizar",
    "acromatizarás": "acromatizar",
    "acromatizarão": "acromatizar",
    "acromatizaríamos": "acromatizar",
    "acromatizaríeis": "acromatizar",
    "acromatizas": "acromatizar",
    "acromatizasse": "acromatizar",
    "acromatizassem": "acromatizar",
    "acromatizasses": "acromatizar",
    "acromatizaste": "acromatizar",
    "acromatizastes": "acromatizar",
    "acromatizava": "acromatizar",
    "acromatizavam": "acromatizar",
    "acromatizavas": "acromatizar",
    "acromatizações": "acromatização",
    "acromatize": "acromatizar",
    "acromatizei": "acromatizar",
    "acromatizeis": "acromatizar",
    "acromatizem": "acromatizar",
    "acromatizemo": "acromatizar",
    "acromatizemos": "acromatizar",
    "acromatizes": "acromatizar",
    "acromatizo": "acromatizar",
    "acromatizou": "acromatizar",
    "acromatizá": "acromatizar",
    "acromatizámo": "acromatizar",
    "acromatizámos": "acromatizar",
    "acromatizáramo": "acromatizar",
    "acromatizáramos": "acromatizar",
    "acromatizárei": "acromatizar",
    "acromatizáreis": "acromatizar",
    "acromatizásseis": "acromatizar",
    "acromatizássemos": "acromatizar",
    "acromatizávamo": "acromatizar",
    "acromatizávamos": "acromatizar",
    "acromatizávei": "acromatizar",
    "acromatizáveis": "acromatizar",
    "acromatopsias": "acromatopsia",
    "acromatoses": "acromatose",
    "acromiais": "acromial",
    "acromias": "acromia",
    "acromos": "acromo",
    "acromática": "acromático",
    "acromáticas": "acromático",
    "acromáticos": "acromático",
    "acronias": "acronia",
    "acropatas": "acropata",
    "acropatias": "acropatia",
    "acropólios": "acropólio",
    "acros": "acro",
    "acrosofias": "acrosofia",
    "acrossemias": "acrossemia",
    "acrossomas": "acrossoma",
    "acrossomos": "acrossomo",
    "acrotismos": "acrotismo",
    "acrotérios": "acrotério",
    "acrozinho": "acro",
    "acrozinhos": "acro",
    "acrozito": "acro",
    "acrozitos": "acro",
    "acroítas": "acroíta",
    "acroítes": "acroíte",
    "acrás": "acrá",
    "acrânia": "acrânio",
    "acrânias": "acrânio",
    "acrânios": "acrânio",
    "acréscimos": "acréscimo",
    "acrídia": "acrídio",
    "acrídias": "acrídio",
    "acrídios": "acrídio",
    "acrílica": "acrílico",
    "acrílicas": "acrílico",
    "acrílicos": "acrílico",
    "acrínica": "acrínico",
    "acrínicas": "acrínico",
    "acrínicos": "acrínico",
    "acrítica": "acrítico",
    "acríticas": "acrítico",
    "acríticos": "acrítico",
    "acróforas": "acrófora",
    "acrólitos": "acrólito",
    "acrómica": "acrómico",
    "acrómicas": "acrómico",
    "acrómicos": "acrómico",
    "acrómios": "acrómio",
    "acrónica": "acrónico",
    "acrónicas": "acrónico",
    "acrónicos": "acrónico",
    "acrónimos": "acrónimo",
    "acrópoles": "acrópole",
    "acróstica": "acróstico",
    "acrósticas": "acróstico",
    "acrósticos": "acróstico",
    "actas": "acta",
    "actinolites": "actinolite",
    "actinometrias": "actinometria",
    "actinomorfa": "actinomorfo",
    "actinomorfas": "actinomorfo",
    "actinomorfos": "actinomorfo",
    "actinoscopias": "actinoscopia",
    "actinoterapias": "actinoterapia",
    "actinotos": "actinoto",
    "actinários": "actinário",
    "actinómetros": "actinómetro",
    "actinônios": "actinônio",
    "activa": "activo",
    "activada": "activar",
    "activadas": "activar",
    "activado": "activar",
    "activadora": "activador",
    "activadoras": "activador",
    "activadores": "activador",
    "activados": "activar",
    "activai": "activar",
    "activais": "activar",
    "activam": "activar",
    "activamo": "activar",
    "activamos": "activar",
    "activando": "activar",
    "activantes": "activante",
    "activara": "activar",
    "activaram": "activar",
    "activaras": "activar",
    "activarde": "activar",
    "activardes": "activar",
    "activare": "activar",
    "activarei": "activar",
    "activareis": "activar",
    "activarem": "activar",
    "activaremos": "activar",
    "activares": "activar",
    "activaria": "activar",
    "activariam": "activar",
    "activarias": "activar",
    "activarmo": "activar",
    "activarmos": "activar",
    "activará": "activar",
    "activarás": "activar",
    "activarão": "activar",
    "activaríamos": "activar",
    "activaríeis": "activar",
    "activas": "activo",
    "activasse": "activar",
    "activassem": "activar",
    "activasses": "activar",
    "activaste": "activar",
    "activastes": "activar",
    "activava": "activar",
    "activavam": "activar",
    "activavas": "activar",
    "activações": "activação",
    "active": "activar",
    "activei": "activar",
    "activeis": "activar",
    "activem": "activar",
    "activemo": "activar",
    "activemos": "activar",
    "actives": "activar",
    "actividades": "actividade",
    "activismos": "activismo",
    "activistas": "activista",
    "activo": "activar",
    "activos": "activo",
    "activou": "activar",
    "activá": "activar",
    "activámo": "activar",
    "activámos": "activar",
    "activáramo": "activar",
    "activáramos": "activar",
    "activárei": "activar",
    "activáreis": "activar",
    "activásseis": "activar",
    "activássemos": "activar",
    "activávamo": "activar",
    "activávamos": "activar",
    "activávei": "activar",
    "activáveis": "activável",
    "activíssima": "activo",
    "activíssimas": "activo",
    "activíssimo": "activo",
    "activíssimos": "activo",
    "actores": "actor",
    "actos": "acto",
    "actriz": "actor",
    "actrizes": "actor",
    "actua": "actuar",
    "actuada": "actuar",
    "actuadas": "actuar",
    "actuado": "actuar",
    "actuadores": "actuador",
    "actuados": "actuar",
    "actuai": "actuar",
    "actuais": "actuar",
    "actuaizinhas": "actual",
    "actuaizinhos": "actual",
    "actuaizitas": "actual",
    "actuaizitos": "actual",
    "actualidades": "actualidade",
    "actualismos": "actualismo",
    "actualistas": "actualista",
    "actualiza": "actualizar",
    "actualizada": "actualizar",
    "actualizadas": "actualizar",
    "actualizado": "actualizar",
    "actualizadora": "actualizador",
    "actualizadoras": "actualizador",
    "actualizadores": "actualizador",
    "actualizados": "actualizar",
    "actualizadíssima": "actualizado",
    "actualizadíssimas": "actualizado",
    "actualizadíssimo": "actualizado",
    "actualizadíssimos": "actualizado",
    "actualizai": "actualizar",
    "actualizais": "actualizar",
    "actualizam": "actualizar",
    "actualizamo": "actualizar",
    "actualizamos": "actualizar",
    "actualizando": "actualizar",
    "actualizara": "actualizar",
    "actualizaram": "actualizar",
    "actualizaras": "actualizar",
    "actualizarde": "actualizar",
    "actualizardes": "actualizar",
    "actualizare": "actualizar",
    "actualizarei": "actualizar",
    "actualizareis": "actualizar",
    "actualizarem": "actualizar",
    "actualizaremos": "actualizar",
    "actualizares": "actualizar",
    "actualizaria": "actualizar",
    "actualizariam": "actualizar",
    "actualizarias": "actualizar",
    "actualizarmo": "actualizar",
    "actualizarmos": "actualizar",
    "actualizará": "actualizar",
    "actualizarás": "actualizar",
    "actualizarão": "actualizar",
    "actualizaríamos": "actualizar",
    "actualizaríeis": "actualizar",
    "actualizas": "actualizar",
    "actualizasse": "actualizar",
    "actualizassem": "actualizar",
    "actualizasses": "actualizar",
    "actualizaste": "actualizar",
    "actualizastes": "actualizar",
    "actualizava": "actualizar",
    "actualizavam": "actualizar",
    "actualizavas": "actualizar",
    "actualizações": "actualização",
    "actualize": "actualizar",
    "actualizei": "actualizar",
    "actualizeis": "actualizar",
    "actualizem": "actualizar",
    "actualizemo": "actualizar",
    "actualizemos": "actualizar",
    "actualizes": "actualizar",
    "actualizo": "actualizar",
    "actualizou": "actualizar",
    "actualizá": "actualizar",
    "actualizámo": "actualizar",
    "actualizámos": "actualizar",
    "actualizáramo": "actualizar",
    "actualizáramos": "actualizar",
    "actualizárei": "actualizar",
    "actualizáreis": "actualizar",
    "actualizásseis": "actualizar",
    "actualizássemos": "actualizar",
    "actualizávamo": "actualizar",
    "actualizávamos": "actualizar",
    "actualizávei": "actualizar",
    "actualizáveis": "actualizável",
    "actualzinha": "actual",
    "actualzinho": "actual",
    "actualzita": "actual",
    "actualzito": "actual",
    "actualíssima": "actual",
    "actualíssimas": "actual",
    "actualíssimo": "actual",
    "actualíssimos": "actual",
    "actuam": "actuar",
    "actuamo": "actuar",
    "actuamos": "actuar",
    "actuando": "actuar",
    "actuantes": "actuante",
    "actuara": "actuar",
    "actuaram": "actuar",
    "actuaras": "actuar",
    "actuardes": "actuar",
    "actuarei": "actuar",
    "actuareis": "actuar",
    "actuarem": "actuar",
    "actuaremos": "actuar",
    "actuares": "actuar",
    "actuaria": "actuar",
    "actuariais": "actuarial",
    "actuariam": "actuar",
    "actuarias": "actuar",
    "actuarmo": "actuar",
    "actuarmos": "actuar",
    "actuará": "actuar",
    "actuarás": "actuar",
    "actuarão": "actuar",
    "actuaríamos": "actuar",
    "actuaríeis": "actuar",
    "actuas": "actuar",
    "actuasse": "actuar",
    "actuassem": "actuar",
    "actuasses": "actuar",
    "actuaste": "actuar",
    "actuastes": "actuar",
    "actuava": "actuar",
    "actuavam": "actuar",
    "actuavas": "actuar",
    "actuações": "actuação",
    "actue": "actuar",
    "actuei": "actuar",
    "actueis": "actuar",
    "actuem": "actuar",
    "actuemo": "actuar",
    "actuemos": "actuar",
    "actues": "actuar",
    "actuo": "actuar",
    "actuosa": "actuoso",
    "actuosas": "actuoso",
    "actuosos": "actuoso",
    "actuou": "actuar",
    "actuámo": "actuar",
    "actuámos": "actuar",
    "actuáramo": "actuar",
    "actuáramos": "actuar",
    "actuáreis": "actuar",
    "actuária": "actuário",
    "actuárias": "actuário",
    "actuários": "actuário",
    "actuásseis": "actuar",
    "actuássemos": "actuar",
    "actuávamo": "actuar",
    "actuávamos": "actuar",
    "actuáveis": "actuar",
    "actínias": "actínia",
    "actínica": "actínico",
    "actínicas": "actínico",
    "actínicos": "actínico",
    "actínios": "actínio",
    "acua": "acuar",
    "acuada": "acuar",
    "acuadas": "acuar",
    "acuado": "acuar",
    "acuados": "acuar",
    "acuai": "acuar",
    "acuais": "acuar",
    "acuam": "acuar",
    "acuamentos": "acuamento",
    "acuamo": "acuar",
    "acuamos": "acuar",
    "acuando": "acuar",
    "acuara": "acuar",
    "acuaram": "acuar",
    "acuaras": "acuar",
    "acuardes": "acuar",
    "acuarei": "acuar",
    "acuareis": "acuar",
    "acuarem": "acuar",
    "acuaremos": "acuar",
    "acuares": "acuar",
    "acuaria": "acuar",
    "acuariam": "acuar",
    "acuarias": "acuar",
    "acuarmo": "acuar",
    "acuarmos": "acuar",
    "acuará": "acuar",
    "acuarás": "acuar",
    "acuarão": "acuar",
    "acuaríamos": "acuar",
    "acuaríeis": "acuar",
    "acuas": "acuar",
    "acuasse": "acuar",
    "acuassem": "acuar",
    "acuasses": "acuar",
    "acuaste": "acuar",
    "acuastes": "acuar",
    "acuava": "acuar",
    "acuavam": "acuar",
    "acuavas": "acuar",
    "acuações": "acuação",
    "acuchila": "acuchilar",
    "acuchilada": "acuchilar",
    "acuchiladas": "acuchilar",
    "acuchilado": "acuchilar",
    "acuchilados": "acuchilar",
    "acuchilai": "acuchilar",
    "acuchilais": "acuchilar",
    "acuchilam": "acuchilar",
    "acuchilamo": "acuchilar",
    "acuchilamos": "acuchilar",
    "acuchilando": "acuchilar",
    "acuchilara": "acuchilar",
    "acuchilaram": "acuchilar",
    "acuchilaras": "acuchilar",
    "acuchilarde": "acuchilar",
    "acuchilardes": "acuchilar",
    "acuchilare": "acuchilar",
    "acuchilarei": "acuchilar",
    "acuchilareis": "acuchilar",
    "acuchilarem": "acuchilar",
    "acuchilaremos": "acuchilar",
    "acuchilares": "acuchilar",
    "acuchilaria": "acuchilar",
    "acuchilariam": "acuchilar",
    "acuchilarias": "acuchilar",
    "acuchilarmo": "acuchilar",
    "acuchilarmos": "acuchilar",
    "acuchilará": "acuchilar",
    "acuchilarás": "acuchilar",
    "acuchilarão": "acuchilar",
    "acuchilaríamos": "acuchilar",
    "acuchilaríeis": "acuchilar",
    "acuchilas": "acuchilar",
    "acuchilasse": "acuchilar",
    "acuchilassem": "acuchilar",
    "acuchilasses": "acuchilar",
    "acuchilaste": "acuchilar",
    "acuchilastes": "acuchilar",
    "acuchilava": "acuchilar",
    "acuchilavam": "acuchilar",
    "acuchilavas": "acuchilar",
    "acuchile": "acuchilar",
    "acuchilei": "acuchilar",
    "acuchileis": "acuchilar",
    "acuchilem": "acuchilar",
    "acuchilemo": "acuchilar",
    "acuchilemos": "acuchilar",
    "acuchiles": "acuchilar",
    "acuchilo": "acuchilar",
    "acuchilou": "acuchilar",
    "acuchilá": "acuchilar",
    "acuchilámo": "acuchilar",
    "acuchilámos": "acuchilar",
    "acuchiláramo": "acuchilar",
    "acuchiláramos": "acuchilar",
    "acuchilárei": "acuchilar",
    "acuchiláreis": "acuchilar",
    "acuchilásseis": "acuchilar",
    "acuchilássemos": "acuchilar",
    "acuchilávamo": "acuchilar",
    "acuchilávamos": "acuchilar",
    "acuchilávei": "acuchilar",
    "acuchiláveis": "acuchilar",
    "acucula": "acucular",
    "acuculada": "acucular",
    "acuculadas": "acucular",
    "acuculado": "acucular",
    "acuculados": "acucular",
    "acuculai": "acucular",
    "acuculais": "acucular",
    "acuculam": "acucular",
    "acuculamo": "acucular",
    "acuculamos": "acucular",
    "acuculando": "acucular",
    "acuculara": "acucular",
    "acucularam": "acucular",
    "acucularas": "acucular",
    "acucularde": "acucular",
    "acuculardes": "acucular",
    "acuculare": "acucular",
    "acucularei": "acucular",
    "acuculareis": "acucular",
    "acucularem": "acucular",
    "acucularemos": "acucular",
    "acuculares": "acucular",
    "acucularia": "acucular",
    "acuculariam": "acucular",
    "acucularias": "acucular",
    "acucularmo": "acucular",
    "acucularmos": "acucular",
    "acuculará": "acucular",
    "acucularás": "acucular",
    "acucularão": "acucular",
    "acucularíamos": "acucular",
    "acucularíeis": "acucular",
    "acuculas": "acucular",
    "acuculasse": "acucular",
    "acuculassem": "acucular",
    "acuculasses": "acucular",
    "acuculaste": "acucular",
    "acuculastes": "acucular",
    "acuculava": "acucular",
    "acuculavam": "acucular",
    "acuculavas": "acucular",
    "acucule": "acucular",
    "acuculei": "acucular",
    "acuculeis": "acucular",
    "acuculem": "acucular",
    "acuculemo": "acucular",
    "acuculemos": "acucular",
    "acucules": "acucular",
    "acuculo": "acucular",
    "acuculou": "acucular",
    "acuculá": "acucular",
    "acuculámo": "acucular",
    "acuculámos": "acucular",
    "acuculáramo": "acucular",
    "acuculáramos": "acucular",
    "acuculárei": "acucular",
    "acuculáreis": "acucular",
    "acuculásseis": "acucular",
    "acuculássemos": "acucular",
    "acuculávamo": "acucular",
    "acuculávamos": "acucular",
    "acuculávei": "acucular",
    "acuculáveis": "acucular",
    "acuda": "acudir",
    "acudais": "acudir",
    "acudam": "acudir",
    "acudamo": "acudir",
    "acudamos": "acudir",
    "acudas": "acudir",
    "acudi": "acudir",
    "acudia": "acudir",
    "acudiam": "acudir",
    "acudias": "acudir",
    "acudida": "acudir",
    "acudidas": "acudir",
    "acudido": "acudir",
    "acudidos": "acudir",
    "acudimo": "acudir",
    "acudimos": "acudir",
    "acudindo": "acudir",
    "acudira": "acudir",
    "acudiram": "acudir",
    "acudiras": "acudir",
    "acudirde": "acudir",
    "acudirdes": "acudir",
    "acudire": "acudir",
    "acudirei": "acudir",
    "acudireis": "acudir",
    "acudirem": "acudir",
    "acudiremos": "acudir",
    "acudires": "acudir",
    "acudiria": "acudir",
    "acudiriam": "acudir",
    "acudirias": "acudir",
    "acudirmo": "acudir",
    "acudirmos": "acudir",
    "acudirá": "acudir",
    "acudirás": "acudir",
    "acudirão": "acudir",
    "acudiríamos": "acudir",
    "acudiríeis": "acudir",
    "acudis": "acudir",
    "acudisse": "acudir",
    "acudissem": "acudir",
    "acudisses": "acudir",
    "acudiste": "acudir",
    "acudistes": "acudir",
    "acudiu": "acudir",
    "acudo": "acudir",
    "acudíamo": "acudir",
    "acudíamos": "acudir",
    "acudíei": "acudir",
    "acudíeis": "acudir",
    "acudíramo": "acudir",
    "acudíramos": "acudir",
    "acudírei": "acudir",
    "acudíreis": "acudir",
    "acudísseis": "acudir",
    "acudíssemos": "acudir",
    "acue": "acuar",
    "acuei": "acuar",
    "acueis": "acuar",
    "acuem": "acuar",
    "acuemo": "acuar",
    "acuemos": "acuar",
    "acues": "acuar",
    "acuidades": "acuidade",
    "aculeada": "aculear",
    "aculeadas": "aculear",
    "aculeado": "aculear",
    "aculeados": "aculear",
    "aculeai": "aculear",
    "aculeais": "aculear",
    "aculeamo": "aculear",
    "aculeamos": "aculear",
    "aculeando": "aculear",
    "aculeara": "aculear",
    "aculearam": "aculear",
    "aculearas": "aculear",
    "aculearde": "aculear",
    "aculeardes": "aculear",
    "aculeare": "aculear",
    "aculearei": "aculear",
    "aculeareis": "aculear",
    "aculearem": "aculear",
    "aculearemos": "aculear",
    "aculeares": "aculear",
    "aculearia": "aculear",
    "aculeariam": "aculear",
    "aculearias": "aculear",
    "aculearmo": "aculear",
    "aculearmos": "aculear",
    "aculeará": "aculear",
    "aculearás": "aculear",
    "aculearão": "aculear",
    "aculearíamos": "aculear",
    "aculearíeis": "aculear",
    "aculeasse": "aculear",
    "aculeassem": "aculear",
    "aculeasses": "aculear",
    "aculeaste": "aculear",
    "aculeastes": "aculear",
    "aculeava": "aculear",
    "aculeavam": "aculear",
    "aculeavas": "aculear",
    "aculeei": "aculear",
    "aculeeis": "aculear",
    "aculeemo": "aculear",
    "aculeemos": "aculear",
    "aculeia": "aculear",
    "aculeiam": "aculear",
    "aculeias": "aculear",
    "aculeie": "aculear",
    "aculeiem": "aculear",
    "aculeies": "aculear",
    "aculeiformes": "aculeiforme",
    "aculeio": "aculear",
    "aculeou": "aculear",
    "aculeá": "aculear",
    "aculeámo": "aculear",
    "aculeámos": "aculear",
    "aculeáramo": "aculear",
    "aculeáramos": "aculear",
    "aculeárei": "aculear",
    "aculeáreis": "aculear",
    "aculeásseis": "aculear",
    "aculeássemos": "aculear",
    "aculeávamo": "aculear",
    "aculeávamos": "aculear",
    "aculeávei": "aculear",
    "aculeáveis": "aculear",
    "aculturada": "aculturado",
    "aculturadas": "aculturado",
    "aculturados": "aculturado",
    "aculturações": "aculturação",
    "acumes": "acume",
    "acumina": "acuminar",
    "acuminada": "acuminar",
    "acuminadas": "acuminar",
    "acuminado": "acuminar",
    "acuminados": "acuminar",
    "acuminai": "acuminar",
    "acuminais": "acuminar",
    "acuminam": "acuminar",
    "acuminamo": "acuminar",
    "acuminamos": "acuminar",
    "acuminando": "acuminar",
    "acuminara": "acuminar",
    "acuminaram": "acuminar",
    "acuminaras": "acuminar",
    "acuminarde": "acuminar",
    "acuminardes": "acuminar",
    "acuminare": "acuminar",
    "acuminarei": "acuminar",
    "acuminareis": "acuminar",
    "acuminarem": "acuminar",
    "acuminaremos": "acuminar",
    "acuminares": "acuminar",
    "acuminaria": "acuminar",
    "acuminariam": "acuminar",
    "acuminarias": "acuminar",
    "acuminarmo": "acuminar",
    "acuminarmos": "acuminar",
    "acuminará": "acuminar",
    "acuminarás": "acuminar",
    "acuminarão": "acuminar",
    "acuminaríamos": "acuminar",
    "acuminaríeis": "acuminar",
    "acuminas": "acuminar",
    "acuminasse": "acuminar",
    "acuminassem": "acuminar",
    "acuminasses": "acuminar",
    "acuminaste": "acuminar",
    "acuminastes": "acuminar",
    "acuminava": "acuminar",
    "acuminavam": "acuminar",
    "acuminavas": "acuminar",
    "acumine": "acuminar",
    "acuminei": "acuminar",
    "acumineis": "acuminar",
    "acuminem": "acuminar",
    "acuminemo": "acuminar",
    "acuminemos": "acuminar",
    "acumines": "acuminar",
    "acumino": "acuminar",
    "acuminosa": "acuminoso",
    "acuminosas": "acuminoso",
    "acuminosos": "acuminoso",
    "acuminou": "acuminar",
    "acuminá": "acuminar",
    "acuminámo": "acuminar",
    "acuminámos": "acuminar",
    "acumináramo": "acuminar",
    "acumináramos": "acuminar",
    "acuminárei": "acuminar",
    "acumináreis": "acuminar",
    "acuminásseis": "acuminar",
    "acuminássemos": "acuminar",
    "acuminávamo": "acuminar",
    "acuminávamos": "acuminar",
    "acuminávei": "acuminar",
    "acumináveis": "acuminar",
    "acumula": "acumular",
    "acumulada": "acumular",
    "acumuladas": "acumular",
    "acumulado": "acumular",
    "acumuladora": "acumulador",
    "acumuladoras": "acumulador",
    "acumuladores": "acumulador",
    "acumulados": "acumular",
    "acumulai": "acumular",
    "acumulais": "acumular",
    "acumulam": "acumular",
    "acumulamentos": "acumulamento",
    "acumulamo": "acumular",
    "acumulamos": "acumular",
    "acumulando": "acumular",
    "acumulara": "acumular",
    "acumularam": "acumular",
    "acumularas": "acumular",
    "acumularde": "acumular",
    "acumulardes": "acumular",
    "acumulare": "acumular",
    "acumularei": "acumular",
    "acumulareis": "acumular",
    "acumularem": "acumular",
    "acumularemos": "acumular",
    "acumulares": "acumular",
    "acumularia": "acumular",
    "acumulariam": "acumular",
    "acumularias": "acumular",
    "acumularmo": "acumular",
    "acumularmos": "acumular",
    "acumulará": "acumular",
    "acumularás": "acumular",
    "acumularão": "acumular",
    "acumularíamos": "acumular",
    "acumularíeis": "acumular",
    "acumulas": "acumular",
    "acumulasse": "acumular",
    "acumulassem": "acumular",
    "acumulasses": "acumular",
    "acumulaste": "acumular",
    "acumulastes": "acumular",
    "acumulativa": "acumulativo",
    "acumulativas": "acumulativo",
    "acumulativos": "acumulativo",
    "acumulava": "acumular",
    "acumulavam": "acumular",
    "acumulavas": "acumular",
    "acumulações": "acumulação",
    "acumule": "acumular",
    "acumulei": "acumular",
    "acumuleis": "acumular",
    "acumulem": "acumular",
    "acumulemo": "acumular",
    "acumulemos": "acumular",
    "acumules": "acumular",
    "acumulo": "acumular",
    "acumulou": "acumular",
    "acumulá": "acumular",
    "acumulámo": "acumular",
    "acumulámos": "acumular",
    "acumuláramo": "acumular",
    "acumuláramos": "acumular",
    "acumulárei": "acumular",
    "acumuláreis": "acumular",
    "acumulásseis": "acumular",
    "acumulássemos": "acumular",
    "acumulávamo": "acumular",
    "acumulávamos": "acumular",
    "acumulávei": "acumular",
    "acumuláveis": "acumulável",
    "acumãs": "acumã",
    "acunha": "acunhar",
    "acunhada": "acunhar",
    "acunhadas": "acunhar",
    "acunhado": "acunhar",
    "acunhados": "acunhar",
    "acunhai": "acunhar",
    "acunhais": "acunhar",
    "acunham": "acunhar",
    "acunhamo": "acunhar",
    "acunhamos": "acunhar",
    "acunhando": "acunhar",
    "acunhara": "acunhar",
    "acunharam": "acunhar",
    "acunharas": "acunhar",
    "acunharde": "acunhar",
    "acunhardes": "acunhar",
    "acunhare": "acunhar",
    "acunharei": "acunhar",
    "acunhareis": "acunhar",
    "acunharem": "acunhar",
    "acunharemos": "acunhar",
    "acunhares": "acunhar",
    "acunharia": "acunhar",
    "acunhariam": "acunhar",
    "acunharias": "acunhar",
    "acunharmo": "acunhar",
    "acunharmos": "acunhar",
    "acunhará": "acunhar",
    "acunharás": "acunhar",
    "acunharão": "acunhar",
    "acunharíamos": "acunhar",
    "acunharíeis": "acunhar",
    "acunhas": "acunhar",
    "acunhasse": "acunhar",
    "acunhassem": "acunhar",
    "acunhasses": "acunhar",
    "acunhaste": "acunhar",
    "acunhastes": "acunhar",
    "acunhava": "acunhar",
    "acunhavam": "acunhar",
    "acunhavas": "acunhar",
    "acunhe": "acunhar",
    "acunheada": "acunhear",
    "acunheadas": "acunhear",
    "acunheado": "acunhear",
    "acunheados": "acunhear",
    "acunheai": "acunhear",
    "acunheais": "acunhear",
    "acunheamo": "acunhear",
    "acunheamos": "acunhear",
    "acunheando": "acunhear",
    "acunheara": "acunhear",
    "acunhearam": "acunhear",
    "acunhearas": "acunhear",
    "acunhearde": "acunhear",
    "acunheardes": "acunhear",
    "acunheare": "acunhear",
    "acunhearei": "acunhear",
    "acunheareis": "acunhear",
    "acunhearem": "acunhear",
    "acunhearemos": "acunhear",
    "acunheares": "acunhear",
    "acunhearia": "acunhear",
    "acunheariam": "acunhear",
    "acunhearias": "acunhear",
    "acunhearmo": "acunhear",
    "acunhearmos": "acunhear",
    "acunheará": "acunhear",
    "acunhearás": "acunhear",
    "acunhearão": "acunhear",
    "acunhearíamos": "acunhear",
    "acunhearíeis": "acunhear",
    "acunheasse": "acunhear",
    "acunheassem": "acunhear",
    "acunheasses": "acunhear",
    "acunheaste": "acunhear",
    "acunheastes": "acunhear",
    "acunheava": "acunhear",
    "acunheavam": "acunhear",
    "acunheavas": "acunhear",
    "acunheei": "acunhear",
    "acunheeis": "acunhear",
    "acunheemo": "acunhear",
    "acunheemos": "acunhear",
    "acunhei": "acunhar",
    "acunheia": "acunhear",
    "acunheiam": "acunhear",
    "acunheias": "acunhear",
    "acunheie": "acunhear",
    "acunheiem": "acunhear",
    "acunheies": "acunhear",
    "acunheio": "acunhear",
    "acunheis": "acunhar",
    "acunhem": "acunhar",
    "acunhemo": "acunhar",
    "acunhemos": "acunhar",
    "acunheou": "acunhear",
    "acunhes": "acunhar",
    "acunheá": "acunhear",
    "acunheámo": "acunhear",
    "acunheámos": "acunhear",
    "acunheáramo": "acunhear",
    "acunheáramos": "acunhear",
    "acunheárei": "acunhear",
    "acunheáreis": "acunhear",
    "acunheásseis": "acunhear",
    "acunheássemos": "acunhear",
    "acunheávamo": "acunhear",
    "acunheávamos": "acunhear",
    "acunheávei": "acunhear",
    "acunheáveis": "acunhear",
    "acunho": "acunhar",
    "acunhou": "acunhar",
    "acunhá": "acunhar",
    "acunhámo": "acunhar",
    "acunhámos": "acunhar",
    "acunháramo": "acunhar",
    "acunháramos": "acunhar",
    "acunhárei": "acunhar",
    "acunháreis": "acunhar",
    "acunhásseis": "acunhar",
    "acunhássemos": "acunhar",
    "acunhávamo": "acunhar",
    "acunhávamos": "acunhar",
    "acunhávei": "acunhar",
    "acunháveis": "acunhar",
    "acuo": "acuar",
    "acuos": "acuo",
    "acuou": "acuar",
    "acupremi": "acupremir",
    "acupremia": "acupremir",
    "acupremiam": "acupremir",
    "acupremias": "acupremir",
    "acupremida": "acupremir",
    "acupremidas": "acupremir",
    "acupremido": "acupremir",
    "acupremidos": "acupremir",
    "acupremimo": "acupremir",
    "acupremimos": "acupremir",
    "acupremindo": "acupremir",
    "acupremira": "acupremir",
    "acupremiram": "acupremir",
    "acupremiras": "acupremir",
    "acupremirde": "acupremir",
    "acupremirdes": "acupremir",
    "acupremire": "acupremir",
    "acupremirei": "acupremir",
    "acupremireis": "acupremir",
    "acupremirem": "acupremir",
    "acupremiremos": "acupremir",
    "acupremires": "acupremir",
    "acupremiria": "acupremir",
    "acupremiriam": "acupremir",
    "acupremirias": "acupremir",
    "acupremirmo": "acupremir",
    "acupremirmos": "acupremir",
    "acupremirá": "acupremir",
    "acupremirás": "acupremir",
    "acupremirão": "acupremir",
    "acupremiríamos": "acupremir",
    "acupremiríeis": "acupremir",
    "acupremis": "acupremir",
    "acupremisse": "acupremir",
    "acupremissem": "acupremir",
    "acupremisses": "acupremir",
    "acupremiste": "acupremir",
    "acupremistes": "acupremir",
    "acupremiu": "acupremir",
    "acupremíamo": "acupremir",
    "acupremíamos": "acupremir",
    "acupremíei": "acupremir",
    "acupremíeis": "acupremir",
    "acupremíramo": "acupremir",
    "acupremíramos": "acupremir",
    "acupremírei": "acupremir",
    "acupremíreis": "acupremir",
    "acupremísseis": "acupremir",
    "acupremíssemos": "acupremir",
    "acupressuras": "acupressura",
    "acupressões": "acupressão",
    "acuprima": "acupremir",
    "acuprimais": "acupremir",
    "acuprimam": "acupremir",
    "acuprimamo": "acupremir",
    "acuprimamos": "acupremir",
    "acuprimas": "acupremir",
    "acuprime": "acupremir",
    "acuprimem": "acupremir",
    "acuprimes": "acupremir",
    "acuprimo": "acupremir",
    "acupunctora": "acupunctor",
    "acupunctoras": "acupunctor",
    "acupunctores": "acupunctor",
    "acupuncturas": "acupunctura",
    "acura": "acurar",
    "acurada": "acurar",
    "acuradas": "acurar",
    "acurado": "acurar",
    "acurados": "acurar",
    "acurai": "acurar",
    "acurais": "acurar",
    "acuram": "acurar",
    "acuramo": "acurar",
    "acuramos": "acurar",
    "acurando": "acurar",
    "acurara": "acurar",
    "acuraram": "acurar",
    "acuraras": "acurar",
    "acurarde": "acurar",
    "acurardes": "acurar",
    "acurare": "acurar",
    "acurarei": "acurar",
    "acurareis": "acurar",
    "acurarem": "acurar",
    "acuraremos": "acurar",
    "acurares": "acurar",
    "acuraria": "acurar",
    "acurariam": "acurar",
    "acurarias": "acurar",
    "acurarmo": "acurar",
    "acurarmos": "acurar",
    "acurará": "acurar",
    "acurarás": "acurar",
    "acurarão": "acurar",
    "acuraríamos": "acurar",
    "acuraríeis": "acurar",
    "acuras": "acurar",
    "acurasse": "acurar",
    "acurassem": "acurar",
    "acurasses": "acurar",
    "acuraste": "acurar",
    "acurastes": "acurar",
    "acurava": "acurar",
    "acuravam": "acurar",
    "acuravas": "acurar",
    "acure": "acurar",
    "acurei": "acurar",
    "acureis": "acurar",
    "acurem": "acurar",
    "acuremo": "acurar",
    "acuremos": "acurar",
    "acures": "acurar",
    "acuro": "acurar",
    "acurou": "acurar",
    "acurrala": "acurralar",
    "acurralada": "acurralar",
    "acurraladas": "acurralar",
    "acurralado": "acurralar",
    "acurralados": "acurralar",
    "acurralai": "acurralar",
    "acurralais": "acurralar",
    "acurralam": "acurralar",
    "acurralamo": "acurralar",
    "acurralamos": "acurralar",
    "acurralando": "acurralar",
    "acurralara": "acurralar",
    "acurralaram": "acurralar",
    "acurralaras": "acurralar",
    "acurralarde": "acurralar",
    "acurralardes": "acurralar",
    "acurralare": "acurralar",
    "acurralarei": "acurralar",
    "acurralareis": "acurralar",
    "acurralarem": "acurralar",
    "acurralaremos": "acurralar",
    "acurralares": "acurralar",
    "acurralaria": "acurralar",
    "acurralariam": "acurralar",
    "acurralarias": "acurralar",
    "acurralarmo": "acurralar",
    "acurralarmos": "acurralar",
    "acurralará": "acurralar",
    "acurralarás": "acurralar",
    "acurralarão": "acurralar",
    "acurralaríamos": "acurralar",
    "acurralaríeis": "acurralar",
    "acurralas": "acurralar",
    "acurralasse": "acurralar",
    "acurralassem": "acurralar",
    "acurralasses": "acurralar",
    "acurralaste": "acurralar",
    "acurralastes": "acurralar",
    "acurralava": "acurralar",
    "acurralavam": "acurralar",
    "acurralavas": "acurralar",
    "acurrale": "acurralar",
    "acurralei": "acurralar",
    "acurraleis": "acurralar",
    "acurralem": "acurralar",
    "acurralemo": "acurralar",
    "acurralemos": "acurralar",
    "acurrales": "acurralar",
    "acurralo": "acurralar",
    "acurralou": "acurralar",
    "acurralá": "acurralar",
    "acurralámo": "acurralar",
    "acurralámos": "acurralar",
    "acurraláramo": "acurralar",
    "acurraláramos": "acurralar",
    "acurralárei": "acurralar",
    "acurraláreis": "acurralar",
    "acurralásseis": "acurralar",
    "acurralássemos": "acurralar",
    "acurralávamo": "acurralar",
    "acurralávamos": "acurralar",
    "acurralávei": "acurralar",
    "acurraláveis": "acurralar",
    "acurva": "acurvar",
    "acurvada": "acurvar",
    "acurvadas": "acurvar",
    "acurvado": "acurvar",
    "acurvados": "acurvar",
    "acurvai": "acurvar",
    "acurvais": "acurvar",
    "acurvam": "acurvar",
    "acurvamentos": "acurvamento",
    "acurvamo": "acurvar",
    "acurvamos": "acurvar",
    "acurvando": "acurvar",
    "acurvara": "acurvar",
    "acurvaram": "acurvar",
    "acurvaras": "acurvar",
    "acurvarde": "acurvar",
    "acurvardes": "acurvar",
    "acurvare": "acurvar",
    "acurvarei": "acurvar",
    "acurvareis": "acurvar",
    "acurvarem": "acurvar",
    "acurvaremos": "acurvar",
    "acurvares": "acurvar",
    "acurvaria": "acurvar",
    "acurvariam": "acurvar",
    "acurvarias": "acurvar",
    "acurvarmo": "acurvar",
    "acurvarmos": "acurvar",
    "acurvará": "acurvar",
    "acurvarás": "acurvar",
    "acurvarão": "acurvar",
    "acurvaríamos": "acurvar",
    "acurvaríeis": "acurvar",
    "acurvas": "acurvar",
    "acurvasse": "acurvar",
    "acurvassem": "acurvar",
    "acurvasses": "acurvar",
    "acurvaste": "acurvar",
    "acurvastes": "acurvar",
    "acurvava": "acurvar",
    "acurvavam": "acurvar",
    "acurvavas": "acurvar",
    "acurve": "acurvar",
    "acurvei": "acurvar",
    "acurveis": "acurvar",
    "acurvem": "acurvar",
    "acurvemo": "acurvar",
    "acurvemos": "acurvar",
    "acurves": "acurvar",
    "acurvilha": "acurvilhar",
    "acurvilhada": "acurvilhar",
    "acurvilhadas": "acurvilhar",
    "acurvilhado": "acurvilhar",
    "acurvilhados": "acurvilhar",
    "acurvilhai": "acurvilhar",
    "acurvilhais": "acurvilhar",
    "acurvilham": "acurvilhar",
    "acurvilhamo": "acurvilhar",
    "acurvilhamos": "acurvilhar",
    "acurvilhando": "acurvilhar",
    "acurvilhara": "acurvilhar",
    "acurvilharam": "acurvilhar",
    "acurvilharas": "acurvilhar",
    "acurvilhardes": "acurvilhar",
    "acurvilharei": "acurvilhar",
    "acurvilhareis": "acurvilhar",
    "acurvilharem": "acurvilhar",
    "acurvilharemos": "acurvilhar",
    "acurvilhares": "acurvilhar",
    "acurvilharia": "acurvilhar",
    "acurvilhariam": "acurvilhar",
    "acurvilharias": "acurvilhar",
    "acurvilharmo": "acurvilhar",
    "acurvilharmos": "acurvilhar",
    "acurvilhará": "acurvilhar",
    "acurvilharás": "acurvilhar",
    "acurvilharão": "acurvilhar",
    "acurvilharíamos": "acurvilhar",
    "acurvilharíeis": "acurvilhar",
    "acurvilhas": "acurvilhar",
    "acurvilhasse": "acurvilhar",
    "acurvilhassem": "acurvilhar",
    "acurvilhasses": "acurvilhar",
    "acurvilhaste": "acurvilhar",
    "acurvilhastes": "acurvilhar",
    "acurvilhava": "acurvilhar",
    "acurvilhavam": "acurvilhar",
    "acurvilhavas": "acurvilhar",
    "acurvilhe": "acurvilhar",
    "acurvilhei": "acurvilhar",
    "acurvilheis": "acurvilhar",
    "acurvilhem": "acurvilhar",
    "acurvilhemo": "acurvilhar",
    "acurvilhemos": "acurvilhar",
    "acurvilhes": "acurvilhar",
    "acurvilho": "acurvilhar",
    "acurvilhou": "acurvilhar",
    "acurvilhámo": "acurvilhar",
    "acurvilhámos": "acurvilhar",
    "acurvilháramo": "acurvilhar",
    "acurvilháramos": "acurvilhar",
    "acurvilháreis": "acurvilhar",
    "acurvilhásseis": "acurvilhar",
    "acurvilhássemos": "acurvilhar",
    "acurvilhávamo": "acurvilhar",
    "acurvilhávamos": "acurvilhar",
    "acurvilháveis": "acurvilhar",
    "acurvo": "acurvar",
    "acurvou": "acurvar",
    "acurvá": "acurvar",
    "acurvámo": "acurvar",
    "acurvámos": "acurvar",
    "acurváramo": "acurvar",
    "acurváramos": "acurvar",
    "acurvárei": "acurvar",
    "acurváreis": "acurvar",
    "acurvásseis": "acurvar",
    "acurvássemos": "acurvar",
    "acurvávamo": "acurvar",
    "acurvávamos": "acurvar",
    "acurvávei": "acurvar",
    "acurváveis": "acurvar",
    "acurá": "acurar",
    "acurácias": "acurácia",
    "acurámo": "acurar",
    "acurámos": "acurar",
    "acuráramo": "acurar",
    "acuráramos": "acurar",
    "acurárei": "acurar",
    "acuráreis": "acurar",
    "acurásseis": "acurar",
    "acurássemos": "acurar",
    "acurávamo": "acurar",
    "acurávamos": "acurar",
    "acurávei": "acurar",
    "acuráveis": "acurar",
    "acurés": "acuré",
    "acusa": "acusar",
    "acusada": "acusar",
    "acusadas": "acusar",
    "acusado": "acusar",
    "acusadora": "acusador",
    "acusadoras": "acusador",
    "acusadores": "acusador",
    "acusados": "acusar",
    "acusai": "acusar",
    "acusais": "acusar",
    "acusam": "acusar",
    "acusamentos": "acusamento",
    "acusamo": "acusar",
    "acusamos": "acusar",
    "acusando": "acusar",
    "acusara": "acusar",
    "acusaram": "acusar",
    "acusaras": "acusar",
    "acusarde": "acusar",
    "acusardes": "acusar",
    "acusare": "acusar",
    "acusarei": "acusar",
    "acusareis": "acusar",
    "acusarem": "acusar",
    "acusaremos": "acusar",
    "acusares": "acusar",
    "acusaria": "acusar",
    "acusariam": "acusar",
    "acusarias": "acusar",
    "acusarmo": "acusar",
    "acusarmos": "acusar",
    "acusará": "acusar",
    "acusarás": "acusar",
    "acusarão": "acusar",
    "acusaríamos": "acusar",
    "acusaríeis": "acusar",
    "acusas": "acusar",
    "acusasse": "acusar",
    "acusassem": "acusar",
    "acusasses": "acusar",
    "acusaste": "acusar",
    "acusastes": "acusar",
    "acusativa": "acusativo",
    "acusativas": "acusativo",
    "acusativos": "acusativo",
    "acusatória": "acusatório",
    "acusatórias": "acusatório",
    "acusatórios": "acusatório",
    "acusava": "acusar",
    "acusavam": "acusar",
    "acusavas": "acusar",
    "acusações": "acusação",
    "acuse": "acusar",
    "acusei": "acusar",
    "acuseis": "acusar",
    "acusem": "acusar",
    "acusemo": "acusar",
    "acusemos": "acusar",
    "acuses": "acusar",
    "acusias": "acusia",
    "acusmas": "acusma",
    "acusmática": "acusmático",
    "acusmáticas": "acusmático",
    "acusmáticos": "acusmático",
    "acuso": "acusar",
    "acusou": "acusar",
    "acusá": "acusar",
    "acusámo": "acusar",
    "acusámos": "acusar",
    "acusáramo": "acusar",
    "acusáramos": "acusar",
    "acusárei": "acusar",
    "acusáreis": "acusar",
    "acusásseis": "acusar",
    "acusássemos": "acusar",
    "acusávamo": "acusar",
    "acusávamos": "acusar",
    "acusávei": "acusar",
    "acusáveis": "acusável",
    "acutangulares": "acutangular",
    "acutas": "acuta",
    "acutelada": "acutelado",
    "acuteladas": "acutelado",
    "acutelados": "acutelado",
    "acutenáculos": "acutenáculo",
    "acuticaudes": "acuticaude",
    "acuticórnea": "acuticórneo",
    "acuticórneas": "acuticórneo",
    "acuticórneos": "acuticórneo",
    "acutifoliada": "acutifoliado",
    "acutifoliadas": "acutifoliado",
    "acutifoliados": "acutifoliado",
    "acutifólia": "acutifólio",
    "acutifólias": "acutifólio",
    "acutifólios": "acutifólio",
    "acutila": "acutilar",
    "acutilada": "acutilar",
    "acutiladas": "acutilar",
    "acutiladiça": "acutiladiço",
    "acutiladiças": "acutiladiço",
    "acutiladiços": "acutiladiço",
    "acutilado": "acutilar",
    "acutiladora": "acutilador",
    "acutiladoras": "acutilador",
    "acutiladores": "acutilador",
    "acutilados": "acutilar",
    "acutilai": "acutilar",
    "acutilais": "acutilar",
    "acutilam": "acutilar",
    "acutilamentos": "acutilamento",
    "acutilamo": "acutilar",
    "acutilamos": "acutilar",
    "acutilando": "acutilar",
    "acutilantes": "acutilante",
    "acutilara": "acutilar",
    "acutilaram": "acutilar",
    "acutilaras": "acutilar",
    "acutilarde": "acutilar",
    "acutilardes": "acutilar",
    "acutilare": "acutilar",
    "acutilarei": "acutilar",
    "acutilareis": "acutilar",
    "acutilarem": "acutilar",
    "acutilaremos": "acutilar",
    "acutilares": "acutilar",
    "acutilaria": "acutilar",
    "acutilariam": "acutilar",
    "acutilarias": "acutilar",
    "acutilarmo": "acutilar",
    "acutilarmos": "acutilar",
    "acutilará": "acutilar",
    "acutilarás": "acutilar",
    "acutilarão": "acutilar",
    "acutilaríamos": "acutilar",
    "acutilaríeis": "acutilar",
    "acutilas": "acutilar",
    "acutilasse": "acutilar",
    "acutilassem": "acutilar",
    "acutilasses": "acutilar",
    "acutilaste": "acutilar",
    "acutilastes": "acutilar",
    "acutilava": "acutilar",
    "acutilavam": "acutilar",
    "acutilavas": "acutilar",
    "acutile": "acutilar",
    "acutilei": "acutilar",
    "acutileis": "acutilar",
    "acutilem": "acutilar",
    "acutilemo": "acutilar",
    "acutilemos": "acutilar",
    "acutiles": "acutilar",
    "acutilingues": "acutilingue",
    "acutilo": "acutilar",
    "acutilou": "acutilar",
    "acutilá": "acutilar",
    "acutilámo": "acutilar",
    "acutilámos": "acutilar",
    "acutiláramo": "acutilar",
    "acutiláramos": "acutilar",
    "acutilárei": "acutilar",
    "acutiláreis": "acutilar",
    "acutilásseis": "acutilar",
    "acutilássemos": "acutilar",
    "acutilávamo": "acutilar",
    "acutilávamos": "acutilar",
    "acutilávei": "acutilar",
    "acutiláveis": "acutilar",
    "acutilíngues": "acutilíngue",
    "acutinbóias": "acutinbóia",
    "acutipuns": "acutipum",
    "acutirrostros": "acutirrostro",
    "acutângula": "acutângulo",
    "acutângulas": "acutângulo",
    "acutângulos": "acutângulo",
    "acuámo": "acuar",
    "acuámos": "acuar",
    "acuáramo": "acuar",
    "acuáramos": "acuar",
    "acuáreis": "acuar",
    "acuásseis": "acuar",
    "acuássemos": "acuar",
    "acuávamo": "acuar",
    "acuávamos": "acuar",
    "acuáveis": "acuar",
    "acácias": "acácia",
    "acálices": "acálice",
    "acárida": "acárido",
    "acáridas": "acárido",
    "acáridos": "acárido",
    "acárpica": "acárpico",
    "acárpicas": "acárpico",
    "acárpicos": "acárpico",
    "acátios": "acátio",
    "acântica": "acântico",
    "acânticas": "acântico",
    "acânticos": "acântico",
    "acântores": "acântor",
    "acãs": "acã",
    "acções": "acção",
    "acédias": "acédia",
    "acéfala": "acéfalo",
    "acéfalas": "acéfalo",
    "acéfalos": "acéfalo",
    "acélios": "acélio",
    "acéquias": "acéquia",
    "acérrima": "acre",
    "acérrimas": "acre",
    "acérrimo": "acre",
    "acérrimos": "acre",
    "acérvulos": "acérvulo",
    "acética": "acético",
    "acéticas": "acético",
    "acéticos": "acético",
    "acíclica": "acíclico",
    "acíclicas": "acíclico",
    "acíclicos": "acíclico",
    "acículas": "acícula",
    "acículos": "acículo",
    "acídias": "acídia",
    "acídica": "acídico",
    "acídicas": "acídico",
    "acídicos": "acídico",
    "acídula": "acídulo",
    "acídulas": "acídulo",
    "acídulos": "acídulo",
    "acínaces": "acínace",
    "acólitos": "acólito",
    "acónitos": "acónito",
    "acórdãos": "acórdão",
    "acôndila": "acôndilo",
    "acôndilas": "acôndilo",
    "acôndilos": "acôndilo",
    "acôntios": "acôntio",
    "acôos": "acôo",
    "acúbitos": "acúbito",
    "acúleos": "acúleo",
    "acúmenes": "acúmen",
    "acúmens": "acúmen",
    "acúmetros": "acúmetro",
    "acúmulos": "acúmulo",
    "acústica": "acústico",
    "acústicas": "acústico",
    "acústicos": "acústico",
    "ada": "adir",
    "adactilias": "adactilia",
    "adagas": "adaga",
    "adages": "adage",
    "adagia": "adagiar",
    "adagiada": "adagiar",
    "adagiadas": "adagiar",
    "adagiado": "adagiar",
    "adagiados": "adagiar",
    "adagiai": "adagiar",
    "adagiais": "adagiar",
    "adagiam": "adagiar",
    "adagiamo": "adagiar",
    "adagiamos": "adagiar",
    "adagiando": "adagiar",
    "adagiara": "adagiar",
    "adagiaram": "adagiar",
    "adagiaras": "adagiar",
    "adagiardes": "adagiar",
    "adagiarei": "adagiar",
    "adagiareis": "adagiar",
    "adagiarem": "adagiar",
    "adagiaremos": "adagiar",
    "adagiares": "adagiar",
    "adagiaria": "adagiar",
    "adagiariam": "adagiar",
    "adagiarias": "adagiar",
    "adagiarmo": "adagiar",
    "adagiarmos": "adagiar",
    "adagiará": "adagiar",
    "adagiarás": "adagiar",
    "adagiarão": "adagiar",
    "adagiaríamos": "adagiar",
    "adagiaríeis": "adagiar",
    "adagias": "adagiar",
    "adagiasse": "adagiar",
    "adagiassem": "adagiar",
    "adagiasses": "adagiar",
    "adagiaste": "adagiar",
    "adagiastes": "adagiar",
    "adagiava": "adagiar",
    "adagiavam": "adagiar",
    "adagiavas": "adagiar",
    "adagie": "adagiar",
    "adagiei": "adagiar",
    "adagieis": "adagiar",
    "adagiem": "adagiar",
    "adagiemo": "adagiar",
    "adagiemos": "adagiar",
    "adagies": "adagiar",
    "adagio": "adagiar",
    "adagiou": "adagiar",
    "adagiámo": "adagiar",
    "adagiámos": "adagiar",
    "adagiáramo": "adagiar",
    "adagiáramos": "adagiar",
    "adagiáreis": "adagiar",
    "adagiários": "adagiário",
    "adagiásseis": "adagiar",
    "adagiássemos": "adagiar",
    "adagiávamo": "adagiar",
    "adagiávamos": "adagiar",
    "adagiáveis": "adagiar",
    "adagueiros": "adagueiro",
    "adais": "adir",
    "adaiões": "adaião",
    "adajibes": "adajibe",
    "adam": "adir",
    "adama": "adamar",
    "adamada": "adamar",
    "adamadas": "adamar",
    "adamado": "adamar",
    "adamados": "adamar",
    "adamai": "adamar",
    "adamais": "adamar",
    "adamam": "adamar",
    "adamamo": "adamar",
    "adamamos": "adamar",
    "adamando": "adamar",
    "adamantina": "adamantino",
    "adamantinas": "adamantino",
    "adamantinos": "adamantino",
    "adamara": "adamar",
    "adamaram": "adamar",
    "adamaras": "adamar",
    "adamarde": "adamar",
    "adamardes": "adamar",
    "adamare": "adamar",
    "adamarei": "adamar",
    "adamareis": "adamar",
    "adamarem": "adamar",
    "adamaremos": "adamar",
    "adamares": "adamar",
    "adamaria": "adamar",
    "adamariam": "adamar",
    "adamarias": "adamar",
    "adamarmo": "adamar",
    "adamarmos": "adamar",
    "adamará": "adamar",
    "adamarás": "adamar",
    "adamarão": "adamar",
    "adamaríamos": "adamar",
    "adamaríeis": "adamar",
    "adamas": "adamar",
    "adamasca": "adamascar",
    "adamascada": "adamascar",
    "adamascadas": "adamascar",
    "adamascado": "adamascar",
    "adamascados": "adamascar",
    "adamascai": "adamascar",
    "adamascais": "adamascar",
    "adamascam": "adamascar",
    "adamascamo": "adamascar",
    "adamascamos": "adamascar",
    "adamascando": "adamascar",
    "adamascara": "adamascar",
    "adamascaram": "adamascar",
    "adamascaras": "adamascar",
    "adamascarde": "adamascar",
    "adamascardes": "adamascar",
    "adamascare": "adamascar",
    "adamascarei": "adamascar",
    "adamascareis": "adamascar",
    "adamascarem": "adamascar",
    "adamascaremos": "adamascar",
    "adamascares": "adamascar",
    "adamascaria": "adamascar",
    "adamascariam": "adamascar",
    "adamascarias": "adamascar",
    "adamascarmo": "adamascar",
    "adamascarmos": "adamascar",
    "adamascará": "adamascar",
    "adamascarás": "adamascar",
    "adamascarão": "adamascar",
    "adamascaríamos": "adamascar",
    "adamascaríeis": "adamascar",
    "adamascas": "adamascar",
    "adamascasse": "adamascar",
    "adamascassem": "adamascar",
    "adamascasses": "adamascar",
    "adamascaste": "adamascar",
    "adamascastes": "adamascar",
    "adamascava": "adamascar",
    "adamascavam": "adamascar",
    "adamascavas": "adamascar",
    "adamasco": "adamascar",
    "adamascou": "adamascar",
    "adamascá": "adamascar",
    "adamascámo": "adamascar",
    "adamascámos": "adamascar",
    "adamascáramo": "adamascar",
    "adamascáramos": "adamascar",
    "adamascárei": "adamascar",
    "adamascáreis": "adamascar",
    "adamascásseis": "adamascar",
    "adamascássemos": "adamascar",
    "adamascávamo": "adamascar",
    "adamascávamos": "adamascar",
    "adamascávei": "adamascar",
    "adamascáveis": "adamascar",
    "adamasque": "adamascar",
    "adamasquei": "adamascar",
    "adamasqueis": "adamascar",
    "adamasquem": "adamascar",
    "adamasquemo": "adamascar",
    "adamasquemos": "adamascar",
    "adamasques": "adamascar",
    "adamasse": "adamar",
    "adamassem": "adamar",
    "adamasses": "adamar",
    "adamaste": "adamar",
    "adamastes": "adamar",
    "adamastores": "adamastor",
    "adamastoriana": "adamastoriano",
    "adamastorianas": "adamastoriano",
    "adamastorianos": "adamastoriano",
    "adamava": "adamar",
    "adamavam": "adamar",
    "adamavas": "adamar",
    "adame": "adamar",
    "adamei": "adamar",
    "adameis": "adamar",
    "adamelitos": "adamelito",
    "adamem": "adamar",
    "adamemo": "adamar",
    "adamemos": "adamar",
    "adames": "adamar",
    "adamitas": "adamita",
    "adamo": "adir",
    "adamos": "adir",
    "adamou": "adamar",
    "adamá": "adamar",
    "adamámo": "adamar",
    "adamámos": "adamar",
    "adamáramo": "adamar",
    "adamáramos": "adamar",
    "adamárei": "adamar",
    "adamáreis": "adamar",
    "adamásseis": "adamar",
    "adamássemos": "adamar",
    "adamávamo": "adamar",
    "adamávamos": "adamar",
    "adamávei": "adamar",
    "adamáveis": "adamar",
    "adamítica": "adamítico",
    "adamíticas": "adamítico",
    "adamíticos": "adamítico",
    "adansónias": "adansónia",
    "adapta": "adaptar",
    "adaptabilidades": "adaptabilidade",
    "adaptada": "adaptar",
    "adaptadas": "adaptar",
    "adaptado": "adaptar",
    "adaptadora": "adaptador",
    "adaptadoras": "adaptador",
    "adaptadores": "adaptador",
    "adaptados": "adaptar",
    "adaptadíssima": "adaptado",
    "adaptadíssimas": "adaptado",
    "adaptadíssimo": "adaptado",
    "adaptadíssimos": "adaptado",
    "adaptai": "adaptar",
    "adaptais": "adaptar",
    "adaptam": "adaptar",
    "adaptamo": "adaptar",
    "adaptamos": "adaptar",
    "adaptando": "adaptar",
    "adaptara": "adaptar",
    "adaptaram": "adaptar",
    "adaptaras": "adaptar",
    "adaptarde": "adaptar",
    "adaptardes": "adaptar",
    "adaptare": "adaptar",
    "adaptarei": "adaptar",
    "adaptareis": "adaptar",
    "adaptarem": "adaptar",
    "adaptaremos": "adaptar",
    "adaptares": "adaptar",
    "adaptaria": "adaptar",
    "adaptariam": "adaptar",
    "adaptarias": "adaptar",
    "adaptarmo": "adaptar",
    "adaptarmos": "adaptar",
    "adaptará": "adaptar",
    "adaptarás": "adaptar",
    "adaptarão": "adaptar",
    "adaptaríamos": "adaptar",
    "adaptaríeis": "adaptar",
    "adaptas": "adaptar",
    "adaptasse": "adaptar",
    "adaptassem": "adaptar",
    "adaptasses": "adaptar",
    "adaptaste": "adaptar",
    "adaptastes": "adaptar",
    "adaptativa": "adaptativo",
    "adaptativas": "adaptativo",
    "adaptativos": "adaptativo",
    "adaptava": "adaptar",
    "adaptavam": "adaptar",
    "adaptavas": "adaptar",
    "adaptações": "adaptação",
    "adapte": "adaptar",
    "adaptei": "adaptar",
    "adapteis": "adaptar",
    "adaptem": "adaptar",
    "adaptemo": "adaptar",
    "adaptemos": "adaptar",
    "adaptes": "adaptar",
    "adapto": "adaptar",
    "adaptou": "adaptar",
    "adaptá": "adaptar",
    "adaptámo": "adaptar",
    "adaptámos": "adaptar",
    "adaptáramo": "adaptar",
    "adaptáramos": "adaptar",
    "adaptárei": "adaptar",
    "adaptáreis": "adaptar",
    "adaptásseis": "adaptar",
    "adaptássemos": "adaptar",
    "adaptávamo": "adaptar",
    "adaptávamos": "adaptar",
    "adaptávei": "adaptar",
    "adaptáveis": "adaptável",
    "adaptómetros": "adaptómetro",
    "adargas": "adarga",
    "adargueiros": "adargueiro",
    "adarmes": "adarme",
    "adarva": "adarvar",
    "adarvada": "adarvar",
    "adarvadas": "adarvar",
    "adarvado": "adarvar",
    "adarvados": "adarvar",
    "adarvai": "adarvar",
    "adarvais": "adarvar",
    "adarvam": "adarvar",
    "adarvamo": "adarvar",
    "adarvamos": "adarvar",
    "adarvando": "adarvar",
    "adarvara": "adarvar",
    "adarvaram": "adarvar",
    "adarvaras": "adarvar",
    "adarvarde": "adarvar",
    "adarvardes": "adarvar",
    "adarvare": "adarvar",
    "adarvarei": "adarvar",
    "adarvareis": "adarvar",
    "adarvarem": "adarvar",
    "adarvaremos": "adarvar",
    "adarvares": "adarvar",
    "adarvaria": "adarvar",
    "adarvariam": "adarvar",
    "adarvarias": "adarvar",
    "adarvarmo": "adarvar",
    "adarvarmos": "adarvar",
    "adarvará": "adarvar",
    "adarvarás": "adarvar",
    "adarvarão": "adarvar",
    "adarvaríamos": "adarvar",
    "adarvaríeis": "adarvar",
    "adarvas": "adarvar",
    "adarvasse": "adarvar",
    "adarvassem": "adarvar",
    "adarvasses": "adarvar",
    "adarvaste": "adarvar",
    "adarvastes": "adarvar",
    "adarvava": "adarvar",
    "adarvavam": "adarvar",
    "adarvavas": "adarvar",
    "adarve": "adarvar",
    "adarvei": "adarvar",
    "adarveis": "adarvar",
    "adarvem": "adarvar",
    "adarvemo": "adarvar",
    "adarvemos": "adarvar",
    "adarves": "adarve",
    "adarvo": "adarvar",
    "adarvou": "adarvar",
    "adarvá": "adarvar",
    "adarvámo": "adarvar",
    "adarvámos": "adarvar",
    "adarváramo": "adarvar",
    "adarváramos": "adarvar",
    "adarvárei": "adarvar",
    "adarváreis": "adarvar",
    "adarvásseis": "adarvar",
    "adarvássemos": "adarvar",
    "adarvávamo": "adarvar",
    "adarvávamos": "adarvar",
    "adarvávei": "adarvar",
    "adarváveis": "adarvar",
    "adas": "adir",
    "adastra": "adastrar",
    "adastrada": "adastrar",
    "adastradas": "adastrar",
    "adastrado": "adastrar",
    "adastrados": "adastrar",
    "adastragens": "adastragem",
    "adastrai": "adastrar",
    "adastrais": "adastrar",
    "adastram": "adastrar",
    "adastramo": "adastrar",
    "adastramos": "adastrar",
    "adastrando": "adastrar",
    "adastrara": "adastrar",
    "adastraram": "adastrar",
    "adastraras": "adastrar",
    "adastrarde": "adastrar",
    "adastrardes": "adastrar",
    "adastrare": "adastrar",
    "adastrarei": "adastrar",
    "adastrareis": "adastrar",
    "adastrarem": "adastrar",
    "adastraremos": "adastrar",
    "adastrares": "adastrar",
    "adastraria": "adastrar",
    "adastrariam": "adastrar",
    "adastrarias": "adastrar",
    "adastrarmo": "adastrar",
    "adastrarmos": "adastrar",
    "adastrará": "adastrar",
    "adastrarás": "adastrar",
    "adastrarão": "adastrar",
    "adastraríamos": "adastrar",
    "adastraríeis": "adastrar",
    "adastras": "adastrar",
    "adastrasse": "adastrar",
    "adastrassem": "adastrar",
    "adastrasses": "adastrar",
    "adastraste": "adastrar",
    "adastrastes": "adastrar",
    "adastrava": "adastrar",
    "adastravam": "adastrar",
    "adastravas": "adastrar",
    "adastre": "adastrar",
    "adastrei": "adastrar",
    "adastreis": "adastrar",
    "adastrem": "adastrar",
    "adastremo": "adastrar",
    "adastremos": "adastrar",
    "adastres": "adastrar",
    "adastro": "adastrar",
    "adastrou": "adastrar",
    "adastrá": "adastrar",
    "adastrámo": "adastrar",
    "adastrámos": "adastrar",
    "adastráramo": "adastrar",
    "adastráramos": "adastrar",
    "adastrárei": "adastrar",
    "adastráreis": "adastrar",
    "adastrásseis": "adastrar",
    "adastrássemos": "adastrar",
    "adastrávamo": "adastrar",
    "adastrávamos": "adastrar",
    "adastrávei": "adastrar",
    "adastráveis": "adastrar",
    "ade": "adir",
    "adefagias": "adefagia",
    "adega": "adegar",
    "adegada": "adegar",
    "adegadas": "adegar",
    "adegado": "adegar",
    "adegados": "adegar",
    "adegai": "adegar",
    "adegais": "adegar",
    "adegam": "adegar",
    "adegamo": "adegar",
    "adegamos": "adegar",
    "adegando": "adegar",
    "adegara": "adegar",
    "adegaram": "adegar",
    "adegaras": "adegar",
    "adegardes": "adegar",
    "adegarei": "adegar",
    "adegareis": "adegar",
    "adegarem": "adegar",
    "adegaremos": "adegar",
    "adegares": "adegar",
    "adegaria": "adegar",
    "adegariam": "adegar",
    "adegarias": "adegar",
    "adegarmo": "adegar",
    "adegarmos": "adegar",
    "adegará": "adegar",
    "adegarás": "adegar",
    "adegarão": "adegar",
    "adegaríamos": "adegar",
    "adegaríeis": "adegar",
    "adegas": "adegar",
    "adegasse": "adegar",
    "adegassem": "adegar",
    "adegasses": "adegar",
    "adegaste": "adegar",
    "adegastes": "adegar",
    "adegava": "adegar",
    "adegavam": "adegar",
    "adegavas": "adegar",
    "adego": "adegar",
    "adegou": "adegar",
    "adegue": "adegar",
    "adeguei": "adegar",
    "adegueiros": "adegueiro",
    "adegueis": "adegar",
    "adeguem": "adegar",
    "adeguemo": "adegar",
    "adeguemos": "adegar",
    "adegues": "adegar",
    "adegámo": "adegar",
    "adegámos": "adegar",
    "adegáramo": "adegar",
    "adegáramos": "adegar",
    "adegáreis": "adegar",
    "adegásseis": "adegar",
    "adegássemos": "adegar",
    "adegávamo": "adegar",
    "adegávamos": "adegar",
    "adegáveis": "adegar",
    "adeja": "adejar",
    "adejada": "adejar",
    "adejadas": "adejar",
    "adejado": "adejar",
    "adejados": "adejar",
    "adejai": "adejar",
    "adejais": "adejar",
    "adejam": "adejar",
    "adejamo": "adejar",
    "adejamos": "adejar",
    "adejando": "adejar",
    "adejara": "adejar",
    "adejaram": "adejar",
    "adejaras": "adejar",
    "adejardes": "adejar",
    "adejarei": "adejar",
    "adejareis": "adejar",
    "adejarem": "adejar",
    "adejaremos": "adejar",
    "adejares": "adejar",
    "adejaria": "adejar",
    "adejariam": "adejar",
    "adejarias": "adejar",
    "adejarmo": "adejar",
    "adejarmos": "adejar",
    "adejará": "adejar",
    "adejarás": "adejar",
    "adejarão": "adejar",
    "adejaríamos": "adejar",
    "adejaríeis": "adejar",
    "adejas": "adejar",
    "adejasse": "adejar",
    "adejassem": "adejar",
    "adejasses": "adejar",
    "adejaste": "adejar",
    "adejastes": "adejar",
    "adejava": "adejar",
    "adejavam": "adejar",
    "adejavas": "adejar",
    "adeje": "adejar",
    "adejei": "adejar",
    "adejeis": "adejar",
    "adejem": "adejar",
    "adejemo": "adejar",
    "adejemos": "adejar",
    "adejes": "adejar",
    "adejo": "adejar",
    "adejos": "adejo",
    "adejou": "adejar",
    "adejámo": "adejar",
    "adejámos": "adejar",
    "adejáramo": "adejar",
    "adejáramos": "adejar",
    "adejáreis": "adejar",
    "adejásseis": "adejar",
    "adejássemos": "adejar",
    "adejávamo": "adejar",
    "adejávamos": "adejar",
    "adejáveis": "adejar",
    "adeleiros": "adeleiro",
    "adelfais": "adelfal",
    "adelfas": "adelfa",
    "adelfeiras": "adelfeira",
    "adelfias": "adelfia",
    "adelfogamias": "adelfogamia",
    "adelfos": "adelfo",
    "adelgace": "adelgaçar",
    "adelgacei": "adelgaçar",
    "adelgaceis": "adelgaçar",
    "adelgacem": "adelgaçar",
    "adelgacemo": "adelgaçar",
    "adelgacemos": "adelgaçar",
    "adelgaces": "adelgaçar",
    "adelgaça": "adelgaçar",
    "adelgaçada": "adelgaçar",
    "adelgaçadas": "adelgaçar",
    "adelgaçadeira": "adelgaçador",
    "adelgaçadeiras": "adelgaçador",
    "adelgaçado": "adelgaçar",
    "adelgaçadora": "adelgaçador",
    "adelgaçadoras": "adelgaçador",
    "adelgaçadores": "adelgaçador",
    "adelgaçados": "adelgaçar",
    "adelgaçai": "adelgaçar",
    "adelgaçais": "adelgaçar",
    "adelgaçam": "adelgaçar",
    "adelgaçamentos": "adelgaçamento",
    "adelgaçamo": "adelgaçar",
    "adelgaçamos": "adelgaçar",
    "adelgaçando": "adelgaçar",
    "adelgaçantes": "adelgaçante",
    "adelgaçara": "adelgaçar",
    "adelgaçaram": "adelgaçar",
    "adelgaçaras": "adelgaçar",
    "adelgaçarde": "adelgaçar",
    "adelgaçardes": "adelgaçar",
    "adelgaçare": "adelgaçar",
    "adelgaçarei": "adelgaçar",
    "adelgaçareis": "adelgaçar",
    "adelgaçarem": "adelgaçar",
    "adelgaçaremos": "adelgaçar",
    "adelgaçares": "adelgaçar",
    "adelgaçaria": "adelgaçar",
    "adelgaçariam": "adelgaçar",
    "adelgaçarias": "adelgaçar",
    "adelgaçarmo": "adelgaçar",
    "adelgaçarmos": "adelgaçar",
    "adelgaçará": "adelgaçar",
    "adelgaçarás": "adelgaçar",
    "adelgaçarão": "adelgaçar",
    "adelgaçaríamos": "adelgaçar",
    "adelgaçaríeis": "adelgaçar",
    "adelgaças": "adelgaçar",
    "adelgaçasse": "adelgaçar",
    "adelgaçassem": "adelgaçar",
    "adelgaçasses": "adelgaçar",
    "adelgaçaste": "adelgaçar",
    "adelgaçastes": "adelgaçar",
    "adelgaçava": "adelgaçar",
    "adelgaçavam": "adelgaçar",
    "adelgaçavas": "adelgaçar",
    "adelgaço": "adelgaçar",
    "adelgaçou": "adelgaçar",
    "adelgaçá": "adelgaçar",
    "adelgaçámo": "adelgaçar",
    "adelgaçámos": "adelgaçar",
    "adelgaçáramo": "adelgaçar",
    "adelgaçáramos": "adelgaçar",
    "adelgaçárei": "adelgaçar",
    "adelgaçáreis": "adelgaçar",
    "adelgaçásseis": "adelgaçar",
    "adelgaçássemos": "adelgaçar",
    "adelgaçávamo": "adelgaçar",
    "adelgaçávamos": "adelgaçar",
    "adelgaçávei": "adelgaçar",
    "adelgaçáveis": "adelgaçar",
    "adelhas": "adelha",
    "adelhões": "adelhão",
    "adelos": "adelo",
    "adem": "adir",
    "ademãos": "ademão",
    "ademãs": "ademã",
    "adendas": "adenda",
    "adenga": "adengar",
    "adengada": "adengar",
    "adengadas": "adengar",
    "adengado": "adengar",
    "adengados": "adengar",
    "adengai": "adengar",
    "adengais": "adengar",
    "adengam": "adengar",
    "adengamo": "adengar",
    "adengamos": "adengar",
    "adengando": "adengar",
    "adengara": "adengar",
    "adengaram": "adengar",
    "adengaras": "adengar",
    "adengarde": "adengar",
    "adengardes": "adengar",
    "adengare": "adengar",
    "adengarei": "adengar",
    "adengareis": "adengar",
    "adengarem": "adengar",
    "adengaremos": "adengar",
    "adengares": "adengar",
    "adengaria": "adengar",
    "adengariam": "adengar",
    "adengarias": "adengar",
    "adengarmo": "adengar",
    "adengarmos": "adengar",
    "adengará": "adengar",
    "adengarás": "adengar",
    "adengarão": "adengar",
    "adengaríamos": "adengar",
    "adengaríeis": "adengar",
    "adengas": "adengar",
    "adengasse": "adengar",
    "adengassem": "adengar",
    "adengasses": "adengar",
    "adengaste": "adengar",
    "adengastes": "adengar",
    "adengava": "adengar",
    "adengavam": "adengar",
    "adengavas": "adengar",
    "adengo": "adengar",
    "adengou": "adengar",
    "adengue": "adengar",
    "adenguei": "adengar",
    "adengueis": "adengar",
    "adenguem": "adengar",
    "adenguemo": "adengar",
    "adenguemos": "adengar",
    "adengues": "adengar",
    "adengá": "adengar",
    "adengámo": "adengar",
    "adengámos": "adengar",
    "adengáramo": "adengar",
    "adengáramos": "adengar",
    "adengárei": "adengar",
    "adengáreis": "adengar",
    "adengásseis": "adengar",
    "adengássemos": "adengar",
    "adengávamo": "adengar",
    "adengávamos": "adengar",
    "adengávei": "adengar",
    "adengáveis": "adengar",
    "adenias": "adenia",
    "adeninas": "adenina",
    "adenites": "adenite",
    "adenoidectomias": "adenoidectomia",
    "adenologias": "adenologia",
    "adenomas": "adenoma",
    "adenopatas": "adenopata",
    "adenopatias": "adenopatia",
    "adenotomias": "adenotomia",
    "adens": "adem",
    "adensa": "adensar",
    "adensada": "adensar",
    "adensadas": "adensar",
    "adensado": "adensar",
    "adensados": "adensar",
    "adensai": "adensar",
    "adensais": "adensar",
    "adensam": "adensar",
    "adensamentos": "adensamento",
    "adensamo": "adensar",
    "adensamos": "adensar",
    "adensando": "adensar",
    "adensara": "adensar",
    "adensaram": "adensar",
    "adensaras": "adensar",
    "adensarde": "adensar",
    "adensardes": "adensar",
    "adensare": "adensar",
    "adensarei": "adensar",
    "adensareis": "adensar",
    "adensarem": "adensar",
    "adensaremos": "adensar",
    "adensares": "adensar",
    "adensaria": "adensar",
    "adensariam": "adensar",
    "adensarias": "adensar",
    "adensarmo": "adensar",
    "adensarmos": "adensar",
    "adensará": "adensar",
    "adensarás": "adensar",
    "adensarão": "adensar",
    "adensaríamos": "adensar",
    "adensaríeis": "adensar",
    "adensas": "adensar",
    "adensasse": "adensar",
    "adensassem": "adensar",
    "adensasses": "adensar",
    "adensaste": "adensar",
    "adensastes": "adensar",
    "adensava": "adensar",
    "adensavam": "adensar",
    "adensavas": "adensar",
    "adense": "adensar",
    "adensei": "adensar",
    "adenseis": "adensar",
    "adensem": "adensar",
    "adensemo": "adensar",
    "adensemos": "adensar",
    "adenses": "adensar",
    "adenso": "adensar",
    "adensou": "adensar",
    "adensá": "adensar",
    "adensámo": "adensar",
    "adensámos": "adensar",
    "adensáramo": "adensar",
    "adensáramos": "adensar",
    "adensárei": "adensar",
    "adensáreis": "adensar",
    "adensásseis": "adensar",
    "adensássemos": "adensar",
    "adensávamo": "adensar",
    "adensávamos": "adensar",
    "adensávei": "adensar",
    "adensáveis": "adensar",
    "adenta": "adentar",
    "adentada": "adentar",
    "adentadas": "adentar",
    "adentado": "adentar",
    "adentados": "adentar",
    "adentai": "adentar",
    "adentais": "adentar",
    "adentam": "adentar",
    "adentamo": "adentar",
    "adentamos": "adentar",
    "adentando": "adentar",
    "adentara": "adentar",
    "adentaram": "adentar",
    "adentaras": "adentar",
    "adentarde": "adentar",
    "adentardes": "adentar",
    "adentare": "adentar",
    "adentarei": "adentar",
    "adentareis": "adentar",
    "adentarem": "adentar",
    "adentaremos": "adentar",
    "adentares": "adentar",
    "adentaria": "adentar",
    "adentariam": "adentar",
    "adentarias": "adentar",
    "adentarmo": "adentar",
    "adentarmos": "adentar",
    "adentará": "adentar",
    "adentarás": "adentar",
    "adentarão": "adentar",
    "adentaríamos": "adentar",
    "adentaríeis": "adentar",
    "adentas": "adentar",
    "adentasse": "adentar",
    "adentassem": "adentar",
    "adentasses": "adentar",
    "adentaste": "adentar",
    "adentastes": "adentar",
    "adentava": "adentar",
    "adentavam": "adentar",
    "adentavas": "adentar",
    "adente": "adentar",
    "adentei": "adentar",
    "adenteis": "adentar",
    "adentem": "adentar",
    "adentemo": "adentar",
    "adentemos": "adentar",
    "adentes": "adentar",
    "adento": "adentar",
    "adentou": "adentar",
    "adentra": "adentrar",
    "adentrada": "adentrar",
    "adentradas": "adentrar",
    "adentrado": "adentrar",
    "adentrados": "adentrar",
    "adentrai": "adentrar",
    "adentrais": "adentrar",
    "adentram": "adentrar",
    "adentramo": "adentrar",
    "adentramos": "adentrar",
    "adentrando": "adentrar",
    "adentrara": "adentrar",
    "adentraram": "adentrar",
    "adentraras": "adentrar",
    "adentrarde": "adentrar",
    "adentrardes": "adentrar",
    "adentrare": "adentrar",
    "adentrarei": "adentrar",
    "adentrareis": "adentrar",
    "adentrarem": "adentrar",
    "adentraremos": "adentrar",
    "adentrares": "adentrar",
    "adentraria": "adentrar",
    "adentrariam": "adentrar",
    "adentrarias": "adentrar",
    "adentrarmo": "adentrar",
    "adentrarmos": "adentrar",
    "adentrará": "adentrar",
    "adentrarás": "adentrar",
    "adentrarão": "adentrar",
    "adentraríamos": "adentrar",
    "adentraríeis": "adentrar",
    "adentras": "adentrar",
    "adentrasse": "adentrar",
    "adentrassem": "adentrar",
    "adentrasses": "adentrar",
    "adentraste": "adentrar",
    "adentrastes": "adentrar",
    "adentrava": "adentrar",
    "adentravam": "adentrar",
    "adentravas": "adentrar",
    "adentre": "adentrar",
    "adentrei": "adentrar",
    "adentreis": "adentrar",
    "adentrem": "adentrar",
    "adentremo": "adentrar",
    "adentremos": "adentrar",
    "adentres": "adentrar",
    "adentro": "adentrar",
    "adentrou": "adentrar",
    "adentrá": "adentrar",
    "adentrámo": "adentrar",
    "adentrámos": "adentrar",
    "adentráramo": "adentrar",
    "adentráramos": "adentrar",
    "adentrárei": "adentrar",
    "adentráreis": "adentrar",
    "adentrásseis": "adentrar",
    "adentrássemos": "adentrar",
    "adentrávamo": "adentrar",
    "adentrávamos": "adentrar",
    "adentrávei": "adentrar",
    "adentráveis": "adentrar",
    "adentá": "adentar",
    "adentámo": "adentar",
    "adentámos": "adentar",
    "adentáramo": "adentar",
    "adentáramos": "adentar",
    "adentárei": "adentar",
    "adentáreis": "adentar",
    "adentásseis": "adentar",
    "adentássemos": "adentar",
    "adentávamo": "adentar",
    "adentávamos": "adentar",
    "adentávei": "adentar",
    "adentáveis": "adentar",
    "adenções": "adenção",
    "adenóides": "adenóide",
    "adepta": "adepto",
    "adeptas": "adepto",
    "adeptos": "adepto",
    "adequa": "adequar",
    "adequabilidades": "adequabilidade",
    "adequada": "adequar",
    "adequadas": "adequar",
    "adequado": "adequar",
    "adequados": "adequar",
    "adequadíssima": "adequado",
    "adequadíssimas": "adequado",
    "adequadíssimo": "adequado",
    "adequadíssimos": "adequado",
    "adequai": "adequar",
    "adequais": "adequar",
    "adequam": "adequar",
    "adequamo": "adequar",
    "adequamos": "adequar",
    "adequando": "adequar",
    "adequara": "adequar",
    "adequaram": "adequar",
    "adequaras": "adequar",
    "adequarde": "adequar",
    "adequardes": "adequar",
    "adequare": "adequar",
    "adequarei": "adequar",
    "adequareis": "adequar",
    "adequarem": "adequar",
    "adequaremos": "adequar",
    "adequares": "adequar",
    "adequaria": "adequar",
    "adequariam": "adequar",
    "adequarias": "adequar",
    "adequarmo": "adequar",
    "adequarmos": "adequar",
    "adequará": "adequar",
    "adequarás": "adequar",
    "adequarão": "adequar",
    "adequaríamos": "adequar",
    "adequaríeis": "adequar",
    "adequas": "adequar",
    "adequasse": "adequar",
    "adequassem": "adequar",
    "adequasses": "adequar",
    "adequaste": "adequar",
    "adequastes": "adequar",
    "adequava": "adequar",
    "adequavam": "adequar",
    "adequavas": "adequar",
    "adequações": "adequação",
    "adequei": "adequar",
    "adequeis": "adequar",
    "adequemo": "adequar",
    "adequemos": "adequar",
    "adeques": "adequar",
    "adequo": "adequar",
    "adequou": "adequar",
    "adequá": "adequar",
    "adequámo": "adequar",
    "adequámos": "adequar",
    "adequáramo": "adequar",
    "adequáramos": "adequar",
    "adequárei": "adequar",
    "adequáreis": "adequar",
    "adequásseis": "adequar",
    "adequássemos": "adequar",
    "adequávamo": "adequar",
    "adequávamos": "adequar",
    "adequávei": "adequar",
    "adequáveis": "adequar",
    "adeqúe": "adequar",
    "adeqúem": "adequar",
    "adeqúes": "adequar",
    "adere": "aderir",
    "aderece": "adereçar",
    "aderecei": "adereçar",
    "adereceis": "adereçar",
    "aderecem": "adereçar",
    "aderecemo": "adereçar",
    "aderecemos": "adereçar",
    "adereces": "aderece",
    "aderecistas": "aderecista",
    "aderem": "aderir",
    "aderentes": "aderente",
    "aderes": "aderir",
    "adereça": "adereçar",
    "adereçada": "adereçar",
    "adereçadas": "adereçar",
    "adereçado": "adereçar",
    "adereçados": "adereçar",
    "adereçai": "adereçar",
    "adereçais": "adereçar",
    "adereçam": "adereçar",
    "adereçamentos": "adereçamento",
    "adereçamo": "adereçar",
    "adereçamos": "adereçar",
    "adereçando": "adereçar",
    "adereçara": "adereçar",
    "adereçaram": "adereçar",
    "adereçaras": "adereçar",
    "adereçarde": "adereçar",
    "adereçardes": "adereçar",
    "adereçare": "adereçar",
    "adereçarei": "adereçar",
    "adereçareis": "adereçar",
    "adereçarem": "adereçar",
    "adereçaremos": "adereçar",
    "adereçares": "adereçar",
    "adereçaria": "adereçar",
    "adereçariam": "adereçar",
    "adereçarias": "adereçar",
    "adereçarmo": "adereçar",
    "adereçarmos": "adereçar",
    "adereçará": "adereçar",
    "adereçarás": "adereçar",
    "adereçarão": "adereçar",
    "adereçaríamos": "adereçar",
    "adereçaríeis": "adereçar",
    "adereças": "adereçar",
    "adereçasse": "adereçar",
    "adereçassem": "adereçar",
    "adereçasses": "adereçar",
    "adereçaste": "adereçar",
    "adereçastes": "adereçar",
    "adereçava": "adereçar",
    "adereçavam": "adereçar",
    "adereçavas": "adereçar",
    "adereço": "adereçar",
    "adereços": "adereço",
    "adereçou": "adereçar",
    "adereçá": "adereçar",
    "adereçámo": "adereçar",
    "adereçámos": "adereçar",
    "adereçáramo": "adereçar",
    "adereçáramos": "adereçar",
    "adereçárei": "adereçar",
    "adereçáreis": "adereçar",
    "adereçásseis": "adereçar",
    "adereçássemos": "adereçar",
    "adereçávamo": "adereçar",
    "adereçávamos": "adereçar",
    "adereçávei": "adereçar",
    "adereçáveis": "adereçar",
    "aderga": "adergar",
    "adergada": "adergar",
    "adergadas": "adergar",
    "adergado": "adergar",
    "adergados": "adergar",
    "adergai": "adergar",
    "adergais": "adergar",
    "adergam": "adergar",
    "adergamo": "adergar",
    "adergamos": "adergar",
    "adergando": "adergar",
    "adergara": "adergar",
    "adergaram": "adergar",
    "adergaras": "adergar",
    "adergardes": "adergar",
    "adergarei": "adergar",
    "adergareis": "adergar",
    "adergarem": "adergar",
    "adergaremos": "adergar",
    "adergares": "adergar",
    "adergaria": "adergar",
    "adergariam": "adergar",
    "adergarias": "adergar",
    "adergarmo": "adergar",
    "adergarmos": "adergar",
    "adergará": "adergar",
    "adergarás": "adergar",
    "adergarão": "adergar",
    "adergaríamos": "adergar",
    "adergaríeis": "adergar",
    "adergas": "adergar",
    "adergasse": "adergar",
    "adergassem": "adergar",
    "adergasses": "adergar",
    "adergaste": "adergar",
    "adergastes": "adergar",
    "adergava": "adergar",
    "adergavam": "adergar",
    "adergavas": "adergar",
    "adergo": "adergar",
    "adergou": "adergar",
    "adergue": "adergar",
    "aderguei": "adergar",
    "adergueis": "adergar",
    "aderguem": "adergar",
    "aderguemo": "adergar",
    "aderguemos": "adergar",
    "adergues": "adergar",
    "adergámo": "adergar",
    "adergámos": "adergar",
    "adergáramo": "adergar",
    "adergáramos": "adergar",
    "adergáreis": "adergar",
    "adergásseis": "adergar",
    "adergássemos": "adergar",
    "adergávamo": "adergar",
    "adergávamos": "adergar",
    "adergáveis": "adergar",
    "aderi": "aderir",
    "aderia": "aderir",
    "aderiam": "aderir",
    "aderias": "aderir",
    "aderida": "aderir",
    "aderidas": "aderir",
    "aderido": "aderir",
    "aderidos": "aderir",
    "aderimo": "aderir",
    "aderimos": "aderir",
    "aderindo": "aderir",
    "aderira": "aderir",
    "aderiram": "aderir",
    "aderiras": "aderir",
    "aderirde": "aderir",
    "aderirdes": "aderir",
    "aderire": "aderir",
    "aderirei": "aderir",
    "aderireis": "aderir",
    "aderirem": "aderir",
    "aderiremos": "aderir",
    "aderires": "aderir",
    "aderiria": "aderir",
    "adeririam": "aderir",
    "aderirias": "aderir",
    "aderirmo": "aderir",
    "aderirmos": "aderir",
    "aderirá": "aderir",
    "aderirás": "aderir",
    "aderirão": "aderir",
    "aderiríamos": "aderir",
    "aderiríeis": "aderir",
    "aderis": "aderir",
    "aderisse": "aderir",
    "aderissem": "aderir",
    "aderisses": "aderir",
    "aderiste": "aderir",
    "aderistes": "aderir",
    "aderiu": "aderir",
    "adermias": "adermia",
    "aderna": "adernar",
    "adernada": "adernar",
    "adernadas": "adernar",
    "adernado": "adernar",
    "adernados": "adernar",
    "adernai": "adernar",
    "adernais": "adernar",
    "adernam": "adernar",
    "adernamo": "adernar",
    "adernamos": "adernar",
    "adernando": "adernar",
    "adernara": "adernar",
    "adernaram": "adernar",
    "adernaras": "adernar",
    "adernardes": "adernar",
    "adernarei": "adernar",
    "adernareis": "adernar",
    "adernarem": "adernar",
    "adernaremos": "adernar",
    "adernares": "adernar",
    "adernaria": "adernar",
    "adernariam": "adernar",
    "adernarias": "adernar",
    "adernarmo": "adernar",
    "adernarmos": "adernar",
    "adernará": "adernar",
    "adernarás": "adernar",
    "adernarão": "adernar",
    "adernaríamos": "adernar",
    "adernaríeis": "adernar",
    "adernas": "adernar",
    "adernasse": "adernar",
    "adernassem": "adernar",
    "adernasses": "adernar",
    "adernaste": "adernar",
    "adernastes": "adernar",
    "adernava": "adernar",
    "adernavam": "adernar",
    "adernavas": "adernar",
    "aderne": "adernar",
    "adernei": "adernar",
    "aderneis": "adernar",
    "adernem": "adernar",
    "adernemo": "adernar",
    "adernemos": "adernar",
    "adernes": "adernar",
    "aderno": "adernar",
    "adernou": "adernar",
    "adernámo": "adernar",
    "adernámos": "adernar",
    "adernáramo": "adernar",
    "adernáramos": "adernar",
    "adernáreis": "adernar",
    "adernásseis": "adernar",
    "adernássemos": "adernar",
    "adernávamo": "adernar",
    "adernávamos": "adernar",
    "adernáveis": "adernar",
    "aderências": "aderência",
    "aderíamo": "aderir",
    "aderíamos": "aderir",
    "aderíei": "aderir",
    "aderíeis": "aderir",
    "aderíramo": "aderir",
    "aderíramos": "aderir",
    "aderírei": "aderir",
    "aderíreis": "aderir",
    "aderísseis": "aderir",
    "aderíssemos": "aderir",
    "ades": "adir",
    "adesiva": "adesivo",
    "adesivas": "adesivo",
    "adesividades": "adesividade",
    "adesivos": "adesivo",
    "adestra": "adestrar",
    "adestrada": "adestrar",
    "adestradas": "adestrar",
    "adestrado": "adestrar",
    "adestradora": "adestrador",
    "adestradoras": "adestrador",
    "adestradores": "adestrador",
    "adestrados": "adestrar",
    "adestradíssima": "adestrado",
    "adestradíssimas": "adestrado",
    "adestradíssimo": "adestrado",
    "adestradíssimos": "adestrado",
    "adestrai": "adestrar",
    "adestrais": "adestrar",
    "adestram": "adestrar",
    "adestramentos": "adestramento",
    "adestramo": "adestrar",
    "adestramos": "adestrar",
    "adestrando": "adestrar",
    "adestrara": "adestrar",
    "adestraram": "adestrar",
    "adestraras": "adestrar",
    "adestrarde": "adestrar",
    "adestrardes": "adestrar",
    "adestrare": "adestrar",
    "adestrarei": "adestrar",
    "adestrareis": "adestrar",
    "adestrarem": "adestrar",
    "adestraremos": "adestrar",
    "adestrares": "adestrar",
    "adestraria": "adestrar",
    "adestrariam": "adestrar",
    "adestrarias": "adestrar",
    "adestrarmo": "adestrar",
    "adestrarmos": "adestrar",
    "adestrará": "adestrar",
    "adestrarás": "adestrar",
    "adestrarão": "adestrar",
    "adestraríamos": "adestrar",
    "adestraríeis": "adestrar",
    "adestras": "adestrar",
    "adestrasse": "adestrar",
    "adestrassem": "adestrar",
    "adestrasses": "adestrar",
    "adestraste": "adestrar",
    "adestrastes": "adestrar",
    "adestrava": "adestrar",
    "adestravam": "adestrar",
    "adestravas": "adestrar",
    "adestre": "adestrar",
    "adestrei": "adestrar",
    "adestreis": "adestrar",
    "adestrem": "adestrar",
    "adestremo": "adestrar",
    "adestremos": "adestrar",
    "adestres": "adestrar",
    "adestro": "adestrar",
    "adestrou": "adestrar",
    "adestrá": "adestrar",
    "adestrámo": "adestrar",
    "adestrámos": "adestrar",
    "adestráramo": "adestrar",
    "adestráramos": "adestrar",
    "adestrárei": "adestrar",
    "adestráreis": "adestrar",
    "adestrásseis": "adestrar",
    "adestrássemos": "adestrar",
    "adestrávamo": "adestrar",
    "adestrávamos": "adestrar",
    "adestrávei": "adestrar",
    "adestráveis": "adestrar",
    "adesões": "adesão",
    "adeusa": "adeusar",
    "adeusada": "adeusar",
    "adeusadas": "adeusar",
    "adeusado": "adeusar",
    "adeusados": "adeusar",
    "adeusai": "adeusar",
    "adeusais": "adeusar",
    "adeusam": "adeusar",
    "adeusamo": "adeusar",
    "adeusamos": "adeusar",
    "adeusando": "adeusar",
    "adeusara": "adeusar",
    "adeusaram": "adeusar",
    "adeusaras": "adeusar",
    "adeusarde": "adeusar",
    "adeusardes": "adeusar",
    "adeusare": "adeusar",
    "adeusarei": "adeusar",
    "adeusareis": "adeusar",
    "adeusarem": "adeusar",
    "adeusaremos": "adeusar",
    "adeusares": "adeusar",
    "adeusaria": "adeusar",
    "adeusariam": "adeusar",
    "adeusarias": "adeusar",
    "adeusarmo": "adeusar",
    "adeusarmos": "adeusar",
    "adeusará": "adeusar",
    "adeusarás": "adeusar",
    "adeusarão": "adeusar",
    "adeusaríamos": "adeusar",
    "adeusaríeis": "adeusar",
    "adeusas": "adeusar",
    "adeusasse": "adeusar",
    "adeusassem": "adeusar",
    "adeusasses": "adeusar",
    "adeusaste": "adeusar",
    "adeusastes": "adeusar",
    "adeusava": "adeusar",
    "adeusavam": "adeusar",
    "adeusavas": "adeusar",
    "adeuse": "adeusar",
    "adeusei": "adeusar",
    "adeuseis": "adeusar",
    "adeusem": "adeusar",
    "adeusemo": "adeusar",
    "adeusemos": "adeusar",
    "adeuses": "adeusar",
    "adeusinho": "adeus",
    "adeusinhos": "adeus",
    "adeusito": "adeus",
    "adeusitos": "adeus",
    "adeuso": "adeusar",
    "adeusou": "adeusar",
    "adeusá": "adeusar",
    "adeusámo": "adeusar",
    "adeusámos": "adeusar",
    "adeusáramo": "adeusar",
    "adeusáramos": "adeusar",
    "adeusárei": "adeusar",
    "adeusáreis": "adeusar",
    "adeusásseis": "adeusar",
    "adeusássemos": "adeusar",
    "adeusávamo": "adeusar",
    "adeusávamos": "adeusar",
    "adeusávei": "adeusar",
    "adeusáveis": "adeusar",
    "adeísmos": "adeísmo",
    "adi": "adir",
    "adia": "adir",
    "adiabilidades": "adiabilidade",
    "adiabática": "adiabático",
    "adiabáticas": "adiabático",
    "adiabáticos": "adiabático",
    "adiada": "adiar",
    "adiadas": "adiar",
    "adiado": "adiar",
    "adiados": "adiar",
    "adiafas": "adiafa",
    "adiafores": "adiafore",
    "adiai": "adiar",
    "adiais": "adiar",
    "adiam": "adir",
    "adiamanta": "adiamantar",
    "adiamantada": "adiamantar",
    "adiamantadas": "adiamantar",
    "adiamantado": "adiamantar",
    "adiamantados": "adiamantar",
    "adiamantai": "adiamantar",
    "adiamantais": "adiamantar",
    "adiamantam": "adiamantar",
    "adiamantamo": "adiamantar",
    "adiamantamos": "adiamantar",
    "adiamantando": "adiamantar",
    "adiamantara": "adiamantar",
    "adiamantaram": "adiamantar",
    "adiamantaras": "adiamantar",
    "adiamantarde": "adiamantar",
    "adiamantardes": "adiamantar",
    "adiamantare": "adiamantar",
    "adiamantarei": "adiamantar",
    "adiamantareis": "adiamantar",
    "adiamantarem": "adiamantar",
    "adiamantaremos": "adiamantar",
    "adiamantares": "adiamantar",
    "adiamantaria": "adiamantar",
    "adiamantariam": "adiamantar",
    "adiamantarias": "adiamantar",
    "adiamantarmo": "adiamantar",
    "adiamantarmos": "adiamantar",
    "adiamantará": "adiamantar",
    "adiamantarás": "adiamantar",
    "adiamantarão": "adiamantar",
    "adiamantaríamos": "adiamantar",
    "adiamantaríeis": "adiamantar",
    "adiamantas": "adiamantar",
    "adiamantasse": "adiamantar",
    "adiamantassem": "adiamantar",
    "adiamantasses": "adiamantar",
    "adiamantaste": "adiamantar",
    "adiamantastes": "adiamantar",
    "adiamantava": "adiamantar",
    "adiamantavam": "adiamantar",
    "adiamantavas": "adiamantar",
    "adiamante": "adiamantar",
    "adiamantei": "adiamantar",
    "adiamanteis": "adiamantar",
    "adiamantem": "adiamantar",
    "adiamantemo": "adiamantar",
    "adiamantemos": "adiamantar",
    "adiamantes": "adiamantar",
    "adiamantina": "adiamantino",
    "adiamantinas": "adiamantino",
    "adiamantinos": "adiamantino",
    "adiamanto": "adiamantar",
    "adiamantou": "adiamantar",
    "adiamantá": "adiamantar",
    "adiamantámo": "adiamantar",
    "adiamantámos": "adiamantar",
    "adiamantáramo": "adiamantar",
    "adiamantáramos": "adiamantar",
    "adiamantárei": "adiamantar",
    "adiamantáreis": "adiamantar",
    "adiamantásseis": "adiamantar",
    "adiamantássemos": "adiamantar",
    "adiamantávamo": "adiamantar",
    "adiamantávamos": "adiamantar",
    "adiamantávei": "adiamantar",
    "adiamantáveis": "adiamantar",
    "adiamentos": "adiamento",
    "adiamo": "adiar",
    "adiamos": "adiar",
    "adiando": "adiar",
    "adianta": "adiantar",
    "adiantada": "adiantar",
    "adiantadas": "adiantar",
    "adiantado": "adiantar",
    "adiantados": "adiantar",
    "adiantadíssima": "adiantado",
    "adiantadíssimas": "adiantado",
    "adiantadíssimo": "adiantado",
    "adiantadíssimos": "adiantado",
    "adiantai": "adiantar",
    "adiantais": "adiantar",
    "adiantam": "adiantar",
    "adiantamentos": "adiantamento",
    "adiantamo": "adiantar",
    "adiantamos": "adiantar",
    "adiantando": "adiantar",
    "adiantara": "adiantar",
    "adiantaram": "adiantar",
    "adiantaras": "adiantar",
    "adiantarde": "adiantar",
    "adiantardes": "adiantar",
    "adiantare": "adiantar",
    "adiantarei": "adiantar",
    "adiantareis": "adiantar",
    "adiantarem": "adiantar",
    "adiantaremos": "adiantar",
    "adiantares": "adiantar",
    "adiantaria": "adiantar",
    "adiantariam": "adiantar",
    "adiantarias": "adiantar",
    "adiantarmo": "adiantar",
    "adiantarmos": "adiantar",
    "adiantará": "adiantar",
    "adiantarás": "adiantar",
    "adiantarão": "adiantar",
    "adiantaríamos": "adiantar",
    "adiantaríeis": "adiantar",
    "adiantas": "adiantar",
    "adiantasse": "adiantar",
    "adiantassem": "adiantar",
    "adiantasses": "adiantar",
    "adiantaste": "adiantar",
    "adiantastes": "adiantar",
    "adiantava": "adiantar",
    "adiantavam": "adiantar",
    "adiantavas": "adiantar",
    "adiante": "adiantar",
    "adiantei": "adiantar",
    "adianteis": "adiantar",
    "adiantem": "adiantar",
    "adiantemo": "adiantar",
    "adiantemos": "adiantar",
    "adiantes": "adiantar",
    "adianto": "adiantar",
    "adiantou": "adiantar",
    "adiantá": "adiantar",
    "adiantámo": "adiantar",
    "adiantámos": "adiantar",
    "adiantáramo": "adiantar",
    "adiantáramos": "adiantar",
    "adiantárei": "adiantar",
    "adiantáreis": "adiantar",
    "adiantásseis": "adiantar",
    "adiantássemos": "adiantar",
    "adiantávamo": "adiantar",
    "adiantávamos": "adiantar",
    "adiantávei": "adiantar",
    "adiantáveis": "adiantável",
    "adiara": "adiar",
    "adiaram": "adiar",
    "adiaras": "adiar",
    "adiarde": "adiar",
    "adiardes": "adiar",
    "adiare": "adiar",
    "adiarei": "adiar",
    "adiareis": "adiar",
    "adiarem": "adiar",
    "adiaremos": "adiar",
    "adiares": "adiar",
    "adiaria": "adiar",
    "adiariam": "adiar",
    "adiarias": "adiar",
    "adiarmo": "adiar",
    "adiarmos": "adiar",
    "adiará": "adiar",
    "adiarás": "adiar",
    "adiarão": "adiar",
    "adiaríamos": "adiar",
    "adiaríeis": "adiar",
    "adias": "adir",
    "adiasse": "adiar",
    "adiassem": "adiar",
    "adiasses": "adiar",
    "adiaste": "adiar",
    "adiastes": "adiar",
    "adiatermias": "adiatermia",
    "adiatérmica": "adiatérmico",
    "adiatérmicas": "adiatérmico",
    "adiatérmicos": "adiatérmico",
    "adiava": "adiar",
    "adiavam": "adiar",
    "adiavas": "adiar",
    "adiciona": "adicionar",
    "adicionada": "adicionar",
    "adicionadas": "adicionar",
    "adicionado": "adicionar",
    "adicionadora": "adicionador",
    "adicionadoras": "adicionador",
    "adicionadores": "adicionador",
    "adicionados": "adicionar",
    "adicionai": "adicionar",
    "adicionais": "adicionar",
    "adicionam": "adicionar",
    "adicionamentos": "adicionamento",
    "adicionamo": "adicionar",
    "adicionamos": "adicionar",
    "adicionando": "adicionar",
    "adicionara": "adicionar",
    "adicionaram": "adicionar",
    "adicionaras": "adicionar",
    "adicionarde": "adicionar",
    "adicionardes": "adicionar",
    "adicionare": "adicionar",
    "adicionarei": "adicionar",
    "adicionareis": "adicionar",
    "adicionarem": "adicionar",
    "adicionaremos": "adicionar",
    "adicionares": "adicionar",
    "adicionaria": "adicionar",
    "adicionariam": "adicionar",
    "adicionarias": "adicionar",
    "adicionarmo": "adicionar",
    "adicionarmos": "adicionar",
    "adicionará": "adicionar",
    "adicionarás": "adicionar",
    "adicionarão": "adicionar",
    "adicionaríamos": "adicionar",
    "adicionaríeis": "adicionar",
    "adicionas": "adicionar",
    "adicionasse": "adicionar",
    "adicionassem": "adicionar",
    "adicionasses": "adicionar",
    "adicionaste": "adicionar",
    "adicionastes": "adicionar",
    "adicionava": "adicionar",
    "adicionavam": "adicionar",
    "adicionavas": "adicionar",
    "adicionações": "adicionação",
    "adicione": "adicionar",
    "adicionei": "adicionar",
    "adicioneis": "adicionar",
    "adicionem": "adicionar",
    "adicionemo": "adicionar",
    "adicionemos": "adicionar",
    "adiciones": "adicionar",
    "adiciono": "adicionar",
    "adicionou": "adicionar",
    "adicioná": "adicionar",
    "adicionámo": "adicionar",
    "adicionámos": "adicionar",
    "adicionáramo": "adicionar",
    "adicionáramos": "adicionar",
    "adicionárei": "adicionar",
    "adicionáreis": "adicionar",
    "adicionásseis": "adicionar",
    "adicionássemos": "adicionar",
    "adicionávamo": "adicionar",
    "adicionávamos": "adicionar",
    "adicionávei": "adicionar",
    "adicionáveis": "adicionável",
    "adicta": "adicto",
    "adictas": "adicto",
    "adictos": "adicto",
    "adictícia": "adictício",
    "adictícias": "adictício",
    "adictícios": "adictício",
    "adida": "adir",
    "adidas": "adir",
    "adido": "adir",
    "adidos": "adir",
    "adie": "adiar",
    "adiei": "adiar",
    "adieis": "adiar",
    "adiem": "adiar",
    "adiemo": "adiar",
    "adiemos": "adiar",
    "adies": "adiar",
    "adieta": "adietar",
    "adietada": "adietar",
    "adietadas": "adietar",
    "adietado": "adietar",
    "adietados": "adietar",
    "adietai": "adietar",
    "adietais": "adietar",
    "adietam": "adietar",
    "adietamo": "adietar",
    "adietamos": "adietar",
    "adietando": "adietar",
    "adietara": "adietar",
    "adietaram": "adietar",
    "adietaras": "adietar",
    "adietarde": "adietar",
    "adietardes": "adietar",
    "adietare": "adietar",
    "adietarei": "adietar",
    "adietareis": "adietar",
    "adietarem": "adietar",
    "adietaremos": "adietar",
    "adietares": "adietar",
    "adietaria": "adietar",
    "adietariam": "adietar",
    "adietarias": "adietar",
    "adietarmo": "adietar",
    "adietarmos": "adietar",
    "adietará": "adietar",
    "adietarás": "adietar",
    "adietarão": "adietar",
    "adietaríamos": "adietar",
    "adietaríeis": "adietar",
    "adietas": "adietar",
    "adietasse": "adietar",
    "adietassem": "adietar",
    "adietasses": "adietar",
    "adietaste": "adietar",
    "adietastes": "adietar",
    "adietava": "adietar",
    "adietavam": "adietar",
    "adietavas": "adietar",
    "adiete": "adietar",
    "adietei": "adietar",
    "adieteis": "adietar",
    "adietem": "adietar",
    "adietemo": "adietar",
    "adietemos": "adietar",
    "adietes": "adietar",
    "adieto": "adietar",
    "adietou": "adietar",
    "adietá": "adietar",
    "adietámo": "adietar",
    "adietámos": "adietar",
    "adietáramo": "adietar",
    "adietáramos": "adietar",
    "adietárei": "adietar",
    "adietáreis": "adietar",
    "adietásseis": "adietar",
    "adietássemos": "adietar",
    "adietávamo": "adietar",
    "adietávamos": "adietar",
    "adietávei": "adietar",
    "adietáveis": "adietar",
    "adila": "adilar",
    "adilada": "adilar",
    "adiladas": "adilar",
    "adilado": "adilar",
    "adilados": "adilar",
    "adilai": "adilar",
    "adilais": "adilar",
    "adilam": "adilar",
    "adilamo": "adilar",
    "adilamos": "adilar",
    "adilando": "adilar",
    "adilara": "adilar",
    "adilaram": "adilar",
    "adilaras": "adilar",
    "adilarde": "adilar",
    "adilardes": "adilar",
    "adilare": "adilar",
    "adilarei": "adilar",
    "adilareis": "adilar",
    "adilarem": "adilar",
    "adilaremos": "adilar",
    "adilares": "adilar",
    "adilaria": "adilar",
    "adilariam": "adilar",
    "adilarias": "adilar",
    "adilarmo": "adilar",
    "adilarmos": "adilar",
    "adilará": "adilar",
    "adilarás": "adilar",
    "adilarão": "adilar",
    "adilaríamos": "adilar",
    "adilaríeis": "adilar",
    "adilas": "adilar",
    "adilasse": "adilar",
    "adilassem": "adilar",
    "adilasses": "adilar",
    "adilaste": "adilar",
    "adilastes": "adilar",
    "adilava": "adilar",
    "adilavam": "adilar",
    "adilavas": "adilar",
    "adile": "adilar",
    "adilei": "adilar",
    "adileis": "adilar",
    "adilem": "adilar",
    "adilemo": "adilar",
    "adilemos": "adilar",
    "adiles": "adilar",
    "adilo": "adilar",
    "adilou": "adilar",
    "adilá": "adilar",
    "adilámo": "adilar",
    "adilámos": "adilar",
    "adiláramo": "adilar",
    "adiláramos": "adilar",
    "adilárei": "adilar",
    "adiláreis": "adilar",
    "adilásseis": "adilar",
    "adilássemos": "adilar",
    "adilávamo": "adilar",
    "adilávamos": "adilar",
    "adilávei": "adilar",
    "adiláveis": "adilar",
    "adimo": "adir",
    "adimos": "adir",
    "adinamias": "adinamia",
    "adindo": "adir",
    "adinheirada": "adinheirado",
    "adinheiradas": "adinheirado",
    "adinheirados": "adinheirado",
    "adinâmica": "adinâmico",
    "adinâmicas": "adinâmico",
    "adinâmicos": "adinâmico",
    "adio": "adiar",
    "adiou": "adiar",
    "adipomas": "adipoma",
    "adiposa": "adiposo",
    "adiposas": "adiposo",
    "adiposes": "adipose",
    "adiposidades": "adiposidade",
    "adiposos": "adiposo",
    "adipsias": "adipsia",
    "adira": "adir",
    "adirais": "aderir",
    "adiram": "adir",
    "adiramo": "aderir",
    "adiramos": "aderir",
    "adiras": "adir",
    "adirde": "adir",
    "adirdes": "adir",
    "adire": "adir",
    "adirei": "adir",
    "adireis": "adir",
    "adirem": "adir",
    "adiremos": "adir",
    "adires": "adir",
    "adiria": "adir",
    "adiriam": "adir",
    "adirias": "adir",
    "adirmo": "adir",
    "adirmos": "adir",
    "adiro": "aderir",
    "adirá": "adir",
    "adirás": "adir",
    "adirão": "adir",
    "adiríamos": "adir",
    "adiríeis": "adir",
    "adis": "adir",
    "adisse": "adir",
    "adissem": "adir",
    "adisses": "adir",
    "adiste": "adir",
    "adistes": "adir",
    "adita": "aditar",
    "aditada": "aditar",
    "aditadas": "aditar",
    "aditado": "aditar",
    "aditados": "aditar",
    "aditai": "aditar",
    "aditais": "aditar",
    "aditam": "aditar",
    "aditamentos": "aditamento",
    "aditamo": "aditar",
    "aditamos": "aditar",
    "aditando": "aditar",
    "aditara": "aditar",
    "aditaram": "aditar",
    "aditaras": "aditar",
    "aditarde": "aditar",
    "aditardes": "aditar",
    "aditare": "aditar",
    "aditarei": "aditar",
    "aditareis": "aditar",
    "aditarem": "aditar",
    "aditaremos": "aditar",
    "aditares": "aditar",
    "aditaria": "aditar",
    "aditariam": "aditar",
    "aditarias": "aditar",
    "aditarmo": "aditar",
    "aditarmos": "aditar",
    "aditará": "aditar",
    "aditarás": "aditar",
    "aditarão": "aditar",
    "aditaríamos": "aditar",
    "aditaríeis": "aditar",
    "aditas": "aditar",
    "aditasse": "aditar",
    "aditassem": "aditar",
    "aditasses": "aditar",
    "aditaste": "aditar",
    "aditastes": "aditar",
    "aditava": "aditar",
    "aditavam": "aditar",
    "aditavas": "aditar",
    "adite": "aditar",
    "aditei": "aditar",
    "aditeis": "aditar",
    "aditem": "aditar",
    "aditemo": "aditar",
    "aditemos": "aditar",
    "adites": "aditar",
    "aditiva": "aditivo",
    "aditivada": "aditivado",
    "aditivadas": "aditivado",
    "aditivados": "aditivado",
    "aditivas": "aditivo",
    "aditivos": "aditivo",
    "adito": "aditar",
    "aditou": "aditar",
    "aditá": "aditar",
    "aditámo": "aditar",
    "aditámos": "aditar",
    "aditáramo": "aditar",
    "aditáramos": "aditar",
    "aditárei": "aditar",
    "aditáreis": "aditar",
    "aditásseis": "aditar",
    "aditássemos": "aditar",
    "aditávamo": "aditar",
    "aditávamos": "aditar",
    "aditávei": "aditar",
    "aditáveis": "aditar",
    "aditícia": "aditício",
    "aditícias": "aditício",
    "aditícios": "aditício",
    "adiu": "adir",
    "adivais": "adival",
    "adivinha": "adivinho",
    "adivinhada": "adivinhar",
    "adivinhadas": "adivinhar",
    "adivinhado": "adivinhar",
    "adivinhadora": "adivinhador",
    "adivinhadoras": "adivinhador",
    "adivinhadores": "adivinhador",
    "adivinhados": "adivinhar",
    "adivinhai": "adivinhar",
    "adivinhais": "adivinhar",
    "adivinham": "adivinhar",
    "adivinhamo": "adivinhar",
    "adivinhamos": "adivinhar",
    "adivinhando": "adivinhar",
    "adivinhara": "adivinhar",
    "adivinharam": "adivinhar",
    "adivinharas": "adivinhar",
    "adivinharde": "adivinhar",
    "adivinhardes": "adivinhar",
    "adivinhare": "adivinhar",
    "adivinharei": "adivinhar",
    "adivinhareis": "adivinhar",
    "adivinharem": "adivinhar",
    "adivinharemos": "adivinhar",
    "adivinhares": "adivinhar",
    "adivinharia": "adivinhar",
    "adivinhariam": "adivinhar",
    "adivinharias": "adivinhar",
    "adivinharmo": "adivinhar",
    "adivinharmos": "adivinhar",
    "adivinhará": "adivinhar",
    "adivinharás": "adivinhar",
    "adivinharão": "adivinhar",
    "adivinharíamos": "adivinhar",
    "adivinharíeis": "adivinhar",
    "adivinhas": "adivinho",
    "adivinhasse": "adivinhar",
    "adivinhassem": "adivinhar",
    "adivinhasses": "adivinhar",
    "adivinhaste": "adivinhar",
    "adivinhastes": "adivinhar",
    "adivinhava": "adivinhar",
    "adivinhavam": "adivinhar",
    "adivinhavas": "adivinhar",
    "adivinhações": "adivinhação",
    "adivinhe": "adivinhar",
    "adivinhei": "adivinhar",
    "adivinheis": "adivinhar",
    "adivinhem": "adivinhar",
    "adivinhemo": "adivinhar",
    "adivinhemos": "adivinhar",
    "adivinhes": "adivinhar",
    "adivinho": "adivinhar",
    "adivinhos": "adivinho",
    "adivinhou": "adivinhar",
    "adivinhá": "adivinhar",
    "adivinhámo": "adivinhar",
    "adivinhámos": "adivinhar",
    "adivinháramo": "adivinhar",
    "adivinháramos": "adivinhar",
    "adivinhárei": "adivinhar",
    "adivinháreis": "adivinhar",
    "adivinhásseis": "adivinhar",
    "adivinhássemos": "adivinhar",
    "adivinhávamo": "adivinhar",
    "adivinhávamos": "adivinhar",
    "adivinhávei": "adivinhar",
    "adivinháveis": "adivinhável",
    "adiá": "adiar",
    "adiáfana": "adiáfano",
    "adiáfanas": "adiáfano",
    "adiáfanos": "adiáfano",
    "adiáfora": "adiáforo",
    "adiáforas": "adiáforo",
    "adiáforos": "adiáforo",
    "adiámo": "adiar",
    "adiámos": "adiar",
    "adiáramo": "adiar",
    "adiáramos": "adiar",
    "adiárei": "adiar",
    "adiáreis": "adiar",
    "adiásseis": "adiar",
    "adiássemos": "adiar",
    "adiávamo": "adiar",
    "adiávamos": "adiar",
    "adiávei": "adiar",
    "adiáveis": "adiável",
    "adições": "adição",
    "adjacentes": "adjacente",
    "adjacências": "adjacência",
    "adjaz": "adjazer",
    "adjaza": "adjazer",
    "adjazam": "adjazer",
    "adjazem": "adjazer",
    "adjazendo": "adjazer",
    "adjazerem": "adjazer",
    "adjazeria": "adjazer",
    "adjazeriam": "adjazer",
    "adjazerá": "adjazer",
    "adjazerão": "adjazer",
    "adjazia": "adjazer",
    "adjaziam": "adjazer",
    "adjazida": "adjazer",
    "adjazidas": "adjazer",
    "adjazido": "adjazer",
    "adjazidos": "adjazer",
    "adjectiva": "adjectivo",
    "adjectivada": "adjectivar",
    "adjectivadas": "adjectivar",
    "adjectivado": "adjectivar",
    "adjectivados": "adjectivar",
    "adjectivai": "adjectivar",
    "adjectivais": "adjectivar",
    "adjectivalizações": "adjectivalização",
    "adjectivam": "adjectivar",
    "adjectivamo": "adjectivar",
    "adjectivamos": "adjectivar",
    "adjectivando": "adjectivar",
    "adjectivara": "adjectivar",
    "adjectivaram": "adjectivar",
    "adjectivaras": "adjectivar",
    "adjectivarde": "adjectivar",
    "adjectivardes": "adjectivar",
    "adjectivare": "adjectivar",
    "adjectivarei": "adjectivar",
    "adjectivareis": "adjectivar",
    "adjectivarem": "adjectivar",
    "adjectivaremos": "adjectivar",
    "adjectivares": "adjectivar",
    "adjectivaria": "adjectivar",
    "adjectivariam": "adjectivar",
    "adjectivarias": "adjectivar",
    "adjectivarmo": "adjectivar",
    "adjectivarmos": "adjectivar",
    "adjectivará": "adjectivar",
    "adjectivarás": "adjectivar",
    "adjectivarão": "adjectivar",
    "adjectivaríamos": "adjectivar",
    "adjectivaríeis": "adjectivar",
    "adjectivas": "adjectivo",
    "adjectivasse": "adjectivar",
    "adjectivassem": "adjectivar",
    "adjectivasses": "adjectivar",
    "adjectivaste": "adjectivar",
    "adjectivastes": "adjectivar",
    "adjectivava": "adjectivar",
    "adjectivavam": "adjectivar",
    "adjectivavas": "adjectivar",
    "adjectivações": "adjectivação",
    "adjective": "adjectivar",
    "adjectivei": "adjectivar",
    "adjectiveis": "adjectivar",
    "adjectivem": "adjectivar",
    "adjectivemo": "adjectivar",
    "adjectivemos": "adjectivar",
    "adjectives": "adjectivar",
    "adjectividades": "adjectividade",
    "adjectivo": "adjectivar",
    "adjectivos": "adjectivo",
    "adjectivou": "adjectivar",
    "adjectivá": "adjectivar",
    "adjectivámo": "adjectivar",
    "adjectivámos": "adjectivar",
    "adjectiváramo": "adjectivar",
    "adjectiváramos": "adjectivar",
    "adjectivárei": "adjectivar",
    "adjectiváreis": "adjectivar",
    "adjectivásseis": "adjectivar",
    "adjectivássemos": "adjectivar",
    "adjectivávamo": "adjectivar",
    "adjectivávamos": "adjectivar",
    "adjectivávei": "adjectivar",
    "adjectiváveis": "adjectivar",
    "adjecções": "adjecção",
    "adjetivalizações": "adjetivalização",
    "adjetivações": "adjetivação",
    "adjetividades": "adjetividade",
    "adjetivos": "adjetivo",
    "adjouve": "adjazer",
    "adjouver": "adjazer",
    "adjouvera": "adjazer",
    "adjouveram": "adjazer",
    "adjouverem": "adjazer",
    "adjouvesse": "adjazer",
    "adjouvessem": "adjazer",
    "adjudica": "adjudicar",
    "adjudicada": "adjudicar",
    "adjudicadas": "adjudicar",
    "adjudicado": "adjudicar",
    "adjudicadora": "adjudicador",
    "adjudicadoras": "adjudicador",
    "adjudicadores": "adjudicador",
    "adjudicados": "adjudicar",
    "adjudicai": "adjudicar",
    "adjudicais": "adjudicar",
    "adjudicam": "adjudicar",
    "adjudicamo": "adjudicar",
    "adjudicamos": "adjudicar",
    "adjudicando": "adjudicar",
    "adjudicara": "adjudicar",
    "adjudicaram": "adjudicar",
    "adjudicaras": "adjudicar",
    "adjudicarde": "adjudicar",
    "adjudicardes": "adjudicar",
    "adjudicare": "adjudicar",
    "adjudicarei": "adjudicar",
    "adjudicareis": "adjudicar",
    "adjudicarem": "adjudicar",
    "adjudicaremos": "adjudicar",
    "adjudicares": "adjudicar",
    "adjudicaria": "adjudicar",
    "adjudicariam": "adjudicar",
    "adjudicarias": "adjudicar",
    "adjudicarmo": "adjudicar",
    "adjudicarmos": "adjudicar",
    "adjudicará": "adjudicar",
    "adjudicarás": "adjudicar",
    "adjudicarão": "adjudicar",
    "adjudicaríamos": "adjudicar",
    "adjudicaríeis": "adjudicar",
    "adjudicas": "adjudicar",
    "adjudicasse": "adjudicar",
    "adjudicassem": "adjudicar",
    "adjudicasses": "adjudicar",
    "adjudicaste": "adjudicar",
    "adjudicastes": "adjudicar",
    "adjudicatária": "adjudicatário",
    "adjudicatárias": "adjudicatário",
    "adjudicatários": "adjudicatário",
    "adjudicatória": "adjudicatório",
    "adjudicatórias": "adjudicatório",
    "adjudicatórios": "adjudicatório",
    "adjudicava": "adjudicar",
    "adjudicavam": "adjudicar",
    "adjudicavas": "adjudicar",
    "adjudicações": "adjudicação",
    "adjudico": "adjudicar",
    "adjudicou": "adjudicar",
    "adjudicá": "adjudicar",
    "adjudicámo": "adjudicar",
    "adjudicámos": "adjudicar",
    "adjudicáramo": "adjudicar",
    "adjudicáramos": "adjudicar",
    "adjudicárei": "adjudicar",
    "adjudicáreis": "adjudicar",
    "adjudicásseis": "adjudicar",
    "adjudicássemos": "adjudicar",
    "adjudicávamo": "adjudicar",
    "adjudicávamos": "adjudicar",
    "adjudicávei": "adjudicar",
    "adjudicáveis": "adjudicar",
    "adjudique": "adjudicar",
    "adjudiquei": "adjudicar",
    "adjudiqueis": "adjudicar",
    "adjudiquem": "adjudicar",
    "adjudiquemo": "adjudicar",
    "adjudiquemos": "adjudicar",
    "adjudiques": "adjudicar",
    "adjunge": "adjungir",
    "adjungem": "adjungir",
    "adjunges": "adjungir",
    "adjungi": "adjungir",
    "adjungia": "adjungir",
    "adjungiam": "adjungir",
    "adjungias": "adjungir",
    "adjungida": "adjungir",
    "adjungidas": "adjungir",
    "adjungido": "adjungir",
    "adjungidos": "adjungir",
    "adjungimo": "adjungir",
    "adjungimos": "adjungir",
    "adjungindo": "adjungir",
    "adjungira": "adjungir",
    "adjungiram": "adjungir",
    "adjungiras": "adjungir",
    "adjungirde": "adjungir",
    "adjungirdes": "adjungir",
    "adjungire": "adjungir",
    "adjungirei": "adjungir",
    "adjungireis": "adjungir",
    "adjungirem": "adjungir",
    "adjungiremos": "adjungir",
    "adjungires": "adjungir",
    "adjungiria": "adjungir",
    "adjungiriam": "adjungir",
    "adjungirias": "adjungir",
    "adjungirmo": "adjungir",
    "adjungirmos": "adjungir",
    "adjungirá": "adjungir",
    "adjungirás": "adjungir",
    "adjungirão": "adjungir",
    "adjungiríamos": "adjungir",
    "adjungiríeis": "adjungir",
    "adjungis": "adjungir",
    "adjungisse": "adjungir",
    "adjungissem": "adjungir",
    "adjungisses": "adjungir",
    "adjungiste": "adjungir",
    "adjungistes": "adjungir",
    "adjungiu": "adjungir",
    "adjungíamo": "adjungir",
    "adjungíamos": "adjungir",
    "adjungíei": "adjungir",
    "adjungíeis": "adjungir",
    "adjungíramo": "adjungir",
    "adjungíramos": "adjungir",
    "adjungírei": "adjungir",
    "adjungíreis": "adjungir",
    "adjungísseis": "adjungir",
    "adjungíssemos": "adjungir",
    "adjunja": "adjungir",
    "adjunjais": "adjungir",
    "adjunjam": "adjungir",
    "adjunjamo": "adjungir",
    "adjunjamos": "adjungir",
    "adjunjas": "adjungir",
    "adjunjo": "adjungir",
    "adjunta": "adjunto",
    "adjuntas": "adjunto",
    "adjuntora": "adjuntor",
    "adjuntoras": "adjuntor",
    "adjuntores": "adjuntor",
    "adjuntos": "adjunto",
    "adjunções": "adjunção",
    "adjura": "adjurar",
    "adjurada": "adjurar",
    "adjuradas": "adjurar",
    "adjurado": "adjurar",
    "adjurados": "adjurar",
    "adjurai": "adjurar",
    "adjurais": "adjurar",
    "adjuram": "adjurar",
    "adjuramo": "adjurar",
    "adjuramos": "adjurar",
    "adjurando": "adjurar",
    "adjurara": "adjurar",
    "adjuraram": "adjurar",
    "adjuraras": "adjurar",
    "adjurarde": "adjurar",
    "adjurardes": "adjurar",
    "adjurare": "adjurar",
    "adjurarei": "adjurar",
    "adjurareis": "adjurar",
    "adjurarem": "adjurar",
    "adjuraremos": "adjurar",
    "adjurares": "adjurar",
    "adjuraria": "adjurar",
    "adjurariam": "adjurar",
    "adjurarias": "adjurar",
    "adjurarmo": "adjurar",
    "adjurarmos": "adjurar",
    "adjurará": "adjurar",
    "adjurarás": "adjurar",
    "adjurarão": "adjurar",
    "adjuraríamos": "adjurar",
    "adjuraríeis": "adjurar",
    "adjuras": "adjurar",
    "adjurasse": "adjurar",
    "adjurassem": "adjurar",
    "adjurasses": "adjurar",
    "adjuraste": "adjurar",
    "adjurastes": "adjurar",
    "adjurava": "adjurar",
    "adjuravam": "adjurar",
    "adjuravas": "adjurar",
    "adjurações": "adjuração",
    "adjure": "adjurar",
    "adjurei": "adjurar",
    "adjureis": "adjurar",
    "adjurem": "adjurar",
    "adjuremo": "adjurar",
    "adjuremos": "adjurar",
    "adjures": "adjurar",
    "adjuro": "adjurar",
    "adjurou": "adjurar",
    "adjurá": "adjurar",
    "adjurámo": "adjurar",
    "adjurámos": "adjurar",
    "adjuráramo": "adjurar",
    "adjuráramos": "adjurar",
    "adjurárei": "adjurar",
    "adjuráreis": "adjurar",
    "adjurásseis": "adjurar",
    "adjurássemos": "adjurar",
    "adjurávamo": "adjurar",
    "adjurávamos": "adjurar",
    "adjurávei": "adjurar",
    "adjuráveis": "adjurar",
    "adjutória": "adjutório",
    "adjutórias": "adjutório",
    "adjutórios": "adjutório",
    "adjuva": "adjuvar",
    "adjuvada": "adjuvar",
    "adjuvadas": "adjuvar",
    "adjuvado": "adjuvar",
    "adjuvados": "adjuvar",
    "adjuvai": "adjuvar",
    "adjuvais": "adjuvar",
    "adjuvam": "adjuvar",
    "adjuvamo": "adjuvar",
    "adjuvamos": "adjuvar",
    "adjuvando": "adjuvar",
    "adjuvantes": "adjuvante",
    "adjuvara": "adjuvar",
    "adjuvaram": "adjuvar",
    "adjuvaras": "adjuvar",
    "adjuvarde": "adjuvar",
    "adjuvardes": "adjuvar",
    "adjuvare": "adjuvar",
    "adjuvarei": "adjuvar",
    "adjuvareis": "adjuvar",
    "adjuvarem": "adjuvar",
    "adjuvaremos": "adjuvar",
    "adjuvares": "adjuvar",
    "adjuvaria": "adjuvar",
    "adjuvariam": "adjuvar",
    "adjuvarias": "adjuvar",
    "adjuvarmo": "adjuvar",
    "adjuvarmos": "adjuvar",
    "adjuvará": "adjuvar",
    "adjuvarás": "adjuvar",
    "adjuvarão": "adjuvar",
    "adjuvaríamos": "adjuvar",
    "adjuvaríeis": "adjuvar",
    "adjuvas": "adjuvar",
    "adjuvasse": "adjuvar",
    "adjuvassem": "adjuvar",
    "adjuvasses": "adjuvar",
    "adjuvaste": "adjuvar",
    "adjuvastes": "adjuvar",
    "adjuvava": "adjuvar",
    "adjuvavam": "adjuvar",
    "adjuvavas": "adjuvar",
    "adjuve": "adjuvar",
    "adjuvei": "adjuvar",
    "adjuveis": "adjuvar",
    "adjuvem": "adjuvar",
    "adjuvemo": "adjuvar",
    "adjuvemos": "adjuvar",
    "adjuves": "adjuvar",
    "adjuvo": "adjuvar",
    "adjuvou": "adjuvar",
    "adjuvá": "adjuvar",
    "adjuvámo": "adjuvar",
    "adjuvámos": "adjuvar",
    "adjuváramo": "adjuvar",
    "adjuváramos": "adjuvar",
    "adjuvárei": "adjuvar",
    "adjuváreis": "adjuvar",
    "adjuvásseis": "adjuvar",
    "adjuvássemos": "adjuvar",
    "adjuvávamo": "adjuvar",
    "adjuvávamos": "adjuvar",
    "adjuvávei": "adjuvar",
    "adjuváveis": "adjuvar",
    "adlegações": "adlegação",
    "adminiculares": "adminicular",
    "administra": "administrar",
    "administrada": "administrar",
    "administradas": "administrar",
    "administrado": "administrar",
    "administradora": "administrador",
    "administradoras": "administrador",
    "administradores": "administrador",
    "administrados": "administrar",
    "administrai": "administrar",
    "administrais": "administrar",
    "administram": "administrar",
    "administramo": "administrar",
    "administramos": "administrar",
    "administrando": "administrar",
    "administrantes": "administrante",
    "administrara": "administrar",
    "administraram": "administrar",
    "administraras": "administrar",
    "administrarde": "administrar",
    "administrardes": "administrar",
    "administrare": "administrar",
    "administrarei": "administrar",
    "administrareis": "administrar",
    "administrarem": "administrar",
    "administraremos": "administrar",
    "administrares": "administrar",
    "administraria": "administrar",
    "administrariam": "administrar",
    "administrarias": "administrar",
    "administrarmo": "administrar",
    "administrarmos": "administrar",
    "administrará": "administrar",
    "administrarás": "administrar",
    "administrarão": "administrar",
    "administraríamos": "administrar",
    "administraríeis": "administrar",
    "administras": "administrar",
    "administrasse": "administrar",
    "administrassem": "administrar",
    "administrasses": "administrar",
    "administraste": "administrar",
    "administrastes": "administrar",
    "administrativa": "administrativo",
    "administrativas": "administrativo",
    "administrativos": "administrativo",
    "administrava": "administrar",
    "administravam": "administrar",
    "administravas": "administrar",
    "administrações": "administração",
    "administre": "administrar",
    "administrei": "administrar",
    "administreis": "administrar",
    "administrem": "administrar",
    "administremo": "administrar",
    "administremos": "administrar",
    "administres": "administrar",
    "administro": "administrar",
    "administrou": "administrar",
    "administrá": "administrar",
    "administrámo": "administrar",
    "administrámos": "administrar",
    "administráramo": "administrar",
    "administráramos": "administrar",
    "administrárei": "administrar",
    "administráreis": "administrar",
    "administrásseis": "administrar",
    "administrássemos": "administrar",
    "administrávamo": "administrar",
    "administrávamos": "administrar",
    "administrávei": "administrar",
    "administráveis": "administrável",
    "adminículos": "adminículo",
    "admira": "admirar",
    "admirabilidades": "admirabilidade",
    "admirada": "admirar",
    "admiradas": "admirar",
    "admirado": "admirar",
    "admiradora": "admirador",
    "admiradoras": "admirador",
    "admiradores": "admirador",
    "admirados": "admirar",
    "admiradíssima": "admirado",
    "admiradíssimas": "admirado",
    "admiradíssimo": "admirado",
    "admiradíssimos": "admirado",
    "admirai": "admirar",
    "admirais": "admirar",
    "admiram": "admirar",
    "admiramo": "admirar",
    "admiramos": "admirar",
    "admiranda": "admirando",
    "admirandas": "admirando",
    "admirando": "admirar",
    "admirandos": "admirando",
    "admirara": "admirar",
    "admiraram": "admirar",
    "admiraras": "admirar",
    "admirarde": "admirar",
    "admirardes": "admirar",
    "admirare": "admirar",
    "admirarei": "admirar",
    "admirareis": "admirar",
    "admirarem": "admirar",
    "admiraremos": "admirar",
    "admirares": "admirar",
    "admiraria": "admirar",
    "admirariam": "admirar",
    "admirarias": "admirar",
    "admirarmo": "admirar",
    "admirarmos": "admirar",
    "admirará": "admirar",
    "admirarás": "admirar",
    "admirarão": "admirar",
    "admiraríamos": "admirar",
    "admiraríeis": "admirar",
    "admiras": "admirar",
    "admirasse": "admirar",
    "admirassem": "admirar",
    "admirasses": "admirar",
    "admiraste": "admirar",
    "admirastes": "admirar",
    "admirativa": "admirativo",
    "admirativas": "admirativo",
    "admirativos": "admirativo",
    "admirava": "admirar",
    "admiravam": "admirar",
    "admiravas": "admirar",
    "admirações": "admiração",
    "admire": "admirar",
    "admirei": "admirar",
    "admireis": "admirar",
    "admirem": "admirar",
    "admiremo": "admirar",
    "admiremos": "admirar",
    "admires": "admirar",
    "admiro": "admirar",
    "admirou": "admirar",
    "admirá": "admirar",
    "admirámo": "admirar",
    "admirámos": "admirar",
    "admiráramo": "admirar",
    "admiráramos": "admirar",
    "admirárei": "admirar",
    "admiráreis": "admirar",
    "admirásseis": "admirar",
    "admirássemos": "admirar",
    "admirávamo": "admirar",
    "admirávamos": "admirar",
    "admirávei": "admirar",
    "admiráveis": "admirável",
    "admissibilidades": "admissibilidade",
    "admissíveis": "admissível",
    "admissões": "admissão",
    "admita": "admitir",
    "admitais": "admitir",
    "admitam": "admitir",
    "admitamo": "admitir",
    "admitamos": "admitir",
    "admitas": "admitir",
    "admite": "admitir",
    "admitem": "admitir",
    "admites": "admitir",
    "admiti": "admitir",
    "admitia": "admitir",
    "admitiam": "admitir",
    "admitias": "admitir",
    "admitida": "admitir",
    "admitidas": "admitir",
    "admitido": "admitir",
    "admitidos": "admitir",
    "admitimo": "admitir",
    "admitimos": "admitir",
    "admitindo": "admitir",
    "admitira": "admitir",
    "admitiram": "admitir",
    "admitiras": "admitir",
    "admitirde": "admitir",
    "admitirdes": "admitir",
    "admitire": "admitir",
    "admitirei": "admitir",
    "admitireis": "admitir",
    "admitirem": "admitir",
    "admitiremos": "admitir",
    "admitires": "admitir",
    "admitiria": "admitir",
    "admitiriam": "admitir",
    "admitirias": "admitir",
    "admitirmo": "admitir",
    "admitirmos": "admitir",
    "admitirá": "admitir",
    "admitirás": "admitir",
    "admitirão": "admitir",
    "admitiríamos": "admitir",
    "admitiríeis": "admitir",
    "admitis": "admitir",
    "admitisse": "admitir",
    "admitissem": "admitir",
    "admitisses": "admitir",
    "admitiste": "admitir",
    "admitistes": "admitir",
    "admitiu": "admitir",
    "admito": "admitir",
    "admitâncias": "admitância",
    "admitíamo": "admitir",
    "admitíamos": "admitir",
    "admitíei": "admitir",
    "admitíeis": "admitir",
    "admitíramo": "admitir",
    "admitíramos": "admitir",
    "admitírei": "admitir",
    "admitíreis": "admitir",
    "admitísseis": "admitir",
    "admitíssemos": "admitir",
    "admoesta": "admoestar",
    "admoestada": "admoestar",
    "admoestadas": "admoestar",
    "admoestado": "admoestar",
    "admoestadora": "admoestador",
    "admoestadoras": "admoestador",
    "admoestadores": "admoestador",
    "admoestados": "admoestar",
    "admoestai": "admoestar",
    "admoestais": "admoestar",
    "admoestam": "admoestar",
    "admoestamo": "admoestar",
    "admoestamos": "admoestar",
    "admoestando": "admoestar",
    "admoestara": "admoestar",
    "admoestaram": "admoestar",
    "admoestaras": "admoestar",
    "admoestarde": "admoestar",
    "admoestardes": "admoestar",
    "admoestare": "admoestar",
    "admoestarei": "admoestar",
    "admoestareis": "admoestar",
    "admoestarem": "admoestar",
    "admoestaremos": "admoestar",
    "admoestares": "admoestar",
    "admoestaria": "admoestar",
    "admoestariam": "admoestar",
    "admoestarias": "admoestar",
    "admoestarmo": "admoestar",
    "admoestarmos": "admoestar",
    "admoestará": "admoestar",
    "admoestarás": "admoestar",
    "admoestarão": "admoestar",
    "admoestaríamos": "admoestar",
    "admoestaríeis": "admoestar",
    "admoestas": "admoestar",
    "admoestasse": "admoestar",
    "admoestassem": "admoestar",
    "admoestasses": "admoestar",
    "admoestaste": "admoestar",
    "admoestastes": "admoestar",
    "admoestatória": "admoestatório",
    "admoestatórias": "admoestatório",
    "admoestatórios": "admoestatório",
    "admoestava": "admoestar",
    "admoestavam": "admoestar",
    "admoestavas": "admoestar",
    "admoestações": "admoestação",
    "admoeste": "admoestar",
    "admoestei": "admoestar",
    "admoesteis": "admoestar",
    "admoestem": "admoestar",
    "admoestemo": "admoestar",
    "admoestemos": "admoestar",
    "admoestes": "admoestar",
    "admoesto": "admoestar",
    "admoestou": "admoestar",
    "admoestá": "admoestar",
    "admoestámo": "admoestar",
    "admoestámos": "admoestar",
    "admoestáramo": "admoestar",
    "admoestáramos": "admoestar",
    "admoestárei": "admoestar",
    "admoestáreis": "admoestar",
    "admoestásseis": "admoestar",
    "admoestássemos": "admoestar",
    "admoestávamo": "admoestar",
    "admoestávamos": "admoestar",
    "admoestávei": "admoestar",
    "admoestáveis": "admoestar",
    "admonitora": "admonitor",
    "admonitoras": "admonitor",
    "admonitores": "admonitor",
    "admonitória": "admonitório",
    "admonitórias": "admonitório",
    "admonitórios": "admonitório",
    "admonições": "admonição",
    "adnata": "adnato",
    "adnatas": "adnato",
    "adnatos": "adnato",
    "adnominais": "adnominal",
    "adnominações": "adnominação",
    "adnotações": "adnotação",
    "ado": "adir",
    "adoba": "adobar",
    "adobada": "adobar",
    "adobadas": "adobar",
    "adobado": "adobar",
    "adobados": "adobar",
    "adobai": "adobar",
    "adobais": "adobar",
    "adobam": "adobar",
    "adobamo": "adobar",
    "adobamos": "adobar",
    "adobando": "adobar",
    "adobara": "adobar",
    "adobaram": "adobar",
    "adobaras": "adobar",
    "adobardes": "adobar",
    "adobarei": "adobar",
    "adobareis": "adobar",
    "adobarem": "adobar",
    "adobaremos": "adobar",
    "adobares": "adobar",
    "adobaria": "adobar",
    "adobariam": "adobar",
    "adobarias": "adobar",
    "adobarmo": "adobar",
    "adobarmos": "adobar",
    "adobará": "adobar",
    "adobarás": "adobar",
    "adobarão": "adobar",
    "adobaríamos": "adobar",
    "adobaríeis": "adobar",
    "adobas": "adobar",
    "adobasse": "adobar",
    "adobassem": "adobar",
    "adobasses": "adobar",
    "adobaste": "adobar",
    "adobastes": "adobar",
    "adobava": "adobar",
    "adobavam": "adobar",
    "adobavas": "adobar",
    "adobe": "adobar",
    "adobei": "adobar",
    "adobeiras": "adobeira",
    "adobeis": "adobar",
    "adobem": "adobar",
    "adobemo": "adobar",
    "adobemos": "adobar",
    "adobes": "adobe",
    "adobo": "adobar",
    "adobos": "adobo",
    "adobou": "adobar",
    "adobámo": "adobar",
    "adobámos": "adobar",
    "adobáramo": "adobar",
    "adobáramos": "adobar",
    "adobáreis": "adobar",
    "adobásseis": "adobar",
    "adobássemos": "adobar",
    "adobávamo": "adobar",
    "adobávamos": "adobar",
    "adobáveis": "adobar",
    "adoce": "adoçar",
    "adocei": "adoçar",
    "adoceis": "adoçar",
    "adocem": "adoçar",
    "adocemo": "adoçar",
    "adocemos": "adoçar",
    "adoces": "adoçar",
    "adocica": "adocicar",
    "adocicada": "adocicar",
    "adocicadas": "adocicar",
    "adocicado": "adocicar",
    "adocicados": "adocicar",
    "adocicai": "adocicar",
    "adocicais": "adocicar",
    "adocicam": "adocicar",
    "adocicamo": "adocicar",
    "adocicamos": "adocicar",
    "adocicando": "adocicar",
    "adocicara": "adocicar",
    "adocicaram": "adocicar",
    "adocicaras": "adocicar",
    "adocicarde": "adocicar",
    "adocicardes": "adocicar",
    "adocicare": "adocicar",
    "adocicarei": "adocicar",
    "adocicareis": "adocicar",
    "adocicarem": "adocicar",
    "adocicaremos": "adocicar",
    "adocicares": "adocicar",
    "adocicaria": "adocicar",
    "adocicariam": "adocicar",
    "adocicarias": "adocicar",
    "adocicarmo": "adocicar",
    "adocicarmos": "adocicar",
    "adocicará": "adocicar",
    "adocicarás": "adocicar",
    "adocicarão": "adocicar",
    "adocicaríamos": "adocicar",
    "adocicaríeis": "adocicar",
    "adocicas": "adocicar",
    "adocicasse": "adocicar",
    "adocicassem": "adocicar",
    "adocicasses": "adocicar",
    "adocicaste": "adocicar",
    "adocicastes": "adocicar",
    "adocicava": "adocicar",
    "adocicavam": "adocicar",
    "adocicavas": "adocicar",
    "adocico": "adocicar",
    "adocicou": "adocicar",
    "adocicá": "adocicar",
    "adocicámo": "adocicar",
    "adocicámos": "adocicar",
    "adocicáramo": "adocicar",
    "adocicáramos": "adocicar",
    "adocicárei": "adocicar",
    "adocicáreis": "adocicar",
    "adocicásseis": "adocicar",
    "adocicássemos": "adocicar",
    "adocicávamo": "adocicar",
    "adocicávamos": "adocicar",
    "adocicávei": "adocicar",
    "adocicáveis": "adocicar",
    "adocique": "adocicar",
    "adociquei": "adocicar",
    "adociqueis": "adocicar",
    "adociquem": "adocicar",
    "adociquemo": "adocicar",
    "adociquemos": "adocicar",
    "adociques": "adocicar",
    "adoece": "adoecer",
    "adoecei": "adoecer",
    "adoeceis": "adoecer",
    "adoecem": "adoecer",
    "adoecemo": "adoecer",
    "adoecemos": "adoecer",
    "adoecendo": "adoecer",
    "adoecera": "adoecer",
    "adoeceram": "adoecer",
    "adoeceras": "adoecer",
    "adoecerde": "adoecer",
    "adoecerdes": "adoecer",
    "adoecere": "adoecer",
    "adoecerei": "adoecer",
    "adoecereis": "adoecer",
    "adoecerem": "adoecer",
    "adoeceremos": "adoecer",
    "adoeceres": "adoecer",
    "adoeceria": "adoecer",
    "adoeceriam": "adoecer",
    "adoecerias": "adoecer",
    "adoecermo": "adoecer",
    "adoecermos": "adoecer",
    "adoecerá": "adoecer",
    "adoecerás": "adoecer",
    "adoecerão": "adoecer",
    "adoeceríamos": "adoecer",
    "adoeceríeis": "adoecer",
    "adoeces": "adoecer",
    "adoecesse": "adoecer",
    "adoecessem": "adoecer",
    "adoecesses": "adoecer",
    "adoeceste": "adoecer",
    "adoecestes": "adoecer",
    "adoeceu": "adoecer",
    "adoeci": "adoecer",
    "adoecia": "adoecer",
    "adoeciam": "adoecer",
    "adoecias": "adoecer",
    "adoecida": "adoecer",
    "adoecidas": "adoecer",
    "adoecido": "adoecer",
    "adoecidos": "adoecer",
    "adoecimentos": "adoecimento",
    "adoecê": "adoecer",
    "adoecêramo": "adoecer",
    "adoecêramos": "adoecer",
    "adoecêrei": "adoecer",
    "adoecêreis": "adoecer",
    "adoecêsseis": "adoecer",
    "adoecêssemos": "adoecer",
    "adoecíamo": "adoecer",
    "adoecíamos": "adoecer",
    "adoecíei": "adoecer",
    "adoecíeis": "adoecer",
    "adoenta": "adoentar",
    "adoentada": "adoentar",
    "adoentadas": "adoentar",
    "adoentadinha": "adoentado",
    "adoentadinhas": "adoentado",
    "adoentadinho": "adoentado",
    "adoentadinhos": "adoentado",
    "adoentadita": "adoentado",
    "adoentaditas": "adoentado",
    "adoentadito": "adoentado",
    "adoentaditos": "adoentado",
    "adoentado": "adoentar",
    "adoentados": "adoentar",
    "adoentadíssima": "adoentado",
    "adoentadíssimas": "adoentado",
    "adoentadíssimo": "adoentado",
    "adoentadíssimos": "adoentado",
    "adoentai": "adoentar",
    "adoentais": "adoentar",
    "adoentam": "adoentar",
    "adoentamo": "adoentar",
    "adoentamos": "adoentar",
    "adoentando": "adoentar",
    "adoentara": "adoentar",
    "adoentaram": "adoentar",
    "adoentaras": "adoentar",
    "adoentarde": "adoentar",
    "adoentardes": "adoentar",
    "adoentare": "adoentar",
    "adoentarei": "adoentar",
    "adoentareis": "adoentar",
    "adoentarem": "adoentar",
    "adoentaremos": "adoentar",
    "adoentares": "adoentar",
    "adoentaria": "adoentar",
    "adoentariam": "adoentar",
    "adoentarias": "adoentar",
    "adoentarmo": "adoentar",
    "adoentarmos": "adoentar",
    "adoentará": "adoentar",
    "adoentarás": "adoentar",
    "adoentarão": "adoentar",
    "adoentaríamos": "adoentar",
    "adoentaríeis": "adoentar",
    "adoentas": "adoentar",
    "adoentasse": "adoentar",
    "adoentassem": "adoentar",
    "adoentasses": "adoentar",
    "adoentaste": "adoentar",
    "adoentastes": "adoentar",
    "adoentava": "adoentar",
    "adoentavam": "adoentar",
    "adoentavas": "adoentar",
    "adoente": "adoentar",
    "adoentei": "adoentar",
    "adoenteis": "adoentar",
    "adoentem": "adoentar",
    "adoentemo": "adoentar",
    "adoentemos": "adoentar",
    "adoentes": "adoentar",
    "adoento": "adoentar",
    "adoentou": "adoentar",
    "adoentá": "adoentar",
    "adoentámo": "adoentar",
    "adoentámos": "adoentar",
    "adoentáramo": "adoentar",
    "adoentáramos": "adoentar",
    "adoentárei": "adoentar",
    "adoentáreis": "adoentar",
    "adoentásseis": "adoentar",
    "adoentássemos": "adoentar",
    "adoentávamo": "adoentar",
    "adoentávamos": "adoentar",
    "adoentávei": "adoentar",
    "adoentáveis": "adoentar",
    "adoesta": "adoestar",
    "adoestada": "adoestar",
    "adoestadas": "adoestar",
    "adoestado": "adoestar",
    "adoestados": "adoestar",
    "adoestai": "adoestar",
    "adoestais": "adoestar",
    "adoestam": "adoestar",
    "adoestamo": "adoestar",
    "adoestamos": "adoestar",
    "adoestando": "adoestar",
    "adoestara": "adoestar",
    "adoestaram": "adoestar",
    "adoestaras": "adoestar",
    "adoestarde": "adoestar",
    "adoestardes": "adoestar",
    "adoestare": "adoestar",
    "adoestarei": "adoestar",
    "adoestareis": "adoestar",
    "adoestarem": "adoestar",
    "adoestaremos": "adoestar",
    "adoestares": "adoestar",
    "adoestaria": "adoestar",
    "adoestariam": "adoestar",
    "adoestarias": "adoestar",
    "adoestarmo": "adoestar",
    "adoestarmos": "adoestar",
    "adoestará": "adoestar",
    "adoestarás": "adoestar",
    "adoestarão": "adoestar",
    "adoestaríamos": "adoestar",
    "adoestaríeis": "adoestar",
    "adoestas": "adoestar",
    "adoestasse": "adoestar",
    "adoestassem": "adoestar",
    "adoestasses": "adoestar",
    "adoestaste": "adoestar",
    "adoestastes": "adoestar",
    "adoestava": "adoestar",
    "adoestavam": "adoestar",
    "adoestavas": "adoestar",
    "adoeste": "adoestar",
    "adoestei": "adoestar",
    "adoesteis": "adoestar",
    "adoestem": "adoestar",
    "adoestemo": "adoestar",
    "adoestemos": "adoestar",
    "adoestes": "adoestar",
    "adoesto": "adoestar",
    "adoestou": "adoestar",
    "adoestá": "adoestar",
    "adoestámo": "adoestar",
    "adoestámos": "adoestar",
    "adoestáramo": "adoestar",
    "adoestáramos": "adoestar",
    "adoestárei": "adoestar",
    "adoestáreis": "adoestar",
    "adoestásseis": "adoestar",
    "adoestássemos": "adoestar",
    "adoestávamo": "adoestar",
    "adoestávamos": "adoestar",
    "adoestávei": "adoestar",
    "adoestáveis": "adoestar",
    "adoeça": "adoecer",
    "adoeçais": "adoecer",
    "adoeçam": "adoecer",
    "adoeçamo": "adoecer",
    "adoeçamos": "adoecer",
    "adoeças": "adoecer",
    "adoeço": "adoecer",
    "adoida": "adoidar",
    "adoidada": "adoidar",
    "adoidadas": "adoidar",
    "adoidado": "adoidar",
    "adoidados": "adoidar",
    "adoidai": "adoidar",
    "adoidais": "adoidar",
    "adoidam": "adoidar",
    "adoidamo": "adoidar",
    "adoidamos": "adoidar",
    "adoidando": "adoidar",
    "adoidara": "adoidar",
    "adoidaram": "adoidar",
    "adoidaras": "adoidar",
    "adoidarde": "adoidar",
    "adoidardes": "adoidar",
    "adoidare": "adoidar",
    "adoidarei": "adoidar",
    "adoidareis": "adoidar",
    "adoidarem": "adoidar",
    "adoidaremos": "adoidar",
    "adoidares": "adoidar",
    "adoidaria": "adoidar",
    "adoidariam": "adoidar",
    "adoidarias": "adoidar",
    "adoidarmo": "adoidar",
    "adoidarmos": "adoidar",
    "adoidará": "adoidar",
    "adoidarás": "adoidar",
    "adoidarão": "adoidar",
    "adoidaríamos": "adoidar",
    "adoidaríeis": "adoidar",
    "adoidas": "adoidar",
    "adoidasse": "adoidar",
    "adoidassem": "adoidar",
    "adoidasses": "adoidar",
    "adoidaste": "adoidar",
    "adoidastes": "adoidar",
    "adoidava": "adoidar",
    "adoidavam": "adoidar",
    "adoidavas": "adoidar",
    "adoide": "adoidar",
    "adoidei": "adoidar",
    "adoideis": "adoidar",
    "adoidem": "adoidar",
    "adoidemo": "adoidar",
    "adoidemos": "adoidar",
    "adoides": "adoidar",
    "adoido": "adoidar",
    "adoidou": "adoidar",
    "adoidá": "adoidar",
    "adoidámo": "adoidar",
    "adoidámos": "adoidar",
    "adoidáramo": "adoidar",
    "adoidáramos": "adoidar",
    "adoidárei": "adoidar",
    "adoidáreis": "adoidar",
    "adoidásseis": "adoidar",
    "adoidássemos": "adoidar",
    "adoidávamo": "adoidar",
    "adoidávamos": "adoidar",
    "adoidávei": "adoidar",
    "adoidáveis": "adoidar",
    "adolesce": "adolescer",
    "adolescei": "adolescer",
    "adolesceis": "adolescer",
    "adolescem": "adolescer",
    "adolescemo": "adolescer",
    "adolescemos": "adolescer",
    "adolescendo": "adolescer",
    "adolescentes": "adolescente",
    "adolescera": "adolescer",
    "adolesceram": "adolescer",
    "adolesceras": "adolescer",
    "adolescerde": "adolescer",
    "adolescerdes": "adolescer",
    "adolescere": "adolescer",
    "adolescerei": "adolescer",
    "adolescereis": "adolescer",
    "adolescerem": "adolescer",
    "adolesceremos": "adolescer",
    "adolesceres": "adolescer",
    "adolesceria": "adolescer",
    "adolesceriam": "adolescer",
    "adolescerias": "adolescer",
    "adolescermo": "adolescer",
    "adolescermos": "adolescer",
    "adolescerá": "adolescer",
    "adolescerás": "adolescer",
    "adolescerão": "adolescer",
    "adolesceríamos": "adolescer",
    "adolesceríeis": "adolescer",
    "adolesces": "adolescer",
    "adolescesse": "adolescer",
    "adolescessem": "adolescer",
    "adolescesses": "adolescer",
    "adolesceste": "adolescer",
    "adolescestes": "adolescer",
    "adolesceu": "adolescer",
    "adolesci": "adolescer",
    "adolescia": "adolescer",
    "adolesciam": "adolescer",
    "adolescias": "adolescer",
    "adolescida": "adolescer",
    "adolescidas": "adolescer",
    "adolescido": "adolescer",
    "adolescidos": "adolescer",
    "adolescê": "adolescer",
    "adolescências": "adolescência",
    "adolescêramo": "adolescer",
    "adolescêramos": "adolescer",
    "adolescêrei": "adolescer",
    "adolescêreis": "adolescer",
    "adolescêsseis": "adolescer",
    "adolescêssemos": "adolescer",
    "adolescíamo": "adolescer",
    "adolescíamos": "adolescer",
    "adolescíei": "adolescer",
    "adolescíeis": "adolescer",
    "adolesça": "adolescer",
    "adolesçais": "adolescer",
    "adolesçam": "adolescer",
    "adolesçamo": "adolescer",
    "adolesçamos": "adolescer",
    "adolesças": "adolescer",
    "adolesço": "adolescer",
    "adolos": "adolo",
    "adominga": "adomingar",
    "adomingada": "adomingar",
    "adomingadas": "adomingar",
    "adomingado": "adomingar",
    "adomingados": "adomingar",
    "adomingai": "adomingar",
    "adomingais": "adomingar",
    "adomingam": "adomingar",
    "adomingamo": "adomingar",
    "adomingamos": "adomingar",
    "adomingando": "adomingar",
    "adomingara": "adomingar",
    "adomingaram": "adomingar",
    "adomingaras": "adomingar",
    "adomingarde": "adomingar",
    "adomingardes": "adomingar",
    "adomingare": "adomingar",
    "adomingarei": "adomingar",
    "adomingareis": "adomingar",
    "adomingarem": "adomingar",
    "adomingaremos": "adomingar",
    "adomingares": "adomingar",
    "adomingaria": "adomingar",
    "adomingariam": "adomingar",
    "adomingarias": "adomingar",
    "adomingarmo": "adomingar",
    "adomingarmos": "adomingar",
    "adomingará": "adomingar",
    "adomingarás": "adomingar",
    "adomingarão": "adomingar",
    "adomingaríamos": "adomingar",
    "adomingaríeis": "adomingar",
    "adomingas": "adomingar",
    "adomingasse": "adomingar",
    "adomingassem": "adomingar",
    "adomingasses": "adomingar",
    "adomingaste": "adomingar",
    "adomingastes": "adomingar",
    "adomingava": "adomingar",
    "adomingavam": "adomingar",
    "adomingavas": "adomingar",
    "adomingo": "adomingar",
    "adomingou": "adomingar",
    "adomingue": "adomingar",
    "adominguei": "adomingar",
    "adomingueis": "adomingar",
    "adominguem": "adomingar",
    "adominguemo": "adomingar",
    "adominguemos": "adomingar",
    "adomingues": "adomingar",
    "adomingá": "adomingar",
    "adomingámo": "adomingar",
    "adomingámos": "adomingar",
    "adomingáramo": "adomingar",
    "adomingáramos": "adomingar",
    "adomingárei": "adomingar",
    "adomingáreis": "adomingar",
    "adomingásseis": "adomingar",
    "adomingássemos": "adomingar",
    "adomingávamo": "adomingar",
    "adomingávamos": "adomingar",
    "adomingávei": "adomingar",
    "adomingáveis": "adomingar",
    "adonaira": "adonairar",
    "adonairada": "adonairar",
    "adonairadas": "adonairar",
    "adonairado": "adonairar",
    "adonairados": "adonairar",
    "adonairai": "adonairar",
    "adonairais": "adonairar",
    "adonairam": "adonairar",
    "adonairamo": "adonairar",
    "adonairamos": "adonairar",
    "adonairando": "adonairar",
    "adonairara": "adonairar",
    "adonairaram": "adonairar",
    "adonairaras": "adonairar",
    "adonairarde": "adonairar",
    "adonairardes": "adonairar",
    "adonairare": "adonairar",
    "adonairarei": "adonairar",
    "adonairareis": "adonairar",
    "adonairarem": "adonairar",
    "adonairaremos": "adonairar",
    "adonairares": "adonairar",
    "adonairaria": "adonairar",
    "adonairariam": "adonairar",
    "adonairarias": "adonairar",
    "adonairarmo": "adonairar",
    "adonairarmos": "adonairar",
    "adonairará": "adonairar",
    "adonairarás": "adonairar",
    "adonairarão": "adonairar",
    "adonairaríamos": "adonairar",
    "adonairaríeis": "adonairar",
    "adonairas": "adonairar",
    "adonairasse": "adonairar",
    "adonairassem": "adonairar",
    "adonairasses": "adonairar",
    "adonairaste": "adonairar",
    "adonairastes": "adonairar",
    "adonairava": "adonairar",
    "adonairavam": "adonairar",
    "adonairavas": "adonairar",
    "adonaire": "adonairar",
    "adonairei": "adonairar",
    "adonaireis": "adonairar",
    "adonairem": "adonairar",
    "adonairemo": "adonairar",
    "adonairemos": "adonairar",
    "adonaires": "adonairar",
    "adonairo": "adonairar",
    "adonairou": "adonairar",
    "adonairá": "adonairar",
    "adonairámo": "adonairar",
    "adonairámos": "adonairar",
    "adonairáramo": "adonairar",
    "adonairáramos": "adonairar",
    "adonairárei": "adonairar",
    "adonairáreis": "adonairar",
    "adonairásseis": "adonairar",
    "adonairássemos": "adonairar",
    "adonairávamo": "adonairar",
    "adonairávamos": "adonairar",
    "adonairávei": "adonairar",
    "adonairáveis": "adonairar",
    "adonisa": "adonisar",
    "adonisada": "adonisar",
    "adonisadas": "adonisar",
    "adonisado": "adonisar",
    "adonisados": "adonisar",
    "adonisai": "adonisar",
    "adonisais": "adonisar",
    "adonisam": "adonisar",
    "adonisamo": "adonisar",
    "adonisamos": "adonisar",
    "adonisando": "adonisar",
    "adonisara": "adonisar",
    "adonisaram": "adonisar",
    "adonisaras": "adonisar",
    "adonisarde": "adonisar",
    "adonisardes": "adonisar",
    "adonisare": "adonisar",
    "adonisarei": "adonisar",
    "adonisareis": "adonisar",
    "adonisarem": "adonisar",
    "adonisaremos": "adonisar",
    "adonisares": "adonisar",
    "adonisaria": "adonisar",
    "adonisariam": "adonisar",
    "adonisarias": "adonisar",
    "adonisarmo": "adonisar",
    "adonisarmos": "adonisar",
    "adonisará": "adonisar",
    "adonisarás": "adonisar",
    "adonisarão": "adonisar",
    "adonisaríamos": "adonisar",
    "adonisaríeis": "adonisar",
    "adonisas": "adonisar",
    "adonisasse": "adonisar",
    "adonisassem": "adonisar",
    "adonisasses": "adonisar",
    "adonisaste": "adonisar",
    "adonisastes": "adonisar",
    "adonisava": "adonisar",
    "adonisavam": "adonisar",
    "adonisavas": "adonisar",
    "adonise": "adonisar",
    "adonisei": "adonisar",
    "adoniseis": "adonisar",
    "adonisem": "adonisar",
    "adonisemo": "adonisar",
    "adonisemos": "adonisar",
    "adonises": "adonisar",
    "adonismos": "adonismo",
    "adoniso": "adonisar",
    "adonisou": "adonisar",
    "adonisá": "adonisar",
    "adonisámo": "adonisar",
    "adonisámos": "adonisar",
    "adonisáramo": "adonisar",
    "adonisáramos": "adonisar",
    "adonisárei": "adonisar",
    "adonisáreis": "adonisar",
    "adonisásseis": "adonisar",
    "adonisássemos": "adonisar",
    "adonisávamo": "adonisar",
    "adonisávamos": "adonisar",
    "adonisávei": "adonisar",
    "adonisáveis": "adonisar",
    "adopcionismos": "adopcionismo",
    "adopta": "adoptar",
    "adoptada": "adoptar",
    "adoptadas": "adoptar",
    "adoptado": "adoptar",
    "adoptados": "adoptar",
    "adoptai": "adoptar",
    "adoptais": "adoptar",
    "adoptam": "adoptar",
    "adoptamo": "adoptar",
    "adoptamos": "adoptar",
    "adoptanda": "adoptando",
    "adoptandas": "adoptando",
    "adoptando": "adoptar",
    "adoptandos": "adoptando",
    "adoptantes": "adoptante",
    "adoptara": "adoptar",
    "adoptaram": "adoptar",
    "adoptaras": "adoptar",
    "adoptarde": "adoptar",
    "adoptardes": "adoptar",
    "adoptare": "adoptar",
    "adoptarei": "adoptar",
    "adoptareis": "adoptar",
    "adoptarem": "adoptar",
    "adoptaremos": "adoptar",
    "adoptares": "adoptar",
    "adoptaria": "adoptar",
    "adoptariam": "adoptar",
    "adoptarias": "adoptar",
    "adoptarmo": "adoptar",
    "adoptarmos": "adoptar",
    "adoptará": "adoptar",
    "adoptarás": "adoptar",
    "adoptarão": "adoptar",
    "adoptaríamos": "adoptar",
    "adoptaríeis": "adoptar",
    "adoptas": "adoptar",
    "adoptasse": "adoptar",
    "adoptassem": "adoptar",
    "adoptasses": "adoptar",
    "adoptaste": "adoptar",
    "adoptastes": "adoptar",
    "adoptava": "adoptar",
    "adoptavam": "adoptar",
    "adoptavas": "adoptar",
    "adopte": "adoptar",
    "adoptei": "adoptar",
    "adopteis": "adoptar",
    "adoptem": "adoptar",
    "adoptemo": "adoptar",
    "adoptemos": "adoptar",
    "adoptes": "adoptar",
    "adoptiva": "adoptivo",
    "adoptivas": "adoptivo",
    "adoptivos": "adoptivo",
    "adopto": "adoptar",
    "adoptou": "adoptar",
    "adoptá": "adoptar",
    "adoptámo": "adoptar",
    "adoptámos": "adoptar",
    "adoptáramo": "adoptar",
    "adoptáramos": "adoptar",
    "adoptárei": "adoptar",
    "adoptáreis": "adoptar",
    "adoptásseis": "adoptar",
    "adoptássemos": "adoptar",
    "adoptávamo": "adoptar",
    "adoptávamos": "adoptar",
    "adoptávei": "adoptar",
    "adoptáveis": "adoptar",
    "adopções": "adopção",
    "adora": "adorar",
    "adorada": "adorar",
    "adoradas": "adorar",
    "adorado": "adorar",
    "adoradora": "adorador",
    "adoradoras": "adorador",
    "adoradores": "adorador",
    "adorados": "adorar",
    "adoradíssima": "adorado",
    "adoradíssimas": "adorado",
    "adoradíssimo": "adorado",
    "adoradíssimos": "adorado",
    "adorai": "adorar",
    "adorais": "adorar",
    "adoram": "adorar",
    "adoramo": "adorar",
    "adoramos": "adorar",
    "adorando": "adorar",
    "adorara": "adorar",
    "adoraram": "adorar",
    "adoraras": "adorar",
    "adorarde": "adorar",
    "adorardes": "adorar",
    "adorare": "adorar",
    "adorarei": "adorar",
    "adorareis": "adorar",
    "adorarem": "adorar",
    "adoraremos": "adorar",
    "adorares": "adorar",
    "adoraria": "adorar",
    "adorariam": "adorar",
    "adorarias": "adorar",
    "adorarmo": "adorar",
    "adorarmos": "adorar",
    "adorará": "adorar",
    "adorarás": "adorar",
    "adorarão": "adorar",
    "adoraríamos": "adorar",
    "adoraríeis": "adorar",
    "adoras": "adorar",
    "adorasse": "adorar",
    "adorassem": "adorar",
    "adorasses": "adorar",
    "adoraste": "adorar",
    "adorastes": "adorar",
    "adorava": "adorar",
    "adoravam": "adorar",
    "adoravas": "adorar",
    "adorações": "adoração",
    "adorbitais": "adorbital",
    "adore": "adorar",
    "adorei": "adorar",
    "adoreis": "adorar",
    "adorem": "adorar",
    "adoremo": "adorar",
    "adoremos": "adorar",
    "adores": "adorar",
    "adormece": "adormecer",
    "adormecedora": "adormecedor",
    "adormecedoras": "adormecedor",
    "adormecedores": "adormecedor",
    "adormecei": "adormecer",
    "adormeceis": "adormecer",
    "adormecem": "adormecer",
    "adormecemo": "adormecer",
    "adormecemos": "adormecer",
    "adormecendo": "adormecer",
    "adormecera": "adormecer",
    "adormeceram": "adormecer",
    "adormeceras": "adormecer",
    "adormecerde": "adormecer",
    "adormecerdes": "adormecer",
    "adormecere": "adormecer",
    "adormecerei": "adormecer",
    "adormecereis": "adormecer",
    "adormecerem": "adormecer",
    "adormeceremos": "adormecer",
    "adormeceres": "adormecer",
    "adormeceria": "adormecer",
    "adormeceriam": "adormecer",
    "adormecerias": "adormecer",
    "adormecermo": "adormecer",
    "adormecermos": "adormecer",
    "adormecerá": "adormecer",
    "adormecerás": "adormecer",
    "adormecerão": "adormecer",
    "adormeceríamos": "adormecer",
    "adormeceríeis": "adormecer",
    "adormeces": "adormecer",
    "adormecesse": "adormecer",
    "adormecessem": "adormecer",
    "adormecesses": "adormecer",
    "adormeceste": "adormecer",
    "adormecestes": "adormecer",
    "adormeceu": "adormecer",
    "adormeci": "adormecer",
    "adormecia": "adormecer",
    "adormeciam": "adormecer",
    "adormecias": "adormecer",
    "adormecida": "adormecido",
    "adormecidas": "adormecido",
    "adormecido": "adormecer",
    "adormecidos": "adormecido",
    "adormecidíssima": "adormecido",
    "adormecidíssimas": "adormecido",
    "adormecidíssimo": "adormecido",
    "adormecidíssimos": "adormecido",
    "adormecimentos": "adormecimento",
    "adormecê": "adormecer",
    "adormecêramo": "adormecer",
    "adormecêramos": "adormecer",
    "adormecêrei": "adormecer",
    "adormecêreis": "adormecer",
    "adormecêsseis": "adormecer",
    "adormecêssemos": "adormecer",
    "adormecíamo": "adormecer",
    "adormecíamos": "adormecer",
    "adormecíei": "adormecer",
    "adormecíeis": "adormecer",
    "adormenta": "adormentar",
    "adormentada": "adormentar",
    "adormentadas": "adormentar",
    "adormentado": "adormentar",
    "adormentadora": "adormentador",
    "adormentadoras": "adormentador",
    "adormentadores": "adormentador",
    "adormentados": "adormentar",
    "adormentai": "adormentar",
    "adormentais": "adormentar",
    "adormentam": "adormentar",
    "adormentamo": "adormentar",
    "adormentamos": "adormentar",
    "adormentando": "adormentar",
    "adormentara": "adormentar",
    "adormentaram": "adormentar",
    "adormentaras": "adormentar",
    "adormentarde": "adormentar",
    "adormentardes": "adormentar",
    "adormentare": "adormentar",
    "adormentarei": "adormentar",
    "adormentareis": "adormentar",
    "adormentarem": "adormentar",
    "adormentaremos": "adormentar",
    "adormentares": "adormentar",
    "adormentaria": "adormentar",
    "adormentariam": "adormentar",
    "adormentarias": "adormentar",
    "adormentarmo": "adormentar",
    "adormentarmos": "adormentar",
    "adormentará": "adormentar",
    "adormentarás": "adormentar",
    "adormentarão": "adormentar",
    "adormentaríamos": "adormentar",
    "adormentaríeis": "adormentar",
    "adormentas": "adormentar",
    "adormentasse": "adormentar",
    "adormentassem": "adormentar",
    "adormentasses": "adormentar",
    "adormentaste": "adormentar",
    "adormentastes": "adormentar",
    "adormentava": "adormentar",
    "adormentavam": "adormentar",
    "adormentavas": "adormentar",
    "adormente": "adormentar",
    "adormentei": "adormentar",
    "adormenteis": "adormentar",
    "adormentem": "adormentar",
    "adormentemo": "adormentar",
    "adormentemos": "adormentar",
    "adormentes": "adormentar",
    "adormento": "adormentar",
    "adormentou": "adormentar",
    "adormentá": "adormentar",
    "adormentámo": "adormentar",
    "adormentámos": "adormentar",
    "adormentáramo": "adormentar",
    "adormentáramos": "adormentar",
    "adormentárei": "adormentar",
    "adormentáreis": "adormentar",
    "adormentásseis": "adormentar",
    "adormentássemos": "adormentar",
    "adormentávamo": "adormentar",
    "adormentávamos": "adormentar",
    "adormentávei": "adormentar",
    "adormentáveis": "adormentar",
    "adormeça": "adormecer",
    "adormeçais": "adormecer",
    "adormeçam": "adormecer",
    "adormeçamo": "adormecer",
    "adormeçamos": "adormecer",
    "adormeças": "adormecer",
    "adormeço": "adormecer",
    "adorna": "adornar",
    "adornada": "adornar",
    "adornadas": "adornar",
    "adornado": "adornar",
    "adornados": "adornar",
    "adornai": "adornar",
    "adornais": "adornar",
    "adornam": "adornar",
    "adornamo": "adornar",
    "adornamos": "adornar",
    "adornando": "adornar",
    "adornara": "adornar",
    "adornaram": "adornar",
    "adornaras": "adornar",
    "adornarde": "adornar",
    "adornardes": "adornar",
    "adornare": "adornar",
    "adornarei": "adornar",
    "adornareis": "adornar",
    "adornarem": "adornar",
    "adornaremos": "adornar",
    "adornares": "adornar",
    "adornaria": "adornar",
    "adornariam": "adornar",
    "adornarias": "adornar",
    "adornarmo": "adornar",
    "adornarmos": "adornar",
    "adornará": "adornar",
    "adornarás": "adornar",
    "adornarão": "adornar",
    "adornaríamos": "adornar",
    "adornaríeis": "adornar",
    "adornas": "adornar",
    "adornasse": "adornar",
    "adornassem": "adornar",
    "adornasses": "adornar",
    "adornaste": "adornar",
    "adornastes": "adornar",
    "adornava": "adornar",
    "adornavam": "adornar",
    "adornavas": "adornar",
    "adorne": "adornar",
    "adornei": "adornar",
    "adorneis": "adornar",
    "adornem": "adornar",
    "adornemo": "adornar",
    "adornemos": "adornar",
    "adornes": "adornar",
    "adorno": "adornar",
    "adornos": "adorno",
    "adornou": "adornar",
    "adorná": "adornar",
    "adornámo": "adornar",
    "adornámos": "adornar",
    "adornáramo": "adornar",
    "adornáramos": "adornar",
    "adornárei": "adornar",
    "adornáreis": "adornar",
    "adornásseis": "adornar",
    "adornássemos": "adornar",
    "adornávamo": "adornar",
    "adornávamos": "adornar",
    "adornávei": "adornar",
    "adornáveis": "adornar",
    "adoro": "adorar",
    "adorou": "adorar",
    "adorá": "adorar",
    "adorámo": "adorar",
    "adorámos": "adorar",
    "adoráramo": "adorar",
    "adoráramos": "adorar",
    "adorárei": "adorar",
    "adoráreis": "adorar",
    "adorásseis": "adorar",
    "adorássemos": "adorar",
    "adorávamo": "adorar",
    "adorávamos": "adorar",
    "adorávei": "adorar",
    "adoráveis": "adorável",
    "adossada": "adossado",
    "adossadas": "adossado",
    "adossados": "adossado",
    "adosselada": "adosselado",
    "adosseladas": "adosselado",
    "adosselados": "adosselado",
    "adouda": "adoudar",
    "adoudada": "adoudar",
    "adoudadas": "adoudar",
    "adoudado": "adoudar",
    "adoudados": "adoudar",
    "adoudai": "adoudar",
    "adoudais": "adoudar",
    "adoudam": "adoudar",
    "adoudamo": "adoudar",
    "adoudamos": "adoudar",
    "adoudando": "adoudar",
    "adoudara": "adoudar",
    "adoudaram": "adoudar",
    "adoudaras": "adoudar",
    "adoudarde": "adoudar",
    "adoudardes": "adoudar",
    "adoudare": "adoudar",
    "adoudarei": "adoudar",
    "adoudareis": "adoudar",
    "adoudarem": "adoudar",
    "adoudaremos": "adoudar",
    "adoudares": "adoudar",
    "adoudaria": "adoudar",
    "adoudariam": "adoudar",
    "adoudarias": "adoudar",
    "adoudarmo": "adoudar",
    "adoudarmos": "adoudar",
    "adoudará": "adoudar",
    "adoudarás": "adoudar",
    "adoudarão": "adoudar",
    "adoudaríamos": "adoudar",
    "adoudaríeis": "adoudar",
    "adoudas": "adoudar",
    "adoudasse": "adoudar",
    "adoudassem": "adoudar",
    "adoudasses": "adoudar",
    "adoudaste": "adoudar",
    "adoudastes": "adoudar",
    "adoudava": "adoudar",
    "adoudavam": "adoudar",
    "adoudavas": "adoudar",
    "adoude": "adoudar",
    "adoudei": "adoudar",
    "adoudeis": "adoudar",
    "adoudem": "adoudar",
    "adoudemo": "adoudar",
    "adoudemos": "adoudar",
    "adoudes": "adoudar",
    "adoudo": "adoudar",
    "adoudou": "adoudar",
    "adoudá": "adoudar",
    "adoudámo": "adoudar",
    "adoudámos": "adoudar",
    "adoudáramo": "adoudar",
    "adoudáramos": "adoudar",
    "adoudárei": "adoudar",
    "adoudáreis": "adoudar",
    "adoudásseis": "adoudar",
    "adoudássemos": "adoudar",
    "adoudávamo": "adoudar",
    "adoudávamos": "adoudar",
    "adoudávei": "adoudar",
    "adoudáveis": "adoudar",
    "adoça": "adoçar",
    "adoçada": "adoçar",
    "adoçadas": "adoçar",
    "adoçado": "adoçar",
    "adoçados": "adoçar",
    "adoçai": "adoçar",
    "adoçais": "adoçar",
    "adoçam": "adoçar",
    "adoçamentos": "adoçamento",
    "adoçamo": "adoçar",
    "adoçamos": "adoçar",
    "adoçando": "adoçar",
    "adoçantes": "adoçante",
    "adoçara": "adoçar",
    "adoçaram": "adoçar",
    "adoçaras": "adoçar",
    "adoçarde": "adoçar",
    "adoçardes": "adoçar",
    "adoçare": "adoçar",
    "adoçarei": "adoçar",
    "adoçareis": "adoçar",
    "adoçarem": "adoçar",
    "adoçaremos": "adoçar",
    "adoçares": "adoçar",
    "adoçaria": "adoçar",
    "adoçariam": "adoçar",
    "adoçarias": "adoçar",
    "adoçarmo": "adoçar",
    "adoçarmos": "adoçar",
    "adoçará": "adoçar",
    "adoçarás": "adoçar",
    "adoçarão": "adoçar",
    "adoçaríamos": "adoçar",
    "adoçaríeis": "adoçar",
    "adoças": "adoçar",
    "adoçasse": "adoçar",
    "adoçassem": "adoçar",
    "adoçasses": "adoçar",
    "adoçaste": "adoçar",
    "adoçastes": "adoçar",
    "adoçava": "adoçar",
    "adoçavam": "adoçar",
    "adoçavas": "adoçar",
    "adoço": "adoçar",
    "adoçou": "adoçar",
    "adoçá": "adoçar",
    "adoçámo": "adoçar",
    "adoçámos": "adoçar",
    "adoçáramo": "adoçar",
    "adoçáramos": "adoçar",
    "adoçárei": "adoçar",
    "adoçáreis": "adoçar",
    "adoçásseis": "adoçar",
    "adoçássemos": "adoçar",
    "adoçávamo": "adoçar",
    "adoçávamos": "adoçar",
    "adoçávei": "adoçar",
    "adoçáveis": "adoçar",
    "adquira": "adquirir",
    "adquirais": "adquirir",
    "adquiram": "adquirir",
    "adquiramo": "adquirir",
    "adquiramos": "adquirir",
    "adquiras": "adquirir",
    "adquire": "adquirir",
    "adquirem": "adquirir",
    "adquirentes": "adquirente",
    "adquires": "adquirir",
    "adquiri": "adquirir",
    "adquiria": "adquirir",
    "adquiriam": "adquirir",
    "adquirias": "adquirir",
    "adquirida": "adquirir",
    "adquiridas": "adquirir",
    "adquirido": "adquirir",
    "adquiridora": "adquiridor",
    "adquiridoras": "adquiridor",
    "adquiridores": "adquiridor",
    "adquiridos": "adquirir",
    "adquirimo": "adquirir",
    "adquirimos": "adquirir",
    "adquirindo": "adquirir",
    "adquirira": "adquirir",
    "adquiriram": "adquirir",
    "adquiriras": "adquirir",
    "adquirirde": "adquirir",
    "adquirirdes": "adquirir",
    "adquirire": "adquirir",
    "adquirirei": "adquirir",
    "adquirireis": "adquirir",
    "adquirirem": "adquirir",
    "adquiriremos": "adquirir",
    "adquirires": "adquirir",
    "adquiriria": "adquirir",
    "adquiririam": "adquirir",
    "adquiririas": "adquirir",
    "adquirirmo": "adquirir",
    "adquirirmos": "adquirir",
    "adquirirá": "adquirir",
    "adquirirás": "adquirir",
    "adquirirão": "adquirir",
    "adquiriríamos": "adquirir",
    "adquiriríeis": "adquirir",
    "adquiris": "adquirir",
    "adquirisse": "adquirir",
    "adquirissem": "adquirir",
    "adquirisses": "adquirir",
    "adquiriste": "adquirir",
    "adquiristes": "adquirir",
    "adquiriu": "adquirir",
    "adquirições": "adquirição",
    "adquiro": "adquirir",
    "adquiríamo": "adquirir",
    "adquiríamos": "adquirir",
    "adquiríei": "adquirir",
    "adquiríeis": "adquirir",
    "adquiríramo": "adquirir",
    "adquiríramos": "adquirir",
    "adquirírei": "adquirir",
    "adquiríreis": "adquirir",
    "adquirísseis": "adquirir",
    "adquiríssemos": "adquirir",
    "adquiríveis": "adquirível",
    "adragantas": "adraganta",
    "adragantos": "adraganto",
    "adrastos": "adrasto",
    "adredes": "adrede",
    "adrega": "adregar",
    "adregada": "adregar",
    "adregadas": "adregar",
    "adregado": "adregar",
    "adregados": "adregar",
    "adregai": "adregar",
    "adregais": "adregar",
    "adregam": "adregar",
    "adregamo": "adregar",
    "adregamos": "adregar",
    "adregando": "adregar",
    "adregara": "adregar",
    "adregaram": "adregar",
    "adregaras": "adregar",
    "adregardes": "adregar",
    "adregarei": "adregar",
    "adregareis": "adregar",
    "adregarem": "adregar",
    "adregaremos": "adregar",
    "adregares": "adregar",
    "adregaria": "adregar",
    "adregariam": "adregar",
    "adregarias": "adregar",
    "adregarmo": "adregar",
    "adregarmos": "adregar",
    "adregará": "adregar",
    "adregarás": "adregar",
    "adregarão": "adregar",
    "adregaríamos": "adregar",
    "adregaríeis": "adregar",
    "adregas": "adregar",
    "adregasse": "adregar",
    "adregassem": "adregar",
    "adregasses": "adregar",
    "adregaste": "adregar",
    "adregastes": "adregar",
    "adregava": "adregar",
    "adregavam": "adregar",
    "adregavas": "adregar",
    "adrego": "adregar",
    "adregos": "adrego",
    "adregou": "adregar",
    "adregue": "adregar",
    "adreguei": "adregar",
    "adregueis": "adregar",
    "adreguem": "adregar",
    "adreguemo": "adregar",
    "adreguemos": "adregar",
    "adregues": "adregar",
    "adregámo": "adregar",
    "adregámos": "adregar",
    "adregáramo": "adregar",
    "adregáramos": "adregar",
    "adregáreis": "adregar",
    "adregásseis": "adregar",
    "adregássemos": "adregar",
    "adregávamo": "adregar",
    "adregávamos": "adregar",
    "adregáveis": "adregar",
    "adrenalinas": "adrenalina",
    "adrice": "adriçar",
    "adricei": "adriçar",
    "adriceis": "adriçar",
    "adricem": "adriçar",
    "adricemo": "adriçar",
    "adricemos": "adriçar",
    "adrices": "adriçar",
    "adriática": "adriático",
    "adriáticas": "adriático",
    "adriáticos": "adriático",
    "adriça": "adriçar",
    "adriçada": "adriçar",
    "adriçadas": "adriçar",
    "adriçado": "adriçar",
    "adriçados": "adriçar",
    "adriçai": "adriçar",
    "adriçais": "adriçar",
    "adriçam": "adriçar",
    "adriçamo": "adriçar",
    "adriçamos": "adriçar",
    "adriçando": "adriçar",
    "adriçara": "adriçar",
    "adriçaram": "adriçar",
    "adriçaras": "adriçar",
    "adriçarde": "adriçar",
    "adriçardes": "adriçar",
    "adriçare": "adriçar",
    "adriçarei": "adriçar",
    "adriçareis": "adriçar",
    "adriçarem": "adriçar",
    "adriçaremos": "adriçar",
    "adriçares": "adriçar",
    "adriçaria": "adriçar",
    "adriçariam": "adriçar",
    "adriçarias": "adriçar",
    "adriçarmo": "adriçar",
    "adriçarmos": "adriçar",
    "adriçará": "adriçar",
    "adriçarás": "adriçar",
    "adriçarão": "adriçar",
    "adriçaríamos": "adriçar",
    "adriçaríeis": "adriçar",
    "adriças": "adriçar",
    "adriçasse": "adriçar",
    "adriçassem": "adriçar",
    "adriçasses": "adriçar",
    "adriçaste": "adriçar",
    "adriçastes": "adriçar",
    "adriçava": "adriçar",
    "adriçavam": "adriçar",
    "adriçavas": "adriçar",
    "adriço": "adriçar",
    "adriçou": "adriçar",
    "adriçá": "adriçar",
    "adriçámo": "adriçar",
    "adriçámos": "adriçar",
    "adriçáramo": "adriçar",
    "adriçáramos": "adriçar",
    "adriçárei": "adriçar",
    "adriçáreis": "adriçar",
    "adriçásseis": "adriçar",
    "adriçássemos": "adriçar",
    "adriçávamo": "adriçar",
    "adriçávamos": "adriçar",
    "adriçávei": "adriçar",
    "adriçáveis": "adriçar",
    "adros": "adro",
    "adscreva": "adscrever",
    "adscrevais": "adscrever",
    "adscrevam": "adscrever",
    "adscrevamo": "adscrever",
    "adscrevamos": "adscrever",
    "adscrevas": "adscrever",
    "adscreve": "adscrever",
    "adscrevei": "adscrever",
    "adscreveis": "adscrever",
    "adscrevem": "adscrever",
    "adscrevemo": "adscrever",
    "adscrevemos": "adscrever",
    "adscrevendo": "adscrever",
    "adscrevera": "adscrever",
    "adscreveram": "adscrever",
    "adscreveras": "adscrever",
    "adscreverde": "adscrever",
    "adscreverdes": "adscrever",
    "adscrevere": "adscrever",
    "adscreverei": "adscrever",
    "adscrevereis": "adscrever",
    "adscreverem": "adscrever",
    "adscreveremos": "adscrever",
    "adscreveres": "adscrever",
    "adscreveria": "adscrever",
    "adscreveriam": "adscrever",
    "adscreverias": "adscrever",
    "adscrevermo": "adscrever",
    "adscrevermos": "adscrever",
    "adscreverá": "adscrever",
    "adscreverás": "adscrever",
    "adscreverão": "adscrever",
    "adscreveríamos": "adscrever",
    "adscreveríeis": "adscrever",
    "adscreves": "adscrever",
    "adscrevesse": "adscrever",
    "adscrevessem": "adscrever",
    "adscrevesses": "adscrever",
    "adscreveste": "adscrever",
    "adscrevestes": "adscrever",
    "adscreveu": "adscrever",
    "adscrevi": "adscrever",
    "adscrevia": "adscrever",
    "adscreviam": "adscrever",
    "adscrevias": "adscrever",
    "adscrevo": "adscrever",
    "adscrevê": "adscrever",
    "adscrevêramo": "adscrever",
    "adscrevêramos": "adscrever",
    "adscrevêrei": "adscrever",
    "adscrevêreis": "adscrever",
    "adscrevêsseis": "adscrever",
    "adscrevêssemos": "adscrever",
    "adscrevíamo": "adscrever",
    "adscrevíamos": "adscrever",
    "adscrevíei": "adscrever",
    "adscrevíeis": "adscrever",
    "adscrita": "adscrito",
    "adscritas": "adscrito",
    "adscrito": "adscrever",
    "adscritos": "adscrito",
    "adscritícia": "adscritício",
    "adscritícias": "adscritício",
    "adscritícios": "adscritício",
    "adscrições": "adscrição",
    "adsorva": "adsorver",
    "adsorvais": "adsorver",
    "adsorvam": "adsorver",
    "adsorvamo": "adsorver",
    "adsorvamos": "adsorver",
    "adsorvas": "adsorver",
    "adsorve": "adsorver",
    "adsorvei": "adsorver",
    "adsorveis": "adsorver",
    "adsorvem": "adsorver",
    "adsorvemo": "adsorver",
    "adsorvemos": "adsorver",
    "adsorvendo": "adsorver",
    "adsorventes": "adsorvente",
    "adsorvera": "adsorver",
    "adsorveram": "adsorver",
    "adsorveras": "adsorver",
    "adsorverde": "adsorver",
    "adsorverdes": "adsorver",
    "adsorvere": "adsorver",
    "adsorverei": "adsorver",
    "adsorvereis": "adsorver",
    "adsorverem": "adsorver",
    "adsorveremos": "adsorver",
    "adsorveres": "adsorver",
    "adsorveria": "adsorver",
    "adsorveriam": "adsorver",
    "adsorverias": "adsorver",
    "adsorvermo": "adsorver",
    "adsorvermos": "adsorver",
    "adsorverá": "adsorver",
    "adsorverás": "adsorver",
    "adsorverão": "adsorver",
    "adsorveríamos": "adsorver",
    "adsorveríeis": "adsorver",
    "adsorves": "adsorver",
    "adsorvesse": "adsorver",
    "adsorvessem": "adsorver",
    "adsorvesses": "adsorver",
    "adsorveste": "adsorver",
    "adsorvestes": "adsorver",
    "adsorveu": "adsorver",
    "adsorvi": "adsorver",
    "adsorvia": "adsorver",
    "adsorviam": "adsorver",
    "adsorvias": "adsorver",
    "adsorvida": "adsorver",
    "adsorvidas": "adsorver",
    "adsorvido": "adsorver",
    "adsorvidos": "adsorver",
    "adsorvo": "adsorver",
    "adsorvê": "adsorver",
    "adsorvêramo": "adsorver",
    "adsorvêramos": "adsorver",
    "adsorvêrei": "adsorver",
    "adsorvêreis": "adsorver",
    "adsorvêsseis": "adsorver",
    "adsorvêssemos": "adsorver",
    "adsorvíamo": "adsorver",
    "adsorvíamos": "adsorver",
    "adsorvíei": "adsorver",
    "adsorvíeis": "adsorver",
    "adsorções": "adsorção",
    "adstratos": "adstrato",
    "adstringe": "adstringir",
    "adstringem": "adstringir",
    "adstringes": "adstringir",
    "adstringi": "adstringir",
    "adstringia": "adstringir",
    "adstringiam": "adstringir",
    "adstringias": "adstringir",
    "adstringida": "adstringir",
    "adstringidas": "adstringir",
    "adstringido": "adstringir",
    "adstringidos": "adstringir",
    "adstringimo": "adstringir",
    "adstringimos": "adstringir",
    "adstringindo": "adstringir",
    "adstringira": "adstringir",
    "adstringiram": "adstringir",
    "adstringiras": "adstringir",
    "adstringirde": "adstringir",
    "adstringirdes": "adstringir",
    "adstringire": "adstringir",
    "adstringirei": "adstringir",
    "adstringireis": "adstringir",
    "adstringirem": "adstringir",
    "adstringiremos": "adstringir",
    "adstringires": "adstringir",
    "adstringiria": "adstringir",
    "adstringiriam": "adstringir",
    "adstringirias": "adstringir",
    "adstringirmo": "adstringir",
    "adstringirmos": "adstringir",
    "adstringirá": "adstringir",
    "adstringirás": "adstringir",
    "adstringirão": "adstringir",
    "adstringiríamos": "adstringir",
    "adstringiríeis": "adstringir",
    "adstringis": "adstringir",
    "adstringisse": "adstringir",
    "adstringissem": "adstringir",
    "adstringisses": "adstringir",
    "adstringiste": "adstringir",
    "adstringistes": "adstringir",
    "adstringiu": "adstringir",
    "adstringências": "adstringência",
    "adstringíamo": "adstringir",
    "adstringíamos": "adstringir",
    "adstringíei": "adstringir",
    "adstringíeis": "adstringir",
    "adstringíramo": "adstringir",
    "adstringíramos": "adstringir",
    "adstringírei": "adstringir",
    "adstringíreis": "adstringir",
    "adstringísseis": "adstringir",
    "adstringíssemos": "adstringir",
    "adstrinja": "adstringir",
    "adstrinjais": "adstringir",
    "adstrinjam": "adstringir",
    "adstrinjamo": "adstringir",
    "adstrinjamos": "adstringir",
    "adstrinjas": "adstringir",
    "adstrinjo": "adstringir",
    "adstrita": "adstrito",
    "adstritas": "adstrito",
    "adstritiva": "adstritivo",
    "adstritivas": "adstritivo",
    "adstritivos": "adstritivo",
    "adstritos": "adstrito",
    "adstrições": "adstrição",
    "adua": "aduar",
    "aduada": "aduar",
    "aduadas": "aduar",
    "aduado": "aduar",
    "aduados": "aduar",
    "aduagens": "aduagem",
    "aduai": "aduar",
    "aduais": "aduar",
    "aduam": "aduar",
    "aduamo": "aduar",
    "aduamos": "aduar",
    "aduanas": "aduana",
    "aduando": "aduar",
    "aduaneira": "aduaneiro",
    "aduaneiras": "aduaneiro",
    "aduaneiros": "aduaneiro",
    "aduara": "aduar",
    "aduaram": "aduar",
    "aduaras": "aduar",
    "aduarde": "aduar",
    "aduardes": "aduar",
    "aduare": "aduar",
    "aduarei": "aduar",
    "aduareis": "aduar",
    "aduarem": "aduar",
    "aduaremos": "aduar",
    "aduares": "aduar",
    "aduaria": "aduar",
    "aduariam": "aduar",
    "aduarias": "aduar",
    "aduarmo": "aduar",
    "aduarmos": "aduar",
    "aduará": "aduar",
    "aduarás": "aduar",
    "aduarão": "aduar",
    "aduaríamos": "aduar",
    "aduaríeis": "aduar",
    "aduas": "aduar",
    "aduasse": "aduar",
    "aduassem": "aduar",
    "aduasses": "aduar",
    "aduaste": "aduar",
    "aduastes": "aduar",
    "aduava": "aduar",
    "aduavam": "aduar",
    "aduavas": "aduar",
    "aduba": "adubar",
    "adubada": "adubar",
    "adubadas": "adubar",
    "adubadelas": "adubadela",
    "adubado": "adubar",
    "adubadora": "adubador",
    "adubadoras": "adubador",
    "adubadores": "adubador",
    "adubados": "adubar",
    "adubaduras": "adubadura",
    "adubagens": "adubagem",
    "adubai": "adubar",
    "adubais": "adubar",
    "adubam": "adubar",
    "adubamentos": "adubamento",
    "adubamo": "adubar",
    "adubamos": "adubar",
    "adubando": "adubar",
    "adubara": "adubar",
    "adubaram": "adubar",
    "adubaras": "adubar",
    "adubarde": "adubar",
    "adubardes": "adubar",
    "adubare": "adubar",
    "adubarei": "adubar",
    "adubareis": "adubar",
    "adubarem": "adubar",
    "adubaremos": "adubar",
    "adubares": "adubar",
    "adubaria": "adubar",
    "adubariam": "adubar",
    "adubarias": "adubar",
    "adubarmo": "adubar",
    "adubarmos": "adubar",
    "adubará": "adubar",
    "adubarás": "adubar",
    "adubarão": "adubar",
    "adubaríamos": "adubar",
    "adubaríeis": "adubar",
    "adubas": "adubar",
    "adubasse": "adubar",
    "adubassem": "adubar",
    "adubasses": "adubar",
    "adubaste": "adubar",
    "adubastes": "adubar",
    "adubava": "adubar",
    "adubavam": "adubar",
    "adubavas": "adubar",
    "adubações": "adubação",
    "adube": "adubar",
    "adubei": "adubar",
    "adubeis": "adubar",
    "adubem": "adubar",
    "adubemo": "adubar",
    "adubemos": "adubar",
    "adubes": "adubar",
    "adubo": "adubar",
    "adubos": "adubo",
    "adubou": "adubar",
    "adubá": "adubar",
    "adubámo": "adubar",
    "adubámos": "adubar",
    "adubáramo": "adubar",
    "adubáramos": "adubar",
    "adubárei": "adubar",
    "adubáreis": "adubar",
    "adubásseis": "adubar",
    "adubássemos": "adubar",
    "adubávamo": "adubar",
    "adubávamos": "adubar",
    "adubávei": "adubar",
    "adubáveis": "adubar",
    "aducha": "aduchar",
    "aduchada": "aduchar",
    "aduchadas": "aduchar",
    "aduchado": "aduchar",
    "aduchados": "aduchar",
    "aduchai": "aduchar",
    "aduchais": "aduchar",
    "aducham": "aduchar",
    "aduchamo": "aduchar",
    "aduchamos": "aduchar",
    "aduchando": "aduchar",
    "aduchara": "aduchar",
    "aducharam": "aduchar",
    "aducharas": "aduchar",
    "aducharde": "aduchar",
    "aduchardes": "aduchar",
    "aduchare": "aduchar",
    "aducharei": "aduchar",
    "aduchareis": "aduchar",
    "aducharem": "aduchar",
    "aducharemos": "aduchar",
    "aduchares": "aduchar",
    "aducharia": "aduchar",
    "aduchariam": "aduchar",
    "aducharias": "aduchar",
    "aducharmo": "aduchar",
    "aducharmos": "aduchar",
    "aduchará": "aduchar",
    "aducharás": "aduchar",
    "aducharão": "aduchar",
    "aducharíamos": "aduchar",
    "aducharíeis": "aduchar",
    "aduchas": "aduchar",
    "aduchasse": "aduchar",
    "aduchassem": "aduchar",
    "aduchasses": "aduchar",
    "aduchaste": "aduchar",
    "aduchastes": "aduchar",
    "aduchava": "aduchar",
    "aduchavam": "aduchar",
    "aduchavas": "aduchar",
    "aduche": "aduchar",
    "aduchei": "aduchar",
    "aducheis": "aduchar",
    "aduchem": "aduchar",
    "aduchemo": "aduchar",
    "aduchemos": "aduchar",
    "aduches": "aduchar",
    "aducho": "aduchar",
    "aduchou": "aduchar",
    "aduchá": "aduchar",
    "aduchámo": "aduchar",
    "aduchámos": "aduchar",
    "aducháramo": "aduchar",
    "aducháramos": "aduchar",
    "aduchárei": "aduchar",
    "aducháreis": "aduchar",
    "aduchásseis": "aduchar",
    "aduchássemos": "aduchar",
    "aduchávamo": "aduchar",
    "aduchávamos": "aduchar",
    "aduchávei": "aduchar",
    "aducháveis": "aduchar",
    "aductos": "aducto",
    "adue": "aduar",
    "aduei": "aduar",
    "adueiros": "adueiro",
    "adueis": "aduar",
    "aduelagens": "aduelagem",
    "aduelas": "aduela",
    "aduem": "aduar",
    "aduemo": "aduar",
    "aduemos": "aduar",
    "adues": "aduar",
    "adufa": "adufar",
    "adufada": "adufar",
    "adufadas": "adufar",
    "adufado": "adufar",
    "adufados": "adufar",
    "adufai": "adufar",
    "adufais": "adufar",
    "adufam": "adufar",
    "adufamo": "adufar",
    "adufamos": "adufar",
    "adufando": "adufar",
    "adufara": "adufar",
    "adufaram": "adufar",
    "adufaras": "adufar",
    "adufarde": "adufar",
    "adufardes": "adufar",
    "adufare": "adufar",
    "adufarei": "adufar",
    "adufareis": "adufar",
    "adufarem": "adufar",
    "adufaremos": "adufar",
    "adufares": "adufar",
    "adufaria": "adufar",
    "adufariam": "adufar",
    "adufarias": "adufar",
    "adufarmo": "adufar",
    "adufarmos": "adufar",
    "adufará": "adufar",
    "adufarás": "adufar",
    "adufarão": "adufar",
    "adufaríamos": "adufar",
    "adufaríeis": "adufar",
    "adufas": "adufar",
    "adufasse": "adufar",
    "adufassem": "adufar",
    "adufasses": "adufar",
    "adufaste": "adufar",
    "adufastes": "adufar",
    "adufava": "adufar",
    "adufavam": "adufar",
    "adufavas": "adufar",
    "adufe": "adufar",
    "adufei": "adufar",
    "adufeira": "adufeiro",
    "adufeiras": "adufeiro",
    "adufeiros": "adufeiro",
    "adufeis": "adufar",
    "adufem": "adufar",
    "adufemo": "adufar",
    "adufemos": "adufar",
    "adufes": "adufe",
    "adufo": "adufar",
    "adufos": "adufo",
    "adufou": "adufar",
    "adufá": "adufar",
    "adufámo": "adufar",
    "adufámos": "adufar",
    "adufáramo": "adufar",
    "adufáramos": "adufar",
    "adufárei": "adufar",
    "adufáreis": "adufar",
    "adufásseis": "adufar",
    "adufássemos": "adufar",
    "adufávamo": "adufar",
    "adufávamos": "adufar",
    "adufávei": "adufar",
    "adufáveis": "adufar",
    "adula": "adular",
    "adulada": "adular",
    "aduladas": "adular",
    "adulado": "adular",
    "aduladora": "adulador",
    "aduladoras": "adulador",
    "aduladores": "adulador",
    "adulados": "adular",
    "aduladíssima": "adulado",
    "aduladíssimas": "adulado",
    "aduladíssimo": "adulado",
    "aduladíssimos": "adulado",
    "adulai": "adular",
    "adulais": "adular",
    "adulam": "adular",
    "adulamo": "adular",
    "adulamos": "adular",
    "adulando": "adular",
    "adulara": "adular",
    "adularam": "adular",
    "adularas": "adular",
    "adularde": "adular",
    "adulardes": "adular",
    "adulare": "adular",
    "adularei": "adular",
    "adulareis": "adular",
    "adularem": "adular",
    "adularemos": "adular",
    "adulares": "adular",
    "adularia": "adular",
    "adulariam": "adular",
    "adularias": "adular",
    "adularizações": "adularização",
    "adularmo": "adular",
    "adularmos": "adular",
    "adulará": "adular",
    "adularás": "adular",
    "adularão": "adular",
    "adularíamos": "adular",
    "adularíeis": "adular",
    "adulas": "adular",
    "adulasse": "adular",
    "adulassem": "adular",
    "adulasses": "adular",
    "adulaste": "adular",
    "adulastes": "adular",
    "adulatória": "adulatório",
    "adulatórias": "adulatório",
    "adulatórios": "adulatório",
    "adulava": "adular",
    "adulavam": "adular",
    "adulavas": "adular",
    "adulações": "adulação",
    "adule": "adular",
    "adulei": "adular",
    "aduleis": "adular",
    "adulem": "adular",
    "adulemo": "adular",
    "adulemos": "adular",
    "adules": "adular",
    "adulo": "adular",
    "adulou": "adular",
    "adulta": "adulto",
    "adultas": "adulto",
    "adultera": "adulterar",
    "adulterada": "adulterar",
    "adulteradas": "adulterar",
    "adulterado": "adulterar",
    "adulteradora": "adulterador",
    "adulteradoras": "adulterador",
    "adulteradores": "adulterador",
    "adulterados": "adulterar",
    "adulteradíssima": "adulterado",
    "adulteradíssimas": "adulterado",
    "adulteradíssimo": "adulterado",
    "adulteradíssimos": "adulterado",
    "adulterai": "adulterar",
    "adulterais": "adulterar",
    "adulteram": "adulterar",
    "adulteramo": "adulterar",
    "adulteramos": "adulterar",
    "adulterando": "adulterar",
    "adulterara": "adulterar",
    "adulteraram": "adulterar",
    "adulteraras": "adulterar",
    "adulterarde": "adulterar",
    "adulterardes": "adulterar",
    "adulterare": "adulterar",
    "adulterarei": "adulterar",
    "adulterareis": "adulterar",
    "adulterarem": "adulterar",
    "adulteraremos": "adulterar",
    "adulterares": "adulterar",
    "adulteraria": "adulterar",
    "adulterariam": "adulterar",
    "adulterarias": "adulterar",
    "adulterarmo": "adulterar",
    "adulterarmos": "adulterar",
    "adulterará": "adulterar",
    "adulterarás": "adulterar",
    "adulterarão": "adulterar",
    "adulteraríamos": "adulterar",
    "adulteraríeis": "adulterar",
    "adulteras": "adulterar",
    "adulterasse": "adulterar",
    "adulterassem": "adulterar",
    "adulterasses": "adulterar",
    "adulteraste": "adulterar",
    "adulterastes": "adulterar",
    "adulterava": "adulterar",
    "adulteravam": "adulterar",
    "adulteravas": "adulterar",
    "adulterações": "adulteração",
    "adultere": "adulterar",
    "adulterei": "adulterar",
    "adultereis": "adulterar",
    "adulterem": "adulterar",
    "adulteremo": "adulterar",
    "adulteremos": "adulterar",
    "adulteres": "adulterar",
    "adulterina": "adulterino",
    "adulterinas": "adulterino",
    "adulterinidades": "adulterinidade",
    "adulterinos": "adulterino",
    "adultero": "adulterar",
    "adulterosa": "adulteroso",
    "adulterosas": "adulteroso",
    "adulterosos": "adulteroso",
    "adulterou": "adulterar",
    "adulterá": "adulterar",
    "adulterámo": "adulterar",
    "adulterámos": "adulterar",
    "adulteráramo": "adulterar",
    "adulteráramos": "adulterar",
    "adulterárei": "adulterar",
    "adulteráreis": "adulterar",
    "adulterásseis": "adulterar",
    "adulterássemos": "adulterar",
    "adulterávamo": "adulterar",
    "adulterávamos": "adulterar",
    "adulterávei": "adulterar",
    "adulteráveis": "adulterável",
    "adultinha": "adulto",
    "adultinhas": "adulto",
    "adultinho": "adulto",
    "adultinhos": "adulto",
    "adultita": "adulto",
    "adultitas": "adulto",
    "adultito": "adulto",
    "adultitos": "adulto",
    "adultos": "adulto",
    "adultérios": "adultério",
    "adulá": "adular",
    "adulámo": "adular",
    "adulámos": "adular",
    "aduláramo": "adular",
    "aduláramos": "adular",
    "adulárei": "adular",
    "aduláreis": "adular",
    "adulárias": "adulária",
    "adulásseis": "adular",
    "adulássemos": "adular",
    "adulávamo": "adular",
    "adulávamos": "adular",
    "adulávei": "adular",
    "aduláveis": "adular",
    "adulçora": "orar",
    "adulçorada": "adulçorar",
    "adulçoradas": "adulçorar",
    "adulçorado": "adulçorar",
    "adulçorados": "adulçorar",
    "adulçorai": "adulçorar",
    "adulçorais": "adulçorar",
    "adulçoram": "adulçorar",
    "adulçoramo": "adulçorar",
    "adulçoramos": "adulçorar",
    "adulçorando": "adulçorar",
    "adulçorar": "orar",
    "adulçorara": "orar",
    "adulçoraram": "orar",
    "adulçoraras": "adulçorar",
    "adulçorarde": "adulçorar",
    "adulçorardes": "adulçorar",
    "adulçorare": "adulçorar",
    "adulçorarei": "adulçorar",
    "adulçorareis": "adulçorar",
    "adulçorarem": "orar",
    "adulçoraremos": "adulçorar",
    "adulçorares": "adulçorar",
    "adulçoraria": "orar",
    "adulçorariam": "adulçorar",
    "adulçorarias": "adulçorar",
    "adulçorarmo": "adulçorar",
    "adulçorarmos": "adulçorar",
    "adulçorará": "adulçorar",
    "adulçorarás": "adulçorar",
    "adulçorarão": "adulçorar",
    "adulçoraríamos": "adulçorar",
    "adulçoraríeis": "adulçorar",
    "adulçoras": "adulçorar",
    "adulçorasse": "orar",
    "adulçorassem": "adulçorar",
    "adulçorasses": "adulçorar",
    "adulçoraste": "adulçorar",
    "adulçorastes": "adulçorar",
    "adulçorava": "orar",
    "adulçoravam": "adulçorar",
    "adulçoravas": "adulçorar",
    "adulçore": "orar",
    "adulçorei": "adulçorar",
    "adulçoreis": "adulçorar",
    "adulçorem": "orar",
    "adulçoremo": "adulçorar",
    "adulçoremos": "adulçorar",
    "adulçores": "adulçorar",
    "adulçoro": "adulçorar",
    "adulçorou": "adulçorar",
    "adulçorá": "orar",
    "adulçorámo": "adulçorar",
    "adulçorámos": "adulçorar",
    "adulçoráramo": "adulçorar",
    "adulçoráramos": "adulçorar",
    "adulçorárei": "adulçorar",
    "adulçoráreis": "adulçorar",
    "adulçorásseis": "adulçorar",
    "adulçorássemos": "adulçorar",
    "adulçorávamo": "adulçorar",
    "adulçorávamos": "adulçorar",
    "adulçorávei": "adulçorar",
    "adulçoráveis": "adulçorar",
    "adumbra": "adumbrar",
    "adumbrada": "adumbrar",
    "adumbradas": "adumbrar",
    "adumbrado": "adumbrar",
    "adumbrados": "adumbrar",
    "adumbrai": "adumbrar",
    "adumbrais": "adumbrar",
    "adumbram": "adumbrar",
    "adumbramo": "adumbrar",
    "adumbramos": "adumbrar",
    "adumbrando": "adumbrar",
    "adumbrara": "adumbrar",
    "adumbraram": "adumbrar",
    "adumbraras": "adumbrar",
    "adumbrarde": "adumbrar",
    "adumbrardes": "adumbrar",
    "adumbrare": "adumbrar",
    "adumbrarei": "adumbrar",
    "adumbrareis": "adumbrar",
    "adumbrarem": "adumbrar",
    "adumbraremos": "adumbrar",
    "adumbrares": "adumbrar",
    "adumbraria": "adumbrar",
    "adumbrariam": "adumbrar",
    "adumbrarias": "adumbrar",
    "adumbrarmo": "adumbrar",
    "adumbrarmos": "adumbrar",
    "adumbrará": "adumbrar",
    "adumbrarás": "adumbrar",
    "adumbrarão": "adumbrar",
    "adumbraríamos": "adumbrar",
    "adumbraríeis": "adumbrar",
    "adumbras": "adumbrar",
    "adumbrasse": "adumbrar",
    "adumbrassem": "adumbrar",
    "adumbrasses": "adumbrar",
    "adumbraste": "adumbrar",
    "adumbrastes": "adumbrar",
    "adumbrava": "adumbrar",
    "adumbravam": "adumbrar",
    "adumbravas": "adumbrar",
    "adumbrações": "adumbração",
    "adumbre": "adumbrar",
    "adumbrei": "adumbrar",
    "adumbreis": "adumbrar",
    "adumbrem": "adumbrar",
    "adumbremo": "adumbrar",
    "adumbremos": "adumbrar",
    "adumbres": "adumbrar",
    "adumbro": "adumbrar",
    "adumbrou": "adumbrar",
    "adumbrá": "adumbrar",
    "adumbrámo": "adumbrar",
    "adumbrámos": "adumbrar",
    "adumbráramo": "adumbrar",
    "adumbráramos": "adumbrar",
    "adumbrárei": "adumbrar",
    "adumbráreis": "adumbrar",
    "adumbrásseis": "adumbrar",
    "adumbrássemos": "adumbrar",
    "adumbrávamo": "adumbrar",
    "adumbrávamos": "adumbrar",
    "adumbrávei": "adumbrar",
    "adumbráveis": "adumbrar",
    "aduna": "adunar",
    "adunada": "adunar",
    "adunadas": "adunar",
    "adunado": "adunar",
    "adunados": "adunar",
    "adunai": "adunar",
    "adunais": "adunar",
    "adunam": "adunar",
    "adunamo": "adunar",
    "adunamos": "adunar",
    "adunando": "adunar",
    "adunara": "adunar",
    "adunaram": "adunar",
    "adunaras": "adunar",
    "adunarde": "adunar",
    "adunardes": "adunar",
    "adunare": "adunar",
    "adunarei": "adunar",
    "adunareis": "adunar",
    "adunarem": "adunar",
    "adunaremos": "adunar",
    "adunares": "adunar",
    "adunaria": "adunar",
    "adunariam": "adunar",
    "adunarias": "adunar",
    "adunarmo": "adunar",
    "adunarmos": "adunar",
    "adunará": "adunar",
    "adunarás": "adunar",
    "adunarão": "adunar",
    "adunaríamos": "adunar",
    "adunaríeis": "adunar",
    "adunas": "adunar",
    "adunasse": "adunar",
    "adunassem": "adunar",
    "adunasses": "adunar",
    "adunaste": "adunar",
    "adunastes": "adunar",
    "adunava": "adunar",
    "adunavam": "adunar",
    "adunavas": "adunar",
    "adunações": "adunação",
    "adunca": "adunco",
    "aduncada": "aduncar",
    "aduncadas": "aduncar",
    "aduncado": "aduncar",
    "aduncados": "aduncar",
    "aduncai": "aduncar",
    "aduncais": "aduncar",
    "aduncam": "aduncar",
    "aduncamo": "aduncar",
    "aduncamos": "aduncar",
    "aduncando": "aduncar",
    "aduncara": "aduncar",
    "aduncaram": "aduncar",
    "aduncaras": "aduncar",
    "aduncarde": "aduncar",
    "aduncardes": "aduncar",
    "aduncare": "aduncar",
    "aduncarei": "aduncar",
    "aduncareis": "aduncar",
    "aduncarem": "aduncar",
    "aduncaremos": "aduncar",
    "aduncares": "aduncar",
    "aduncaria": "aduncar",
    "aduncariam": "aduncar",
    "aduncarias": "aduncar",
    "aduncarmo": "aduncar",
    "aduncarmos": "aduncar",
    "aduncará": "aduncar",
    "aduncarás": "aduncar",
    "aduncarão": "aduncar",
    "aduncaríamos": "aduncar",
    "aduncaríeis": "aduncar",
    "aduncas": "adunco",
    "aduncasse": "aduncar",
    "aduncassem": "aduncar",
    "aduncasses": "aduncar",
    "aduncaste": "aduncar",
    "aduncastes": "aduncar",
    "aduncava": "aduncar",
    "aduncavam": "aduncar",
    "aduncavas": "aduncar",
    "aduncidades": "aduncidade",
    "aduncirrostros": "aduncirrostro",
    "adunco": "aduncar",
    "aduncos": "adunco",
    "aduncou": "aduncar",
    "aduncá": "aduncar",
    "aduncámo": "aduncar",
    "aduncámos": "aduncar",
    "aduncáramo": "aduncar",
    "aduncáramos": "aduncar",
    "aduncárei": "aduncar",
    "aduncáreis": "aduncar",
    "aduncásseis": "aduncar",
    "aduncássemos": "aduncar",
    "aduncávamo": "aduncar",
    "aduncávamos": "aduncar",
    "aduncávei": "aduncar",
    "aduncáveis": "aduncar",
    "adune": "adunar",
    "adunei": "adunar",
    "aduneis": "adunar",
    "adunem": "adunar",
    "adunemo": "adunar",
    "adunemos": "adunar",
    "adunes": "adunar",
    "aduno": "adunar",
    "adunou": "adunar",
    "adunque": "aduncar",
    "adunquei": "aduncar",
    "adunqueis": "aduncar",
    "adunquem": "aduncar",
    "adunquemo": "aduncar",
    "adunquemos": "aduncar",
    "adunques": "aduncar",
    "aduná": "adunar",
    "adunámo": "adunar",
    "adunámos": "adunar",
    "adunáramo": "adunar",
    "adunáramos": "adunar",
    "adunárei": "adunar",
    "adunáreis": "adunar",
    "adunásseis": "adunar",
    "adunássemos": "adunar",
    "adunávamo": "adunar",
    "adunávamos": "adunar",
    "adunávei": "adunar",
    "adunáveis": "adunar",
    "aduo": "aduar",
    "aduou": "aduar",
    "adura": "adurir",
    "adurais": "adurir",
    "aduram": "adurir",
    "aduramo": "adurir",
    "aduramos": "adurir",
    "aduras": "adurir",
    "adure": "adurir",
    "adurem": "adurir",
    "adurentes": "adurente",
    "adures": "adurir",
    "aduri": "adurir",
    "aduria": "adurir",
    "aduriam": "adurir",
    "adurias": "adurir",
    "adurida": "adurir",
    "aduridas": "adurir",
    "adurido": "adurir",
    "aduridos": "adurir",
    "adurimo": "adurir",
    "adurimos": "adurir",
    "adurindo": "adurir",
    "adurira": "adurir",
    "aduriram": "adurir",
    "aduriras": "adurir",
    "adurirde": "adurir",
    "adurirdes": "adurir",
    "adurire": "adurir",
    "adurirei": "adurir",
    "adurireis": "adurir",
    "adurirem": "adurir",
    "aduriremos": "adurir",
    "adurires": "adurir",
    "aduriria": "adurir",
    "aduririam": "adurir",
    "aduririas": "adurir",
    "adurirmo": "adurir",
    "adurirmos": "adurir",
    "adurirá": "adurir",
    "adurirás": "adurir",
    "adurirão": "adurir",
    "aduriríamos": "adurir",
    "aduriríeis": "adurir",
    "aduris": "adurir",
    "adurisse": "adurir",
    "adurissem": "adurir",
    "adurisses": "adurir",
    "aduriste": "adurir",
    "aduristes": "adurir",
    "aduriu": "adurir",
    "aduro": "adurir",
    "adurências": "adurência",
    "aduríamo": "adurir",
    "aduríamos": "adurir",
    "aduríei": "adurir",
    "aduríeis": "adurir",
    "aduríramo": "adurir",
    "aduríramos": "adurir",
    "adurírei": "adurir",
    "aduríreis": "adurir",
    "adurísseis": "adurir",
    "aduríssemos": "adurir",
    "adusta": "adusto",
    "adustas": "adusto",
    "adustiva": "adustivo",
    "adustivas": "adustivo",
    "adustivos": "adustivo",
    "adustos": "adusto",
    "adustões": "adustão",
    "aduterina": "aduterino",
    "aduterinas": "aduterino",
    "aduterinos": "aduterino",
    "adutora": "adutor",
    "adutoras": "adutor",
    "adutores": "adutor",
    "aduz": "aduzir",
    "aduza": "aduzir",
    "aduzais": "aduzir",
    "aduzam": "aduzir",
    "aduzamo": "aduzir",
    "aduzamos": "aduzir",
    "aduzas": "aduzir",
    "aduze": "aduzir",
    "aduzem": "aduzir",
    "aduzes": "aduzir",
    "aduzi": "aduzir",
    "aduzia": "aduzir",
    "aduziam": "aduzir",
    "aduzias": "aduzir",
    "aduzida": "aduzir",
    "aduzidas": "aduzir",
    "aduzido": "aduzir",
    "aduzidos": "aduzir",
    "aduzimo": "aduzir",
    "aduzimos": "aduzir",
    "aduzindo": "aduzir",
    "aduzira": "aduzir",
    "aduziram": "aduzir",
    "aduziras": "aduzir",
    "aduzirde": "aduzir",
    "aduzirdes": "aduzir",
    "aduzire": "aduzir",
    "aduzirei": "aduzir",
    "aduzireis": "aduzir",
    "aduzirem": "aduzir",
    "aduziremos": "aduzir",
    "aduzires": "aduzir",
    "aduziria": "aduzir",
    "aduziriam": "aduzir",
    "aduzirias": "aduzir",
    "aduzirmo": "aduzir",
    "aduzirmos": "aduzir",
    "aduzirá": "aduzir",
    "aduzirás": "aduzir",
    "aduzirão": "aduzir",
    "aduziríamos": "aduzir",
    "aduziríeis": "aduzir",
    "aduzis": "aduzir",
    "aduzisse": "aduzir",
    "aduzissem": "aduzir",
    "aduzisses": "aduzir",
    "aduziste": "aduzir",
    "aduzistes": "aduzir",
    "aduziu": "aduzir",
    "aduzo": "aduzir",
    "aduzíamo": "aduzir",
    "aduzíamos": "aduzir",
    "aduzíei": "aduzir",
    "aduzíeis": "aduzir",
    "aduzíramo": "aduzir",
    "aduzíramos": "aduzir",
    "aduzírei": "aduzir",
    "aduzíreis": "aduzir",
    "aduzísseis": "aduzir",
    "aduzíssemos": "aduzir",
    "aduzíveis": "aduzível",
    "aduá": "aduar",
    "aduámo": "aduar",
    "aduámos": "aduar",
    "aduáramo": "aduar",
    "aduáramos": "aduar",
    "aduárei": "aduar",
    "aduáreis": "aduar",
    "aduásseis": "aduar",
    "aduássemos": "aduar",
    "aduávamo": "aduar",
    "aduávamos": "aduar",
    "aduávei": "aduar",
    "aduáveis": "aduar",
    "aduções": "adução",
    "advecções": "advecção",
    "adveio": "advir",
    "advem": "advir",
    "advenha": "advir",
    "advenhais": "advir",
    "advenham": "advir",
    "advenhamo": "advir",
    "advenhamos": "advir",
    "advenhas": "advir",
    "advenho": "advir",
    "advenientes": "adveniente",
    "adventismos": "adventismo",
    "adventistas": "adventista",
    "adventos": "advento",
    "adventícia": "adventício",
    "adventícias": "adventício",
    "adventícios": "adventício",
    "adverbia": "adverbiar",
    "adverbiada": "adverbiar",
    "adverbiadas": "adverbiar",
    "adverbiado": "adverbiar",
    "adverbiados": "adverbiar",
    "adverbiai": "adverbiar",
    "adverbiais": "adverbiar",
    "adverbializa": "adverbializar",
    "adverbializada": "adverbializar",
    "adverbializadas": "adverbializar",
    "adverbializado": "adverbializar",
    "adverbializados": "adverbializar",
    "adverbializai": "adverbializar",
    "adverbializais": "adverbializar",
    "adverbializam": "adverbializar",
    "adverbializamo": "adverbializar",
    "adverbializamos": "adverbializar",
    "adverbializando": "adverbializar",
    "adverbializara": "adverbializar",
    "adverbializaram": "adverbializar",
    "adverbializaras": "adverbializar",
    "adverbializarde": "adverbializar",
    "adverbializardes": "adverbializar",
    "adverbializare": "adverbializar",
    "adverbializarei": "adverbializar",
    "adverbializareis": "adverbializar",
    "adverbializarem": "adverbializar",
    "adverbializaremos": "adverbializar",
    "adverbializares": "adverbializar",
    "adverbializaria": "adverbializar",
    "adverbializariam": "adverbializar",
    "adverbializarias": "adverbializar",
    "adverbializarmo": "adverbializar",
    "adverbializarmos": "adverbializar",
    "adverbializará": "adverbializar",
    "adverbializarás": "adverbializar",
    "adverbializarão": "adverbializar",
    "adverbializaríamos": "adverbializar",
    "adverbializaríeis": "adverbializar",
    "adverbializas": "adverbializar",
    "adverbializasse": "adverbializar",
    "adverbializassem": "adverbializar",
    "adverbializasses": "adverbializar",
    "adverbializaste": "adverbializar",
    "adverbializastes": "adverbializar",
    "adverbializava": "adverbializar",
    "adverbializavam": "adverbializar",
    "adverbializavas": "adverbializar",
    "adverbialize": "adverbializar",
    "adverbializei": "adverbializar",
    "adverbializeis": "adverbializar",
    "adverbializem": "adverbializar",
    "adverbializemo": "adverbializar",
    "adverbializemos": "adverbializar",
    "adverbializes": "adverbializar",
    "adverbializo": "adverbializar",
    "adverbializou": "adverbializar",
    "adverbializá": "adverbializar",
    "adverbializámo": "adverbializar",
    "adverbializámos": "adverbializar",
    "adverbializáramo": "adverbializar",
    "adverbializáramos": "adverbializar",
    "adverbializárei": "adverbializar",
    "adverbializáreis": "adverbializar",
    "adverbializásseis": "adverbializar",
    "adverbializássemos": "adverbializar",
    "adverbializávamo": "adverbializar",
    "adverbializávamos": "adverbializar",
    "adverbializávei": "adverbializar",
    "adverbializáveis": "adverbializar",
    "adverbiam": "adverbiar",
    "adverbiamo": "adverbiar",
    "adverbiamos": "adverbiar",
    "adverbiando": "adverbiar",
    "adverbiara": "adverbiar",
    "adverbiaram": "adverbiar",
    "adverbiaras": "adverbiar",
    "adverbiarde": "adverbiar",
    "adverbiardes": "adverbiar",
    "adverbiare": "adverbiar",
    "adverbiarei": "adverbiar",
    "adverbiareis": "adverbiar",
    "adverbiarem": "adverbiar",
    "adverbiaremos": "adverbiar",
    "adverbiares": "adverbiar",
    "adverbiaria": "adverbiar",
    "adverbiariam": "adverbiar",
    "adverbiarias": "adverbiar",
    "adverbiarmo": "adverbiar",
    "adverbiarmos": "adverbiar",
    "adverbiará": "adverbiar",
    "adverbiarás": "adverbiar",
    "adverbiarão": "adverbiar",
    "adverbiaríamos": "adverbiar",
    "adverbiaríeis": "adverbiar",
    "adverbias": "adverbiar",
    "adverbiasse": "adverbiar",
    "adverbiassem": "adverbiar",
    "adverbiasses": "adverbiar",
    "adverbiaste": "adverbiar",
    "adverbiastes": "adverbiar",
    "adverbiava": "adverbiar",
    "adverbiavam": "adverbiar",
    "adverbiavas": "adverbiar",
    "adverbie": "adverbiar",
    "adverbiei": "adverbiar",
    "adverbieis": "adverbiar",
    "adverbiem": "adverbiar",
    "adverbiemo": "adverbiar",
    "adverbiemos": "adverbiar",
    "adverbies": "adverbiar",
    "adverbio": "adverbiar",
    "adverbiou": "adverbiar",
    "adverbiá": "adverbiar",
    "adverbiámo": "adverbiar",
    "adverbiámos": "adverbiar",
    "adverbiáramo": "adverbiar",
    "adverbiáramos": "adverbiar",
    "adverbiárei": "adverbiar",
    "adverbiáreis": "adverbiar",
    "adverbiásseis": "adverbiar",
    "adverbiássemos": "adverbiar",
    "adverbiávamo": "adverbiar",
    "adverbiávamos": "adverbiar",
    "adverbiávei": "adverbiar",
    "adverbiáveis": "adverbiar",
    "adversa": "adverso",
    "adversada": "adversar",
    "adversadas": "adversar",
    "adversado": "adversar",
    "adversados": "adversar",
    "adversai": "adversar",
    "adversais": "adversar",
    "adversam": "adversar",
    "adversamo": "adversar",
    "adversamos": "adversar",
    "adversando": "adversar",
    "adversara": "adversar",
    "adversaram": "adversar",
    "adversaras": "adversar",
    "adversarde": "adversar",
    "adversardes": "adversar",
    "adversare": "adversar",
    "adversarei": "adversar",
    "adversareis": "adversar",
    "adversarem": "adversar",
    "adversaremos": "adversar",
    "adversares": "adversar",
    "adversaria": "adversar",
    "adversariam": "adversar",
    "adversarias": "adversar",
    "adversarmo": "adversar",
    "adversarmos": "adversar",
    "adversará": "adversar",
    "adversarás": "adversar",
    "adversarão": "adversar",
    "adversaríamos": "adversar",
    "adversaríeis": "adversar",
    "adversas": "adverso",
    "adversasse": "adversar",
    "adversassem": "adversar",
    "adversasses": "adversar",
    "adversaste": "adversar",
    "adversastes": "adversar",
    "adversativa": "adversativo",
    "adversativas": "adversativo",
    "adversativos": "adversativo",
    "adversava": "adversar",
    "adversavam": "adversar",
    "adversavas": "adversar",
    "adverse": "adversar",
    "adversei": "adversar",
    "adverseis": "adversar",
    "adversem": "adversar",
    "adversemo": "adversar",
    "adversemos": "adversar",
    "adverses": "adversar",
    "adversidades": "adversidade",
    "adverso": "adversar",
    "adversos": "adverso",
    "adversou": "adversar",
    "adversá": "adversar",
    "adversámo": "adversar",
    "adversámos": "adversar",
    "adversáramo": "adversar",
    "adversáramos": "adversar",
    "adversárei": "adversar",
    "adversáreis": "adversar",
    "adversária": "adversário",
    "adversárias": "adversário",
    "adversários": "adversário",
    "adversásseis": "adversar",
    "adversássemos": "adversar",
    "adversávamo": "adversar",
    "adversávamos": "adversar",
    "adversávei": "adversar",
    "adversáveis": "adversar",
    "adversões": "adversão",
    "adverte": "advertir",
    "advertem": "advertir",
    "advertes": "advertir",
    "adverti": "advertir",
    "advertia": "advertir",
    "advertiam": "advertir",
    "advertias": "advertir",
    "advertida": "advertir",
    "advertidas": "advertir",
    "advertido": "advertir",
    "advertidos": "advertir",
    "advertidíssima": "advertido",
    "advertidíssimas": "advertido",
    "advertidíssimo": "advertido",
    "advertidíssimos": "advertido",
    "advertimentos": "advertimento",
    "advertimo": "advertir",
    "advertimos": "advertir",
    "advertindo": "advertir",
    "advertira": "advertir",
    "advertiram": "advertir",
    "advertiras": "advertir",
    "advertirde": "advertir",
    "advertirdes": "advertir",
    "advertire": "advertir",
    "advertirei": "advertir",
    "advertireis": "advertir",
    "advertirem": "advertir",
    "advertiremos": "advertir",
    "advertires": "advertir",
    "advertiria": "advertir",
    "advertiriam": "advertir",
    "advertirias": "advertir",
    "advertirmo": "advertir",
    "advertirmos": "advertir",
    "advertirá": "advertir",
    "advertirás": "advertir",
    "advertirão": "advertir",
    "advertiríamos": "advertir",
    "advertiríeis": "advertir",
    "advertis": "advertir",
    "advertisse": "advertir",
    "advertissem": "advertir",
    "advertisses": "advertir",
    "advertiste": "advertir",
    "advertistes": "advertir",
    "advertiu": "advertir",
    "advertências": "advertência",
    "advertíamo": "advertir",
    "advertíamos": "advertir",
    "advertíei": "advertir",
    "advertíeis": "advertir",
    "advertíramo": "advertir",
    "advertíramos": "advertir",
    "advertírei": "advertir",
    "advertíreis": "advertir",
    "advertísseis": "advertir",
    "advertíssemos": "advertir",
    "adviemo": "advir",
    "adviemos": "advir",
    "advier": "advir",
    "adviera": "advir",
    "advieram": "advir",
    "advieras": "advir",
    "advierdes": "advir",
    "advierem": "advir",
    "advieres": "advir",
    "adviermos": "advir",
    "adviesse": "advir",
    "adviessem": "advir",
    "adviesses": "advir",
    "advieste": "advir",
    "adviestes": "advir",
    "advim": "advir",
    "advimo": "advir",
    "advimos": "advir",
    "advinda": "advir",
    "advindas": "advir",
    "advinde": "advir",
    "advindes": "advir",
    "advindo": "advir",
    "advindos": "advir",
    "advinha": "advir",
    "advinham": "advir",
    "advinhas": "advir",
    "advins": "advim",
    "advirdes": "advir",
    "advirei": "advir",
    "advireis": "advir",
    "advirem": "advir",
    "adviremos": "advir",
    "advires": "advir",
    "adviria": "advir",
    "adviriam": "advir",
    "advirias": "advir",
    "advirmo": "advir",
    "advirmos": "advir",
    "advirta": "advertir",
    "advirtais": "advertir",
    "advirtam": "advertir",
    "advirtamo": "advertir",
    "advirtamos": "advertir",
    "advirtas": "advertir",
    "advirto": "advertir",
    "advirá": "advir",
    "advirás": "advir",
    "advirão": "advir",
    "adviríamos": "advir",
    "adviríeis": "advir",
    "adviéramo": "advir",
    "adviéramos": "advir",
    "adviéreis": "advir",
    "adviésseis": "advir",
    "adviéssemos": "advir",
    "advocacias": "advocacia",
    "advocaturas": "advocatura",
    "advocatória": "advocatório",
    "advocatórias": "advocatório",
    "advocatórios": "advocatório",
    "advoga": "advogar",
    "advogada": "advogar",
    "advogadas": "advogar",
    "advogado": "advogar",
    "advogados": "advogar",
    "advogai": "advogar",
    "advogais": "advogar",
    "advogam": "advogar",
    "advogamo": "advogar",
    "advogamos": "advogar",
    "advogando": "advogar",
    "advogara": "advogar",
    "advogaram": "advogar",
    "advogaras": "advogar",
    "advogarde": "advogar",
    "advogardes": "advogar",
    "advogare": "advogar",
    "advogarei": "advogar",
    "advogareis": "advogar",
    "advogarem": "advogar",
    "advogaremos": "advogar",
    "advogares": "advogar",
    "advogaria": "advogar",
    "advogariam": "advogar",
    "advogarias": "advogar",
    "advogarmo": "advogar",
    "advogarmos": "advogar",
    "advogará": "advogar",
    "advogarás": "advogar",
    "advogarão": "advogar",
    "advogaríamos": "advogar",
    "advogaríeis": "advogar",
    "advogas": "advogar",
    "advogasse": "advogar",
    "advogassem": "advogar",
    "advogasses": "advogar",
    "advogaste": "advogar",
    "advogastes": "advogar",
    "advogava": "advogar",
    "advogavam": "advogar",
    "advogavas": "advogar",
    "advogo": "advogar",
    "advogou": "advogar",
    "advogue": "advogar",
    "advoguei": "advogar",
    "advogueis": "advogar",
    "advoguem": "advogar",
    "advoguemo": "advogar",
    "advoguemos": "advogar",
    "advogues": "advogar",
    "advogá": "advogar",
    "advogámo": "advogar",
    "advogámos": "advogar",
    "advogáramo": "advogar",
    "advogáramos": "advogar",
    "advogárei": "advogar",
    "advogáreis": "advogar",
    "advogásseis": "advogar",
    "advogássemos": "advogar",
    "advogávamo": "advogar",
    "advogávamos": "advogar",
    "advogávei": "advogar",
    "advogáveis": "advogável",
    "advém": "advir",
    "advéns": "advir",
    "advérbios": "advérbio",
    "advêm": "advir",
    "advínhamo": "advir",
    "advínhamos": "advir",
    "advínheis": "advir",
    "adágios": "adágio",
    "adâmica": "adâmico",
    "adâmicas": "adâmico",
    "adâmicos": "adâmico",
    "adíamo": "adir",
    "adíamos": "adir",
    "adíei": "adir",
    "adíeis": "adir",
    "adíramo": "adir",
    "adíramos": "adir",
    "adírei": "adir",
    "adíreis": "adir",
    "adísseis": "adir",
    "adíssemos": "adir",
    "adónia": "adónio",
    "adónias": "adónio",
    "adónica": "adónico",
    "adónicas": "adónico",
    "adónicos": "adónico",
    "adónios": "adónio",
    "adúltera": "adúltero",
    "adúlteras": "adúltero",
    "adúlteros": "adúltero",
    "adúteros": "adútero",
    "aedos": "aedo",
    "aegirinas": "aegirina",
    "aegirites": "aegirite",
    "aenigmatites": "aenigmatite",
    "aerações": "aeração",
    "aeremias": "aeremia",
    "aerifica": "aerificar",
    "aerificada": "aerificar",
    "aerificadas": "aerificar",
    "aerificado": "aerificar",
    "aerificados": "aerificar",
    "aerificai": "aerificar",
    "aerificais": "aerificar",
    "aerificam": "aerificar",
    "aerificamo": "aerificar",
    "aerificamos": "aerificar",
    "aerificando": "aerificar",
    "aerificara": "aerificar",
    "aerificaram": "aerificar",
    "aerificaras": "aerificar",
    "aerificarde": "aerificar",
    "aerificardes": "aerificar",
    "aerificare": "aerificar",
    "aerificarei": "aerificar",
    "aerificareis": "aerificar",
    "aerificarem": "aerificar",
    "aerificaremos": "aerificar",
    "aerificares": "aerificar",
    "aerificaria": "aerificar",
    "aerificariam": "aerificar",
    "aerificarias": "aerificar",
    "aerificarmo": "aerificar",
    "aerificarmos": "aerificar",
    "aerificará": "aerificar",
    "aerificarás": "aerificar",
    "aerificarão": "aerificar",
    "aerificaríamos": "aerificar",
    "aerificaríeis": "aerificar",
    "aerificas": "aerificar",
    "aerificasse": "aerificar",
    "aerificassem": "aerificar",
    "aerificasses": "aerificar",
    "aerificaste": "aerificar",
    "aerificastes": "aerificar",
    "aerificava": "aerificar",
    "aerificavam": "aerificar",
    "aerificavas": "aerificar",
    "aerificações": "aerificação",
    "aerifico": "aerificar",
    "aerificou": "aerificar",
    "aerificá": "aerificar",
    "aerificámo": "aerificar",
    "aerificámos": "aerificar",
    "aerificáramo": "aerificar",
    "aerificáramos": "aerificar",
    "aerificárei": "aerificar",
    "aerificáreis": "aerificar",
    "aerificásseis": "aerificar",
    "aerificássemos": "aerificar",
    "aerificávamo": "aerificar",
    "aerificávamos": "aerificar",
    "aerificávei": "aerificar",
    "aerificáveis": "aerificar",
    "aerifique": "aerificar",
    "aerifiquei": "aerificar",
    "aerifiqueis": "aerificar",
    "aerifiquem": "aerificar",
    "aerifiquemo": "aerificar",
    "aerifiquemos": "aerificar",
    "aerifiques": "aerificar",
    "aeriformes": "aeriforme",
    "aeriza": "aerizar",
    "aerizada": "aerizar",
    "aerizadas": "aerizar",
    "aerizado": "aerizar",
    "aerizados": "aerizar",
    "aerizai": "aerizar",
    "aerizais": "aerizar",
    "aerizam": "aerizar",
    "aerizamo": "aerizar",
    "aerizamos": "aerizar",
    "aerizando": "aerizar",
    "aerizara": "aerizar",
    "aerizaram": "aerizar",
    "aerizaras": "aerizar",
    "aerizarde": "aerizar",
    "aerizardes": "aerizar",
    "aerizare": "aerizar",
    "aerizarei": "aerizar",
    "aerizareis": "aerizar",
    "aerizarem": "aerizar",
    "aerizaremos": "aerizar",
    "aerizares": "aerizar",
    "aerizaria": "aerizar",
    "aerizariam": "aerizar",
    "aerizarias": "aerizar",
    "aerizarmo": "aerizar",
    "aerizarmos": "aerizar",
    "aerizará": "aerizar",
    "aerizarás": "aerizar",
    "aerizarão": "aerizar",
    "aerizaríamos": "aerizar",
    "aerizaríeis": "aerizar",
    "aerizas": "aerizar",
    "aerizasse": "aerizar",
    "aerizassem": "aerizar",
    "aerizasses": "aerizar",
    "aerizaste": "aerizar",
    "aerizastes": "aerizar",
    "aerizava": "aerizar",
    "aerizavam": "aerizar",
    "aerizavas": "aerizar",
    "aerizações": "aerização",
    "aerize": "aerizar",
    "aerizei": "aerizar",
    "aerizeis": "aerizar",
    "aerizem": "aerizar",
    "aerizemo": "aerizar",
    "aerizemos": "aerizar",
    "aerizes": "aerizar",
    "aerizo": "aerizar",
    "aerizou": "aerizar",
    "aerizá": "aerizar",
    "aerizámo": "aerizar",
    "aerizámos": "aerizar",
    "aerizáramo": "aerizar",
    "aerizáramos": "aerizar",
    "aerizárei": "aerizar",
    "aerizáreis": "aerizar",
    "aerizásseis": "aerizar",
    "aerizássemos": "aerizar",
    "aerizávamo": "aerizar",
    "aerizávamos": "aerizar",
    "aerizávei": "aerizar",
    "aerizáveis": "aerizar",
    "aerobalísticas": "aerobalística",
    "aeroblastos": "aeroblasto",
    "aeroclubes": "aeroclube",
    "aerocondensadores": "aerocondensador",
    "aerodinâmica": "aerodinâmico",
    "aerodinâmicas": "aerodinâmico",
    "aerodinâmicos": "aerodinâmico",
    "aeroductos": "aeroducto",
    "aeroelasticidades": "aeroelasticidade",
    "aeroespaciais": "aeroespacial",
    "aeroespaços": "aeroespaço",
    "aerofaga": "aerofago",
    "aerofagas": "aerofago",
    "aerofagias": "aerofagia",
    "aerofagos": "aerofago",
    "aerofilmes": "aerofilme",
    "aerofobias": "aerofobia",
    "aerofísicas": "aerofísica",
    "aerofólios": "aerofólio",
    "aerogares": "aerogare",
    "aerognosias": "aerognosia",
    "aerognostas": "aerognosta",
    "aerografias": "aerografia",
    "aerogramas": "aerograma",
    "aerologias": "aerologia",
    "aerolítica": "aerolítico",
    "aerolíticas": "aerolítico",
    "aerolíticos": "aerolítico",
    "aeromancias": "aeromancia",
    "aeromantes": "aeromante",
    "aerometrias": "aerometria",
    "aeromodelismos": "aeromodelismo",
    "aeromodelistas": "aeromodelista",
    "aeromotores": "aeromotor",
    "aeromotos": "aeromoto",
    "aeromântica": "aeromântico",
    "aeromânticas": "aeromântico",
    "aeromânticos": "aeromântico",
    "aerométrica": "aerométrico",
    "aerométricas": "aerométrico",
    "aerométricos": "aerométrico",
    "aeronautas": "aeronauta",
    "aeronavegações": "aeronavegação",
    "aeronaves": "aeronave",
    "aeronáutica": "aeronáutico",
    "aeronáuticas": "aeronáutico",
    "aeronáuticos": "aeronáutico",
    "aeropausas": "aeropausa",
    "aeropistas": "aeropista",
    "aeroplanismos": "aeroplanismo",
    "aeroplanos": "aeroplano",
    "aeroportos": "aeroporto",
    "aeroportuária": "aeroportuário",
    "aeroportuárias": "aeroportuário",
    "aeroportuários": "aeroportuário",
    "aeropostais": "aeropostal",
    "aeropostas": "aeroposta",
    "aeroscopias": "aeroscopia",
    "aeroscópios": "aeroscópio",
    "aerosferas": "aerosfera",
    "aerospaciais": "aerospacial",
    "aerossóis": "aerossol",
    "aerostações": "aerostação",
    "aerostática": "aerostático",
    "aerostáticas": "aerostático",
    "aerostáticos": "aerostático",
    "aerotanques": "aerotanque",
    "aerotecnias": "aerotecnia",
    "aeroterapeutas": "aeroterapeuta",
    "aeroterapias": "aeroterapia",
    "aeroterapêutica": "aeroterapêutico",
    "aeroterapêuticas": "aeroterapêutico",
    "aeroterapêuticos": "aeroterapêutico",
    "aerotermodinâmicas": "aerotermodinâmica",
    "aerotermos": "aerotermo",
    "aeroterápica": "aeroterápico",
    "aeroterápicas": "aeroterápico",
    "aeroterápicos": "aeroterápico",
    "aerotransportada": "aerotransportado",
    "aerotransportadas": "aerotransportado",
    "aerotransportadoras": "aerotransportadora",
    "aerotransportados": "aerotransportado",
    "aerotransportes": "aerotransporte",
    "aerotropismos": "aerotropismo",
    "aerotáxis": "aerotáxi",
    "aerotécnica": "aerotécnico",
    "aerotécnicas": "aerotécnico",
    "aerotécnicos": "aerotécnico",
    "aerotérmica": "aerotérmico",
    "aerotérmicas": "aerotérmico",
    "aerotérmicos": "aerotérmico",
    "aerovias": "aerovia",
    "aerícolas": "aerícola",
    "aerífera": "aerífero",
    "aeríferas": "aerífero",
    "aeríferos": "aerífero",
    "aerívora": "aerívoro",
    "aerívoras": "aerívoro",
    "aerívoros": "aerívoro",
    "aeróbatas": "aeróbata",
    "aeróbia": "aeróbio",
    "aeróbias": "aeróbio",
    "aeróbica": "aeróbico",
    "aeróbicas": "aeróbico",
    "aeróbicos": "aeróbico",
    "aeróbios": "aeróbio",
    "aeródinos": "aeródino",
    "aeródromos": "aeródromo",
    "aerófaga": "aerófago",
    "aerófagas": "aerófago",
    "aerófagos": "aerófago",
    "aerófita": "aerófito",
    "aerófitas": "aerófito",
    "aerófitos": "aerófito",
    "aerófoba": "aerófobo",
    "aerófobas": "aerófobo",
    "aerófobos": "aerófobo",
    "aerógrafos": "aerógrafo",
    "aeróides": "aeróide",
    "aerólitos": "aerólito",
    "aerólogos": "aerólogo",
    "aerómetros": "aerómetro",
    "aeróstatos": "aeróstato",
    "aetites": "aetite",
    "afabilidades": "afabilidade",
    "afacias": "afacia",
    "afadiga": "afadigar",
    "afadigada": "afadigar",
    "afadigadas": "afadigar",
    "afadigado": "afadigar",
    "afadigados": "afadigar",
    "afadigadíssima": "afadigado",
    "afadigadíssimas": "afadigado",
    "afadigadíssimo": "afadigado",
    "afadigadíssimos": "afadigado",
    "afadigai": "afadigar",
    "afadigais": "afadigar",
    "afadigam": "afadigar",
    "afadigamo": "afadigar",
    "afadigamos": "afadigar",
    "afadigando": "afadigar",
    "afadigara": "afadigar",
    "afadigaram": "afadigar",
    "afadigaras": "afadigar",
    "afadigarde": "afadigar",
    "afadigardes": "afadigar",
    "afadigare": "afadigar",
    "afadigarei": "afadigar",
    "afadigareis": "afadigar",
    "afadigarem": "afadigar",
    "afadigaremos": "afadigar",
    "afadigares": "afadigar",
    "afadigaria": "afadigar",
    "afadigariam": "afadigar",
    "afadigarias": "afadigar",
    "afadigarmo": "afadigar",
    "afadigarmos": "afadigar",
    "afadigará": "afadigar",
    "afadigarás": "afadigar",
    "afadigarão": "afadigar",
    "afadigaríamos": "afadigar",
    "afadigaríeis": "afadigar",
    "afadigas": "afadigar",
    "afadigasse": "afadigar",
    "afadigassem": "afadigar",
    "afadigasses": "afadigar",
    "afadigaste": "afadigar",
    "afadigastes": "afadigar",
    "afadigava": "afadigar",
    "afadigavam": "afadigar",
    "afadigavas": "afadigar",
    "afadigo": "afadigar",
    "afadigosa": "afadigoso",
    "afadigosas": "afadigoso",
    "afadigosos": "afadigoso",
    "afadigou": "afadigar",
    "afadigue": "afadigar",
    "afadiguei": "afadigar",
    "afadigueis": "afadigar",
    "afadiguem": "afadigar",
    "afadiguemo": "afadigar",
    "afadiguemos": "afadigar",
    "afadigues": "afadigar",
    "afadigá": "afadigar",
    "afadigámo": "afadigar",
    "afadigámos": "afadigar",
    "afadigáramo": "afadigar",
    "afadigáramos": "afadigar",
    "afadigárei": "afadigar",
    "afadigáreis": "afadigar",
    "afadigásseis": "afadigar",
    "afadigássemos": "afadigar",
    "afadigávamo": "afadigar",
    "afadigávamos": "afadigar",
    "afadigávei": "afadigar",
    "afadigáveis": "afadigar",
    "afadista": "afadistar",
    "afadistada": "afadistar",
    "afadistadas": "afadistar",
    "afadistado": "afadistar",
    "afadistados": "afadistar",
    "afadistai": "afadistar",
    "afadistais": "afadistar",
    "afadistam": "afadistar",
    "afadistamo": "afadistar",
    "afadistamos": "afadistar",
    "afadistando": "afadistar",
    "afadistara": "afadistar",
    "afadistaram": "afadistar",
    "afadistaras": "afadistar",
    "afadistarde": "afadistar",
    "afadistardes": "afadistar",
    "afadistare": "afadistar",
    "afadistarei": "afadistar",
    "afadistareis": "afadistar",
    "afadistarem": "afadistar",
    "afadistaremos": "afadistar",
    "afadistares": "afadistar",
    "afadistaria": "afadistar",
    "afadistariam": "afadistar",
    "afadistarias": "afadistar",
    "afadistarmo": "afadistar",
    "afadistarmos": "afadistar",
    "afadistará": "afadistar",
    "afadistarás": "afadistar",
    "afadistarão": "afadistar",
    "afadistaríamos": "afadistar",
    "afadistaríeis": "afadistar",
    "afadistas": "afadistar",
    "afadistasse": "afadistar",
    "afadistassem": "afadistar",
    "afadistasses": "afadistar",
    "afadistaste": "afadistar",
    "afadistastes": "afadistar",
    "afadistava": "afadistar",
    "afadistavam": "afadistar",
    "afadistavas": "afadistar",
    "afadiste": "afadistar",
    "afadistei": "afadistar",
    "afadisteis": "afadistar",
    "afadistem": "afadistar",
    "afadistemo": "afadistar",
    "afadistemos": "afadistar",
    "afadistes": "afadistar",
    "afadisto": "afadistar",
    "afadistou": "afadistar",
    "afadistá": "afadistar",
    "afadistámo": "afadistar",
    "afadistámos": "afadistar",
    "afadistáramo": "afadistar",
    "afadistáramos": "afadistar",
    "afadistárei": "afadistar",
    "afadistáreis": "afadistar",
    "afadistásseis": "afadistar",
    "afadistássemos": "afadistar",
    "afadistávamo": "afadistar",
    "afadistávamos": "afadistar",
    "afadistávei": "afadistar",
    "afadistáveis": "afadistar",
    "afaga": "afagar",
    "afagada": "afagar",
    "afagadas": "afagar",
    "afagado": "afagar",
    "afagadora": "afagador",
    "afagadoras": "afagadora",
    "afagadores": "afagador",
    "afagados": "afagar",
    "afagai": "afagar",
    "afagais": "afagar",
    "afagam": "afagar",
    "afagamentos": "afagamento",
    "afagamo": "afagar",
    "afagamos": "afagar",
    "afagando": "afagar",
    "afagara": "afagar",
    "afagaram": "afagar",
    "afagaras": "afagar",
    "afagarde": "afagar",
    "afagardes": "afagar",
    "afagare": "afagar",
    "afagarei": "afagar",
    "afagareis": "afagar",
    "afagarem": "afagar",
    "afagaremos": "afagar",
    "afagares": "afagar",
    "afagaria": "afagar",
    "afagariam": "afagar",
    "afagarias": "afagar",
    "afagarmo": "afagar",
    "afagarmos": "afagar",
    "afagará": "afagar",
    "afagarás": "afagar",
    "afagarão": "afagar",
    "afagaríamos": "afagar",
    "afagaríeis": "afagar",
    "afagas": "afagar",
    "afagasse": "afagar",
    "afagassem": "afagar",
    "afagasses": "afagar",
    "afagaste": "afagar",
    "afagastes": "afagar",
    "afagava": "afagar",
    "afagavam": "afagar",
    "afagavas": "afagar",
    "afago": "afagar",
    "afagos": "afago",
    "afagosa": "afagoso",
    "afagosas": "afagoso",
    "afagosos": "afagoso",
    "afagou": "afagar",
    "afague": "afagar",
    "afaguei": "afagar",
    "afagueis": "afagar",
    "afaguem": "afagar",
    "afaguemo": "afagar",
    "afaguemos": "afagar",
    "afagues": "afagar",
    "afagá": "afagar",
    "afagámo": "afagar",
    "afagámos": "afagar",
    "afagáramo": "afagar",
    "afagáramos": "afagar",
    "afagárei": "afagar",
    "afagáreis": "afagar",
    "afagásseis": "afagar",
    "afagássemos": "afagar",
    "afagávamo": "afagar",
    "afagávamos": "afagar",
    "afagávei": "afagar",
    "afagáveis": "afagar",
    "afaina": "afainar",
    "afainada": "afainar",
    "afainadas": "afainar",
    "afainado": "afainar",
    "afainados": "afainar",
    "afainai": "afainar",
    "afainais": "afainar",
    "afainam": "afainar",
    "afainamo": "afainar",
    "afainamos": "afainar",
    "afainando": "afainar",
    "afainara": "afainar",
    "afainaram": "afainar",
    "afainaras": "afainar",
    "afainarde": "afainar",
    "afainardes": "afainar",
    "afainare": "afainar",
    "afainarei": "afainar",
    "afainareis": "afainar",
    "afainarem": "afainar",
    "afainaremos": "afainar",
    "afainares": "afainar",
    "afainaria": "afainar",
    "afainariam": "afainar",
    "afainarias": "afainar",
    "afainarmo": "afainar",
    "afainarmos": "afainar",
    "afainará": "afainar",
    "afainarás": "afainar",
    "afainarão": "afainar",
    "afainaríamos": "afainar",
    "afainaríeis": "afainar",
    "afainas": "afainar",
    "afainasse": "afainar",
    "afainassem": "afainar",
    "afainasses": "afainar",
    "afainaste": "afainar",
    "afainastes": "afainar",
    "afainava": "afainar",
    "afainavam": "afainar",
    "afainavas": "afainar",
    "afaine": "afainar",
    "afainei": "afainar",
    "afaineis": "afainar",
    "afainem": "afainar",
    "afainemo": "afainar",
    "afainemos": "afainar",
    "afaines": "afainar",
    "afaino": "afainar",
    "afainou": "afainar",
    "afainá": "afainar",
    "afainámo": "afainar",
    "afainámos": "afainar",
    "afaináramo": "afainar",
    "afaináramos": "afainar",
    "afainárei": "afainar",
    "afaináreis": "afainar",
    "afainásseis": "afainar",
    "afainássemos": "afainar",
    "afainávamo": "afainar",
    "afainávamos": "afainar",
    "afainávei": "afainar",
    "afaináveis": "afainar",
    "afala": "afalar",
    "afalada": "afalar",
    "afaladas": "afalar",
    "afalado": "afalar",
    "afalados": "afalar",
    "afalai": "afalar",
    "afalais": "afalar",
    "afalam": "afalar",
    "afalamo": "afalar",
    "afalamos": "afalar",
    "afalando": "afalar",
    "afalara": "afalar",
    "afalaram": "afalar",
    "afalaras": "afalar",
    "afalarde": "afalar",
    "afalardes": "afalar",
    "afalare": "afalar",
    "afalarei": "afalar",
    "afalareis": "afalar",
    "afalarem": "afalar",
    "afalaremos": "afalar",
    "afalares": "afalar",
    "afalaria": "afalar",
    "afalariam": "afalar",
    "afalarias": "afalar",
    "afalarmo": "afalar",
    "afalarmos": "afalar",
    "afalará": "afalar",
    "afalarás": "afalar",
    "afalarão": "afalar",
    "afalaríamos": "afalar",
    "afalaríeis": "afalar",
    "afalas": "afalar",
    "afalasse": "afalar",
    "afalassem": "afalar",
    "afalasses": "afalar",
    "afalaste": "afalar",
    "afalastes": "afalar",
    "afalava": "afalar",
    "afalavam": "afalar",
    "afalavas": "afalar",
    "afalcoa": "afalcoar",
    "afalcoada": "afalcoar",
    "afalcoadas": "afalcoar",
    "afalcoado": "afalcoar",
    "afalcoados": "afalcoar",
    "afalcoai": "afalcoar",
    "afalcoais": "afalcoar",
    "afalcoam": "afalcoar",
    "afalcoamo": "afalcoar",
    "afalcoamos": "afalcoar",
    "afalcoando": "afalcoar",
    "afalcoara": "afalcoar",
    "afalcoaram": "afalcoar",
    "afalcoaras": "afalcoar",
    "afalcoardes": "afalcoar",
    "afalcoarei": "afalcoar",
    "afalcoareis": "afalcoar",
    "afalcoarem": "afalcoar",
    "afalcoaremos": "afalcoar",
    "afalcoares": "afalcoar",
    "afalcoaria": "afalcoar",
    "afalcoariam": "afalcoar",
    "afalcoarias": "afalcoar",
    "afalcoarmo": "afalcoar",
    "afalcoarmos": "afalcoar",
    "afalcoará": "afalcoar",
    "afalcoarás": "afalcoar",
    "afalcoarão": "afalcoar",
    "afalcoaríamos": "afalcoar",
    "afalcoaríeis": "afalcoar",
    "afalcoas": "afalcoar",
    "afalcoasse": "afalcoar",
    "afalcoassem": "afalcoar",
    "afalcoasses": "afalcoar",
    "afalcoaste": "afalcoar",
    "afalcoastes": "afalcoar",
    "afalcoava": "afalcoar",
    "afalcoavam": "afalcoar",
    "afalcoavas": "afalcoar",
    "afalcoe": "afalcoar",
    "afalcoei": "afalcoar",
    "afalcoeis": "afalcoar",
    "afalcoem": "afalcoar",
    "afalcoemo": "afalcoar",
    "afalcoemos": "afalcoar",
    "afalcoes": "afalcoar",
    "afalcoo": "afalcoar",
    "afalcoou": "afalcoar",
    "afalcoámo": "afalcoar",
    "afalcoámos": "afalcoar",
    "afalcoáramo": "afalcoar",
    "afalcoáramos": "afalcoar",
    "afalcoáreis": "afalcoar",
    "afalcoásseis": "afalcoar",
    "afalcoássemos": "afalcoar",
    "afalcoávamo": "afalcoar",
    "afalcoávamos": "afalcoar",
    "afalcoáveis": "afalcoar",
    "afale": "afalar",
    "afalei": "afalar",
    "afaleis": "afalar",
    "afalem": "afalar",
    "afalemo": "afalar",
    "afalemos": "afalar",
    "afales": "afalar",
    "afalo": "afalar",
    "afalou": "afalar",
    "afalá": "afalar",
    "afalámo": "afalar",
    "afalámos": "afalar",
    "afaláramo": "afalar",
    "afaláramos": "afalar",
    "afalárei": "afalar",
    "afaláreis": "afalar",
    "afalásseis": "afalar",
    "afalássemos": "afalar",
    "afalávamo": "afalar",
    "afalávamos": "afalar",
    "afalávei": "afalar",
    "afaláveis": "afalar",
    "afama": "afamar",
    "afamada": "afamar",
    "afamadas": "afamar",
    "afamadeira": "afamador",
    "afamadeiras": "afamador",
    "afamado": "afamar",
    "afamadora": "afamador",
    "afamadoras": "afamador",
    "afamadores": "afamador",
    "afamados": "afamar",
    "afamadíssima": "afamado",
    "afamadíssimas": "afamado",
    "afamadíssimo": "afamado",
    "afamadíssimos": "afamado",
    "afamai": "afamar",
    "afamais": "afamar",
    "afamam": "afamar",
    "afamamo": "afamar",
    "afamamos": "afamar",
    "afamando": "afamar",
    "afamara": "afamar",
    "afamaram": "afamar",
    "afamaras": "afamar",
    "afamarde": "afamar",
    "afamardes": "afamar",
    "afamare": "afamar",
    "afamarei": "afamar",
    "afamareis": "afamar",
    "afamarem": "afamar",
    "afamaremos": "afamar",
    "afamares": "afamar",
    "afamaria": "afamar",
    "afamariam": "afamar",
    "afamarias": "afamar",
    "afamarmo": "afamar",
    "afamarmos": "afamar",
    "afamará": "afamar",
    "afamarás": "afamar",
    "afamarão": "afamar",
    "afamaríamos": "afamar",
    "afamaríeis": "afamar",
    "afamas": "afamar",
    "afamasse": "afamar",
    "afamassem": "afamar",
    "afamasses": "afamar",
    "afamaste": "afamar",
    "afamastes": "afamar",
    "afamava": "afamar",
    "afamavam": "afamar",
    "afamavas": "afamar",
    "afame": "afamar",
    "afamei": "afamar",
    "afameis": "afamar",
    "afamem": "afamar",
    "afamemo": "afamar",
    "afamemos": "afamar",
    "afames": "afamar",
    "afamo": "afamar",
    "afamou": "afamar",
    "afamá": "afamar",
    "afamámo": "afamar",
    "afamámos": "afamar",
    "afamáramo": "afamar",
    "afamáramos": "afamar",
    "afamárei": "afamar",
    "afamáreis": "afamar",
    "afamásseis": "afamar",
    "afamássemos": "afamar",
    "afamávamo": "afamar",
    "afamávamos": "afamar",
    "afamávei": "afamar",
    "afamáveis": "afamar",
    "afana": "afanar",
    "afanada": "afanar",
    "afanadas": "afanar",
    "afanado": "afanar",
    "afanados": "afanar",
    "afanai": "afanar",
    "afanais": "afanar",
    "afanam": "afanar",
    "afanamo": "afanar",
    "afanamos": "afanar",
    "afanando": "afanar",
    "afanara": "afanar",
    "afanaram": "afanar",
    "afanaras": "afanar",
    "afanarde": "afanar",
    "afanardes": "afanar",
    "afanare": "afanar",
    "afanarei": "afanar",
    "afanareis": "afanar",
    "afanarem": "afanar",
    "afanaremos": "afanar",
    "afanares": "afanar",
    "afanaria": "afanar",
    "afanariam": "afanar",
    "afanarias": "afanar",
    "afanarmo": "afanar",
    "afanarmos": "afanar",
    "afanará": "afanar",
    "afanarás": "afanar",
    "afanarão": "afanar",
    "afanaríamos": "afanar",
    "afanaríeis": "afanar",
    "afanas": "afanar",
    "afanasse": "afanar",
    "afanassem": "afanar",
    "afanasses": "afanar",
    "afanaste": "afanar",
    "afanastes": "afanar",
    "afanava": "afanar",
    "afanavam": "afanar",
    "afanavas": "afanar",
    "afanchonada": "afanchonado",
    "afanchonadas": "afanchonado",
    "afanchonados": "afanchonado",
    "afandanga": "afandangar",
    "afandangada": "afandangar",
    "afandangadas": "afandangar",
    "afandangado": "afandangar",
    "afandangados": "afandangar",
    "afandangai": "afandangar",
    "afandangais": "afandangar",
    "afandangam": "afandangar",
    "afandangamo": "afandangar",
    "afandangamos": "afandangar",
    "afandangando": "afandangar",
    "afandangara": "afandangar",
    "afandangaram": "afandangar",
    "afandangaras": "afandangar",
    "afandangarde": "afandangar",
    "afandangardes": "afandangar",
    "afandangare": "afandangar",
    "afandangarei": "afandangar",
    "afandangareis": "afandangar",
    "afandangarem": "afandangar",
    "afandangaremos": "afandangar",
    "afandangares": "afandangar",
    "afandangaria": "afandangar",
    "afandangariam": "afandangar",
    "afandangarias": "afandangar",
    "afandangarmo": "afandangar",
    "afandangarmos": "afandangar",
    "afandangará": "afandangar",
    "afandangarás": "afandangar",
    "afandangarão": "afandangar",
    "afandangaríamos": "afandangar",
    "afandangaríeis": "afandangar",
    "afandangas": "afandangar",
    "afandangasse": "afandangar",
    "afandangassem": "afandangar",
    "afandangasses": "afandangar",
    "afandangaste": "afandangar",
    "afandangastes": "afandangar",
    "afandangava": "afandangar",
    "afandangavam": "afandangar",
    "afandangavas": "afandangar",
    "afandango": "afandangar",
    "afandangou": "afandangar",
    "afandangue": "afandangar",
    "afandanguei": "afandangar",
    "afandangueis": "afandangar",
    "afandanguem": "afandangar",
    "afandanguemo": "afandangar",
    "afandanguemos": "afandangar",
    "afandangues": "afandangar",
    "afandangá": "afandangar",
    "afandangámo": "afandangar",
    "afandangámos": "afandangar",
    "afandangáramo": "afandangar",
    "afandangáramos": "afandangar",
    "afandangárei": "afandangar",
    "afandangáreis": "afandangar",
    "afandangásseis": "afandangar",
    "afandangássemos": "afandangar",
    "afandangávamo": "afandangar",
    "afandangávamos": "afandangar",
    "afandangávei": "afandangar",
    "afandangáveis": "afandangar",
    "afane": "afanar",
    "afanei": "afanar",
    "afaneis": "afanar",
    "afanem": "afanar",
    "afanemo": "afanar",
    "afanemos": "afanar",
    "afanes": "afanar",
    "afano": "afanar",
    "afanou": "afanar",
    "afaná": "afanar",
    "afanámo": "afanar",
    "afanámos": "afanar",
    "afanáramo": "afanar",
    "afanáramos": "afanar",
    "afanárei": "afanar",
    "afanáreis": "afanar",
    "afanásseis": "afanar",
    "afanássemos": "afanar",
    "afanávamo": "afanar",
    "afanávamos": "afanar",
    "afanávei": "afanar",
    "afanáveis": "afanar",
    "afanítica": "afanítico",
    "afaníticas": "afanítico",
    "afaníticos": "afanítico",
    "afara": "afarar",
    "afarada": "afarar",
    "afaradas": "afarar",
    "afarado": "afarar",
    "afarados": "afarar",
    "afarai": "afarar",
    "afarais": "afarar",
    "afaram": "afarar",
    "afaramo": "afarar",
    "afaramos": "afarar",
    "afarando": "afarar",
    "afarara": "afarar",
    "afararam": "afarar",
    "afararas": "afarar",
    "afararde": "afarar",
    "afarardes": "afarar",
    "afarare": "afarar",
    "afararei": "afarar",
    "afarareis": "afarar",
    "afararem": "afarar",
    "afararemos": "afarar",
    "afarares": "afarar",
    "afararia": "afarar",
    "afarariam": "afarar",
    "afararias": "afarar",
    "afararmo": "afarar",
    "afararmos": "afarar",
    "afarará": "afarar",
    "afararás": "afarar",
    "afararão": "afarar",
    "afararíamos": "afarar",
    "afararíeis": "afarar",
    "afaras": "afarar",
    "afarasse": "afarar",
    "afarassem": "afarar",
    "afarasses": "afarar",
    "afaraste": "afarar",
    "afarastes": "afarar",
    "afarava": "afarar",
    "afaravam": "afarar",
    "afaravas": "afarar",
    "afare": "afarar",
    "afarei": "afazer",
    "afareis": "afazer",
    "afarem": "afarar",
    "afaremo": "afarar",
    "afaremos": "afazer",
    "afares": "afarar",
    "afaria": "afazer",
    "afariam": "afazer",
    "afarias": "afazer",
    "afaro": "afarar",
    "afarou": "afarar",
    "afará": "afazer",
    "afarámo": "afarar",
    "afarámos": "afarar",
    "afaráramo": "afarar",
    "afaráramos": "afarar",
    "afarárei": "afarar",
    "afaráreis": "afarar",
    "afarás": "afazer",
    "afarásseis": "afarar",
    "afarássemos": "afarar",
    "afarávamo": "afarar",
    "afarávamos": "afarar",
    "afarávei": "afarar",
    "afaráveis": "afarar",
    "afarão": "afazer",
    "afaríamos": "afazer",
    "afaríeis": "afazer",
    "afasias": "afasia",
    "afasta": "afastar",
    "afastada": "afastar",
    "afastadas": "afastar",
    "afastadinha": "afastado",
    "afastadinhas": "afastado",
    "afastadinho": "afastado",
    "afastadinhos": "afastado",
    "afastadita": "afastado",
    "afastaditas": "afastado",
    "afastadito": "afastado",
    "afastaditos": "afastado",
    "afastado": "afastar",
    "afastadora": "afastador",
    "afastadoras": "afastador",
    "afastadores": "afastador",
    "afastados": "afastar",
    "afastadíssima": "afastado",
    "afastadíssimas": "afastado",
    "afastadíssimo": "afastado",
    "afastadíssimos": "afastado",
    "afastai": "afastar",
    "afastais": "afastar",
    "afastam": "afastar",
    "afastamentos": "afastamento",
    "afastamo": "afastar",
    "afastamos": "afastar",
    "afastando": "afastar",
    "afastara": "afastar",
    "afastaram": "afastar",
    "afastaras": "afastar",
    "afastarde": "afastar",
    "afastardes": "afastar",
    "afastare": "afastar",
    "afastarei": "afastar",
    "afastareis": "afastar",
    "afastarem": "afastar",
    "afastaremos": "afastar",
    "afastares": "afastar",
    "afastaria": "afastar",
    "afastariam": "afastar",
    "afastarias": "afastar",
    "afastarmo": "afastar",
    "afastarmos": "afastar",
    "afastará": "afastar",
    "afastarás": "afastar",
    "afastarão": "afastar",
    "afastaríamos": "afastar",
    "afastaríeis": "afastar",
    "afastas": "afastar",
    "afastasse": "afastar",
    "afastassem": "afastar",
    "afastasses": "afastar",
    "afastaste": "afastar",
    "afastastes": "afastar",
    "afastava": "afastar",
    "afastavam": "afastar",
    "afastavas": "afastar",
    "afaste": "afastar",
    "afastei": "afastar",
    "afasteis": "afastar",
    "afastem": "afastar",
    "afastemo": "afastar",
    "afastemos": "afastar",
    "afastes": "afastar",
    "afasto": "afastar",
    "afastou": "afastar",
    "afastá": "afastar",
    "afastámo": "afastar",
    "afastámos": "afastar",
    "afastáramo": "afastar",
    "afastáramos": "afastar",
    "afastárei": "afastar",
    "afastáreis": "afastar",
    "afastásseis": "afastar",
    "afastássemos": "afastar",
    "afastávamo": "afastar",
    "afastávamos": "afastar",
    "afastávei": "afastar",
    "afastáveis": "afastável",
    "afatia": "afatiar",
    "afatiada": "afatiar",
    "afatiadas": "afatiar",
    "afatiado": "afatiar",
    "afatiados": "afatiar",
    "afatiai": "afatiar",
    "afatiais": "afatiar",
    "afatiam": "afatiar",
    "afatiamo": "afatiar",
    "afatiamos": "afatiar",
    "afatiando": "afatiar",
    "afatiara": "afatiar",
    "afatiaram": "afatiar",
    "afatiaras": "afatiar",
    "afatiarde": "afatiar",
    "afatiardes": "afatiar",
    "afatiare": "afatiar",
    "afatiarei": "afatiar",
    "afatiareis": "afatiar",
    "afatiarem": "afatiar",
    "afatiaremos": "afatiar",
    "afatiares": "afatiar",
    "afatiaria": "afatiar",
    "afatiariam": "afatiar",
    "afatiarias": "afatiar",
    "afatiarmo": "afatiar",
    "afatiarmos": "afatiar",
    "afatiará": "afatiar",
    "afatiarás": "afatiar",
    "afatiarão": "afatiar",
    "afatiaríamos": "afatiar",
    "afatiaríeis": "afatiar",
    "afatias": "afatiar",
    "afatiasse": "afatiar",
    "afatiassem": "afatiar",
    "afatiasses": "afatiar",
    "afatiaste": "afatiar",
    "afatiastes": "afatiar",
    "afatiava": "afatiar",
    "afatiavam": "afatiar",
    "afatiavas": "afatiar",
    "afatie": "afatiar",
    "afatiei": "afatiar",
    "afatieis": "afatiar",
    "afatiem": "afatiar",
    "afatiemo": "afatiar",
    "afatiemos": "afatiar",
    "afaties": "afatiar",
    "afatio": "afatiar",
    "afatiou": "afatiar",
    "afatiá": "afatiar",
    "afatiámo": "afatiar",
    "afatiámos": "afatiar",
    "afatiáramo": "afatiar",
    "afatiáramos": "afatiar",
    "afatiárei": "afatiar",
    "afatiáreis": "afatiar",
    "afatiásseis": "afatiar",
    "afatiássemos": "afatiar",
    "afatiávamo": "afatiar",
    "afatiávamos": "afatiar",
    "afatiávei": "afatiar",
    "afatiáveis": "afatiar",
    "afaxina": "afaxinar",
    "afaxinada": "afaxinar",
    "afaxinadas": "afaxinar",
    "afaxinado": "afaxinar",
    "afaxinados": "afaxinar",
    "afaxinai": "afaxinar",
    "afaxinais": "afaxinar",
    "afaxinam": "afaxinar",
    "afaxinamo": "afaxinar",
    "afaxinamos": "afaxinar",
    "afaxinando": "afaxinar",
    "afaxinara": "afaxinar",
    "afaxinaram": "afaxinar",
    "afaxinaras": "afaxinar",
    "afaxinarde": "afaxinar",
    "afaxinardes": "afaxinar",
    "afaxinare": "afaxinar",
    "afaxinarei": "afaxinar",
    "afaxinareis": "afaxinar",
    "afaxinarem": "afaxinar",
    "afaxinaremos": "afaxinar",
    "afaxinares": "afaxinar",
    "afaxinaria": "afaxinar",
    "afaxinariam": "afaxinar",
    "afaxinarias": "afaxinar",
    "afaxinarmo": "afaxinar",
    "afaxinarmos": "afaxinar",
    "afaxinará": "afaxinar",
    "afaxinarás": "afaxinar",
    "afaxinarão": "afaxinar",
    "afaxinaríamos": "afaxinar",
    "afaxinaríeis": "afaxinar",
    "afaxinas": "afaxinar",
    "afaxinasse": "afaxinar",
    "afaxinassem": "afaxinar",
    "afaxinasses": "afaxinar",
    "afaxinaste": "afaxinar",
    "afaxinastes": "afaxinar",
    "afaxinava": "afaxinar",
    "afaxinavam": "afaxinar",
    "afaxinavas": "afaxinar",
    "afaxine": "afaxinar",
    "afaxinei": "afaxinar",
    "afaxineis": "afaxinar",
    "afaxinem": "afaxinar",
    "afaxinemo": "afaxinar",
    "afaxinemos": "afaxinar",
    "afaxines": "afaxinar",
    "afaxino": "afaxinar",
    "afaxinou": "afaxinar",
    "afaxiná": "afaxinar",
    "afaxinámo": "afaxinar",
    "afaxinámos": "afaxinar",
    "afaxináramo": "afaxinar",
    "afaxináramos": "afaxinar",
    "afaxinárei": "afaxinar",
    "afaxináreis": "afaxinar",
    "afaxinásseis": "afaxinar",
    "afaxinássemos": "afaxinar",
    "afaxinávamo": "afaxinar",
    "afaxinávamos": "afaxinar",
    "afaxinávei": "afaxinar",
    "afaxináveis": "afaxinar",
    "afaz": "afazer",
    "afaze": "afazer",
    "afazei": "afazer",
    "afazeis": "afazer",
    "afazem": "afazer",
    "afazemo": "afazer",
    "afazemos": "afazer",
    "afazenda": "afazendar",
    "afazendada": "afazendar",
    "afazendadas": "afazendar",
    "afazendado": "afazendar",
    "afazendados": "afazendar",
    "afazendai": "afazendar",
    "afazendais": "afazendar",
    "afazendam": "afazendar",
    "afazendamo": "afazendar",
    "afazendamos": "afazendar",
    "afazendando": "afazendar",
    "afazendara": "afazendar",
    "afazendaram": "afazendar",
    "afazendaras": "afazendar",
    "afazendarde": "afazendar",
    "afazendardes": "afazendar",
    "afazendare": "afazendar",
    "afazendarei": "afazendar",
    "afazendareis": "afazendar",
    "afazendarem": "afazendar",
    "afazendaremos": "afazendar",
    "afazendares": "afazendar",
    "afazendaria": "afazendar",
    "afazendariam": "afazendar",
    "afazendarias": "afazendar",
    "afazendarmo": "afazendar",
    "afazendarmos": "afazendar",
    "afazendará": "afazendar",
    "afazendarás": "afazendar",
    "afazendarão": "afazendar",
    "afazendaríamos": "afazendar",
    "afazendaríeis": "afazendar",
    "afazendas": "afazendar",
    "afazendasse": "afazendar",
    "afazendassem": "afazendar",
    "afazendasses": "afazendar",
    "afazendaste": "afazendar",
    "afazendastes": "afazendar",
    "afazendava": "afazendar",
    "afazendavam": "afazendar",
    "afazendavas": "afazendar",
    "afazende": "afazendar",
    "afazendei": "afazendar",
    "afazendeis": "afazendar",
    "afazendem": "afazendar",
    "afazendemo": "afazendar",
    "afazendemos": "afazendar",
    "afazendes": "afazendar",
    "afazendo": "afazer",
    "afazendou": "afazendar",
    "afazendá": "afazendar",
    "afazendámo": "afazendar",
    "afazendámos": "afazendar",
    "afazendáramo": "afazendar",
    "afazendáramos": "afazendar",
    "afazendárei": "afazendar",
    "afazendáreis": "afazendar",
    "afazendásseis": "afazendar",
    "afazendássemos": "afazendar",
    "afazendávamo": "afazendar",
    "afazendávamos": "afazendar",
    "afazendávei": "afazendar",
    "afazendáveis": "afazendar",
    "afazerde": "afazer",
    "afazerdes": "afazer",
    "afazere": "afazer",
    "afazerem": "afazer",
    "afazeres": "afazer",
    "afazermo": "afazer",
    "afazermos": "afazer",
    "afazes": "afazer",
    "afazia": "afazer",
    "afaziam": "afazer",
    "afazias": "afazer",
    "afazimentos": "afazimento",
    "afazê": "afazer",
    "afazíamo": "afazer",
    "afazíamos": "afazer",
    "afazíei": "afazer",
    "afazíeis": "afazer",
    "afaça": "afazer",
    "afaçais": "afazer",
    "afaçam": "afazer",
    "afaçamo": "afazer",
    "afaçamos": "afazer",
    "afaças": "afazer",
    "afaço": "afazer",
    "afeada": "afear",
    "afeadas": "afear",
    "afeado": "afear",
    "afeados": "afear",
    "afeai": "afear",
    "afeais": "afear",
    "afeamentos": "afeamento",
    "afeamo": "afear",
    "afeamos": "afear",
    "afeando": "afear",
    "afeara": "afear",
    "afearam": "afear",
    "afearas": "afear",
    "afearde": "afear",
    "afeardes": "afear",
    "afeare": "afear",
    "afearei": "afear",
    "afeareis": "afear",
    "afearem": "afear",
    "afearemos": "afear",
    "afeares": "afear",
    "afearia": "afear",
    "afeariam": "afear",
    "afearias": "afear",
    "afearmo": "afear",
    "afearmos": "afear",
    "afeará": "afear",
    "afearás": "afear",
    "afearão": "afear",
    "afearíamos": "afear",
    "afearíeis": "afear",
    "afeasse": "afear",
    "afeassem": "afear",
    "afeasses": "afear",
    "afeaste": "afear",
    "afeastes": "afear",
    "afeava": "afear",
    "afeavam": "afear",
    "afeavas": "afear",
    "afecta": "afectar",
    "afectada": "afectar",
    "afectadas": "afectar",
    "afectado": "afectar",
    "afectados": "afectar",
    "afectadíssima": "afectado",
    "afectadíssimas": "afectado",
    "afectadíssimo": "afectado",
    "afectadíssimos": "afectado",
    "afectai": "afectar",
    "afectais": "afectar",
    "afectam": "afectar",
    "afectamo": "afectar",
    "afectamos": "afectar",
    "afectando": "afectar",
    "afectantes": "afectante",
    "afectara": "afectar",
    "afectaram": "afectar",
    "afectaras": "afectar",
    "afectarde": "afectar",
    "afectardes": "afectar",
    "afectare": "afectar",
    "afectarei": "afectar",
    "afectareis": "afectar",
    "afectarem": "afectar",
    "afectaremos": "afectar",
    "afectares": "afectar",
    "afectaria": "afectar",
    "afectariam": "afectar",
    "afectarias": "afectar",
    "afectarmo": "afectar",
    "afectarmos": "afectar",
    "afectará": "afectar",
    "afectarás": "afectar",
    "afectarão": "afectar",
    "afectaríamos": "afectar",
    "afectaríeis": "afectar",
    "afectas": "afectar",
    "afectasse": "afectar",
    "afectassem": "afectar",
    "afectasses": "afectar",
    "afectaste": "afectar",
    "afectastes": "afectar",
    "afectava": "afectar",
    "afectavam": "afectar",
    "afectavas": "afectar",
    "afectações": "afectação",
    "afecte": "afectar",
    "afectei": "afectar",
    "afecteis": "afectar",
    "afectem": "afectar",
    "afectemo": "afectar",
    "afectemos": "afectar",
    "afectes": "afectar",
    "afectiva": "afectivo",
    "afectivas": "afectivo",
    "afectividades": "afectividade",
    "afectivos": "afectivo",
    "afecto": "afectar",
    "afectos": "afecto",
    "afectou": "afectar",
    "afectuosa": "afectuoso",
    "afectuosas": "afectuoso",
    "afectuosos": "afectuoso",
    "afectá": "afectar",
    "afectámo": "afectar",
    "afectámos": "afectar",
    "afectáramo": "afectar",
    "afectáramos": "afectar",
    "afectárei": "afectar",
    "afectáreis": "afectar",
    "afectásseis": "afectar",
    "afectássemos": "afectar",
    "afectávamo": "afectar",
    "afectávamos": "afectar",
    "afectávei": "afectar",
    "afectáveis": "afectável",
    "afecções": "afecção",
    "afeei": "afear",
    "afeeis": "afear",
    "afeemo": "afear",
    "afeemos": "afear",
    "afeganes": "afegane",
    "afegã": "afegão",
    "afegãos": "afegão",
    "afegãs": "afegão",
    "afeia": "afear",
    "afeiam": "afear",
    "afeias": "afear",
    "afeie": "afear",
    "afeiem": "afear",
    "afeies": "afear",
    "afeio": "afear",
    "afeita": "afeito",
    "afeitas": "afeito",
    "afeito": "afazer",
    "afeitos": "afeito",
    "afeiçoa": "afeiçoar",
    "afeiçoada": "afeiçoar",
    "afeiçoadas": "afeiçoar",
    "afeiçoadinha": "afeiçoado",
    "afeiçoadinhas": "afeiçoado",
    "afeiçoadinho": "afeiçoado",
    "afeiçoadinhos": "afeiçoado",
    "afeiçoadita": "afeiçoado",
    "afeiçoaditas": "afeiçoado",
    "afeiçoadito": "afeiçoado",
    "afeiçoaditos": "afeiçoado",
    "afeiçoado": "afeiçoar",
    "afeiçoados": "afeiçoar",
    "afeiçoadíssima": "afeiçoado",
    "afeiçoadíssimas": "afeiçoado",
    "afeiçoadíssimo": "afeiçoado",
    "afeiçoadíssimos": "afeiçoado",
    "afeiçoai": "afeiçoar",
    "afeiçoais": "afeiçoar",
    "afeiçoam": "afeiçoar",
    "afeiçoamentos": "afeiçoamento",
    "afeiçoamo": "afeiçoar",
    "afeiçoamos": "afeiçoar",
    "afeiçoando": "afeiçoar",
    "afeiçoara": "afeiçoar",
    "afeiçoaram": "afeiçoar",
    "afeiçoaras": "afeiçoar",
    "afeiçoardes": "afeiçoar",
    "afeiçoarei": "afeiçoar",
    "afeiçoareis": "afeiçoar",
    "afeiçoarem": "afeiçoar",
    "afeiçoaremos": "afeiçoar",
    "afeiçoares": "afeiçoar",
    "afeiçoaria": "afeiçoar",
    "afeiçoariam": "afeiçoar",
    "afeiçoarias": "afeiçoar",
    "afeiçoarmo": "afeiçoar",
    "afeiçoarmos": "afeiçoar",
    "afeiçoará": "afeiçoar",
    "afeiçoarás": "afeiçoar",
    "afeiçoarão": "afeiçoar",
    "afeiçoaríamos": "afeiçoar",
    "afeiçoaríeis": "afeiçoar",
    "afeiçoas": "afeiçoar",
    "afeiçoasse": "afeiçoar",
    "afeiçoassem": "afeiçoar",
    "afeiçoasses": "afeiçoar",
    "afeiçoaste": "afeiçoar",
    "afeiçoastes": "afeiçoar",
    "afeiçoava": "afeiçoar",
    "afeiçoavam": "afeiçoar",
    "afeiçoavas": "afeiçoar",
    "afeiçoe": "afeiçoar",
    "afeiçoei": "afeiçoar",
    "afeiçoeis": "afeiçoar",
    "afeiçoem": "afeiçoar",
    "afeiçoemo": "afeiçoar",
    "afeiçoemos": "afeiçoar",
    "afeiçoes": "afeiçoar",
    "afeiçoo": "afeiçoar",
    "afeiçoou": "afeiçoar",
    "afeiçoámo": "afeiçoar",
    "afeiçoámos": "afeiçoar",
    "afeiçoáramo": "afeiçoar",
    "afeiçoáramos": "afeiçoar",
    "afeiçoáreis": "afeiçoar",
    "afeiçoásseis": "afeiçoar",
    "afeiçoássemos": "afeiçoar",
    "afeiçoávamo": "afeiçoar",
    "afeiçoávamos": "afeiçoar",
    "afeiçoáveis": "afeiçoar",
    "afeições": "afeição",
    "afeleada": "afelear",
    "afeleadas": "afelear",
    "afeleado": "afelear",
    "afeleados": "afelear",
    "afeleai": "afelear",
    "afeleais": "afelear",
    "afeleamo": "afelear",
    "afeleamos": "afelear",
    "afeleando": "afelear",
    "afeleara": "afelear",
    "afelearam": "afelear",
    "afelearas": "afelear",
    "afelearde": "afelear",
    "afeleardes": "afelear",
    "afeleare": "afelear",
    "afelearei": "afelear",
    "afeleareis": "afelear",
    "afelearem": "afelear",
    "afelearemos": "afelear",
    "afeleares": "afelear",
    "afelearia": "afelear",
    "afeleariam": "afelear",
    "afelearias": "afelear",
    "afelearmo": "afelear",
    "afelearmos": "afelear",
    "afeleará": "afelear",
    "afelearás": "afelear",
    "afelearão": "afelear",
    "afelearíamos": "afelear",
    "afelearíeis": "afelear",
    "afeleasse": "afelear",
    "afeleassem": "afelear",
    "afeleasses": "afelear",
    "afeleaste": "afelear",
    "afeleastes": "afelear",
    "afeleava": "afelear",
    "afeleavam": "afelear",
    "afeleavas": "afelear",
    "afeleei": "afelear",
    "afeleeis": "afelear",
    "afeleemo": "afelear",
    "afeleemos": "afelear",
    "afeleia": "afelear",
    "afeleiam": "afelear",
    "afeleias": "afelear",
    "afeleie": "afelear",
    "afeleiem": "afelear",
    "afeleies": "afelear",
    "afeleio": "afelear",
    "afeleou": "afelear",
    "afeleá": "afelear",
    "afeleámo": "afelear",
    "afeleámos": "afelear",
    "afeleáramo": "afelear",
    "afeleáramos": "afelear",
    "afeleárei": "afelear",
    "afeleáreis": "afelear",
    "afeleásseis": "afelear",
    "afeleássemos": "afelear",
    "afeleávamo": "afelear",
    "afeleávamos": "afelear",
    "afeleávei": "afelear",
    "afeleáveis": "afelear",
    "afelpada": "afelpado",
    "afelpadas": "afelpado",
    "afelpados": "afelpado",
    "afemeada": "afemear",
    "afemeadas": "afemear",
    "afemeado": "afemear",
    "afemeados": "afemear",
    "afemeai": "afemear",
    "afemeais": "afemear",
    "afemeamo": "afemear",
    "afemeamos": "afemear",
    "afemeando": "afemear",
    "afemeara": "afemear",
    "afemearam": "afemear",
    "afemearas": "afemear",
    "afemearde": "afemear",
    "afemeardes": "afemear",
    "afemeare": "afemear",
    "afemearei": "afemear",
    "afemeareis": "afemear",
    "afemearem": "afemear",
    "afemearemos": "afemear",
    "afemeares": "afemear",
    "afemearia": "afemear",
    "afemeariam": "afemear",
    "afemearias": "afemear",
    "afemearmo": "afemear",
    "afemearmos": "afemear",
    "afemeará": "afemear",
    "afemearás": "afemear",
    "afemearão": "afemear",
    "afemearíamos": "afemear",
    "afemearíeis": "afemear",
    "afemeasse": "afemear",
    "afemeassem": "afemear",
    "afemeasses": "afemear",
    "afemeaste": "afemear",
    "afemeastes": "afemear",
    "afemeava": "afemear",
    "afemeavam": "afemear",
    "afemeavas": "afemear",
    "afemeei": "afemear",
    "afemeeis": "afemear",
    "afemeemo": "afemear",
    "afemeemos": "afemear",
    "afemeia": "afemear",
    "afemeiam": "afemear",
    "afemeias": "afemear",
    "afemeie": "afemear",
    "afemeiem": "afemear",
    "afemeies": "afemear",
    "afemeio": "afemear",
    "afemeou": "afemear",
    "afemeá": "afemear",
    "afemeámo": "afemear",
    "afemeámos": "afemear",
    "afemeáramo": "afemear",
    "afemeáramos": "afemear",
    "afemeárei": "afemear",
    "afemeáreis": "afemear",
    "afemeásseis": "afemear",
    "afemeássemos": "afemear",
    "afemeávamo": "afemear",
    "afemeávamos": "afemear",
    "afemeávei": "afemear",
    "afemeáveis": "afemear",
    "afemias": "afemia",
    "afemina": "afeminar",
    "afeminada": "afeminar",
    "afeminadas": "afeminar",
    "afeminado": "afeminar",
    "afeminados": "afeminar",
    "afeminai": "afeminar",
    "afeminais": "afeminar",
    "afeminam": "afeminar",
    "afeminamo": "afeminar",
    "afeminamos": "afeminar",
    "afeminando": "afeminar",
    "afeminara": "afeminar",
    "afeminaram": "afeminar",
    "afeminaras": "afeminar",
    "afeminarde": "afeminar",
    "afeminardes": "afeminar",
    "afeminare": "afeminar",
    "afeminarei": "afeminar",
    "afeminareis": "afeminar",
    "afeminarem": "afeminar",
    "afeminaremos": "afeminar",
    "afeminares": "afeminar",
    "afeminaria": "afeminar",
    "afeminariam": "afeminar",
    "afeminarias": "afeminar",
    "afeminarmo": "afeminar",
    "afeminarmos": "afeminar",
    "afeminará": "afeminar",
    "afeminarás": "afeminar",
    "afeminarão": "afeminar",
    "afeminaríamos": "afeminar",
    "afeminaríeis": "afeminar",
    "afeminas": "afeminar",
    "afeminasse": "afeminar",
    "afeminassem": "afeminar",
    "afeminasses": "afeminar",
    "afeminaste": "afeminar",
    "afeminastes": "afeminar",
    "afeminava": "afeminar",
    "afeminavam": "afeminar",
    "afeminavas": "afeminar",
    "afemine": "afeminar",
    "afeminei": "afeminar",
    "afemineis": "afeminar",
    "afeminem": "afeminar",
    "afeminemo": "afeminar",
    "afeminemos": "afeminar",
    "afemines": "afeminar",
    "afemino": "afeminar",
    "afeminou": "afeminar",
    "afeminá": "afeminar",
    "afeminámo": "afeminar",
    "afeminámos": "afeminar",
    "afemináramo": "afeminar",
    "afemináramos": "afeminar",
    "afeminárei": "afeminar",
    "afemináreis": "afeminar",
    "afeminásseis": "afeminar",
    "afeminássemos": "afeminar",
    "afeminávamo": "afeminar",
    "afeminávamos": "afeminar",
    "afeminávei": "afeminar",
    "afemináveis": "afeminar",
    "afeou": "afear",
    "afere": "aferir",
    "aferem": "aferir",
    "aferentes": "aferente",
    "aferes": "aferir",
    "aferi": "aferir",
    "aferia": "aferir",
    "aferiam": "aferir",
    "aferias": "aferir",
    "aferida": "aferir",
    "aferidas": "aferir",
    "aferido": "aferir",
    "aferidora": "aferidor",
    "aferidoras": "aferidor",
    "aferidores": "aferidor",
    "aferidos": "aferir",
    "aferidíssima": "aferido",
    "aferidíssimas": "aferido",
    "aferidíssimo": "aferido",
    "aferidíssimos": "aferido",
    "aferimentos": "aferimento",
    "aferimo": "aferir",
    "aferimos": "aferir",
    "aferindo": "aferir",
    "aferira": "aferir",
    "aferiram": "aferir",
    "aferiras": "aferir",
    "aferirde": "aferir",
    "aferirdes": "aferir",
    "aferire": "aferir",
    "aferirei": "aferir",
    "aferireis": "aferir",
    "aferirem": "aferir",
    "aferiremos": "aferir",
    "aferires": "aferir",
    "aferiria": "aferir",
    "afeririam": "aferir",
    "aferirias": "aferir",
    "aferirmo": "aferir",
    "aferirmos": "aferir",
    "aferirá": "aferir",
    "aferirás": "aferir",
    "aferirão": "aferir",
    "aferiríamos": "aferir",
    "aferiríeis": "aferir",
    "aferis": "aferir",
    "aferisse": "aferir",
    "aferissem": "aferir",
    "aferisses": "aferir",
    "aferiste": "aferir",
    "aferistes": "aferir",
    "aferiu": "aferir",
    "aferições": "aferição",
    "aferra": "aferrar",
    "aferrada": "aferrar",
    "aferradas": "aferrar",
    "aferrado": "aferrar",
    "aferrados": "aferrar",
    "aferradíssima": "aferrado",
    "aferradíssimas": "aferrado",
    "aferradíssimo": "aferrado",
    "aferradíssimos": "aferrado",
    "aferrai": "aferrar",
    "aferrais": "aferrar",
    "aferram": "aferrar",
    "aferramentos": "aferramento",
    "aferramo": "aferrar",
    "aferramos": "aferrar",
    "aferrando": "aferrar",
    "aferrara": "aferrar",
    "aferraram": "aferrar",
    "aferraras": "aferrar",
    "aferrarde": "aferrar",
    "aferrardes": "aferrar",
    "aferrare": "aferrar",
    "aferrarei": "aferrar",
    "aferrareis": "aferrar",
    "aferrarem": "aferrar",
    "aferraremos": "aferrar",
    "aferrares": "aferrar",
    "aferraria": "aferrar",
    "aferrariam": "aferrar",
    "aferrarias": "aferrar",
    "aferrarmo": "aferrar",
    "aferrarmos": "aferrar",
    "aferrará": "aferrar",
    "aferrarás": "aferrar",
    "aferrarão": "aferrar",
    "aferraríamos": "aferrar",
    "aferraríeis": "aferrar",
    "aferras": "aferrar",
    "aferrasse": "aferrar",
    "aferrassem": "aferrar",
    "aferrasses": "aferrar",
    "aferraste": "aferrar",
    "aferrastes": "aferrar",
    "aferrava": "aferrar",
    "aferravam": "aferrar",
    "aferravas": "aferrar",
    "aferre": "aferrar",
    "aferrei": "aferrar",
    "aferreis": "aferrar",
    "aferrem": "aferrar",
    "aferremo": "aferrar",
    "aferremos": "aferrar",
    "aferrenha": "aferrenhar",
    "aferrenhada": "aferrenhar",
    "aferrenhadas": "aferrenhar",
    "aferrenhado": "aferrenhar",
    "aferrenhados": "aferrenhar",
    "aferrenhai": "aferrenhar",
    "aferrenhais": "aferrenhar",
    "aferrenham": "aferrenhar",
    "aferrenhamo": "aferrenhar",
    "aferrenhamos": "aferrenhar",
    "aferrenhando": "aferrenhar",
    "aferrenhara": "aferrenhar",
    "aferrenharam": "aferrenhar",
    "aferrenharas": "aferrenhar",
    "aferrenharde": "aferrenhar",
    "aferrenhardes": "aferrenhar",
    "aferrenhare": "aferrenhar",
    "aferrenharei": "aferrenhar",
    "aferrenhareis": "aferrenhar",
    "aferrenharem": "aferrenhar",
    "aferrenharemos": "aferrenhar",
    "aferrenhares": "aferrenhar",
    "aferrenharia": "aferrenhar",
    "aferrenhariam": "aferrenhar",
    "aferrenharias": "aferrenhar",
    "aferrenharmo": "aferrenhar",
    "aferrenharmos": "aferrenhar",
    "aferrenhará": "aferrenhar",
    "aferrenharás": "aferrenhar",
    "aferrenharão": "aferrenhar",
    "aferrenharíamos": "aferrenhar",
    "aferrenharíeis": "aferrenhar",
    "aferrenhas": "aferrenhar",
    "aferrenhasse": "aferrenhar",
    "aferrenhassem": "aferrenhar",
    "aferrenhasses": "aferrenhar",
    "aferrenhaste": "aferrenhar",
    "aferrenhastes": "aferrenhar",
    "aferrenhava": "aferrenhar",
    "aferrenhavam": "aferrenhar",
    "aferrenhavas": "aferrenhar",
    "aferrenhe": "aferrenhar",
    "aferrenhei": "aferrenhar",
    "aferrenheis": "aferrenhar",
    "aferrenhem": "aferrenhar",
    "aferrenhemo": "aferrenhar",
    "aferrenhemos": "aferrenhar",
    "aferrenhes": "aferrenhar",
    "aferrenho": "aferrenhar",
    "aferrenhou": "aferrenhar",
    "aferrenhá": "aferrenhar",
    "aferrenhámo": "aferrenhar",
    "aferrenhámos": "aferrenhar",
    "aferrenháramo": "aferrenhar",
    "aferrenháramos": "aferrenhar",
    "aferrenhárei": "aferrenhar",
    "aferrenháreis": "aferrenhar",
    "aferrenhásseis": "aferrenhar",
    "aferrenhássemos": "aferrenhar",
    "aferrenhávamo": "aferrenhar",
    "aferrenhávamos": "aferrenhar",
    "aferrenhávei": "aferrenhar",
    "aferrenháveis": "aferrenhar",
    "aferres": "aferrar",
    "aferretada": "aferretado",
    "aferretadas": "aferretado",
    "aferretados": "aferretado",
    "aferretoa": "aferretoar",
    "aferretoada": "aferretoar",
    "aferretoadas": "aferretoar",
    "aferretoado": "aferretoar",
    "aferretoados": "aferretoar",
    "aferretoai": "aferretoar",
    "aferretoais": "aferretoar",
    "aferretoam": "aferretoar",
    "aferretoamo": "aferretoar",
    "aferretoamos": "aferretoar",
    "aferretoando": "aferretoar",
    "aferretoara": "aferretoar",
    "aferretoaram": "aferretoar",
    "aferretoaras": "aferretoar",
    "aferretoarde": "aferretoar",
    "aferretoardes": "aferretoar",
    "aferretoare": "aferretoar",
    "aferretoarei": "aferretoar",
    "aferretoareis": "aferretoar",
    "aferretoarem": "aferretoar",
    "aferretoaremos": "aferretoar",
    "aferretoares": "aferretoar",
    "aferretoaria": "aferretoar",
    "aferretoariam": "aferretoar",
    "aferretoarias": "aferretoar",
    "aferretoarmo": "aferretoar",
    "aferretoarmos": "aferretoar",
    "aferretoará": "aferretoar",
    "aferretoarás": "aferretoar",
    "aferretoarão": "aferretoar",
    "aferretoaríamos": "aferretoar",
    "aferretoaríeis": "aferretoar",
    "aferretoas": "aferretoar",
    "aferretoasse": "aferretoar",
    "aferretoassem": "aferretoar",
    "aferretoasses": "aferretoar",
    "aferretoaste": "aferretoar",
    "aferretoastes": "aferretoar",
    "aferretoava": "aferretoar",
    "aferretoavam": "aferretoar",
    "aferretoavas": "aferretoar",
    "aferretoe": "aferretoar",
    "aferretoei": "aferretoar",
    "aferretoeis": "aferretoar",
    "aferretoem": "aferretoar",
    "aferretoemo": "aferretoar",
    "aferretoemos": "aferretoar",
    "aferretoes": "aferretoar",
    "aferretoo": "aferretoar",
    "aferretoou": "aferretoar",
    "aferretoá": "aferretoar",
    "aferretoámo": "aferretoar",
    "aferretoámos": "aferretoar",
    "aferretoáramo": "aferretoar",
    "aferretoáramos": "aferretoar",
    "aferretoárei": "aferretoar",
    "aferretoáreis": "aferretoar",
    "aferretoásseis": "aferretoar",
    "aferretoássemos": "aferretoar",
    "aferretoávamo": "aferretoar",
    "aferretoávamos": "aferretoar",
    "aferretoávei": "aferretoar",
    "aferretoáveis": "aferretoar",
    "aferro": "aferrar",
    "aferroa": "aferroar",
    "aferroada": "aferroar",
    "aferroadas": "aferroar",
    "aferroado": "aferroar",
    "aferroadora": "aferroador",
    "aferroadoras": "aferroador",
    "aferroadores": "aferroador",
    "aferroados": "aferroar",
    "aferroai": "aferroar",
    "aferroais": "aferroar",
    "aferroam": "aferroar",
    "aferroamo": "aferroar",
    "aferroamos": "aferroar",
    "aferroando": "aferroar",
    "aferroara": "aferroar",
    "aferroaram": "aferroar",
    "aferroaras": "aferroar",
    "aferroarde": "aferroar",
    "aferroardes": "aferroar",
    "aferroare": "aferroar",
    "aferroarei": "aferroar",
    "aferroareis": "aferroar",
    "aferroarem": "aferroar",
    "aferroaremos": "aferroar",
    "aferroares": "aferroar",
    "aferroaria": "aferroar",
    "aferroariam": "aferroar",
    "aferroarias": "aferroar",
    "aferroarmo": "aferroar",
    "aferroarmos": "aferroar",
    "aferroará": "aferroar",
    "aferroarás": "aferroar",
    "aferroarão": "aferroar",
    "aferroaríamos": "aferroar",
    "aferroaríeis": "aferroar",
    "aferroas": "aferroar",
    "aferroasse": "aferroar",
    "aferroassem": "aferroar",
    "aferroasses": "aferroar",
    "aferroaste": "aferroar",
    "aferroastes": "aferroar",
    "aferroava": "aferroar",
    "aferroavam": "aferroar",
    "aferroavas": "aferroar",
    "aferroe": "aferroar",
    "aferroei": "aferroar",
    "aferroeis": "aferroar",
    "aferroem": "aferroar",
    "aferroemo": "aferroar",
    "aferroemos": "aferroar",
    "aferroes": "aferroar",
    "aferrolha": "aferrolhar",
    "aferrolhada": "aferrolhar",
    "aferrolhadas": "aferrolhar",
    "aferrolhado": "aferrolhar",
    "aferrolhados": "aferrolhar",
    "aferrolhai": "aferrolhar",
    "aferrolhais": "aferrolhar",
    "aferrolham": "aferrolhar",
    "aferrolhamo": "aferrolhar",
    "aferrolhamos": "aferrolhar",
    "aferrolhando": "aferrolhar",
    "aferrolhara": "aferrolhar",
    "aferrolharam": "aferrolhar",
    "aferrolharas": "aferrolhar",
    "aferrolharde": "aferrolhar",
    "aferrolhardes": "aferrolhar",
    "aferrolhare": "aferrolhar",
    "aferrolharei": "aferrolhar",
    "aferrolhareis": "aferrolhar",
    "aferrolharem": "aferrolhar",
    "aferrolharemos": "aferrolhar",
    "aferrolhares": "aferrolhar",
    "aferrolharia": "aferrolhar",
    "aferrolhariam": "aferrolhar",
    "aferrolharias": "aferrolhar",
    "aferrolharmo": "aferrolhar",
    "aferrolharmos": "aferrolhar",
    "aferrolhará": "aferrolhar",
    "aferrolharás": "aferrolhar",
    "aferrolharão": "aferrolhar",
    "aferrolharíamos": "aferrolhar",
    "aferrolharíeis": "aferrolhar",
    "aferrolhas": "aferrolhar",
    "aferrolhasse": "aferrolhar",
    "aferrolhassem": "aferrolhar",
    "aferrolhasses": "aferrolhar",
    "aferrolhaste": "aferrolhar",
    "aferrolhastes": "aferrolhar",
    "aferrolhava": "aferrolhar",
    "aferrolhavam": "aferrolhar",
    "aferrolhavas": "aferrolhar",
    "aferrolhe": "aferrolhar",
    "aferrolhei": "aferrolhar",
    "aferrolheis": "aferrolhar",
    "aferrolhem": "aferrolhar",
    "aferrolhemo": "aferrolhar",
    "aferrolhemos": "aferrolhar",
    "aferrolhes": "aferrolhar",
    "aferrolho": "aferrolhar",
    "aferrolhou": "aferrolhar",
    "aferrolhá": "aferrolhar",
    "aferrolhámo": "aferrolhar",
    "aferrolhámos": "aferrolhar",
    "aferrolháramo": "aferrolhar",
    "aferrolháramos": "aferrolhar",
    "aferrolhárei": "aferrolhar",
    "aferrolháreis": "aferrolhar",
    "aferrolhásseis": "aferrolhar",
    "aferrolhássemos": "aferrolhar",
    "aferrolhávamo": "aferrolhar",
    "aferrolhávamos": "aferrolhar",
    "aferrolhávei": "aferrolhar",
    "aferrolháveis": "aferrolhar",
    "aferroo": "aferroar",
    "aferroou": "aferroar",
    "aferros": "aferro",
    "aferrou": "aferrar",
    "aferroá": "aferroar",
    "aferroámo": "aferroar",
    "aferroámos": "aferroar",
    "aferroáramo": "aferroar",
    "aferroáramos": "aferroar",
    "aferroárei": "aferroar",
    "aferroáreis": "aferroar",
    "aferroásseis": "aferroar",
    "aferroássemos": "aferroar",
    "aferroávamo": "aferroar",
    "aferroávamos": "aferroar",
    "aferroávei": "aferroar",
    "aferroáveis": "aferroar",
    "aferrá": "aferrar",
    "aferrámo": "aferrar",
    "aferrámos": "aferrar",
    "aferráramo": "aferrar",
    "aferráramos": "aferrar",
    "aferrárei": "aferrar",
    "aferráreis": "aferrar",
    "aferrásseis": "aferrar",
    "aferrássemos": "aferrar",
    "aferrávamo": "aferrar",
    "aferrávamos": "aferrar",
    "aferrávei": "aferrar",
    "aferráveis": "aferrar",
    "aferva": "afervar",
    "afervada": "afervar",
    "afervadas": "afervar",
    "afervado": "afervar",
    "afervados": "afervar",
    "afervai": "afervar",
    "afervais": "afervar",
    "afervam": "afervar",
    "afervamo": "afervar",
    "afervamos": "afervar",
    "afervando": "afervar",
    "afervara": "afervar",
    "afervaram": "afervar",
    "afervaras": "afervar",
    "afervarde": "afervar",
    "afervardes": "afervar",
    "afervare": "afervar",
    "afervarei": "afervar",
    "afervareis": "afervar",
    "afervarem": "afervar",
    "afervaremos": "afervar",
    "afervares": "afervar",
    "afervaria": "afervar",
    "afervariam": "afervar",
    "afervarias": "afervar",
    "afervarmo": "afervar",
    "afervarmos": "afervar",
    "afervará": "afervar",
    "afervarás": "afervar",
    "afervarão": "afervar",
    "afervaríamos": "afervar",
    "afervaríeis": "afervar",
    "afervas": "afervar",
    "afervasse": "afervar",
    "afervassem": "afervar",
    "afervasses": "afervar",
    "afervaste": "afervar",
    "afervastes": "afervar",
    "afervava": "afervar",
    "afervavam": "afervar",
    "afervavas": "afervar",
    "aferve": "afervar",
    "afervei": "afervar",
    "aferveis": "afervar",
    "afervem": "afervar",
    "afervemo": "afervar",
    "afervemos": "afervar",
    "aferventa": "aferventar",
    "aferventada": "aferventar",
    "aferventadas": "aferventar",
    "aferventado": "aferventar",
    "aferventados": "aferventar",
    "aferventai": "aferventar",
    "aferventais": "aferventar",
    "aferventam": "aferventar",
    "aferventamo": "aferventar",
    "aferventamos": "aferventar",
    "aferventando": "aferventar",
    "aferventara": "aferventar",
    "aferventaram": "aferventar",
    "aferventaras": "aferventar",
    "aferventarde": "aferventar",
    "aferventardes": "aferventar",
    "aferventare": "aferventar",
    "aferventarei": "aferventar",
    "aferventareis": "aferventar",
    "aferventarem": "aferventar",
    "aferventaremos": "aferventar",
    "aferventares": "aferventar",
    "aferventaria": "aferventar",
    "aferventariam": "aferventar",
    "aferventarias": "aferventar",
    "aferventarmo": "aferventar",
    "aferventarmos": "aferventar",
    "aferventará": "aferventar",
    "aferventarás": "aferventar",
    "aferventarão": "aferventar",
    "aferventaríamos": "aferventar",
    "aferventaríeis": "aferventar",
    "aferventas": "aferventar",
    "aferventasse": "aferventar",
    "aferventassem": "aferventar",
    "aferventasses": "aferventar",
    "aferventaste": "aferventar",
    "aferventastes": "aferventar",
    "aferventava": "aferventar",
    "aferventavam": "aferventar",
    "aferventavas": "aferventar",
    "aferventações": "aferventação",
    "afervente": "aferventar",
    "aferventei": "aferventar",
    "aferventeis": "aferventar",
    "aferventem": "aferventar",
    "aferventemo": "aferventar",
    "aferventemos": "aferventar",
    "aferventes": "aferventar",
    "afervento": "aferventar",
    "aferventou": "aferventar",
    "aferventá": "aferventar",
    "aferventámo": "aferventar",
    "aferventámos": "aferventar",
    "aferventáramo": "aferventar",
    "aferventáramos": "aferventar",
    "aferventárei": "aferventar",
    "aferventáreis": "aferventar",
    "aferventásseis": "aferventar",
    "aferventássemos": "aferventar",
    "aferventávamo": "aferventar",
    "aferventávamos": "aferventar",
    "aferventávei": "aferventar",
    "aferventáveis": "aferventar",
    "aferves": "afervar",
    "afervo": "afervar",
    "afervora": "afervorar",
    "afervorada": "afervorar",
    "afervoradas": "afervorar",
    "afervorado": "afervorar",
    "afervorados": "afervorar",
    "afervorai": "afervorar",
    "afervorais": "afervorar",
    "afervoram": "afervorar",
    "afervoramo": "afervorar",
    "afervoramos": "afervorar",
    "afervorando": "afervorar",
    "afervorara": "afervorar",
    "afervoraram": "afervorar",
    "afervoraras": "afervorar",
    "afervorarde": "afervorar",
    "afervorardes": "afervorar",
    "afervorare": "afervorar",
    "afervorarei": "afervorar",
    "afervorareis": "afervorar",
    "afervorarem": "afervorar",
    "afervoraremos": "afervorar",
    "afervorares": "afervorar",
    "afervoraria": "afervorar",
    "afervorariam": "afervorar",
    "afervorarias": "afervorar",
    "afervorarmo": "afervorar",
    "afervorarmos": "afervorar",
    "afervorará": "afervorar",
    "afervorarás": "afervorar",
    "afervorarão": "afervorar",
    "afervoraríamos": "afervorar",
    "afervoraríeis": "afervorar",
    "afervoras": "afervorar",
    "afervorasse": "afervorar",
    "afervorassem": "afervorar",
    "afervorasses": "afervorar",
    "afervoraste": "afervorar",
    "afervorastes": "afervorar",
    "afervorava": "afervorar",
    "afervoravam": "afervorar",
    "afervoravas": "afervorar",
    "afervore": "afervorar",
    "afervorei": "afervorar",
    "afervoreis": "afervorar",
    "afervorem": "afervorar",
    "afervoremo": "afervorar",
    "afervoremos": "afervorar",
    "afervores": "afervorar",
    "afervoro": "afervorar",
    "afervorou": "afervorar",
    "afervorá": "afervorar",
    "afervorámo": "afervorar",
    "afervorámos": "afervorar",
    "afervoráramo": "afervorar",
    "afervoráramos": "afervorar",
    "afervorárei": "afervorar",
    "afervoráreis": "afervorar",
    "afervorásseis": "afervorar",
    "afervorássemos": "afervorar",
    "afervorávamo": "afervorar",
    "afervorávamos": "afervorar",
    "afervorávei": "afervorar",
    "afervoráveis": "afervorar",
    "afervou": "afervar",
    "afervá": "afervar",
    "afervámo": "afervar",
    "afervámos": "afervar",
    "aferváramo": "afervar",
    "aferváramos": "afervar",
    "afervárei": "afervar",
    "aferváreis": "afervar",
    "afervásseis": "afervar",
    "afervássemos": "afervar",
    "afervávamo": "afervar",
    "afervávamos": "afervar",
    "afervávei": "afervar",
    "aferváveis": "afervar",
    "aferética": "aferético",
    "aferéticas": "aferético",
    "aferéticos": "aferético",
    "aferíamo": "aferir",
    "aferíamos": "aferir",
    "aferíei": "aferir",
    "aferíeis": "aferir",
    "aferíramo": "aferir",
    "aferíramos": "aferir",
    "aferírei": "aferir",
    "aferíreis": "aferir",
    "aferísseis": "aferir",
    "aferíssemos": "aferir",
    "afestoa": "afestoar",
    "afestoada": "afestoar",
    "afestoadas": "afestoar",
    "afestoado": "afestoar",
    "afestoados": "afestoar",
    "afestoai": "afestoar",
    "afestoais": "afestoar",
    "afestoam": "afestoar",
    "afestoamo": "afestoar",
    "afestoamos": "afestoar",
    "afestoando": "afestoar",
    "afestoara": "afestoar",
    "afestoaram": "afestoar",
    "afestoaras": "afestoar",
    "afestoarde": "afestoar",
    "afestoardes": "afestoar",
    "afestoare": "afestoar",
    "afestoarei": "afestoar",
    "afestoareis": "afestoar",
    "afestoarem": "afestoar",
    "afestoaremos": "afestoar",
    "afestoares": "afestoar",
    "afestoaria": "afestoar",
    "afestoariam": "afestoar",
    "afestoarias": "afestoar",
    "afestoarmo": "afestoar",
    "afestoarmos": "afestoar",
    "afestoará": "afestoar",
    "afestoarás": "afestoar",
    "afestoarão": "afestoar",
    "afestoaríamos": "afestoar",
    "afestoaríeis": "afestoar",
    "afestoas": "afestoar",
    "afestoasse": "afestoar",
    "afestoassem": "afestoar",
    "afestoasses": "afestoar",
    "afestoaste": "afestoar",
    "afestoastes": "afestoar",
    "afestoava": "afestoar",
    "afestoavam": "afestoar",
    "afestoavas": "afestoar",
    "afestoe": "afestoar",
    "afestoei": "afestoar",
    "afestoeis": "afestoar",
    "afestoem": "afestoar",
    "afestoemo": "afestoar",
    "afestoemos": "afestoar",
    "afestoes": "afestoar",
    "afestoo": "afestoar",
    "afestoou": "afestoar",
    "afestoá": "afestoar",
    "afestoámo": "afestoar",
    "afestoámos": "afestoar",
    "afestoáramo": "afestoar",
    "afestoáramos": "afestoar",
    "afestoárei": "afestoar",
    "afestoáreis": "afestoar",
    "afestoásseis": "afestoar",
    "afestoássemos": "afestoar",
    "afestoávamo": "afestoar",
    "afestoávamos": "afestoar",
    "afestoávei": "afestoar",
    "afestoáveis": "afestoar",
    "afez": "afazer",
    "afeá": "afear",
    "afeámo": "afear",
    "afeámos": "afear",
    "afeáramo": "afear",
    "afeáramos": "afear",
    "afeárei": "afear",
    "afeáreis": "afear",
    "afeásseis": "afear",
    "afeássemos": "afear",
    "afeávamo": "afear",
    "afeávamos": "afear",
    "afeávei": "afear",
    "afeáveis": "afear",
    "affaires": "affaire",
    "afi": "afazer",
    "afia": "afiar",
    "afiada": "afiar",
    "afiadas": "afiar",
    "afiadeiras": "afiadeira",
    "afiadinha": "afiado",
    "afiadinhas": "afiado",
    "afiadinho": "afiado",
    "afiadinhos": "afiado",
    "afiadita": "afiado",
    "afiaditas": "afiado",
    "afiadito": "afiado",
    "afiaditos": "afiado",
    "afiado": "afiar",
    "afiadora": "afiador",
    "afiadoras": "afiador",
    "afiadores": "afiador",
    "afiados": "afiar",
    "afiadíssima": "afiado",
    "afiadíssimas": "afiado",
    "afiadíssimo": "afiado",
    "afiadíssimos": "afiado",
    "afiai": "afiar",
    "afiais": "afiar",
    "afiam": "afiar",
    "afiambra": "afiambrar",
    "afiambrada": "afiambrar",
    "afiambradas": "afiambrar",
    "afiambrado": "afiambrar",
    "afiambrados": "afiambrar",
    "afiambrai": "afiambrar",
    "afiambrais": "afiambrar",
    "afiambram": "afiambrar",
    "afiambramo": "afiambrar",
    "afiambramos": "afiambrar",
    "afiambrando": "afiambrar",
    "afiambrara": "afiambrar",
    "afiambraram": "afiambrar",
    "afiambraras": "afiambrar",
    "afiambrarde": "afiambrar",
    "afiambrardes": "afiambrar",
    "afiambrare": "afiambrar",
    "afiambrarei": "afiambrar",
    "afiambrareis": "afiambrar",
    "afiambrarem": "afiambrar",
    "afiambraremos": "afiambrar",
    "afiambrares": "afiambrar",
    "afiambraria": "afiambrar",
    "afiambrariam": "afiambrar",
    "afiambrarias": "afiambrar",
    "afiambrarmo": "afiambrar",
    "afiambrarmos": "afiambrar",
    "afiambrará": "afiambrar",
    "afiambrarás": "afiambrar",
    "afiambrarão": "afiambrar",
    "afiambraríamos": "afiambrar",
    "afiambraríeis": "afiambrar",
    "afiambras": "afiambrar",
    "afiambrasse": "afiambrar",
    "afiambrassem": "afiambrar",
    "afiambrasses": "afiambrar",
    "afiambraste": "afiambrar",
    "afiambrastes": "afiambrar",
    "afiambrava": "afiambrar",
    "afiambravam": "afiambrar",
    "afiambravas": "afiambrar",
    "afiambre": "afiambrar",
    "afiambrei": "afiambrar",
    "afiambreis": "afiambrar",
    "afiambrem": "afiambrar",
    "afiambremo": "afiambrar",
    "afiambremos": "afiambrar",
    "afiambres": "afiambrar",
    "afiambro": "afiambrar",
    "afiambrou": "afiambrar",
    "afiambrá": "afiambrar",
    "afiambrámo": "afiambrar",
    "afiambrámos": "afiambrar",
    "afiambráramo": "afiambrar",
    "afiambráramos": "afiambrar",
    "afiambrárei": "afiambrar",
    "afiambráreis": "afiambrar",
    "afiambrásseis": "afiambrar",
    "afiambrássemos": "afiambrar",
    "afiambrávamo": "afiambrar",
    "afiambrávamos": "afiambrar",
    "afiambrávei": "afiambrar",
    "afiambráveis": "afiambrar",
    "afiamo": "afiar",
    "afiamos": "afiar",
    "afiance": "afiançar",
    "afiancei": "afiançar",
    "afianceis": "afiançar",
    "afiancem": "afiançar",
    "afiancemo": "afiançar",
    "afiancemos": "afiançar",
    "afiances": "afiançar",
    "afiando": "afiar",
    "afiança": "afiançar",
    "afiançada": "afiançar",
    "afiançadas": "afiançar",
    "afiançado": "afiançar",
    "afiançadora": "afiançador",
    "afiançadoras": "afiançador",
    "afiançadores": "afiançador",
    "afiançados": "afiançar",
    "afiançai": "afiançar",
    "afiançais": "afiançar",
    "afiançam": "afiançar",
    "afiançamo": "afiançar",
    "afiançamos": "afiançar",
    "afiançando": "afiançar",
    "afiançara": "afiançar",
    "afiançaram": "afiançar",
    "afiançaras": "afiançar",
    "afiançarde": "afiançar",
    "afiançardes": "afiançar",
    "afiançare": "afiançar",
    "afiançarei": "afiançar",
    "afiançareis": "afiançar",
    "afiançarem": "afiançar",
    "afiançaremos": "afiançar",
    "afiançares": "afiançar",
    "afiançaria": "afiançar",
    "afiançariam": "afiançar",
    "afiançarias": "afiançar",
    "afiançarmo": "afiançar",
    "afiançarmos": "afiançar",
    "afiançará": "afiançar",
    "afiançarás": "afiançar",
    "afiançarão": "afiançar",
    "afiançaríamos": "afiançar",
    "afiançaríeis": "afiançar",
    "afianças": "afiançar",
    "afiançasse": "afiançar",
    "afiançassem": "afiançar",
    "afiançasses": "afiançar",
    "afiançaste": "afiançar",
    "afiançastes": "afiançar",
    "afiançava": "afiançar",
    "afiançavam": "afiançar",
    "afiançavas": "afiançar",
    "afianço": "afiançar",
    "afiançou": "afiançar",
    "afiançá": "afiançar",
    "afiançámo": "afiançar",
    "afiançámos": "afiançar",
    "afiançáramo": "afiançar",
    "afiançáramos": "afiançar",
    "afiançárei": "afiançar",
    "afiançáreis": "afiançar",
    "afiançásseis": "afiançar",
    "afiançássemos": "afiançar",
    "afiançávamo": "afiançar",
    "afiançávamos": "afiançar",
    "afiançávei": "afiançar",
    "afiançáveis": "afiançar",
    "afiara": "afiar",
    "afiaram": "afiar",
    "afiaras": "afiar",
    "afiarde": "afiar",
    "afiardes": "afiar",
    "afiare": "afiar",
    "afiarei": "afiar",
    "afiareis": "afiar",
    "afiarem": "afiar",
    "afiaremos": "afiar",
    "afiares": "afiar",
    "afiaria": "afiar",
    "afiariam": "afiar",
    "afiarias": "afiar",
    "afiarmo": "afiar",
    "afiarmos": "afiar",
    "afiará": "afiar",
    "afiarás": "afiar",
    "afiarão": "afiar",
    "afiaríamos": "afiar",
    "afiaríeis": "afiar",
    "afias": "afiar",
    "afiasse": "afiar",
    "afiassem": "afiar",
    "afiasses": "afiar",
    "afiaste": "afiar",
    "afiastes": "afiar",
    "afiava": "afiar",
    "afiavam": "afiar",
    "afiavas": "afiar",
    "afiações": "afiação",
    "aficionada": "aficionado",
    "aficionadas": "aficionado",
    "aficionados": "aficionado",
    "afidalga": "afidalgar",
    "afidalgada": "afidalgar",
    "afidalgadas": "afidalgar",
    "afidalgado": "afidalgar",
    "afidalgados": "afidalgar",
    "afidalgai": "afidalgar",
    "afidalgais": "afidalgar",
    "afidalgam": "afidalgar",
    "afidalgamentos": "afidalgamento",
    "afidalgamo": "afidalgar",
    "afidalgamos": "afidalgar",
    "afidalgando": "afidalgar",
    "afidalgara": "afidalgar",
    "afidalgaram": "afidalgar",
    "afidalgaras": "afidalgar",
    "afidalgarde": "afidalgar",
    "afidalgardes": "afidalgar",
    "afidalgare": "afidalgar",
    "afidalgarei": "afidalgar",
    "afidalgareis": "afidalgar",
    "afidalgarem": "afidalgar",
    "afidalgaremos": "afidalgar",
    "afidalgares": "afidalgar",
    "afidalgaria": "afidalgar",
    "afidalgariam": "afidalgar",
    "afidalgarias": "afidalgar",
    "afidalgarmo": "afidalgar",
    "afidalgarmos": "afidalgar",
    "afidalgará": "afidalgar",
    "afidalgarás": "afidalgar",
    "afidalgarão": "afidalgar",
    "afidalgaríamos": "afidalgar",
    "afidalgaríeis": "afidalgar",
    "afidalgas": "afidalgar",
    "afidalgasse": "afidalgar",
    "afidalgassem": "afidalgar",
    "afidalgasses": "afidalgar",
    "afidalgaste": "afidalgar",
    "afidalgastes": "afidalgar",
    "afidalgava": "afidalgar",
    "afidalgavam": "afidalgar",
    "afidalgavas": "afidalgar",
    "afidalgo": "afidalgar",
    "afidalgou": "afidalgar",
    "afidalgue": "afidalgar",
    "afidalguei": "afidalgar",
    "afidalgueis": "afidalgar",
    "afidalguem": "afidalgar",
    "afidalguemo": "afidalgar",
    "afidalguemos": "afidalgar",
    "afidalgues": "afidalgar",
    "afidalgá": "afidalgar",
    "afidalgámo": "afidalgar",
    "afidalgámos": "afidalgar",
    "afidalgáramo": "afidalgar",
    "afidalgáramos": "afidalgar",
    "afidalgárei": "afidalgar",
    "afidalgáreis": "afidalgar",
    "afidalgásseis": "afidalgar",
    "afidalgássemos": "afidalgar",
    "afidalgávamo": "afidalgar",
    "afidalgávamos": "afidalgar",
    "afidalgávei": "afidalgar",
    "afidalgáveis": "afidalgar",
    "afididas": "afidida",
    "afie": "afiar",
    "afiei": "afiar",
    "afieis": "afiar",
    "afiem": "afiar",
    "afiemo": "afiar",
    "afiemos": "afiar",
    "afies": "afiar",
    "afifa": "afifar",
    "afifada": "afifar",
    "afifadas": "afifar",
    "afifado": "afifar",
    "afifados": "afifar",
    "afifai": "afifar",
    "afifais": "afifar",
    "afifam": "afifar",
    "afifamo": "afifar",
    "afifamos": "afifar",
    "afifando": "afifar",
    "afifara": "afifar",
    "afifaram": "afifar",
    "afifaras": "afifar",
    "afifarde": "afifar",
    "afifardes": "afifar",
    "afifare": "afifar",
    "afifarei": "afifar",
    "afifareis": "afifar",
    "afifarem": "afifar",
    "afifaremos": "afifar",
    "afifares": "afifar",
    "afifaria": "afifar",
    "afifariam": "afifar",
    "afifarias": "afifar",
    "afifarmo": "afifar",
    "afifarmos": "afifar",
    "afifará": "afifar",
    "afifarás": "afifar",
    "afifarão": "afifar",
    "afifaríamos": "afifar",
    "afifaríeis": "afifar",
    "afifas": "afifar",
    "afifasse": "afifar",
    "afifassem": "afifar",
    "afifasses": "afifar",
    "afifaste": "afifar",
    "afifastes": "afifar",
    "afifava": "afifar",
    "afifavam": "afifar",
    "afifavas": "afifar",
    "afife": "afifar",
    "afifei": "afifar",
    "afifeis": "afifar",
    "afifem": "afifar",
    "afifemo": "afifar",
    "afifemos": "afifar",
    "afifes": "afifar",
    "afifo": "afifar",
    "afifou": "afifar",
    "afifá": "afifar",
    "afifámo": "afifar",
    "afifámos": "afifar",
    "afifáramo": "afifar",
    "afifáramos": "afifar",
    "afifárei": "afifar",
    "afifáreis": "afifar",
    "afifásseis": "afifar",
    "afifássemos": "afifar",
    "afifávamo": "afifar",
    "afifávamos": "afifar",
    "afifávei": "afifar",
    "afifáveis": "afifar",
    "afigura": "afigurar",
    "afigurada": "afigurar",
    "afiguradas": "afigurar",
    "afigurado": "afigurar",
    "afigurados": "afigurar",
    "afigurai": "afigurar",
    "afigurais": "afigurar",
    "afiguram": "afigurar",
    "afiguramo": "afigurar",
    "afiguramos": "afigurar",
    "afigurando": "afigurar",
    "afigurara": "afigurar",
    "afiguraram": "afigurar",
    "afiguraras": "afigurar",
    "afigurarde": "afigurar",
    "afigurardes": "afigurar",
    "afigurare": "afigurar",
    "afigurarei": "afigurar",
    "afigurareis": "afigurar",
    "afigurarem": "afigurar",
    "afiguraremos": "afigurar",
    "afigurares": "afigurar",
    "afiguraria": "afigurar",
    "afigurariam": "afigurar",
    "afigurarias": "afigurar",
    "afigurarmo": "afigurar",
    "afigurarmos": "afigurar",
    "afigurará": "afigurar",
    "afigurarás": "afigurar",
    "afigurarão": "afigurar",
    "afiguraríamos": "afigurar",
    "afiguraríeis": "afigurar",
    "afiguras": "afigurar",
    "afigurasse": "afigurar",
    "afigurassem": "afigurar",
    "afigurasses": "afigurar",
    "afiguraste": "afigurar",
    "afigurastes": "afigurar",
    "afigurativa": "afigurativo",
    "afigurativas": "afigurativo",
    "afigurativos": "afigurativo",
    "afigurava": "afigurar",
    "afiguravam": "afigurar",
    "afiguravas": "afigurar",
    "afigurações": "afiguração",
    "afigure": "afigurar",
    "afigurei": "afigurar",
    "afigureis": "afigurar",
    "afigurem": "afigurar",
    "afiguremo": "afigurar",
    "afiguremos": "afigurar",
    "afigures": "afigurar",
    "afiguro": "afigurar",
    "afigurou": "afigurar",
    "afigurá": "afigurar",
    "afigurámo": "afigurar",
    "afigurámos": "afigurar",
    "afiguráramo": "afigurar",
    "afiguráramos": "afigurar",
    "afigurárei": "afigurar",
    "afiguráreis": "afigurar",
    "afigurásseis": "afigurar",
    "afigurássemos": "afigurar",
    "afigurávamo": "afigurar",
    "afigurávamos": "afigurar",
    "afigurávei": "afigurar",
    "afiguráveis": "afigurar",
    "afila": "afilo",
    "afilada": "afilar",
    "afiladas": "afilar",
    "afilado": "afilar",
    "afiladora": "afilador",
    "afiladoras": "afilador",
    "afiladores": "afilador",
    "afilados": "afilar",
    "afilai": "afilar",
    "afilais": "afilar",
    "afilam": "afilar",
    "afilamentos": "afilamento",
    "afilamo": "afilar",
    "afilamos": "afilar",
    "afilando": "afilar",
    "afilara": "afilar",
    "afilaram": "afilar",
    "afilaras": "afilar",
    "afilarde": "afilar",
    "afilardes": "afilar",
    "afilare": "afilar",
    "afilarei": "afilar",
    "afilareis": "afilar",
    "afilarem": "afilar",
    "afilaremos": "afilar",
    "afilares": "afilar",
    "afilaria": "afilar",
    "afilariam": "afilar",
    "afilarias": "afilar",
    "afilarmo": "afilar",
    "afilarmos": "afilar",
    "afilará": "afilar",
    "afilarás": "afilar",
    "afilarão": "afilar",
    "afilaríamos": "afilar",
    "afilaríeis": "afilar",
    "afilas": "afilo",
    "afilasse": "afilar",
    "afilassem": "afilar",
    "afilasses": "afilar",
    "afilaste": "afilar",
    "afilastes": "afilar",
    "afilava": "afilar",
    "afilavam": "afilar",
    "afilavas": "afilar",
    "afile": "afilar",
    "afilei": "afilar",
    "afileis": "afilar",
    "afilem": "afilar",
    "afilemo": "afilar",
    "afilemos": "afilar",
    "afiles": "afilar",
    "afilha": "afilhar",
    "afilhada": "afilhar",
    "afilhadagens": "afilhadagem",
    "afilhadas": "afilhar",
    "afilhadismos": "afilhadismo",
    "afilhado": "afilhar",
    "afilhados": "afilhar",
    "afilhai": "afilhar",
    "afilhais": "afilhar",
    "afilham": "afilhar",
    "afilhamo": "afilhar",
    "afilhamos": "afilhar",
    "afilhando": "afilhar",
    "afilhara": "afilhar",
    "afilharam": "afilhar",
    "afilharas": "afilhar",
    "afilhardes": "afilhar",
    "afilharei": "afilhar",
    "afilhareis": "afilhar",
    "afilharem": "afilhar",
    "afilharemos": "afilhar",
    "afilhares": "afilhar",
    "afilharia": "afilhar",
    "afilhariam": "afilhar",
    "afilharias": "afilhar",
    "afilharmo": "afilhar",
    "afilharmos": "afilhar",
    "afilhará": "afilhar",
    "afilharás": "afilhar",
    "afilharão": "afilhar",
    "afilharíamos": "afilhar",
    "afilharíeis": "afilhar",
    "afilhas": "afilhar",
    "afilhasse": "afilhar",
    "afilhassem": "afilhar",
    "afilhasses": "afilhar",
    "afilhaste": "afilhar",
    "afilhastes": "afilhar",
    "afilhava": "afilhar",
    "afilhavam": "afilhar",
    "afilhavas": "afilhar",
    "afilhe": "afilhar",
    "afilhei": "afilhar",
    "afilheis": "afilhar",
    "afilhem": "afilhar",
    "afilhemo": "afilhar",
    "afilhemos": "afilhar",
    "afilhes": "afilhar",
    "afilho": "afilhar",
    "afilhou": "afilhar",
    "afilhámo": "afilhar",
    "afilhámos": "afilhar",
    "afilháramo": "afilhar",
    "afilháramos": "afilhar",
    "afilháreis": "afilhar",
    "afilhásseis": "afilhar",
    "afilhássemos": "afilhar",
    "afilhávamo": "afilhar",
    "afilhávamos": "afilhar",
    "afilháveis": "afilhar",
    "afilia": "afiliar",
    "afiliada": "afiliar",
    "afiliadas": "afiliar",
    "afiliado": "afiliar",
    "afiliados": "afiliar",
    "afiliai": "afiliar",
    "afiliais": "afiliar",
    "afiliam": "afiliar",
    "afiliamo": "afiliar",
    "afiliamos": "afiliar",
    "afiliando": "afiliar",
    "afiliara": "afiliar",
    "afiliaram": "afiliar",
    "afiliaras": "afiliar",
    "afiliarde": "afiliar",
    "afiliardes": "afiliar",
    "afiliare": "afiliar",
    "afiliarei": "afiliar",
    "afiliareis": "afiliar",
    "afiliarem": "afiliar",
    "afiliaremos": "afiliar",
    "afiliares": "afiliar",
    "afiliaria": "afiliar",
    "afiliariam": "afiliar",
    "afiliarias": "afiliar",
    "afiliarmo": "afiliar",
    "afiliarmos": "afiliar",
    "afiliará": "afiliar",
    "afiliarás": "afiliar",
    "afiliarão": "afiliar",
    "afiliaríamos": "afiliar",
    "afiliaríeis": "afiliar",
    "afilias": "afiliar",
    "afiliasse": "afiliar",
    "afiliassem": "afiliar",
    "afiliasses": "afiliar",
    "afiliaste": "afiliar",
    "afiliastes": "afiliar",
    "afiliava": "afiliar",
    "afiliavam": "afiliar",
    "afiliavas": "afiliar",
    "afiliações": "afiliação",
    "afilie": "afiliar",
    "afiliei": "afiliar",
    "afilieis": "afiliar",
    "afiliem": "afiliar",
    "afiliemo": "afiliar",
    "afiliemos": "afiliar",
    "afilies": "afiliar",
    "afilio": "afiliar",
    "afiliou": "afiliar",
    "afiliá": "afiliar",
    "afiliámo": "afiliar",
    "afiliámos": "afiliar",
    "afiliáramo": "afiliar",
    "afiliáramos": "afiliar",
    "afiliárei": "afiliar",
    "afiliáreis": "afiliar",
    "afiliásseis": "afiliar",
    "afiliássemos": "afiliar",
    "afiliávamo": "afiliar",
    "afiliávamos": "afiliar",
    "afiliávei": "afiliar",
    "afiliáveis": "afiliar",
    "afilo": "afilar",
    "afilos": "afilo",
    "afilou": "afilar",
    "afilá": "afilar",
    "afilámo": "afilar",
    "afilámos": "afilar",
    "afiláramo": "afilar",
    "afiláramos": "afilar",
    "afilárei": "afilar",
    "afiláreis": "afilar",
    "afilásseis": "afilar",
    "afilássemos": "afilar",
    "afilávamo": "afilar",
    "afilávamos": "afilar",
    "afilávei": "afilar",
    "afiláveis": "afilar",
    "afina": "afinar",
    "afinada": "afinar",
    "afinadas": "afinar",
    "afinado": "afinar",
    "afinadora": "afinador",
    "afinadoras": "afinador",
    "afinadores": "afinador",
    "afinados": "afinar",
    "afinadíssima": "afinado",
    "afinadíssimas": "afinado",
    "afinadíssimo": "afinado",
    "afinadíssimos": "afinado",
    "afinagens": "afinagem",
    "afinai": "afinar",
    "afinais": "afinar",
    "afinam": "afinar",
    "afinamentos": "afinamento",
    "afinamo": "afinar",
    "afinamos": "afinar",
    "afinando": "afinar",
    "afinara": "afinar",
    "afinaram": "afinar",
    "afinaras": "afinar",
    "afinarde": "afinar",
    "afinardes": "afinar",
    "afinare": "afinar",
    "afinarei": "afinar",
    "afinareis": "afinar",
    "afinarem": "afinar",
    "afinaremos": "afinar",
    "afinares": "afinar",
    "afinaria": "afinar",
    "afinariam": "afinar",
    "afinarias": "afinar",
    "afinarmo": "afinar",
    "afinarmos": "afinar",
    "afinará": "afinar",
    "afinarás": "afinar",
    "afinarão": "afinar",
    "afinaríamos": "afinar",
    "afinaríeis": "afinar",
    "afinas": "afinar",
    "afinasse": "afinar",
    "afinassem": "afinar",
    "afinasses": "afinar",
    "afinaste": "afinar",
    "afinastes": "afinar",
    "afinava": "afinar",
    "afinavam": "afinar",
    "afinavas": "afinar",
    "afinações": "afinação",
    "afinca": "afincar",
    "afincada": "afincar",
    "afincadas": "afincar",
    "afincado": "afincar",
    "afincados": "afincar",
    "afincai": "afincar",
    "afincais": "afincar",
    "afincam": "afincar",
    "afincamentos": "afincamento",
    "afincamo": "afincar",
    "afincamos": "afincar",
    "afincando": "afincar",
    "afincara": "afincar",
    "afincaram": "afincar",
    "afincaras": "afincar",
    "afincarde": "afincar",
    "afincardes": "afincar",
    "afincare": "afincar",
    "afincarei": "afincar",
    "afincareis": "afincar",
    "afincarem": "afincar",
    "afincaremos": "afincar",
    "afincares": "afincar",
    "afincaria": "afincar",
    "afincariam": "afincar",
    "afincarias": "afincar",
    "afincarmo": "afincar",
    "afincarmos": "afincar",
    "afincará": "afincar",
    "afincarás": "afincar",
    "afincarão": "afincar",
    "afincaríamos": "afincar",
    "afincaríeis": "afincar",
    "afincas": "afincar",
    "afincasse": "afincar",
    "afincassem": "afincar",
    "afincasses": "afincar",
    "afincaste": "afincar",
    "afincastes": "afincar",
    "afincava": "afincar",
    "afincavam": "afincar",
    "afincavas": "afincar",
    "afinco": "afincar",
    "afincoa": "afincoar",
    "afincoada": "afincoar",
    "afincoadas": "afincoar",
    "afincoado": "afincoar",
    "afincoados": "afincoar",
    "afincoai": "afincoar",
    "afincoais": "afincoar",
    "afincoam": "afincoar",
    "afincoamo": "afincoar",
    "afincoamos": "afincoar",
    "afincoando": "afincoar",
    "afincoara": "afincoar",
    "afincoaram": "afincoar",
    "afincoaras": "afincoar",
    "afincoarde": "afincoar",
    "afincoardes": "afincoar",
    "afincoare": "afincoar",
    "afincoarei": "afincoar",
    "afincoareis": "afincoar",
    "afincoarem": "afincoar",
    "afincoaremos": "afincoar",
    "afincoares": "afincoar",
    "afincoaria": "afincoar",
    "afincoariam": "afincoar",
    "afincoarias": "afincoar",
    "afincoarmo": "afincoar",
    "afincoarmos": "afincoar",
    "afincoará": "afincoar",
    "afincoarás": "afincoar",
    "afincoarão": "afincoar",
    "afincoaríamos": "afincoar",
    "afincoaríeis": "afincoar",
    "afincoas": "afincoar",
    "afincoasse": "afincoar",
    "afincoassem": "afincoar",
    "afincoasses": "afincoar",
    "afincoaste": "afincoar",
    "afincoastes": "afincoar",
    "afincoava": "afincoar",
    "afincoavam": "afincoar",
    "afincoavas": "afincoar",
    "afincoe": "afincoar",
    "afincoei": "afincoar",
    "afincoeis": "afincoar",
    "afincoem": "afincoar",
    "afincoemo": "afincoar",
    "afincoemos": "afincoar",
    "afincoes": "afincoar",
    "afincoo": "afincoar",
    "afincoou": "afincoar",
    "afincou": "afincar",
    "afincoá": "afincoar",
    "afincoámo": "afincoar",
    "afincoámos": "afincoar",
    "afincoáramo": "afincoar",
    "afincoáramos": "afincoar",
    "afincoárei": "afincoar",
    "afincoáreis": "afincoar",
    "afincoásseis": "afincoar",
    "afincoássemos": "afincoar",
    "afincoávamo": "afincoar",
    "afincoávamos": "afincoar",
    "afincoávei": "afincoar",
    "afincoáveis": "afincoar",
    "afincá": "afincar",
    "afincámo": "afincar",
    "afincámos": "afincar",
    "afincáramo": "afincar",
    "afincáramos": "afincar",
    "afincárei": "afincar",
    "afincáreis": "afincar",
    "afincásseis": "afincar",
    "afincássemos": "afincar",
    "afincávamo": "afincar",
    "afincávamos": "afincar",
    "afincávei": "afincar",
    "afincáveis": "afincar",
    "afine": "afinar",
    "afinei": "afinar",
    "afineis": "afinar",
    "afinem": "afinar",
    "afinemo": "afinar",
    "afinemos": "afinar",
    "afines": "afinar",
    "afinfa": "afinfar",
    "afinfada": "afinfar",
    "afinfadas": "afinfar",
    "afinfado": "afinfar",
    "afinfados": "afinfar",
    "afinfai": "afinfar",
    "afinfais": "afinfar",
    "afinfam": "afinfar",
    "afinfamo": "afinfar",
    "afinfamos": "afinfar",
    "afinfando": "afinfar",
    "afinfara": "afinfar",
    "afinfaram": "afinfar",
    "afinfaras": "afinfar",
    "afinfarde": "afinfar",
    "afinfardes": "afinfar",
    "afinfare": "afinfar",
    "afinfarei": "afinfar",
    "afinfareis": "afinfar",
    "afinfarem": "afinfar",
    "afinfaremos": "afinfar",
    "afinfares": "afinfar",
    "afinfaria": "afinfar",
    "afinfariam": "afinfar",
    "afinfarias": "afinfar",
    "afinfarmo": "afinfar",
    "afinfarmos": "afinfar",
    "afinfará": "afinfar",
    "afinfarás": "afinfar",
    "afinfarão": "afinfar",
    "afinfaríamos": "afinfar",
    "afinfaríeis": "afinfar",
    "afinfas": "afinfar",
    "afinfasse": "afinfar",
    "afinfassem": "afinfar",
    "afinfasses": "afinfar",
    "afinfaste": "afinfar",
    "afinfastes": "afinfar",
    "afinfava": "afinfar",
    "afinfavam": "afinfar",
    "afinfavas": "afinfar",
    "afinfe": "afinfar",
    "afinfei": "afinfar",
    "afinfeis": "afinfar",
    "afinfem": "afinfar",
    "afinfemo": "afinfar",
    "afinfemos": "afinfar",
    "afinfes": "afinfar",
    "afinfo": "afinfar",
    "afinfou": "afinfar",
    "afinfá": "afinfar",
    "afinfámo": "afinfar",
    "afinfámos": "afinfar",
    "afinfáramo": "afinfar",
    "afinfáramos": "afinfar",
    "afinfárei": "afinfar",
    "afinfáreis": "afinfar",
    "afinfásseis": "afinfar",
    "afinfássemos": "afinfar",
    "afinfávamo": "afinfar",
    "afinfávamos": "afinfar",
    "afinfávei": "afinfar",
    "afinfáveis": "afinfar",
    "afinidades": "afinidade",
    "afino": "afinar",
    "afinou": "afinar",
    "afinque": "afincar",
    "afinquei": "afincar",
    "afinqueis": "afincar",
    "afinquem": "afincar",
    "afinquemo": "afincar",
    "afinquemos": "afincar",
    "afinques": "afincar",
    "afins": "afim",
    "afiná": "afinar",
    "afinámo": "afinar",
    "afinámos": "afinar",
    "afináramo": "afinar",
    "afináramos": "afinar",
    "afinárei": "afinar",
    "afináreis": "afinar",
    "afinásseis": "afinar",
    "afinássemos": "afinar",
    "afinávamo": "afinar",
    "afinávamos": "afinar",
    "afinávei": "afinar",
    "afináveis": "afinável",
    "afio": "afiar",
    "afiou": "afiar",
    "afira": "aferir",
    "afirais": "aferir",
    "afiram": "aferir",
    "afiramo": "aferir",
    "afiramos": "aferir",
    "afiras": "aferir",
    "afirma": "afirmar",
    "afirmada": "afirmar",
    "afirmadas": "afirmar",
    "afirmado": "afirmar",
    "afirmados": "afirmar",
    "afirmai": "afirmar",
    "afirmais": "afirmar",
    "afirmam": "afirmar",
    "afirmamo": "afirmar",
    "afirmamos": "afirmar",
    "afirmando": "afirmar",
    "afirmantes": "afirmante",
    "afirmara": "afirmar",
    "afirmaram": "afirmar",
    "afirmaras": "afirmar",
    "afirmarde": "afirmar",
    "afirmardes": "afirmar",
    "afirmare": "afirmar",
    "afirmarei": "afirmar",
    "afirmareis": "afirmar",
    "afirmarem": "afirmar",
    "afirmaremos": "afirmar",
    "afirmares": "afirmar",
    "afirmaria": "afirmar",
    "afirmariam": "afirmar",
    "afirmarias": "afirmar",
    "afirmarmo": "afirmar",
    "afirmarmos": "afirmar",
    "afirmará": "afirmar",
    "afirmarás": "afirmar",
    "afirmarão": "afirmar",
    "afirmaríamos": "afirmar",
    "afirmaríeis": "afirmar",
    "afirmas": "afirmar",
    "afirmasse": "afirmar",
    "afirmassem": "afirmar",
    "afirmasses": "afirmar",
    "afirmaste": "afirmar",
    "afirmastes": "afirmar",
    "afirmativa": "afirmativo",
    "afirmativas": "afirmativo",
    "afirmativos": "afirmativo",
    "afirmava": "afirmar",
    "afirmavam": "afirmar",
    "afirmavas": "afirmar",
    "afirmações": "afirmação",
    "afirme": "afirmar",
    "afirmei": "afirmar",
    "afirmeis": "afirmar",
    "afirmem": "afirmar",
    "afirmemo": "afirmar",
    "afirmemos": "afirmar",
    "afirmes": "afirmar",
    "afirmo": "afirmar",
    "afirmou": "afirmar",
    "afirmá": "afirmar",
    "afirmámo": "afirmar",
    "afirmámos": "afirmar",
    "afirmáramo": "afirmar",
    "afirmáramos": "afirmar",
    "afirmárei": "afirmar",
    "afirmáreis": "afirmar",
    "afirmásseis": "afirmar",
    "afirmássemos": "afirmar",
    "afirmávamo": "afirmar",
    "afirmávamos": "afirmar",
    "afirmávei": "afirmar",
    "afirmáveis": "afirmar",
    "afiro": "aferir",
    "afistula": "afistular",
    "afistulada": "afistular",
    "afistuladas": "afistular",
    "afistulado": "afistular",
    "afistulados": "afistular",
    "afistulai": "afistular",
    "afistulais": "afistular",
    "afistulam": "afistular",
    "afistulamo": "afistular",
    "afistulamos": "afistular",
    "afistulando": "afistular",
    "afistulara": "afistular",
    "afistularam": "afistular",
    "afistularas": "afistular",
    "afistularde": "afistular",
    "afistulardes": "afistular",
    "afistulare": "afistular",
    "afistularei": "afistular",
    "afistulareis": "afistular",
    "afistularem": "afistular",
    "afistularemos": "afistular",
    "afistulares": "afistular",
    "afistularia": "afistular",
    "afistulariam": "afistular",
    "afistularias": "afistular",
    "afistularmo": "afistular",
    "afistularmos": "afistular",
    "afistulará": "afistular",
    "afistularás": "afistular",
    "afistularão": "afistular",
    "afistularíamos": "afistular",
    "afistularíeis": "afistular",
    "afistulas": "afistular",
    "afistulasse": "afistular",
    "afistulassem": "afistular",
    "afistulasses": "afistular",
    "afistulaste": "afistular",
    "afistulastes": "afistular",
    "afistulava": "afistular",
    "afistulavam": "afistular",
    "afistulavas": "afistular",
    "afistule": "afistular",
    "afistulei": "afistular",
    "afistuleis": "afistular",
    "afistulem": "afistular",
    "afistulemo": "afistular",
    "afistulemos": "afistular",
    "afistules": "afistular",
    "afistulo": "afistular",
    "afistulou": "afistular",
    "afistulá": "afistular",
    "afistulámo": "afistular",
    "afistulámos": "afistular",
    "afistuláramo": "afistular",
    "afistuláramos": "afistular",
    "afistulárei": "afistular",
    "afistuláreis": "afistular",
    "afistulásseis": "afistular",
    "afistulássemos": "afistular",
    "afistulávamo": "afistular",
    "afistulávamos": "afistular",
    "afistulávei": "afistular",
    "afistuláveis": "afistular",
    "afitada": "afitado",
    "afitadas": "afitado",
    "afitados": "afitado",
    "afitamentos": "afitamento",
    "afitos": "afito",
    "afivela": "afivelar",
    "afivelada": "afivelar",
    "afiveladas": "afivelar",
    "afivelado": "afivelar",
    "afivelados": "afivelar",
    "afivelai": "afivelar",
    "afivelais": "afivelar",
    "afivelam": "afivelar",
    "afivelamo": "afivelar",
    "afivelamos": "afivelar",
    "afivelando": "afivelar",
    "afivelara": "afivelar",
    "afivelaram": "afivelar",
    "afivelaras": "afivelar",
    "afivelarde": "afivelar",
    "afivelardes": "afivelar",
    "afivelare": "afivelar",
    "afivelarei": "afivelar",
    "afivelareis": "afivelar",
    "afivelarem": "afivelar",
    "afivelaremos": "afivelar",
    "afivelares": "afivelar",
    "afivelaria": "afivelar",
    "afivelariam": "afivelar",
    "afivelarias": "afivelar",
    "afivelarmo": "afivelar",
    "afivelarmos": "afivelar",
    "afivelará": "afivelar",
    "afivelarás": "afivelar",
    "afivelarão": "afivelar",
    "afivelaríamos": "afivelar",
    "afivelaríeis": "afivelar",
    "afivelas": "afivelar",
    "afivelasse": "afivelar",
    "afivelassem": "afivelar",
    "afivelasses": "afivelar",
    "afivelaste": "afivelar",
    "afivelastes": "afivelar",
    "afivelava": "afivelar",
    "afivelavam": "afivelar",
    "afivelavas": "afivelar",
    "afivele": "afivelar",
    "afivelei": "afivelar",
    "afiveleis": "afivelar",
    "afivelem": "afivelar",
    "afivelemo": "afivelar",
    "afivelemos": "afivelar",
    "afiveles": "afivelar",
    "afivelo": "afivelar",
    "afivelou": "afivelar",
    "afivelá": "afivelar",
    "afivelámo": "afivelar",
    "afivelámos": "afivelar",
    "afiveláramo": "afivelar",
    "afiveláramos": "afivelar",
    "afivelárei": "afivelar",
    "afiveláreis": "afivelar",
    "afivelásseis": "afivelar",
    "afivelássemos": "afivelar",
    "afivelávamo": "afivelar",
    "afivelávamos": "afivelar",
    "afivelávei": "afivelar",
    "afiveláveis": "afivelar",
    "afixa": "afixo",
    "afixada": "afixar",
    "afixadas": "afixar",
    "afixado": "afixar",
    "afixados": "afixar",
    "afixai": "afixar",
    "afixais": "afixar",
    "afixam": "afixar",
    "afixamo": "afixar",
    "afixamos": "afixar",
    "afixando": "afixar",
    "afixara": "afixar",
    "afixaram": "afixar",
    "afixaras": "afixar",
    "afixarde": "afixar",
    "afixardes": "afixar",
    "afixare": "afixar",
    "afixarei": "afixar",
    "afixareis": "afixar",
    "afixarem": "afixar",
    "afixaremos": "afixar",
    "afixares": "afixar",
    "afixaria": "afixar",
    "afixariam": "afixar",
    "afixarias": "afixar",
    "afixarmo": "afixar",
    "afixarmos": "afixar",
    "afixará": "afixar",
    "afixarás": "afixar",
    "afixarão": "afixar",
    "afixaríamos": "afixar",
    "afixaríeis": "afixar",
    "afixas": "afixo",
    "afixasse": "afixar",
    "afixassem": "afixar",
    "afixasses": "afixar",
    "afixaste": "afixar",
    "afixastes": "afixar",
    "afixava": "afixar",
    "afixavam": "afixar",
    "afixavas": "afixar",
    "afixações": "afixação",
    "afixe": "afixar",
    "afixei": "afixar",
    "afixeis": "afixar",
    "afixem": "afixar",
    "afixemo": "afixar",
    "afixemos": "afixar",
    "afixes": "afixar",
    "afixo": "afixar",
    "afixos": "afixo",
    "afixou": "afixar",
    "afixá": "afixar",
    "afixámo": "afixar",
    "afixámos": "afixar",
    "afixáramo": "afixar",
    "afixáramos": "afixar",
    "afixárei": "afixar",
    "afixáreis": "afixar",
    "afixásseis": "afixar",
    "afixássemos": "afixar",
    "afixávamo": "afixar",
    "afixávamos": "afixar",
    "afixávei": "afixar",
    "afixáveis": "afixável",
    "afiz": "afazer",
    "afizemo": "afazer",
    "afizemos": "afazer",
    "afizer": "afazer",
    "afizera": "afazer",
    "afizeram": "afazer",
    "afizeras": "afazer",
    "afizerdes": "afazer",
    "afizerem": "afazer",
    "afizeres": "afazer",
    "afizermos": "afazer",
    "afizesse": "afazer",
    "afizessem": "afazer",
    "afizesses": "afazer",
    "afizeste": "afazer",
    "afizestes": "afazer",
    "afizéramo": "afazer",
    "afizéramos": "afazer",
    "afizérei": "afazer",
    "afizéreis": "afazer",
    "afizésseis": "afazer",
    "afizéssemos": "afazer",
    "afiá": "afiar",
    "afiámo": "afiar",
    "afiámos": "afiar",
    "afiáramo": "afiar",
    "afiáramos": "afiar",
    "afiárei": "afiar",
    "afiáreis": "afiar",
    "afiásseis": "afiar",
    "afiássemos": "afiar",
    "afiávamo": "afiar",
    "afiávamos": "afiar",
    "afiávei": "afiar",
    "afiáveis": "afiar",
    "afla": "aflar",
    "aflada": "aflar",
    "afladas": "aflar",
    "aflado": "aflar",
    "aflados": "aflar",
    "aflai": "aflar",
    "aflais": "aflar",
    "aflam": "aflar",
    "aflamengada": "aflamengado",
    "aflamengadas": "aflamengado",
    "aflamengados": "aflamengado",
    "aflamo": "aflar",
    "aflamos": "aflar",
    "aflando": "aflar",
    "aflara": "aflar",
    "aflaram": "aflar",
    "aflaras": "aflar",
    "aflarde": "aflar",
    "aflardes": "aflar",
    "aflare": "aflar",
    "aflarei": "aflar",
    "aflareis": "aflar",
    "aflarem": "aflar",
    "aflaremos": "aflar",
    "aflares": "aflar",
    "aflaria": "aflar",
    "aflariam": "aflar",
    "aflarias": "aflar",
    "aflarmo": "aflar",
    "aflarmos": "aflar",
    "aflará": "aflar",
    "aflarás": "aflar",
    "aflarão": "aflar",
    "aflaríamos": "aflar",
    "aflaríeis": "aflar",
    "aflas": "aflar",
    "aflasse": "aflar",
    "aflassem": "aflar",
    "aflasses": "aflar",
    "aflaste": "aflar",
    "aflastes": "aflar",
    "aflatos": "aflato",
    "aflauta": "aflautar",
    "aflautada": "aflautar",
    "aflautadas": "aflautar",
    "aflautado": "aflautar",
    "aflautados": "aflautar",
    "aflautai": "aflautar",
    "aflautais": "aflautar",
    "aflautam": "aflautar",
    "aflautamo": "aflautar",
    "aflautamos": "aflautar",
    "aflautando": "aflautar",
    "aflautara": "aflautar",
    "aflautaram": "aflautar",
    "aflautaras": "aflautar",
    "aflautarde": "aflautar",
    "aflautardes": "aflautar",
    "aflautare": "aflautar",
    "aflautarei": "aflautar",
    "aflautareis": "aflautar",
    "aflautarem": "aflautar",
    "aflautaremos": "aflautar",
    "aflautares": "aflautar",
    "aflautaria": "aflautar",
    "aflautariam": "aflautar",
    "aflautarias": "aflautar",
    "aflautarmo": "aflautar",
    "aflautarmos": "aflautar",
    "aflautará": "aflautar",
    "aflautarás": "aflautar",
    "aflautarão": "aflautar",
    "aflautaríamos": "aflautar",
    "aflautaríeis": "aflautar",
    "aflautas": "aflautar",
    "aflautasse": "aflautar",
    "aflautassem": "aflautar",
    "aflautasses": "aflautar",
    "aflautaste": "aflautar",
    "aflautastes": "aflautar",
    "aflautava": "aflautar",
    "aflautavam": "aflautar",
    "aflautavas": "aflautar",
    "aflaute": "aflautar",
    "aflautei": "aflautar",
    "aflauteis": "aflautar",
    "aflautem": "aflautar",
    "aflautemo": "aflautar",
    "aflautemos": "aflautar",
    "aflautes": "aflautar",
    "aflauto": "aflautar",
    "aflautou": "aflautar",
    "aflautá": "aflautar",
    "aflautámo": "aflautar",
    "aflautámos": "aflautar",
    "aflautáramo": "aflautar",
    "aflautáramos": "aflautar",
    "aflautárei": "aflautar",
    "aflautáreis": "aflautar",
    "aflautásseis": "aflautar",
    "aflautássemos": "aflautar",
    "aflautávamo": "aflautar",
    "aflautávamos": "aflautar",
    "aflautávei": "aflautar",
    "aflautáveis": "aflautar",
    "aflava": "aflar",
    "aflavam": "aflar",
    "aflavas": "aflar",
    "afle": "aflar",
    "aflei": "aflar",
    "afleima": "afleimar",
    "afleimada": "afleimar",
    "afleimadas": "afleimar",
    "afleimado": "afleimar",
    "afleimados": "afleimar",
    "afleimai": "afleimar",
    "afleimais": "afleimar",
    "afleimam": "afleimar",
    "afleimamo": "afleimar",
    "afleimamos": "afleimar",
    "afleimando": "afleimar",
    "afleimara": "afleimar",
    "afleimaram": "afleimar",
    "afleimaras": "afleimar",
    "afleimarde": "afleimar",
    "afleimardes": "afleimar",
    "afleimare": "afleimar",
    "afleimarei": "afleimar",
    "afleimareis": "afleimar",
    "afleimarem": "afleimar",
    "afleimaremos": "afleimar",
    "afleimares": "afleimar",
    "afleimaria": "afleimar",
    "afleimariam": "afleimar",
    "afleimarias": "afleimar",
    "afleimarmo": "afleimar",
    "afleimarmos": "afleimar",
    "afleimará": "afleimar",
    "afleimarás": "afleimar",
    "afleimarão": "afleimar",
    "afleimaríamos": "afleimar",
    "afleimaríeis": "afleimar",
    "afleimas": "afleimar",
    "afleimasse": "afleimar",
    "afleimassem": "afleimar",
    "afleimasses": "afleimar",
    "afleimaste": "afleimar",
    "afleimastes": "afleimar",
    "afleimava": "afleimar",
    "afleimavam": "afleimar",
    "afleimavas": "afleimar",
    "afleime": "afleimar",
    "afleimei": "afleimar",
    "afleimeis": "afleimar",
    "afleimem": "afleimar",
    "afleimemo": "afleimar",
    "afleimemos": "afleimar",
    "afleimes": "afleimar",
    "afleimo": "afleimar",
    "afleimou": "afleimar",
    "afleimá": "afleimar",
    "afleimámo": "afleimar",
    "afleimámos": "afleimar",
    "afleimáramo": "afleimar",
    "afleimáramos": "afleimar",
    "afleimárei": "afleimar",
    "afleimáreis": "afleimar",
    "afleimásseis": "afleimar",
    "afleimássemos": "afleimar",
    "afleimávamo": "afleimar",
    "afleimávamos": "afleimar",
    "afleimávei": "afleimar",
    "afleimáveis": "afleimar",
    "afleis": "aflar",
    "aflem": "aflar",
    "aflemo": "aflar",
    "aflemos": "aflar",
    "afles": "aflar",
    "afleuma": "afleumar",
    "afleumada": "afleumar",
    "afleumadas": "afleumar",
    "afleumado": "afleumar",
    "afleumados": "afleumar",
    "afleumai": "afleumar",
    "afleumais": "afleumar",
    "afleumam": "afleumar",
    "afleumamo": "afleumar",
    "afleumamos": "afleumar",
    "afleumando": "afleumar",
    "afleumara": "afleumar",
    "afleumaram": "afleumar",
    "afleumaras": "afleumar",
    "afleumarde": "afleumar",
    "afleumardes": "afleumar",
    "afleumare": "afleumar",
    "afleumarei": "afleumar",
    "afleumareis": "afleumar",
    "afleumarem": "afleumar",
    "afleumaremos": "afleumar",
    "afleumares": "afleumar",
    "afleumaria": "afleumar",
    "afleumariam": "afleumar",
    "afleumarias": "afleumar",
    "afleumarmo": "afleumar",
    "afleumarmos": "afleumar",
    "afleumará": "afleumar",
    "afleumarás": "afleumar",
    "afleumarão": "afleumar",
    "afleumaríamos": "afleumar",
    "afleumaríeis": "afleumar",
    "afleumas": "afleumar",
    "afleumasse": "afleumar",
    "afleumassem": "afleumar",
    "afleumasses": "afleumar",
    "afleumaste": "afleumar",
    "afleumastes": "afleumar",
    "afleumava": "afleumar",
    "afleumavam": "afleumar",
    "afleumavas": "afleumar",
    "afleume": "afleumar",
    "afleumei": "afleumar",
    "afleumeis": "afleumar",
    "afleumem": "afleumar",
    "afleumemo": "afleumar",
    "afleumemos": "afleumar",
    "afleumes": "afleumar",
    "afleumo": "afleumar",
    "afleumou": "afleumar",
    "afleumá": "afleumar",
    "afleumámo": "afleumar",
    "afleumámos": "afleumar",
    "afleumáramo": "afleumar",
    "afleumáramos": "afleumar",
    "afleumárei": "afleumar",
    "afleumáreis": "afleumar",
    "afleumásseis": "afleumar",
    "afleumássemos": "afleumar",
    "afleumávamo": "afleumar",
    "afleumávamos": "afleumar",
    "afleumávei": "afleumar",
    "afleumáveis": "afleumar",
    "afliaçãozinha": "afliação",
    "afliaçãozita": "afliação",
    "afliações": "afliação",
    "afliaçõezinhas": "afliação",
    "afliaçõezitas": "afliação",
    "aflige": "afligir",
    "afligem": "afligir",
    "afliges": "afligir",
    "afligi": "afligir",
    "afligia": "afligir",
    "afligiam": "afligir",
    "afligias": "afligir",
    "afligida": "afligir",
    "afligidas": "afligir",
    "afligido": "afligir",
    "afligidos": "afligir",
    "afligimentos": "afligimento",
    "afligimo": "afligir",
    "afligimos": "afligir",
    "afligindo": "afligir",
    "afligira": "afligir",
    "afligiram": "afligir",
    "afligiras": "afligir",
    "afligirde": "afligir",
    "afligirdes": "afligir",
    "afligire": "afligir",
    "afligirei": "afligir",
    "afligireis": "afligir",
    "afligirem": "afligir",
    "afligiremos": "afligir",
    "afligires": "afligir",
    "afligiria": "afligir",
    "afligiriam": "afligir",
    "afligirias": "afligir",
    "afligirmo": "afligir",
    "afligirmos": "afligir",
    "afligirá": "afligir",
    "afligirás": "afligir",
    "afligirão": "afligir",
    "afligiríamos": "afligir",
    "afligiríeis": "afligir",
    "afligis": "afligir",
    "afligisse": "afligir",
    "afligissem": "afligir",
    "afligisses": "afligir",
    "afligiste": "afligir",
    "afligistes": "afligir",
    "afligiu": "afligir",
    "afligíamo": "afligir",
    "afligíamos": "afligir",
    "afligíei": "afligir",
    "afligíeis": "afligir",
    "afligíramo": "afligir",
    "afligíramos": "afligir",
    "afligírei": "afligir",
    "afligíreis": "afligir",
    "afligísseis": "afligir",
    "afligíssemos": "afligir",
    "afligíveis": "afligível",
    "aflija": "afligir",
    "aflijais": "afligir",
    "aflijam": "afligir",
    "aflijamo": "afligir",
    "aflijamos": "afligir",
    "aflijas": "afligir",
    "aflijo": "afligir",
    "aflita": "aflito",
    "aflitas": "aflito",
    "aflitinha": "aflito",
    "aflitinhas": "aflito",
    "aflitinho": "aflito",
    "aflitinhos": "aflito",
    "aflitita": "aflito",
    "aflititas": "aflito",
    "aflitito": "aflito",
    "aflititos": "aflito",
    "aflitiva": "aflitivo",
    "aflitivas": "aflitivo",
    "aflitivos": "aflitivo",
    "aflitos": "aflito",
    "aflitíssima": "aflito",
    "aflitíssimas": "aflito",
    "aflitíssimo": "aflito",
    "aflitíssimos": "aflito",
    "afliçãozinha": "aflição",
    "afliçãozita": "aflição",
    "aflições": "aflição",
    "afliçõezinhas": "aflição",
    "afliçõezitas": "aflição",
    "aflo": "aflar",
    "aflogística": "aflogístico",
    "aflogísticas": "aflogístico",
    "aflogísticos": "aflogístico",
    "aflora": "aflorar",
    "aflorada": "aflorar",
    "afloradas": "aflorar",
    "aflorado": "aflorar",
    "aflorados": "aflorar",
    "aflorai": "aflorar",
    "aflorais": "aflorar",
    "afloram": "aflorar",
    "afloramentos": "afloramento",
    "afloramo": "aflorar",
    "afloramos": "aflorar",
    "aflorando": "aflorar",
    "aflorara": "aflorar",
    "afloraram": "aflorar",
    "afloraras": "aflorar",
    "aflorarde": "aflorar",
    "aflorardes": "aflorar",
    "aflorare": "aflorar",
    "aflorarei": "aflorar",
    "aflorareis": "aflorar",
    "aflorarem": "aflorar",
    "afloraremos": "aflorar",
    "aflorares": "aflorar",
    "afloraria": "aflorar",
    "aflorariam": "aflorar",
    "aflorarias": "aflorar",
    "aflorarmo": "aflorar",
    "aflorarmos": "aflorar",
    "aflorará": "aflorar",
    "aflorarás": "aflorar",
    "aflorarão": "aflorar",
    "afloraríamos": "aflorar",
    "afloraríeis": "aflorar",
    "afloras": "aflorar",
    "aflorasse": "aflorar",
    "aflorassem": "aflorar",
    "aflorasses": "aflorar",
    "afloraste": "aflorar",
    "aflorastes": "aflorar",
    "aflorava": "aflorar",
    "afloravam": "aflorar",
    "afloravas": "aflorar",
    "aflorações": "afloração",
    "aflore": "aflorar",
    "aflorei": "aflorar",
    "afloreis": "aflorar",
    "aflorem": "aflorar",
    "afloremo": "aflorar",
    "afloremos": "aflorar",
    "aflores": "aflorar",
    "afloro": "aflorar",
    "aflorou": "aflorar",
    "aflorá": "aflorar",
    "aflorámo": "aflorar",
    "aflorámos": "aflorar",
    "afloráramo": "aflorar",
    "afloráramos": "aflorar",
    "aflorárei": "aflorar",
    "afloráreis": "aflorar",
    "aflorásseis": "aflorar",
    "aflorássemos": "aflorar",
    "aflorávamo": "aflorar",
    "aflorávamos": "aflorar",
    "aflorávei": "aflorar",
    "afloráveis": "aflorar",
    "aflou": "aflar",
    "aflua": "afluir",
    "afluais": "afluir",
    "afluam": "afluir",
    "afluamo": "afluir",
    "afluamos": "afluir",
    "afluas": "afluir",
    "afluem": "afluir",
    "afluentes": "afluente",
    "aflui": "afluir",
    "afluindo": "afluir",
    "afluirdes": "afluir",
    "afluirei": "afluir",
    "afluireis": "afluir",
    "afluiremos": "afluir",
    "afluiria": "afluir",
    "afluiriam": "afluir",
    "afluirias": "afluir",
    "afluirmo": "afluir",
    "afluirmos": "afluir",
    "afluirá": "afluir",
    "afluirás": "afluir",
    "afluirão": "afluir",
    "afluiríamos": "afluir",
    "afluiríeis": "afluir",
    "afluis": "afluir",
    "afluiu": "afluir",
    "afluo": "afluir",
    "afluxos": "afluxo",
    "afluências": "afluência",
    "afluí": "afluir",
    "afluía": "afluir",
    "afluíam": "afluir",
    "afluíamo": "afluir",
    "afluíamos": "afluir",
    "afluías": "afluir",
    "afluída": "afluir",
    "afluídas": "afluir",
    "afluído": "afluir",
    "afluídos": "afluir",
    "afluíeis": "afluir",
    "afluímo": "afluir",
    "afluímos": "afluir",
    "afluíra": "afluir",
    "afluíram": "afluir",
    "afluíramo": "afluir",
    "afluíramos": "afluir",
    "afluíras": "afluir",
    "afluíreis": "afluir",
    "afluírem": "afluir",
    "afluíres": "afluir",
    "afluís": "afluir",
    "afluísse": "afluir",
    "afluísseis": "afluir",
    "afluíssem": "afluir",
    "afluíssemos": "afluir",
    "afluísses": "afluir",
    "afluíste": "afluir",
    "afluístes": "afluir",
    "aflá": "aflar",
    "aflámo": "aflar",
    "aflámos": "aflar",
    "afláramo": "aflar",
    "afláramos": "aflar",
    "aflárei": "aflar",
    "afláreis": "aflar",
    "aflásseis": "aflar",
    "aflássemos": "aflar",
    "aflávamo": "aflar",
    "aflávamos": "aflar",
    "aflávei": "aflar",
    "afláveis": "aflar",
    "afnosa": "afnoso",
    "afnosas": "afnoso",
    "afnosos": "afnoso",
    "afocinha": "afocinhar",
    "afocinhada": "afocinhar",
    "afocinhadas": "afocinhar",
    "afocinhado": "afocinhar",
    "afocinhados": "afocinhar",
    "afocinhai": "afocinhar",
    "afocinhais": "afocinhar",
    "afocinham": "afocinhar",
    "afocinhamentos": "afocinhamento",
    "afocinhamo": "afocinhar",
    "afocinhamos": "afocinhar",
    "afocinhando": "afocinhar",
    "afocinhara": "afocinhar",
    "afocinharam": "afocinhar",
    "afocinharas": "afocinhar",
    "afocinharde": "afocinhar",
    "afocinhardes": "afocinhar",
    "afocinhare": "afocinhar",
    "afocinharei": "afocinhar",
    "afocinhareis": "afocinhar",
    "afocinharem": "afocinhar",
    "afocinharemos": "afocinhar",
    "afocinhares": "afocinhar",
    "afocinharia": "afocinhar",
    "afocinhariam": "afocinhar",
    "afocinharias": "afocinhar",
    "afocinharmo": "afocinhar",
    "afocinharmos": "afocinhar",
    "afocinhará": "afocinhar",
    "afocinharás": "afocinhar",
    "afocinharão": "afocinhar",
    "afocinharíamos": "afocinhar",
    "afocinharíeis": "afocinhar",
    "afocinhas": "afocinhar",
    "afocinhasse": "afocinhar",
    "afocinhassem": "afocinhar",
    "afocinhasses": "afocinhar",
    "afocinhaste": "afocinhar",
    "afocinhastes": "afocinhar",
    "afocinhava": "afocinhar",
    "afocinhavam": "afocinhar",
    "afocinhavas": "afocinhar",
    "afocinhe": "afocinhar",
    "afocinhei": "afocinhar",
    "afocinheis": "afocinhar",
    "afocinhem": "afocinhar",
    "afocinhemo": "afocinhar",
    "afocinhemos": "afocinhar",
    "afocinhes": "afocinhar",
    "afocinho": "afocinhar",
    "afocinhou": "afocinhar",
    "afocinhá": "afocinhar",
    "afocinhámo": "afocinhar",
    "afocinhámos": "afocinhar",
    "afocinháramo": "afocinhar",
    "afocinháramos": "afocinhar",
    "afocinhárei": "afocinhar",
    "afocinháreis": "afocinhar",
    "afocinhásseis": "afocinhar",
    "afocinhássemos": "afocinhar",
    "afocinhávamo": "afocinhar",
    "afocinhávamos": "afocinhar",
    "afocinhávei": "afocinhar",
    "afocinháveis": "afocinhar",
    "afofa": "afofar",
    "afofada": "afofar",
    "afofadas": "afofar",
    "afofado": "afofar",
    "afofados": "afofar",
    "afofai": "afofar",
    "afofais": "afofar",
    "afofam": "afofar",
    "afofamo": "afofar",
    "afofamos": "afofar",
    "afofando": "afofar",
    "afofara": "afofar",
    "afofaram": "afofar",
    "afofaras": "afofar",
    "afofarde": "afofar",
    "afofardes": "afofar",
    "afofare": "afofar",
    "afofarei": "afofar",
    "afofareis": "afofar",
    "afofarem": "afofar",
    "afofaremos": "afofar",
    "afofares": "afofar",
    "afofaria": "afofar",
    "afofariam": "afofar",
    "afofarias": "afofar",
    "afofarmo": "afofar",
    "afofarmos": "afofar",
    "afofará": "afofar",
    "afofarás": "afofar",
    "afofarão": "afofar",
    "afofaríamos": "afofar",
    "afofaríeis": "afofar",
    "afofas": "afofar",
    "afofasse": "afofar",
    "afofassem": "afofar",
    "afofasses": "afofar",
    "afofaste": "afofar",
    "afofastes": "afofar",
    "afofava": "afofar",
    "afofavam": "afofar",
    "afofavas": "afofar",
    "afofe": "afofar",
    "afofei": "afofar",
    "afofeis": "afofar",
    "afofem": "afofar",
    "afofemo": "afofar",
    "afofemos": "afofar",
    "afofes": "afofar",
    "afofo": "afofar",
    "afofou": "afofar",
    "afofá": "afofar",
    "afofámo": "afofar",
    "afofámos": "afofar",
    "afofáramo": "afofar",
    "afofáramos": "afofar",
    "afofárei": "afofar",
    "afofáreis": "afofar",
    "afofásseis": "afofar",
    "afofássemos": "afofar",
    "afofávamo": "afofar",
    "afofávamos": "afofar",
    "afofávei": "afofar",
    "afofáveis": "afofar",
    "afoga": "afogar",
    "afogada": "afogar",
    "afogadas": "afogar",
    "afogadelas": "afogadela",
    "afogadilhos": "afogadilho",
    "afogadiça": "afogadiço",
    "afogadiças": "afogadiço",
    "afogadiços": "afogadiço",
    "afogado": "afogar",
    "afogadora": "afogador",
    "afogadoras": "afogador",
    "afogadores": "afogador",
    "afogados": "afogar",
    "afogadíssima": "afogado",
    "afogadíssimas": "afogado",
    "afogadíssimo": "afogado",
    "afogadíssimos": "afogado",
    "afogai": "afogar",
    "afogais": "afogar",
    "afogam": "afogar",
    "afogamentos": "afogamento",
    "afogamo": "afogar",
    "afogamos": "afogar",
    "afogando": "afogar",
    "afogara": "afogar",
    "afogaram": "afogar",
    "afogaras": "afogar",
    "afogarde": "afogar",
    "afogardes": "afogar",
    "afogare": "afogar",
    "afogarei": "afogar",
    "afogareis": "afogar",
    "afogarem": "afogar",
    "afogaremos": "afogar",
    "afogares": "afogar",
    "afogaria": "afogar",
    "afogariam": "afogar",
    "afogarias": "afogar",
    "afogarmo": "afogar",
    "afogarmos": "afogar",
    "afogará": "afogar",
    "afogarás": "afogar",
    "afogarão": "afogar",
    "afogaríamos": "afogar",
    "afogaríeis": "afogar",
    "afogas": "afogar",
    "afogasse": "afogar",
    "afogassem": "afogar",
    "afogasses": "afogar",
    "afogaste": "afogar",
    "afogastes": "afogar",
    "afogava": "afogar",
    "afogavam": "afogar",
    "afogavas": "afogar",
    "afogo": "afogar",
    "afogos": "afogo",
    "afogou": "afogar",
    "afogue": "afogar",
    "afogueada": "afoguear",
    "afogueadas": "afoguear",
    "afogueado": "afoguear",
    "afogueados": "afoguear",
    "afogueadíssima": "afogueado",
    "afogueadíssimas": "afogueado",
    "afogueadíssimo": "afogueado",
    "afogueadíssimos": "afogueado",
    "afogueai": "afoguear",
    "afogueais": "afoguear",
    "afogueamentos": "afogueamento",
    "afogueamo": "afoguear",
    "afogueamos": "afoguear",
    "afogueando": "afoguear",
    "afogueara": "afoguear",
    "afoguearam": "afoguear",
    "afoguearas": "afoguear",
    "afoguearde": "afoguear",
    "afogueardes": "afoguear",
    "afogueare": "afoguear",
    "afoguearei": "afoguear",
    "afogueareis": "afoguear",
    "afoguearem": "afoguear",
    "afoguearemos": "afoguear",
    "afogueares": "afoguear",
    "afoguearia": "afoguear",
    "afogueariam": "afoguear",
    "afoguearias": "afoguear",
    "afoguearmo": "afoguear",
    "afoguearmos": "afoguear",
    "afogueará": "afoguear",
    "afoguearás": "afoguear",
    "afoguearão": "afoguear",
    "afoguearíamos": "afoguear",
    "afoguearíeis": "afoguear",
    "afogueasse": "afoguear",
    "afogueassem": "afoguear",
    "afogueasses": "afoguear",
    "afogueaste": "afoguear",
    "afogueastes": "afoguear",
    "afogueava": "afoguear",
    "afogueavam": "afoguear",
    "afogueavas": "afoguear",
    "afogueei": "afoguear",
    "afogueeis": "afoguear",
    "afogueemo": "afoguear",
    "afogueemos": "afoguear",
    "afoguei": "afogar",
    "afogueia": "afoguear",
    "afogueiam": "afoguear",
    "afogueias": "afoguear",
    "afogueie": "afoguear",
    "afogueiem": "afoguear",
    "afogueies": "afoguear",
    "afogueio": "afoguear",
    "afogueis": "afogar",
    "afoguem": "afogar",
    "afoguemo": "afogar",
    "afoguemos": "afogar",
    "afogueou": "afoguear",
    "afogues": "afogar",
    "afogueá": "afoguear",
    "afogueámo": "afoguear",
    "afogueámos": "afoguear",
    "afogueáramo": "afoguear",
    "afogueáramos": "afoguear",
    "afogueárei": "afoguear",
    "afogueáreis": "afoguear",
    "afogueásseis": "afoguear",
    "afogueássemos": "afoguear",
    "afogueávamo": "afoguear",
    "afogueávamos": "afoguear",
    "afogueávei": "afoguear",
    "afogueáveis": "afoguear",
    "afogá": "afogar",
    "afogámo": "afogar",
    "afogámos": "afogar",
    "afogáramo": "afogar",
    "afogáramos": "afogar",
    "afogárei": "afogar",
    "afogáreis": "afogar",
    "afogásseis": "afogar",
    "afogássemos": "afogar",
    "afogávamo": "afogar",
    "afogávamos": "afogar",
    "afogávei": "afogar",
    "afogáveis": "afogar",
    "afoita": "afoito",
    "afoitada": "afoitar",
    "afoitadas": "afoitar",
    "afoitado": "afoitar",
    "afoitados": "afoitar",
    "afoitai": "afoitar",
    "afoitais": "afoitar",
    "afoitam": "afoitar",
    "afoitamo": "afoitar",
    "afoitamos": "afoitar",
    "afoitando": "afoitar",
    "afoitara": "afoitar",
    "afoitaram": "afoitar",
    "afoitaras": "afoitar",
    "afoitarde": "afoitar",
    "afoitardes": "afoitar",
    "afoitare": "afoitar",
    "afoitarei": "afoitar",
    "afoitareis": "afoitar",
    "afoitarem": "afoitar",
    "afoitaremos": "afoitar",
    "afoitares": "afoitar",
    "afoitaria": "afoitar",
    "afoitariam": "afoitar",
    "afoitarias": "afoitar",
    "afoitarmo": "afoitar",
    "afoitarmos": "afoitar",
    "afoitará": "afoitar",
    "afoitarás": "afoitar",
    "afoitarão": "afoitar",
    "afoitaríamos": "afoitar",
    "afoitaríeis": "afoitar",
    "afoitas": "afoito",
    "afoitasse": "afoitar",
    "afoitassem": "afoitar",
    "afoitasses": "afoitar",
    "afoitaste": "afoitar",
    "afoitastes": "afoitar",
    "afoitava": "afoitar",
    "afoitavam": "afoitar",
    "afoitavas": "afoitar",
    "afoite": "afoitar",
    "afoitei": "afoitar",
    "afoiteis": "afoitar",
    "afoitem": "afoitar",
    "afoitemo": "afoitar",
    "afoitemos": "afoitar",
    "afoites": "afoitar",
    "afoitezas": "afoiteza",
    "afoito": "afoitar",
    "afoitos": "afoito",
    "afoitou": "afoitar",
    "afoitá": "afoitar",
    "afoitámo": "afoitar",
    "afoitámos": "afoitar",
    "afoitáramo": "afoitar",
    "afoitáramos": "afoitar",
    "afoitárei": "afoitar",
    "afoitáreis": "afoitar",
    "afoitásseis": "afoitar",
    "afoitássemos": "afoitar",
    "afoitávamo": "afoitar",
    "afoitávamos": "afoitar",
    "afoitávei": "afoitar",
    "afoitáveis": "afoitar",
    "afoitíssima": "afoito",
    "afoitíssimas": "afoito",
    "afoitíssimo": "afoito",
    "afoitíssimos": "afoito",
    "afola": "afolar",
    "afolada": "afolar",
    "afoladas": "afolar",
    "afolado": "afolar",
    "afolados": "afolar",
    "afolai": "afolar",
    "afolais": "afolar",
    "afolam": "afolar",
    "afolamo": "afolar",
    "afolamos": "afolar",
    "afolando": "afolar",
    "afolara": "afolar",
    "afolaram": "afolar",
    "afolaras": "afolar",
    "afolarde": "afolar",
    "afolardes": "afolar",
    "afolare": "afolar",
    "afolarei": "afolar",
    "afolareis": "afolar",
    "afolarem": "afolar",
    "afolaremos": "afolar",
    "afolares": "afolar",
    "afolaria": "afolar",
    "afolariam": "afolar",
    "afolarias": "afolar",
    "afolarmo": "afolar",
    "afolarmos": "afolar",
    "afolará": "afolar",
    "afolarás": "afolar",
    "afolarão": "afolar",
    "afolaríamos": "afolar",
    "afolaríeis": "afolar",
    "afolas": "afolar",
    "afolasse": "afolar",
    "afolassem": "afolar",
    "afolasses": "afolar",
    "afolaste": "afolar",
    "afolastes": "afolar",
    "afolava": "afolar",
    "afolavam": "afolar",
    "afolavas": "afolar",
    "afole": "afolar",
    "afolei": "afolar",
    "afoleis": "afolar",
    "afolem": "afolar",
    "afolemo": "afolar",
    "afolemos": "afolar",
    "afoles": "afolar",
    "afolha": "afolhar",
    "afolhada": "afolhar",
    "afolhadas": "afolhar",
    "afolhado": "afolhar",
    "afolhados": "afolhar",
    "afolhai": "afolhar",
    "afolhais": "afolhar",
    "afolham": "afolhar",
    "afolhamentos": "afolhamento",
    "afolhamo": "afolhar",
    "afolhamos": "afolhar",
    "afolhando": "afolhar",
    "afolhara": "afolhar",
    "afolharam": "afolhar",
    "afolharas": "afolhar",
    "afolharde": "afolhar",
    "afolhardes": "afolhar",
    "afolhare": "afolhar",
    "afolharei": "afolhar",
    "afolhareis": "afolhar",
    "afolharem": "afolhar",
    "afolharemos": "afolhar",
    "afolhares": "afolhar",
    "afolharia": "afolhar",
    "afolhariam": "afolhar",
    "afolharias": "afolhar",
    "afolharmo": "afolhar",
    "afolharmos": "afolhar",
    "afolhará": "afolhar",
    "afolharás": "afolhar",
    "afolharão": "afolhar",
    "afolharíamos": "afolhar",
    "afolharíeis": "afolhar",
    "afolhas": "afolhar",
    "afolhasse": "afolhar",
    "afolhassem": "afolhar",
    "afolhasses": "afolhar",
    "afolhaste": "afolhar",
    "afolhastes": "afolhar",
    "afolhava": "afolhar",
    "afolhavam": "afolhar",
    "afolhavas": "afolhar",
    "afolhe": "afolhar",
    "afolhei": "afolhar",
    "afolheis": "afolhar",
    "afolhem": "afolhar",
    "afolhemo": "afolhar",
    "afolhemos": "afolhar",
    "afolhes": "afolhar",
    "afolho": "afolhar",
    "afolhou": "afolhar",
    "afolhá": "afolhar",
    "afolhámo": "afolhar",
    "afolhámos": "afolhar",
    "afolháramo": "afolhar",
    "afolháramos": "afolhar",
    "afolhárei": "afolhar",
    "afolháreis": "afolhar",
    "afolhásseis": "afolhar",
    "afolhássemos": "afolhar",
    "afolhávamo": "afolhar",
    "afolhávamos": "afolhar",
    "afolhávei": "afolhar",
    "afolháveis": "afolhar",
    "afolo": "afolar",
    "afolou": "afolar",
    "afolá": "afolar",
    "afolámo": "afolar",
    "afolámos": "afolar",
    "afoláramo": "afolar",
    "afoláramos": "afolar",
    "afolárei": "afolar",
    "afoláreis": "afolar",
    "afolásseis": "afolar",
    "afolássemos": "afolar",
    "afolávamo": "afolar",
    "afolávamos": "afolar",
    "afolávei": "afolar",
    "afoláveis": "afolar",
    "afomeada": "afomear",
    "afomeadas": "afomear",
    "afomeado": "afomear",
    "afomeados": "afomear",
    "afomeai": "afomear",
    "afomeais": "afomear",
    "afomeamo": "afomear",
    "afomeamos": "afomear",
    "afomeando": "afomear",
    "afomeara": "afomear",
    "afomearam": "afomear",
    "afomearas": "afomear",
    "afomearde": "afomear",
    "afomeardes": "afomear",
    "afomeare": "afomear",
    "afomearei": "afomear",
    "afomeareis": "afomear",
    "afomearem": "afomear",
    "afomearemos": "afomear",
    "afomeares": "afomear",
    "afomearia": "afomear",
    "afomeariam": "afomear",
    "afomearias": "afomear",
    "afomearmo": "afomear",
    "afomearmos": "afomear",
    "afomeará": "afomear",
    "afomearás": "afomear",
    "afomearão": "afomear",
    "afomearíamos": "afomear",
    "afomearíeis": "afomear",
    "afomeasse": "afomear",
    "afomeassem": "afomear",
    "afomeasses": "afomear",
    "afomeaste": "afomear",
    "afomeastes": "afomear",
    "afomeava": "afomear",
    "afomeavam": "afomear",
    "afomeavas": "afomear",
    "afomeei": "afomear",
    "afomeeis": "afomear",
    "afomeemo": "afomear",
    "afomeemos": "afomear",
    "afomeia": "afomear",
    "afomeiam": "afomear",
    "afomeias": "afomear",
    "afomeie": "afomear",
    "afomeiem": "afomear",
    "afomeies": "afomear",
    "afomeio": "afomear",
    "afomeou": "afomear",
    "afomeá": "afomear",
    "afomeámo": "afomear",
    "afomeámos": "afomear",
    "afomeáramo": "afomear",
    "afomeáramos": "afomear",
    "afomeárei": "afomear",
    "afomeáreis": "afomear",
    "afomeásseis": "afomear",
    "afomeássemos": "afomear",
    "afomeávamo": "afomear",
    "afomeávamos": "afomear",
    "afomeávei": "afomear",
    "afomeáveis": "afomear",
    "afona": "afono",
    "afonas": "afono",
    "afonias": "afonia",
    "afonos": "afono",
    "afonsina": "afonsino",
    "afonsinas": "afonsino",
    "afonsinha": "afonsinho",
    "afonsinhas": "afonsinho",
    "afonsinhos": "afonsinho",
    "afonsinos": "afonsino",
    "afora": "aforar",
    "aforada": "aforar",
    "aforadas": "aforar",
    "aforado": "aforar",
    "aforadora": "aforador",
    "aforadoras": "aforador",
    "aforadores": "aforador",
    "aforados": "aforar",
    "aforai": "aforar",
    "aforais": "aforar",
    "aforam": "aforar",
    "aforamentos": "aforamento",
    "aforamo": "aforar",
    "aforamos": "aforar",
    "aforando": "aforar",
    "aforara": "aforar",
    "aforaram": "aforar",
    "aforaras": "aforar",
    "aforarde": "aforar",
    "aforardes": "aforar",
    "aforare": "aforar",
    "aforarei": "aforar",
    "aforareis": "aforar",
    "aforarem": "aforar",
    "aforaremos": "aforar",
    "aforares": "aforar",
    "aforaria": "aforar",
    "aforariam": "aforar",
    "aforarias": "aforar",
    "aforarmo": "aforar",
    "aforarmos": "aforar",
    "aforará": "aforar",
    "aforarás": "aforar",
    "aforarão": "aforar",
    "aforaríamos": "aforar",
    "aforaríeis": "aforar",
    "aforas": "aforar",
    "aforasse": "aforar",
    "aforassem": "aforar",
    "aforasses": "aforar",
    "aforaste": "aforar",
    "aforastes": "aforar",
    "aforava": "aforar",
    "aforavam": "aforar",
    "aforavas": "aforar",
    "aforações": "aforação",
    "afore": "aforar",
    "aforei": "aforar",
    "aforeis": "aforar",
    "aforem": "aforar",
    "aforemo": "aforar",
    "aforemos": "aforar",
    "afores": "aforar",
    "aforismos": "aforismo",
    "aforismática": "aforismático",
    "aforismáticas": "aforismático",
    "aforismáticos": "aforismático",
    "aforistas": "aforista",
    "aformala": "aformalar",
    "aformalada": "aformalar",
    "aformaladas": "aformalar",
    "aformalado": "aformalar",
    "aformalados": "aformalar",
    "aformalai": "aformalar",
    "aformalais": "aformalar",
    "aformalam": "aformalar",
    "aformalamo": "aformalar",
    "aformalamos": "aformalar",
    "aformalando": "aformalar",
    "aformalara": "aformalar",
    "aformalaram": "aformalar",
    "aformalaras": "aformalar",
    "aformalarde": "aformalar",
    "aformalardes": "aformalar",
    "aformalare": "aformalar",
    "aformalarei": "aformalar",
    "aformalareis": "aformalar",
    "aformalarem": "aformalar",
    "aformalaremos": "aformalar",
    "aformalares": "aformalar",
    "aformalaria": "aformalar",
    "aformalariam": "aformalar",
    "aformalarias": "aformalar",
    "aformalarmo": "aformalar",
    "aformalarmos": "aformalar",
    "aformalará": "aformalar",
    "aformalarás": "aformalar",
    "aformalarão": "aformalar",
    "aformalaríamos": "aformalar",
    "aformalaríeis": "aformalar",
    "aformalas": "aformalar",
    "aformalasse": "aformalar",
    "aformalassem": "aformalar",
    "aformalasses": "aformalar",
    "aformalaste": "aformalar",
    "aformalastes": "aformalar",
    "aformalava": "aformalar",
    "aformalavam": "aformalar",
    "aformalavas": "aformalar",
    "aformale": "aformalar",
    "aformalei": "aformalar",
    "aformaleis": "aformalar",
    "aformalem": "aformalar",
    "aformalemo": "aformalar",
    "aformalemos": "aformalar",
    "aformales": "aformalar",
    "aformalo": "aformalar",
    "aformalou": "aformalar",
    "aformalá": "aformalar",
    "aformalámo": "aformalar",
    "aformalámos": "aformalar",
    "aformaláramo": "aformalar",
    "aformaláramos": "aformalar",
    "aformalárei": "aformalar",
    "aformaláreis": "aformalar",
    "aformalásseis": "aformalar",
    "aformalássemos": "aformalar",
    "aformalávamo": "aformalar",
    "aformalávamos": "aformalar",
    "aformalávei": "aformalar",
    "aformaláveis": "aformalar",
    "aformoseada": "aformosear",
    "aformoseadas": "aformosear",
    "aformoseado": "aformosear",
    "aformoseadora": "aformoseador",
    "aformoseadoras": "aformoseador",
    "aformoseadores": "aformoseador",
    "aformoseados": "aformosear",
    "aformoseai": "aformosear",
    "aformoseais": "aformosear",
    "aformoseamentos": "aformoseamento",
    "aformoseamo": "aformosear",
    "aformoseamos": "aformosear",
    "aformoseando": "aformosear",
    "aformoseara": "aformosear",
    "aformosearam": "aformosear",
    "aformosearas": "aformosear",
    "aformosearde": "aformosear",
    "aformoseardes": "aformosear",
    "aformoseare": "aformosear",
    "aformosearei": "aformosear",
    "aformoseareis": "aformosear",
    "aformosearem": "aformosear",
    "aformosearemos": "aformosear",
    "aformoseares": "aformosear",
    "aformosearia": "aformosear",
    "aformoseariam": "aformosear",
    "aformosearias": "aformosear",
    "aformosearmo": "aformosear",
    "aformosearmos": "aformosear",
    "aformoseará": "aformosear",
    "aformosearás": "aformosear",
    "aformosearão": "aformosear",
    "aformosearíamos": "aformosear",
    "aformosearíeis": "aformosear",
    "aformoseasse": "aformosear",
    "aformoseassem": "aformosear",
    "aformoseasses": "aformosear",
    "aformoseaste": "aformosear",
    "aformoseastes": "aformosear",
    "aformoseava": "aformosear",
    "aformoseavam": "aformosear",
    "aformoseavas": "aformosear",
    "aformoseei": "aformosear",
    "aformoseeis": "aformosear",
    "aformoseemo": "aformosear",
    "aformoseemos": "aformosear",
    "aformoseia": "aformosear",
    "aformoseiam": "aformosear",
    "aformoseias": "aformosear",
    "aformoseie": "aformosear",
    "aformoseiem": "aformosear",
    "aformoseies": "aformosear",
    "aformoseio": "aformosear",
    "aformosenta": "aformosentar",
    "aformosentada": "aformosentar",
    "aformosentadas": "aformosentar",
    "aformosentado": "aformosentar",
    "aformosentados": "aformosentar",
    "aformosentai": "aformosentar",
    "aformosentais": "aformosentar",
    "aformosentam": "aformosentar",
    "aformosentamo": "aformosentar",
    "aformosentamos": "aformosentar",
    "aformosentando": "aformosentar",
    "aformosentara": "aformosentar",
    "aformosentaram": "aformosentar",
    "aformosentaras": "aformosentar",
    "aformosentarde": "aformosentar",
    "aformosentardes": "aformosentar",
    "aformosentare": "aformosentar",
    "aformosentarei": "aformosentar",
    "aformosentareis": "aformosentar",
    "aformosentarem": "aformosentar",
    "aformosentaremos": "aformosentar",
    "aformosentares": "aformosentar",
    "aformosentaria": "aformosentar",
    "aformosentariam": "aformosentar",
    "aformosentarias": "aformosentar",
    "aformosentarmo": "aformosentar",
    "aformosentarmos": "aformosentar",
    "aformosentará": "aformosentar",
    "aformosentarás": "aformosentar",
    "aformosentarão": "aformosentar",
    "aformosentaríamos": "aformosentar",
    "aformosentaríeis": "aformosentar",
    "aformosentas": "aformosentar",
    "aformosentasse": "aformosentar",
    "aformosentassem": "aformosentar",
    "aformosentasses": "aformosentar",
    "aformosentaste": "aformosentar",
    "aformosentastes": "aformosentar",
    "aformosentava": "aformosentar",
    "aformosentavam": "aformosentar",
    "aformosentavas": "aformosentar",
    "aformosente": "aformosentar",
    "aformosentei": "aformosentar",
    "aformosenteis": "aformosentar",
    "aformosentem": "aformosentar",
    "aformosentemo": "aformosentar",
    "aformosentemos": "aformosentar",
    "aformosentes": "aformosentar",
    "aformosento": "aformosentar",
    "aformosentou": "aformosentar",
    "aformosentá": "aformosentar",
    "aformosentámo": "aformosentar",
    "aformosentámos": "aformosentar",
    "aformosentáramo": "aformosentar",
    "aformosentáramos": "aformosentar",
    "aformosentárei": "aformosentar",
    "aformosentáreis": "aformosentar",
    "aformosentásseis": "aformosentar",
    "aformosentássemos": "aformosentar",
    "aformosentávamo": "aformosentar",
    "aformosentávamos": "aformosentar",
    "aformosentávei": "aformosentar",
    "aformosentáveis": "aformosentar",
    "aformoseou": "aformosear",
    "aformoseá": "aformosear",
    "aformoseámo": "aformosear",
    "aformoseámos": "aformosear",
    "aformoseáramo": "aformosear",
    "aformoseáramos": "aformosear",
    "aformoseárei": "aformosear",
    "aformoseáreis": "aformosear",
    "aformoseásseis": "aformosear",
    "aformoseássemos": "aformosear",
    "aformoseávamo": "aformosear",
    "aformoseávamos": "aformosear",
    "aformoseávei": "aformosear",
    "aformoseáveis": "aformosear",
    "aforo": "aforar",
    "aforou": "aforar",
    "aforquilha": "aforquilhar",
    "aforquilhada": "aforquilhar",
    "aforquilhadas": "aforquilhar",
    "aforquilhado": "aforquilhar",
    "aforquilhados": "aforquilhar",
    "aforquilhaduras": "aforquilhadura",
    "aforquilhai": "aforquilhar",
    "aforquilhais": "aforquilhar",
    "aforquilham": "aforquilhar",
    "aforquilhamentos": "aforquilhamento",
    "aforquilhamo": "aforquilhar",
    "aforquilhamos": "aforquilhar",
    "aforquilhando": "aforquilhar",
    "aforquilhara": "aforquilhar",
    "aforquilharam": "aforquilhar",
    "aforquilharas": "aforquilhar",
    "aforquilharde": "aforquilhar",
    "aforquilhardes": "aforquilhar",
    "aforquilhare": "aforquilhar",
    "aforquilharei": "aforquilhar",
    "aforquilhareis": "aforquilhar",
    "aforquilharem": "aforquilhar",
    "aforquilharemos": "aforquilhar",
    "aforquilhares": "aforquilhar",
    "aforquilharia": "aforquilhar",
    "aforquilhariam": "aforquilhar",
    "aforquilharias": "aforquilhar",
    "aforquilharmo": "aforquilhar",
    "aforquilharmos": "aforquilhar",
    "aforquilhará": "aforquilhar",
    "aforquilharás": "aforquilhar",
    "aforquilharão": "aforquilhar",
    "aforquilharíamos": "aforquilhar",
    "aforquilharíeis": "aforquilhar",
    "aforquilhas": "aforquilhar",
    "aforquilhasse": "aforquilhar",
    "aforquilhassem": "aforquilhar",
    "aforquilhasses": "aforquilhar",
    "aforquilhaste": "aforquilhar",
    "aforquilhastes": "aforquilhar",
    "aforquilhava": "aforquilhar",
    "aforquilhavam": "aforquilhar",
    "aforquilhavas": "aforquilhar",
    "aforquilhe": "aforquilhar",
    "aforquilhei": "aforquilhar",
    "aforquilheis": "aforquilhar",
    "aforquilhem": "aforquilhar",
    "aforquilhemo": "aforquilhar",
    "aforquilhemos": "aforquilhar",
    "aforquilhes": "aforquilhar",
    "aforquilho": "aforquilhar",
    "aforquilhou": "aforquilhar",
    "aforquilhá": "aforquilhar",
    "aforquilhámo": "aforquilhar",
    "aforquilhámos": "aforquilhar",
    "aforquilháramo": "aforquilhar",
    "aforquilháramos": "aforquilhar",
    "aforquilhárei": "aforquilhar",
    "aforquilháreis": "aforquilhar",
    "aforquilhásseis": "aforquilhar",
    "aforquilhássemos": "aforquilhar",
    "aforquilhávamo": "aforquilhar",
    "aforquilhávamos": "aforquilhar",
    "aforquilhávei": "aforquilhar",
    "aforquilháveis": "aforquilhar",
    "aforra": "aforrar",
    "aforrada": "aforrar",
    "aforradas": "aforrar",
    "aforrado": "aforrar",
    "aforrados": "aforrar",
    "aforrai": "aforrar",
    "aforrais": "aforrar",
    "aforram": "aforrar",
    "aforramo": "aforrar",
    "aforramos": "aforrar",
    "aforrando": "aforrar",
    "aforrara": "aforrar",
    "aforraram": "aforrar",
    "aforraras": "aforrar",
    "aforrarde": "aforrar",
    "aforrardes": "aforrar",
    "aforrare": "aforrar",
    "aforrarei": "aforrar",
    "aforrareis": "aforrar",
    "aforrarem": "aforrar",
    "aforraremos": "aforrar",
    "aforrares": "aforrar",
    "aforraria": "aforrar",
    "aforrariam": "aforrar",
    "aforrarias": "aforrar",
    "aforrarmo": "aforrar",
    "aforrarmos": "aforrar",
    "aforrará": "aforrar",
    "aforrarás": "aforrar",
    "aforrarão": "aforrar",
    "aforraríamos": "aforrar",
    "aforraríeis": "aforrar",
    "aforras": "aforrar",
    "aforrasse": "aforrar",
    "aforrassem": "aforrar",
    "aforrasses": "aforrar",
    "aforraste": "aforrar",
    "aforrastes": "aforrar",
    "aforrava": "aforrar",
    "aforravam": "aforrar",
    "aforravas": "aforrar",
    "aforre": "aforrar",
    "aforrei": "aforrar",
    "aforreis": "aforrar",
    "aforrem": "aforrar",
    "aforremo": "aforrar",
    "aforremos": "aforrar",
    "aforres": "aforrar",
    "aforro": "aforrar",
    "aforros": "aforro",
    "aforrou": "aforrar",
    "aforrá": "aforrar",
    "aforrámo": "aforrar",
    "aforrámos": "aforrar",
    "aforráramo": "aforrar",
    "aforráramos": "aforrar",
    "aforrárei": "aforrar",
    "aforráreis": "aforrar",
    "aforrásseis": "aforrar",
    "aforrássemos": "aforrar",
    "aforrávamo": "aforrar",
    "aforrávamos": "aforrar",
    "aforrávei": "aforrar",
    "aforráveis": "aforrar",
    "afortaleza": "afortalezar",
    "afortalezada": "afortalezar",
    "afortalezadas": "afortalezar",
    "afortalezado": "afortalezar",
    "afortalezados": "afortalezar",
    "afortalezai": "afortalezar",
    "afortalezais": "afortalezar",
    "afortalezam": "afortalezar",
    "afortalezamo": "afortalezar",
    "afortalezamos": "afortalezar",
    "afortalezando": "afortalezar",
    "afortalezara": "afortalezar",
    "afortalezaram": "afortalezar",
    "afortalezaras": "afortalezar",
    "afortalezarde": "afortalezar",
    "afortalezardes": "afortalezar",
    "afortalezare": "afortalezar",
    "afortalezarei": "afortalezar",
    "afortalezareis": "afortalezar",
    "afortalezarem": "afortalezar",
    "afortalezaremos": "afortalezar",
    "afortalezares": "afortalezar",
    "afortalezaria": "afortalezar",
    "afortalezariam": "afortalezar",
    "afortalezarias": "afortalezar",
    "afortalezarmo": "afortalezar",
    "afortalezarmos": "afortalezar",
    "afortalezará": "afortalezar",
    "afortalezarás": "afortalezar",
    "afortalezarão": "afortalezar",
    "afortalezaríamos": "afortalezar",
    "afortalezaríeis": "afortalezar",
    "afortalezas": "afortalezar",
    "afortalezasse": "afortalezar",
    "afortalezassem": "afortalezar",
    "afortalezasses": "afortalezar",
    "afortalezaste": "afortalezar",
    "afortalezastes": "afortalezar",
    "afortalezava": "afortalezar",
    "afortalezavam": "afortalezar",
    "afortalezavas": "afortalezar",
    "afortaleze": "afortalezar",
    "afortalezei": "afortalezar",
    "afortalezeis": "afortalezar",
    "afortalezem": "afortalezar",
    "afortalezemo": "afortalezar",
    "afortalezemos": "afortalezar",
    "afortalezes": "afortalezar",
    "afortalezo": "afortalezar",
    "afortalezou": "afortalezar",
    "afortalezá": "afortalezar",
    "afortalezámo": "afortalezar",
    "afortalezámos": "afortalezar",
    "afortalezáramo": "afortalezar",
    "afortalezáramos": "afortalezar",
    "afortalezárei": "afortalezar",
    "afortalezáreis": "afortalezar",
    "afortalezásseis": "afortalezar",
    "afortalezássemos": "afortalezar",
    "afortalezávamo": "afortalezar",
    "afortalezávamos": "afortalezar",
    "afortalezávei": "afortalezar",
    "afortalezáveis": "afortalezar",
    "afortuna": "afortunar",
    "afortunada": "afortunar",
    "afortunadas": "afortunar",
    "afortunado": "afortunar",
    "afortunados": "afortunar",
    "afortunadíssima": "afortunado",
    "afortunadíssimas": "afortunado",
    "afortunadíssimo": "afortunado",
    "afortunadíssimos": "afortunado",
    "afortunai": "afortunar",
    "afortunais": "afortunar",
    "afortunam": "afortunar",
    "afortunamo": "afortunar",
    "afortunamos": "afortunar",
    "afortunando": "afortunar",
    "afortunara": "afortunar",
    "afortunaram": "afortunar",
    "afortunaras": "afortunar",
    "afortunarde": "afortunar",
    "afortunardes": "afortunar",
    "afortunare": "afortunar",
    "afortunarei": "afortunar",
    "afortunareis": "afortunar",
    "afortunarem": "afortunar",
    "afortunaremos": "afortunar",
    "afortunares": "afortunar",
    "afortunaria": "afortunar",
    "afortunariam": "afortunar",
    "afortunarias": "afortunar",
    "afortunarmo": "afortunar",
    "afortunarmos": "afortunar",
    "afortunará": "afortunar",
    "afortunarás": "afortunar",
    "afortunarão": "afortunar",
    "afortunaríamos": "afortunar",
    "afortunaríeis": "afortunar",
    "afortunas": "afortunar",
    "afortunasse": "afortunar",
    "afortunassem": "afortunar",
    "afortunasses": "afortunar",
    "afortunaste": "afortunar",
    "afortunastes": "afortunar",
    "afortunava": "afortunar",
    "afortunavam": "afortunar",
    "afortunavas": "afortunar",
    "afortune": "afortunar",
    "afortunei": "afortunar",
    "afortuneis": "afortunar",
    "afortunem": "afortunar",
    "afortunemo": "afortunar",
    "afortunemos": "afortunar",
    "afortunes": "afortunar",
    "afortuno": "afortunar",
    "afortunou": "afortunar",
    "afortuná": "afortunar",
    "afortunámo": "afortunar",
    "afortunámos": "afortunar",
    "afortunáramo": "afortunar",
    "afortunáramos": "afortunar",
    "afortunárei": "afortunar",
    "afortunáreis": "afortunar",
    "afortunásseis": "afortunar",
    "afortunássemos": "afortunar",
    "afortunávamo": "afortunar",
    "afortunávamos": "afortunar",
    "afortunávei": "afortunar",
    "afortunáveis": "afortunar",
    "aforá": "aforar",
    "aforámo": "aforar",
    "aforámos": "aforar",
    "aforáramo": "aforar",
    "aforáramos": "aforar",
    "aforárei": "aforar",
    "aforáreis": "aforar",
    "aforásseis": "aforar",
    "aforássemos": "aforar",
    "aforávamo": "aforar",
    "aforávamos": "aforar",
    "aforávei": "aforar",
    "aforáveis": "aforar",
    "aforística": "aforístico",
    "aforísticas": "aforístico",
    "aforísticos": "aforístico",
    "afouta": "afouto",
    "afoutada": "afoutar",
    "afoutadas": "afoutar",
    "afoutado": "afoutar",
    "afoutados": "afoutar",
    "afoutai": "afoutar",
    "afoutais": "afoutar",
    "afoutam": "afoutar",
    "afoutamo": "afoutar",
    "afoutamos": "afoutar",
    "afoutando": "afoutar",
    "afoutara": "afoutar",
    "afoutaram": "afoutar",
    "afoutaras": "afoutar",
    "afoutarde": "afoutar",
    "afoutardes": "afoutar",
    "afoutare": "afoutar",
    "afoutarei": "afoutar",
    "afoutareis": "afoutar",
    "afoutarem": "afoutar",
    "afoutaremos": "afoutar",
    "afoutares": "afoutar",
    "afoutaria": "afoutar",
    "afoutariam": "afoutar",
    "afoutarias": "afoutar",
    "afoutarmo": "afoutar",
    "afoutarmos": "afoutar",
    "afoutará": "afoutar",
    "afoutarás": "afoutar",
    "afoutarão": "afoutar",
    "afoutaríamos": "afoutar",
    "afoutaríeis": "afoutar",
    "afoutas": "afouto",
    "afoutasse": "afoutar",
    "afoutassem": "afoutar",
    "afoutasses": "afoutar",
    "afoutaste": "afoutar",
    "afoutastes": "afoutar",
    "afoutava": "afoutar",
    "afoutavam": "afoutar",
    "afoutavas": "afoutar",
    "afoute": "afoutar",
    "afoutei": "afoutar",
    "afouteis": "afoutar",
    "afoutem": "afoutar",
    "afoutemo": "afoutar",
    "afoutemos": "afoutar",
    "afoutes": "afoutar",
    "afoutezas": "afouteza",
    "afouto": "afoutar",
    "afoutos": "afouto",
    "afoutou": "afoutar",
    "afoutá": "afoutar",
    "afoutámo": "afoutar",
    "afoutámos": "afoutar",
    "afoutáramo": "afoutar",
    "afoutáramos": "afoutar",
    "afoutárei": "afoutar",
    "afoutáreis": "afoutar",
    "afoutásseis": "afoutar",
    "afoutássemos": "afoutar",
    "afoutávamo": "afoutar",
    "afoutávamos": "afoutar",
    "afoutávei": "afoutar",
    "afoutáveis": "afoutar",
    "afoutíssima": "afouto",
    "afoutíssimas": "afouto",
    "afoutíssimo": "afouto",
    "afoutíssimos": "afouto",
    "afraca": "afracar",
    "afracada": "afracar",
    "afracadas": "afracar",
    "afracado": "afracar",
    "afracados": "afracar",
    "afracai": "afracar",
    "afracais": "afracar",
    "afracam": "afracar",
    "afracamentos": "afracamento",
    "afracamo": "afracar",
    "afracamos": "afracar",
    "afracando": "afracar",
    "afracara": "afracar",
    "afracaram": "afracar",
    "afracaras": "afracar",
    "afracarde": "afracar",
    "afracardes": "afracar",
    "afracare": "afracar",
    "afracarei": "afracar",
    "afracareis": "afracar",
    "afracarem": "afracar",
    "afracaremos": "afracar",
    "afracares": "afracar",
    "afracaria": "afracar",
    "afracariam": "afracar",
    "afracarias": "afracar",
    "afracarmo": "afracar",
    "afracarmos": "afracar",
    "afracará": "afracar",
    "afracarás": "afracar",
    "afracarão": "afracar",
    "afracaríamos": "afracar",
    "afracaríeis": "afracar",
    "afracas": "afracar",
    "afracasse": "afracar",
    "afracassem": "afracar",
    "afracasses": "afracar",
    "afracaste": "afracar",
    "afracastes": "afracar",
    "afracava": "afracar",
    "afracavam": "afracar",
    "afracavas": "afracar",
    "afraco": "afracar",
    "afracou": "afracar",
    "afracá": "afracar",
    "afracámo": "afracar",
    "afracámos": "afracar",
    "afracáramo": "afracar",
    "afracáramos": "afracar",
    "afracárei": "afracar",
    "afracáreis": "afracar",
    "afracásseis": "afracar",
    "afracássemos": "afracar",
    "afracávamo": "afracar",
    "afracávamos": "afracar",
    "afracávei": "afracar",
    "afracáveis": "afracar",
    "afragata": "afragatar",
    "afragatada": "afragatar",
    "afragatadas": "afragatar",
    "afragatado": "afragatar",
    "afragatados": "afragatar",
    "afragatai": "afragatar",
    "afragatais": "afragatar",
    "afragatam": "afragatar",
    "afragatamo": "afragatar",
    "afragatamos": "afragatar",
    "afragatando": "afragatar",
    "afragatara": "afragatar",
    "afragataram": "afragatar",
    "afragataras": "afragatar",
    "afragatarde": "afragatar",
    "afragatardes": "afragatar",
    "afragatare": "afragatar",
    "afragatarei": "afragatar",
    "afragatareis": "afragatar",
    "afragatarem": "afragatar",
    "afragataremos": "afragatar",
    "afragatares": "afragatar",
    "afragataria": "afragatar",
    "afragatariam": "afragatar",
    "afragatarias": "afragatar",
    "afragatarmo": "afragatar",
    "afragatarmos": "afragatar",
    "afragatará": "afragatar",
    "afragatarás": "afragatar",
    "afragatarão": "afragatar",
    "afragataríamos": "afragatar",
    "afragataríeis": "afragatar",
    "afragatas": "afragatar",
    "afragatasse": "afragatar",
    "afragatassem": "afragatar",
    "afragatasses": "afragatar",
    "afragataste": "afragatar",
    "afragatastes": "afragatar",
    "afragatava": "afragatar",
    "afragatavam": "afragatar",
    "afragatavas": "afragatar",
    "afragate": "afragatar",
    "afragatei": "afragatar",
    "afragateis": "afragatar",
    "afragatem": "afragatar",
    "afragatemo": "afragatar",
    "afragatemos": "afragatar",
    "afragates": "afragatar",
    "afragato": "afragatar",
    "afragatou": "afragatar",
    "afragatá": "afragatar",
    "afragatámo": "afragatar",
    "afragatámos": "afragatar",
    "afragatáramo": "afragatar",
    "afragatáramos": "afragatar",
    "afragatárei": "afragatar",
    "afragatáreis": "afragatar",
    "afragatásseis": "afragatar",
    "afragatássemos": "afragatar",
    "afragatávamo": "afragatar",
    "afragatávamos": "afragatar",
    "afragatávei": "afragatar",
    "afragatáveis": "afragatar",
    "afrancesa": "afrancesar",
    "afrancesada": "afrancesar",
    "afrancesadas": "afrancesar",
    "afrancesado": "afrancesar",
    "afrancesados": "afrancesar",
    "afrancesadíssima": "afrancesado",
    "afrancesadíssimas": "afrancesado",
    "afrancesadíssimo": "afrancesado",
    "afrancesadíssimos": "afrancesado",
    "afrancesai": "afrancesar",
    "afrancesais": "afrancesar",
    "afrancesam": "afrancesar",
    "afrancesamentos": "afrancesamento",
    "afrancesamo": "afrancesar",
    "afrancesamos": "afrancesar",
    "afrancesando": "afrancesar",
    "afrancesara": "afrancesar",
    "afrancesaram": "afrancesar",
    "afrancesaras": "afrancesar",
    "afrancesarde": "afrancesar",
    "afrancesardes": "afrancesar",
    "afrancesare": "afrancesar",
    "afrancesarei": "afrancesar",
    "afrancesareis": "afrancesar",
    "afrancesarem": "afrancesar",
    "afrancesaremos": "afrancesar",
    "afrancesares": "afrancesar",
    "afrancesaria": "afrancesar",
    "afrancesariam": "afrancesar",
    "afrancesarias": "afrancesar",
    "afrancesarmo": "afrancesar",
    "afrancesarmos": "afrancesar",
    "afrancesará": "afrancesar",
    "afrancesarás": "afrancesar",
    "afrancesarão": "afrancesar",
    "afrancesaríamos": "afrancesar",
    "afrancesaríeis": "afrancesar",
    "afrancesas": "afrancesar",
    "afrancesasse": "afrancesar",
    "afrancesassem": "afrancesar",
    "afrancesasses": "afrancesar",
    "afrancesaste": "afrancesar",
    "afrancesastes": "afrancesar",
    "afrancesava": "afrancesar",
    "afrancesavam": "afrancesar",
    "afrancesavas": "afrancesar",
    "afrancese": "afrancesar",
    "afrancesei": "afrancesar",
    "afranceseis": "afrancesar",
    "afrancesem": "afrancesar",
    "afrancesemo": "afrancesar",
    "afrancesemos": "afrancesar",
    "afranceses": "afrancesar",
    "afranceso": "afrancesar",
    "afrancesou": "afrancesar",
    "afrancesá": "afrancesar",
    "afrancesámo": "afrancesar",
    "afrancesámos": "afrancesar",
    "afrancesáramo": "afrancesar",
    "afrancesáramos": "afrancesar",
    "afrancesárei": "afrancesar",
    "afrancesáreis": "afrancesar",
    "afrancesásseis": "afrancesar",
    "afrancesássemos": "afrancesar",
    "afrancesávamo": "afrancesar",
    "afrancesávamos": "afrancesar",
    "afrancesávei": "afrancesar",
    "afrancesáveis": "afrancesável",
    "afranzina": "afranzinar",
    "afranzinada": "afranzinar",
    "afranzinadas": "afranzinar",
    "afranzinado": "afranzinar",
    "afranzinados": "afranzinar",
    "afranzinai": "afranzinar",
    "afranzinais": "afranzinar",
    "afranzinam": "afranzinar",
    "afranzinamo": "afranzinar",
    "afranzinamos": "afranzinar",
    "afranzinando": "afranzinar",
    "afranzinara": "afranzinar",
    "afranzinaram": "afranzinar",
    "afranzinaras": "afranzinar",
    "afranzinarde": "afranzinar",
    "afranzinardes": "afranzinar",
    "afranzinare": "afranzinar",
    "afranzinarei": "afranzinar",
    "afranzinareis": "afranzinar",
    "afranzinarem": "afranzinar",
    "afranzinaremos": "afranzinar",
    "afranzinares": "afranzinar",
    "afranzinaria": "afranzinar",
    "afranzinariam": "afranzinar",
    "afranzinarias": "afranzinar",
    "afranzinarmo": "afranzinar",
    "afranzinarmos": "afranzinar",
    "afranzinará": "afranzinar",
    "afranzinarás": "afranzinar",
    "afranzinarão": "afranzinar",
    "afranzinaríamos": "afranzinar",
    "afranzinaríeis": "afranzinar",
    "afranzinas": "afranzinar",
    "afranzinasse": "afranzinar",
    "afranzinassem": "afranzinar",
    "afranzinasses": "afranzinar",
    "afranzinaste": "afranzinar",
    "afranzinastes": "afranzinar",
    "afranzinava": "afranzinar",
    "afranzinavam": "afranzinar",
    "afranzinavas": "afranzinar",
    "afranzine": "afranzinar",
    "afranzinei": "afranzinar",
    "afranzineis": "afranzinar",
    "afranzinem": "afranzinar",
    "afranzinemo": "afranzinar",
    "afranzinemos": "afranzinar",
    "afranzines": "afranzinar",
    "afranzino": "afranzinar",
    "afranzinou": "afranzinar",
    "afranziná": "afranzinar",
    "afranzinámo": "afranzinar",
    "afranzinámos": "afranzinar",
    "afranzináramo": "afranzinar",
    "afranzináramos": "afranzinar",
    "afranzinárei": "afranzinar",
    "afranzináreis": "afranzinar",
    "afranzinásseis": "afranzinar",
    "afranzinássemos": "afranzinar",
    "afranzinávamo": "afranzinar",
    "afranzinávamos": "afranzinar",
    "afranzinávei": "afranzinar",
    "afranzináveis": "afranzinar",
    "afraque": "afracar",
    "afraquei": "afracar",
    "afraqueis": "afracar",
    "afraquem": "afracar",
    "afraquemo": "afracar",
    "afraquemos": "afracar",
    "afraques": "afracar",
    "afrasias": "afrasia",
    "afrecha": "afrechar",
    "afrechada": "afrechar",
    "afrechadas": "afrechar",
    "afrechado": "afrechar",
    "afrechados": "afrechar",
    "afrechai": "afrechar",
    "afrechais": "afrechar",
    "afrecham": "afrechar",
    "afrechamo": "afrechar",
    "afrechamos": "afrechar",
    "afrechando": "afrechar",
    "afrechara": "afrechar",
    "afrecharam": "afrechar",
    "afrecharas": "afrechar",
    "afrecharde": "afrechar",
    "afrechardes": "afrechar",
    "afrechare": "afrechar",
    "afrecharei": "afrechar",
    "afrechareis": "afrechar",
    "afrecharem": "afrechar",
    "afrecharemos": "afrechar",
    "afrechares": "afrechar",
    "afrecharia": "afrechar",
    "afrechariam": "afrechar",
    "afrecharias": "afrechar",
    "afrecharmo": "afrechar",
    "afrecharmos": "afrechar",
    "afrechará": "afrechar",
    "afrecharás": "afrechar",
    "afrecharão": "afrechar",
    "afrecharíamos": "afrechar",
    "afrecharíeis": "afrechar",
    "afrechas": "afrechar",
    "afrechasse": "afrechar",
    "afrechassem": "afrechar",
    "afrechasses": "afrechar",
    "afrechaste": "afrechar",
    "afrechastes": "afrechar",
    "afrechava": "afrechar",
    "afrechavam": "afrechar",
    "afrechavas": "afrechar",
    "afreche": "afrechar",
    "afrechei": "afrechar",
    "afrecheis": "afrechar",
    "afrechem": "afrechar",
    "afrechemo": "afrechar",
    "afrechemos": "afrechar",
    "afreches": "afrechar",
    "afrecho": "afrechar",
    "afrechou": "afrechar",
    "afrechá": "afrechar",
    "afrechámo": "afrechar",
    "afrechámos": "afrechar",
    "afrecháramo": "afrechar",
    "afrecháramos": "afrechar",
    "afrechárei": "afrechar",
    "afrecháreis": "afrechar",
    "afrechásseis": "afrechar",
    "afrechássemos": "afrechar",
    "afrechávamo": "afrechar",
    "afrechávamos": "afrechar",
    "afrechávei": "afrechar",
    "afrecháveis": "afrechar",
    "afreguesa": "afreguesar",
    "afreguesada": "afreguesar",
    "afreguesadas": "afreguesar",
    "afreguesado": "afreguesar",
    "afreguesados": "afreguesar",
    "afreguesai": "afreguesar",
    "afreguesais": "afreguesar",
    "afreguesam": "afreguesar",
    "afreguesamentos": "afreguesamento",
    "afreguesamo": "afreguesar",
    "afreguesamos": "afreguesar",
    "afreguesando": "afreguesar",
    "afreguesara": "afreguesar",
    "afreguesaram": "afreguesar",
    "afreguesaras": "afreguesar",
    "afreguesarde": "afreguesar",
    "afreguesardes": "afreguesar",
    "afreguesare": "afreguesar",
    "afreguesarei": "afreguesar",
    "afreguesareis": "afreguesar",
    "afreguesarem": "afreguesar",
    "afreguesaremos": "afreguesar",
    "afreguesares": "afreguesar",
    "afreguesaria": "afreguesar",
    "afreguesariam": "afreguesar",
    "afreguesarias": "afreguesar",
    "afreguesarmo": "afreguesar",
    "afreguesarmos": "afreguesar",
    "afreguesará": "afreguesar",
    "afreguesarás": "afreguesar",
    "afreguesarão": "afreguesar",
    "afreguesaríamos": "afreguesar",
    "afreguesaríeis": "afreguesar",
    "afreguesas": "afreguesar",
    "afreguesasse": "afreguesar",
    "afreguesassem": "afreguesar",
    "afreguesasses": "afreguesar",
    "afreguesaste": "afreguesar",
    "afreguesastes": "afreguesar",
    "afreguesava": "afreguesar",
    "afreguesavam": "afreguesar",
    "afreguesavas": "afreguesar",
    "afreguese": "afreguesar",
    "afreguesei": "afreguesar",
    "afregueseis": "afreguesar",
    "afreguesem": "afreguesar",
    "afreguesemo": "afreguesar",
    "afreguesemos": "afreguesar",
    "afregueses": "afreguesar",
    "afregueso": "afreguesar",
    "afreguesou": "afreguesar",
    "afreguesá": "afreguesar",
    "afreguesámo": "afreguesar",
    "afreguesámos": "afreguesar",
    "afreguesáramo": "afreguesar",
    "afreguesáramos": "afreguesar",
    "afreguesárei": "afreguesar",
    "afreguesáreis": "afreguesar",
    "afreguesásseis": "afreguesar",
    "afreguesássemos": "afreguesar",
    "afreguesávamo": "afreguesar",
    "afreguesávamos": "afreguesar",
    "afreguesávei": "afreguesar",
    "afreguesáveis": "afreguesar",
    "afreima": "afreimar",
    "afreimada": "afreimar",
    "afreimadas": "afreimar",
    "afreimado": "afreimar",
    "afreimados": "afreimar",
    "afreimai": "afreimar",
    "afreimais": "afreimar",
    "afreimam": "afreimar",
    "afreimamo": "afreimar",
    "afreimamos": "afreimar",
    "afreimando": "afreimar",
    "afreimara": "afreimar",
    "afreimaram": "afreimar",
    "afreimaras": "afreimar",
    "afreimarde": "afreimar",
    "afreimardes": "afreimar",
    "afreimare": "afreimar",
    "afreimarei": "afreimar",
    "afreimareis": "afreimar",
    "afreimarem": "afreimar",
    "afreimaremos": "afreimar",
    "afreimares": "afreimar",
    "afreimaria": "afreimar",
    "afreimariam": "afreimar",
    "afreimarias": "afreimar",
    "afreimarmo": "afreimar",
    "afreimarmos": "afreimar",
    "afreimará": "afreimar",
    "afreimarás": "afreimar",
    "afreimarão": "afreimar",
    "afreimaríamos": "afreimar",
    "afreimaríeis": "afreimar",
    "afreimas": "afreimar",
    "afreimasse": "afreimar",
    "afreimassem": "afreimar",
    "afreimasses": "afreimar",
    "afreimaste": "afreimar",
    "afreimastes": "afreimar",
    "afreimava": "afreimar",
    "afreimavam": "afreimar",
    "afreimavas": "afreimar",
    "afreime": "afreimar",
    "afreimei": "afreimar",
    "afreimeis": "afreimar",
    "afreimem": "afreimar",
    "afreimemo": "afreimar",
    "afreimemos": "afreimar",
    "afreimes": "afreimar",
    "afreimo": "afreimar",
    "afreimou": "afreimar",
    "afreimá": "afreimar",
    "afreimámo": "afreimar",
    "afreimámos": "afreimar",
    "afreimáramo": "afreimar",
    "afreimáramos": "afreimar",
    "afreimárei": "afreimar",
    "afreimáreis": "afreimar",
    "afreimásseis": "afreimar",
    "afreimássemos": "afreimar",
    "afreimávamo": "afreimar",
    "afreimávamos": "afreimar",
    "afreimávei": "afreimar",
    "afreimáveis": "afreimar",
    "afrenta": "afrentar",
    "afrentada": "afrentar",
    "afrentadas": "afrentar",
    "afrentado": "afrentar",
    "afrentados": "afrentar",
    "afrentai": "afrentar",
    "afrentais": "afrentar",
    "afrentam": "afrentar",
    "afrentamo": "afrentar",
    "afrentamos": "afrentar",
    "afrentando": "afrentar",
    "afrentara": "afrentar",
    "afrentaram": "afrentar",
    "afrentaras": "afrentar",
    "afrentarde": "afrentar",
    "afrentardes": "afrentar",
    "afrentare": "afrentar",
    "afrentarei": "afrentar",
    "afrentareis": "afrentar",
    "afrentarem": "afrentar",
    "afrentaremos": "afrentar",
    "afrentares": "afrentar",
    "afrentaria": "afrentar",
    "afrentariam": "afrentar",
    "afrentarias": "afrentar",
    "afrentarmo": "afrentar",
    "afrentarmos": "afrentar",
    "afrentará": "afrentar",
    "afrentarás": "afrentar",
    "afrentarão": "afrentar",
    "afrentaríamos": "afrentar",
    "afrentaríeis": "afrentar",
    "afrentas": "afrentar",
    "afrentasse": "afrentar",
    "afrentassem": "afrentar",
    "afrentasses": "afrentar",
    "afrentaste": "afrentar",
    "afrentastes": "afrentar",
    "afrentava": "afrentar",
    "afrentavam": "afrentar",
    "afrentavas": "afrentar",
    "afrente": "afrentar",
    "afrentei": "afrentar",
    "afrenteis": "afrentar",
    "afrentem": "afrentar",
    "afrentemo": "afrentar",
    "afrentemos": "afrentar",
    "afrentes": "afrentar",
    "afrento": "afrentar",
    "afrentou": "afrentar",
    "afrentá": "afrentar",
    "afrentámo": "afrentar",
    "afrentámos": "afrentar",
    "afrentáramo": "afrentar",
    "afrentáramos": "afrentar",
    "afrentárei": "afrentar",
    "afrentáreis": "afrentar",
    "afrentásseis": "afrentar",
    "afrentássemos": "afrentar",
    "afrentávamo": "afrentar",
    "afrentávamos": "afrentar",
    "afrentávei": "afrentar",
    "afrentáveis": "afrentar",
    "afrescos": "afresco",
    "afressurada": "afressurado",
    "afressuradas": "afressurado",
    "afressurados": "afressurado",
    "afreta": "afretar",
    "afretada": "afretar",
    "afretadas": "afretar",
    "afretado": "afretar",
    "afretadores": "afretador",
    "afretados": "afretar",
    "afretai": "afretar",
    "afretais": "afretar",
    "afretam": "afretar",
    "afretamentos": "afretamento",
    "afretamo": "afretar",
    "afretamos": "afretar",
    "afretando": "afretar",
    "afretara": "afretar",
    "afretaram": "afretar",
    "afretaras": "afretar",
    "afretarde": "afretar",
    "afretardes": "afretar",
    "afretare": "afretar",
    "afretarei": "afretar",
    "afretareis": "afretar",
    "afretarem": "afretar",
    "afretaremos": "afretar",
    "afretares": "afretar",
    "afretaria": "afretar",
    "afretariam": "afretar",
    "afretarias": "afretar",
    "afretarmo": "afretar",
    "afretarmos": "afretar",
    "afretará": "afretar",
    "afretarás": "afretar",
    "afretarão": "afretar",
    "afretaríamos": "afretar",
    "afretaríeis": "afretar",
    "afretas": "afretar",
    "afretasse": "afretar",
    "afretassem": "afretar",
    "afretasses": "afretar",
    "afretaste": "afretar",
    "afretastes": "afretar",
    "afretava": "afretar",
    "afretavam": "afretar",
    "afretavas": "afretar",
    "afrete": "afretar",
    "afretei": "afretar",
    "afreteis": "afretar",
    "afretem": "afretar",
    "afretemo": "afretar",
    "afretemos": "afretar",
    "afretes": "afretar",
    "afreto": "afretar",
    "afretou": "afretar",
    "afretá": "afretar",
    "afretámo": "afretar",
    "afretámos": "afretar",
    "afretáramo": "afretar",
    "afretáramos": "afretar",
    "afretárei": "afretar",
    "afretáreis": "afretar",
    "afretásseis": "afretar",
    "afretássemos": "afretar",
    "afretávamo": "afretar",
    "afretávamos": "afretar",
    "afretávei": "afretar",
    "afretáveis": "afretar",
    "africada": "africado",
    "africadas": "africado",
    "africados": "africado",
    "africana": "africano",
    "africanada": "africanar",
    "africanadas": "africanar",
    "africanado": "africanar",
    "africanados": "africanar",
    "africanai": "africanar",
    "africanais": "africanar",
    "africanam": "africanar",
    "africanamo": "africanar",
    "africanamos": "africanar",
    "africanando": "africanar",
    "africanara": "africanar",
    "africanaram": "africanar",
    "africanaras": "africanar",
    "africanarde": "africanar",
    "africanardes": "africanar",
    "africanare": "africanar",
    "africanarei": "africanar",
    "africanareis": "africanar",
    "africanarem": "africanar",
    "africanaremos": "africanar",
    "africanares": "africanar",
    "africanaria": "africanar",
    "africanariam": "africanar",
    "africanarias": "africanar",
    "africanarmo": "africanar",
    "africanarmos": "africanar",
    "africanará": "africanar",
    "africanarás": "africanar",
    "africanarão": "africanar",
    "africanaríamos": "africanar",
    "africanaríeis": "africanar",
    "africanas": "africano",
    "africanasse": "africanar",
    "africanassem": "africanar",
    "africanasses": "africanar",
    "africanaste": "africanar",
    "africanastes": "africanar",
    "africanava": "africanar",
    "africanavam": "africanar",
    "africanavas": "africanar",
    "africane": "africanar",
    "africanei": "africanar",
    "africaneis": "africanar",
    "africanem": "africanar",
    "africanemo": "africanar",
    "africanemos": "africanar",
    "africanes": "africanar",
    "africanidades": "africanidade",
    "africanismos": "africanismo",
    "africanistas": "africanista",
    "africaniza": "africanizar",
    "africanizada": "africanizar",
    "africanizadas": "africanizar",
    "africanizado": "africanizar",
    "africanizados": "africanizar",
    "africanizai": "africanizar",
    "africanizais": "africanizar",
    "africanizam": "africanizar",
    "africanizamo": "africanizar",
    "africanizamos": "africanizar",
    "africanizando": "africanizar",
    "africanizara": "africanizar",
    "africanizaram": "africanizar",
    "africanizaras": "africanizar",
    "africanizarde": "africanizar",
    "africanizardes": "africanizar",
    "africanizare": "africanizar",
    "africanizarei": "africanizar",
    "africanizareis": "africanizar",
    "africanizarem": "africanizar",
    "africanizaremos": "africanizar",
    "africanizares": "africanizar",
    "africanizaria": "africanizar",
    "africanizariam": "africanizar",
    "africanizarias": "africanizar",
    "africanizarmo": "africanizar",
    "africanizarmos": "africanizar",
    "africanizará": "africanizar",
    "africanizarás": "africanizar",
    "africanizarão": "africanizar",
    "africanizaríamos": "africanizar",
    "africanizaríeis": "africanizar",
    "africanizas": "africanizar",
    "africanizasse": "africanizar",
    "africanizassem": "africanizar",
    "africanizasses": "africanizar",
    "africanizaste": "africanizar",
    "africanizastes": "africanizar",
    "africanizava": "africanizar",
    "africanizavam": "africanizar",
    "africanizavas": "africanizar",
    "africanize": "africanizar",
    "africanizei": "africanizar",
    "africanizeis": "africanizar",
    "africanizem": "africanizar",
    "africanizemo": "africanizar",
    "africanizemos": "africanizar",
    "africanizes": "africanizar",
    "africanizo": "africanizar",
    "africanizou": "africanizar",
    "africanizá": "africanizar",
    "africanizámo": "africanizar",
    "africanizámos": "africanizar",
    "africanizáramo": "africanizar",
    "africanizáramos": "africanizar",
    "africanizárei": "africanizar",
    "africanizáreis": "africanizar",
    "africanizásseis": "africanizar",
    "africanizássemos": "africanizar",
    "africanizávamo": "africanizar",
    "africanizávamos": "africanizar",
    "africanizávei": "africanizar",
    "africanizáveis": "africanizável",
    "africano": "africanar",
    "africanos": "africano",
    "africanou": "africanar",
    "africaná": "africanar",
    "africanámo": "africanar",
    "africanámos": "africanar",
    "africanáramo": "africanar",
    "africanáramos": "africanar",
    "africanárei": "africanar",
    "africanáreis": "africanar",
    "africanásseis": "africanar",
    "africanássemos": "africanar",
    "africanávamo": "africanar",
    "africanávamos": "africanar",
    "africanávei": "africanar",
    "africanáveis": "africanar",
    "africânderes": "africânder",
    "afroamericana": "afroamericano",
    "afroamericanas": "afroamericano",
    "afroamericanos": "afroamericano",
    "afrodisias": "afrodisia",
    "afrodisíaca": "afrodisíaco",
    "afrodisíacas": "afrodisíaco",
    "afrodisíacos": "afrodisíaco",
    "afroditas": "afrodita",
    "afroditografias": "afroditografia",
    "afroixa": "afroixar",
    "afroixada": "afroixar",
    "afroixadas": "afroixar",
    "afroixado": "afroixar",
    "afroixados": "afroixar",
    "afroixai": "afroixar",
    "afroixais": "afroixar",
    "afroixam": "afroixar",
    "afroixamentos": "afroixamento",
    "afroixamo": "afroixar",
    "afroixamos": "afroixar",
    "afroixando": "afroixar",
    "afroixara": "afroixar",
    "afroixaram": "afroixar",
    "afroixaras": "afroixar",
    "afroixarde": "afroixar",
    "afroixardes": "afroixar",
    "afroixare": "afroixar",
    "afroixarei": "afroixar",
    "afroixareis": "afroixar",
    "afroixarem": "afroixar",
    "afroixaremos": "afroixar",
    "afroixares": "afroixar",
    "afroixaria": "afroixar",
    "afroixariam": "afroixar",
    "afroixarias": "afroixar",
    "afroixarmo": "afroixar",
    "afroixarmos": "afroixar",
    "afroixará": "afroixar",
    "afroixarás": "afroixar",
    "afroixarão": "afroixar",
    "afroixaríamos": "afroixar",
    "afroixaríeis": "afroixar",
    "afroixas": "afroixar",
    "afroixasse": "afroixar",
    "afroixassem": "afroixar",
    "afroixasses": "afroixar",
    "afroixaste": "afroixar",
    "afroixastes": "afroixar",
    "afroixava": "afroixar",
    "afroixavam": "afroixar",
    "afroixavas": "afroixar",
    "afroixe": "afroixar",
    "afroixei": "afroixar",
    "afroixeis": "afroixar",
    "afroixela": "afroixelar",
    "afroixelada": "afroixelar",
    "afroixeladas": "afroixelar",
    "afroixelado": "afroixelar",
    "afroixelados": "afroixelar",
    "afroixelai": "afroixelar",
    "afroixelais": "afroixelar",
    "afroixelam": "afroixelar",
    "afroixelamo": "afroixelar",
    "afroixelamos": "afroixelar",
    "afroixelando": "afroixelar",
    "afroixelara": "afroixelar",
    "afroixelaram": "afroixelar",
    "afroixelaras": "afroixelar",
    "afroixelarde": "afroixelar",
    "afroixelardes": "afroixelar",
    "afroixelare": "afroixelar",
    "afroixelarei": "afroixelar",
    "afroixelareis": "afroixelar",
    "afroixelarem": "afroixelar",
    "afroixelaremos": "afroixelar",
    "afroixelares": "afroixelar",
    "afroixelaria": "afroixelar",
    "afroixelariam": "afroixelar",
    "afroixelarias": "afroixelar",
    "afroixelarmo": "afroixelar",
    "afroixelarmos": "afroixelar",
    "afroixelará": "afroixelar",
    "afroixelarás": "afroixelar",
    "afroixelarão": "afroixelar",
    "afroixelaríamos": "afroixelar",
    "afroixelaríeis": "afroixelar",
    "afroixelas": "afroixelar",
    "afroixelasse": "afroixelar",
    "afroixelassem": "afroixelar",
    "afroixelasses": "afroixelar",
    "afroixelaste": "afroixelar",
    "afroixelastes": "afroixelar",
    "afroixelava": "afroixelar",
    "afroixelavam": "afroixelar",
    "afroixelavas": "afroixelar",
    "afroixele": "afroixelar",
    "afroixelei": "afroixelar",
    "afroixeleis": "afroixelar",
    "afroixelem": "afroixelar",
    "afroixelemo": "afroixelar",
    "afroixelemos": "afroixelar",
    "afroixeles": "afroixelar",
    "afroixelo": "afroixelar",
    "afroixelou": "afroixelar",
    "afroixelá": "afroixelar",
    "afroixelámo": "afroixelar",
    "afroixelámos": "afroixelar",
    "afroixeláramo": "afroixelar",
    "afroixeláramos": "afroixelar",
    "afroixelárei": "afroixelar",
    "afroixeláreis": "afroixelar",
    "afroixelásseis": "afroixelar",
    "afroixelássemos": "afroixelar",
    "afroixelávamo": "afroixelar",
    "afroixelávamos": "afroixelar",
    "afroixelávei": "afroixelar",
    "afroixeláveis": "afroixelar",
    "afroixem": "afroixar",
    "afroixemo": "afroixar",
    "afroixemos": "afroixar",
    "afroixes": "afroixar",
    "afroixo": "afroixar",
    "afroixou": "afroixar",
    "afroixá": "afroixar",
    "afroixámo": "afroixar",
    "afroixámos": "afroixar",
    "afroixáramo": "afroixar",
    "afroixáramos": "afroixar",
    "afroixárei": "afroixar",
    "afroixáreis": "afroixar",
    "afroixásseis": "afroixar",
    "afroixássemos": "afroixar",
    "afroixávamo": "afroixar",
    "afroixávamos": "afroixar",
    "afroixávei": "afroixar",
    "afroixáveis": "afroixar",
    "afronesias": "afronesia",
    "afronha": "afronhar",
    "afronhada": "afronhar",
    "afronhadas": "afronhar",
    "afronhado": "afronhar",
    "afronhados": "afronhar",
    "afronhai": "afronhar",
    "afronhais": "afronhar",
    "afronham": "afronhar",
    "afronhamo": "afronhar",
    "afronhamos": "afronhar",
    "afronhando": "afronhar",
    "afronhara": "afronhar",
    "afronharam": "afronhar",
    "afronharas": "afronhar",
    "afronharde": "afronhar",
    "afronhardes": "afronhar",
    "afronhare": "afronhar",
    "afronharei": "afronhar",
    "afronhareis": "afronhar",
    "afronharem": "afronhar",
    "afronharemos": "afronhar",
    "afronhares": "afronhar",
    "afronharia": "afronhar",
    "afronhariam": "afronhar",
    "afronharias": "afronhar",
    "afronharmo": "afronhar",
    "afronharmos": "afronhar",
    "afronhará": "afronhar",
    "afronharás": "afronhar",
    "afronharão": "afronhar",
    "afronharíamos": "afronhar",
    "afronharíeis": "afronhar",
    "afronhas": "afronhar",
    "afronhasse": "afronhar",
    "afronhassem": "afronhar",
    "afronhasses": "afronhar",
    "afronhaste": "afronhar",
    "afronhastes": "afronhar",
    "afronhava": "afronhar",
    "afronhavam": "afronhar",
    "afronhavas": "afronhar",
    "afronhe": "afronhar",
    "afronhei": "afronhar",
    "afronheis": "afronhar",
    "afronhem": "afronhar",
    "afronhemo": "afronhar",
    "afronhemos": "afronhar",
    "afronhes": "afronhar",
    "afronho": "afronhar",
    "afronhou": "afronhar",
    "afronhá": "afronhar",
    "afronhámo": "afronhar",
    "afronhámos": "afronhar",
    "afronháramo": "afronhar",
    "afronháramos": "afronhar",
    "afronhárei": "afronhar",
    "afronháreis": "afronhar",
    "afronhásseis": "afronhar",
    "afronhássemos": "afronhar",
    "afronhávamo": "afronhar",
    "afronhávamos": "afronhar",
    "afronhávei": "afronhar",
    "afronháveis": "afronhar",
    "afronta": "afrontar",
    "afrontada": "afrontar",
    "afrontadas": "afrontar",
    "afrontadiça": "afrontadiço",
    "afrontadiças": "afrontadiço",
    "afrontadiços": "afrontadiço",
    "afrontado": "afrontar",
    "afrontadora": "afrontador",
    "afrontadoras": "afrontador",
    "afrontadores": "afrontador",
    "afrontados": "afrontar",
    "afrontadíssima": "afrontado",
    "afrontadíssimas": "afrontado",
    "afrontadíssimo": "afrontado",
    "afrontadíssimos": "afrontado",
    "afrontai": "afrontar",
    "afrontais": "afrontar",
    "afrontam": "afrontar",
    "afrontamentos": "afrontamento",
    "afrontamo": "afrontar",
    "afrontamos": "afrontar",
    "afrontando": "afrontar",
    "afrontara": "afrontar",
    "afrontaram": "afrontar",
    "afrontaras": "afrontar",
    "afrontarde": "afrontar",
    "afrontardes": "afrontar",
    "afrontare": "afrontar",
    "afrontarei": "afrontar",
    "afrontareis": "afrontar",
    "afrontarem": "afrontar",
    "afrontaremos": "afrontar",
    "afrontares": "afrontar",
    "afrontaria": "afrontar",
    "afrontariam": "afrontar",
    "afrontarias": "afrontar",
    "afrontarmo": "afrontar",
    "afrontarmos": "afrontar",
    "afrontará": "afrontar",
    "afrontarás": "afrontar",
    "afrontarão": "afrontar",
    "afrontaríamos": "afrontar",
    "afrontaríeis": "afrontar",
    "afrontas": "afrontar",
    "afrontasse": "afrontar",
    "afrontassem": "afrontar",
    "afrontasses": "afrontar",
    "afrontaste": "afrontar",
    "afrontastes": "afrontar",
    "afrontava": "afrontar",
    "afrontavam": "afrontar",
    "afrontavas": "afrontar",
    "afrontazinha": "afronta",
    "afrontazinhas": "afronta",
    "afrontazita": "afronta",
    "afrontazitas": "afronta",
    "afrontações": "afrontação",
    "afronte": "afrontar",
    "afrontei": "afrontar",
    "afronteis": "afrontar",
    "afrontem": "afrontar",
    "afrontemo": "afrontar",
    "afrontemos": "afrontar",
    "afrontes": "afrontar",
    "afronto": "afrontar",
    "afrontosa": "afrontoso",
    "afrontosas": "afrontoso",
    "afrontosos": "afrontoso",
    "afrontou": "afrontar",
    "afrontá": "afrontar",
    "afrontámo": "afrontar",
    "afrontámos": "afrontar",
    "afrontáramo": "afrontar",
    "afrontáramos": "afrontar",
    "afrontárei": "afrontar",
    "afrontáreis": "afrontar",
    "afrontásseis": "afrontar",
    "afrontássemos": "afrontar",
    "afrontávamo": "afrontar",
    "afrontávamos": "afrontar",
    "afrontávei": "afrontar",
    "afrontáveis": "afrontar",
    "afros": "afro",
    "afrouxa": "afrouxar",
    "afrouxada": "afrouxar",
    "afrouxadas": "afrouxar",
    "afrouxado": "afrouxar",
    "afrouxados": "afrouxar",
    "afrouxai": "afrouxar",
    "afrouxais": "afrouxar",
    "afrouxam": "afrouxar",
    "afrouxamentos": "afrouxamento",
    "afrouxamo": "afrouxar",
    "afrouxamos": "afrouxar",
    "afrouxando": "afrouxar",
    "afrouxara": "afrouxar",
    "afrouxaram": "afrouxar",
    "afrouxaras": "afrouxar",
    "afrouxarde": "afrouxar",
    "afrouxardes": "afrouxar",
    "afrouxare": "afrouxar",
    "afrouxarei": "afrouxar",
    "afrouxareis": "afrouxar",
    "afrouxarem": "afrouxar",
    "afrouxaremos": "afrouxar",
    "afrouxares": "afrouxar",
    "afrouxaria": "afrouxar",
    "afrouxariam": "afrouxar",
    "afrouxarias": "afrouxar",
    "afrouxarmo": "afrouxar",
    "afrouxarmos": "afrouxar",
    "afrouxará": "afrouxar",
    "afrouxarás": "afrouxar",
    "afrouxarão": "afrouxar",
    "afrouxaríamos": "afrouxar",
    "afrouxaríeis": "afrouxar",
    "afrouxas": "afrouxar",
    "afrouxasse": "afrouxar",
    "afrouxassem": "afrouxar",
    "afrouxasses": "afrouxar",
    "afrouxaste": "afrouxar",
    "afrouxastes": "afrouxar",
    "afrouxava": "afrouxar",
    "afrouxavam": "afrouxar",
    "afrouxavas": "afrouxar",
    "afrouxe": "afrouxar",
    "afrouxei": "afrouxar",
    "afrouxeis": "afrouxar",
    "afrouxela": "afrouxelar",
    "afrouxelada": "afrouxelar",
    "afrouxeladas": "afrouxelar",
    "afrouxelado": "afrouxelar",
    "afrouxelados": "afrouxelar",
    "afrouxelai": "afrouxelar",
    "afrouxelais": "afrouxelar",
    "afrouxelam": "afrouxelar",
    "afrouxelamo": "afrouxelar",
    "afrouxelamos": "afrouxelar",
    "afrouxelando": "afrouxelar",
    "afrouxelara": "afrouxelar",
    "afrouxelaram": "afrouxelar",
    "afrouxelaras": "afrouxelar",
    "afrouxelarde": "afrouxelar",
    "afrouxelardes": "afrouxelar",
    "afrouxelare": "afrouxelar",
    "afrouxelarei": "afrouxelar",
    "afrouxelareis": "afrouxelar",
    "afrouxelarem": "afrouxelar",
    "afrouxelaremos": "afrouxelar",
    "afrouxelares": "afrouxelar",
    "afrouxelaria": "afrouxelar",
    "afrouxelariam": "afrouxelar",
    "afrouxelarias": "afrouxelar",
    "afrouxelarmo": "afrouxelar",
    "afrouxelarmos": "afrouxelar",
    "afrouxelará": "afrouxelar",
    "afrouxelarás": "afrouxelar",
    "afrouxelarão": "afrouxelar",
    "afrouxelaríamos": "afrouxelar",
    "afrouxelaríeis": "afrouxelar",
    "afrouxelas": "afrouxelar",
    "afrouxelasse": "afrouxelar",
    "afrouxelassem": "afrouxelar",
    "afrouxelasses": "afrouxelar",
    "afrouxelaste": "afrouxelar",
    "afrouxelastes": "afrouxelar",
    "afrouxelava": "afrouxelar",
    "afrouxelavam": "afrouxelar",
    "afrouxelavas": "afrouxelar",
    "afrouxele": "afrouxelar",
    "afrouxelei": "afrouxelar",
    "afrouxeleis": "afrouxelar",
    "afrouxelem": "afrouxelar",
    "afrouxelemo": "afrouxelar",
    "afrouxelemos": "afrouxelar",
    "afrouxeles": "afrouxelar",
    "afrouxelo": "afrouxelar",
    "afrouxelou": "afrouxelar",
    "afrouxelá": "afrouxelar",
    "afrouxelámo": "afrouxelar",
    "afrouxelámos": "afrouxelar",
    "afrouxeláramo": "afrouxelar",
    "afrouxeláramos": "afrouxelar",
    "afrouxelárei": "afrouxelar",
    "afrouxeláreis": "afrouxelar",
    "afrouxelásseis": "afrouxelar",
    "afrouxelássemos": "afrouxelar",
    "afrouxelávamo": "afrouxelar",
    "afrouxelávamos": "afrouxelar",
    "afrouxelávei": "afrouxelar",
    "afrouxeláveis": "afrouxelar",
    "afrouxem": "afrouxar",
    "afrouxemo": "afrouxar",
    "afrouxemos": "afrouxar",
    "afrouxes": "afrouxar",
    "afrouxo": "afrouxar",
    "afrouxou": "afrouxar",
    "afrouxá": "afrouxar",
    "afrouxámo": "afrouxar",
    "afrouxámos": "afrouxar",
    "afrouxáramo": "afrouxar",
    "afrouxáramos": "afrouxar",
    "afrouxárei": "afrouxar",
    "afrouxáreis": "afrouxar",
    "afrouxásseis": "afrouxar",
    "afrouxássemos": "afrouxar",
    "afrouxávamo": "afrouxar",
    "afrouxávamos": "afrouxar",
    "afrouxávei": "afrouxar",
    "afrouxáveis": "afrouxar",
    "afruta": "afrutar",
    "afrutada": "afrutar",
    "afrutadas": "afrutar",
    "afrutado": "afrutar",
    "afrutados": "afrutar",
    "afrutai": "afrutar",
    "afrutais": "afrutar",
    "afrutam": "afrutar",
    "afrutamo": "afrutar",
    "afrutamos": "afrutar",
    "afrutando": "afrutar",
    "afrutara": "afrutar",
    "afrutaram": "afrutar",
    "afrutaras": "afrutar",
    "afrutardes": "afrutar",
    "afrutarei": "afrutar",
    "afrutareis": "afrutar",
    "afrutarem": "afrutar",
    "afrutaremos": "afrutar",
    "afrutares": "afrutar",
    "afrutaria": "afrutar",
    "afrutariam": "afrutar",
    "afrutarias": "afrutar",
    "afrutarmo": "afrutar",
    "afrutarmos": "afrutar",
    "afrutará": "afrutar",
    "afrutarás": "afrutar",
    "afrutarão": "afrutar",
    "afrutaríamos": "afrutar",
    "afrutaríeis": "afrutar",
    "afrutas": "afrutar",
    "afrutasse": "afrutar",
    "afrutassem": "afrutar",
    "afrutasses": "afrutar",
    "afrutaste": "afrutar",
    "afrutastes": "afrutar",
    "afrutava": "afrutar",
    "afrutavam": "afrutar",
    "afrutavas": "afrutar",
    "afrute": "afrutar",
    "afrutei": "afrutar",
    "afruteis": "afrutar",
    "afrutem": "afrutar",
    "afrutemo": "afrutar",
    "afrutemos": "afrutar",
    "afrutes": "afrutar",
    "afruto": "afrutar",
    "afrutou": "afrutar",
    "afrutámo": "afrutar",
    "afrutámos": "afrutar",
    "afrutáramo": "afrutar",
    "afrutáramos": "afrutar",
    "afrutáreis": "afrutar",
    "afrutásseis": "afrutar",
    "afrutássemos": "afrutar",
    "afrutávamo": "afrutar",
    "afrutávamos": "afrutar",
    "afrutáveis": "afrutar",
    "afrósinas": "afrósina",
    "aftas": "afta",
    "aftongias": "aftongia",
    "aftosa": "aftoso",
    "aftosas": "aftoso",
    "aftosos": "aftoso",
    "afugenta": "afugentar",
    "afugentada": "afugentar",
    "afugentadas": "afugentar",
    "afugentado": "afugentar",
    "afugentadora": "afugentador",
    "afugentadoras": "afugentador",
    "afugentadores": "afugentador",
    "afugentados": "afugentar",
    "afugentai": "afugentar",
    "afugentais": "afugentar",
    "afugentam": "afugentar",
    "afugentamentos": "afugentamento",
    "afugentamo": "afugentar",
    "afugentamos": "afugentar",
    "afugentando": "afugentar",
    "afugentara": "afugentar",
    "afugentaram": "afugentar",
    "afugentaras": "afugentar",
    "afugentarde": "afugentar",
    "afugentardes": "afugentar",
    "afugentare": "afugentar",
    "afugentarei": "afugentar",
    "afugentareis": "afugentar",
    "afugentarem": "afugentar",
    "afugentaremos": "afugentar",
    "afugentares": "afugentar",
    "afugentaria": "afugentar",
    "afugentariam": "afugentar",
    "afugentarias": "afugentar",
    "afugentarmo": "afugentar",
    "afugentarmos": "afugentar",
    "afugentará": "afugentar",
    "afugentarás": "afugentar",
    "afugentarão": "afugentar",
    "afugentaríamos": "afugentar",
    "afugentaríeis": "afugentar",
    "afugentas": "afugentar",
    "afugentasse": "afugentar",
    "afugentassem": "afugentar",
    "afugentasses": "afugentar",
    "afugentaste": "afugentar",
    "afugentastes": "afugentar",
    "afugentava": "afugentar",
    "afugentavam": "afugentar",
    "afugentavas": "afugentar",
    "afugente": "afugentar",
    "afugentei": "afugentar",
    "afugenteis": "afugentar",
    "afugentem": "afugentar",
    "afugentemo": "afugentar",
    "afugentemos": "afugentar",
    "afugentes": "afugentar",
    "afugento": "afugentar",
    "afugentou": "afugentar",
    "afugentá": "afugentar",
    "afugentámo": "afugentar",
    "afugentámos": "afugentar",
    "afugentáramo": "afugentar",
    "afugentáramos": "afugentar",
    "afugentárei": "afugentar",
    "afugentáreis": "afugentar",
    "afugentásseis": "afugentar",
    "afugentássemos": "afugentar",
    "afugentávamo": "afugentar",
    "afugentávamos": "afugentar",
    "afugentávei": "afugentar",
    "afugentáveis": "afugentável",
    "afulva": "afulvar",
    "afulvada": "afulvar",
    "afulvadas": "afulvar",
    "afulvado": "afulvar",
    "afulvados": "afulvar",
    "afulvai": "afulvar",
    "afulvais": "afulvar",
    "afulvam": "afulvar",
    "afulvamo": "afulvar",
    "afulvamos": "afulvar",
    "afulvando": "afulvar",
    "afulvara": "afulvar",
    "afulvaram": "afulvar",
    "afulvaras": "afulvar",
    "afulvarde": "afulvar",
    "afulvardes": "afulvar",
    "afulvare": "afulvar",
    "afulvarei": "afulvar",
    "afulvareis": "afulvar",
    "afulvarem": "afulvar",
    "afulvaremos": "afulvar",
    "afulvares": "afulvar",
    "afulvaria": "afulvar",
    "afulvariam": "afulvar",
    "afulvarias": "afulvar",
    "afulvarmo": "afulvar",
    "afulvarmos": "afulvar",
    "afulvará": "afulvar",
    "afulvarás": "afulvar",
    "afulvarão": "afulvar",
    "afulvaríamos": "afulvar",
    "afulvaríeis": "afulvar",
    "afulvas": "afulvar",
    "afulvasse": "afulvar",
    "afulvassem": "afulvar",
    "afulvasses": "afulvar",
    "afulvaste": "afulvar",
    "afulvastes": "afulvar",
    "afulvava": "afulvar",
    "afulvavam": "afulvar",
    "afulvavas": "afulvar",
    "afulve": "afulvar",
    "afulvei": "afulvar",
    "afulveis": "afulvar",
    "afulvem": "afulvar",
    "afulvemo": "afulvar",
    "afulvemos": "afulvar",
    "afulves": "afulvar",
    "afulvo": "afulvar",
    "afulvou": "afulvar",
    "afulvá": "afulvar",
    "afulvámo": "afulvar",
    "afulvámos": "afulvar",
    "afulváramo": "afulvar",
    "afulváramos": "afulvar",
    "afulvárei": "afulvar",
    "afulváreis": "afulvar",
    "afulvásseis": "afulvar",
    "afulvássemos": "afulvar",
    "afulvávamo": "afulvar",
    "afulvávamos": "afulvar",
    "afulvávei": "afulvar",
    "afulváveis": "afulvar",
    "afuma": "afumar",
    "afumada": "afumar",
    "afumadas": "afumar",
    "afumado": "afumar",
    "afumados": "afumar",
    "afumaduras": "afumadura",
    "afumai": "afumar",
    "afumais": "afumar",
    "afumam": "afumar",
    "afumamo": "afumar",
    "afumamos": "afumar",
    "afumando": "afumar",
    "afumara": "afumar",
    "afumaram": "afumar",
    "afumaras": "afumar",
    "afumarde": "afumar",
    "afumardes": "afumar",
    "afumare": "afumar",
    "afumarei": "afumar",
    "afumareis": "afumar",
    "afumarem": "afumar",
    "afumaremos": "afumar",
    "afumares": "afumar",
    "afumaria": "afumar",
    "afumariam": "afumar",
    "afumarias": "afumar",
    "afumarmo": "afumar",
    "afumarmos": "afumar",
    "afumará": "afumar",
    "afumarás": "afumar",
    "afumarão": "afumar",
    "afumaríamos": "afumar",
    "afumaríeis": "afumar",
    "afumas": "afumar",
    "afumasse": "afumar",
    "afumassem": "afumar",
    "afumasses": "afumar",
    "afumaste": "afumar",
    "afumastes": "afumar",
    "afumava": "afumar",
    "afumavam": "afumar",
    "afumavas": "afumar",
    "afume": "afumar",
    "afumei": "afumar",
    "afumeis": "afumar",
    "afumem": "afumar",
    "afumemo": "afumar",
    "afumemos": "afumar",
    "afumes": "afumar",
    "afumo": "afumar",
    "afumou": "afumar",
    "afumá": "afumar",
    "afumámo": "afumar",
    "afumámos": "afumar",
    "afumáramo": "afumar",
    "afumáramos": "afumar",
    "afumárei": "afumar",
    "afumáreis": "afumar",
    "afumásseis": "afumar",
    "afumássemos": "afumar",
    "afumávamo": "afumar",
    "afumávamos": "afumar",
    "afumávei": "afumar",
    "afumáveis": "afumar",
    "afunada": "afunado",
    "afunadas": "afunado",
    "afunados": "afunado",
    "afunda": "afundir",
    "afundada": "afundar",
    "afundadas": "afundar",
    "afundado": "afundar",
    "afundados": "afundar",
    "afundai": "afundar",
    "afundais": "afundir",
    "afundam": "afundir",
    "afundamentos": "afundamento",
    "afundamo": "afundir",
    "afundamos": "afundir",
    "afundando": "afundar",
    "afundanços": "afundanço",
    "afundara": "afundar",
    "afundaram": "afundar",
    "afundaras": "afundar",
    "afundarde": "afundar",
    "afundardes": "afundar",
    "afundare": "afundar",
    "afundarei": "afundar",
    "afundareis": "afundar",
    "afundarem": "afundar",
    "afundaremos": "afundar",
    "afundares": "afundar",
    "afundaria": "afundar",
    "afundariam": "afundar",
    "afundarias": "afundar",
    "afundarmo": "afundar",
    "afundarmos": "afundar",
    "afundará": "afundar",
    "afundarás": "afundar",
    "afundarão": "afundar",
    "afundaríamos": "afundar",
    "afundaríeis": "afundar",
    "afundas": "afundir",
    "afundasse": "afundar",
    "afundassem": "afundar",
    "afundasses": "afundar",
    "afundaste": "afundar",
    "afundastes": "afundar",
    "afundava": "afundar",
    "afundavam": "afundar",
    "afundavas": "afundar",
    "afunde": "afundir",
    "afundei": "afundar",
    "afundeis": "afundar",
    "afundem": "afundir",
    "afundemo": "afundar",
    "afundemos": "afundar",
    "afundes": "afundir",
    "afundi": "afundir",
    "afundia": "afundir",
    "afundiam": "afundir",
    "afundias": "afundir",
    "afundida": "afundir",
    "afundidas": "afundir",
    "afundido": "afundir",
    "afundidos": "afundir",
    "afundimentos": "afundimento",
    "afundimo": "afundir",
    "afundimos": "afundir",
    "afundindo": "afundir",
    "afundira": "afundir",
    "afundiram": "afundir",
    "afundiras": "afundir",
    "afundirde": "afundir",
    "afundirdes": "afundir",
    "afundire": "afundir",
    "afundirei": "afundir",
    "afundireis": "afundir",
    "afundirem": "afundir",
    "afundiremos": "afundir",
    "afundires": "afundir",
    "afundiria": "afundir",
    "afundiriam": "afundir",
    "afundirias": "afundir",
    "afundirmo": "afundir",
    "afundirmos": "afundir",
    "afundirá": "afundir",
    "afundirás": "afundir",
    "afundirão": "afundir",
    "afundiríamos": "afundir",
    "afundiríeis": "afundir",
    "afundis": "afundir",
    "afundisse": "afundir",
    "afundissem": "afundir",
    "afundisses": "afundir",
    "afundiste": "afundir",
    "afundistes": "afundir",
    "afundiu": "afundir",
    "afundo": "afundir",
    "afundou": "afundar",
    "afundá": "afundar",
    "afundámo": "afundar",
    "afundámos": "afundar",
    "afundáramo": "afundar",
    "afundáramos": "afundar",
    "afundárei": "afundar",
    "afundáreis": "afundar",
    "afundásseis": "afundar",
    "afundássemos": "afundar",
    "afundávamo": "afundar",
    "afundávamos": "afundar",
    "afundávei": "afundar",
    "afundáveis": "afundar",
    "afundíamo": "afundir",
    "afundíamos": "afundir",
    "afundíei": "afundir",
    "afundíeis": "afundir",
    "afundíramo": "afundir",
    "afundíramos": "afundir",
    "afundírei": "afundir",
    "afundíreis": "afundir",
    "afundísseis": "afundir",
    "afundíssemos": "afundir",
    "afunila": "afunilar",
    "afunilada": "afunilar",
    "afuniladas": "afunilar",
    "afunilado": "afunilar",
    "afunilados": "afunilar",
    "afunilai": "afunilar",
    "afunilais": "afunilar",
    "afunilam": "afunilar",
    "afunilamentos": "afunilamento",
    "afunilamo": "afunilar",
    "afunilamos": "afunilar",
    "afunilando": "afunilar",
    "afunilara": "afunilar",
    "afunilaram": "afunilar",
    "afunilaras": "afunilar",
    "afunilarde": "afunilar",
    "afunilardes": "afunilar",
    "afunilare": "afunilar",
    "afunilarei": "afunilar",
    "afunilareis": "afunilar",
    "afunilarem": "afunilar",
    "afunilaremos": "afunilar",
    "afunilares": "afunilar",
    "afunilaria": "afunilar",
    "afunilariam": "afunilar",
    "afunilarias": "afunilar",
    "afunilarmo": "afunilar",
    "afunilarmos": "afunilar",
    "afunilará": "afunilar",
    "afunilarás": "afunilar",
    "afunilarão": "afunilar",
    "afunilaríamos": "afunilar",
    "afunilaríeis": "afunilar",
    "afunilas": "afunilar",
    "afunilasse": "afunilar",
    "afunilassem": "afunilar",
    "afunilasses": "afunilar",
    "afunilaste": "afunilar",
    "afunilastes": "afunilar",
    "afunilava": "afunilar",
    "afunilavam": "afunilar",
    "afunilavas": "afunilar",
    "afunile": "afunilar",
    "afunilei": "afunilar",
    "afunileis": "afunilar",
    "afunilem": "afunilar",
    "afunilemo": "afunilar",
    "afunilemos": "afunilar",
    "afuniles": "afunilar",
    "afunilo": "afunilar",
    "afunilou": "afunilar",
    "afunilá": "afunilar",
    "afunilámo": "afunilar",
    "afunilámos": "afunilar",
    "afuniláramo": "afunilar",
    "afuniláramos": "afunilar",
    "afunilárei": "afunilar",
    "afuniláreis": "afunilar",
    "afunilásseis": "afunilar",
    "afunilássemos": "afunilar",
    "afunilávamo": "afunilar",
    "afunilávamos": "afunilar",
    "afunilávei": "afunilar",
    "afuniláveis": "afunilar",
    "afuroa": "afuroar",
    "afuroada": "afuroar",
    "afuroadas": "afuroar",
    "afuroado": "afuroar",
    "afuroadora": "afuroador",
    "afuroadoras": "afuroador",
    "afuroadores": "afuroador",
    "afuroados": "afuroar",
    "afuroai": "afuroar",
    "afuroais": "afuroar",
    "afuroam": "afuroar",
    "afuroamo": "afuroar",
    "afuroamos": "afuroar",
    "afuroando": "afuroar",
    "afuroara": "afuroar",
    "afuroaram": "afuroar",
    "afuroaras": "afuroar",
    "afuroarde": "afuroar",
    "afuroardes": "afuroar",
    "afuroare": "afuroar",
    "afuroarei": "afuroar",
    "afuroareis": "afuroar",
    "afuroarem": "afuroar",
    "afuroaremos": "afuroar",
    "afuroares": "afuroar",
    "afuroaria": "afuroar",
    "afuroariam": "afuroar",
    "afuroarias": "afuroar",
    "afuroarmo": "afuroar",
    "afuroarmos": "afuroar",
    "afuroará": "afuroar",
    "afuroarás": "afuroar",
    "afuroarão": "afuroar",
    "afuroaríamos": "afuroar",
    "afuroaríeis": "afuroar",
    "afuroas": "afuroar",
    "afuroasse": "afuroar",
    "afuroassem": "afuroar",
    "afuroasses": "afuroar",
    "afuroaste": "afuroar",
    "afuroastes": "afuroar",
    "afuroava": "afuroar",
    "afuroavam": "afuroar",
    "afuroavas": "afuroar",
    "afuroe": "afuroar",
    "afuroei": "afuroar",
    "afuroeis": "afuroar",
    "afuroem": "afuroar",
    "afuroemo": "afuroar",
    "afuroemos": "afuroar",
    "afuroes": "afuroar",
    "afuroo": "afuroar",
    "afuroou": "afuroar",
    "afuroá": "afuroar",
    "afuroámo": "afuroar",
    "afuroámos": "afuroar",
    "afuroáramo": "afuroar",
    "afuroáramos": "afuroar",
    "afuroárei": "afuroar",
    "afuroáreis": "afuroar",
    "afuroásseis": "afuroar",
    "afuroássemos": "afuroar",
    "afuroávamo": "afuroar",
    "afuroávamos": "afuroar",
    "afuroávei": "afuroar",
    "afuroáveis": "afuroar",
    "afusa": "afusar",
    "afusada": "afusar",
    "afusadas": "afusar",
    "afusado": "afusar",
    "afusados": "afusar",
    "afusai": "afusar",
    "afusais": "afusar",
    "afusam": "afusar",
    "afusamo": "afusar",
    "afusamos": "afusar",
    "afusando": "afusar",
    "afusara": "afusar",
    "afusaram": "afusar",
    "afusaras": "afusar",
    "afusarde": "afusar",
    "afusardes": "afusar",
    "afusare": "afusar",
    "afusarei": "afusar",
    "afusareis": "afusar",
    "afusarem": "afusar",
    "afusaremos": "afusar",
    "afusares": "afusar",
    "afusaria": "afusar",
    "afusariam": "afusar",
    "afusarias": "afusar",
    "afusarmo": "afusar",
    "afusarmos": "afusar",
    "afusará": "afusar",
    "afusarás": "afusar",
    "afusarão": "afusar",
    "afusaríamos": "afusar",
    "afusaríeis": "afusar",
    "afusas": "afusar",
    "afusasse": "afusar",
    "afusassem": "afusar",
    "afusasses": "afusar",
    "afusaste": "afusar",
    "afusastes": "afusar",
    "afusava": "afusar",
    "afusavam": "afusar",
    "afusavas": "afusar",
    "afuse": "afusar",
    "afusei": "afusar",
    "afuseis": "afusar",
    "afuselada": "afuselado",
    "afuseladas": "afuselado",
    "afuselados": "afuselado",
    "afuselamentos": "afuselamento",
    "afusem": "afusar",
    "afusemo": "afusar",
    "afusemos": "afusar",
    "afuses": "afusar",
    "afuso": "afusar",
    "afusou": "afusar",
    "afustada": "afustado",
    "afustadas": "afustado",
    "afustados": "afustado",
    "afusá": "afusar",
    "afusámo": "afusar",
    "afusámos": "afusar",
    "afusáramo": "afusar",
    "afusáramos": "afusar",
    "afusárei": "afusar",
    "afusáreis": "afusar",
    "afusásseis": "afusar",
    "afusássemos": "afusar",
    "afusávamo": "afusar",
    "afusávamos": "afusar",
    "afusávei": "afusar",
    "afusáveis": "afusar",
    "afusões": "afusão",
    "afutrica": "afutricar",
    "afutricada": "afutricar",
    "afutricadas": "afutricar",
    "afutricado": "afutricar",
    "afutricados": "afutricar",
    "afutricai": "afutricar",
    "afutricais": "afutricar",
    "afutricam": "afutricar",
    "afutricamo": "afutricar",
    "afutricamos": "afutricar",
    "afutricando": "afutricar",
    "afutricara": "afutricar",
    "afutricaram": "afutricar",
    "afutricaras": "afutricar",
    "afutricarde": "afutricar",
    "afutricardes": "afutricar",
    "afutricare": "afutricar",
    "afutricarei": "afutricar",
    "afutricareis": "afutricar",
    "afutricarem": "afutricar",
    "afutricaremos": "afutricar",
    "afutricares": "afutricar",
    "afutricaria": "afutricar",
    "afutricariam": "afutricar",
    "afutricarias": "afutricar",
    "afutricarmo": "afutricar",
    "afutricarmos": "afutricar",
    "afutricará": "afutricar",
    "afutricarás": "afutricar",
    "afutricarão": "afutricar",
    "afutricaríamos": "afutricar",
    "afutricaríeis": "afutricar",
    "afutricas": "afutricar",
    "afutricasse": "afutricar",
    "afutricassem": "afutricar",
    "afutricasses": "afutricar",
    "afutricaste": "afutricar",
    "afutricastes": "afutricar",
    "afutricava": "afutricar",
    "afutricavam": "afutricar",
    "afutricavas": "afutricar",
    "afutrico": "afutricar",
    "afutricou": "afutricar",
    "afutricá": "afutricar",
    "afutricámo": "afutricar",
    "afutricámos": "afutricar",
    "afutricáramo": "afutricar",
    "afutricáramos": "afutricar",
    "afutricárei": "afutricar",
    "afutricáreis": "afutricar",
    "afutricásseis": "afutricar",
    "afutricássemos": "afutricar",
    "afutricávamo": "afutricar",
    "afutricávamos": "afutricar",
    "afutricávei": "afutricar",
    "afutricáveis": "afutricar",
    "afutrique": "afutricar",
    "afutriquei": "afutricar",
    "afutriqueis": "afutricar",
    "afutriquem": "afutricar",
    "afutriquemo": "afutricar",
    "afutriquemos": "afutricar",
    "afutriques": "afutricar",
    "afuzila": "afuzilar",
    "afuzilada": "afuzilar",
    "afuziladas": "afuzilar",
    "afuzilado": "afuzilar",
    "afuzilados": "afuzilar",
    "afuzilai": "afuzilar",
    "afuzilais": "afuzilar",
    "afuzilam": "afuzilar",
    "afuzilamo": "afuzilar",
    "afuzilamos": "afuzilar",
    "afuzilando": "afuzilar",
    "afuzilara": "afuzilar",
    "afuzilaram": "afuzilar",
    "afuzilaras": "afuzilar",
    "afuzilarde": "afuzilar",
    "afuzilardes": "afuzilar",
    "afuzilare": "afuzilar",
    "afuzilarei": "afuzilar",
    "afuzilareis": "afuzilar",
    "afuzilarem": "afuzilar",
    "afuzilaremos": "afuzilar",
    "afuzilares": "afuzilar",
    "afuzilaria": "afuzilar",
    "afuzilariam": "afuzilar",
    "afuzilarias": "afuzilar",
    "afuzilarmo": "afuzilar",
    "afuzilarmos": "afuzilar",
    "afuzilará": "afuzilar",
    "afuzilarás": "afuzilar",
    "afuzilarão": "afuzilar",
    "afuzilaríamos": "afuzilar",
    "afuzilaríeis": "afuzilar",
    "afuzilas": "afuzilar",
    "afuzilasse": "afuzilar",
    "afuzilassem": "afuzilar",
    "afuzilasses": "afuzilar",
    "afuzilaste": "afuzilar",
    "afuzilastes": "afuzilar",
    "afuzilava": "afuzilar",
    "afuzilavam": "afuzilar",
    "afuzilavas": "afuzilar",
    "afuzile": "afuzilar",
    "afuzilei": "afuzilar",
    "afuzileis": "afuzilar",
    "afuzilem": "afuzilar",
    "afuzilemo": "afuzilar",
    "afuzilemos": "afuzilar",
    "afuziles": "afuzilar",
    "afuzilo": "afuzilar",
    "afuzilou": "afuzilar",
    "afuzilá": "afuzilar",
    "afuzilámo": "afuzilar",
    "afuzilámos": "afuzilar",
    "afuziláramo": "afuzilar",
    "afuziláramos": "afuzilar",
    "afuzilárei": "afuzilar",
    "afuziláreis": "afuzilar",
    "afuzilásseis": "afuzilar",
    "afuzilássemos": "afuzilar",
    "afuzilávamo": "afuzilar",
    "afuzilávamos": "afuzilar",
    "afuzilávei": "afuzilar",
    "afuziláveis": "afuzilar",
    "afá": "afazer",
    "afásica": "afásico",
    "afásicas": "afásico",
    "afásicos": "afásico",
    "afáveis": "afável",
    "afélios": "afélio",
    "aféreses": "aférese",
    "afê": "afazer",
    "afídia": "afídio",
    "afídias": "afídio",
    "afídios": "afídio",
    "afítulos": "afítulo",
    "afónica": "afónico",
    "afónicas": "afónico",
    "afónicos": "afónico",
    "agacha": "agachar",
    "agachada": "agachar",
    "agachadas": "agachar",
    "agachadinha": "agachado",
    "agachadinhas": "agachado",
    "agachadinho": "agachado",
    "agachadinhos": "agachado",
    "agachadita": "agachado",
    "agachaditas": "agachado",
    "agachadito": "agachado",
    "agachaditos": "agachado",
    "agachado": "agachar",
    "agachados": "agachar",
    "agachadíssima": "agachado",
    "agachadíssimas": "agachado",
    "agachadíssimo": "agachado",
    "agachadíssimos": "agachado",
    "agachai": "agachar",
    "agachais": "agachar",
    "agacham": "agachar",
    "agachamentos": "agachamento",
    "agachamo": "agachar",
    "agachamos": "agachar",
    "agachando": "agachar",
    "agachara": "agachar",
    "agacharam": "agachar",
    "agacharas": "agachar",
    "agacharde": "agachar",
    "agachardes": "agachar",
    "agachare": "agachar",
    "agacharei": "agachar",
    "agachareis": "agachar",
    "agacharem": "agachar",
    "agacharemos": "agachar",
    "agachares": "agachar",
    "agacharia": "agachar",
    "agachariam": "agachar",
    "agacharias": "agachar",
    "agacharmo": "agachar",
    "agacharmos": "agachar",
    "agachará": "agachar",
    "agacharás": "agachar",
    "agacharão": "agachar",
    "agacharíamos": "agachar",
    "agacharíeis": "agachar",
    "agachas": "agachar",
    "agachasse": "agachar",
    "agachassem": "agachar",
    "agachasses": "agachar",
    "agachaste": "agachar",
    "agachastes": "agachar",
    "agachava": "agachar",
    "agachavam": "agachar",
    "agachavas": "agachar",
    "agache": "agachar",
    "agachei": "agachar",
    "agacheis": "agachar",
    "agachem": "agachar",
    "agachemo": "agachar",
    "agachemos": "agachar",
    "agaches": "agachar",
    "agacho": "agachar",
    "agachos": "agacho",
    "agachou": "agachar",
    "agachá": "agachar",
    "agachámo": "agachar",
    "agachámos": "agachar",
    "agacháramo": "agachar",
    "agacháramos": "agachar",
    "agachárei": "agachar",
    "agacháreis": "agachar",
    "agachásseis": "agachar",
    "agachássemos": "agachar",
    "agachávamo": "agachar",
    "agachávamos": "agachar",
    "agachávei": "agachar",
    "agacháveis": "agachar",
    "agacés": "agacé",
    "agadanha": "agadanhar",
    "agadanhada": "agadanhar",
    "agadanhadas": "agadanhar",
    "agadanhadeira": "agadanhador",
    "agadanhadeiras": "agadanhador",
    "agadanhado": "agadanhar",
    "agadanhadora": "agadanhador",
    "agadanhadoras": "agadanhador",
    "agadanhadores": "agadanhador",
    "agadanhados": "agadanhar",
    "agadanhai": "agadanhar",
    "agadanhais": "agadanhar",
    "agadanham": "agadanhar",
    "agadanhamo": "agadanhar",
    "agadanhamos": "agadanhar",
    "agadanhando": "agadanhar",
    "agadanhara": "agadanhar",
    "agadanharam": "agadanhar",
    "agadanharas": "agadanhar",
    "agadanharde": "agadanhar",
    "agadanhardes": "agadanhar",
    "agadanhare": "agadanhar",
    "agadanharei": "agadanhar",
    "agadanhareis": "agadanhar",
    "agadanharem": "agadanhar",
    "agadanharemos": "agadanhar",
    "agadanhares": "agadanhar",
    "agadanharia": "agadanhar",
    "agadanhariam": "agadanhar",
    "agadanharias": "agadanhar",
    "agadanharmo": "agadanhar",
    "agadanharmos": "agadanhar",
    "agadanhará": "agadanhar",
    "agadanharás": "agadanhar",
    "agadanharão": "agadanhar",
    "agadanharíamos": "agadanhar",
    "agadanharíeis": "agadanhar",
    "agadanhas": "agadanhar",
    "agadanhasse": "agadanhar",
    "agadanhassem": "agadanhar",
    "agadanhasses": "agadanhar",
    "agadanhaste": "agadanhar",
    "agadanhastes": "agadanhar",
    "agadanhava": "agadanhar",
    "agadanhavam": "agadanhar",
    "agadanhavas": "agadanhar",
    "agadanhe": "agadanhar",
    "agadanhei": "agadanhar",
    "agadanheis": "agadanhar",
    "agadanhem": "agadanhar",
    "agadanhemo": "agadanhar",
    "agadanhemos": "agadanhar",
    "agadanhes": "agadanhar",
    "agadanho": "agadanhar",
    "agadanhou": "agadanhar",
    "agadanhá": "agadanhar",
    "agadanhámo": "agadanhar",
    "agadanhámos": "agadanhar",
    "agadanháramo": "agadanhar",
    "agadanháramos": "agadanhar",
    "agadanhárei": "agadanhar",
    "agadanháreis": "agadanhar",
    "agadanhásseis": "agadanhar",
    "agadanhássemos": "agadanhar",
    "agadanhávamo": "agadanhar",
    "agadanhávamos": "agadanhar",
    "agadanhávei": "agadanhar",
    "agadanháveis": "agadanhar",
    "agafanha": "agafanhar",
    "agafanhada": "agafanhar",
    "agafanhadas": "agafanhar",
    "agafanhadeira": "agafanhador",
    "agafanhadeiras": "agafanhador",
    "agafanhado": "agafanhar",
    "agafanhadora": "agafanhador",
    "agafanhadoras": "agafanhador",
    "agafanhadores": "agafanhador",
    "agafanhados": "agafanhar",
    "agafanhai": "agafanhar",
    "agafanhais": "agafanhar",
    "agafanham": "agafanhar",
    "agafanhamo": "agafanhar",
    "agafanhamos": "agafanhar",
    "agafanhando": "agafanhar",
    "agafanhara": "agafanhar",
    "agafanharam": "agafanhar",
    "agafanharas": "agafanhar",
    "agafanharde": "agafanhar",
    "agafanhardes": "agafanhar",
    "agafanhare": "agafanhar",
    "agafanharei": "agafanhar",
    "agafanhareis": "agafanhar",
    "agafanharem": "agafanhar",
    "agafanharemos": "agafanhar",
    "agafanhares": "agafanhar",
    "agafanharia": "agafanhar",
    "agafanhariam": "agafanhar",
    "agafanharias": "agafanhar",
    "agafanharmo": "agafanhar",
    "agafanharmos": "agafanhar",
    "agafanhará": "agafanhar",
    "agafanharás": "agafanhar",
    "agafanharão": "agafanhar",
    "agafanharíamos": "agafanhar",
    "agafanharíeis": "agafanhar",
    "agafanhas": "agafanhar",
    "agafanhasse": "agafanhar",
    "agafanhassem": "agafanhar",
    "agafanhasses": "agafanhar",
    "agafanhaste": "agafanhar",
    "agafanhastes": "agafanhar",
    "agafanhava": "agafanhar",
    "agafanhavam": "agafanhar",
    "agafanhavas": "agafanhar",
    "agafanhe": "agafanhar",
    "agafanhei": "agafanhar",
    "agafanheis": "agafanhar",
    "agafanhem": "agafanhar",
    "agafanhemo": "agafanhar",
    "agafanhemos": "agafanhar",
    "agafanhes": "agafanhar",
    "agafanho": "agafanhar",
    "agafanhou": "agafanhar",
    "agafanhá": "agafanhar",
    "agafanhámo": "agafanhar",
    "agafanhámos": "agafanhar",
    "agafanháramo": "agafanhar",
    "agafanháramos": "agafanhar",
    "agafanhárei": "agafanhar",
    "agafanháreis": "agafanhar",
    "agafanhásseis": "agafanhar",
    "agafanhássemos": "agafanhar",
    "agafanhávamo": "agafanhar",
    "agafanhávamos": "agafanhar",
    "agafanhávei": "agafanhar",
    "agafanháveis": "agafanhar",
    "agafites": "agafite",
    "agaiata": "agaiatar",
    "agaiatada": "agaiatar",
    "agaiatadas": "agaiatar",
    "agaiatado": "agaiatar",
    "agaiatados": "agaiatar",
    "agaiatai": "agaiatar",
    "agaiatais": "agaiatar",
    "agaiatam": "agaiatar",
    "agaiatamo": "agaiatar",
    "agaiatamos": "agaiatar",
    "agaiatando": "agaiatar",
    "agaiatara": "agaiatar",
    "agaiataram": "agaiatar",
    "agaiataras": "agaiatar",
    "agaiatarde": "agaiatar",
    "agaiatardes": "agaiatar",
    "agaiatare": "agaiatar",
    "agaiatarei": "agaiatar",
    "agaiatareis": "agaiatar",
    "agaiatarem": "agaiatar",
    "agaiataremos": "agaiatar",
    "agaiatares": "agaiatar",
    "agaiataria": "agaiatar",
    "agaiatariam": "agaiatar",
    "agaiatarias": "agaiatar",
    "agaiatarmo": "agaiatar",
    "agaiatarmos": "agaiatar",
    "agaiatará": "agaiatar",
    "agaiatarás": "agaiatar",
    "agaiatarão": "agaiatar",
    "agaiataríamos": "agaiatar",
    "agaiataríeis": "agaiatar",
    "agaiatas": "agaiatar",
    "agaiatasse": "agaiatar",
    "agaiatassem": "agaiatar",
    "agaiatasses": "agaiatar",
    "agaiataste": "agaiatar",
    "agaiatastes": "agaiatar",
    "agaiatava": "agaiatar",
    "agaiatavam": "agaiatar",
    "agaiatavas": "agaiatar",
    "agaiate": "agaiatar",
    "agaiatei": "agaiatar",
    "agaiateis": "agaiatar",
    "agaiatem": "agaiatar",
    "agaiatemo": "agaiatar",
    "agaiatemos": "agaiatar",
    "agaiates": "agaiatar",
    "agaiato": "agaiatar",
    "agaiatou": "agaiatar",
    "agaiatá": "agaiatar",
    "agaiatámo": "agaiatar",
    "agaiatámos": "agaiatar",
    "agaiatáramo": "agaiatar",
    "agaiatáramos": "agaiatar",
    "agaiatárei": "agaiatar",
    "agaiatáreis": "agaiatar",
    "agaiatásseis": "agaiatar",
    "agaiatássemos": "agaiatar",
    "agaiatávamo": "agaiatar",
    "agaiatávamos": "agaiatar",
    "agaiatávei": "agaiatar",
    "agaiatáveis": "agaiatar",
    "agaitada": "agaitado",
    "agaitadas": "agaitado",
    "agaitados": "agaitado",
    "agalactas": "agalacta",
    "agalactações": "agalactação",
    "agalactias": "agalactia",
    "agalana": "agalanar",
    "agalanada": "agalanar",
    "agalanadas": "agalanar",
    "agalanado": "agalanar",
    "agalanados": "agalanar",
    "agalanai": "agalanar",
    "agalanais": "agalanar",
    "agalanam": "agalanar",
    "agalanamo": "agalanar",
    "agalanamos": "agalanar",
    "agalanando": "agalanar",
    "agalanara": "agalanar",
    "agalanaram": "agalanar",
    "agalanaras": "agalanar",
    "agalanarde": "agalanar",
    "agalanardes": "agalanar",
    "agalanare": "agalanar",
    "agalanarei": "agalanar",
    "agalanareis": "agalanar",
    "agalanarem": "agalanar",
    "agalanaremos": "agalanar",
    "agalanares": "agalanar",
    "agalanaria": "agalanar",
    "agalanariam": "agalanar",
    "agalanarias": "agalanar",
    "agalanarmo": "agalanar",
    "agalanarmos": "agalanar",
    "agalanará": "agalanar",
    "agalanarás": "agalanar",
    "agalanarão": "agalanar",
    "agalanaríamos": "agalanar",
    "agalanaríeis": "agalanar",
    "agalanas": "agalanar",
    "agalanasse": "agalanar",
    "agalanassem": "agalanar",
    "agalanasses": "agalanar",
    "agalanaste": "agalanar",
    "agalanastes": "agalanar",
    "agalanava": "agalanar",
    "agalanavam": "agalanar",
    "agalanavas": "agalanar",
    "agalane": "agalanar",
    "agalanei": "agalanar",
    "agalaneis": "agalanar",
    "agalanem": "agalanar",
    "agalanemo": "agalanar",
    "agalanemos": "agalanar",
    "agalanes": "agalanar",
    "agalano": "agalanar",
    "agalanou": "agalanar",
    "agalaná": "agalanar",
    "agalanámo": "agalanar",
    "agalanámos": "agalanar",
    "agalanáramo": "agalanar",
    "agalanáramos": "agalanar",
    "agalanárei": "agalanar",
    "agalanáreis": "agalanar",
    "agalanásseis": "agalanar",
    "agalanássemos": "agalanar",
    "agalanávamo": "agalanar",
    "agalanávamos": "agalanar",
    "agalanávei": "agalanar",
    "agalanáveis": "agalanar",
    "agalaxias": "agalaxia",
    "agalega": "agalegar",
    "agalegada": "agalegar",
    "agalegadas": "agalegar",
    "agalegado": "agalegar",
    "agalegados": "agalegar",
    "agalegai": "agalegar",
    "agalegais": "agalegar",
    "agalegam": "agalegar",
    "agalegamo": "agalegar",
    "agalegamos": "agalegar",
    "agalegando": "agalegar",
    "agalegara": "agalegar",
    "agalegaram": "agalegar",
    "agalegaras": "agalegar",
    "agalegarde": "agalegar",
    "agalegardes": "agalegar",
    "agalegare": "agalegar",
    "agalegarei": "agalegar",
    "agalegareis": "agalegar",
    "agalegarem": "agalegar",
    "agalegaremos": "agalegar",
    "agalegares": "agalegar",
    "agalegaria": "agalegar",
    "agalegariam": "agalegar",
    "agalegarias": "agalegar",
    "agalegarmo": "agalegar",
    "agalegarmos": "agalegar",
    "agalegará": "agalegar",
    "agalegarás": "agalegar",
    "agalegarão": "agalegar",
    "agalegaríamos": "agalegar",
    "agalegaríeis": "agalegar",
    "agalegas": "agalegar",
    "agalegasse": "agalegar",
    "agalegassem": "agalegar",
    "agalegasses": "agalegar",
    "agalegaste": "agalegar",
    "agalegastes": "agalegar",
    "agalegava": "agalegar",
    "agalegavam": "agalegar",
    "agalegavas": "agalegar",
    "agalego": "agalegar",
    "agalegou": "agalegar",
    "agalegue": "agalegar",
    "agaleguei": "agalegar",
    "agalegueis": "agalegar",
    "agaleguem": "agalegar",
    "agaleguemo": "agalegar",
    "agaleguemos": "agalegar",
    "agalegues": "agalegar",
    "agalegá": "agalegar",
    "agalegámo": "agalegar",
    "agalegámos": "agalegar",
    "agalegáramo": "agalegar",
    "agalegáramos": "agalegar",
    "agalegárei": "agalegar",
    "agalegáreis": "agalegar",
    "agalegásseis": "agalegar",
    "agalegássemos": "agalegar",
    "agalegávamo": "agalegar",
    "agalegávamos": "agalegar",
    "agalegávei": "agalegar",
    "agalegáveis": "agalegar",
    "agalga": "agalgar",
    "agalgada": "agalgar",
    "agalgadas": "agalgar",
    "agalgado": "agalgar",
    "agalgados": "agalgar",
    "agalgai": "agalgar",
    "agalgais": "agalgar",
    "agalgam": "agalgar",
    "agalgamo": "agalgar",
    "agalgamos": "agalgar",
    "agalgando": "agalgar",
    "agalgara": "agalgar",
    "agalgaram": "agalgar",
    "agalgaras": "agalgar",
    "agalgarde": "agalgar",
    "agalgardes": "agalgar",
    "agalgare": "agalgar",
    "agalgarei": "agalgar",
    "agalgareis": "agalgar",
    "agalgarem": "agalgar",
    "agalgaremos": "agalgar",
    "agalgares": "agalgar",
    "agalgaria": "agalgar",
    "agalgariam": "agalgar",
    "agalgarias": "agalgar",
    "agalgarmo": "agalgar",
    "agalgarmos": "agalgar",
    "agalgará": "agalgar",
    "agalgarás": "agalgar",
    "agalgarão": "agalgar",
    "agalgaríamos": "agalgar",
    "agalgaríeis": "agalgar",
    "agalgas": "agalgar",
    "agalgasse": "agalgar",
    "agalgassem": "agalgar",
    "agalgasses": "agalgar",
    "agalgaste": "agalgar",
    "agalgastes": "agalgar",
    "agalgava": "agalgar",
    "agalgavam": "agalgar",
    "agalgavas": "agalgar",
    "agalgo": "agalgar",
    "agalgou": "agalgar",
    "agalgue": "agalgar",
    "agalguei": "agalgar",
    "agalgueis": "agalgar",
    "agalguem": "agalgar",
    "agalguemo": "agalgar",
    "agalguemos": "agalgar",
    "agalgues": "agalgar",
    "agalgá": "agalgar",
    "agalgámo": "agalgar",
    "agalgámos": "agalgar",
    "agalgáramo": "agalgar",
    "agalgáramos": "agalgar",
    "agalgárei": "agalgar",
    "agalgáreis": "agalgar",
    "agalgásseis": "agalgar",
    "agalgássemos": "agalgar",
    "agalgávamo": "agalgar",
    "agalgávamos": "agalgar",
    "agalgávei": "agalgar",
    "agalgáveis": "agalgar",
    "agalha": "agalhar",
    "agalhada": "agalhar",
    "agalhadas": "agalhar",
    "agalhado": "agalhar",
    "agalhados": "agalhar",
    "agalhai": "agalhar",
    "agalhais": "agalhar",
    "agalham": "agalhar",
    "agalhamo": "agalhar",
    "agalhamos": "agalhar",
    "agalhando": "agalhar",
    "agalhara": "agalhar",
    "agalharam": "agalhar",
    "agalharas": "agalhar",
    "agalhardes": "agalhar",
    "agalharei": "agalhar",
    "agalhareis": "agalhar",
    "agalharem": "agalhar",
    "agalharemos": "agalhar",
    "agalhares": "agalhar",
    "agalharia": "agalhar",
    "agalhariam": "agalhar",
    "agalharias": "agalhar",
    "agalharmo": "agalhar",
    "agalharmos": "agalhar",
    "agalhará": "agalhar",
    "agalharás": "agalhar",
    "agalharão": "agalhar",
    "agalharíamos": "agalhar",
    "agalharíeis": "agalhar",
    "agalhas": "agalhar",
    "agalhasse": "agalhar",
    "agalhassem": "agalhar",
    "agalhasses": "agalhar",
    "agalhaste": "agalhar",
    "agalhastes": "agalhar",
    "agalhava": "agalhar",
    "agalhavam": "agalhar",
    "agalhavas": "agalhar",
    "agalhe": "agalhar",
    "agalhei": "agalhar",
    "agalheis": "agalhar",
    "agalhem": "agalhar",
    "agalhemo": "agalhar",
    "agalhemos": "agalhar",
    "agalhes": "agalhar",
    "agalho": "agalhar",
    "agalhou": "agalhar",
    "agalhámo": "agalhar",
    "agalhámos": "agalhar",
    "agalháramo": "agalhar",
    "agalháramos": "agalhar",
    "agalháreis": "agalhar",
    "agalhásseis": "agalhar",
    "agalhássemos": "agalhar",
    "agalhávamo": "agalhar",
    "agalhávamos": "agalhar",
    "agalháveis": "agalhar",
    "agaloa": "agaloar",
    "agaloada": "agaloar",
    "agaloadas": "agaloar",
    "agaloado": "agaloar",
    "agaloados": "agaloar",
    "agaloaduras": "agaloadura",
    "agaloai": "agaloar",
    "agaloais": "agaloar",
    "agaloam": "agaloar",
    "agaloamo": "agaloar",
    "agaloamos": "agaloar",
    "agaloando": "agaloar",
    "agaloara": "agaloar",
    "agaloaram": "agaloar",
    "agaloaras": "agaloar",
    "agaloarde": "agaloar",
    "agaloardes": "agaloar",
    "agaloare": "agaloar",
    "agaloarei": "agaloar",
    "agaloareis": "agaloar",
    "agaloarem": "agaloar",
    "agaloaremos": "agaloar",
    "agaloares": "agaloar",
    "agaloaria": "agaloar",
    "agaloariam": "agaloar",
    "agaloarias": "agaloar",
    "agaloarmo": "agaloar",
    "agaloarmos": "agaloar",
    "agaloará": "agaloar",
    "agaloarás": "agaloar",
    "agaloarão": "agaloar",
    "agaloaríamos": "agaloar",
    "agaloaríeis": "agaloar",
    "agaloas": "agaloar",
    "agaloasse": "agaloar",
    "agaloassem": "agaloar",
    "agaloasses": "agaloar",
    "agaloaste": "agaloar",
    "agaloastes": "agaloar",
    "agaloava": "agaloar",
    "agaloavam": "agaloar",
    "agaloavas": "agaloar",
    "agaloe": "agaloar",
    "agaloei": "agaloar",
    "agaloeis": "agaloar",
    "agaloem": "agaloar",
    "agaloemo": "agaloar",
    "agaloemos": "agaloar",
    "agaloes": "agaloar",
    "agaloo": "agaloar",
    "agaloou": "agaloar",
    "agalopada": "agalopado",
    "agalopadas": "agalopado",
    "agalopados": "agalopado",
    "agaloá": "agaloar",
    "agaloámo": "agaloar",
    "agaloámos": "agaloar",
    "agaloáramo": "agaloar",
    "agaloáramos": "agaloar",
    "agaloárei": "agaloar",
    "agaloáreis": "agaloar",
    "agaloásseis": "agaloar",
    "agaloássemos": "agaloar",
    "agaloávamo": "agaloar",
    "agaloávamos": "agaloar",
    "agaloávei": "agaloar",
    "agaloáveis": "agaloar",
    "agamias": "agamia",
    "agamis": "agami",
    "agamídea": "agamídeo",
    "agamídeas": "agamídeo",
    "agamídeos": "agamídeo",
    "agapantos": "agapanto",
    "agapetas": "agapeta",
    "agapetos": "agapeto",
    "agarena": "agareno",
    "agarenas": "agareno",
    "agarenos": "agareno",
    "agargalada": "agargalado",
    "agargaladas": "agargalado",
    "agargalados": "agargalado",
    "agaricinas": "agaricina",
    "agaricácea": "agaricáceo",
    "agaricáceas": "agaricáceo",
    "agaricáceos": "agaricáceo",
    "agarnacha": "agarnachar",
    "agarnachada": "agarnachar",
    "agarnachadas": "agarnachar",
    "agarnachado": "agarnachar",
    "agarnachados": "agarnachar",
    "agarnachai": "agarnachar",
    "agarnachais": "agarnachar",
    "agarnacham": "agarnachar",
    "agarnachamo": "agarnachar",
    "agarnachamos": "agarnachar",
    "agarnachando": "agarnachar",
    "agarnachara": "agarnachar",
    "agarnacharam": "agarnachar",
    "agarnacharas": "agarnachar",
    "agarnacharde": "agarnachar",
    "agarnachardes": "agarnachar",
    "agarnachare": "agarnachar",
    "agarnacharei": "agarnachar",
    "agarnachareis": "agarnachar",
    "agarnacharem": "agarnachar",
    "agarnacharemos": "agarnachar",
    "agarnachares": "agarnachar",
    "agarnacharia": "agarnachar",
    "agarnachariam": "agarnachar",
    "agarnacharias": "agarnachar",
    "agarnacharmo": "agarnachar",
    "agarnacharmos": "agarnachar",
    "agarnachará": "agarnachar",
    "agarnacharás": "agarnachar",
    "agarnacharão": "agarnachar",
    "agarnacharíamos": "agarnachar",
    "agarnacharíeis": "agarnachar",
    "agarnachas": "agarnachar",
    "agarnachasse": "agarnachar",
    "agarnachassem": "agarnachar",
    "agarnachasses": "agarnachar",
    "agarnachaste": "agarnachar",
    "agarnachastes": "agarnachar",
    "agarnachava": "agarnachar",
    "agarnachavam": "agarnachar",
    "agarnachavas": "agarnachar",
    "agarnache": "agarnachar",
    "agarnachei": "agarnachar",
    "agarnacheis": "agarnachar",
    "agarnachem": "agarnachar",
    "agarnachemo": "agarnachar",
    "agarnachemos": "agarnachar",
    "agarnaches": "agarnachar",
    "agarnacho": "agarnachar",
    "agarnachou": "agarnachar",
    "agarnachá": "agarnachar",
    "agarnachámo": "agarnachar",
    "agarnachámos": "agarnachar",
    "agarnacháramo": "agarnachar",
    "agarnacháramos": "agarnachar",
    "agarnachárei": "agarnachar",
    "agarnacháreis": "agarnachar",
    "agarnachásseis": "agarnachar",
    "agarnachássemos": "agarnachar",
    "agarnachávamo": "agarnachar",
    "agarnachávamos": "agarnachar",
    "agarnachávei": "agarnachar",
    "agarnacháveis": "agarnachar",
    "agarota": "agarotar",
    "agarotada": "agarotar",
    "agarotadas": "agarotar",
    "agarotado": "agarotar",
    "agarotados": "agarotar",
    "agarotai": "agarotar",
    "agarotais": "agarotar",
    "agarotam": "agarotar",
    "agarotamo": "agarotar",
    "agarotamos": "agarotar",
    "agarotando": "agarotar",
    "agarotara": "agarotar",
    "agarotaram": "agarotar",
    "agarotaras": "agarotar",
    "agarotarde": "agarotar",
    "agarotardes": "agarotar",
    "agarotare": "agarotar",
    "agarotarei": "agarotar",
    "agarotareis": "agarotar",
    "agarotarem": "agarotar",
    "agarotaremos": "agarotar",
    "agarotares": "agarotar",
    "agarotaria": "agarotar",
    "agarotariam": "agarotar",
    "agarotarias": "agarotar",
    "agarotarmo": "agarotar",
    "agarotarmos": "agarotar",
    "agarotará": "agarotar",
    "agarotarás": "agarotar",
    "agarotarão": "agarotar",
    "agarotaríamos": "agarotar",
    "agarotaríeis": "agarotar",
    "agarotas": "agarotar",
    "agarotasse": "agarotar",
    "agarotassem": "agarotar",
    "agarotasses": "agarotar",
    "agarotaste": "agarotar",
    "agarotastes": "agarotar",
    "agarotava": "agarotar",
    "agarotavam": "agarotar",
    "agarotavas": "agarotar",
    "agarote": "agarotar",
    "agarotei": "agarotar",
    "agaroteis": "agarotar",
    "agarotem": "agarotar",
    "agarotemo": "agarotar",
    "agarotemos": "agarotar",
    "agarotes": "agarotar",
    "agaroto": "agarotar",
    "agarotou": "agarotar",
    "agarotá": "agarotar",
    "agarotámo": "agarotar",
    "agarotámos": "agarotar",
    "agarotáramo": "agarotar",
    "agarotáramos": "agarotar",
    "agarotárei": "agarotar",
    "agarotáreis": "agarotar",
    "agarotásseis": "agarotar",
    "agarotássemos": "agarotar",
    "agarotávamo": "agarotar",
    "agarotávamos": "agarotar",
    "agarotávei": "agarotar",
    "agarotáveis": "agarotar",
    "agarra": "agarrar",
    "agarrada": "agarrar",
    "agarradas": "agarrar",
    "agarradeira": "agarrador",
    "agarradeiras": "agarrador",
    "agarradinha": "agarrado",
    "agarradinhas": "agarrado",
    "agarradinho": "agarrado",
    "agarradinhos": "agarrado",
    "agarradita": "agarrado",
    "agarraditas": "agarrado",
    "agarradito": "agarrado",
    "agarraditos": "agarrado",
    "agarradiça": "agarradiço",
    "agarradiças": "agarradiço",
    "agarradiços": "agarradiço",
    "agarrado": "agarrar",
    "agarradora": "agarrador",
    "agarradoras": "agarrador",
    "agarradores": "agarrador",
    "agarrados": "agarrar",
    "agarradíssima": "agarrado",
    "agarradíssimas": "agarrado",
    "agarradíssimo": "agarrado",
    "agarradíssimos": "agarrado",
    "agarrai": "agarrar",
    "agarrais": "agarrar",
    "agarram": "agarrar",
    "agarramentos": "agarramento",
    "agarramo": "agarrar",
    "agarramos": "agarrar",
    "agarranada": "agarranado",
    "agarranadas": "agarranado",
    "agarranados": "agarranado",
    "agarrando": "agarrar",
    "agarrara": "agarrar",
    "agarraram": "agarrar",
    "agarraras": "agarrar",
    "agarrarde": "agarrar",
    "agarrardes": "agarrar",
    "agarrare": "agarrar",
    "agarrarei": "agarrar",
    "agarrareis": "agarrar",
    "agarrarem": "agarrar",
    "agarraremos": "agarrar",
    "agarrares": "agarrar",
    "agarraria": "agarrar",
    "agarrariam": "agarrar",
    "agarrarias": "agarrar",
    "agarrarmo": "agarrar",
    "agarrarmos": "agarrar",
    "agarrará": "agarrar",
    "agarrarás": "agarrar",
    "agarrarão": "agarrar",
    "agarraríamos": "agarrar",
    "agarraríeis": "agarrar",
    "agarras": "agarrar",
    "agarrasse": "agarrar",
    "agarrassem": "agarrar",
    "agarrasses": "agarrar",
    "agarraste": "agarrar",
    "agarrastes": "agarrar",
    "agarrava": "agarrar",
    "agarravam": "agarrar",
    "agarravas": "agarrar",
    "agarrações": "agarração",
    "agarre": "agarrar",
    "agarrei": "agarrar",
    "agarreis": "agarrar",
    "agarrem": "agarrar",
    "agarremo": "agarrar",
    "agarremos": "agarrar",
    "agarres": "agarrar",
    "agarro": "agarrar",
    "agarrou": "agarrar",
    "agarrucha": "agarruchar",
    "agarruchada": "agarruchar",
    "agarruchadas": "agarruchar",
    "agarruchado": "agarruchar",
    "agarruchados": "agarruchar",
    "agarruchai": "agarruchar",
    "agarruchais": "agarruchar",
    "agarrucham": "agarruchar",
    "agarruchamo": "agarruchar",
    "agarruchamos": "agarruchar",
    "agarruchando": "agarruchar",
    "agarruchara": "agarruchar",
    "agarrucharam": "agarruchar",
    "agarrucharas": "agarruchar",
    "agarrucharde": "agarruchar",
    "agarruchardes": "agarruchar",
    "agarruchare": "agarruchar",
    "agarrucharei": "agarruchar",
    "agarruchareis": "agarruchar",
    "agarrucharem": "agarruchar",
    "agarrucharemos": "agarruchar",
    "agarruchares": "agarruchar",
    "agarrucharia": "agarruchar",
    "agarruchariam": "agarruchar",
    "agarrucharias": "agarruchar",
    "agarrucharmo": "agarruchar",
    "agarrucharmos": "agarruchar",
    "agarruchará": "agarruchar",
    "agarrucharás": "agarruchar",
    "agarrucharão": "agarruchar",
    "agarrucharíamos": "agarruchar",
    "agarrucharíeis": "agarruchar",
    "agarruchas": "agarruchar",
    "agarruchasse": "agarruchar",
    "agarruchassem": "agarruchar",
    "agarruchasses": "agarruchar",
    "agarruchaste": "agarruchar",
    "agarruchastes": "agarruchar",
    "agarruchava": "agarruchar",
    "agarruchavam": "agarruchar",
    "agarruchavas": "agarruchar",
    "agarruche": "agarruchar",
    "agarruchei": "agarruchar",
    "agarrucheis": "agarruchar",
    "agarruchem": "agarruchar",
    "agarruchemo": "agarruchar",
    "agarruchemos": "agarruchar",
    "agarruches": "agarruchar",
    "agarrucho": "agarruchar",
    "agarruchou": "agarruchar",
    "agarruchá": "agarruchar",
    "agarruchámo": "agarruchar",
    "agarruchámos": "agarruchar",
    "agarrucháramo": "agarruchar",
    "agarrucháramos": "agarruchar",
    "agarruchárei": "agarruchar",
    "agarrucháreis": "agarruchar",
    "agarruchásseis": "agarruchar",
    "agarruchássemos": "agarruchar",
    "agarruchávamo": "agarruchar",
    "agarruchávamos": "agarruchar",
    "agarruchávei": "agarruchar",
    "agarrucháveis": "agarruchar",
    "agarruncha": "agarrunchar",
    "agarrunchada": "agarrunchar",
    "agarrunchadas": "agarrunchar",
    "agarrunchado": "agarrunchar",
    "agarrunchados": "agarrunchar",
    "agarrunchai": "agarrunchar",
    "agarrunchais": "agarrunchar",
    "agarruncham": "agarrunchar",
    "agarrunchamo": "agarrunchar",
    "agarrunchamos": "agarrunchar",
    "agarrunchando": "agarrunchar",
    "agarrunchara": "agarrunchar",
    "agarruncharam": "agarrunchar",
    "agarruncharas": "agarrunchar",
    "agarruncharde": "agarrunchar",
    "agarrunchardes": "agarrunchar",
    "agarrunchare": "agarrunchar",
    "agarruncharei": "agarrunchar",
    "agarrunchareis": "agarrunchar",
    "agarruncharem": "agarrunchar",
    "agarruncharemos": "agarrunchar",
    "agarrunchares": "agarrunchar",
    "agarruncharia": "agarrunchar",
    "agarrunchariam": "agarrunchar",
    "agarruncharias": "agarrunchar",
    "agarruncharmo": "agarrunchar",
    "agarruncharmos": "agarrunchar",
    "agarrunchará": "agarrunchar",
    "agarruncharás": "agarrunchar",
    "agarruncharão": "agarrunchar",
    "agarruncharíamos": "agarrunchar",
    "agarruncharíeis": "agarrunchar",
    "agarrunchas": "agarrunchar",
    "agarrunchasse": "agarrunchar",
    "agarrunchassem": "agarrunchar",
    "agarrunchasses": "agarrunchar",
    "agarrunchaste": "agarrunchar",
    "agarrunchastes": "agarrunchar",
    "agarrunchava": "agarrunchar",
    "agarrunchavam": "agarrunchar",
    "agarrunchavas": "agarrunchar",
    "agarrunche": "agarrunchar",
    "agarrunchei": "agarrunchar",
    "agarruncheis": "agarrunchar",
    "agarrunchem": "agarrunchar",
    "agarrunchemo": "agarrunchar",
    "agarrunchemos": "agarrunchar",
    "agarrunches": "agarrunchar",
    "agarruncho": "agarrunchar",
    "agarrunchou": "agarrunchar",
    "agarrunchá": "agarrunchar",
    "agarrunchámo": "agarrunchar",
    "agarrunchámos": "agarrunchar",
    "agarruncháramo": "agarrunchar",
    "agarruncháramos": "agarrunchar",
    "agarrunchárei": "agarrunchar",
    "agarruncháreis": "agarrunchar",
    "agarrunchásseis": "agarrunchar",
    "agarrunchássemos": "agarrunchar",
    "agarrunchávamo": "agarrunchar",
    "agarrunchávamos": "agarrunchar",
    "agarrunchávei": "agarrunchar",
    "agarruncháveis": "agarrunchar",
    "agarrá": "agarrar",
    "agarrámo": "agarrar",
    "agarrámos": "agarrar",
    "agarráramo": "agarrar",
    "agarráramos": "agarrar",
    "agarrárei": "agarrar",
    "agarráreis": "agarrar",
    "agarrásseis": "agarrar",
    "agarrássemos": "agarrar",
    "agarrávamo": "agarrar",
    "agarrávamos": "agarrar",
    "agarrávei": "agarrar",
    "agarráveis": "agarrável",
    "agaríceas": "agarícea",
    "agarícia": "agarício",
    "agarícias": "agarício",
    "agarícios": "agarício",
    "agasalha": "agasalhar",
    "agasalhada": "agasalhar",
    "agasalhadas": "agasalhar",
    "agasalhadeira": "agasalhadeiro",
    "agasalhadeiras": "agasalhadeiro",
    "agasalhadeiros": "agasalhadeiro",
    "agasalhadinha": "agasalhado",
    "agasalhadinhas": "agasalhado",
    "agasalhadinho": "agasalhado",
    "agasalhadinhos": "agasalhado",
    "agasalhadita": "agasalhado",
    "agasalhaditas": "agasalhado",
    "agasalhadito": "agasalhado",
    "agasalhaditos": "agasalhado",
    "agasalhado": "agasalhar",
    "agasalhadora": "agasalhador",
    "agasalhadoras": "agasalhador",
    "agasalhadores": "agasalhador",
    "agasalhados": "agasalhar",
    "agasalhadíssima": "agasalhado",
    "agasalhadíssimas": "agasalhado",
    "agasalhadíssimo": "agasalhado",
    "agasalhadíssimos": "agasalhado",
    "agasalhai": "agasalhar",
    "agasalhais": "agasalhar",
    "agasalham": "agasalhar",
    "agasalhamo": "agasalhar",
    "agasalhamos": "agasalhar",
    "agasalhando": "agasalhar",
    "agasalhara": "agasalhar",
    "agasalharam": "agasalhar",
    "agasalharas": "agasalhar",
    "agasalharde": "agasalhar",
    "agasalhardes": "agasalhar",
    "agasalhare": "agasalhar",
    "agasalharei": "agasalhar",
    "agasalhareis": "agasalhar",
    "agasalharem": "agasalhar",
    "agasalharemos": "agasalhar",
    "agasalhares": "agasalhar",
    "agasalharia": "agasalhar",
    "agasalhariam": "agasalhar",
    "agasalharias": "agasalhar",
    "agasalharmo": "agasalhar",
    "agasalharmos": "agasalhar",
    "agasalhará": "agasalhar",
    "agasalharás": "agasalhar",
    "agasalharão": "agasalhar",
    "agasalharíamos": "agasalhar",
    "agasalharíeis": "agasalhar",
    "agasalhas": "agasalhar",
    "agasalhasse": "agasalhar",
    "agasalhassem": "agasalhar",
    "agasalhasses": "agasalhar",
    "agasalhaste": "agasalhar",
    "agasalhastes": "agasalhar",
    "agasalhava": "agasalhar",
    "agasalhavam": "agasalhar",
    "agasalhavas": "agasalhar",
    "agasalhe": "agasalhar",
    "agasalhei": "agasalhar",
    "agasalheis": "agasalhar",
    "agasalhem": "agasalhar",
    "agasalhemo": "agasalhar",
    "agasalhemos": "agasalhar",
    "agasalhes": "agasalhar",
    "agasalho": "agasalhar",
    "agasalhos": "agasalho",
    "agasalhou": "agasalhar",
    "agasalhá": "agasalhar",
    "agasalhámo": "agasalhar",
    "agasalhámos": "agasalhar",
    "agasalháramo": "agasalhar",
    "agasalháramos": "agasalhar",
    "agasalhárei": "agasalhar",
    "agasalháreis": "agasalhar",
    "agasalhásseis": "agasalhar",
    "agasalhássemos": "agasalhar",
    "agasalhávamo": "agasalhar",
    "agasalhávamos": "agasalhar",
    "agasalhávei": "agasalhar",
    "agasalháveis": "agasalhar",
    "agasta": "agastar",
    "agastada": "agastar",
    "agastadas": "agastar",
    "agastadiça": "agastadiço",
    "agastadiças": "agastadiço",
    "agastadiços": "agastadiço",
    "agastado": "agastar",
    "agastados": "agastar",
    "agastadíssima": "agastado",
    "agastadíssimas": "agastado",
    "agastadíssimo": "agastado",
    "agastadíssimos": "agastado",
    "agastai": "agastar",
    "agastais": "agastar",
    "agastam": "agastar",
    "agastamentos": "agastamento",
    "agastamo": "agastar",
    "agastamos": "agastar",
    "agastando": "agastar",
    "agastara": "agastar",
    "agastaram": "agastar",
    "agastaras": "agastar",
    "agastarde": "agastar",
    "agastardes": "agastar",
    "agastare": "agastar",
    "agastarei": "agastar",
    "agastareis": "agastar",
    "agastarem": "agastar",
    "agastaremos": "agastar",
    "agastares": "agastar",
    "agastaria": "agastar",
    "agastariam": "agastar",
    "agastarias": "agastar",
    "agastarmo": "agastar",
    "agastarmos": "agastar",
    "agastará": "agastar",
    "agastarás": "agastar",
    "agastarão": "agastar",
    "agastaríamos": "agastar",
    "agastaríeis": "agastar",
    "agastas": "agastar",
    "agastasse": "agastar",
    "agastassem": "agastar",
    "agastasses": "agastar",
    "agastaste": "agastar",
    "agastastes": "agastar",
    "agastava": "agastar",
    "agastavam": "agastar",
    "agastavas": "agastar",
    "agaste": "agastar",
    "agastei": "agastar",
    "agasteis": "agastar",
    "agastem": "agastar",
    "agastemo": "agastar",
    "agastemos": "agastar",
    "agastes": "agastar",
    "agasto": "agastar",
    "agastou": "agastar",
    "agasturas": "agastura",
    "agastá": "agastar",
    "agastámo": "agastar",
    "agastámos": "agastar",
    "agastáramo": "agastar",
    "agastáramos": "agastar",
    "agastárei": "agastar",
    "agastáreis": "agastar",
    "agastásseis": "agastar",
    "agastássemos": "agastar",
    "agastávamo": "agastar",
    "agastávamos": "agastar",
    "agastávei": "agastar",
    "agastáveis": "agastar",
    "agatafunha": "agatafunhar",
    "agatafunhada": "agatafunhar",
    "agatafunhadas": "agatafunhar",
    "agatafunhado": "agatafunhar",
    "agatafunhados": "agatafunhar",
    "agatafunhai": "agatafunhar",
    "agatafunhais": "agatafunhar",
    "agatafunham": "agatafunhar",
    "agatafunhamo": "agatafunhar",
    "agatafunhamos": "agatafunhar",
    "agatafunhando": "agatafunhar",
    "agatafunhara": "agatafunhar",
    "agatafunharam": "agatafunhar",
    "agatafunharas": "agatafunhar",
    "agatafunharde": "agatafunhar",
    "agatafunhardes": "agatafunhar",
    "agatafunhare": "agatafunhar",
    "agatafunharei": "agatafunhar",
    "agatafunhareis": "agatafunhar",
    "agatafunharem": "agatafunhar",
    "agatafunharemos": "agatafunhar",
    "agatafunhares": "agatafunhar",
    "agatafunharia": "agatafunhar",
    "agatafunhariam": "agatafunhar",
    "agatafunharias": "agatafunhar",
    "agatafunharmo": "agatafunhar",
    "agatafunharmos": "agatafunhar",
    "agatafunhará": "agatafunhar",
    "agatafunharás": "agatafunhar",
    "agatafunharão": "agatafunhar",
    "agatafunharíamos": "agatafunhar",
    "agatafunharíeis": "agatafunhar",
    "agatafunhas": "agatafunhar",
    "agatafunhasse": "agatafunhar",
    "agatafunhassem": "agatafunhar",
    "agatafunhasses": "agatafunhar",
    "agatafunhaste": "agatafunhar",
    "agatafunhastes": "agatafunhar",
    "agatafunhava": "agatafunhar",
    "agatafunhavam": "agatafunhar",
    "agatafunhavas": "agatafunhar",
    "agatafunhe": "agatafunhar",
    "agatafunhei": "agatafunhar",
    "agatafunheis": "agatafunhar",
    "agatafunhem": "agatafunhar",
    "agatafunhemo": "agatafunhar",
    "agatafunhemos": "agatafunhar",
    "agatafunhes": "agatafunhar",
    "agatafunho": "agatafunhar",
    "agatafunhou": "agatafunhar",
    "agatafunhá": "agatafunhar",
    "agatafunhámo": "agatafunhar",
    "agatafunhámos": "agatafunhar",
    "agatafunháramo": "agatafunhar",
    "agatafunháramos": "agatafunhar",
    "agatafunhárei": "agatafunhar",
    "agatafunháreis": "agatafunhar",
    "agatafunhásseis": "agatafunhar",
    "agatafunhássemos": "agatafunhar",
    "agatafunhávamo": "agatafunhar",
    "agatafunhávamos": "agatafunhar",
    "agatafunhávei": "agatafunhar",
    "agatafunháveis": "agatafunhar",
    "agatanha": "agatanhar",
    "agatanhada": "agatanhar",
    "agatanhadas": "agatanhar",
    "agatanhado": "agatanhar",
    "agatanhados": "agatanhar",
    "agatanhaduras": "agatanhadura",
    "agatanhai": "agatanhar",
    "agatanhais": "agatanhar",
    "agatanham": "agatanhar",
    "agatanhamo": "agatanhar",
    "agatanhamos": "agatanhar",
    "agatanhando": "agatanhar",
    "agatanhara": "agatanhar",
    "agatanharam": "agatanhar",
    "agatanharas": "agatanhar",
    "agatanharde": "agatanhar",
    "agatanhardes": "agatanhar",
    "agatanhare": "agatanhar",
    "agatanharei": "agatanhar",
    "agatanhareis": "agatanhar",
    "agatanharem": "agatanhar",
    "agatanharemos": "agatanhar",
    "agatanhares": "agatanhar",
    "agatanharia": "agatanhar",
    "agatanhariam": "agatanhar",
    "agatanharias": "agatanhar",
    "agatanharmo": "agatanhar",
    "agatanharmos": "agatanhar",
    "agatanhará": "agatanhar",
    "agatanharás": "agatanhar",
    "agatanharão": "agatanhar",
    "agatanharíamos": "agatanhar",
    "agatanharíeis": "agatanhar",
    "agatanhas": "agatanhar",
    "agatanhasse": "agatanhar",
    "agatanhassem": "agatanhar",
    "agatanhasses": "agatanhar",
    "agatanhaste": "agatanhar",
    "agatanhastes": "agatanhar",
    "agatanhava": "agatanhar",
    "agatanhavam": "agatanhar",
    "agatanhavas": "agatanhar",
    "agatanhe": "agatanhar",
    "agatanhei": "agatanhar",
    "agatanheis": "agatanhar",
    "agatanhem": "agatanhar",
    "agatanhemo": "agatanhar",
    "agatanhemos": "agatanhar",
    "agatanhes": "agatanhar",
    "agatanho": "agatanhar",
    "agatanhou": "agatanhar",
    "agatanhá": "agatanhar",
    "agatanhámo": "agatanhar",
    "agatanhámos": "agatanhar",
    "agatanháramo": "agatanhar",
    "agatanháramos": "agatanhar",
    "agatanhárei": "agatanhar",
    "agatanháreis": "agatanhar",
    "agatanhásseis": "agatanhar",
    "agatanhássemos": "agatanhar",
    "agatanhávamo": "agatanhar",
    "agatanhávamos": "agatanhar",
    "agatanhávei": "agatanhar",
    "agatanháveis": "agatanhar",
    "agatifica": "agatificar",
    "agatificada": "agatificar",
    "agatificadas": "agatificar",
    "agatificado": "agatificar",
    "agatificados": "agatificar",
    "agatificai": "agatificar",
    "agatificais": "agatificar",
    "agatificam": "agatificar",
    "agatificamo": "agatificar",
    "agatificamos": "agatificar",
    "agatificando": "agatificar",
    "agatificara": "agatificar",
    "agatificaram": "agatificar",
    "agatificaras": "agatificar",
    "agatificarde": "agatificar",
    "agatificardes": "agatificar",
    "agatificare": "agatificar",
    "agatificarei": "agatificar",
    "agatificareis": "agatificar",
    "agatificarem": "agatificar",
    "agatificaremos": "agatificar",
    "agatificares": "agatificar",
    "agatificaria": "agatificar",
    "agatificariam": "agatificar",
    "agatificarias": "agatificar",
    "agatificarmo": "agatificar",
    "agatificarmos": "agatificar",
    "agatificará": "agatificar",
    "agatificarás": "agatificar",
    "agatificarão": "agatificar",
    "agatificaríamos": "agatificar",
    "agatificaríeis": "agatificar",
    "agatificas": "agatificar",
    "agatificasse": "agatificar",
    "agatificassem": "agatificar",
    "agatificasses": "agatificar",
    "agatificaste": "agatificar",
    "agatificastes": "agatificar",
    "agatificava": "agatificar",
    "agatificavam": "agatificar",
    "agatificavas": "agatificar",
    "agatifico": "agatificar",
    "agatificou": "agatificar",
    "agatificá": "agatificar",
    "agatificámo": "agatificar",
    "agatificámos": "agatificar",
    "agatificáramo": "agatificar",
    "agatificáramos": "agatificar",
    "agatificárei": "agatificar",
    "agatificáreis": "agatificar",
    "agatificásseis": "agatificar",
    "agatificássemos": "agatificar",
    "agatificávamo": "agatificar",
    "agatificávamos": "agatificar",
    "agatificávei": "agatificar",
    "agatificáveis": "agatificar",
    "agatifique": "agatificar",
    "agatifiquei": "agatificar",
    "agatifiqueis": "agatificar",
    "agatifiquem": "agatificar",
    "agatifiquemo": "agatificar",
    "agatifiquemos": "agatificar",
    "agatifiques": "agatificar",
    "agatunada": "agatunado",
    "agatunadas": "agatunado",
    "agatunados": "agatunado",
    "agatífera": "agatífero",
    "agatíferas": "agatífero",
    "agatíferos": "agatífero",
    "agatóides": "agatóide",
    "agavela": "agavelar",
    "agavelada": "agavelar",
    "agaveladas": "agavelar",
    "agavelado": "agavelar",
    "agavelados": "agavelar",
    "agavelai": "agavelar",
    "agavelais": "agavelar",
    "agavelam": "agavelar",
    "agavelamo": "agavelar",
    "agavelamos": "agavelar",
    "agavelando": "agavelar",
    "agavelara": "agavelar",
    "agavelaram": "agavelar",
    "agavelaras": "agavelar",
    "agavelarde": "agavelar",
    "agavelardes": "agavelar",
    "agavelare": "agavelar",
    "agavelarei": "agavelar",
    "agavelareis": "agavelar",
    "agavelarem": "agavelar",
    "agavelaremos": "agavelar",
    "agavelares": "agavelar",
    "agavelaria": "agavelar",
    "agavelariam": "agavelar",
    "agavelarias": "agavelar",
    "agavelarmo": "agavelar",
    "agavelarmos": "agavelar",
    "agavelará": "agavelar",
    "agavelarás": "agavelar",
    "agavelarão": "agavelar",
    "agavelaríamos": "agavelar",
    "agavelaríeis": "agavelar",
    "agavelas": "agavelar",
    "agavelasse": "agavelar",
    "agavelassem": "agavelar",
    "agavelasses": "agavelar",
    "agavelaste": "agavelar",
    "agavelastes": "agavelar",
    "agavelava": "agavelar",
    "agavelavam": "agavelar",
    "agavelavas": "agavelar",
    "agavele": "agavelar",
    "agavelei": "agavelar",
    "agaveleis": "agavelar",
    "agavelem": "agavelar",
    "agavelemo": "agavelar",
    "agavelemos": "agavelar",
    "agaveles": "agavelar",
    "agavelo": "agavelar",
    "agavelou": "agavelar",
    "agavelá": "agavelar",
    "agavelámo": "agavelar",
    "agavelámos": "agavelar",
    "agaveláramo": "agavelar",
    "agaveláramos": "agavelar",
    "agavelárei": "agavelar",
    "agaveláreis": "agavelar",
    "agavelásseis": "agavelar",
    "agavelássemos": "agavelar",
    "agavelávamo": "agavelar",
    "agavelávamos": "agavelar",
    "agavelávei": "agavelar",
    "agaveláveis": "agavelar",
    "agavácea": "agaváceo",
    "agaváceas": "agaváceo",
    "agaváceos": "agaváceo",
    "agazetada": "agazetado",
    "agazetadas": "agazetado",
    "agazetados": "agazetado",
    "agazua": "agazuar",
    "agazuada": "agazuar",
    "agazuadas": "agazuar",
    "agazuado": "agazuar",
    "agazuados": "agazuar",
    "agazuai": "agazuar",
    "agazuais": "agazuar",
    "agazuam": "agazuar",
    "agazuamo": "agazuar",
    "agazuamos": "agazuar",
    "agazuando": "agazuar",
    "agazuara": "agazuar",
    "agazuaram": "agazuar",
    "agazuaras": "agazuar",
    "agazuarde": "agazuar",
    "agazuardes": "agazuar",
    "agazuare": "agazuar",
    "agazuarei": "agazuar",
    "agazuareis": "agazuar",
    "agazuarem": "agazuar",
    "agazuaremos": "agazuar",
    "agazuares": "agazuar",
    "agazuaria": "agazuar",
    "agazuariam": "agazuar",
    "agazuarias": "agazuar",
    "agazuarmo": "agazuar",
    "agazuarmos": "agazuar",
    "agazuará": "agazuar",
    "agazuarás": "agazuar",
    "agazuarão": "agazuar",
    "agazuaríamos": "agazuar",
    "agazuaríeis": "agazuar",
    "agazuas": "agazuar",
    "agazuasse": "agazuar",
    "agazuassem": "agazuar",
    "agazuasses": "agazuar",
    "agazuaste": "agazuar",
    "agazuastes": "agazuar",
    "agazuava": "agazuar",
    "agazuavam": "agazuar",
    "agazuavas": "agazuar",
    "agazue": "agazuar",
    "agazuei": "agazuar",
    "agazueis": "agazuar",
    "agazuem": "agazuar",
    "agazuemo": "agazuar",
    "agazuemos": "agazuar",
    "agazues": "agazuar",
    "agazuo": "agazuar",
    "agazuou": "agazuar",
    "agazuá": "agazuar",
    "agazuámo": "agazuar",
    "agazuámos": "agazuar",
    "agazuáramo": "agazuar",
    "agazuáramos": "agazuar",
    "agazuárei": "agazuar",
    "agazuáreis": "agazuar",
    "agazuásseis": "agazuar",
    "agazuássemos": "agazuar",
    "agazuávamo": "agazuar",
    "agazuávamos": "agazuar",
    "agazuávei": "agazuar",
    "agazuáveis": "agazuar",
    "age": "agir",
    "agem": "agir",
    "agemada": "agemado",
    "agemadas": "agemado",
    "agemados": "agemado",
    "agenceia": "agenciar",
    "agenceiam": "agenciar",
    "agenceias": "agenciar",
    "agenceie": "agenciar",
    "agenceiem": "agenciar",
    "agenceies": "agenciar",
    "agenceio": "agenciar",
    "agencia": "agenciar",
    "agenciada": "agenciar",
    "agenciadas": "agenciar",
    "agenciadeira": "agenciador",
    "agenciadeiras": "agenciador",
    "agenciadeiros": "agenciadeiro",
    "agenciado": "agenciar",
    "agenciadora": "agenciador",
    "agenciadoras": "agenciador",
    "agenciadores": "agenciador",
    "agenciados": "agenciar",
    "agenciai": "agenciar",
    "agenciais": "agenciar",
    "agenciam": "agenciar",
    "agenciamentos": "agenciamento",
    "agenciamo": "agenciar",
    "agenciamos": "agenciar",
    "agenciando": "agenciar",
    "agenciara": "agenciar",
    "agenciaram": "agenciar",
    "agenciaras": "agenciar",
    "agenciardes": "agenciar",
    "agenciarei": "agenciar",
    "agenciareis": "agenciar",
    "agenciarem": "agenciar",
    "agenciaremos": "agenciar",
    "agenciares": "agenciar",
    "agenciaria": "agenciar",
    "agenciariam": "agenciar",
    "agenciarias": "agenciar",
    "agenciarmo": "agenciar",
    "agenciarmos": "agenciar",
    "agenciará": "agenciar",
    "agenciarás": "agenciar",
    "agenciarão": "agenciar",
    "agenciaríamos": "agenciar",
    "agenciaríeis": "agenciar",
    "agencias": "agenciar",
    "agenciasse": "agenciar",
    "agenciassem": "agenciar",
    "agenciasses": "agenciar",
    "agenciaste": "agenciar",
    "agenciastes": "agenciar",
    "agenciava": "agenciar",
    "agenciavam": "agenciar",
    "agenciavas": "agenciar",
    "agenciações": "agenciação",
    "agencie": "agenciar",
    "agenciei": "agenciar",
    "agencieis": "agenciar",
    "agenciem": "agenciar",
    "agenciemo": "agenciar",
    "agenciemos": "agenciar",
    "agencies": "agenciar",
    "agencio": "agenciar",
    "agenciosa": "agencioso",
    "agenciosas": "agencioso",
    "agenciosos": "agencioso",
    "agenciou": "agenciar",
    "agenciámo": "agenciar",
    "agenciámos": "agenciar",
    "agenciáramo": "agenciar",
    "agenciáramos": "agenciar",
    "agenciáreis": "agenciar",
    "agenciária": "agenciário",
    "agenciárias": "agenciário",
    "agenciários": "agenciário",
    "agenciásseis": "agenciar",
    "agenciássemos": "agenciar",
    "agenciávamo": "agenciar",
    "agenciávamos": "agenciar",
    "agenciáveis": "agenciar",
    "agenda": "agendar",
    "agendada": "agendar",
    "agendadas": "agendar",
    "agendado": "agendar",
    "agendados": "agendar",
    "agendai": "agendar",
    "agendais": "agendar",
    "agendam": "agendar",
    "agendamentos": "agendamento",
    "agendamo": "agendar",
    "agendamos": "agendar",
    "agendando": "agendar",
    "agendara": "agendar",
    "agendaram": "agendar",
    "agendaras": "agendar",
    "agendarde": "agendar",
    "agendardes": "agendar",
    "agendare": "agendar",
    "agendarei": "agendar",
    "agendareis": "agendar",
    "agendarem": "agendar",
    "agendaremos": "agendar",
    "agendares": "agendar",
    "agendaria": "agendar",
    "agendariam": "agendar",
    "agendarias": "agendar",
    "agendarmo": "agendar",
    "agendarmos": "agendar",
    "agendará": "agendar",
    "agendarás": "agendar",
    "agendarão": "agendar",
    "agendaríamos": "agendar",
    "agendaríeis": "agendar",
    "agendas": "agendar",
    "agendasse": "agendar",
    "agendassem": "agendar",
    "agendasses": "agendar",
    "agendaste": "agendar",
    "agendastes": "agendar",
    "agendava": "agendar",
    "agendavam": "agendar",
    "agendavas": "agendar",
    "agende": "agendar",
    "agendei": "agendar",
    "agendeis": "agendar",
    "agendem": "agendar",
    "agendemo": "agendar",
    "agendemos": "agendar",
    "agendes": "agendar",
    "agendinha": "agenda",
    "agendinhas": "agenda",
    "agendita": "agenda",
    "agenditas": "agenda",
    "agendo": "agendar",
    "agendou": "agendar",
    "agendá": "agendar",
    "agendámo": "agendar",
    "agendámos": "agendar",
    "agendáramo": "agendar",
    "agendáramos": "agendar",
    "agendárei": "agendar",
    "agendáreis": "agendar",
    "agendásseis": "agendar",
    "agendássemos": "agendar",
    "agendávamo": "agendar",
    "agendávamos": "agendar",
    "agendávei": "agendar",
    "agendáveis": "agendar",
    "agenesias": "agenesia",
    "agengibra": "agengibrar",
    "agengibrada": "agengibrar",
    "agengibradas": "agengibrar",
    "agengibrado": "agengibrar",
    "agengibrados": "agengibrar",
    "agengibrai": "agengibrar",
    "agengibrais": "agengibrar",
    "agengibram": "agengibrar",
    "agengibramo": "agengibrar",
    "agengibramos": "agengibrar",
    "agengibrando": "agengibrar",
    "agengibrara": "agengibrar",
    "agengibraram": "agengibrar",
    "agengibraras": "agengibrar",
    "agengibrarde": "agengibrar",
    "agengibrardes": "agengibrar",
    "agengibrare": "agengibrar",
    "agengibrarei": "agengibrar",
    "agengibrareis": "agengibrar",
    "agengibrarem": "agengibrar",
    "agengibraremos": "agengibrar",
    "agengibrares": "agengibrar",
    "agengibraria": "agengibrar",
    "agengibrariam": "agengibrar",
    "agengibrarias": "agengibrar",
    "agengibrarmo": "agengibrar",
    "agengibrarmos": "agengibrar",
    "agengibrará": "agengibrar",
    "agengibrarás": "agengibrar",
    "agengibrarão": "agengibrar",
    "agengibraríamos": "agengibrar",
    "agengibraríeis": "agengibrar",
    "agengibras": "agengibrar",
    "agengibrasse": "agengibrar",
    "agengibrassem": "agengibrar",
    "agengibrasses": "agengibrar",
    "agengibraste": "agengibrar",
    "agengibrastes": "agengibrar",
    "agengibrava": "agengibrar",
    "agengibravam": "agengibrar",
    "agengibravas": "agengibrar",
    "agengibre": "agengibrar",
    "agengibrei": "agengibrar",
    "agengibreis": "agengibrar",
    "agengibrem": "agengibrar",
    "agengibremo": "agengibrar",
    "agengibremos": "agengibrar",
    "agengibres": "agengibrar",
    "agengibro": "agengibrar",
    "agengibrou": "agengibrar",
    "agengibrá": "agengibrar",
    "agengibrámo": "agengibrar",
    "agengibrámos": "agengibrar",
    "agengibráramo": "agengibrar",
    "agengibráramos": "agengibrar",
    "agengibrárei": "agengibrar",
    "agengibráreis": "agengibrar",
    "agengibrásseis": "agengibrar",
    "agengibrássemos": "agengibrar",
    "agengibrávamo": "agengibrar",
    "agengibrávamos": "agengibrar",
    "agengibrávei": "agengibrar",
    "agengibráveis": "agengibrar",
    "agentes": "agente",
    "agenésica": "agenésico",
    "agenésicas": "agenésico",
    "agenésicos": "agenésico",
    "ageometreosias": "ageometreosia",
    "agerasias": "agerasia",
    "agermana": "agermanar",
    "agermanada": "agermanar",
    "agermanadas": "agermanar",
    "agermanado": "agermanar",
    "agermanados": "agermanar",
    "agermanai": "agermanar",
    "agermanais": "agermanar",
    "agermanam": "agermanar",
    "agermanamo": "agermanar",
    "agermanamos": "agermanar",
    "agermanando": "agermanar",
    "agermanara": "agermanar",
    "agermanaram": "agermanar",
    "agermanaras": "agermanar",
    "agermanarde": "agermanar",
    "agermanardes": "agermanar",
    "agermanare": "agermanar",
    "agermanarei": "agermanar",
    "agermanareis": "agermanar",
    "agermanarem": "agermanar",
    "agermanaremos": "agermanar",
    "agermanares": "agermanar",
    "agermanaria": "agermanar",
    "agermanariam": "agermanar",
    "agermanarias": "agermanar",
    "agermanarmo": "agermanar",
    "agermanarmos": "agermanar",
    "agermanará": "agermanar",
    "agermanarás": "agermanar",
    "agermanarão": "agermanar",
    "agermanaríamos": "agermanar",
    "agermanaríeis": "agermanar",
    "agermanas": "agermanar",
    "agermanasse": "agermanar",
    "agermanassem": "agermanar",
    "agermanasses": "agermanar",
    "agermanaste": "agermanar",
    "agermanastes": "agermanar",
    "agermanava": "agermanar",
    "agermanavam": "agermanar",
    "agermanavas": "agermanar",
    "agermane": "agermanar",
    "agermanei": "agermanar",
    "agermaneis": "agermanar",
    "agermanem": "agermanar",
    "agermanemo": "agermanar",
    "agermanemos": "agermanar",
    "agermanes": "agermanar",
    "agermano": "agermanar",
    "agermanou": "agermanar",
    "agermaná": "agermanar",
    "agermanámo": "agermanar",
    "agermanámos": "agermanar",
    "agermanáramo": "agermanar",
    "agermanáramos": "agermanar",
    "agermanárei": "agermanar",
    "agermanáreis": "agermanar",
    "agermanásseis": "agermanar",
    "agermanássemos": "agermanar",
    "agermanávamo": "agermanar",
    "agermanávamos": "agermanar",
    "agermanávei": "agermanar",
    "agermanáveis": "agermanável",
    "agerásica": "agerásico",
    "agerásicas": "agerásico",
    "agerásicos": "agerásico",
    "ages": "agir",
    "ageusias": "ageusia",
    "ageustias": "ageustia",
    "agi": "agir",
    "agia": "agir",
    "agiam": "agir",
    "agias": "agir",
    "agida": "agir",
    "agidas": "agir",
    "agido": "agir",
    "agidos": "agir",
    "agiganta": "agigantar",
    "agigantada": "agigantar",
    "agigantadas": "agigantar",
    "agigantado": "agigantar",
    "agigantados": "agigantar",
    "agigantai": "agigantar",
    "agigantais": "agigantar",
    "agigantam": "agigantar",
    "agigantamentos": "agigantamento",
    "agigantamo": "agigantar",
    "agigantamos": "agigantar",
    "agigantando": "agigantar",
    "agigantara": "agigantar",
    "agigantaram": "agigantar",
    "agigantaras": "agigantar",
    "agigantarde": "agigantar",
    "agigantardes": "agigantar",
    "agigantare": "agigantar",
    "agigantarei": "agigantar",
    "agigantareis": "agigantar",
    "agigantarem": "agigantar",
    "agigantaremos": "agigantar",
    "agigantares": "agigantar",
    "agigantaria": "agigantar",
    "agigantariam": "agigantar",
    "agigantarias": "agigantar",
    "agigantarmo": "agigantar",
    "agigantarmos": "agigantar",
    "agigantará": "agigantar",
    "agigantarás": "agigantar",
    "agigantarão": "agigantar",
    "agigantaríamos": "agigantar",
    "agigantaríeis": "agigantar",
    "agigantas": "agigantar",
    "agigantasse": "agigantar",
    "agigantassem": "agigantar",
    "agigantasses": "agigantar",
    "agigantaste": "agigantar",
    "agigantastes": "agigantar",
    "agigantava": "agigantar",
    "agigantavam": "agigantar",
    "agigantavas": "agigantar",
    "agigante": "agigantar",
    "agigantei": "agigantar",
    "agiganteis": "agigantar",
    "agigantem": "agigantar",
    "agigantemo": "agigantar",
    "agigantemos": "agigantar",
    "agigantes": "agigantar",
    "agiganto": "agigantar",
    "agigantou": "agigantar",
    "agigantá": "agigantar",
    "agigantámo": "agigantar",
    "agigantámos": "agigantar",
    "agigantáramo": "agigantar",
    "agigantáramos": "agigantar",
    "agigantárei": "agigantar",
    "agigantáreis": "agigantar",
    "agigantásseis": "agigantar",
    "agigantássemos": "agigantar",
    "agigantávamo": "agigantar",
    "agigantávamos": "agigantar",
    "agigantávei": "agigantar",
    "agigantáveis": "agigantar",
    "agilidades": "agilidade",
    "agilita": "agilitar",
    "agilitada": "agilitar",
    "agilitadas": "agilitar",
    "agilitado": "agilitar",
    "agilitados": "agilitar",
    "agilitai": "agilitar",
    "agilitais": "agilitar",
    "agilitam": "agilitar",
    "agilitamo": "agilitar",
    "agilitamos": "agilitar",
    "agilitando": "agilitar",
    "agilitara": "agilitar",
    "agilitaram": "agilitar",
    "agilitaras": "agilitar",
    "agilitarde": "agilitar",
    "agilitardes": "agilitar",
    "agilitare": "agilitar",
    "agilitarei": "agilitar",
    "agilitareis": "agilitar",
    "agilitarem": "agilitar",
    "agilitaremos": "agilitar",
    "agilitares": "agilitar",
    "agilitaria": "agilitar",
    "agilitariam": "agilitar",
    "agilitarias": "agilitar",
    "agilitarmo": "agilitar",
    "agilitarmos": "agilitar",
    "agilitará": "agilitar",
    "agilitarás": "agilitar",
    "agilitarão": "agilitar",
    "agilitaríamos": "agilitar",
    "agilitaríeis": "agilitar",
    "agilitas": "agilitar",
    "agilitasse": "agilitar",
    "agilitassem": "agilitar",
    "agilitasses": "agilitar",
    "agilitaste": "agilitar",
    "agilitastes": "agilitar",
    "agilitava": "agilitar",
    "agilitavam": "agilitar",
    "agilitavas": "agilitar",
    "agilite": "agilitar",
    "agilitei": "agilitar",
    "agiliteis": "agilitar",
    "agilitem": "agilitar",
    "agilitemo": "agilitar",
    "agilitemos": "agilitar",
    "agilites": "agilitar",
    "agilito": "agilitar",
    "agilitou": "agilitar",
    "agilitá": "agilitar",
    "agilitámo": "agilitar",
    "agilitámos": "agilitar",
    "agilitáramo": "agilitar",
    "agilitáramos": "agilitar",
    "agilitárei": "agilitar",
    "agilitáreis": "agilitar",
    "agilitásseis": "agilitar",
    "agilitássemos": "agilitar",
    "agilitávamo": "agilitar",
    "agilitávamos": "agilitar",
    "agilitávei": "agilitar",
    "agilitáveis": "agilitar",
    "agiliza": "agilizar",
    "agilizada": "agilizar",
    "agilizadas": "agilizar",
    "agilizado": "agilizar",
    "agilizados": "agilizar",
    "agilizai": "agilizar",
    "agilizais": "agilizar",
    "agilizam": "agilizar",
    "agilizamo": "agilizar",
    "agilizamos": "agilizar",
    "agilizando": "agilizar",
    "agilizara": "agilizar",
    "agilizaram": "agilizar",
    "agilizaras": "agilizar",
    "agilizarde": "agilizar",
    "agilizardes": "agilizar",
    "agilizare": "agilizar",
    "agilizarei": "agilizar",
    "agilizareis": "agilizar",
    "agilizarem": "agilizar",
    "agilizaremos": "agilizar",
    "agilizares": "agilizar",
    "agilizaria": "agilizar",
    "agilizariam": "agilizar",
    "agilizarias": "agilizar",
    "agilizarmo": "agilizar",
    "agilizarmos": "agilizar",
    "agilizará": "agilizar",
    "agilizarás": "agilizar",
    "agilizarão": "agilizar",
    "agilizaríamos": "agilizar",
    "agilizaríeis": "agilizar",
    "agilizas": "agilizar",
    "agilizasse": "agilizar",
    "agilizassem": "agilizar",
    "agilizasses": "agilizar",
    "agilizaste": "agilizar",
    "agilizastes": "agilizar",
    "agilizava": "agilizar",
    "agilizavam": "agilizar",
    "agilizavas": "agilizar",
    "agilize": "agilizar",
    "agilizei": "agilizar",
    "agilizeis": "agilizar",
    "agilizem": "agilizar",
    "agilizemo": "agilizar",
    "agilizemos": "agilizar",
    "agilizes": "agilizar",
    "agilizo": "agilizar",
    "agilizou": "agilizar",
    "agilizá": "agilizar",
    "agilizámo": "agilizar",
    "agilizámos": "agilizar",
    "agilizáramo": "agilizar",
    "agilizáramos": "agilizar",
    "agilizárei": "agilizar",
    "agilizáreis": "agilizar",
    "agilizásseis": "agilizar",
    "agilizássemos": "agilizar",
    "agilizávamo": "agilizar",
    "agilizávamos": "agilizar",
    "agilizávei": "agilizar",
    "agilizáveis": "agilizar",
    "agilíssima": "ágil",
    "agilíssimas": "ágil",
    "agilíssimo": "ágil",
    "agilíssimos": "ágil",
    "agimo": "agir",
    "agimos": "agir",
    "agindo": "agir",
    "aginias": "aginia",
    "agiota": "agiotar",
    "agiotada": "agiotar",
    "agiotadas": "agiotar",
    "agiotado": "agiotar",
    "agiotados": "agiotar",
    "agiotagens": "agiotagem",
    "agiotai": "agiotar",
    "agiotais": "agiotar",
    "agiotam": "agiotar",
    "agiotamo": "agiotar",
    "agiotamos": "agiotar",
    "agiotando": "agiotar",
    "agiotara": "agiotar",
    "agiotaram": "agiotar",
    "agiotaras": "agiotar",
    "agiotardes": "agiotar",
    "agiotarei": "agiotar",
    "agiotareis": "agiotar",
    "agiotarem": "agiotar",
    "agiotaremos": "agiotar",
    "agiotares": "agiotar",
    "agiotaria": "agiotar",
    "agiotariam": "agiotar",
    "agiotarias": "agiotar",
    "agiotarmo": "agiotar",
    "agiotarmos": "agiotar",
    "agiotará": "agiotar",
    "agiotarás": "agiotar",
    "agiotarão": "agiotar",
    "agiotaríamos": "agiotar",
    "agiotaríeis": "agiotar",
    "agiotas": "agiotar",
    "agiotasse": "agiotar",
    "agiotassem": "agiotar",
    "agiotasses": "agiotar",
    "agiotaste": "agiotar",
    "agiotastes": "agiotar",
    "agiotava": "agiotar",
    "agiotavam": "agiotar",
    "agiotavas": "agiotar",
    "agiote": "agiotar",
    "agiotei": "agiotar",
    "agioteis": "agiotar",
    "agiotem": "agiotar",
    "agiotemo": "agiotar",
    "agiotemos": "agiotar",
    "agiotes": "agiotar",
    "agioto": "agiotar",
    "agiotou": "agiotar",
    "agiotámo": "agiotar",
    "agiotámos": "agiotar",
    "agiotáramo": "agiotar",
    "agiotáramos": "agiotar",
    "agiotáreis": "agiotar",
    "agiotásseis": "agiotar",
    "agiotássemos": "agiotar",
    "agiotávamo": "agiotar",
    "agiotávamos": "agiotar",
    "agiotáveis": "agiotar",
    "agira": "agir",
    "agirafada": "agirafado",
    "agirafadas": "agirafado",
    "agirafados": "agirafado",
    "agiram": "agir",
    "agiras": "agir",
    "agirdes": "agir",
    "agirei": "agir",
    "agireis": "agir",
    "agirem": "agir",
    "agiremos": "agir",
    "agires": "agir",
    "agiria": "agir",
    "agiriam": "agir",
    "agirias": "agir",
    "agirmo": "agir",
    "agirmos": "agir",
    "agirá": "agir",
    "agirás": "agir",
    "agirão": "agir",
    "agiríamos": "agir",
    "agiríeis": "agir",
    "agis": "agir",
    "agisse": "agir",
    "agissem": "agir",
    "agisses": "agir",
    "agiste": "agir",
    "agistes": "agir",
    "agita": "agitar",
    "agitabilidades": "agitabilidade",
    "agitada": "agitar",
    "agitadas": "agitar",
    "agitadinha": "agitado",
    "agitadinhas": "agitado",
    "agitadinho": "agitado",
    "agitadinhos": "agitado",
    "agitadita": "agitado",
    "agitaditas": "agitado",
    "agitadito": "agitado",
    "agitaditos": "agitado",
    "agitadiça": "agitadiço",
    "agitadiças": "agitadiço",
    "agitadiços": "agitadiço",
    "agitado": "agitar",
    "agitadora": "agitador",
    "agitadoras": "agitador",
    "agitadores": "agitador",
    "agitados": "agitar",
    "agitadíssima": "agitado",
    "agitadíssimas": "agitado",
    "agitadíssimo": "agitado",
    "agitadíssimos": "agitado",
    "agitai": "agitar",
    "agitais": "agitar",
    "agitam": "agitar",
    "agitamentos": "agitamento",
    "agitamo": "agitar",
    "agitamos": "agitar",
    "agitando": "agitar",
    "agitara": "agitar",
    "agitaram": "agitar",
    "agitaras": "agitar",
    "agitarde": "agitar",
    "agitardes": "agitar",
    "agitare": "agitar",
    "agitarei": "agitar",
    "agitareis": "agitar",
    "agitarem": "agitar",
    "agitaremos": "agitar",
    "agitares": "agitar",
    "agitaria": "agitar",
    "agitariam": "agitar",
    "agitarias": "agitar",
    "agitarmo": "agitar",
    "agitarmos": "agitar",
    "agitará": "agitar",
    "agitarás": "agitar",
    "agitarão": "agitar",
    "agitaríamos": "agitar",
    "agitaríeis": "agitar",
    "agitas": "agitar",
    "agitasse": "agitar",
    "agitassem": "agitar",
    "agitasses": "agitar",
    "agitaste": "agitar",
    "agitastes": "agitar",
    "agitava": "agitar",
    "agitavam": "agitar",
    "agitavas": "agitar",
    "agitações": "agitação",
    "agite": "agitar",
    "agitei": "agitar",
    "agiteis": "agitar",
    "agitem": "agitar",
    "agitemo": "agitar",
    "agitemos": "agitar",
    "agites": "agitar",
    "agito": "agitar",
    "agitos": "agito",
    "agitou": "agitar",
    "agitá": "agitar",
    "agitámo": "agitar",
    "agitámos": "agitar",
    "agitáramo": "agitar",
    "agitáramos": "agitar",
    "agitárei": "agitar",
    "agitáreis": "agitar",
    "agitásseis": "agitar",
    "agitássemos": "agitar",
    "agitávamo": "agitar",
    "agitávamos": "agitar",
    "agitávei": "agitar",
    "agitáveis": "agitável",
    "agiu": "agir",
    "aglobulias": "aglobulia",
    "aglomera": "aglomerar",
    "aglomerada": "aglomerar",
    "aglomeradas": "aglomerar",
    "aglomerado": "aglomerar",
    "aglomerados": "aglomerar",
    "aglomerai": "aglomerar",
    "aglomerais": "aglomerar",
    "aglomeram": "aglomerar",
    "aglomeramo": "aglomerar",
    "aglomeramos": "aglomerar",
    "aglomerando": "aglomerar",
    "aglomerara": "aglomerar",
    "aglomeraram": "aglomerar",
    "aglomeraras": "aglomerar",
    "aglomerarde": "aglomerar",
    "aglomerardes": "aglomerar",
    "aglomerare": "aglomerar",
    "aglomerarei": "aglomerar",
    "aglomerareis": "aglomerar",
    "aglomerarem": "aglomerar",
    "aglomeraremos": "aglomerar",
    "aglomerares": "aglomerar",
    "aglomeraria": "aglomerar",
    "aglomerariam": "aglomerar",
    "aglomerarias": "aglomerar",
    "aglomerarmo": "aglomerar",
    "aglomerarmos": "aglomerar",
    "aglomerará": "aglomerar",
    "aglomerarás": "aglomerar",
    "aglomerarão": "aglomerar",
    "aglomeraríamos": "aglomerar",
    "aglomeraríeis": "aglomerar",
    "aglomeras": "aglomerar",
    "aglomerasse": "aglomerar",
    "aglomerassem": "aglomerar",
    "aglomerasses": "aglomerar",
    "aglomeraste": "aglomerar",
    "aglomerastes": "aglomerar",
    "aglomerava": "aglomerar",
    "aglomeravam": "aglomerar",
    "aglomeravas": "aglomerar",
    "aglomerações": "aglomeração",
    "aglomere": "aglomerar",
    "aglomerei": "aglomerar",
    "aglomereis": "aglomerar",
    "aglomerem": "aglomerar",
    "aglomeremo": "aglomerar",
    "aglomeremos": "aglomerar",
    "aglomeres": "aglomerar",
    "aglomero": "aglomerar",
    "aglomerou": "aglomerar",
    "aglomerá": "aglomerar",
    "aglomerámo": "aglomerar",
    "aglomerámos": "aglomerar",
    "aglomeráramo": "aglomerar",
    "aglomeráramos": "aglomerar",
    "aglomerárei": "aglomerar",
    "aglomeráreis": "aglomerar",
    "aglomerásseis": "aglomerar",
    "aglomerássemos": "aglomerar",
    "aglomerávamo": "aglomerar",
    "aglomerávamos": "aglomerar",
    "aglomerávei": "aglomerar",
    "aglomeráveis": "aglomerar",
    "aglossa": "aglosso",
    "aglossas": "aglosso",
    "aglossias": "aglossia",
    "aglossos": "aglosso",
    "aglutina": "aglutinar",
    "aglutinabilidades": "aglutinabilidade",
    "aglutinada": "aglutinar",
    "aglutinadas": "aglutinar",
    "aglutinado": "aglutinar",
    "aglutinadora": "aglutinador",
    "aglutinadoras": "aglutinador",
    "aglutinadores": "aglutinador",
    "aglutinados": "aglutinar",
    "aglutinadíssima": "aglutinado",
    "aglutinadíssimas": "aglutinado",
    "aglutinadíssimo": "aglutinado",
    "aglutinadíssimos": "aglutinado",
    "aglutinai": "aglutinar",
    "aglutinais": "aglutinar",
    "aglutinam": "aglutinar",
    "aglutinamentos": "aglutinamento",
    "aglutinamo": "aglutinar",
    "aglutinamos": "aglutinar",
    "aglutinando": "aglutinar",
    "aglutinantes": "aglutinante",
    "aglutinara": "aglutinar",
    "aglutinaram": "aglutinar",
    "aglutinaras": "aglutinar",
    "aglutinarde": "aglutinar",
    "aglutinardes": "aglutinar",
    "aglutinare": "aglutinar",
    "aglutinarei": "aglutinar",
    "aglutinareis": "aglutinar",
    "aglutinarem": "aglutinar",
    "aglutinaremos": "aglutinar",
    "aglutinares": "aglutinar",
    "aglutinaria": "aglutinar",
    "aglutinariam": "aglutinar",
    "aglutinarias": "aglutinar",
    "aglutinarmo": "aglutinar",
    "aglutinarmos": "aglutinar",
    "aglutinará": "aglutinar",
    "aglutinarás": "aglutinar",
    "aglutinarão": "aglutinar",
    "aglutinaríamos": "aglutinar",
    "aglutinaríeis": "aglutinar",
    "aglutinas": "aglutinar",
    "aglutinasse": "aglutinar",
    "aglutinassem": "aglutinar",
    "aglutinasses": "aglutinar",
    "aglutinaste": "aglutinar",
    "aglutinastes": "aglutinar",
    "aglutinativa": "aglutinativo",
    "aglutinativas": "aglutinativo",
    "aglutinativos": "aglutinativo",
    "aglutinava": "aglutinar",
    "aglutinavam": "aglutinar",
    "aglutinavas": "aglutinar",
    "aglutinações": "aglutinação",
    "aglutine": "aglutinar",
    "aglutinei": "aglutinar",
    "aglutineis": "aglutinar",
    "aglutinem": "aglutinar",
    "aglutinemo": "aglutinar",
    "aglutinemos": "aglutinar",
    "aglutines": "aglutinar",
    "aglutininas": "aglutinina",
    "aglutino": "aglutinar",
    "aglutinou": "aglutinar",
    "aglutiná": "aglutinar",
    "aglutinámo": "aglutinar",
    "aglutinámos": "aglutinar",
    "aglutináramo": "aglutinar",
    "aglutináramos": "aglutinar",
    "aglutinárei": "aglutinar",
    "aglutináreis": "aglutinar",
    "aglutinásseis": "aglutinar",
    "aglutinássemos": "aglutinar",
    "aglutinávamo": "aglutinar",
    "aglutinávamos": "aglutinar",
    "aglutinávei": "aglutinar",
    "aglutináveis": "aglutinável",
    "aglutições": "aglutição",
    "agmas": "agma",
    "agmatologias": "agmatologia",
    "agnada": "agnado",
    "agnadas": "agnado",
    "agnados": "agnado",
    "agnata": "agnato",
    "agnatas": "agnato",
    "agnatias": "agnatia",
    "agnatos": "agnato",
    "agnatícia": "agnatício",
    "agnatícias": "agnatício",
    "agnatícios": "agnatício",
    "agnatóstomos": "agnatóstomo",
    "agnações": "agnação",
    "agnelina": "agnelino",
    "agnelinas": "agnelino",
    "agnelinos": "agnelino",
    "agnições": "agnição",
    "agnocaustos": "agnocausto",
    "agnomes": "agnome",
    "agnominações": "agnominação",
    "agnosias": "agnosia",
    "agnosticismos": "agnosticismo",
    "agnosticistas": "agnosticista",
    "agnotozóica": "agnotozóico",
    "agnotozóicas": "agnotozóico",
    "agnotozóicos": "agnotozóico",
    "agnóstica": "agnóstico",
    "agnósticas": "agnóstico",
    "agnósticos": "agnóstico",
    "agogôs": "agogô",
    "agoira": "agoirar",
    "agoirada": "agoirar",
    "agoiradas": "agoirar",
    "agoirado": "agoirar",
    "agoirados": "agoirar",
    "agoirai": "agoirar",
    "agoirais": "agoirar",
    "agoiram": "agoirar",
    "agoiramo": "agoirar",
    "agoiramos": "agoirar",
    "agoirando": "agoirar",
    "agoirara": "agoirar",
    "agoiraram": "agoirar",
    "agoiraras": "agoirar",
    "agoirarde": "agoirar",
    "agoirardes": "agoirar",
    "agoirare": "agoirar",
    "agoirarei": "agoirar",
    "agoirareis": "agoirar",
    "agoirarem": "agoirar",
    "agoiraremos": "agoirar",
    "agoirares": "agoirar",
    "agoiraria": "agoirar",
    "agoirariam": "agoirar",
    "agoirarias": "agoirar",
    "agoirarmo": "agoirar",
    "agoirarmos": "agoirar",
    "agoirará": "agoirar",
    "agoirarás": "agoirar",
    "agoirarão": "agoirar",
    "agoiraríamos": "agoirar",
    "agoiraríeis": "agoirar",
    "agoiras": "agoirar",
    "agoirasse": "agoirar",
    "agoirassem": "agoirar",
    "agoirasses": "agoirar",
    "agoiraste": "agoirar",
    "agoirastes": "agoirar",
    "agoirava": "agoirar",
    "agoiravam": "agoirar",
    "agoiravas": "agoirar",
    "agoire": "agoirar",
    "agoirei": "agoirar",
    "agoireira": "agoireiro",
    "agoireiras": "agoireiro",
    "agoireiros": "agoireiro",
    "agoireis": "agoirar",
    "agoirem": "agoirar",
    "agoiremo": "agoirar",
    "agoiremos": "agoirar",
    "agoirenta": "agoirento",
    "agoirentada": "agoirentar",
    "agoirentadas": "agoirentar",
    "agoirentado": "agoirentar",
    "agoirentados": "agoirentar",
    "agoirentai": "agoirentar",
    "agoirentais": "agoirentar",
    "agoirentam": "agoirentar",
    "agoirentamo": "agoirentar",
    "agoirentamos": "agoirentar",
    "agoirentando": "agoirentar",
    "agoirentara": "agoirentar",
    "agoirentaram": "agoirentar",
    "agoirentaras": "agoirentar",
    "agoirentarde": "agoirentar",
    "agoirentardes": "agoirentar",
    "agoirentare": "agoirentar",
    "agoirentarei": "agoirentar",
    "agoirentareis": "agoirentar",
    "agoirentarem": "agoirentar",
    "agoirentaremos": "agoirentar",
    "agoirentares": "agoirentar",
    "agoirentaria": "agoirentar",
    "agoirentariam": "agoirentar",
    "agoirentarias": "agoirentar",
    "agoirentarmo": "agoirentar",
    "agoirentarmos": "agoirentar",
    "agoirentará": "agoirentar",
    "agoirentarás": "agoirentar",
    "agoirentarão": "agoirentar",
    "agoirentaríamos": "agoirentar",
    "agoirentaríeis": "agoirentar",
    "agoirentas": "agoirento",
    "agoirentasse": "agoirentar",
    "agoirentassem": "agoirentar",
    "agoirentasses": "agoirentar",
    "agoirentaste": "agoirentar",
    "agoirentastes": "agoirentar",
    "agoirentava": "agoirentar",
    "agoirentavam": "agoirentar",
    "agoirentavas": "agoirentar",
    "agoirente": "agoirentar",
    "agoirentei": "agoirentar",
    "agoirenteis": "agoirentar",
    "agoirentem": "agoirentar",
    "agoirentemo": "agoirentar",
    "agoirentemos": "agoirentar",
    "agoirentes": "agoirentar",
    "agoirento": "agoirentar",
    "agoirentos": "agoirento",
    "agoirentou": "agoirentar",
    "agoirentá": "agoirentar",
    "agoirentámo": "agoirentar",
    "agoirentámos": "agoirentar",
    "agoirentáramo": "agoirentar",
    "agoirentáramos": "agoirentar",
    "agoirentárei": "agoirentar",
    "agoirentáreis": "agoirentar",
    "agoirentásseis": "agoirentar",
    "agoirentássemos": "agoirentar",
    "agoirentávamo": "agoirentar",
    "agoirentávamos": "agoirentar",
    "agoirentávei": "agoirentar",
    "agoirentáveis": "agoirentar",
    "agoires": "agoirar",
    "agoiro": "agoirar",
    "agoiros": "agoiro",
    "agoirou": "agoirar",
    "agoirá": "agoirar",
    "agoirámo": "agoirar",
    "agoirámos": "agoirar",
    "agoiráramo": "agoirar",
    "agoiráramos": "agoirar",
    "agoirárei": "agoirar",
    "agoiráreis": "agoirar",
    "agoirásseis": "agoirar",
    "agoirássemos": "agoirar",
    "agoirávamo": "agoirar",
    "agoirávamos": "agoirar",
    "agoirávei": "agoirar",
    "agoiráveis": "agoirar",
    "agolfinhada": "agolfinhado",
    "agolfinhadas": "agolfinhado",
    "agolfinhados": "agolfinhado",
    "agolpeada": "agolpear",
    "agolpeadas": "agolpear",
    "agolpeado": "agolpear",
    "agolpeados": "agolpear",
    "agolpeai": "agolpear",
    "agolpeais": "agolpear",
    "agolpeamo": "agolpear",
    "agolpeamos": "agolpear",
    "agolpeando": "agolpear",
    "agolpeara": "agolpear",
    "agolpearam": "agolpear",
    "agolpearas": "agolpear",
    "agolpearde": "agolpear",
    "agolpeardes": "agolpear",
    "agolpeare": "agolpear",
    "agolpearei": "agolpear",
    "agolpeareis": "agolpear",
    "agolpearem": "agolpear",
    "agolpearemos": "agolpear",
    "agolpeares": "agolpear",
    "agolpearia": "agolpear",
    "agolpeariam": "agolpear",
    "agolpearias": "agolpear",
    "agolpearmo": "agolpear",
    "agolpearmos": "agolpear",
    "agolpeará": "agolpear",
    "agolpearás": "agolpear",
    "agolpearão": "agolpear",
    "agolpearíamos": "agolpear",
    "agolpearíeis": "agolpear",
    "agolpeasse": "agolpear",
    "agolpeassem": "agolpear",
    "agolpeasses": "agolpear",
    "agolpeaste": "agolpear",
    "agolpeastes": "agolpear",
    "agolpeava": "agolpear",
    "agolpeavam": "agolpear",
    "agolpeavas": "agolpear",
    "agolpeei": "agolpear",
    "agolpeeis": "agolpear",
    "agolpeemo": "agolpear",
    "agolpeemos": "agolpear",
    "agolpeia": "agolpear",
    "agolpeiam": "agolpear",
    "agolpeias": "agolpear",
    "agolpeie": "agolpear",
    "agolpeiem": "agolpear",
    "agolpeies": "agolpear",
    "agolpeio": "agolpear",
    "agolpeou": "agolpear",
    "agolpeá": "agolpear",
    "agolpeámo": "agolpear",
    "agolpeámos": "agolpear",
    "agolpeáramo": "agolpear",
    "agolpeáramos": "agolpear",
    "agolpeárei": "agolpear",
    "agolpeáreis": "agolpear",
    "agolpeásseis": "agolpear",
    "agolpeássemos": "agolpear",
    "agolpeávamo": "agolpear",
    "agolpeávamos": "agolpear",
    "agolpeávei": "agolpear",
    "agolpeáveis": "agolpear",
    "agoma": "agomar",
    "agomada": "agomar",
    "agomadas": "agomar",
    "agomado": "agomar",
    "agomados": "agomar",
    "agomai": "agomar",
    "agomais": "agomar",
    "agomam": "agomar",
    "agomamo": "agomar",
    "agomamos": "agomar",
    "agomando": "agomar",
    "agomara": "agomar",
    "agomaram": "agomar",
    "agomaras": "agomar",
    "agomardes": "agomar",
    "agomarei": "agomar",
    "agomareis": "agomar",
    "agomarem": "agomar",
    "agomaremos": "agomar",
    "agomares": "agomar",
    "agomaria": "agomar",
    "agomariam": "agomar",
    "agomarias": "agomar",
    "agomarmo": "agomar",
    "agomarmos": "agomar",
    "agomará": "agomar",
    "agomarás": "agomar",
    "agomarão": "agomar",
    "agomaríamos": "agomar",
    "agomaríeis": "agomar",
    "agomas": "agomar",
    "agomasse": "agomar",
    "agomassem": "agomar",
    "agomasses": "agomar",
    "agomaste": "agomar",
    "agomastes": "agomar",
    "agomava": "agomar",
    "agomavam": "agomar",
    "agomavas": "agomar",
    "agome": "agomar",
    "agomei": "agomar",
    "agomeis": "agomar",
    "agomem": "agomar",
    "agomemo": "agomar",
    "agomemos": "agomar",
    "agomes": "agomar",
    "agomiadas": "agomiada",
    "agomias": "agomia",
    "agomilada": "agomilado",
    "agomiladas": "agomilado",
    "agomilados": "agomilado",
    "agomis": "agomil",
    "agomo": "agomar",
    "agomou": "agomar",
    "agomámo": "agomar",
    "agomámos": "agomar",
    "agomáramo": "agomar",
    "agomáramos": "agomar",
    "agomáreis": "agomar",
    "agomásseis": "agomar",
    "agomássemos": "agomar",
    "agomávamo": "agomar",
    "agomávamos": "agomar",
    "agomáveis": "agomar",
    "agongora": "agongorar",
    "agongorada": "agongorar",
    "agongoradas": "agongorar",
    "agongorado": "agongorar",
    "agongorados": "agongorar",
    "agongorai": "agongorar",
    "agongorais": "agongorar",
    "agongoram": "agongorar",
    "agongoramo": "agongorar",
    "agongoramos": "agongorar",
    "agongorando": "agongorar",
    "agongorara": "agongorar",
    "agongoraram": "agongorar",
    "agongoraras": "agongorar",
    "agongorarde": "agongorar",
    "agongorardes": "agongorar",
    "agongorare": "agongorar",
    "agongorarei": "agongorar",
    "agongorareis": "agongorar",
    "agongorarem": "agongorar",
    "agongoraremos": "agongorar",
    "agongorares": "agongorar",
    "agongoraria": "agongorar",
    "agongorariam": "agongorar",
    "agongorarias": "agongorar",
    "agongorarmo": "agongorar",
    "agongorarmos": "agongorar",
    "agongorará": "agongorar",
    "agongorarás": "agongorar",
    "agongorarão": "agongorar",
    "agongoraríamos": "agongorar",
    "agongoraríeis": "agongorar",
    "agongoras": "agongorar",
    "agongorasse": "agongorar",
    "agongorassem": "agongorar",
    "agongorasses": "agongorar",
    "agongoraste": "agongorar",
    "agongorastes": "agongorar",
    "agongorava": "agongorar",
    "agongoravam": "agongorar",
    "agongoravas": "agongorar",
    "agongore": "agongorar",
    "agongorei": "agongorar",
    "agongoreis": "agongorar",
    "agongorem": "agongorar",
    "agongoremo": "agongorar",
    "agongoremos": "agongorar",
    "agongores": "agongorar",
    "agongoro": "agongorar",
    "agongorou": "agongorar",
    "agongorá": "agongorar",
    "agongorámo": "agongorar",
    "agongorámos": "agongorar",
    "agongoráramo": "agongorar",
    "agongoráramos": "agongorar",
    "agongorárei": "agongorar",
    "agongoráreis": "agongorar",
    "agongorásseis": "agongorar",
    "agongorássemos": "agongorar",
    "agongorávamo": "agongorar",
    "agongorávamos": "agongorar",
    "agongorávei": "agongorar",
    "agongoráveis": "agongorar",
    "agonia": "agoniar",
    "agoniada": "agoniar",
    "agoniadas": "agoniar",
    "agoniado": "agoniar",
    "agoniados": "agoniar",
    "agoniadíssima": "agoniado",
    "agoniadíssimas": "agoniado",
    "agoniadíssimo": "agoniado",
    "agoniadíssimos": "agoniado",
    "agoniai": "agoniar",
    "agoniais": "agoniar",
    "agoniam": "agoniar",
    "agoniamo": "agoniar",
    "agoniamos": "agoniar",
    "agoniando": "agoniar",
    "agoniantes": "agoniante",
    "agoniara": "agoniar",
    "agoniaram": "agoniar",
    "agoniaras": "agoniar",
    "agoniarde": "agoniar",
    "agoniardes": "agoniar",
    "agoniare": "agoniar",
    "agoniarei": "agoniar",
    "agoniareis": "agoniar",
    "agoniarem": "agoniar",
    "agoniaremos": "agoniar",
    "agoniares": "agoniar",
    "agoniaria": "agoniar",
    "agoniariam": "agoniar",
    "agoniarias": "agoniar",
    "agoniarmo": "agoniar",
    "agoniarmos": "agoniar",
    "agoniará": "agoniar",
    "agoniarás": "agoniar",
    "agoniarão": "agoniar",
    "agoniaríamos": "agoniar",
    "agoniaríeis": "agoniar",
    "agonias": "agoniar",
    "agoniasse": "agoniar",
    "agoniassem": "agoniar",
    "agoniasses": "agoniar",
    "agoniaste": "agoniar",
    "agoniastes": "agoniar",
    "agoniava": "agoniar",
    "agoniavam": "agoniar",
    "agoniavas": "agoniar",
    "agoniações": "agoniação",
    "agonie": "agoniar",
    "agoniei": "agoniar",
    "agonieis": "agoniar",
    "agoniem": "agoniar",
    "agoniemo": "agoniar",
    "agoniemos": "agoniar",
    "agonies": "agoniar",
    "agonio": "agoniar",
    "agoniou": "agoniar",
    "agonistarcas": "agonistarca",
    "agonistas": "agonista",
    "agoniza": "agonizar",
    "agonizada": "agonizar",
    "agonizadas": "agonizar",
    "agonizado": "agonizar",
    "agonizados": "agonizar",
    "agonizai": "agonizar",
    "agonizais": "agonizar",
    "agonizam": "agonizar",
    "agonizamo": "agonizar",
    "agonizamos": "agonizar",
    "agonizando": "agonizar",
    "agonizantes": "agonizante",
    "agonizara": "agonizar",
    "agonizaram": "agonizar",
    "agonizaras": "agonizar",
    "agonizardes": "agonizar",
    "agonizarei": "agonizar",
    "agonizareis": "agonizar",
    "agonizarem": "agonizar",
    "agonizaremos": "agonizar",
    "agonizares": "agonizar",
    "agonizaria": "agonizar",
    "agonizariam": "agonizar",
    "agonizarias": "agonizar",
    "agonizarmo": "agonizar",
    "agonizarmos": "agonizar",
    "agonizará": "agonizar",
    "agonizarás": "agonizar",
    "agonizarão": "agonizar",
    "agonizaríamos": "agonizar",
    "agonizaríeis": "agonizar",
    "agonizas": "agonizar",
    "agonizasse": "agonizar",
    "agonizassem": "agonizar",
    "agonizasses": "agonizar",
    "agonizaste": "agonizar",
    "agonizastes": "agonizar",
    "agonizava": "agonizar",
    "agonizavam": "agonizar",
    "agonizavas": "agonizar",
    "agonize": "agonizar",
    "agonizei": "agonizar",
    "agonizeis": "agonizar",
    "agonizem": "agonizar",
    "agonizemo": "agonizar",
    "agonizemos": "agonizar",
    "agonizes": "agonizar",
    "agonizo": "agonizar",
    "agonizou": "agonizar",
    "agonizámo": "agonizar",
    "agonizámos": "agonizar",
    "agonizáramo": "agonizar",
    "agonizáramos": "agonizar",
    "agonizáreis": "agonizar",
    "agonizásseis": "agonizar",
    "agonizássemos": "agonizar",
    "agonizávamo": "agonizar",
    "agonizávamos": "agonizar",
    "agonizáveis": "agonizar",
    "agoniá": "agoniar",
    "agoniámo": "agoniar",
    "agoniámos": "agoniar",
    "agoniáramo": "agoniar",
    "agoniáramos": "agoniar",
    "agoniárei": "agoniar",
    "agoniáreis": "agoniar",
    "agoniásseis": "agoniar",
    "agoniássemos": "agoniar",
    "agoniávamo": "agoniar",
    "agoniávamos": "agoniar",
    "agoniávei": "agoniar",
    "agoniáveis": "agoniar",
    "agonídea": "agonídeo",
    "agonídeas": "agonídeo",
    "agonídeos": "agonídeo",
    "agonística": "agonístico",
    "agonísticas": "agonístico",
    "agonísticos": "agonístico",
    "agorafobias": "agorafobia",
    "agorenta": "agorentar",
    "agorentada": "agorentar",
    "agorentadas": "agorentar",
    "agorentado": "agorentar",
    "agorentados": "agorentar",
    "agorentai": "agorentar",
    "agorentais": "agorentar",
    "agorentam": "agorentar",
    "agorentamo": "agorentar",
    "agorentamos": "agorentar",
    "agorentando": "agorentar",
    "agorentara": "agorentar",
    "agorentaram": "agorentar",
    "agorentaras": "agorentar",
    "agorentarde": "agorentar",
    "agorentardes": "agorentar",
    "agorentare": "agorentar",
    "agorentarei": "agorentar",
    "agorentareis": "agorentar",
    "agorentarem": "agorentar",
    "agorentaremos": "agorentar",
    "agorentares": "agorentar",
    "agorentaria": "agorentar",
    "agorentariam": "agorentar",
    "agorentarias": "agorentar",
    "agorentarmo": "agorentar",
    "agorentarmos": "agorentar",
    "agorentará": "agorentar",
    "agorentarás": "agorentar",
    "agorentarão": "agorentar",
    "agorentaríamos": "agorentar",
    "agorentaríeis": "agorentar",
    "agorentas": "agorentar",
    "agorentasse": "agorentar",
    "agorentassem": "agorentar",
    "agorentasses": "agorentar",
    "agorentaste": "agorentar",
    "agorentastes": "agorentar",
    "agorentava": "agorentar",
    "agorentavam": "agorentar",
    "agorentavas": "agorentar",
    "agorente": "agorentar",
    "agorentei": "agorentar",
    "agorenteis": "agorentar",
    "agorentem": "agorentar",
    "agorentemo": "agorentar",
    "agorentemos": "agorentar",
    "agorentes": "agorentar",
    "agorento": "agorentar",
    "agorentou": "agorentar",
    "agorentá": "agorentar",
    "agorentámo": "agorentar",
    "agorentámos": "agorentar",
    "agorentáramo": "agorentar",
    "agorentáramos": "agorentar",
    "agorentárei": "agorentar",
    "agorentáreis": "agorentar",
    "agorentásseis": "agorentar",
    "agorentássemos": "agorentar",
    "agorentávamo": "agorentar",
    "agorentávamos": "agorentar",
    "agorentávei": "agorentar",
    "agorentáveis": "agorentar",
    "agoráfoba": "agoráfobo",
    "agoráfobas": "agoráfobo",
    "agoráfobos": "agoráfobo",
    "agosta": "agostar",
    "agostada": "agostar",
    "agostadas": "agostar",
    "agostado": "agostar",
    "agostadoiros": "agostadoiro",
    "agostados": "agostar",
    "agostadouros": "agostadouro",
    "agostai": "agostar",
    "agostais": "agostar",
    "agostam": "agostar",
    "agostamo": "agostar",
    "agostamos": "agostar",
    "agostando": "agostar",
    "agostara": "agostar",
    "agostaram": "agostar",
    "agostaras": "agostar",
    "agostarde": "agostar",
    "agostardes": "agostar",
    "agostare": "agostar",
    "agostarei": "agostar",
    "agostareis": "agostar",
    "agostarem": "agostar",
    "agostaremos": "agostar",
    "agostares": "agostar",
    "agostaria": "agostar",
    "agostariam": "agostar",
    "agostarias": "agostar",
    "agostarmo": "agostar",
    "agostarmos": "agostar",
    "agostará": "agostar",
    "agostarás": "agostar",
    "agostarão": "agostar",
    "agostaríamos": "agostar",
    "agostaríeis": "agostar",
    "agostas": "agostar",
    "agostasse": "agostar",
    "agostassem": "agostar",
    "agostasses": "agostar",
    "agostaste": "agostar",
    "agostastes": "agostar",
    "agostava": "agostar",
    "agostavam": "agostar",
    "agostavas": "agostar",
    "agoste": "agostar",
    "agostei": "agostar",
    "agosteira": "agosteiro",
    "agosteiras": "agosteiro",
    "agosteiros": "agosteiro",
    "agosteis": "agostar",
    "agostem": "agostar",
    "agostemo": "agostar",
    "agostemos": "agostar",
    "agostes": "agostar",
    "agostinha": "agostinho",
    "agostinhas": "agostinho",
    "agostinhos": "agostinho",
    "agostiniana": "agostiniano",
    "agostinianas": "agostiniano",
    "agostinianos": "agostiniano",
    "agostinismos": "agostinismo",
    "agostinistas": "agostinista",
    "agosto": "agostar",
    "agostou": "agostar",
    "agostá": "agostar",
    "agostámo": "agostar",
    "agostámos": "agostar",
    "agostáramo": "agostar",
    "agostáramos": "agostar",
    "agostárei": "agostar",
    "agostáreis": "agostar",
    "agostásseis": "agostar",
    "agostássemos": "agostar",
    "agostávamo": "agostar",
    "agostávamos": "agostar",
    "agostávei": "agostar",
    "agostáveis": "agostar",
    "agoura": "agourar",
    "agourada": "agourar",
    "agouradas": "agourar",
    "agourado": "agourar",
    "agourados": "agourar",
    "agourai": "agourar",
    "agourais": "agourar",
    "agouram": "agourar",
    "agouramo": "agourar",
    "agouramos": "agourar",
    "agourando": "agourar",
    "agourara": "agourar",
    "agouraram": "agourar",
    "agouraras": "agourar",
    "agourarde": "agourar",
    "agourardes": "agourar",
    "agourare": "agourar",
    "agourarei": "agourar",
    "agourareis": "agourar",
    "agourarem": "agourar",
    "agouraremos": "agourar",
    "agourares": "agourar",
    "agouraria": "agourar",
    "agourariam": "agourar",
    "agourarias": "agourar",
    "agourarmo": "agourar",
    "agourarmos": "agourar",
    "agourará": "agourar",
    "agourarás": "agourar",
    "agourarão": "agourar",
    "agouraríamos": "agourar",
    "agouraríeis": "agourar",
    "agouras": "agourar",
    "agourasse": "agourar",
    "agourassem": "agourar",
    "agourasses": "agourar",
    "agouraste": "agourar",
    "agourastes": "agourar",
    "agourava": "agourar",
    "agouravam": "agourar",
    "agouravas": "agourar",
    "agoure": "agourar",
    "agourei": "agourar",
    "agoureira": "agoureiro",
    "agoureiras": "agoureiro",
    "agoureiros": "agoureiro",
    "agoureis": "agourar",
    "agourem": "agourar",
    "agouremo": "agourar",
    "agouremos": "agourar",
    "agourenta": "agourento",
    "agourentada": "agourentar",
    "agourentadas": "agourentar",
    "agourentado": "agourentar",
    "agourentados": "agourentar",
    "agourentai": "agourentar",
    "agourentais": "agourentar",
    "agourentam": "agourentar",
    "agourentamo": "agourentar",
    "agourentamos": "agourentar",
    "agourentando": "agourentar",
    "agourentara": "agourentar",
    "agourentaram": "agourentar",
    "agourentaras": "agourentar",
    "agourentarde": "agourentar",
    "agourentardes": "agourentar",
    "agourentare": "agourentar",
    "agourentarei": "agourentar",
    "agourentareis": "agourentar",
    "agourentarem": "agourentar",
    "agourentaremos": "agourentar",
    "agourentares": "agourentar",
    "agourentaria": "agourentar",
    "agourentariam": "agourentar",
    "agourentarias": "agourentar",
    "agourentarmo": "agourentar",
    "agourentarmos": "agourentar",
    "agourentará": "agourentar",
    "agourentarás": "agourentar",
    "agourentarão": "agourentar",
    "agourentaríamos": "agourentar",
    "agourentaríeis": "agourentar",
    "agourentas": "agourento",
    "agourentasse": "agourentar",
    "agourentassem": "agourentar",
    "agourentasses": "agourentar",
    "agourentaste": "agourentar",
    "agourentastes": "agourentar",
    "agourentava": "agourentar",
    "agourentavam": "agourentar",
    "agourentavas": "agourentar",
    "agourente": "agourentar",
    "agourentei": "agourentar",
    "agourenteis": "agourentar",
    "agourentem": "agourentar",
    "agourentemo": "agourentar",
    "agourentemos": "agourentar",
    "agourentes": "agourentar",
    "agourento": "agourentar",
    "agourentos": "agourento",
    "agourentou": "agourentar",
    "agourentá": "agourentar",
    "agourentámo": "agourentar",
    "agourentámos": "agourentar",
    "agourentáramo": "agourentar",
    "agourentáramos": "agourentar",
    "agourentárei": "agourentar",
    "agourentáreis": "agourentar",
    "agourentásseis": "agourentar",
    "agourentássemos": "agourentar",
    "agourentávamo": "agourentar",
    "agourentávamos": "agourentar",
    "agourentávei": "agourentar",
    "agourentáveis": "agourentar",
    "agoures": "agourar",
    "agouro": "agourar",
    "agouros": "agouro",
    "agourou": "agourar",
    "agourá": "agourar",
    "agourámo": "agourar",
    "agourámos": "agourar",
    "agouráramo": "agourar",
    "agouráramos": "agourar",
    "agourárei": "agourar",
    "agouráreis": "agourar",
    "agourásseis": "agourar",
    "agourássemos": "agourar",
    "agourávamo": "agourar",
    "agourávamos": "agourar",
    "agourávei": "agourar",
    "agouráveis": "agourar",
    "agra": "agro",
    "agracia": "agraciar",
    "agraciada": "agraciar",
    "agraciadas": "agraciar",
    "agraciado": "agraciar",
    "agraciados": "agraciar",
    "agraciai": "agraciar",
    "agraciais": "agraciar",
    "agraciam": "agraciar",
    "agraciamentos": "agraciamento",
    "agraciamo": "agraciar",
    "agraciamos": "agraciar",
    "agraciando": "agraciar",
    "agraciara": "agraciar",
    "agraciaram": "agraciar",
    "agraciaras": "agraciar",
    "agraciarde": "agraciar",
    "agraciardes": "agraciar",
    "agraciare": "agraciar",
    "agraciarei": "agraciar",
    "agraciareis": "agraciar",
    "agraciarem": "agraciar",
    "agraciaremos": "agraciar",
    "agraciares": "agraciar",
    "agraciaria": "agraciar",
    "agraciariam": "agraciar",
    "agraciarias": "agraciar",
    "agraciarmo": "agraciar",
    "agraciarmos": "agraciar",
    "agraciará": "agraciar",
    "agraciarás": "agraciar",
    "agraciarão": "agraciar",
    "agraciaríamos": "agraciar",
    "agraciaríeis": "agraciar",
    "agracias": "agraciar",
    "agraciasse": "agraciar",
    "agraciassem": "agraciar",
    "agraciasses": "agraciar",
    "agraciaste": "agraciar",
    "agraciastes": "agraciar",
    "agraciava": "agraciar",
    "agraciavam": "agraciar",
    "agraciavas": "agraciar",
    "agraciações": "agraciação",
    "agracie": "agraciar",
    "agraciei": "agraciar",
    "agracieis": "agraciar",
    "agraciem": "agraciar",
    "agraciemo": "agraciar",
    "agraciemos": "agraciar",
    "agracies": "agraciar",
    "agracio": "agraciar",
    "agraciou": "agraciar",
    "agraciá": "agraciar",
    "agraciámo": "agraciar",
    "agraciámos": "agraciar",
    "agraciáramo": "agraciar",
    "agraciáramos": "agraciar",
    "agraciárei": "agraciar",
    "agraciáreis": "agraciar",
    "agraciásseis": "agraciar",
    "agraciássemos": "agraciar",
    "agraciávamo": "agraciar",
    "agraciávamos": "agraciar",
    "agraciávei": "agraciar",
    "agraciáveis": "agraciável",
    "agrada": "agradar",
    "agradabilíssima": "agradável",
    "agradabilíssimas": "agradável",
    "agradabilíssimo": "agradável",
    "agradabilíssimos": "agradável",
    "agradada": "agradar",
    "agradadas": "agradar",
    "agradado": "agradar",
    "agradados": "agradar",
    "agradai": "agradar",
    "agradais": "agradar",
    "agradam": "agradar",
    "agradamo": "agradar",
    "agradamos": "agradar",
    "agradando": "agradar",
    "agradara": "agradar",
    "agradaram": "agradar",
    "agradaras": "agradar",
    "agradardes": "agradar",
    "agradarei": "agradar",
    "agradareis": "agradar",
    "agradarem": "agradar",
    "agradaremos": "agradar",
    "agradares": "agradar",
    "agradaria": "agradar",
    "agradariam": "agradar",
    "agradarias": "agradar",
    "agradarmo": "agradar",
    "agradarmos": "agradar",
    "agradará": "agradar",
    "agradarás": "agradar",
    "agradarão": "agradar",
    "agradaríamos": "agradar",
    "agradaríeis": "agradar",
    "agradas": "agradar",
    "agradasse": "agradar",
    "agradassem": "agradar",
    "agradasses": "agradar",
    "agradaste": "agradar",
    "agradastes": "agradar",
    "agradava": "agradar",
    "agradavam": "agradar",
    "agradavas": "agradar",
    "agradaveizinhas": "agradável",
    "agradaveizinhos": "agradável",
    "agradaveizitas": "agradável",
    "agradaveizitos": "agradável",
    "agradavelzinha": "agradável",
    "agradavelzinho": "agradável",
    "agradavelzita": "agradável",
    "agradavelzito": "agradável",
    "agrade": "agradar",
    "agradece": "agradecer",
    "agradecei": "agradecer",
    "agradeceis": "agradecer",
    "agradecem": "agradecer",
    "agradecemo": "agradecer",
    "agradecemos": "agradecer",
    "agradecendo": "agradecer",
    "agradecera": "agradecer",
    "agradeceram": "agradecer",
    "agradeceras": "agradecer",
    "agradecerde": "agradecer",
    "agradecerdes": "agradecer",
    "agradecere": "agradecer",
    "agradecerei": "agradecer",
    "agradecereis": "agradecer",
    "agradecerem": "agradecer",
    "agradeceremos": "agradecer",
    "agradeceres": "agradecer",
    "agradeceria": "agradecer",
    "agradeceriam": "agradecer",
    "agradecerias": "agradecer",
    "agradecermo": "agradecer",
    "agradecermos": "agradecer",
    "agradecerá": "agradecer",
    "agradecerás": "agradecer",
    "agradecerão": "agradecer",
    "agradeceríamos": "agradecer",
    "agradeceríeis": "agradecer",
    "agradeces": "agradecer",
    "agradecesse": "agradecer",
    "agradecessem": "agradecer",
    "agradecesses": "agradecer",
    "agradeceste": "agradecer",
    "agradecestes": "agradecer",
    "agradeceu": "agradecer",
    "agradeci": "agradecer",
    "agradecia": "agradecer",
    "agradeciam": "agradecer",
    "agradecias": "agradecer",
    "agradecida": "agradecido",
    "agradecidas": "agradecido",
    "agradecido": "agradecer",
    "agradecidos": "agradecido",
    "agradecidíssima": "agradecido",
    "agradecidíssimas": "agradecido",
    "agradecidíssimo": "agradecido",
    "agradecidíssimos": "agradecido",
    "agradecimentos": "agradecimento",
    "agradecê": "agradecer",
    "agradecêramo": "agradecer",
    "agradecêramos": "agradecer",
    "agradecêrei": "agradecer",
    "agradecêreis": "agradecer",
    "agradecêsseis": "agradecer",
    "agradecêssemos": "agradecer",
    "agradecíamo": "agradecer",
    "agradecíamos": "agradecer",
    "agradecíei": "agradecer",
    "agradecíeis": "agradecer",
    "agradecíveis": "agradecível",
    "agradei": "agradar",
    "agradeis": "agradar",
    "agradem": "agradar",
    "agrademo": "agradar",
    "agrademos": "agradar",
    "agrades": "agradar",
    "agradeça": "agradecer",
    "agradeçais": "agradecer",
    "agradeçam": "agradecer",
    "agradeçamo": "agradecer",
    "agradeçamos": "agradecer",
    "agradeças": "agradecer",
    "agradeço": "agradecer",
    "agrado": "agradar",
    "agrados": "agrado",
    "agradou": "agradar",
    "agradámo": "agradar",
    "agradámos": "agradar",
    "agradáramo": "agradar",
    "agradáramos": "agradar",
    "agradáreis": "agradar",
    "agradásseis": "agradar",
    "agradássemos": "agradar",
    "agradávamo": "agradar",
    "agradávamos": "agradar",
    "agradáveis": "agradável",
    "agrafa": "agrafar",
    "agrafada": "agrafar",
    "agrafadas": "agrafar",
    "agrafado": "agrafar",
    "agrafados": "agrafar",
    "agrafai": "agrafar",
    "agrafais": "agrafar",
    "agrafam": "agrafar",
    "agrafamo": "agrafar",
    "agrafamos": "agrafar",
    "agrafando": "agrafar",
    "agrafara": "agrafar",
    "agrafaram": "agrafar",
    "agrafaras": "agrafar",
    "agrafarde": "agrafar",
    "agrafardes": "agrafar",
    "agrafare": "agrafar",
    "agrafarei": "agrafar",
    "agrafareis": "agrafar",
    "agrafarem": "agrafar",
    "agrafaremos": "agrafar",
    "agrafares": "agrafar",
    "agrafaria": "agrafar",
    "agrafariam": "agrafar",
    "agrafarias": "agrafar",
    "agrafarmo": "agrafar",
    "agrafarmos": "agrafar",
    "agrafará": "agrafar",
    "agrafarás": "agrafar",
    "agrafarão": "agrafar",
    "agrafaríamos": "agrafar",
    "agrafaríeis": "agrafar",
    "agrafas": "agrafar",
    "agrafasse": "agrafar",
    "agrafassem": "agrafar",
    "agrafasses": "agrafar",
    "agrafaste": "agrafar",
    "agrafastes": "agrafar",
    "agrafava": "agrafar",
    "agrafavam": "agrafar",
    "agrafavas": "agrafar",
    "agrafe": "agrafar",
    "agrafei": "agrafar",
    "agrafeis": "agrafar",
    "agrafem": "agrafar",
    "agrafemo": "agrafar",
    "agrafemos": "agrafar",
    "agrafes": "agrafe",
    "agrafias": "agrafia",
    "agrafo": "agrafar",
    "agrafos": "agrafo",
    "agrafou": "agrafar",
    "agrafá": "agrafar",
    "agrafámo": "agrafar",
    "agrafámos": "agrafar",
    "agrafáramo": "agrafar",
    "agrafáramos": "agrafar",
    "agrafárei": "agrafar",
    "agrafáreis": "agrafar",
    "agrafásseis": "agrafar",
    "agrafássemos": "agrafar",
    "agrafávamo": "agrafar",
    "agrafávamos": "agrafar",
    "agrafávei": "agrafar",
    "agrafáveis": "agrafar",
    "agramaticais": "agramatical",
    "agramatismos": "agramatismo",
    "agrana": "agranar",
    "agranada": "agranar",
    "agranadas": "agranar",
    "agranado": "agranar",
    "agranados": "agranar",
    "agranai": "agranar",
    "agranais": "agranar",
    "agranam": "agranar",
    "agranamo": "agranar",
    "agranamos": "agranar",
    "agranando": "agranar",
    "agranara": "agranar",
    "agranaram": "agranar",
    "agranaras": "agranar",
    "agranardes": "agranar",
    "agranarei": "agranar",
    "agranareis": "agranar",
    "agranarem": "agranar",
    "agranaremos": "agranar",
    "agranares": "agranar",
    "agranaria": "agranar",
    "agranariam": "agranar",
    "agranarias": "agranar",
    "agranarmo": "agranar",
    "agranarmos": "agranar",
    "agranará": "agranar",
    "agranarás": "agranar",
    "agranarão": "agranar",
    "agranaríamos": "agranar",
    "agranaríeis": "agranar",
    "agranas": "agranar",
    "agranasse": "agranar",
    "agranassem": "agranar",
    "agranasses": "agranar",
    "agranaste": "agranar",
    "agranastes": "agranar",
    "agranava": "agranar",
    "agranavam": "agranar",
    "agranavas": "agranar",
    "agrane": "agranar",
    "agranei": "agranar",
    "agraneis": "agranar",
    "agranem": "agranar",
    "agranemo": "agranar",
    "agranemos": "agranar",
    "agranes": "agranar",
    "agranjada": "agranjado",
    "agranjadas": "agranjado",
    "agranjados": "agranjado",
    "agrano": "agranar",
    "agranou": "agranar",
    "agranámo": "agranar",
    "agranámos": "agranar",
    "agranáramo": "agranar",
    "agranáramos": "agranar",
    "agranáreis": "agranar",
    "agranásseis": "agranar",
    "agranássemos": "agranar",
    "agranávamo": "agranar",
    "agranávamos": "agranar",
    "agranáveis": "agranar",
    "agras": "agro",
    "agraudada": "agraudar",
    "agraudadas": "agraudar",
    "agraudado": "agraudar",
    "agraudados": "agraudar",
    "agraudai": "agraudar",
    "agraudais": "agraudar",
    "agraudamo": "agraudar",
    "agraudamos": "agraudar",
    "agraudando": "agraudar",
    "agraudara": "agraudar",
    "agraudaram": "agraudar",
    "agraudaras": "agraudar",
    "agraudarde": "agraudar",
    "agraudardes": "agraudar",
    "agraudare": "agraudar",
    "agraudarei": "agraudar",
    "agraudareis": "agraudar",
    "agraudarem": "agraudar",
    "agraudaremos": "agraudar",
    "agraudares": "agraudar",
    "agraudaria": "agraudar",
    "agraudariam": "agraudar",
    "agraudarias": "agraudar",
    "agraudarmo": "agraudar",
    "agraudarmos": "agraudar",
    "agraudará": "agraudar",
    "agraudarás": "agraudar",
    "agraudarão": "agraudar",
    "agraudaríamos": "agraudar",
    "agraudaríeis": "agraudar",
    "agraudasse": "agraudar",
    "agraudassem": "agraudar",
    "agraudasses": "agraudar",
    "agraudaste": "agraudar",
    "agraudastes": "agraudar",
    "agraudava": "agraudar",
    "agraudavam": "agraudar",
    "agraudavas": "agraudar",
    "agraudei": "agraudar",
    "agraudeis": "agraudar",
    "agraudemo": "agraudar",
    "agraudemos": "agraudar",
    "agraudou": "agraudar",
    "agraudá": "agraudar",
    "agraudámo": "agraudar",
    "agraudámos": "agraudar",
    "agraudáramo": "agraudar",
    "agraudáramos": "agraudar",
    "agraudárei": "agraudar",
    "agraudáreis": "agraudar",
    "agraudásseis": "agraudar",
    "agraudássemos": "agraudar",
    "agraudávamo": "agraudar",
    "agraudávamos": "agraudar",
    "agraudávei": "agraudar",
    "agraudáveis": "agraudar",
    "agrava": "agravar",
    "agravada": "agravar",
    "agravadas": "agravar",
    "agravado": "agravar",
    "agravados": "agravar",
    "agravai": "agravar",
    "agravais": "agravar",
    "agravam": "agravar",
    "agravamentos": "agravamento",
    "agravamo": "agravar",
    "agravamos": "agravar",
    "agravando": "agravar",
    "agravantes": "agravante",
    "agravara": "agravar",
    "agravaram": "agravar",
    "agravaras": "agravar",
    "agravarde": "agravar",
    "agravardes": "agravar",
    "agravare": "agravar",
    "agravarei": "agravar",
    "agravareis": "agravar",
    "agravarem": "agravar",
    "agravaremos": "agravar",
    "agravares": "agravar",
    "agravaria": "agravar",
    "agravariam": "agravar",
    "agravarias": "agravar",
    "agravarmo": "agravar",
    "agravarmos": "agravar",
    "agravará": "agravar",
    "agravarás": "agravar",
    "agravarão": "agravar",
    "agravaríamos": "agravar",
    "agravaríeis": "agravar",
    "agravas": "agravar",
    "agravasse": "agravar",
    "agravassem": "agravar",
    "agravasses": "agravar",
    "agravaste": "agravar",
    "agravastes": "agravar",
    "agravativa": "agravativo",
    "agravativas": "agravativo",
    "agravativos": "agravativo",
    "agravatória": "agravatório",
    "agravatórias": "agravatório",
    "agravatórios": "agravatório",
    "agravava": "agravar",
    "agravavam": "agravar",
    "agravavas": "agravar",
    "agravações": "agravação",
    "agrave": "agravar",
    "agravei": "agravar",
    "agraveis": "agravar",
    "agravem": "agravar",
    "agravemo": "agravar",
    "agravemos": "agravar",
    "agraves": "agravar",
    "agravia": "agraviar",
    "agraviada": "agraviar",
    "agraviadas": "agraviar",
    "agraviado": "agraviar",
    "agraviados": "agraviar",
    "agraviai": "agraviar",
    "agraviais": "agraviar",
    "agraviam": "agraviar",
    "agraviamo": "agraviar",
    "agraviamos": "agraviar",
    "agraviando": "agraviar",
    "agraviara": "agraviar",
    "agraviaram": "agraviar",
    "agraviaras": "agraviar",
    "agraviarde": "agraviar",
    "agraviardes": "agraviar",
    "agraviare": "agraviar",
    "agraviarei": "agraviar",
    "agraviareis": "agraviar",
    "agraviarem": "agraviar",
    "agraviaremos": "agraviar",
    "agraviares": "agraviar",
    "agraviaria": "agraviar",
    "agraviariam": "agraviar",
    "agraviarias": "agraviar",
    "agraviarmo": "agraviar",
    "agraviarmos": "agraviar",
    "agraviará": "agraviar",
    "agraviarás": "agraviar",
    "agraviarão": "agraviar",
    "agraviaríamos": "agraviar",
    "agraviaríeis": "agraviar",
    "agravias": "agraviar",
    "agraviasse": "agraviar",
    "agraviassem": "agraviar",
    "agraviasses": "agraviar",
    "agraviaste": "agraviar",
    "agraviastes": "agraviar",
    "agraviava": "agraviar",
    "agraviavam": "agraviar",
    "agraviavas": "agraviar",
    "agravie": "agraviar",
    "agraviei": "agraviar",
    "agravieis": "agraviar",
    "agraviem": "agraviar",
    "agraviemo": "agraviar",
    "agraviemos": "agraviar",
    "agravies": "agraviar",
    "agravio": "agraviar",
    "agraviou": "agraviar",
    "agravistas": "agravista",
    "agraviá": "agraviar",
    "agraviámo": "agraviar",
    "agraviámos": "agraviar",
    "agraviáramo": "agraviar",
    "agraviáramos": "agraviar",
    "agraviárei": "agraviar",
    "agraviáreis": "agraviar",
    "agraviásseis": "agraviar",
    "agraviássemos": "agraviar",
    "agraviávamo": "agraviar",
    "agraviávamos": "agraviar",
    "agraviávei": "agraviar",
    "agraviáveis": "agraviar",
    "agravo": "agravar",
    "agravos": "agravo",
    "agravosa": "agravoso",
    "agravosas": "agravoso",
    "agravosos": "agravoso",
    "agravou": "agravar",
    "agravá": "agravar",
    "agravámo": "agravar",
    "agravámos": "agravar",
    "agraváramo": "agravar",
    "agraváramos": "agravar",
    "agravárei": "agravar",
    "agraváreis": "agravar",
    "agravásseis": "agravar",
    "agravássemos": "agravar",
    "agravávamo": "agravar",
    "agravávamos": "agravar",
    "agravávei": "agravar",
    "agraváveis": "agravável",
    "agrazes": "agraz",
    "agraços": "agraço",
    "agraúda": "agraudar",
    "agraúdam": "agraudar",
    "agraúdas": "agraudar",
    "agraúde": "agraudar",
    "agraúdem": "agraudar",
    "agraúdes": "agraudar",
    "agraúdo": "agraudar",
    "agredi": "agredir",
    "agredia": "agredir",
    "agrediam": "agredir",
    "agredias": "agredir",
    "agredida": "agredir",
    "agredidas": "agredir",
    "agredido": "agredir",
    "agredidos": "agredir",
    "agredimo": "agredir",
    "agredimos": "agredir",
    "agredindo": "agredir",
    "agredira": "agredir",
    "agrediram": "agredir",
    "agrediras": "agredir",
    "agredirde": "agredir",
    "agredirdes": "agredir",
    "agredire": "agredir",
    "agredirei": "agredir",
    "agredireis": "agredir",
    "agredirem": "agredir",
    "agrediremos": "agredir",
    "agredires": "agredir",
    "agrediria": "agredir",
    "agrediriam": "agredir",
    "agredirias": "agredir",
    "agredirmo": "agredir",
    "agredirmos": "agredir",
    "agredirá": "agredir",
    "agredirás": "agredir",
    "agredirão": "agredir",
    "agrediríamos": "agredir",
    "agrediríeis": "agredir",
    "agredis": "agredir",
    "agredisse": "agredir",
    "agredissem": "agredir",
    "agredisses": "agredir",
    "agrediste": "agredir",
    "agredistes": "agredir",
    "agrediu": "agredir",
    "agredíamo": "agredir",
    "agredíamos": "agredir",
    "agredíei": "agredir",
    "agredíeis": "agredir",
    "agredíramo": "agredir",
    "agredíramos": "agredir",
    "agredírei": "agredir",
    "agredíreis": "agredir",
    "agredísseis": "agredir",
    "agredíssemos": "agredir",
    "agrega": "agregar",
    "agregada": "agregar",
    "agregadas": "agregar",
    "agregado": "agregar",
    "agregados": "agregar",
    "agregai": "agregar",
    "agregais": "agregar",
    "agregam": "agregar",
    "agregamo": "agregar",
    "agregamos": "agregar",
    "agregando": "agregar",
    "agregara": "agregar",
    "agregaram": "agregar",
    "agregaras": "agregar",
    "agregarde": "agregar",
    "agregardes": "agregar",
    "agregare": "agregar",
    "agregarei": "agregar",
    "agregareis": "agregar",
    "agregarem": "agregar",
    "agregaremos": "agregar",
    "agregares": "agregar",
    "agregaria": "agregar",
    "agregariam": "agregar",
    "agregarias": "agregar",
    "agregarmo": "agregar",
    "agregarmos": "agregar",
    "agregará": "agregar",
    "agregarás": "agregar",
    "agregarão": "agregar",
    "agregaríamos": "agregar",
    "agregaríeis": "agregar",
    "agregas": "agregar",
    "agregasse": "agregar",
    "agregassem": "agregar",
    "agregasses": "agregar",
    "agregaste": "agregar",
    "agregastes": "agregar",
    "agregativa": "agregativo",
    "agregativas": "agregativo",
    "agregativos": "agregativo",
    "agregava": "agregar",
    "agregavam": "agregar",
    "agregavas": "agregar",
    "agregações": "agregação",
    "agrego": "agregar",
    "agregou": "agregar",
    "agregue": "agregar",
    "agreguei": "agregar",
    "agregueis": "agregar",
    "agreguem": "agregar",
    "agreguemo": "agregar",
    "agreguemos": "agregar",
    "agregues": "agregar",
    "agregá": "agregar",
    "agregámo": "agregar",
    "agregámos": "agregar",
    "agregáramo": "agregar",
    "agregáramos": "agregar",
    "agregárei": "agregar",
    "agregáreis": "agregar",
    "agregásseis": "agregar",
    "agregássemos": "agregar",
    "agregávamo": "agregar",
    "agregávamos": "agregar",
    "agregávei": "agregar",
    "agregáveis": "agregar",
    "agreiras": "agreira",
    "agremia": "agremiar",
    "agremiada": "agremiar",
    "agremiadas": "agremiar",
    "agremiado": "agremiar",
    "agremiadora": "agremiador",
    "agremiadoras": "agremiador",
    "agremiadores": "agremiador",
    "agremiados": "agremiar",
    "agremiai": "agremiar",
    "agremiais": "agremiar",
    "agremiam": "agremiar",
    "agremiamo": "agremiar",
    "agremiamos": "agremiar",
    "agremiando": "agremiar",
    "agremiara": "agremiar",
    "agremiaram": "agremiar",
    "agremiaras": "agremiar",
    "agremiarde": "agremiar",
    "agremiardes": "agremiar",
    "agremiare": "agremiar",
    "agremiarei": "agremiar",
    "agremiareis": "agremiar",
    "agremiarem": "agremiar",
    "agremiaremos": "agremiar",
    "agremiares": "agremiar",
    "agremiaria": "agremiar",
    "agremiariam": "agremiar",
    "agremiarias": "agremiar",
    "agremiarmo": "agremiar",
    "agremiarmos": "agremiar",
    "agremiará": "agremiar",
    "agremiarás": "agremiar",
    "agremiarão": "agremiar",
    "agremiaríamos": "agremiar",
    "agremiaríeis": "agremiar",
    "agremias": "agremiar",
    "agremiasse": "agremiar",
    "agremiassem": "agremiar",
    "agremiasses": "agremiar",
    "agremiaste": "agremiar",
    "agremiastes": "agremiar",
    "agremiava": "agremiar",
    "agremiavam": "agremiar",
    "agremiavas": "agremiar",
    "agremiações": "agremiação",
    "agremie": "agremiar",
    "agremiei": "agremiar",
    "agremieis": "agremiar",
    "agremiem": "agremiar",
    "agremiemo": "agremiar",
    "agremiemos": "agremiar",
    "agremies": "agremiar",
    "agremio": "agremiar",
    "agremiou": "agremiar",
    "agremiá": "agremiar",
    "agremiámo": "agremiar",
    "agremiámos": "agremiar",
    "agremiáramo": "agremiar",
    "agremiáramos": "agremiar",
    "agremiárei": "agremiar",
    "agremiáreis": "agremiar",
    "agremiásseis": "agremiar",
    "agremiássemos": "agremiar",
    "agremiávamo": "agremiar",
    "agremiávamos": "agremiar",
    "agremiávei": "agremiar",
    "agremiáveis": "agremiar",
    "agres": "agre",
    "agressiva": "agressivo",
    "agressivas": "agressivo",
    "agressividades": "agressividade",
    "agressivos": "agressivo",
    "agressora": "agressor",
    "agressoras": "agressor",
    "agressores": "agressor",
    "agressões": "agressão",
    "agrestes": "agreste",
    "agrestias": "agrestia",
    "agrestices": "agrestice",
    "agrestidades": "agrestidade",
    "agrezinha": "agre",
    "agrezinhas": "agre",
    "agrezinho": "agre",
    "agrezinhos": "agre",
    "agrezita": "agre",
    "agrezitas": "agre",
    "agrezito": "agre",
    "agrezitos": "agre",
    "agriais": "agrial",
    "agricultora": "agricultor",
    "agricultoras": "agricultor",
    "agricultores": "agricultor",
    "agriculturas": "agricultura",
    "agricultáveis": "agricultável",
    "agrida": "agredir",
    "agridais": "agredir",
    "agridam": "agredir",
    "agridamo": "agredir",
    "agridamos": "agredir",
    "agridas": "agredir",
    "agride": "agredir",
    "agridem": "agredir",
    "agrides": "agredir",
    "agrido": "agredir",
    "agridoces": "agridoce",
    "agrilheta": "agrilhetar",
    "agrilhetada": "agrilhetar",
    "agrilhetadas": "agrilhetar",
    "agrilhetado": "agrilhetar",
    "agrilhetados": "agrilhetar",
    "agrilhetai": "agrilhetar",
    "agrilhetais": "agrilhetar",
    "agrilhetam": "agrilhetar",
    "agrilhetamo": "agrilhetar",
    "agrilhetamos": "agrilhetar",
    "agrilhetando": "agrilhetar",
    "agrilhetara": "agrilhetar",
    "agrilhetaram": "agrilhetar",
    "agrilhetaras": "agrilhetar",
    "agrilhetarde": "agrilhetar",
    "agrilhetardes": "agrilhetar",
    "agrilhetare": "agrilhetar",
    "agrilhetarei": "agrilhetar",
    "agrilhetareis": "agrilhetar",
    "agrilhetarem": "agrilhetar",
    "agrilhetaremos": "agrilhetar",
    "agrilhetares": "agrilhetar",
    "agrilhetaria": "agrilhetar",
    "agrilhetariam": "agrilhetar",
    "agrilhetarias": "agrilhetar",
    "agrilhetarmo": "agrilhetar",
    "agrilhetarmos": "agrilhetar",
    "agrilhetará": "agrilhetar",
    "agrilhetarás": "agrilhetar",
    "agrilhetarão": "agrilhetar",
    "agrilhetaríamos": "agrilhetar",
    "agrilhetaríeis": "agrilhetar",
    "agrilhetas": "agrilhetar",
    "agrilhetasse": "agrilhetar",
    "agrilhetassem": "agrilhetar",
    "agrilhetasses": "agrilhetar",
    "agrilhetaste": "agrilhetar",
    "agrilhetastes": "agrilhetar",
    "agrilhetava": "agrilhetar",
    "agrilhetavam": "agrilhetar",
    "agrilhetavas": "agrilhetar",
    "agrilhete": "agrilhetar",
    "agrilhetei": "agrilhetar",
    "agrilheteis": "agrilhetar",
    "agrilhetem": "agrilhetar",
    "agrilhetemo": "agrilhetar",
    "agrilhetemos": "agrilhetar",
    "agrilhetes": "agrilhetar",
    "agrilheto": "agrilhetar",
    "agrilhetou": "agrilhetar",
    "agrilhetá": "agrilhetar",
    "agrilhetámo": "agrilhetar",
    "agrilhetámos": "agrilhetar",
    "agrilhetáramo": "agrilhetar",
    "agrilhetáramos": "agrilhetar",
    "agrilhetárei": "agrilhetar",
    "agrilhetáreis": "agrilhetar",
    "agrilhetásseis": "agrilhetar",
    "agrilhetássemos": "agrilhetar",
    "agrilhetávamo": "agrilhetar",
    "agrilhetávamos": "agrilhetar",
    "agrilhetávei": "agrilhetar",
    "agrilhetáveis": "agrilhetar",
    "agrilhoa": "agrilhoar",
    "agrilhoada": "agrilhoar",
    "agrilhoadas": "agrilhoar",
    "agrilhoado": "agrilhoar",
    "agrilhoados": "agrilhoar",
    "agrilhoai": "agrilhoar",
    "agrilhoais": "agrilhoar",
    "agrilhoam": "agrilhoar",
    "agrilhoamentos": "agrilhoamento",
    "agrilhoamo": "agrilhoar",
    "agrilhoamos": "agrilhoar",
    "agrilhoando": "agrilhoar",
    "agrilhoara": "agrilhoar",
    "agrilhoaram": "agrilhoar",
    "agrilhoaras": "agrilhoar",
    "agrilhoarde": "agrilhoar",
    "agrilhoardes": "agrilhoar",
    "agrilhoare": "agrilhoar",
    "agrilhoarei": "agrilhoar",
    "agrilhoareis": "agrilhoar",
    "agrilhoarem": "agrilhoar",
    "agrilhoaremos": "agrilhoar",
    "agrilhoares": "agrilhoar",
    "agrilhoaria": "agrilhoar",
    "agrilhoariam": "agrilhoar",
    "agrilhoarias": "agrilhoar",
    "agrilhoarmo": "agrilhoar",
    "agrilhoarmos": "agrilhoar",
    "agrilhoará": "agrilhoar",
    "agrilhoarás": "agrilhoar",
    "agrilhoarão": "agrilhoar",
    "agrilhoaríamos": "agrilhoar",
    "agrilhoaríeis": "agrilhoar",
    "agrilhoas": "agrilhoar",
    "agrilhoasse": "agrilhoar",
    "agrilhoassem": "agrilhoar",
    "agrilhoasses": "agrilhoar",
    "agrilhoaste": "agrilhoar",
    "agrilhoastes": "agrilhoar",
    "agrilhoava": "agrilhoar",
    "agrilhoavam": "agrilhoar",
    "agrilhoavas": "agrilhoar",
    "agrilhoe": "agrilhoar",
    "agrilhoei": "agrilhoar",
    "agrilhoeis": "agrilhoar",
    "agrilhoem": "agrilhoar",
    "agrilhoemo": "agrilhoar",
    "agrilhoemos": "agrilhoar",
    "agrilhoes": "agrilhoar",
    "agrilhoo": "agrilhoar",
    "agrilhoou": "agrilhoar",
    "agrilhoá": "agrilhoar",
    "agrilhoámo": "agrilhoar",
    "agrilhoámos": "agrilhoar",
    "agrilhoáramo": "agrilhoar",
    "agrilhoáramos": "agrilhoar",
    "agrilhoárei": "agrilhoar",
    "agrilhoáreis": "agrilhoar",
    "agrilhoásseis": "agrilhoar",
    "agrilhoássemos": "agrilhoar",
    "agrilhoávamo": "agrilhoar",
    "agrilhoávamos": "agrilhoar",
    "agrilhoávei": "agrilhoar",
    "agrilhoáveis": "agrilhoar",
    "agrima": "agrimar",
    "agrimada": "agrimar",
    "agrimadas": "agrimar",
    "agrimado": "agrimar",
    "agrimados": "agrimar",
    "agrimai": "agrimar",
    "agrimais": "agrimar",
    "agrimam": "agrimar",
    "agrimamo": "agrimar",
    "agrimamos": "agrimar",
    "agrimando": "agrimar",
    "agrimara": "agrimar",
    "agrimaram": "agrimar",
    "agrimaras": "agrimar",
    "agrimarde": "agrimar",
    "agrimardes": "agrimar",
    "agrimare": "agrimar",
    "agrimarei": "agrimar",
    "agrimareis": "agrimar",
    "agrimarem": "agrimar",
    "agrimaremos": "agrimar",
    "agrimares": "agrimar",
    "agrimaria": "agrimar",
    "agrimariam": "agrimar",
    "agrimarias": "agrimar",
    "agrimarmo": "agrimar",
    "agrimarmos": "agrimar",
    "agrimará": "agrimar",
    "agrimarás": "agrimar",
    "agrimarão": "agrimar",
    "agrimaríamos": "agrimar",
    "agrimaríeis": "agrimar",
    "agrimas": "agrimar",
    "agrimasse": "agrimar",
    "agrimassem": "agrimar",
    "agrimasses": "agrimar",
    "agrimaste": "agrimar",
    "agrimastes": "agrimar",
    "agrimava": "agrimar",
    "agrimavam": "agrimar",
    "agrimavas": "agrimar",
    "agrime": "agrimar",
    "agrimei": "agrimar",
    "agrimeis": "agrimar",
    "agrimem": "agrimar",
    "agrimemo": "agrimar",
    "agrimemos": "agrimar",
    "agrimensa": "agrimensar",
    "agrimensada": "agrimensar",
    "agrimensadas": "agrimensar",
    "agrimensado": "agrimensar",
    "agrimensados": "agrimensar",
    "agrimensai": "agrimensar",
    "agrimensais": "agrimensar",
    "agrimensam": "agrimensar",
    "agrimensamo": "agrimensar",
    "agrimensamos": "agrimensar",
    "agrimensando": "agrimensar",
    "agrimensara": "agrimensar",
    "agrimensaram": "agrimensar",
    "agrimensaras": "agrimensar",
    "agrimensarde": "agrimensar",
    "agrimensardes": "agrimensar",
    "agrimensare": "agrimensar",
    "agrimensarei": "agrimensar",
    "agrimensareis": "agrimensar",
    "agrimensarem": "agrimensar",
    "agrimensaremos": "agrimensar",
    "agrimensares": "agrimensar",
    "agrimensaria": "agrimensar",
    "agrimensariam": "agrimensar",
    "agrimensarias": "agrimensar",
    "agrimensarmo": "agrimensar",
    "agrimensarmos": "agrimensar",
    "agrimensará": "agrimensar",
    "agrimensarás": "agrimensar",
    "agrimensarão": "agrimensar",
    "agrimensaríamos": "agrimensar",
    "agrimensaríeis": "agrimensar",
    "agrimensas": "agrimensar",
    "agrimensasse": "agrimensar",
    "agrimensassem": "agrimensar",
    "agrimensasses": "agrimensar",
    "agrimensaste": "agrimensar",
    "agrimensastes": "agrimensar",
    "agrimensava": "agrimensar",
    "agrimensavam": "agrimensar",
    "agrimensavas": "agrimensar",
    "agrimense": "agrimensar",
    "agrimensei": "agrimensar",
    "agrimenseis": "agrimensar",
    "agrimensem": "agrimensar",
    "agrimensemo": "agrimensar",
    "agrimensemos": "agrimensar",
    "agrimenses": "agrimensar",
    "agrimenso": "agrimensar",
    "agrimensora": "agrimensor",
    "agrimensoras": "agrimensor",
    "agrimensores": "agrimensor",
    "agrimensou": "agrimensar",
    "agrimensuras": "agrimensura",
    "agrimensá": "agrimensar",
    "agrimensámo": "agrimensar",
    "agrimensámos": "agrimensar",
    "agrimensáramo": "agrimensar",
    "agrimensáramos": "agrimensar",
    "agrimensárei": "agrimensar",
    "agrimensáreis": "agrimensar",
    "agrimensásseis": "agrimensar",
    "agrimensássemos": "agrimensar",
    "agrimensávamo": "agrimensar",
    "agrimensávamos": "agrimensar",
    "agrimensávei": "agrimensar",
    "agrimensáveis": "agrimensar",
    "agrimensões": "agrimensão",
    "agrimes": "agrimar",
    "agrimo": "agrimar",
    "agrimou": "agrimar",
    "agrimá": "agrimar",
    "agrimámo": "agrimar",
    "agrimámos": "agrimar",
    "agrimáramo": "agrimar",
    "agrimáramos": "agrimar",
    "agrimárei": "agrimar",
    "agrimáreis": "agrimar",
    "agrimásseis": "agrimar",
    "agrimássemos": "agrimar",
    "agrimávamo": "agrimar",
    "agrimávamos": "agrimar",
    "agrimávei": "agrimar",
    "agrimáveis": "agrimar",
    "agrimónias": "agrimónia",
    "agrinalda": "agrinaldar",
    "agrinaldada": "agrinaldar",
    "agrinaldadas": "agrinaldar",
    "agrinaldado": "agrinaldar",
    "agrinaldados": "agrinaldar",
    "agrinaldai": "agrinaldar",
    "agrinaldais": "agrinaldar",
    "agrinaldam": "agrinaldar",
    "agrinaldamo": "agrinaldar",
    "agrinaldamos": "agrinaldar",
    "agrinaldando": "agrinaldar",
    "agrinaldara": "agrinaldar",
    "agrinaldaram": "agrinaldar",
    "agrinaldaras": "agrinaldar",
    "agrinaldarde": "agrinaldar",
    "agrinaldardes": "agrinaldar",
    "agrinaldare": "agrinaldar",
    "agrinaldarei": "agrinaldar",
    "agrinaldareis": "agrinaldar",
    "agrinaldarem": "agrinaldar",
    "agrinaldaremos": "agrinaldar",
    "agrinaldares": "agrinaldar",
    "agrinaldaria": "agrinaldar",
    "agrinaldariam": "agrinaldar",
    "agrinaldarias": "agrinaldar",
    "agrinaldarmo": "agrinaldar",
    "agrinaldarmos": "agrinaldar",
    "agrinaldará": "agrinaldar",
    "agrinaldarás": "agrinaldar",
    "agrinaldarão": "agrinaldar",
    "agrinaldaríamos": "agrinaldar",
    "agrinaldaríeis": "agrinaldar",
    "agrinaldas": "agrinaldar",
    "agrinaldasse": "agrinaldar",
    "agrinaldassem": "agrinaldar",
    "agrinaldasses": "agrinaldar",
    "agrinaldaste": "agrinaldar",
    "agrinaldastes": "agrinaldar",
    "agrinaldava": "agrinaldar",
    "agrinaldavam": "agrinaldar",
    "agrinaldavas": "agrinaldar",
    "agrinalde": "agrinaldar",
    "agrinaldei": "agrinaldar",
    "agrinaldeis": "agrinaldar",
    "agrinaldem": "agrinaldar",
    "agrinaldemo": "agrinaldar",
    "agrinaldemos": "agrinaldar",
    "agrinaldes": "agrinaldar",
    "agrinaldo": "agrinaldar",
    "agrinaldou": "agrinaldar",
    "agrinaldá": "agrinaldar",
    "agrinaldámo": "agrinaldar",
    "agrinaldámos": "agrinaldar",
    "agrinaldáramo": "agrinaldar",
    "agrinaldáramos": "agrinaldar",
    "agrinaldárei": "agrinaldar",
    "agrinaldáreis": "agrinaldar",
    "agrinaldásseis": "agrinaldar",
    "agrinaldássemos": "agrinaldar",
    "agrinaldávamo": "agrinaldar",
    "agrinaldávamos": "agrinaldar",
    "agrinaldávei": "agrinaldar",
    "agrinaldáveis": "agrinaldar",
    "agriotas": "agriota",
    "agripas": "agripa",
    "agripenes": "agripene",
    "agripinas": "agripina",
    "agripnias": "agripnia",
    "agrisalha": "agrisalhar",
    "agrisalhada": "agrisalhar",
    "agrisalhadas": "agrisalhar",
    "agrisalhado": "agrisalhar",
    "agrisalhados": "agrisalhar",
    "agrisalhai": "agrisalhar",
    "agrisalhais": "agrisalhar",
    "agrisalham": "agrisalhar",
    "agrisalhamo": "agrisalhar",
    "agrisalhamos": "agrisalhar",
    "agrisalhando": "agrisalhar",
    "agrisalhara": "agrisalhar",
    "agrisalharam": "agrisalhar",
    "agrisalharas": "agrisalhar",
    "agrisalharde": "agrisalhar",
    "agrisalhardes": "agrisalhar",
    "agrisalhare": "agrisalhar",
    "agrisalharei": "agrisalhar",
    "agrisalhareis": "agrisalhar",
    "agrisalharem": "agrisalhar",
    "agrisalharemos": "agrisalhar",
    "agrisalhares": "agrisalhar",
    "agrisalharia": "agrisalhar",
    "agrisalhariam": "agrisalhar",
    "agrisalharias": "agrisalhar",
    "agrisalharmo": "agrisalhar",
    "agrisalharmos": "agrisalhar",
    "agrisalhará": "agrisalhar",
    "agrisalharás": "agrisalhar",
    "agrisalharão": "agrisalhar",
    "agrisalharíamos": "agrisalhar",
    "agrisalharíeis": "agrisalhar",
    "agrisalhas": "agrisalhar",
    "agrisalhasse": "agrisalhar",
    "agrisalhassem": "agrisalhar",
    "agrisalhasses": "agrisalhar",
    "agrisalhaste": "agrisalhar",
    "agrisalhastes": "agrisalhar",
    "agrisalhava": "agrisalhar",
    "agrisalhavam": "agrisalhar",
    "agrisalhavas": "agrisalhar",
    "agrisalhe": "agrisalhar",
    "agrisalhei": "agrisalhar",
    "agrisalheis": "agrisalhar",
    "agrisalhem": "agrisalhar",
    "agrisalhemo": "agrisalhar",
    "agrisalhemos": "agrisalhar",
    "agrisalhes": "agrisalhar",
    "agrisalho": "agrisalhar",
    "agrisalhou": "agrisalhar",
    "agrisalhá": "agrisalhar",
    "agrisalhámo": "agrisalhar",
    "agrisalhámos": "agrisalhar",
    "agrisalháramo": "agrisalhar",
    "agrisalháramos": "agrisalhar",
    "agrisalhárei": "agrisalhar",
    "agrisalháreis": "agrisalhar",
    "agrisalhásseis": "agrisalhar",
    "agrisalhássemos": "agrisalhar",
    "agrisalhávamo": "agrisalhar",
    "agrisalhávamos": "agrisalhar",
    "agrisalhávei": "agrisalhar",
    "agrisalháveis": "agrisalhar",
    "agriófaga": "agriófago",
    "agriófagas": "agriófago",
    "agriófagos": "agriófago",
    "agriões": "agrião",
    "agroalimentares": "agroalimentar",
    "agrogeologias": "agrogeologia",
    "agrografias": "agrografia",
    "agrográfica": "agrográfico",
    "agrográficas": "agrográfico",
    "agrográficos": "agrográfico",
    "agroindustriais": "agroindustrial",
    "agroindústrias": "agroindústria",
    "agrologias": "agrologia",
    "agrológica": "agrológico",
    "agrológicas": "agrológico",
    "agrológicos": "agrológico",
    "agromanias": "agromania",
    "agromaníaca": "agromaníaco",
    "agromaníacas": "agromaníaco",
    "agromaníacos": "agromaníaco",
    "agronometrias": "agronometria",
    "agronomias": "agronomia",
    "agronómica": "agronómico",
    "agronómicas": "agronómico",
    "agronómicos": "agronómico",
    "agropecuária": "agropecuário",
    "agropecuárias": "agropecuário",
    "agropecuários": "agropecuário",
    "agroquímicas": "agroquímica",
    "agrores": "agror",
    "agros": "agro",
    "agrosseirada": "agrosseirado",
    "agrosseiradas": "agrosseirado",
    "agrosseirados": "agrosseirado",
    "agrovias": "agrovia",
    "agrumela": "agrumelar",
    "agrumelada": "agrumelar",
    "agrumeladas": "agrumelar",
    "agrumelado": "agrumelar",
    "agrumelados": "agrumelar",
    "agrumelai": "agrumelar",
    "agrumelais": "agrumelar",
    "agrumelam": "agrumelar",
    "agrumelamo": "agrumelar",
    "agrumelamos": "agrumelar",
    "agrumelando": "agrumelar",
    "agrumelara": "agrumelar",
    "agrumelaram": "agrumelar",
    "agrumelaras": "agrumelar",
    "agrumelarde": "agrumelar",
    "agrumelardes": "agrumelar",
    "agrumelare": "agrumelar",
    "agrumelarei": "agrumelar",
    "agrumelareis": "agrumelar",
    "agrumelarem": "agrumelar",
    "agrumelaremos": "agrumelar",
    "agrumelares": "agrumelar",
    "agrumelaria": "agrumelar",
    "agrumelariam": "agrumelar",
    "agrumelarias": "agrumelar",
    "agrumelarmo": "agrumelar",
    "agrumelarmos": "agrumelar",
    "agrumelará": "agrumelar",
    "agrumelarás": "agrumelar",
    "agrumelarão": "agrumelar",
    "agrumelaríamos": "agrumelar",
    "agrumelaríeis": "agrumelar",
    "agrumelas": "agrumelar",
    "agrumelasse": "agrumelar",
    "agrumelassem": "agrumelar",
    "agrumelasses": "agrumelar",
    "agrumelaste": "agrumelar",
    "agrumelastes": "agrumelar",
    "agrumelava": "agrumelar",
    "agrumelavam": "agrumelar",
    "agrumelavas": "agrumelar",
    "agrumele": "agrumelar",
    "agrumelei": "agrumelar",
    "agrumeleis": "agrumelar",
    "agrumelem": "agrumelar",
    "agrumelemo": "agrumelar",
    "agrumelemos": "agrumelar",
    "agrumeles": "agrumelar",
    "agrumelo": "agrumelar",
    "agrumelou": "agrumelar",
    "agrumelá": "agrumelar",
    "agrumelámo": "agrumelar",
    "agrumelámos": "agrumelar",
    "agrumeláramo": "agrumelar",
    "agrumeláramos": "agrumelar",
    "agrumelárei": "agrumelar",
    "agrumeláreis": "agrumelar",
    "agrumelásseis": "agrumelar",
    "agrumelássemos": "agrumelar",
    "agrumelávamo": "agrumelar",
    "agrumelávamos": "agrumelar",
    "agrumelávei": "agrumelar",
    "agrumeláveis": "agrumelar",
    "agrumula": "agrumular",
    "agrumulada": "agrumular",
    "agrumuladas": "agrumular",
    "agrumulado": "agrumular",
    "agrumulados": "agrumular",
    "agrumulai": "agrumular",
    "agrumulais": "agrumular",
    "agrumulam": "agrumular",
    "agrumulamo": "agrumular",
    "agrumulamos": "agrumular",
    "agrumulando": "agrumular",
    "agrumulara": "agrumular",
    "agrumularam": "agrumular",
    "agrumularas": "agrumular",
    "agrumularde": "agrumular",
    "agrumulardes": "agrumular",
    "agrumulare": "agrumular",
    "agrumularei": "agrumular",
    "agrumulareis": "agrumular",
    "agrumularem": "agrumular",
    "agrumularemos": "agrumular",
    "agrumulares": "agrumular",
    "agrumularia": "agrumular",
    "agrumulariam": "agrumular",
    "agrumularias": "agrumular",
    "agrumularmo": "agrumular",
    "agrumularmos": "agrumular",
    "agrumulará": "agrumular",
    "agrumularás": "agrumular",
    "agrumularão": "agrumular",
    "agrumularíamos": "agrumular",
    "agrumularíeis": "agrumular",
    "agrumulas": "agrumular",
    "agrumulasse": "agrumular",
    "agrumulassem": "agrumular",
    "agrumulasses": "agrumular",
    "agrumulaste": "agrumular",
    "agrumulastes": "agrumular",
    "agrumulava": "agrumular",
    "agrumulavam": "agrumular",
    "agrumulavas": "agrumular",
    "agrumule": "agrumular",
    "agrumulei": "agrumular",
    "agrumuleis": "agrumular",
    "agrumulem": "agrumular",
    "agrumulemo": "agrumular",
    "agrumulemos": "agrumular",
    "agrumules": "agrumular",
    "agrumulo": "agrumular",
    "agrumulou": "agrumular",
    "agrumulá": "agrumular",
    "agrumulámo": "agrumular",
    "agrumulámos": "agrumular",
    "agrumuláramo": "agrumular",
    "agrumuláramos": "agrumular",
    "agrumulárei": "agrumular",
    "agrumuláreis": "agrumular",
    "agrumulásseis": "agrumular",
    "agrumulássemos": "agrumular",
    "agrumulávamo": "agrumular",
    "agrumulávamos": "agrumular",
    "agrumulávei": "agrumular",
    "agrumuláveis": "agrumular",
    "agrupa": "agrupar",
    "agrupada": "agrupar",
    "agrupadas": "agrupar",
    "agrupadinha": "agrupado",
    "agrupadinhas": "agrupado",
    "agrupadinho": "agrupado",
    "agrupadinhos": "agrupado",
    "agrupadita": "agrupado",
    "agrupaditas": "agrupado",
    "agrupadito": "agrupado",
    "agrupaditos": "agrupado",
    "agrupado": "agrupar",
    "agrupados": "agrupar",
    "agrupadíssima": "agrupado",
    "agrupadíssimas": "agrupado",
    "agrupadíssimo": "agrupado",
    "agrupadíssimos": "agrupado",
    "agrupai": "agrupar",
    "agrupais": "agrupar",
    "agrupam": "agrupar",
    "agrupamentos": "agrupamento",
    "agrupamo": "agrupar",
    "agrupamos": "agrupar",
    "agrupando": "agrupar",
    "agrupara": "agrupar",
    "agruparam": "agrupar",
    "agruparas": "agrupar",
    "agruparde": "agrupar",
    "agrupardes": "agrupar",
    "agrupare": "agrupar",
    "agruparei": "agrupar",
    "agrupareis": "agrupar",
    "agruparem": "agrupar",
    "agruparemos": "agrupar",
    "agrupares": "agrupar",
    "agruparia": "agrupar",
    "agrupariam": "agrupar",
    "agruparias": "agrupar",
    "agruparmo": "agrupar",
    "agruparmos": "agrupar",
    "agrupará": "agrupar",
    "agruparás": "agrupar",
    "agruparão": "agrupar",
    "agruparíamos": "agrupar",
    "agruparíeis": "agrupar",
    "agrupas": "agrupar",
    "agrupasse": "agrupar",
    "agrupassem": "agrupar",
    "agrupasses": "agrupar",
    "agrupaste": "agrupar",
    "agrupastes": "agrupar",
    "agrupava": "agrupar",
    "agrupavam": "agrupar",
    "agrupavas": "agrupar",
    "agrupe": "agrupar",
    "agrupei": "agrupar",
    "agrupeis": "agrupar",
    "agrupem": "agrupar",
    "agrupemo": "agrupar",
    "agrupemos": "agrupar",
    "agrupes": "agrupar",
    "agrupo": "agrupar",
    "agrupou": "agrupar",
    "agrupá": "agrupar",
    "agrupámo": "agrupar",
    "agrupámos": "agrupar",
    "agrupáramo": "agrupar",
    "agrupáramos": "agrupar",
    "agrupárei": "agrupar",
    "agrupáreis": "agrupar",
    "agrupásseis": "agrupar",
    "agrupássemos": "agrupar",
    "agrupávamo": "agrupar",
    "agrupávamos": "agrupar",
    "agrupávei": "agrupar",
    "agrupáveis": "agrupável",
    "agruras": "agrura",
    "agrária": "agrário",
    "agrárias": "agrário",
    "agrários": "agrário",
    "agréments": "agrément",
    "agrícolas": "agrícola",
    "agróloga": "agrólogo",
    "agrólogas": "agrólogo",
    "agrólogos": "agrólogo",
    "agrónoma": "agrónomo",
    "agrónomas": "agrónomo",
    "agrónomos": "agrónomo",
    "agua": "aguar",
    "aguacates": "aguacate",
    "aguaceiras": "aguaceira",
    "aguaceiros": "aguaceiro",
    "aguacenta": "aguacento",
    "aguacentas": "aguacento",
    "aguacentos": "aguacento",
    "aguachados": "aguachado",
    "aguada": "aguar",
    "aguadas": "aguar",
    "aguadeira": "aguadeiro",
    "aguadeiras": "aguadeiro",
    "aguadeiros": "aguadeiro",
    "aguadentações": "aguadentação",
    "aguadentosa": "aguadentoso",
    "aguadentosas": "aguadentoso",
    "aguadentosos": "aguadentoso",
    "aguadilhas": "aguadilha",
    "aguado": "aguar",
    "aguadora": "aguador",
    "aguadoras": "aguador",
    "aguadores": "aguador",
    "aguados": "aguar",
    "aguadouros": "aguadouro",
    "aguagens": "aguagem",
    "aguai": "aguar",
    "aguais": "aguar",
    "aguam": "aguar",
    "aguamentos": "aguamento",
    "aguamo": "aguar",
    "aguamos": "aguar",
    "aguando": "aguar",
    "aguantes": "aguante",
    "aguapés": "aguapé",
    "aguara": "aguar",
    "aguaram": "aguar",
    "aguaras": "aguar",
    "aguarda": "aguardar",
    "aguardada": "aguardar",
    "aguardadas": "aguardar",
    "aguardado": "aguardar",
    "aguardadora": "aguardador",
    "aguardadoras": "aguardador",
    "aguardadores": "aguardador",
    "aguardados": "aguardar",
    "aguardai": "aguardar",
    "aguardais": "aguardar",
    "aguardam": "aguardar",
    "aguardamo": "aguardar",
    "aguardamos": "aguardar",
    "aguardando": "aguardar",
    "aguardara": "aguardar",
    "aguardaram": "aguardar",
    "aguardaras": "aguardar",
    "aguardarde": "aguardar",
    "aguardardes": "aguardar",
    "aguardare": "aguardar",
    "aguardarei": "aguardar",
    "aguardareis": "aguardar",
    "aguardarem": "aguardar",
    "aguardaremos": "aguardar",
    "aguardares": "aguardar",
    "aguardaria": "aguardar",
    "aguardariam": "aguardar",
    "aguardarias": "aguardar",
    "aguardarmo": "aguardar",
    "aguardarmos": "aguardar",
    "aguardará": "aguardar",
    "aguardarás": "aguardar",
    "aguardarão": "aguardar",
    "aguardaríamos": "aguardar",
    "aguardaríeis": "aguardar",
    "aguardas": "aguardar",
    "aguardasse": "aguardar",
    "aguardassem": "aguardar",
    "aguardasses": "aguardar",
    "aguardaste": "aguardar",
    "aguardastes": "aguardar",
    "aguardava": "aguardar",
    "aguardavam": "aguardar",
    "aguardavas": "aguardar",
    "aguarde": "aguardar",
    "aguardei": "aguardar",
    "aguardeis": "aguardar",
    "aguardem": "aguardar",
    "aguardemo": "aguardar",
    "aguardemos": "aguardar",
    "aguardenta": "aguardentar",
    "aguardentada": "aguardentar",
    "aguardentadas": "aguardentar",
    "aguardentado": "aguardentar",
    "aguardentados": "aguardentar",
    "aguardentai": "aguardentar",
    "aguardentais": "aguardentar",
    "aguardentam": "aguardentar",
    "aguardentamo": "aguardentar",
    "aguardentamos": "aguardentar",
    "aguardentando": "aguardentar",
    "aguardentara": "aguardentar",
    "aguardentaram": "aguardentar",
    "aguardentaras": "aguardentar",
    "aguardentarde": "aguardentar",
    "aguardentardes": "aguardentar",
    "aguardentare": "aguardentar",
    "aguardentarei": "aguardentar",
    "aguardentareis": "aguardentar",
    "aguardentarem": "aguardentar",
    "aguardentaremos": "aguardentar",
    "aguardentares": "aguardentar",
    "aguardentaria": "aguardentar",
    "aguardentariam": "aguardentar",
    "aguardentarias": "aguardentar",
    "aguardentarmo": "aguardentar",
    "aguardentarmos": "aguardentar",
    "aguardentará": "aguardentar",
    "aguardentarás": "aguardentar",
    "aguardentarão": "aguardentar",
    "aguardentaríamos": "aguardentar",
    "aguardentaríeis": "aguardentar",
    "aguardentas": "aguardentar",
    "aguardentasse": "aguardentar",
    "aguardentassem": "aguardentar",
    "aguardentasses": "aguardentar",
    "aguardentaste": "aguardentar",
    "aguardentastes": "aguardentar",
    "aguardentava": "aguardentar",
    "aguardentavam": "aguardentar",
    "aguardentavas": "aguardentar",
    "aguardente": "aguardentar",
    "aguardentei": "aguardentar",
    "aguardenteira": "aguardenteiro",
    "aguardenteiras": "aguardenteiro",
    "aguardenteiros": "aguardenteiro",
    "aguardenteis": "aguardentar",
    "aguardentem": "aguardentar",
    "aguardentemo": "aguardentar",
    "aguardentemos": "aguardentar",
    "aguardentes": "aguardente",
    "aguardentias": "aguardentia",
    "aguardento": "aguardentar",
    "aguardentona": "aguardentão",
    "aguardentonas": "aguardentão",
    "aguardentou": "aguardentar",
    "aguardentá": "aguardentar",
    "aguardentámo": "aguardentar",
    "aguardentámos": "aguardentar",
    "aguardentáramo": "aguardentar",
    "aguardentáramos": "aguardentar",
    "aguardentárei": "aguardentar",
    "aguardentáreis": "aguardentar",
    "aguardentásseis": "aguardentar",
    "aguardentássemos": "aguardentar",
    "aguardentávamo": "aguardentar",
    "aguardentávamos": "aguardentar",
    "aguardentávei": "aguardentar",
    "aguardentáveis": "aguardentar",
    "aguardentões": "aguardentão",
    "aguardes": "aguardar",
    "aguardo": "aguardar",
    "aguardou": "aguardar",
    "aguardá": "aguardar",
    "aguardámo": "aguardar",
    "aguardámos": "aguardar",
    "aguardáramo": "aguardar",
    "aguardáramos": "aguardar",
    "aguardárei": "aguardar",
    "aguardáreis": "aguardar",
    "aguardásseis": "aguardar",
    "aguardássemos": "aguardar",
    "aguardávamo": "aguardar",
    "aguardávamos": "aguardar",
    "aguardávei": "aguardar",
    "aguardáveis": "aguardar",
    "aguare": "aguar",
    "aguarei": "aguar",
    "aguareis": "aguar",
    "aguarela": "aguarelar",
    "aguarelada": "aguarelar",
    "aguareladas": "aguarelar",
    "aguarelado": "aguarelar",
    "aguarelados": "aguarelar",
    "aguarelai": "aguarelar",
    "aguarelais": "aguarelar",
    "aguarelam": "aguarelar",
    "aguarelamo": "aguarelar",
    "aguarelamos": "aguarelar",
    "aguarelando": "aguarelar",
    "aguarelara": "aguarelar",
    "aguarelaram": "aguarelar",
    "aguarelaras": "aguarelar",
    "aguarelarde": "aguarelar",
    "aguarelardes": "aguarelar",
    "aguarelare": "aguarelar",
    "aguarelarei": "aguarelar",
    "aguarelareis": "aguarelar",
    "aguarelarem": "aguarelar",
    "aguarelaremos": "aguarelar",
    "aguarelares": "aguarelar",
    "aguarelaria": "aguarelar",
    "aguarelariam": "aguarelar",
    "aguarelarias": "aguarelar",
    "aguarelarmo": "aguarelar",
    "aguarelarmos": "aguarelar",
    "aguarelará": "aguarelar",
    "aguarelarás": "aguarelar",
    "aguarelarão": "aguarelar",
    "aguarelaríamos": "aguarelar",
    "aguarelaríeis": "aguarelar",
    "aguarelas": "aguarelar",
    "aguarelasse": "aguarelar",
    "aguarelassem": "aguarelar",
    "aguarelasses": "aguarelar",
    "aguarelaste": "aguarelar",
    "aguarelastes": "aguarelar",
    "aguarelava": "aguarelar",
    "aguarelavam": "aguarelar",
    "aguarelavas": "aguarelar",
    "aguarele": "aguarelar",
    "aguarelei": "aguarelar",
    "aguareleis": "aguarelar",
    "aguarelem": "aguarelar",
    "aguarelemo": "aguarelar",
    "aguarelemos": "aguarelar",
    "aguareles": "aguarelar",
    "aguarelistas": "aguarelista",
    "aguarelo": "aguarelar",
    "aguarelou": "aguarelar",
    "aguarelá": "aguarelar",
    "aguarelámo": "aguarelar",
    "aguarelámos": "aguarelar",
    "aguareláramo": "aguarelar",
    "aguareláramos": "aguarelar",
    "aguarelárei": "aguarelar",
    "aguareláreis": "aguarelar",
    "aguarelásseis": "aguarelar",
    "aguarelássemos": "aguarelar",
    "aguarelávamo": "aguarelar",
    "aguarelávamos": "aguarelar",
    "aguarelávei": "aguarelar",
    "aguareláveis": "aguarelar",
    "aguarem": "aguar",
    "aguaremos": "aguar",
    "aguarenta": "aguarentar",
    "aguarentada": "aguarentar",
    "aguarentadas": "aguarentar",
    "aguarentado": "aguarentar",
    "aguarentadora": "aguarentador",
    "aguarentadoras": "aguarentador",
    "aguarentadores": "aguarentador",
    "aguarentados": "aguarentar",
    "aguarentai": "aguarentar",
    "aguarentais": "aguarentar",
    "aguarentam": "aguarentar",
    "aguarentamo": "aguarentar",
    "aguarentamos": "aguarentar",
    "aguarentando": "aguarentar",
    "aguarentara": "aguarentar",
    "aguarentaram": "aguarentar",
    "aguarentaras": "aguarentar",
    "aguarentarde": "aguarentar",
    "aguarentardes": "aguarentar",
    "aguarentare": "aguarentar",
    "aguarentarei": "aguarentar",
    "aguarentareis": "aguarentar",
    "aguarentarem": "aguarentar",
    "aguarentaremos": "aguarentar",
    "aguarentares": "aguarentar",
    "aguarentaria": "aguarentar",
    "aguarentariam": "aguarentar",
    "aguarentarias": "aguarentar",
    "aguarentarmo": "aguarentar",
    "aguarentarmos": "aguarentar",
    "aguarentará": "aguarentar",
    "aguarentarás": "aguarentar",
    "aguarentarão": "aguarentar",
    "aguarentaríamos": "aguarentar",
    "aguarentaríeis": "aguarentar",
    "aguarentas": "aguarentar",
    "aguarentasse": "aguarentar",
    "aguarentassem": "aguarentar",
    "aguarentasses": "aguarentar",
    "aguarentaste": "aguarentar",
    "aguarentastes": "aguarentar",
    "aguarentava": "aguarentar",
    "aguarentavam": "aguarentar",
    "aguarentavas": "aguarentar",
    "aguarente": "aguarentar",
    "aguarentei": "aguarentar",
    "aguarenteis": "aguarentar",
    "aguarentem": "aguarentar",
    "aguarentemo": "aguarentar",
    "aguarentemos": "aguarentar",
    "aguarentes": "aguarentar",
    "aguarento": "aguarentar",
    "aguarentou": "aguarentar",
    "aguarentá": "aguarentar",
    "aguarentámo": "aguarentar",
    "aguarentámos": "aguarentar",
    "aguarentáramo": "aguarentar",
    "aguarentáramos": "aguarentar",
    "aguarentárei": "aguarentar",
    "aguarentáreis": "aguarentar",
    "aguarentásseis": "aguarentar",
    "aguarentássemos": "aguarentar",
    "aguarentávamo": "aguarentar",
    "aguarentávamos": "aguarentar",
    "aguarentávei": "aguarentar",
    "aguarentáveis": "aguarentar",
    "aguares": "aguar",
    "aguaria": "aguar",
    "aguariam": "aguar",
    "aguarias": "aguar",
    "aguarita": "aguaritar",
    "aguaritada": "aguaritar",
    "aguaritadas": "aguaritar",
    "aguaritado": "aguaritar",
    "aguaritados": "aguaritar",
    "aguaritai": "aguaritar",
    "aguaritais": "aguaritar",
    "aguaritam": "aguaritar",
    "aguaritamo": "aguaritar",
    "aguaritamos": "aguaritar",
    "aguaritando": "aguaritar",
    "aguaritara": "aguaritar",
    "aguaritaram": "aguaritar",
    "aguaritaras": "aguaritar",
    "aguaritarde": "aguaritar",
    "aguaritardes": "aguaritar",
    "aguaritare": "aguaritar",
    "aguaritarei": "aguaritar",
    "aguaritareis": "aguaritar",
    "aguaritarem": "aguaritar",
    "aguaritaremos": "aguaritar",
    "aguaritares": "aguaritar",
    "aguaritaria": "aguaritar",
    "aguaritariam": "aguaritar",
    "aguaritarias": "aguaritar",
    "aguaritarmo": "aguaritar",
    "aguaritarmos": "aguaritar",
    "aguaritará": "aguaritar",
    "aguaritarás": "aguaritar",
    "aguaritarão": "aguaritar",
    "aguaritaríamos": "aguaritar",
    "aguaritaríeis": "aguaritar",
    "aguaritas": "aguaritar",
    "aguaritasse": "aguaritar",
    "aguaritassem": "aguaritar",
    "aguaritasses": "aguaritar",
    "aguaritaste": "aguaritar",
    "aguaritastes": "aguaritar",
    "aguaritava": "aguaritar",
    "aguaritavam": "aguaritar",
    "aguaritavas": "aguaritar",
    "aguarite": "aguaritar",
    "aguaritei": "aguaritar",
    "aguariteis": "aguaritar",
    "aguaritem": "aguaritar",
    "aguaritemo": "aguaritar",
    "aguaritemos": "aguaritar",
    "aguarites": "aguaritar",
    "aguarito": "aguaritar",
    "aguaritou": "aguaritar",
    "aguaritá": "aguaritar",
    "aguaritámo": "aguaritar",
    "aguaritámos": "aguaritar",
    "aguaritáramo": "aguaritar",
    "aguaritáramos": "aguaritar",
    "aguaritárei": "aguaritar",
    "aguaritáreis": "aguaritar",
    "aguaritásseis": "aguaritar",
    "aguaritássemos": "aguaritar",
    "aguaritávamo": "aguaritar",
    "aguaritávamos": "aguaritar",
    "aguaritávei": "aguaritar",
    "aguaritáveis": "aguaritar",
    "aguarmo": "aguar",
    "aguarmos": "aguar",
    "aguará": "aguar",
    "aguarás": "aguar",
    "aguarão": "aguar",
    "aguaríamos": "aguar",
    "aguaríeis": "aguar",
    "aguas": "aguar",
    "aguasse": "aguar",
    "aguassem": "aguar",
    "aguasses": "aguar",
    "aguaste": "aguar",
    "aguastes": "aguar",
    "aguateira": "aguateiro",
    "aguateiras": "aguateiro",
    "aguateiros": "aguateiro",
    "aguava": "aguar",
    "aguavam": "aguar",
    "aguavas": "aguar",
    "aguaxados": "aguaxado",
    "aguazis": "aguazil",
    "aguaçais": "aguaçal",
    "aguaças": "aguaça",
    "aguce": "aguçar",
    "agucei": "aguçar",
    "aguceis": "aguçar",
    "agucem": "aguçar",
    "agucemo": "aguçar",
    "agucemos": "aguçar",
    "aguces": "aguçar",
    "aguda": "agudo",
    "agudas": "agudo",
    "agudelhos": "agudelho",
    "agudes": "agude",
    "agudezas": "agudeza",
    "agudiza": "agudizar",
    "agudizada": "agudizar",
    "agudizadas": "agudizar",
    "agudizado": "agudizar",
    "agudizados": "agudizar",
    "agudizai": "agudizar",
    "agudizais": "agudizar",
    "agudizam": "agudizar",
    "agudizamo": "agudizar",
    "agudizamos": "agudizar",
    "agudizando": "agudizar",
    "agudizara": "agudizar",
    "agudizaram": "agudizar",
    "agudizaras": "agudizar",
    "agudizarde": "agudizar",
    "agudizardes": "agudizar",
    "agudizare": "agudizar",
    "agudizarei": "agudizar",
    "agudizareis": "agudizar",
    "agudizarem": "agudizar",
    "agudizaremos": "agudizar",
    "agudizares": "agudizar",
    "agudizaria": "agudizar",
    "agudizariam": "agudizar",
    "agudizarias": "agudizar",
    "agudizarmo": "agudizar",
    "agudizarmos": "agudizar",
    "agudizará": "agudizar",
    "agudizarás": "agudizar",
    "agudizarão": "agudizar",
    "agudizaríamos": "agudizar",
    "agudizaríeis": "agudizar",
    "agudizas": "agudizar",
    "agudizasse": "agudizar",
    "agudizassem": "agudizar",
    "agudizasses": "agudizar",
    "agudizaste": "agudizar",
    "agudizastes": "agudizar",
    "agudizava": "agudizar",
    "agudizavam": "agudizar",
    "agudizavas": "agudizar",
    "agudizações": "agudização",
    "agudize": "agudizar",
    "agudizei": "agudizar",
    "agudizeis": "agudizar",
    "agudizem": "agudizar",
    "agudizemo": "agudizar",
    "agudizemos": "agudizar",
    "agudizes": "agudizar",
    "agudizo": "agudizar",
    "agudizou": "agudizar",
    "agudizá": "agudizar",
    "agudizámo": "agudizar",
    "agudizámos": "agudizar",
    "agudizáramo": "agudizar",
    "agudizáramos": "agudizar",
    "agudizárei": "agudizar",
    "agudizáreis": "agudizar",
    "agudizásseis": "agudizar",
    "agudizássemos": "agudizar",
    "agudizávamo": "agudizar",
    "agudizávamos": "agudizar",
    "agudizávei": "agudizar",
    "agudizáveis": "agudizar",
    "agudos": "agudo",
    "agudíssima": "agudo",
    "agudíssimas": "agudo",
    "agudíssimo": "agudo",
    "agudíssimos": "agudo",
    "aguei": "aguar",
    "agueira": "agueirar",
    "agueirada": "agueirar",
    "agueiradas": "agueirar",
    "agueirado": "agueirar",
    "agueirados": "agueirar",
    "agueirai": "agueirar",
    "agueirais": "agueirar",
    "agueiram": "agueirar",
    "agueiramo": "agueirar",
    "agueiramos": "agueirar",
    "agueirando": "agueirar",
    "agueirara": "agueirar",
    "agueiraram": "agueirar",
    "agueiraras": "agueirar",
    "agueirarde": "agueirar",
    "agueirardes": "agueirar",
    "agueirare": "agueirar",
    "agueirarei": "agueirar",
    "agueirareis": "agueirar",
    "agueirarem": "agueirar",
    "agueiraremos": "agueirar",
    "agueirares": "agueirar",
    "agueiraria": "agueirar",
    "agueirariam": "agueirar",
    "agueirarias": "agueirar",
    "agueirarmo": "agueirar",
    "agueirarmos": "agueirar",
    "agueirará": "agueirar",
    "agueirarás": "agueirar",
    "agueirarão": "agueirar",
    "agueiraríamos": "agueirar",
    "agueiraríeis": "agueirar",
    "agueiras": "agueirar",
    "agueirasse": "agueirar",
    "agueirassem": "agueirar",
    "agueirasses": "agueirar",
    "agueiraste": "agueirar",
    "agueirastes": "agueirar",
    "agueirava": "agueirar",
    "agueiravam": "agueirar",
    "agueiravas": "agueirar",
    "agueire": "agueirar",
    "agueirei": "agueirar",
    "agueireis": "agueirar",
    "agueirem": "agueirar",
    "agueiremo": "agueirar",
    "agueiremos": "agueirar",
    "agueires": "agueirar",
    "agueiro": "agueirar",
    "agueiros": "agueiro",
    "agueirou": "agueirar",
    "agueirá": "agueirar",
    "agueirámo": "agueirar",
    "agueirámos": "agueirar",
    "agueiráramo": "agueirar",
    "agueiráramos": "agueirar",
    "agueirárei": "agueirar",
    "agueiráreis": "agueirar",
    "agueirásseis": "agueirar",
    "agueirássemos": "agueirar",
    "agueirávamo": "agueirar",
    "agueirávamos": "agueirar",
    "agueirávei": "agueirar",
    "agueiráveis": "agueirar",
    "agueis": "aguar",
    "aguemo": "aguar",
    "aguemos": "aguar",
    "aguenta": "aguentar",
    "aguentada": "aguentar",
    "aguentadas": "aguentar",
    "aguentado": "aguentar",
    "aguentadora": "aguentador",
    "aguentadoras": "aguentador",
    "aguentadores": "aguentador",
    "aguentados": "aguentar",
    "aguentai": "aguentar",
    "aguentais": "aguentar",
    "aguentam": "aguentar",
    "aguentamo": "aguentar",
    "aguentamos": "aguentar",
    "aguentando": "aguentar",
    "aguentara": "aguentar",
    "aguentaram": "aguentar",
    "aguentaras": "aguentar",
    "aguentarde": "aguentar",
    "aguentardes": "aguentar",
    "aguentare": "aguentar",
    "aguentarei": "aguentar",
    "aguentareis": "aguentar",
    "aguentarem": "aguentar",
    "aguentaremos": "aguentar",
    "aguentares": "aguentar",
    "aguentaria": "aguentar",
    "aguentariam": "aguentar",
    "aguentarias": "aguentar",
    "aguentarmo": "aguentar",
    "aguentarmos": "aguentar",
    "aguentará": "aguentar",
    "aguentarás": "aguentar",
    "aguentarão": "aguentar",
    "aguentaríamos": "aguentar",
    "aguentaríeis": "aguentar",
    "aguentas": "aguentar",
    "aguentasse": "aguentar",
    "aguentassem": "aguentar",
    "aguentasses": "aguentar",
    "aguentaste": "aguentar",
    "aguentastes": "aguentar",
    "aguentava": "aguentar",
    "aguentavam": "aguentar",
    "aguentavas": "aguentar",
    "aguente": "aguentar",
    "aguentei": "aguentar",
    "aguenteis": "aguentar",
    "aguentem": "aguentar",
    "aguentemo": "aguentar",
    "aguentemos": "aguentar",
    "aguentes": "aguentar",
    "aguento": "aguentar",
    "aguentou": "aguentar",
    "aguentá": "aguentar",
    "aguentámo": "aguentar",
    "aguentámos": "aguentar",
    "aguentáramo": "aguentar",
    "aguentáramos": "aguentar",
    "aguentárei": "aguentar",
    "aguentáreis": "aguentar",
    "aguentásseis": "aguentar",
    "aguentássemos": "aguentar",
    "aguentávamo": "aguentar",
    "aguentávamos": "aguentar",
    "aguentávei": "aguentar",
    "aguentáveis": "aguentável",
    "aguerreada": "aguerrear",
    "aguerreadas": "aguerrear",
    "aguerreado": "aguerrear",
    "aguerreados": "aguerrear",
    "aguerreai": "aguerrear",
    "aguerreais": "aguerrear",
    "aguerreamo": "aguerrear",
    "aguerreamos": "aguerrear",
    "aguerreando": "aguerrear",
    "aguerreara": "aguerrear",
    "aguerrearam": "aguerrear",
    "aguerrearas": "aguerrear",
    "aguerrearde": "aguerrear",
    "aguerreardes": "aguerrear",
    "aguerreare": "aguerrear",
    "aguerrearei": "aguerrear",
    "aguerreareis": "aguerrear",
    "aguerrearem": "aguerrear",
    "aguerrearemos": "aguerrear",
    "aguerreares": "aguerrear",
    "aguerrearia": "aguerrear",
    "aguerreariam": "aguerrear",
    "aguerrearias": "aguerrear",
    "aguerrearmo": "aguerrear",
    "aguerrearmos": "aguerrear",
    "aguerreará": "aguerrear",
    "aguerrearás": "aguerrear",
    "aguerrearão": "aguerrear",
    "aguerrearíamos": "aguerrear",
    "aguerrearíeis": "aguerrear",
    "aguerreasse": "aguerrear",
    "aguerreassem": "aguerrear",
    "aguerreasses": "aguerrear",
    "aguerreaste": "aguerrear",
    "aguerreastes": "aguerrear",
    "aguerreava": "aguerrear",
    "aguerreavam": "aguerrear",
    "aguerreavas": "aguerrear",
    "aguerreações": "aguerreação",
    "aguerreei": "aguerrear",
    "aguerreeis": "aguerrear",
    "aguerreemo": "aguerrear",
    "aguerreemos": "aguerrear",
    "aguerreia": "aguerrear",
    "aguerreiam": "aguerrear",
    "aguerreias": "aguerrear",
    "aguerreie": "aguerrear",
    "aguerreiem": "aguerrear",
    "aguerreies": "aguerrear",
    "aguerreio": "aguerrear",
    "aguerreou": "aguerrear",
    "aguerreá": "aguerrear",
    "aguerreámo": "aguerrear",
    "aguerreámos": "aguerrear",
    "aguerreáramo": "aguerrear",
    "aguerreáramos": "aguerrear",
    "aguerreárei": "aguerrear",
    "aguerreáreis": "aguerrear",
    "aguerreásseis": "aguerrear",
    "aguerreássemos": "aguerrear",
    "aguerreávamo": "aguerrear",
    "aguerreávamos": "aguerrear",
    "aguerreávei": "aguerrear",
    "aguerreáveis": "aguerrear",
    "aguerri": "aguerrir",
    "aguerria": "aguerrir",
    "aguerriam": "aguerrir",
    "aguerrias": "aguerrir",
    "aguerrida": "aguerrir",
    "aguerridas": "aguerrir",
    "aguerrido": "aguerrir",
    "aguerridos": "aguerrir",
    "aguerridíssima": "aguerrido",
    "aguerridíssimas": "aguerrido",
    "aguerridíssimo": "aguerrido",
    "aguerridíssimos": "aguerrido",
    "aguerrilha": "aguerrilhar",
    "aguerrilhada": "aguerrilhar",
    "aguerrilhadas": "aguerrilhar",
    "aguerrilhado": "aguerrilhar",
    "aguerrilhados": "aguerrilhar",
    "aguerrilhai": "aguerrilhar",
    "aguerrilhais": "aguerrilhar",
    "aguerrilham": "aguerrilhar",
    "aguerrilhamo": "aguerrilhar",
    "aguerrilhamos": "aguerrilhar",
    "aguerrilhando": "aguerrilhar",
    "aguerrilhara": "aguerrilhar",
    "aguerrilharam": "aguerrilhar",
    "aguerrilharas": "aguerrilhar",
    "aguerrilharde": "aguerrilhar",
    "aguerrilhardes": "aguerrilhar",
    "aguerrilhare": "aguerrilhar",
    "aguerrilharei": "aguerrilhar",
    "aguerrilhareis": "aguerrilhar",
    "aguerrilharem": "aguerrilhar",
    "aguerrilharemos": "aguerrilhar",
    "aguerrilhares": "aguerrilhar",
    "aguerrilharia": "aguerrilhar",
    "aguerrilhariam": "aguerrilhar",
    "aguerrilharias": "aguerrilhar",
    "aguerrilharmo": "aguerrilhar",
    "aguerrilharmos": "aguerrilhar",
    "aguerrilhará": "aguerrilhar",
    "aguerrilharás": "aguerrilhar",
    "aguerrilharão": "aguerrilhar",
    "aguerrilharíamos": "aguerrilhar",
    "aguerrilharíeis": "aguerrilhar",
    "aguerrilhas": "aguerrilhar",
    "aguerrilhasse": "aguerrilhar",
    "aguerrilhassem": "aguerrilhar",
    "aguerrilhasses": "aguerrilhar",
    "aguerrilhaste": "aguerrilhar",
    "aguerrilhastes": "aguerrilhar",
    "aguerrilhava": "aguerrilhar",
    "aguerrilhavam": "aguerrilhar",
    "aguerrilhavas": "aguerrilhar",
    "aguerrilhe": "aguerrilhar",
    "aguerrilhei": "aguerrilhar",
    "aguerrilheis": "aguerrilhar",
    "aguerrilhem": "aguerrilhar",
    "aguerrilhemo": "aguerrilhar",
    "aguerrilhemos": "aguerrilhar",
    "aguerrilhes": "aguerrilhar",
    "aguerrilho": "aguerrilhar",
    "aguerrilhou": "aguerrilhar",
    "aguerrilhá": "aguerrilhar",
    "aguerrilhámo": "aguerrilhar",
    "aguerrilhámos": "aguerrilhar",
    "aguerrilháramo": "aguerrilhar",
    "aguerrilháramos": "aguerrilhar",
    "aguerrilhárei": "aguerrilhar",
    "aguerrilháreis": "aguerrilhar",
    "aguerrilhásseis": "aguerrilhar",
    "aguerrilhássemos": "aguerrilhar",
    "aguerrilhávamo": "aguerrilhar",
    "aguerrilhávamos": "aguerrilhar",
    "aguerrilhávei": "aguerrilhar",
    "aguerrilháveis": "aguerrilhar",
    "aguerrimentos": "aguerrimento",
    "aguerrimo": "aguerrir",
    "aguerrimos": "aguerrir",
    "aguerrindo": "aguerrir",
    "aguerrira": "aguerrir",
    "aguerriram": "aguerrir",
    "aguerriras": "aguerrir",
    "aguerrirde": "aguerrir",
    "aguerrirdes": "aguerrir",
    "aguerrire": "aguerrir",
    "aguerrirei": "aguerrir",
    "aguerrireis": "aguerrir",
    "aguerrirem": "aguerrir",
    "aguerriremos": "aguerrir",
    "aguerrires": "aguerrir",
    "aguerriria": "aguerrir",
    "aguerririam": "aguerrir",
    "aguerririas": "aguerrir",
    "aguerrirmo": "aguerrir",
    "aguerrirmos": "aguerrir",
    "aguerrirá": "aguerrir",
    "aguerrirás": "aguerrir",
    "aguerrirão": "aguerrir",
    "aguerriríamos": "aguerrir",
    "aguerriríeis": "aguerrir",
    "aguerris": "aguerrir",
    "aguerrisse": "aguerrir",
    "aguerrissem": "aguerrir",
    "aguerrisses": "aguerrir",
    "aguerriste": "aguerrir",
    "aguerristes": "aguerrir",
    "aguerriu": "aguerrir",
    "aguerríamo": "aguerrir",
    "aguerríamos": "aguerrir",
    "aguerríei": "aguerrir",
    "aguerríeis": "aguerrir",
    "aguerríramo": "aguerrir",
    "aguerríramos": "aguerrir",
    "aguerrírei": "aguerrir",
    "aguerríreis": "aguerrir",
    "aguerrísseis": "aguerrir",
    "aguerríssemos": "aguerrir",
    "agues": "aguar",
    "aguia": "aguiar",
    "aguiada": "aguiar",
    "aguiadas": "aguiar",
    "aguiado": "aguiar",
    "aguiados": "aguiar",
    "aguiai": "aguiar",
    "aguiais": "aguiar",
    "aguiam": "aguiar",
    "aguiamo": "aguiar",
    "aguiamos": "aguiar",
    "aguiando": "aguiar",
    "aguiara": "aguiar",
    "aguiaram": "aguiar",
    "aguiaras": "aguiar",
    "aguiardes": "aguiar",
    "aguiarei": "aguiar",
    "aguiareis": "aguiar",
    "aguiarem": "aguiar",
    "aguiaremos": "aguiar",
    "aguiarenses": "aguiarense",
    "aguiares": "aguiar",
    "aguiaria": "aguiar",
    "aguiariam": "aguiar",
    "aguiarias": "aguiar",
    "aguiarmo": "aguiar",
    "aguiarmos": "aguiar",
    "aguiará": "aguiar",
    "aguiarás": "aguiar",
    "aguiarão": "aguiar",
    "aguiaríamos": "aguiar",
    "aguiaríeis": "aguiar",
    "aguias": "aguiar",
    "aguiasse": "aguiar",
    "aguiassem": "aguiar",
    "aguiasses": "aguiar",
    "aguiaste": "aguiar",
    "aguiastes": "aguiar",
    "aguiava": "aguiar",
    "aguiavam": "aguiar",
    "aguiavas": "aguiar",
    "aguie": "aguiar",
    "aguiei": "aguiar",
    "aguieiros": "aguieiro",
    "aguieis": "aguiar",
    "aguiem": "aguiar",
    "aguiemo": "aguiar",
    "aguiemos": "aguiar",
    "aguies": "aguiar",
    "aguietas": "aguieta",
    "aguilha": "aguilhar",
    "aguilhada": "aguilhar",
    "aguilhadas": "aguilhar",
    "aguilhado": "aguilhar",
    "aguilhados": "aguilhar",
    "aguilhai": "aguilhar",
    "aguilhais": "aguilhar",
    "aguilham": "aguilhar",
    "aguilhamo": "aguilhar",
    "aguilhamos": "aguilhar",
    "aguilhando": "aguilhar",
    "aguilhara": "aguilhar",
    "aguilharam": "aguilhar",
    "aguilharas": "aguilhar",
    "aguilharde": "aguilhar",
    "aguilhardes": "aguilhar",
    "aguilhare": "aguilhar",
    "aguilharei": "aguilhar",
    "aguilhareis": "aguilhar",
    "aguilharem": "aguilhar",
    "aguilharemos": "aguilhar",
    "aguilhares": "aguilhar",
    "aguilharia": "aguilhar",
    "aguilhariam": "aguilhar",
    "aguilharias": "aguilhar",
    "aguilharmo": "aguilhar",
    "aguilharmos": "aguilhar",
    "aguilhará": "aguilhar",
    "aguilharás": "aguilhar",
    "aguilharão": "aguilhar",
    "aguilharíamos": "aguilhar",
    "aguilharíeis": "aguilhar",
    "aguilhas": "aguilhar",
    "aguilhasse": "aguilhar",
    "aguilhassem": "aguilhar",
    "aguilhasses": "aguilhar",
    "aguilhaste": "aguilhar",
    "aguilhastes": "aguilhar",
    "aguilhava": "aguilhar",
    "aguilhavam": "aguilhar",
    "aguilhavas": "aguilhar",
    "aguilhe": "aguilhar",
    "aguilhei": "aguilhar",
    "aguilheis": "aguilhar",
    "aguilhem": "aguilhar",
    "aguilhemo": "aguilhar",
    "aguilhemos": "aguilhar",
    "aguilhes": "aguilhar",
    "aguilho": "aguilhar",
    "aguilhoa": "aguilhoar",
    "aguilhoada": "aguilhoar",
    "aguilhoadas": "aguilhoar",
    "aguilhoadelas": "aguilhoadela",
    "aguilhoado": "aguilhoar",
    "aguilhoadora": "aguilhoador",
    "aguilhoadoras": "aguilhoador",
    "aguilhoadores": "aguilhoador",
    "aguilhoados": "aguilhoar",
    "aguilhoai": "aguilhoar",
    "aguilhoais": "aguilhoar",
    "aguilhoam": "aguilhoar",
    "aguilhoamentos": "aguilhoamento",
    "aguilhoamo": "aguilhoar",
    "aguilhoamos": "aguilhoar",
    "aguilhoando": "aguilhoar",
    "aguilhoara": "aguilhoar",
    "aguilhoaram": "aguilhoar",
    "aguilhoaras": "aguilhoar",
    "aguilhoarde": "aguilhoar",
    "aguilhoardes": "aguilhoar",
    "aguilhoare": "aguilhoar",
    "aguilhoarei": "aguilhoar",
    "aguilhoareis": "aguilhoar",
    "aguilhoarem": "aguilhoar",
    "aguilhoaremos": "aguilhoar",
    "aguilhoares": "aguilhoar",
    "aguilhoaria": "aguilhoar",
    "aguilhoariam": "aguilhoar",
    "aguilhoarias": "aguilhoar",
    "aguilhoarmo": "aguilhoar",
    "aguilhoarmos": "aguilhoar",
    "aguilhoará": "aguilhoar",
    "aguilhoarás": "aguilhoar",
    "aguilhoarão": "aguilhoar",
    "aguilhoaríamos": "aguilhoar",
    "aguilhoaríeis": "aguilhoar",
    "aguilhoas": "aguilhoar",
    "aguilhoasse": "aguilhoar",
    "aguilhoassem": "aguilhoar",
    "aguilhoasses": "aguilhoar",
    "aguilhoaste": "aguilhoar",
    "aguilhoastes": "aguilhoar",
    "aguilhoava": "aguilhoar",
    "aguilhoavam": "aguilhoar",
    "aguilhoavas": "aguilhoar",
    "aguilhoe": "aguilhoar",
    "aguilhoei": "aguilhoar",
    "aguilhoeiros": "aguilhoeiro",
    "aguilhoeis": "aguilhoar",
    "aguilhoem": "aguilhoar",
    "aguilhoemo": "aguilhoar",
    "aguilhoemos": "aguilhoar",
    "aguilhoes": "aguilhoar",
    "aguilhoo": "aguilhoar",
    "aguilhoou": "aguilhoar",
    "aguilhou": "aguilhar",
    "aguilhoá": "aguilhoar",
    "aguilhoámo": "aguilhoar",
    "aguilhoámos": "aguilhoar",
    "aguilhoáramo": "aguilhoar",
    "aguilhoáramos": "aguilhoar",
    "aguilhoárei": "aguilhoar",
    "aguilhoáreis": "aguilhoar",
    "aguilhoásseis": "aguilhoar",
    "aguilhoássemos": "aguilhoar",
    "aguilhoávamo": "aguilhoar",
    "aguilhoávamos": "aguilhoar",
    "aguilhoávei": "aguilhoar",
    "aguilhoáveis": "aguilhoar",
    "aguilhá": "aguilhar",
    "aguilhámo": "aguilhar",
    "aguilhámos": "aguilhar",
    "aguilháramo": "aguilhar",
    "aguilháramos": "aguilhar",
    "aguilhárei": "aguilhar",
    "aguilháreis": "aguilhar",
    "aguilhásseis": "aguilhar",
    "aguilhássemos": "aguilhar",
    "aguilhávamo": "aguilhar",
    "aguilhávamos": "aguilhar",
    "aguilhávei": "aguilhar",
    "aguilháveis": "aguilhar",
    "aguilhões": "aguilhão",
    "aguinha": "água",
    "aguinhas": "água",
    "aguio": "aguiar",
    "aguiotos": "aguioto",
    "aguiou": "aguiar",
    "aguirra": "aguerrir",
    "aguirrais": "aguerrir",
    "aguirram": "aguerrir",
    "aguirramo": "aguerrir",
    "aguirramos": "aguerrir",
    "aguirras": "aguerrir",
    "aguirre": "aguerrir",
    "aguirrem": "aguerrir",
    "aguirres": "aguerrir",
    "aguirro": "aguerrir",
    "aguisa": "aguisar",
    "aguisada": "aguisar",
    "aguisadas": "aguisar",
    "aguisado": "aguisar",
    "aguisados": "aguisar",
    "aguisai": "aguisar",
    "aguisais": "aguisar",
    "aguisam": "aguisar",
    "aguisamo": "aguisar",
    "aguisamos": "aguisar",
    "aguisando": "aguisar",
    "aguisara": "aguisar",
    "aguisaram": "aguisar",
    "aguisaras": "aguisar",
    "aguisarde": "aguisar",
    "aguisardes": "aguisar",
    "aguisare": "aguisar",
    "aguisarei": "aguisar",
    "aguisareis": "aguisar",
    "aguisarem": "aguisar",
    "aguisaremos": "aguisar",
    "aguisares": "aguisar",
    "aguisaria": "aguisar",
    "aguisariam": "aguisar",
    "aguisarias": "aguisar",
    "aguisarmo": "aguisar",
    "aguisarmos": "aguisar",
    "aguisará": "aguisar",
    "aguisarás": "aguisar",
    "aguisarão": "aguisar",
    "aguisaríamos": "aguisar",
    "aguisaríeis": "aguisar",
    "aguisas": "aguisar",
    "aguisasse": "aguisar",
    "aguisassem": "aguisar",
    "aguisasses": "aguisar",
    "aguisaste": "aguisar",
    "aguisastes": "aguisar",
    "aguisava": "aguisar",
    "aguisavam": "aguisar",
    "aguisavas": "aguisar",
    "aguise": "aguisar",
    "aguisei": "aguisar",
    "aguiseis": "aguisar",
    "aguisem": "aguisar",
    "aguisemo": "aguisar",
    "aguisemos": "aguisar",
    "aguises": "aguisar",
    "aguiso": "aguisar",
    "aguisou": "aguisar",
    "aguistas": "aguista",
    "aguisá": "aguisar",
    "aguisámo": "aguisar",
    "aguisámos": "aguisar",
    "aguisáramo": "aguisar",
    "aguisáramos": "aguisar",
    "aguisárei": "aguisar",
    "aguisáreis": "aguisar",
    "aguisásseis": "aguisar",
    "aguisássemos": "aguisar",
    "aguisávamo": "aguisar",
    "aguisávamos": "aguisar",
    "aguisávei": "aguisar",
    "aguisáveis": "aguisar",
    "aguita": "água",
    "aguitarra": "aguitarrar",
    "aguitarrada": "aguitarrar",
    "aguitarradas": "aguitarrar",
    "aguitarrado": "aguitarrar",
    "aguitarrados": "aguitarrar",
    "aguitarrai": "aguitarrar",
    "aguitarrais": "aguitarrar",
    "aguitarram": "aguitarrar",
    "aguitarramo": "aguitarrar",
    "aguitarramos": "aguitarrar",
    "aguitarrando": "aguitarrar",
    "aguitarrara": "aguitarrar",
    "aguitarraram": "aguitarrar",
    "aguitarraras": "aguitarrar",
    "aguitarrarde": "aguitarrar",
    "aguitarrardes": "aguitarrar",
    "aguitarrare": "aguitarrar",
    "aguitarrarei": "aguitarrar",
    "aguitarrareis": "aguitarrar",
    "aguitarrarem": "aguitarrar",
    "aguitarraremos": "aguitarrar",
    "aguitarrares": "aguitarrar",
    "aguitarraria": "aguitarrar",
    "aguitarrariam": "aguitarrar",
    "aguitarrarias": "aguitarrar",
    "aguitarrarmo": "aguitarrar",
    "aguitarrarmos": "aguitarrar",
    "aguitarrará": "aguitarrar",
    "aguitarrarás": "aguitarrar",
    "aguitarrarão": "aguitarrar",
    "aguitarraríamos": "aguitarrar",
    "aguitarraríeis": "aguitarrar",
    "aguitarras": "aguitarrar",
    "aguitarrasse": "aguitarrar",
    "aguitarrassem": "aguitarrar",
    "aguitarrasses": "aguitarrar",
    "aguitarraste": "aguitarrar",
    "aguitarrastes": "aguitarrar",
    "aguitarrava": "aguitarrar",
    "aguitarravam": "aguitarrar",
    "aguitarravas": "aguitarrar",
    "aguitarre": "aguitarrar",
    "aguitarrei": "aguitarrar",
    "aguitarreis": "aguitarrar",
    "aguitarrem": "aguitarrar",
    "aguitarremo": "aguitarrar",
    "aguitarremos": "aguitarrar",
    "aguitarres": "aguitarrar",
    "aguitarro": "aguitarrar",
    "aguitarrou": "aguitarrar",
    "aguitarrá": "aguitarrar",
    "aguitarrámo": "aguitarrar",
    "aguitarrámos": "aguitarrar",
    "aguitarráramo": "aguitarrar",
    "aguitarráramos": "aguitarrar",
    "aguitarrárei": "aguitarrar",
    "aguitarráreis": "aguitarrar",
    "aguitarrásseis": "aguitarrar",
    "aguitarrássemos": "aguitarrar",
    "aguitarrávamo": "aguitarrar",
    "aguitarrávamos": "aguitarrar",
    "aguitarrávei": "aguitarrar",
    "aguitarráveis": "aguitarrar",
    "aguitas": "água",
    "aguiámo": "aguiar",
    "aguiámos": "aguiar",
    "aguiáramo": "aguiar",
    "aguiáramos": "aguiar",
    "aguiáreis": "aguiar",
    "aguiásseis": "aguiar",
    "aguiássemos": "aguiar",
    "aguiávamo": "aguiar",
    "aguiávamos": "aguiar",
    "aguiáveis": "aguiar",
    "agulha": "agulhar",
    "agulhada": "agulhar",
    "agulhadas": "agulhar",
    "agulhado": "agulhar",
    "agulhados": "agulhar",
    "agulhadouros": "agulhadouro",
    "agulhagens": "agulhagem",
    "agulhai": "agulhar",
    "agulhais": "agulhar",
    "agulham": "agulhar",
    "agulhamo": "agulhar",
    "agulhamos": "agulhar",
    "agulhando": "agulhar",
    "agulhara": "agulhar",
    "agulharam": "agulhar",
    "agulharas": "agulhar",
    "agulharde": "agulhar",
    "agulhardes": "agulhar",
    "agulhare": "agulhar",
    "agulharei": "agulhar",
    "agulhareis": "agulhar",
    "agulharem": "agulhar",
    "agulharemos": "agulhar",
    "agulhares": "agulhar",
    "agulharia": "agulhar",
    "agulhariam": "agulhar",
    "agulharias": "agulhar",
    "agulharmo": "agulhar",
    "agulharmos": "agulhar",
    "agulhará": "agulhar",
    "agulharás": "agulhar",
    "agulharão": "agulhar",
    "agulharíamos": "agulhar",
    "agulharíeis": "agulhar",
    "agulhas": "agulhar",
    "agulhasse": "agulhar",
    "agulhassem": "agulhar",
    "agulhasses": "agulhar",
    "agulhaste": "agulhar",
    "agulhastes": "agulhar",
    "agulhava": "agulhar",
    "agulhavam": "agulhar",
    "agulhavas": "agulhar",
    "agulhe": "agulhar",
    "agulheada": "agulheado",
    "agulheadas": "agulheado",
    "agulheados": "agulheado",
    "agulhei": "agulhar",
    "agulheiras": "agulheira",
    "agulheiros": "agulheiro",
    "agulheis": "agulhar",
    "agulhem": "agulhar",
    "agulhemo": "agulhar",
    "agulhemos": "agulhar",
    "agulhenta": "agulhento",
    "agulhentas": "agulhento",
    "agulhentos": "agulhento",
    "agulhes": "agulhar",
    "agulhetas": "agulheta",
    "agulhinha": "agulha",
    "agulhinhas": "agulha",
    "agulhita": "agulha",
    "agulhitas": "agulha",
    "agulho": "agulhar",
    "agulhou": "agulhar",
    "agulhá": "agulhar",
    "agulhámo": "agulhar",
    "agulhámos": "agulhar",
    "agulháramo": "agulhar",
    "agulháramos": "agulhar",
    "agulhárei": "agulhar",
    "agulháreis": "agulhar",
    "agulhásseis": "agulhar",
    "agulhássemos": "agulhar",
    "agulhávamo": "agulhar",
    "agulhávamos": "agulhar",
    "agulhávei": "agulhar",
    "agulháveis": "agulhar",
    "agulhões": "agulhão",
    "aguo": "aguar",
    "aguou": "aguar",
    "agustias": "agustia",
    "aguá": "aguar",
    "aguámo": "aguar",
    "aguámos": "aguar",
    "aguáramo": "aguar",
    "aguáramos": "aguar",
    "aguárei": "aguar",
    "aguáreis": "aguar",
    "aguásseis": "aguar",
    "aguássemos": "aguar",
    "aguávamo": "aguar",
    "aguávamos": "aguar",
    "aguávei": "aguar",
    "aguáveis": "aguar",
    "aguça": "aguçar",
    "aguçada": "aguçar",
    "aguçadas": "aguçar",
    "aguçadeiras": "aguçadeira",
    "aguçado": "aguçar",
    "aguçadora": "aguçador",
    "aguçadoras": "aguçador",
    "aguçadores": "aguçador",
    "aguçados": "aguçar",
    "aguçadouras": "aguçadoura",
    "aguçaduras": "aguçadura",
    "aguçai": "aguçar",
    "aguçais": "aguçar",
    "aguçam": "aguçar",
    "aguçamentos": "aguçamento",
    "aguçamo": "aguçar",
    "aguçamos": "aguçar",
    "aguçando": "aguçar",
    "aguçara": "aguçar",
    "aguçaram": "aguçar",
    "aguçaras": "aguçar",
    "aguçarde": "aguçar",
    "aguçardes": "aguçar",
    "aguçare": "aguçar",
    "aguçarei": "aguçar",
    "aguçareis": "aguçar",
    "aguçarem": "aguçar",
    "aguçaremos": "aguçar",
    "aguçares": "aguçar",
    "aguçaria": "aguçar",
    "aguçariam": "aguçar",
    "aguçarias": "aguçar",
    "aguçarmo": "aguçar",
    "aguçarmos": "aguçar",
    "aguçará": "aguçar",
    "aguçarás": "aguçar",
    "aguçarão": "aguçar",
    "aguçaríamos": "aguçar",
    "aguçaríeis": "aguçar",
    "aguças": "aguçar",
    "aguçasse": "aguçar",
    "aguçassem": "aguçar",
    "aguçasses": "aguçar",
    "aguçaste": "aguçar",
    "aguçastes": "aguçar",
    "aguçava": "aguçar",
    "aguçavam": "aguçar",
    "aguçavas": "aguçar",
    "aguço": "aguçar",
    "aguços": "aguço",
    "aguçou": "aguçar",
    "aguçá": "aguçar",
    "aguçámo": "aguçar",
    "aguçámos": "aguçar",
    "aguçáramo": "aguçar",
    "aguçáramos": "aguçar",
    "aguçárei": "aguçar",
    "aguçáreis": "aguçar",
    "aguçásseis": "aguçar",
    "aguçássemos": "aguçar",
    "aguçávamo": "aguçar",
    "aguçávamos": "aguçar",
    "aguçávei": "aguçar",
    "aguçáveis": "aguçar",
    "agáricos": "agárico",
    "agás": "agá",
    "agátea": "agáteo",
    "agáteas": "agáteo",
    "agáteos": "agáteo",
    "agâmica": "agâmico",
    "agâmicas": "agâmico",
    "agâmicos": "agâmico",
    "agâmidas": "agâmida",
    "agências": "agência",
    "agíamo": "agir",
    "agíamos": "agir",
    "agíeis": "agir",
    "agíramo": "agir",
    "agíramos": "agir",
    "agíreis": "agir",
    "agísseis": "agir",
    "agíssemos": "agir",
    "agógica": "agógico",
    "agógicas": "agógico",
    "agógicos": "agógico",
    "agónica": "agónico",
    "agónicas": "agónico",
    "agónicos": "agónico",
    "agónidas": "agónida",
    "agúe": "aguar",
    "agúem": "aguar",
    "agúes": "aguar",
    "aia": "aio",
    "aiada": "aiar",
    "aiadas": "aiar",
    "aiado": "aiar",
    "aiados": "aiar",
    "aiai": "aiar",
    "aiais": "aiar",
    "aiam": "aiar",
    "aiamo": "aiar",
    "aiamos": "aiar",
    "aiando": "aiar",
    "aiapanas": "aiapana",
    "aiara": "aiar",
    "aiaram": "aiar",
    "aiaras": "aiar",
    "aiardes": "aiar",
    "aiarei": "aiar",
    "aiareis": "aiar",
    "aiarem": "aiar",
    "aiaremos": "aiar",
    "aiares": "aiar",
    "aiaria": "aiar",
    "aiariam": "aiar",
    "aiarias": "aiar",
    "aiarmo": "aiar",
    "aiarmos": "aiar",
    "aiará": "aiar",
    "aiarás": "aiar",
    "aiarão": "aiar",
    "aiaríamos": "aiar",
    "aiaríeis": "aiar",
    "aias": "aio",
    "aiasse": "aiar",
    "aiassem": "aiar",
    "aiasses": "aiar",
    "aiaste": "aiar",
    "aiastes": "aiar",
    "aiatolás": "aiatolá",
    "aiava": "aiar",
    "aiavam": "aiar",
    "aiavas": "aiar",
    "aidos": "aido",
    "aie": "aiar",
    "aiei": "aiar",
    "aieis": "aiar",
    "aiem": "aiar",
    "aiemo": "aiar",
    "aiemos": "aiar",
    "aies": "aiar",
    "ailanticulturas": "ailanticultura",
    "ailantinas": "ailantina",
    "ailantos": "ailanto",
    "ailerons": "aileron",
    "aimarás": "aimará",
    "aimoreenses": "aimoreense",
    "aimorés": "aimoré",
    "aio": "aiar",
    "aiolas": "aiola",
    "aios": "aio",
    "aiou": "aiar",
    "aipos": "aipo",
    "airada": "airado",
    "airadas": "airado",
    "airados": "airado",
    "airbags": "airbag",
    "airis": "airi",
    "airogas": "airoga",
    "airos": "airo",
    "airosa": "airoso",
    "airosas": "airoso",
    "airosias": "airosia",
    "airosidades": "airosidade",
    "airosos": "airoso",
    "airós": "airó",
    "ais": "ai",
    "aitás": "aitá",
    "aiuateris": "aiuateri",
    "aivados": "aivado",
    "aivecas": "aiveca",
    "aivões": "aivão",
    "aixes": "aixe",
    "aizoácea": "aizoáceo",
    "aizoáceas": "aizoáceo",
    "aizoáceos": "aizoáceo",
    "aiámo": "aiar",
    "aiámos": "aiar",
    "aiáramo": "aiar",
    "aiáramos": "aiar",
    "aiáreis": "aiar",
    "aiásseis": "aiar",
    "aiássemos": "aiar",
    "aiávamo": "aiar",
    "aiávamos": "aiar",
    "aiáveis": "aiar",
    "aja": "agir",
    "ajaeza": "ajaezar",
    "ajaezada": "ajaezar",
    "ajaezadas": "ajaezar",
    "ajaezado": "ajaezar",
    "ajaezados": "ajaezar",
    "ajaezai": "ajaezar",
    "ajaezais": "ajaezar",
    "ajaezam": "ajaezar",
    "ajaezamo": "ajaezar",
    "ajaezamos": "ajaezar",
    "ajaezando": "ajaezar",
    "ajaezara": "ajaezar",
    "ajaezaram": "ajaezar",
    "ajaezaras": "ajaezar",
    "ajaezarde": "ajaezar",
    "ajaezardes": "ajaezar",
    "ajaezare": "ajaezar",
    "ajaezarei": "ajaezar",
    "ajaezareis": "ajaezar",
    "ajaezarem": "ajaezar",
    "ajaezaremos": "ajaezar",
    "ajaezares": "ajaezar",
    "ajaezaria": "ajaezar",
    "ajaezariam": "ajaezar",
    "ajaezarias": "ajaezar",
    "ajaezarmo": "ajaezar",
    "ajaezarmos": "ajaezar",
    "ajaezará": "ajaezar",
    "ajaezarás": "ajaezar",
    "ajaezarão": "ajaezar",
    "ajaezaríamos": "ajaezar",
    "ajaezaríeis": "ajaezar",
    "ajaezas": "ajaezar",
    "ajaezasse": "ajaezar",
    "ajaezassem": "ajaezar",
    "ajaezasses": "ajaezar",
    "ajaezaste": "ajaezar",
    "ajaezastes": "ajaezar",
    "ajaezava": "ajaezar",
    "ajaezavam": "ajaezar",
    "ajaezavas": "ajaezar",
    "ajaeze": "ajaezar",
    "ajaezei": "ajaezar",
    "ajaezeis": "ajaezar",
    "ajaezem": "ajaezar",
    "ajaezemo": "ajaezar",
    "ajaezemos": "ajaezar",
    "ajaezes": "ajaezar",
    "ajaezo": "ajaezar",
    "ajaezou": "ajaezar",
    "ajaezá": "ajaezar",
    "ajaezámo": "ajaezar",
    "ajaezámos": "ajaezar",
    "ajaezáramo": "ajaezar",
    "ajaezáramos": "ajaezar",
    "ajaezárei": "ajaezar",
    "ajaezáreis": "ajaezar",
    "ajaezásseis": "ajaezar",
    "ajaezássemos": "ajaezar",
    "ajaezávamo": "ajaezar",
    "ajaezávamos": "ajaezar",
    "ajaezávei": "ajaezar",
    "ajaezáveis": "ajaezar",
    "ajais": "agir",
    "ajam": "agir",
    "ajambra": "ajambrar",
    "ajambrada": "ajambrar",
    "ajambradas": "ajambrar",
    "ajambrado": "ajambrar",
    "ajambrados": "ajambrar",
    "ajambrai": "ajambrar",
    "ajambrais": "ajambrar",
    "ajambram": "ajambrar",
    "ajambramo": "ajambrar",
    "ajambramos": "ajambrar",
    "ajambrando": "ajambrar",
    "ajambrara": "ajambrar",
    "ajambraram": "ajambrar",
    "ajambraras": "ajambrar",
    "ajambrarde": "ajambrar",
    "ajambrardes": "ajambrar",
    "ajambrare": "ajambrar",
    "ajambrarei": "ajambrar",
    "ajambrareis": "ajambrar",
    "ajambrarem": "ajambrar",
    "ajambraremos": "ajambrar",
    "ajambrares": "ajambrar",
    "ajambraria": "ajambrar",
    "ajambrariam": "ajambrar",
    "ajambrarias": "ajambrar",
    "ajambrarmo": "ajambrar",
    "ajambrarmos": "ajambrar",
    "ajambrará": "ajambrar",
    "ajambrarás": "ajambrar",
    "ajambrarão": "ajambrar",
    "ajambraríamos": "ajambrar",
    "ajambraríeis": "ajambrar",
    "ajambras": "ajambrar",
    "ajambrasse": "ajambrar",
    "ajambrassem": "ajambrar",
    "ajambrasses": "ajambrar",
    "ajambraste": "ajambrar",
    "ajambrastes": "ajambrar",
    "ajambrava": "ajambrar",
    "ajambravam": "ajambrar",
    "ajambravas": "ajambrar",
    "ajambre": "ajambrar",
    "ajambrei": "ajambrar",
    "ajambreis": "ajambrar",
    "ajambrem": "ajambrar",
    "ajambremo": "ajambrar",
    "ajambremos": "ajambrar",
    "ajambres": "ajambrar",
    "ajambro": "ajambrar",
    "ajambrou": "ajambrar",
    "ajambrá": "ajambrar",
    "ajambrámo": "ajambrar",
    "ajambrámos": "ajambrar",
    "ajambráramo": "ajambrar",
    "ajambráramos": "ajambrar",
    "ajambrárei": "ajambrar",
    "ajambráreis": "ajambrar",
    "ajambrásseis": "ajambrar",
    "ajambrássemos": "ajambrar",
    "ajambrávamo": "ajambrar",
    "ajambrávamos": "ajambrar",
    "ajambrávei": "ajambrar",
    "ajambráveis": "ajambrar",
    "ajamo": "agir",
    "ajamos": "agir",
    "ajanelada": "ajanelado",
    "ajaneladas": "ajanelado",
    "ajanelados": "ajanelado",
    "ajanota": "ajanotar",
    "ajanotada": "ajanotar",
    "ajanotadas": "ajanotar",
    "ajanotado": "ajanotar",
    "ajanotados": "ajanotar",
    "ajanotai": "ajanotar",
    "ajanotais": "ajanotar",
    "ajanotam": "ajanotar",
    "ajanotamo": "ajanotar",
    "ajanotamos": "ajanotar",
    "ajanotando": "ajanotar",
    "ajanotara": "ajanotar",
    "ajanotaram": "ajanotar",
    "ajanotaras": "ajanotar",
    "ajanotarde": "ajanotar",
    "ajanotardes": "ajanotar",
    "ajanotare": "ajanotar",
    "ajanotarei": "ajanotar",
    "ajanotareis": "ajanotar",
    "ajanotarem": "ajanotar",
    "ajanotaremos": "ajanotar",
    "ajanotares": "ajanotar",
    "ajanotaria": "ajanotar",
    "ajanotariam": "ajanotar",
    "ajanotarias": "ajanotar",
    "ajanotarmo": "ajanotar",
    "ajanotarmos": "ajanotar",
    "ajanotará": "ajanotar",
    "ajanotarás": "ajanotar",
    "ajanotarão": "ajanotar",
    "ajanotaríamos": "ajanotar",
    "ajanotaríeis": "ajanotar",
    "ajanotas": "ajanotar",
    "ajanotasse": "ajanotar",
    "ajanotassem": "ajanotar",
    "ajanotasses": "ajanotar",
    "ajanotaste": "ajanotar",
    "ajanotastes": "ajanotar",
    "ajanotava": "ajanotar",
    "ajanotavam": "ajanotar",
    "ajanotavas": "ajanotar",
    "ajanote": "ajanotar",
    "ajanotei": "ajanotar",
    "ajanoteis": "ajanotar",
    "ajanotem": "ajanotar",
    "ajanotemo": "ajanotar",
    "ajanotemos": "ajanotar",
    "ajanotes": "ajanotar",
    "ajanoto": "ajanotar",
    "ajanotou": "ajanotar",
    "ajanotá": "ajanotar",
    "ajanotámo": "ajanotar",
    "ajanotámos": "ajanotar",
    "ajanotáramo": "ajanotar",
    "ajanotáramos": "ajanotar",
    "ajanotárei": "ajanotar",
    "ajanotáreis": "ajanotar",
    "ajanotásseis": "ajanotar",
    "ajanotássemos": "ajanotar",
    "ajanotávamo": "ajanotar",
    "ajanotávamos": "ajanotar",
    "ajanotávei": "ajanotar",
    "ajanotáveis": "ajanotar",
    "ajantarada": "ajantarado",
    "ajantaradas": "ajantarado",
    "ajantarados": "ajantarado",
    "ajaponesa": "ajaponesar",
    "ajaponesada": "ajaponesar",
    "ajaponesadas": "ajaponesar",
    "ajaponesado": "ajaponesar",
    "ajaponesados": "ajaponesar",
    "ajaponesai": "ajaponesar",
    "ajaponesais": "ajaponesar",
    "ajaponesam": "ajaponesar",
    "ajaponesamo": "ajaponesar",
    "ajaponesamos": "ajaponesar",
    "ajaponesando": "ajaponesar",
    "ajaponesara": "ajaponesar",
    "ajaponesaram": "ajaponesar",
    "ajaponesaras": "ajaponesar",
    "ajaponesarde": "ajaponesar",
    "ajaponesardes": "ajaponesar",
    "ajaponesare": "ajaponesar",
    "ajaponesarei": "ajaponesar",
    "ajaponesareis": "ajaponesar",
    "ajaponesarem": "ajaponesar",
    "ajaponesaremos": "ajaponesar",
    "ajaponesares": "ajaponesar",
    "ajaponesaria": "ajaponesar",
    "ajaponesariam": "ajaponesar",
    "ajaponesarias": "ajaponesar",
    "ajaponesarmo": "ajaponesar",
    "ajaponesarmos": "ajaponesar",
    "ajaponesará": "ajaponesar",
    "ajaponesarás": "ajaponesar",
    "ajaponesarão": "ajaponesar",
    "ajaponesaríamos": "ajaponesar",
    "ajaponesaríeis": "ajaponesar",
    "ajaponesas": "ajaponesar",
    "ajaponesasse": "ajaponesar",
    "ajaponesassem": "ajaponesar",
    "ajaponesasses": "ajaponesar",
    "ajaponesaste": "ajaponesar",
    "ajaponesastes": "ajaponesar",
    "ajaponesava": "ajaponesar",
    "ajaponesavam": "ajaponesar",
    "ajaponesavas": "ajaponesar",
    "ajaponese": "ajaponesar",
    "ajaponesei": "ajaponesar",
    "ajaponeseis": "ajaponesar",
    "ajaponesem": "ajaponesar",
    "ajaponesemo": "ajaponesar",
    "ajaponesemos": "ajaponesar",
    "ajaponeses": "ajaponesar",
    "ajaponeso": "ajaponesar",
    "ajaponesou": "ajaponesar",
    "ajaponesá": "ajaponesar",
    "ajaponesámo": "ajaponesar",
    "ajaponesámos": "ajaponesar",
    "ajaponesáramo": "ajaponesar",
    "ajaponesáramos": "ajaponesar",
    "ajaponesárei": "ajaponesar",
    "ajaponesáreis": "ajaponesar",
    "ajaponesásseis": "ajaponesar",
    "ajaponesássemos": "ajaponesar",
    "ajaponesávamo": "ajaponesar",
    "ajaponesávamos": "ajaponesar",
    "ajaponesávei": "ajaponesar",
    "ajaponesáveis": "ajaponesar",
    "ajardina": "ajardinar",
    "ajardinada": "ajardinar",
    "ajardinadas": "ajardinar",
    "ajardinado": "ajardinar",
    "ajardinados": "ajardinar",
    "ajardinai": "ajardinar",
    "ajardinais": "ajardinar",
    "ajardinam": "ajardinar",
    "ajardinamentos": "ajardinamento",
    "ajardinamo": "ajardinar",
    "ajardinamos": "ajardinar",
    "ajardinando": "ajardinar",
    "ajardinara": "ajardinar",
    "ajardinaram": "ajardinar",
    "ajardinaras": "ajardinar",
    "ajardinarde": "ajardinar",
    "ajardinardes": "ajardinar",
    "ajardinare": "ajardinar",
    "ajardinarei": "ajardinar",
    "ajardinareis": "ajardinar",
    "ajardinarem": "ajardinar",
    "ajardinaremos": "ajardinar",
    "ajardinares": "ajardinar",
    "ajardinaria": "ajardinar",
    "ajardinariam": "ajardinar",
    "ajardinarias": "ajardinar",
    "ajardinarmo": "ajardinar",
    "ajardinarmos": "ajardinar",
    "ajardinará": "ajardinar",
    "ajardinarás": "ajardinar",
    "ajardinarão": "ajardinar",
    "ajardinaríamos": "ajardinar",
    "ajardinaríeis": "ajardinar",
    "ajardinas": "ajardinar",
    "ajardinasse": "ajardinar",
    "ajardinassem": "ajardinar",
    "ajardinasses": "ajardinar",
    "ajardinaste": "ajardinar",
    "ajardinastes": "ajardinar",
    "ajardinava": "ajardinar",
    "ajardinavam": "ajardinar",
    "ajardinavas": "ajardinar",
    "ajardine": "ajardinar",
    "ajardinei": "ajardinar",
    "ajardineis": "ajardinar",
    "ajardinem": "ajardinar",
    "ajardinemo": "ajardinar",
    "ajardinemos": "ajardinar",
    "ajardines": "ajardinar",
    "ajardino": "ajardinar",
    "ajardinou": "ajardinar",
    "ajardiná": "ajardinar",
    "ajardinámo": "ajardinar",
    "ajardinámos": "ajardinar",
    "ajardináramo": "ajardinar",
    "ajardináramos": "ajardinar",
    "ajardinárei": "ajardinar",
    "ajardináreis": "ajardinar",
    "ajardinásseis": "ajardinar",
    "ajardinássemos": "ajardinar",
    "ajardinávamo": "ajardinar",
    "ajardinávamos": "ajardinar",
    "ajardinávei": "ajardinar",
    "ajardináveis": "ajardinável",
    "ajas": "agir",
    "ajaulada": "ajaulado",
    "ajauladas": "ajaulado",
    "ajaulados": "ajaulado",
    "ajavarda": "ajavardar",
    "ajavardada": "ajavardar",
    "ajavardadas": "ajavardar",
    "ajavardado": "ajavardar",
    "ajavardados": "ajavardar",
    "ajavardai": "ajavardar",
    "ajavardais": "ajavardar",
    "ajavardam": "ajavardar",
    "ajavardamo": "ajavardar",
    "ajavardamos": "ajavardar",
    "ajavardando": "ajavardar",
    "ajavardara": "ajavardar",
    "ajavardaram": "ajavardar",
    "ajavardaras": "ajavardar",
    "ajavardarde": "ajavardar",
    "ajavardardes": "ajavardar",
    "ajavardare": "ajavardar",
    "ajavardarei": "ajavardar",
    "ajavardareis": "ajavardar",
    "ajavardarem": "ajavardar",
    "ajavardaremos": "ajavardar",
    "ajavardares": "ajavardar",
    "ajavardaria": "ajavardar",
    "ajavardariam": "ajavardar",
    "ajavardarias": "ajavardar",
    "ajavardarmo": "ajavardar",
    "ajavardarmos": "ajavardar",
    "ajavardará": "ajavardar",
    "ajavardarás": "ajavardar",
    "ajavardarão": "ajavardar",
    "ajavardaríamos": "ajavardar",
    "ajavardaríeis": "ajavardar",
    "ajavardas": "ajavardar",
    "ajavardasse": "ajavardar",
    "ajavardassem": "ajavardar",
    "ajavardasses": "ajavardar",
    "ajavardaste": "ajavardar",
    "ajavardastes": "ajavardar",
    "ajavardava": "ajavardar",
    "ajavardavam": "ajavardar",
    "ajavardavas": "ajavardar",
    "ajavarde": "ajavardar",
    "ajavardei": "ajavardar",
    "ajavardeis": "ajavardar",
    "ajavardem": "ajavardar",
    "ajavardemo": "ajavardar",
    "ajavardemos": "ajavardar",
    "ajavardes": "ajavardar",
    "ajavardo": "ajavardar",
    "ajavardou": "ajavardar",
    "ajavardá": "ajavardar",
    "ajavardámo": "ajavardar",
    "ajavardámos": "ajavardar",
    "ajavardáramo": "ajavardar",
    "ajavardáramos": "ajavardar",
    "ajavardárei": "ajavardar",
    "ajavardáreis": "ajavardar",
    "ajavardásseis": "ajavardar",
    "ajavardássemos": "ajavardar",
    "ajavardávamo": "ajavardar",
    "ajavardávamos": "ajavardar",
    "ajavardávei": "ajavardar",
    "ajavardáveis": "ajavardável",
    "ajeira": "ajeirar",
    "ajeirada": "ajeirar",
    "ajeiradas": "ajeirar",
    "ajeirado": "ajeirar",
    "ajeirados": "ajeirar",
    "ajeirai": "ajeirar",
    "ajeirais": "ajeirar",
    "ajeiram": "ajeirar",
    "ajeiramo": "ajeirar",
    "ajeiramos": "ajeirar",
    "ajeirando": "ajeirar",
    "ajeirara": "ajeirar",
    "ajeiraram": "ajeirar",
    "ajeiraras": "ajeirar",
    "ajeirarde": "ajeirar",
    "ajeirardes": "ajeirar",
    "ajeirare": "ajeirar",
    "ajeirarei": "ajeirar",
    "ajeirareis": "ajeirar",
    "ajeirarem": "ajeirar",
    "ajeiraremos": "ajeirar",
    "ajeirares": "ajeirar",
    "ajeiraria": "ajeirar",
    "ajeirariam": "ajeirar",
    "ajeirarias": "ajeirar",
    "ajeirarmo": "ajeirar",
    "ajeirarmos": "ajeirar",
    "ajeirará": "ajeirar",
    "ajeirarás": "ajeirar",
    "ajeirarão": "ajeirar",
    "ajeiraríamos": "ajeirar",
    "ajeiraríeis": "ajeirar",
    "ajeiras": "ajeirar",
    "ajeirasse": "ajeirar",
    "ajeirassem": "ajeirar",
    "ajeirasses": "ajeirar",
    "ajeiraste": "ajeirar",
    "ajeirastes": "ajeirar",
    "ajeirava": "ajeirar",
    "ajeiravam": "ajeirar",
    "ajeiravas": "ajeirar",
    "ajeire": "ajeirar",
    "ajeirei": "ajeirar",
    "ajeireis": "ajeirar",
    "ajeirem": "ajeirar",
    "ajeiremo": "ajeirar",
    "ajeiremos": "ajeirar",
    "ajeires": "ajeirar",
    "ajeiro": "ajeirar",
    "ajeirou": "ajeirar",
    "ajeirá": "ajeirar",
    "ajeirámo": "ajeirar",
    "ajeirámos": "ajeirar",
    "ajeiráramo": "ajeirar",
    "ajeiráramos": "ajeirar",
    "ajeirárei": "ajeirar",
    "ajeiráreis": "ajeirar",
    "ajeirásseis": "ajeirar",
    "ajeirássemos": "ajeirar",
    "ajeirávamo": "ajeirar",
    "ajeirávamos": "ajeirar",
    "ajeirávei": "ajeirar",
    "ajeiráveis": "ajeirar",
    "ajeita": "ajeitar",
    "ajeitada": "ajeitar",
    "ajeitadas": "ajeitar",
    "ajeitadinha": "ajeitado",
    "ajeitadinhas": "ajeitado",
    "ajeitadinho": "ajeitado",
    "ajeitadinhos": "ajeitado",
    "ajeitadita": "ajeitado",
    "ajeitaditas": "ajeitado",
    "ajeitadito": "ajeitado",
    "ajeitaditos": "ajeitado",
    "ajeitado": "ajeitar",
    "ajeitados": "ajeitar",
    "ajeitadíssima": "ajeitado",
    "ajeitadíssimas": "ajeitado",
    "ajeitadíssimo": "ajeitado",
    "ajeitadíssimos": "ajeitado",
    "ajeitai": "ajeitar",
    "ajeitais": "ajeitar",
    "ajeitam": "ajeitar",
    "ajeitamo": "ajeitar",
    "ajeitamos": "ajeitar",
    "ajeitando": "ajeitar",
    "ajeitara": "ajeitar",
    "ajeitaram": "ajeitar",
    "ajeitaras": "ajeitar",
    "ajeitarde": "ajeitar",
    "ajeitardes": "ajeitar",
    "ajeitare": "ajeitar",
    "ajeitarei": "ajeitar",
    "ajeitareis": "ajeitar",
    "ajeitarem": "ajeitar",
    "ajeitaremos": "ajeitar",
    "ajeitares": "ajeitar",
    "ajeitaria": "ajeitar",
    "ajeitariam": "ajeitar",
    "ajeitarias": "ajeitar",
    "ajeitarmo": "ajeitar",
    "ajeitarmos": "ajeitar",
    "ajeitará": "ajeitar",
    "ajeitarás": "ajeitar",
    "ajeitarão": "ajeitar",
    "ajeitaríamos": "ajeitar",
    "ajeitaríeis": "ajeitar",
    "ajeitas": "ajeitar",
    "ajeitasse": "ajeitar",
    "ajeitassem": "ajeitar",
    "ajeitasses": "ajeitar",
    "ajeitaste": "ajeitar",
    "ajeitastes": "ajeitar",
    "ajeitava": "ajeitar",
    "ajeitavam": "ajeitar",
    "ajeitavas": "ajeitar",
    "ajeite": "ajeitar",
    "ajeitei": "ajeitar",
    "ajeiteis": "ajeitar",
    "ajeitem": "ajeitar",
    "ajeitemo": "ajeitar",
    "ajeitemos": "ajeitar",
    "ajeites": "ajeitar",
    "ajeito": "ajeitar",
    "ajeitou": "ajeitar",
    "ajeitá": "ajeitar",
    "ajeitámo": "ajeitar",
    "ajeitámos": "ajeitar",
    "ajeitáramo": "ajeitar",
    "ajeitáramos": "ajeitar",
    "ajeitárei": "ajeitar",
    "ajeitáreis": "ajeitar",
    "ajeitásseis": "ajeitar",
    "ajeitássemos": "ajeitar",
    "ajeitávamo": "ajeitar",
    "ajeitávamos": "ajeitar",
    "ajeitávei": "ajeitar",
    "ajeitáveis": "ajeitar",
    "ajenis": "ajenil",
    "ajeropigada": "ajeropigado",
    "ajeropigadas": "ajeropigado",
    "ajeropigados": "ajeropigado",
    "ajesuita": "ajesuitar",
    "ajesuitada": "ajesuitar",
    "ajesuitadas": "ajesuitar",
    "ajesuitado": "ajesuitar",
    "ajesuitados": "ajesuitar",
    "ajesuitai": "ajesuitar",
    "ajesuitais": "ajesuitar",
    "ajesuitam": "ajesuitar",
    "ajesuitamo": "ajesuitar",
    "ajesuitamos": "ajesuitar",
    "ajesuitando": "ajesuitar",
    "ajesuitara": "ajesuitar",
    "ajesuitaram": "ajesuitar",
    "ajesuitaras": "ajesuitar",
    "ajesuitarde": "ajesuitar",
    "ajesuitardes": "ajesuitar",
    "ajesuitare": "ajesuitar",
    "ajesuitarei": "ajesuitar",
    "ajesuitareis": "ajesuitar",
    "ajesuitarem": "ajesuitar",
    "ajesuitaremos": "ajesuitar",
    "ajesuitares": "ajesuitar",
    "ajesuitaria": "ajesuitar",
    "ajesuitariam": "ajesuitar",
    "ajesuitarias": "ajesuitar",
    "ajesuitarmo": "ajesuitar",
    "ajesuitarmos": "ajesuitar",
    "ajesuitará": "ajesuitar",
    "ajesuitarás": "ajesuitar",
    "ajesuitarão": "ajesuitar",
    "ajesuitaríamos": "ajesuitar",
    "ajesuitaríeis": "ajesuitar",
    "ajesuitas": "ajesuitar",
    "ajesuitasse": "ajesuitar",
    "ajesuitassem": "ajesuitar",
    "ajesuitasses": "ajesuitar",
    "ajesuitaste": "ajesuitar",
    "ajesuitastes": "ajesuitar",
    "ajesuitava": "ajesuitar",
    "ajesuitavam": "ajesuitar",
    "ajesuitavas": "ajesuitar",
    "ajesuite": "ajesuitar",
    "ajesuitei": "ajesuitar",
    "ajesuiteis": "ajesuitar",
    "ajesuitem": "ajesuitar",
    "ajesuitemo": "ajesuitar",
    "ajesuitemos": "ajesuitar",
    "ajesuites": "ajesuitar",
    "ajesuito": "ajesuitar",
    "ajesuitou": "ajesuitar",
    "ajesuitá": "ajesuitar",
    "ajesuitámo": "ajesuitar",
    "ajesuitámos": "ajesuitar",
    "ajesuitáramo": "ajesuitar",
    "ajesuitáramos": "ajesuitar",
    "ajesuitárei": "ajesuitar",
    "ajesuitáreis": "ajesuitar",
    "ajesuitásseis": "ajesuitar",
    "ajesuitássemos": "ajesuitar",
    "ajesuitávamo": "ajesuitar",
    "ajesuitávamos": "ajesuitar",
    "ajesuitávei": "ajesuitar",
    "ajesuitáveis": "ajesuitar",
    "ajimezes": "ajimez",
    "ajiquites": "ajiquite",
    "ajo": "agir",
    "ajoelha": "ajoelhar",
    "ajoelhada": "ajoelhar",
    "ajoelhadas": "ajoelhar",
    "ajoelhado": "ajoelhar",
    "ajoelhados": "ajoelhar",
    "ajoelhai": "ajoelhar",
    "ajoelhais": "ajoelhar",
    "ajoelham": "ajoelhar",
    "ajoelhamo": "ajoelhar",
    "ajoelhamos": "ajoelhar",
    "ajoelhando": "ajoelhar",
    "ajoelhara": "ajoelhar",
    "ajoelharam": "ajoelhar",
    "ajoelharas": "ajoelhar",
    "ajoelhardes": "ajoelhar",
    "ajoelharei": "ajoelhar",
    "ajoelhareis": "ajoelhar",
    "ajoelharem": "ajoelhar",
    "ajoelharemos": "ajoelhar",
    "ajoelhares": "ajoelhar",
    "ajoelharia": "ajoelhar",
    "ajoelhariam": "ajoelhar",
    "ajoelharias": "ajoelhar",
    "ajoelharmo": "ajoelhar",
    "ajoelharmos": "ajoelhar",
    "ajoelhará": "ajoelhar",
    "ajoelharás": "ajoelhar",
    "ajoelharão": "ajoelhar",
    "ajoelharíamos": "ajoelhar",
    "ajoelharíeis": "ajoelhar",
    "ajoelhas": "ajoelhar",
    "ajoelhasse": "ajoelhar",
    "ajoelhassem": "ajoelhar",
    "ajoelhasses": "ajoelhar",
    "ajoelhaste": "ajoelhar",
    "ajoelhastes": "ajoelhar",
    "ajoelhava": "ajoelhar",
    "ajoelhavam": "ajoelhar",
    "ajoelhavas": "ajoelhar",
    "ajoelhações": "ajoelhação",
    "ajoelhe": "ajoelhar",
    "ajoelhei": "ajoelhar",
    "ajoelheis": "ajoelhar",
    "ajoelhem": "ajoelhar",
    "ajoelhemo": "ajoelhar",
    "ajoelhemos": "ajoelhar",
    "ajoelhes": "ajoelhar",
    "ajoelho": "ajoelhar",
    "ajoelhou": "ajoelhar",
    "ajoelhámo": "ajoelhar",
    "ajoelhámos": "ajoelhar",
    "ajoelháramo": "ajoelhar",
    "ajoelháramos": "ajoelhar",
    "ajoelháreis": "ajoelhar",
    "ajoelhásseis": "ajoelhar",
    "ajoelhássemos": "ajoelhar",
    "ajoelhávamo": "ajoelhar",
    "ajoelhávamos": "ajoelhar",
    "ajoelháveis": "ajoelhar",
    "ajoenetada": "ajoenetado",
    "ajoenetadas": "ajoenetado",
    "ajoenetados": "ajoenetado",
    "ajornala": "ajornalar",
    "ajornalada": "ajornalar",
    "ajornaladas": "ajornalar",
    "ajornalado": "ajornalar",
    "ajornalados": "ajornalar",
    "ajornalai": "ajornalar",
    "ajornalais": "ajornalar",
    "ajornalam": "ajornalar",
    "ajornalamo": "ajornalar",
    "ajornalamos": "ajornalar",
    "ajornalando": "ajornalar",
    "ajornalara": "ajornalar",
    "ajornalaram": "ajornalar",
    "ajornalaras": "ajornalar",
    "ajornalarde": "ajornalar",
    "ajornalardes": "ajornalar",
    "ajornalare": "ajornalar",
    "ajornalarei": "ajornalar",
    "ajornalareis": "ajornalar",
    "ajornalarem": "ajornalar",
    "ajornalaremos": "ajornalar",
    "ajornalares": "ajornalar",
    "ajornalaria": "ajornalar",
    "ajornalariam": "ajornalar",
    "ajornalarias": "ajornalar",
    "ajornalarmo": "ajornalar",
    "ajornalarmos": "ajornalar",
    "ajornalará": "ajornalar",
    "ajornalarás": "ajornalar",
    "ajornalarão": "ajornalar",
    "ajornalaríamos": "ajornalar",
    "ajornalaríeis": "ajornalar",
    "ajornalas": "ajornalar",
    "ajornalasse": "ajornalar",
    "ajornalassem": "ajornalar",
    "ajornalasses": "ajornalar",
    "ajornalaste": "ajornalar",
    "ajornalastes": "ajornalar",
    "ajornalava": "ajornalar",
    "ajornalavam": "ajornalar",
    "ajornalavas": "ajornalar",
    "ajornale": "ajornalar",
    "ajornalei": "ajornalar",
    "ajornaleis": "ajornalar",
    "ajornalem": "ajornalar",
    "ajornalemo": "ajornalar",
    "ajornalemos": "ajornalar",
    "ajornales": "ajornalar",
    "ajornalo": "ajornalar",
    "ajornalou": "ajornalar",
    "ajornalá": "ajornalar",
    "ajornalámo": "ajornalar",
    "ajornalámos": "ajornalar",
    "ajornaláramo": "ajornalar",
    "ajornaláramos": "ajornalar",
    "ajornalárei": "ajornalar",
    "ajornaláreis": "ajornalar",
    "ajornalásseis": "ajornalar",
    "ajornalássemos": "ajornalar",
    "ajornalávamo": "ajornalar",
    "ajornalávamos": "ajornalar",
    "ajornalávei": "ajornalar",
    "ajornaláveis": "ajornalar",
    "ajouja": "ajoujar",
    "ajoujada": "ajoujar",
    "ajoujadas": "ajoujar",
    "ajoujado": "ajoujar",
    "ajoujados": "ajoujar",
    "ajoujai": "ajoujar",
    "ajoujais": "ajoujar",
    "ajoujam": "ajoujar",
    "ajoujamentos": "ajoujamento",
    "ajoujamo": "ajoujar",
    "ajoujamos": "ajoujar",
    "ajoujando": "ajoujar",
    "ajoujara": "ajoujar",
    "ajoujaram": "ajoujar",
    "ajoujaras": "ajoujar",
    "ajoujarde": "ajoujar",
    "ajoujardes": "ajoujar",
    "ajoujare": "ajoujar",
    "ajoujarei": "ajoujar",
    "ajoujareis": "ajoujar",
    "ajoujarem": "ajoujar",
    "ajoujaremos": "ajoujar",
    "ajoujares": "ajoujar",
    "ajoujaria": "ajoujar",
    "ajoujariam": "ajoujar",
    "ajoujarias": "ajoujar",
    "ajoujarmo": "ajoujar",
    "ajoujarmos": "ajoujar",
    "ajoujará": "ajoujar",
    "ajoujarás": "ajoujar",
    "ajoujarão": "ajoujar",
    "ajoujaríamos": "ajoujar",
    "ajoujaríeis": "ajoujar",
    "ajoujas": "ajoujar",
    "ajoujasse": "ajoujar",
    "ajoujassem": "ajoujar",
    "ajoujasses": "ajoujar",
    "ajoujaste": "ajoujar",
    "ajoujastes": "ajoujar",
    "ajoujava": "ajoujar",
    "ajoujavam": "ajoujar",
    "ajoujavas": "ajoujar",
    "ajouje": "ajoujar",
    "ajoujei": "ajoujar",
    "ajoujeis": "ajoujar",
    "ajoujem": "ajoujar",
    "ajoujemo": "ajoujar",
    "ajoujemos": "ajoujar",
    "ajoujes": "ajoujar",
    "ajoujo": "ajoujar",
    "ajoujos": "ajoujo",
    "ajoujou": "ajoujar",
    "ajoujá": "ajoujar",
    "ajoujámo": "ajoujar",
    "ajoujámos": "ajoujar",
    "ajoujáramo": "ajoujar",
    "ajoujáramos": "ajoujar",
    "ajoujárei": "ajoujar",
    "ajoujáreis": "ajoujar",
    "ajoujásseis": "ajoujar",
    "ajoujássemos": "ajoujar",
    "ajoujávamo": "ajoujar",
    "ajoujávamos": "ajoujar",
    "ajoujávei": "ajoujar",
    "ajoujáveis": "ajoujar",
    "ajuagas": "ajuaga",
    "ajuda": "ajudar",
    "ajudada": "ajudar",
    "ajudadas": "ajudar",
    "ajudado": "ajudar",
    "ajudadors": "ajudador",
    "ajudados": "ajudar",
    "ajudai": "ajudar",
    "ajudais": "ajudar",
    "ajudam": "ajudar",
    "ajudamo": "ajudar",
    "ajudamos": "ajudar",
    "ajudando": "ajudar",
    "ajudantes": "ajudante",
    "ajudara": "ajudar",
    "ajudaram": "ajudar",
    "ajudaras": "ajudar",
    "ajudarde": "ajudar",
    "ajudardes": "ajudar",
    "ajudare": "ajudar",
    "ajudarei": "ajudar",
    "ajudareis": "ajudar",
    "ajudarem": "ajudar",
    "ajudaremos": "ajudar",
    "ajudares": "ajudar",
    "ajudaria": "ajudar",
    "ajudariam": "ajudar",
    "ajudarias": "ajudar",
    "ajudarmo": "ajudar",
    "ajudarmos": "ajudar",
    "ajudará": "ajudar",
    "ajudarás": "ajudar",
    "ajudarão": "ajudar",
    "ajudaríamos": "ajudar",
    "ajudaríeis": "ajudar",
    "ajudas": "ajudar",
    "ajudasse": "ajudar",
    "ajudassem": "ajudar",
    "ajudasses": "ajudar",
    "ajudaste": "ajudar",
    "ajudastes": "ajudar",
    "ajudava": "ajudar",
    "ajudavam": "ajudar",
    "ajudavas": "ajudar",
    "ajude": "ajudar",
    "ajudei": "ajudar",
    "ajudeis": "ajudar",
    "ajudem": "ajudar",
    "ajudemo": "ajudar",
    "ajudemos": "ajudar",
    "ajudenga": "ajudengar",
    "ajudengada": "ajudengar",
    "ajudengadas": "ajudengar",
    "ajudengado": "ajudengar",
    "ajudengados": "ajudengar",
    "ajudengai": "ajudengar",
    "ajudengais": "ajudengar",
    "ajudengam": "ajudengar",
    "ajudengamo": "ajudengar",
    "ajudengamos": "ajudengar",
    "ajudengando": "ajudengar",
    "ajudengara": "ajudengar",
    "ajudengaram": "ajudengar",
    "ajudengaras": "ajudengar",
    "ajudengarde": "ajudengar",
    "ajudengardes": "ajudengar",
    "ajudengare": "ajudengar",
    "ajudengarei": "ajudengar",
    "ajudengareis": "ajudengar",
    "ajudengarem": "ajudengar",
    "ajudengaremos": "ajudengar",
    "ajudengares": "ajudengar",
    "ajudengaria": "ajudengar",
    "ajudengariam": "ajudengar",
    "ajudengarias": "ajudengar",
    "ajudengarmo": "ajudengar",
    "ajudengarmos": "ajudengar",
    "ajudengará": "ajudengar",
    "ajudengarás": "ajudengar",
    "ajudengarão": "ajudengar",
    "ajudengaríamos": "ajudengar",
    "ajudengaríeis": "ajudengar",
    "ajudengas": "ajudengar",
    "ajudengasse": "ajudengar",
    "ajudengassem": "ajudengar",
    "ajudengasses": "ajudengar",
    "ajudengaste": "ajudengar",
    "ajudengastes": "ajudengar",
    "ajudengava": "ajudengar",
    "ajudengavam": "ajudengar",
    "ajudengavas": "ajudengar",
    "ajudengo": "ajudengar",
    "ajudengou": "ajudengar",
    "ajudengue": "ajudengar",
    "ajudenguei": "ajudengar",
    "ajudengueis": "ajudengar",
    "ajudenguem": "ajudengar",
    "ajudenguemo": "ajudengar",
    "ajudenguemos": "ajudengar",
    "ajudengues": "ajudengar",
    "ajudengá": "ajudengar",
    "ajudengámo": "ajudengar",
    "ajudengámos": "ajudengar",
    "ajudengáramo": "ajudengar",
    "ajudengáramos": "ajudengar",
    "ajudengárei": "ajudengar",
    "ajudengáreis": "ajudengar",
    "ajudengásseis": "ajudengar",
    "ajudengássemos": "ajudengar",
    "ajudengávamo": "ajudengar",
    "ajudengávamos": "ajudengar",
    "ajudengávei": "ajudengar",
    "ajudengáveis": "ajudengar",
    "ajudes": "ajudar",
    "ajudinha": "ajuda",
    "ajudinhas": "ajuda",
    "ajudita": "ajuda",
    "ajuditas": "ajuda",
    "ajudo": "ajudar",
    "ajudou": "ajudar",
    "ajudá": "ajudar",
    "ajudámo": "ajudar",
    "ajudámos": "ajudar",
    "ajudáramo": "ajudar",
    "ajudáramos": "ajudar",
    "ajudárei": "ajudar",
    "ajudáreis": "ajudar",
    "ajudásseis": "ajudar",
    "ajudássemos": "ajudar",
    "ajudávamo": "ajudar",
    "ajudávamos": "ajudar",
    "ajudávei": "ajudar",
    "ajudáveis": "ajudável",
    "ajuizada": "ajuizar",
    "ajuizadas": "ajuizar",
    "ajuizadinha": "ajuizado",
    "ajuizadinhas": "ajuizado",
    "ajuizadinho": "ajuizado",
    "ajuizadinhos": "ajuizado",
    "ajuizadita": "ajuizado",
    "ajuizaditas": "ajuizado",
    "ajuizadito": "ajuizado",
    "ajuizaditos": "ajuizado",
    "ajuizado": "ajuizar",
    "ajuizadora": "ajuizador",
    "ajuizadoras": "ajuizador",
    "ajuizadores": "ajuizador",
    "ajuizados": "ajuizar",
    "ajuizadíssima": "ajuizado",
    "ajuizadíssimas": "ajuizado",
    "ajuizadíssimo": "ajuizado",
    "ajuizadíssimos": "ajuizado",
    "ajuizai": "ajuizar",
    "ajuizais": "ajuizar",
    "ajuizamo": "ajuizar",
    "ajuizamos": "ajuizar",
    "ajuizando": "ajuizar",
    "ajuizara": "ajuizar",
    "ajuizaram": "ajuizar",
    "ajuizaras": "ajuizar",
    "ajuizarde": "ajuizar",
    "ajuizardes": "ajuizar",
    "ajuizare": "ajuizar",
    "ajuizarei": "ajuizar",
    "ajuizareis": "ajuizar",
    "ajuizarem": "ajuizar",
    "ajuizaremos": "ajuizar",
    "ajuizares": "ajuizar",
    "ajuizaria": "ajuizar",
    "ajuizariam": "ajuizar",
    "ajuizarias": "ajuizar",
    "ajuizarmo": "ajuizar",
    "ajuizarmos": "ajuizar",
    "ajuizará": "ajuizar",
    "ajuizarás": "ajuizar",
    "ajuizarão": "ajuizar",
    "ajuizaríamos": "ajuizar",
    "ajuizaríeis": "ajuizar",
    "ajuizasse": "ajuizar",
    "ajuizassem": "ajuizar",
    "ajuizasses": "ajuizar",
    "ajuizaste": "ajuizar",
    "ajuizastes": "ajuizar",
    "ajuizava": "ajuizar",
    "ajuizavam": "ajuizar",
    "ajuizavas": "ajuizar",
    "ajuizei": "ajuizar",
    "ajuizeis": "ajuizar",
    "ajuizemo": "ajuizar",
    "ajuizemos": "ajuizar",
    "ajuizou": "ajuizar",
    "ajuizá": "ajuizar",
    "ajuizámo": "ajuizar",
    "ajuizámos": "ajuizar",
    "ajuizáramo": "ajuizar",
    "ajuizáramos": "ajuizar",
    "ajuizárei": "ajuizar",
    "ajuizáreis": "ajuizar",
    "ajuizásseis": "ajuizar",
    "ajuizássemos": "ajuizar",
    "ajuizávamo": "ajuizar",
    "ajuizávamos": "ajuizar",
    "ajuizávei": "ajuizar",
    "ajuizáveis": "ajuizável",
    "ajula": "ajular",
    "ajulada": "ajular",
    "ajuladas": "ajular",
    "ajulado": "ajular",
    "ajulados": "ajular",
    "ajulai": "ajular",
    "ajulais": "ajular",
    "ajulam": "ajular",
    "ajulamo": "ajular",
    "ajulamos": "ajular",
    "ajulando": "ajular",
    "ajulara": "ajular",
    "ajularam": "ajular",
    "ajularas": "ajular",
    "ajularde": "ajular",
    "ajulardes": "ajular",
    "ajulare": "ajular",
    "ajularei": "ajular",
    "ajulareis": "ajular",
    "ajularem": "ajular",
    "ajularemos": "ajular",
    "ajulares": "ajular",
    "ajularia": "ajular",
    "ajulariam": "ajular",
    "ajularias": "ajular",
    "ajularmo": "ajular",
    "ajularmos": "ajular",
    "ajulará": "ajular",
    "ajularás": "ajular",
    "ajularão": "ajular",
    "ajularíamos": "ajular",
    "ajularíeis": "ajular",
    "ajulas": "ajular",
    "ajulasse": "ajular",
    "ajulassem": "ajular",
    "ajulasses": "ajular",
    "ajulaste": "ajular",
    "ajulastes": "ajular",
    "ajulava": "ajular",
    "ajulavam": "ajular",
    "ajulavas": "ajular",
    "ajule": "ajular",
    "ajulei": "ajular",
    "ajuleis": "ajular",
    "ajulem": "ajular",
    "ajulemo": "ajular",
    "ajulemos": "ajular",
    "ajules": "ajular",
    "ajulo": "ajular",
    "ajulou": "ajular",
    "ajulá": "ajular",
    "ajulámo": "ajular",
    "ajulámos": "ajular",
    "ajuláramo": "ajular",
    "ajuláramos": "ajular",
    "ajulárei": "ajular",
    "ajuláreis": "ajular",
    "ajulásseis": "ajular",
    "ajulássemos": "ajular",
    "ajulávamo": "ajular",
    "ajulávamos": "ajular",
    "ajulávei": "ajular",
    "ajuláveis": "ajular",
    "ajumentada": "ajumentado",
    "ajumentadas": "ajumentado",
    "ajumentados": "ajumentado",
    "ajunta": "ajuntar",
    "ajuntada": "ajuntar",
    "ajuntadas": "ajuntar",
    "ajuntadeira": "ajuntador",
    "ajuntadeiras": "ajuntador",
    "ajuntado": "ajuntar",
    "ajuntadoiros": "ajuntadoiro",
    "ajuntadora": "ajuntador",
    "ajuntadoras": "ajuntador",
    "ajuntadores": "ajuntador",
    "ajuntados": "ajuntar",
    "ajuntadouros": "ajuntadouro",
    "ajuntai": "ajuntar",
    "ajuntais": "ajuntar",
    "ajuntam": "ajuntar",
    "ajuntamentos": "ajuntamento",
    "ajuntamo": "ajuntar",
    "ajuntamos": "ajuntar",
    "ajuntando": "ajuntar",
    "ajuntara": "ajuntar",
    "ajuntaram": "ajuntar",
    "ajuntaras": "ajuntar",
    "ajuntarde": "ajuntar",
    "ajuntardes": "ajuntar",
    "ajuntare": "ajuntar",
    "ajuntarei": "ajuntar",
    "ajuntareis": "ajuntar",
    "ajuntarem": "ajuntar",
    "ajuntaremos": "ajuntar",
    "ajuntares": "ajuntar",
    "ajuntaria": "ajuntar",
    "ajuntariam": "ajuntar",
    "ajuntarias": "ajuntar",
    "ajuntarmo": "ajuntar",
    "ajuntarmos": "ajuntar",
    "ajuntará": "ajuntar",
    "ajuntarás": "ajuntar",
    "ajuntarão": "ajuntar",
    "ajuntaríamos": "ajuntar",
    "ajuntaríeis": "ajuntar",
    "ajuntas": "ajuntar",
    "ajuntasse": "ajuntar",
    "ajuntassem": "ajuntar",
    "ajuntasses": "ajuntar",
    "ajuntaste": "ajuntar",
    "ajuntastes": "ajuntar",
    "ajuntava": "ajuntar",
    "ajuntavam": "ajuntar",
    "ajuntavas": "ajuntar",
    "ajunte": "ajuntar",
    "ajunteadeiras": "ajunteadeira",
    "ajuntei": "ajuntar",
    "ajunteis": "ajuntar",
    "ajuntem": "ajuntar",
    "ajuntemo": "ajuntar",
    "ajuntemos": "ajuntar",
    "ajuntes": "ajuntar",
    "ajunto": "ajuntar",
    "ajuntoiras": "ajuntoira",
    "ajuntou": "ajuntar",
    "ajuntouras": "ajuntoura",
    "ajuntá": "ajuntar",
    "ajuntámo": "ajuntar",
    "ajuntámos": "ajuntar",
    "ajuntáramo": "ajuntar",
    "ajuntáramos": "ajuntar",
    "ajuntárei": "ajuntar",
    "ajuntáreis": "ajuntar",
    "ajuntásseis": "ajuntar",
    "ajuntássemos": "ajuntar",
    "ajuntávamo": "ajuntar",
    "ajuntávamos": "ajuntar",
    "ajuntávei": "ajuntar",
    "ajuntáveis": "ajuntável",
    "ajuramenta": "ajuramentar",
    "ajuramentada": "ajuramentar",
    "ajuramentadas": "ajuramentar",
    "ajuramentado": "ajuramentar",
    "ajuramentados": "ajuramentar",
    "ajuramentai": "ajuramentar",
    "ajuramentais": "ajuramentar",
    "ajuramentam": "ajuramentar",
    "ajuramentamo": "ajuramentar",
    "ajuramentamos": "ajuramentar",
    "ajuramentando": "ajuramentar",
    "ajuramentara": "ajuramentar",
    "ajuramentaram": "ajuramentar",
    "ajuramentaras": "ajuramentar",
    "ajuramentarde": "ajuramentar",
    "ajuramentardes": "ajuramentar",
    "ajuramentare": "ajuramentar",
    "ajuramentarei": "ajuramentar",
    "ajuramentareis": "ajuramentar",
    "ajuramentarem": "ajuramentar",
    "ajuramentaremos": "ajuramentar",
    "ajuramentares": "ajuramentar",
    "ajuramentaria": "ajuramentar",
    "ajuramentariam": "ajuramentar",
    "ajuramentarias": "ajuramentar",
    "ajuramentarmo": "ajuramentar",
    "ajuramentarmos": "ajuramentar",
    "ajuramentará": "ajuramentar",
    "ajuramentarás": "ajuramentar",
    "ajuramentarão": "ajuramentar",
    "ajuramentaríamos": "ajuramentar",
    "ajuramentaríeis": "ajuramentar",
    "ajuramentas": "ajuramentar",
    "ajuramentasse": "ajuramentar",
    "ajuramentassem": "ajuramentar",
    "ajuramentasses": "ajuramentar",
    "ajuramentaste": "ajuramentar",
    "ajuramentastes": "ajuramentar",
    "ajuramentava": "ajuramentar",
    "ajuramentavam": "ajuramentar",
    "ajuramentavas": "ajuramentar",
    "ajuramentações": "ajuramentação",
    "ajuramente": "ajuramentar",
    "ajuramentei": "ajuramentar",
    "ajuramenteis": "ajuramentar",
    "ajuramentem": "ajuramentar",
    "ajuramentemo": "ajuramentar",
    "ajuramentemos": "ajuramentar",
    "ajuramentes": "ajuramentar",
    "ajuramento": "ajuramentar",
    "ajuramentou": "ajuramentar",
    "ajuramentá": "ajuramentar",
    "ajuramentámo": "ajuramentar",
    "ajuramentámos": "ajuramentar",
    "ajuramentáramo": "ajuramentar",
    "ajuramentáramos": "ajuramentar",
    "ajuramentárei": "ajuramentar",
    "ajuramentáreis": "ajuramentar",
    "ajuramentásseis": "ajuramentar",
    "ajuramentássemos": "ajuramentar",
    "ajuramentávamo": "ajuramentar",
    "ajuramentávamos": "ajuramentar",
    "ajuramentávei": "ajuramentar",
    "ajuramentáveis": "ajuramentar",
    "ajusta": "ajustar",
    "ajustada": "ajustar",
    "ajustadas": "ajustar",
    "ajustadinha": "ajustado",
    "ajustadinhas": "ajustado",
    "ajustadinho": "ajustado",
    "ajustadinhos": "ajustado",
    "ajustadita": "ajustado",
    "ajustaditas": "ajustado",
    "ajustadito": "ajustado",
    "ajustaditos": "ajustado",
    "ajustado": "ajustar",
    "ajustadora": "ajustador",
    "ajustadoras": "ajustador",
    "ajustadores": "ajustador",
    "ajustados": "ajustar",
    "ajustadíssima": "ajustado",
    "ajustadíssimas": "ajustado",
    "ajustadíssimo": "ajustado",
    "ajustadíssimos": "ajustado",
    "ajustai": "ajustar",
    "ajustais": "ajustar",
    "ajustam": "ajustar",
    "ajustamentos": "ajustamento",
    "ajustamo": "ajustar",
    "ajustamos": "ajustar",
    "ajustando": "ajustar",
    "ajustara": "ajustar",
    "ajustaram": "ajustar",
    "ajustaras": "ajustar",
    "ajustarde": "ajustar",
    "ajustardes": "ajustar",
    "ajustare": "ajustar",
    "ajustarei": "ajustar",
    "ajustareis": "ajustar",
    "ajustarem": "ajustar",
    "ajustaremos": "ajustar",
    "ajustares": "ajustar",
    "ajustaria": "ajustar",
    "ajustariam": "ajustar",
    "ajustarias": "ajustar",
    "ajustarmo": "ajustar",
    "ajustarmos": "ajustar",
    "ajustará": "ajustar",
    "ajustarás": "ajustar",
    "ajustarão": "ajustar",
    "ajustaríamos": "ajustar",
    "ajustaríeis": "ajustar",
    "ajustas": "ajustar",
    "ajustasse": "ajustar",
    "ajustassem": "ajustar",
    "ajustasses": "ajustar",
    "ajustaste": "ajustar",
    "ajustastes": "ajustar",
    "ajustava": "ajustar",
    "ajustavam": "ajustar",
    "ajustavas": "ajustar",
    "ajuste": "ajustar",
    "ajustei": "ajustar",
    "ajusteis": "ajustar",
    "ajustem": "ajustar",
    "ajustemo": "ajustar",
    "ajustemos": "ajustar",
    "ajustes": "ajuste",
    "ajustezinho": "ajuste",
    "ajustezinhos": "ajuste",
    "ajustezito": "ajuste",
    "ajustezitos": "ajuste",
    "ajustice": "ajustiçar",
    "ajusticei": "ajustiçar",
    "ajusticeis": "ajustiçar",
    "ajusticem": "ajustiçar",
    "ajusticemo": "ajustiçar",
    "ajusticemos": "ajustiçar",
    "ajustices": "ajustiçar",
    "ajustiça": "ajustiçar",
    "ajustiçada": "ajustiçar",
    "ajustiçadas": "ajustiçar",
    "ajustiçado": "ajustiçar",
    "ajustiçados": "ajustiçar",
    "ajustiçai": "ajustiçar",
    "ajustiçais": "ajustiçar",
    "ajustiçam": "ajustiçar",
    "ajustiçamo": "ajustiçar",
    "ajustiçamos": "ajustiçar",
    "ajustiçando": "ajustiçar",
    "ajustiçara": "ajustiçar",
    "ajustiçaram": "ajustiçar",
    "ajustiçaras": "ajustiçar",
    "ajustiçarde": "ajustiçar",
    "ajustiçardes": "ajustiçar",
    "ajustiçare": "ajustiçar",
    "ajustiçarei": "ajustiçar",
    "ajustiçareis": "ajustiçar",
    "ajustiçarem": "ajustiçar",
    "ajustiçaremos": "ajustiçar",
    "ajustiçares": "ajustiçar",
    "ajustiçaria": "ajustiçar",
    "ajustiçariam": "ajustiçar",
    "ajustiçarias": "ajustiçar",
    "ajustiçarmo": "ajustiçar",
    "ajustiçarmos": "ajustiçar",
    "ajustiçará": "ajustiçar",
    "ajustiçarás": "ajustiçar",
    "ajustiçarão": "ajustiçar",
    "ajustiçaríamos": "ajustiçar",
    "ajustiçaríeis": "ajustiçar",
    "ajustiças": "ajustiçar",
    "ajustiçasse": "ajustiçar",
    "ajustiçassem": "ajustiçar",
    "ajustiçasses": "ajustiçar",
    "ajustiçaste": "ajustiçar",
    "ajustiçastes": "ajustiçar",
    "ajustiçava": "ajustiçar",
    "ajustiçavam": "ajustiçar",
    "ajustiçavas": "ajustiçar",
    "ajustiço": "ajustiçar",
    "ajustiçou": "ajustiçar",
    "ajustiçá": "ajustiçar",
    "ajustiçámo": "ajustiçar",
    "ajustiçámos": "ajustiçar",
    "ajustiçáramo": "ajustiçar",
    "ajustiçáramos": "ajustiçar",
    "ajustiçárei": "ajustiçar",
    "ajustiçáreis": "ajustiçar",
    "ajustiçásseis": "ajustiçar",
    "ajustiçássemos": "ajustiçar",
    "ajustiçávamo": "ajustiçar",
    "ajustiçávamos": "ajustiçar",
    "ajustiçávei": "ajustiçar",
    "ajustiçáveis": "ajustiçar",
    "ajusto": "ajustar",
    "ajustou": "ajustar",
    "ajusturas": "ajustura",
    "ajustá": "ajustar",
    "ajustámo": "ajustar",
    "ajustámos": "ajustar",
    "ajustáramo": "ajustar",
    "ajustáramos": "ajustar",
    "ajustárei": "ajustar",
    "ajustáreis": "ajustar",
    "ajustásseis": "ajustar",
    "ajustássemos": "ajustar",
    "ajustávamo": "ajustar",
    "ajustávamos": "ajustar",
    "ajustávei": "ajustar",
    "ajustáveis": "ajustável",
    "ajuíza": "ajuizar",
    "ajuízam": "ajuizar",
    "ajuízas": "ajuizar",
    "ajuíze": "ajuizar",
    "ajuízem": "ajuizar",
    "ajuízes": "ajuizar",
    "ajuízo": "ajuizar",
    "ala": "alar",
    "alabadadas": "alabadada",
    "alabadas": "alabada",
    "alabandas": "alabanda",
    "alabandinas": "alabandina",
    "alabandites": "alabandite",
    "alabara": "alabarar",
    "alabarada": "alabarar",
    "alabaradas": "alabarar",
    "alabarado": "alabarar",
    "alabarados": "alabarar",
    "alabarai": "alabarar",
    "alabarais": "alabarar",
    "alabaram": "alabarar",
    "alabaramo": "alabarar",
    "alabaramos": "alabarar",
    "alabarando": "alabarar",
    "alabarara": "alabarar",
    "alabararam": "alabarar",
    "alabararas": "alabarar",
    "alabararde": "alabarar",
    "alabarardes": "alabarar",
    "alabarare": "alabarar",
    "alabararei": "alabarar",
    "alabarareis": "alabarar",
    "alabararem": "alabarar",
    "alabararemos": "alabarar",
    "alabarares": "alabarar",
    "alabararia": "alabarar",
    "alabarariam": "alabarar",
    "alabararias": "alabarar",
    "alabararmo": "alabarar",
    "alabararmos": "alabarar",
    "alabarará": "alabarar",
    "alabararás": "alabarar",
    "alabararão": "alabarar",
    "alabararíamos": "alabarar",
    "alabararíeis": "alabarar",
    "alabaras": "alabarar",
    "alabarasse": "alabarar",
    "alabarassem": "alabarar",
    "alabarasses": "alabarar",
    "alabaraste": "alabarar",
    "alabarastes": "alabarar",
    "alabarava": "alabarar",
    "alabaravam": "alabarar",
    "alabaravas": "alabarar",
    "alabarda": "alabardar",
    "alabardada": "alabardar",
    "alabardadas": "alabardar",
    "alabardado": "alabardar",
    "alabardados": "alabardar",
    "alabardai": "alabardar",
    "alabardais": "alabardar",
    "alabardam": "alabardar",
    "alabardamo": "alabardar",
    "alabardamos": "alabardar",
    "alabardando": "alabardar",
    "alabardara": "alabardar",
    "alabardaram": "alabardar",
    "alabardaras": "alabardar",
    "alabardarde": "alabardar",
    "alabardardes": "alabardar",
    "alabardare": "alabardar",
    "alabardarei": "alabardar",
    "alabardareis": "alabardar",
    "alabardarem": "alabardar",
    "alabardaremos": "alabardar",
    "alabardares": "alabardar",
    "alabardaria": "alabardar",
    "alabardariam": "alabardar",
    "alabardarias": "alabardar",
    "alabardarmo": "alabardar",
    "alabardarmos": "alabardar",
    "alabardará": "alabardar",
    "alabardarás": "alabardar",
    "alabardarão": "alabardar",
    "alabardaríamos": "alabardar",
    "alabardaríeis": "alabardar",
    "alabardas": "alabardar",
    "alabardasse": "alabardar",
    "alabardassem": "alabardar",
    "alabardasses": "alabardar",
    "alabardaste": "alabardar",
    "alabardastes": "alabardar",
    "alabardava": "alabardar",
    "alabardavam": "alabardar",
    "alabardavas": "alabardar",
    "alabarde": "alabardar",
    "alabardei": "alabardar",
    "alabardeira": "alabardeiro",
    "alabardeiras": "alabardeiro",
    "alabardeiros": "alabardeiro",
    "alabardeis": "alabardar",
    "alabardem": "alabardar",
    "alabardemo": "alabardar",
    "alabardemos": "alabardar",
    "alabardes": "alabardar",
    "alabardina": "alabardino",
    "alabardinas": "alabardino",
    "alabardinos": "alabardino",
    "alabardo": "alabardar",
    "alabardou": "alabardar",
    "alabardá": "alabardar",
    "alabardámo": "alabardar",
    "alabardámos": "alabardar",
    "alabardáramo": "alabardar",
    "alabardáramos": "alabardar",
    "alabardárei": "alabardar",
    "alabardáreis": "alabardar",
    "alabardásseis": "alabardar",
    "alabardássemos": "alabardar",
    "alabardávamo": "alabardar",
    "alabardávamos": "alabardar",
    "alabardávei": "alabardar",
    "alabardáveis": "alabardar",
    "alabare": "alabarar",
    "alabarei": "alabarar",
    "alabareis": "alabarar",
    "alabarem": "alabarar",
    "alabaremo": "alabarar",
    "alabaremos": "alabarar",
    "alabares": "alabarar",
    "alabaro": "alabarar",
    "alabarou": "alabarar",
    "alabará": "alabarar",
    "alabarámo": "alabarar",
    "alabarámos": "alabarar",
    "alabaráramo": "alabarar",
    "alabaráramos": "alabarar",
    "alabarárei": "alabarar",
    "alabaráreis": "alabarar",
    "alabarásseis": "alabarar",
    "alabarássemos": "alabarar",
    "alabarávamo": "alabarar",
    "alabarávamos": "alabarar",
    "alabarávei": "alabarar",
    "alabaráveis": "alabarar",
    "alabastrina": "alabastrino",
    "alabastrinas": "alabastrino",
    "alabastrinos": "alabastrino",
    "alabastrites": "alabastrite",
    "alabastriza": "alabastrizar",
    "alabastrizada": "alabastrizar",
    "alabastrizadas": "alabastrizar",
    "alabastrizado": "alabastrizar",
    "alabastrizados": "alabastrizar",
    "alabastrizai": "alabastrizar",
    "alabastrizais": "alabastrizar",
    "alabastrizam": "alabastrizar",
    "alabastrizamo": "alabastrizar",
    "alabastrizamos": "alabastrizar",
    "alabastrizando": "alabastrizar",
    "alabastrizara": "alabastrizar",
    "alabastrizaram": "alabastrizar",
    "alabastrizaras": "alabastrizar",
    "alabastrizarde": "alabastrizar",
    "alabastrizardes": "alabastrizar",
    "alabastrizare": "alabastrizar",
    "alabastrizarei": "alabastrizar",
    "alabastrizareis": "alabastrizar",
    "alabastrizarem": "alabastrizar",
    "alabastrizaremos": "alabastrizar",
    "alabastrizares": "alabastrizar",
    "alabastrizaria": "alabastrizar",
    "alabastrizariam": "alabastrizar",
    "alabastrizarias": "alabastrizar",
    "alabastrizarmo": "alabastrizar",
    "alabastrizarmos": "alabastrizar",
    "alabastrizará": "alabastrizar",
    "alabastrizarás": "alabastrizar",
    "alabastrizarão": "alabastrizar",
    "alabastrizaríamos": "alabastrizar",
    "alabastrizaríeis": "alabastrizar",
    "alabastrizas": "alabastrizar",
    "alabastrizasse": "alabastrizar",
    "alabastrizassem": "alabastrizar",
    "alabastrizasses": "alabastrizar",
    "alabastrizaste": "alabastrizar",
    "alabastrizastes": "alabastrizar",
    "alabastrizava": "alabastrizar",
    "alabastrizavam": "alabastrizar",
    "alabastrizavas": "alabastrizar",
    "alabastrize": "alabastrizar",
    "alabastrizei": "alabastrizar",
    "alabastrizeis": "alabastrizar",
    "alabastrizem": "alabastrizar",
    "alabastrizemo": "alabastrizar",
    "alabastrizemos": "alabastrizar",
    "alabastrizes": "alabastrizar",
    "alabastrizo": "alabastrizar",
    "alabastrizou": "alabastrizar",
    "alabastrizá": "alabastrizar",
    "alabastrizámo": "alabastrizar",
    "alabastrizámos": "alabastrizar",
    "alabastrizáramo": "alabastrizar",
    "alabastrizáramos": "alabastrizar",
    "alabastrizárei": "alabastrizar",
    "alabastrizáreis": "alabastrizar",
    "alabastrizásseis": "alabastrizar",
    "alabastrizássemos": "alabastrizar",
    "alabastrizávamo": "alabastrizar",
    "alabastrizávamos": "alabastrizar",
    "alabastrizávei": "alabastrizar",
    "alabastrizáveis": "alabastrizar",
    "alabastros": "alabastro",
    "alabaças": "alabaça",
    "alabirinta": "alabirintar",
    "alabirintada": "alabirintar",
    "alabirintadas": "alabirintar",
    "alabirintado": "alabirintar",
    "alabirintados": "alabirintar",
    "alabirintai": "alabirintar",
    "alabirintais": "alabirintar",
    "alabirintam": "alabirintar",
    "alabirintamo": "alabirintar",
    "alabirintamos": "alabirintar",
    "alabirintando": "alabirintar",
    "alabirintara": "alabirintar",
    "alabirintaram": "alabirintar",
    "alabirintaras": "alabirintar",
    "alabirintarde": "alabirintar",
    "alabirintardes": "alabirintar",
    "alabirintare": "alabirintar",
    "alabirintarei": "alabirintar",
    "alabirintareis": "alabirintar",
    "alabirintarem": "alabirintar",
    "alabirintaremos": "alabirintar",
    "alabirintares": "alabirintar",
    "alabirintaria": "alabirintar",
    "alabirintariam": "alabirintar",
    "alabirintarias": "alabirintar",
    "alabirintarmo": "alabirintar",
    "alabirintarmos": "alabirintar",
    "alabirintará": "alabirintar",
    "alabirintarás": "alabirintar",
    "alabirintarão": "alabirintar",
    "alabirintaríamos": "alabirintar",
    "alabirintaríeis": "alabirintar",
    "alabirintas": "alabirintar",
    "alabirintasse": "alabirintar",
    "alabirintassem": "alabirintar",
    "alabirintasses": "alabirintar",
    "alabirintaste": "alabirintar",
    "alabirintastes": "alabirintar",
    "alabirintava": "alabirintar",
    "alabirintavam": "alabirintar",
    "alabirintavas": "alabirintar",
    "alabirinte": "alabirintar",
    "alabirintei": "alabirintar",
    "alabirinteis": "alabirintar",
    "alabirintem": "alabirintar",
    "alabirintemo": "alabirintar",
    "alabirintemos": "alabirintar",
    "alabirintes": "alabirintar",
    "alabirinto": "alabirintar",
    "alabirintou": "alabirintar",
    "alabirintá": "alabirintar",
    "alabirintámo": "alabirintar",
    "alabirintámos": "alabirintar",
    "alabirintáramo": "alabirintar",
    "alabirintáramos": "alabirintar",
    "alabirintárei": "alabirintar",
    "alabirintáreis": "alabirintar",
    "alabirintásseis": "alabirintar",
    "alabirintássemos": "alabirintar",
    "alabirintávamo": "alabirintar",
    "alabirintávamos": "alabirintar",
    "alabirintávei": "alabirintar",
    "alabirintáveis": "alabirintar",
    "alaboeiros": "alaboeiro",
    "alabona": "alabão",
    "alabonas": "alabão",
    "alabrega": "alabregar",
    "alabregada": "alabregar",
    "alabregadas": "alabregar",
    "alabregado": "alabregar",
    "alabregados": "alabregar",
    "alabregai": "alabregar",
    "alabregais": "alabregar",
    "alabregam": "alabregar",
    "alabregamo": "alabregar",
    "alabregamos": "alabregar",
    "alabregando": "alabregar",
    "alabregara": "alabregar",
    "alabregaram": "alabregar",
    "alabregaras": "alabregar",
    "alabregarde": "alabregar",
    "alabregardes": "alabregar",
    "alabregare": "alabregar",
    "alabregarei": "alabregar",
    "alabregareis": "alabregar",
    "alabregarem": "alabregar",
    "alabregaremos": "alabregar",
    "alabregares": "alabregar",
    "alabregaria": "alabregar",
    "alabregariam": "alabregar",
    "alabregarias": "alabregar",
    "alabregarmo": "alabregar",
    "alabregarmos": "alabregar",
    "alabregará": "alabregar",
    "alabregarás": "alabregar",
    "alabregarão": "alabregar",
    "alabregaríamos": "alabregar",
    "alabregaríeis": "alabregar",
    "alabregas": "alabregar",
    "alabregasse": "alabregar",
    "alabregassem": "alabregar",
    "alabregasses": "alabregar",
    "alabregaste": "alabregar",
    "alabregastes": "alabregar",
    "alabregava": "alabregar",
    "alabregavam": "alabregar",
    "alabregavas": "alabregar",
    "alabrego": "alabregar",
    "alabregou": "alabregar",
    "alabregue": "alabregar",
    "alabreguei": "alabregar",
    "alabregueis": "alabregar",
    "alabreguem": "alabregar",
    "alabreguemo": "alabregar",
    "alabreguemos": "alabregar",
    "alabregues": "alabregar",
    "alabregá": "alabregar",
    "alabregámo": "alabregar",
    "alabregámos": "alabregar",
    "alabregáramo": "alabregar",
    "alabregáramos": "alabregar",
    "alabregárei": "alabregar",
    "alabregáreis": "alabregar",
    "alabregásseis": "alabregar",
    "alabregássemos": "alabregar",
    "alabregávamo": "alabregar",
    "alabregávamos": "alabregar",
    "alabregávei": "alabregar",
    "alabregáveis": "alabregar",
    "alabástrica": "alabástrico",
    "alabástricas": "alabástrico",
    "alabástricos": "alabástrico",
    "alabões": "alabão",
    "alaca": "alacar",
    "alacada": "alacar",
    "alacadas": "alacar",
    "alacado": "alacar",
    "alacados": "alacar",
    "alacaia": "alacaiar",
    "alacaiada": "alacaiar",
    "alacaiadas": "alacaiar",
    "alacaiado": "alacaiar",
    "alacaiados": "alacaiar",
    "alacaiai": "alacaiar",
    "alacaiais": "alacaiar",
    "alacaiam": "alacaiar",
    "alacaiamo": "alacaiar",
    "alacaiamos": "alacaiar",
    "alacaiando": "alacaiar",
    "alacaiara": "alacaiar",
    "alacaiaram": "alacaiar",
    "alacaiaras": "alacaiar",
    "alacaiarde": "alacaiar",
    "alacaiardes": "alacaiar",
    "alacaiare": "alacaiar",
    "alacaiarei": "alacaiar",
    "alacaiareis": "alacaiar",
    "alacaiarem": "alacaiar",
    "alacaiaremos": "alacaiar",
    "alacaiares": "alacaiar",
    "alacaiaria": "alacaiar",
    "alacaiariam": "alacaiar",
    "alacaiarias": "alacaiar",
    "alacaiarmo": "alacaiar",
    "alacaiarmos": "alacaiar",
    "alacaiará": "alacaiar",
    "alacaiarás": "alacaiar",
    "alacaiarão": "alacaiar",
    "alacaiaríamos": "alacaiar",
    "alacaiaríeis": "alacaiar",
    "alacaias": "alacaiar",
    "alacaiasse": "alacaiar",
    "alacaiassem": "alacaiar",
    "alacaiasses": "alacaiar",
    "alacaiaste": "alacaiar",
    "alacaiastes": "alacaiar",
    "alacaiava": "alacaiar",
    "alacaiavam": "alacaiar",
    "alacaiavas": "alacaiar",
    "alacaie": "alacaiar",
    "alacaiei": "alacaiar",
    "alacaieis": "alacaiar",
    "alacaiem": "alacaiar",
    "alacaiemo": "alacaiar",
    "alacaiemos": "alacaiar",
    "alacaies": "alacaiar",
    "alacaio": "alacaiar",
    "alacaiou": "alacaiar",
    "alacais": "alacar",
    "alacaiá": "alacaiar",
    "alacaiámo": "alacaiar",
    "alacaiámos": "alacaiar",
    "alacaiáramo": "alacaiar",
    "alacaiáramos": "alacaiar",
    "alacaiárei": "alacaiar",
    "alacaiáreis": "alacaiar",
    "alacaiásseis": "alacaiar",
    "alacaiássemos": "alacaiar",
    "alacaiávamo": "alacaiar",
    "alacaiávamos": "alacaiar",
    "alacaiávei": "alacaiar",
    "alacaiáveis": "alacaiar",
    "alacam": "alacar",
    "alacamo": "alacar",
    "alacamos": "alacar",
    "alacando": "alacar",
    "alacara": "alacar",
    "alacaram": "alacar",
    "alacaras": "alacar",
    "alacardes": "alacar",
    "alacarei": "alacar",
    "alacareis": "alacar",
    "alacarem": "alacar",
    "alacaremos": "alacar",
    "alacares": "alacar",
    "alacaria": "alacar",
    "alacariam": "alacar",
    "alacarias": "alacar",
    "alacarmo": "alacar",
    "alacarmos": "alacar",
    "alacará": "alacar",
    "alacarás": "alacar",
    "alacarão": "alacar",
    "alacaríamos": "alacar",
    "alacaríeis": "alacar",
    "alacas": "alacar",
    "alacasse": "alacar",
    "alacassem": "alacar",
    "alacasses": "alacar",
    "alacaste": "alacar",
    "alacastes": "alacar",
    "alacava": "alacar",
    "alacavam": "alacar",
    "alacavas": "alacar",
    "alacaçareiros": "alacaçareiro",
    "alacires": "alacir",
    "alaco": "alacar",
    "alacoada": "alacoado",
    "alacoadas": "alacoado",
    "alacoados": "alacoado",
    "alacou": "alacar",
    "alacrada": "alacrado",
    "alacradas": "alacrado",
    "alacrados": "alacrado",
    "alacraias": "alacraia",
    "alacraus": "alacrau",
    "alacridades": "alacridade",
    "alacta": "alactar",
    "alactada": "alactar",
    "alactadas": "alactar",
    "alactado": "alactar",
    "alactados": "alactar",
    "alactai": "alactar",
    "alactais": "alactar",
    "alactam": "alactar",
    "alactamentos": "alactamento",
    "alactamo": "alactar",
    "alactamos": "alactar",
    "alactando": "alactar",
    "alactara": "alactar",
    "alactaram": "alactar",
    "alactaras": "alactar",
    "alactarde": "alactar",
    "alactardes": "alactar",
    "alactare": "alactar",
    "alactarei": "alactar",
    "alactareis": "alactar",
    "alactarem": "alactar",
    "alactaremos": "alactar",
    "alactares": "alactar",
    "alactaria": "alactar",
    "alactariam": "alactar",
    "alactarias": "alactar",
    "alactarmo": "alactar",
    "alactarmos": "alactar",
    "alactará": "alactar",
    "alactarás": "alactar",
    "alactarão": "alactar",
    "alactaríamos": "alactar",
    "alactaríeis": "alactar",
    "alactas": "alactar",
    "alactasse": "alactar",
    "alactassem": "alactar",
    "alactasses": "alactar",
    "alactaste": "alactar",
    "alactastes": "alactar",
    "alactava": "alactar",
    "alactavam": "alactar",
    "alactavas": "alactar",
    "alacte": "alactar",
    "alactei": "alactar",
    "alacteis": "alactar",
    "alactem": "alactar",
    "alactemo": "alactar",
    "alactemos": "alactar",
    "alactes": "alactar",
    "alacto": "alactar",
    "alactou": "alactar",
    "alactá": "alactar",
    "alactámo": "alactar",
    "alactámos": "alactar",
    "alactáramo": "alactar",
    "alactáramos": "alactar",
    "alactárei": "alactar",
    "alactáreis": "alactar",
    "alactásseis": "alactar",
    "alactássemos": "alactar",
    "alactávamo": "alactar",
    "alactávamos": "alactar",
    "alactávei": "alactar",
    "alactáveis": "alactar",
    "alacámo": "alacar",
    "alacámos": "alacar",
    "alacáramo": "alacar",
    "alacáramos": "alacar",
    "alacáreis": "alacar",
    "alacásseis": "alacar",
    "alacássemos": "alacar",
    "alacávamo": "alacar",
    "alacávamos": "alacar",
    "alacáveis": "alacar",
    "alada": "alar",
    "aladainhada": "aladainhado",
    "aladainhadas": "aladainhado",
    "aladainhados": "aladainhado",
    "aladas": "alar",
    "alado": "alar",
    "alados": "alar",
    "aladroada": "aladroado",
    "aladroadas": "aladroado",
    "aladroados": "aladroado",
    "alaga": "alagar",
    "alagada": "alagar",
    "alagadas": "alagar",
    "alagadeira": "alagador",
    "alagadeiras": "alagador",
    "alagadeiros": "alagadeiro",
    "alagadelas": "alagadela",
    "alagadiça": "alagadiço",
    "alagadiças": "alagadiço",
    "alagadiçeira": "alagadiçeiro",
    "alagadiçeiras": "alagadiçeiro",
    "alagadiçeiros": "alagadiçeiro",
    "alagadiços": "alagadiço",
    "alagado": "alagar",
    "alagadora": "alagador",
    "alagadoras": "alagador",
    "alagadores": "alagador",
    "alagados": "alagar",
    "alagadouros": "alagadouro",
    "alagai": "alagar",
    "alagais": "alagar",
    "alagam": "alagar",
    "alagamentos": "alagamento",
    "alagamo": "alagar",
    "alagamos": "alagar",
    "alagando": "alagar",
    "alagara": "alagar",
    "alagaram": "alagar",
    "alagaras": "alagar",
    "alagarde": "alagar",
    "alagardes": "alagar",
    "alagare": "alagar",
    "alagarei": "alagar",
    "alagareis": "alagar",
    "alagarem": "alagar",
    "alagaremos": "alagar",
    "alagares": "alagar",
    "alagaria": "alagar",
    "alagariam": "alagar",
    "alagarias": "alagar",
    "alagarmo": "alagar",
    "alagarmos": "alagar",
    "alagartados": "alagartado",
    "alagará": "alagar",
    "alagarás": "alagar",
    "alagarão": "alagar",
    "alagaríamos": "alagar",
    "alagaríeis": "alagar",
    "alagas": "alagar",
    "alagasse": "alagar",
    "alagassem": "alagar",
    "alagasses": "alagar",
    "alagaste": "alagar",
    "alagastes": "alagar",
    "alagava": "alagar",
    "alagavam": "alagar",
    "alagavas": "alagar",
    "alagações": "alagação",
    "alagens": "alagem",
    "alago": "alagar",
    "alagoana": "alagoano",
    "alagoanas": "alagoano",
    "alagoanos": "alagoano",
    "alagoas": "alagoa",
    "alagoeiros": "alagoeiro",
    "alagosa": "alagoso",
    "alagosas": "alagoso",
    "alagosos": "alagoso",
    "alagostada": "alagostado",
    "alagostadas": "alagostado",
    "alagostados": "alagostado",
    "alagou": "alagar",
    "alague": "alagar",
    "alaguei": "alagar",
    "alagueis": "alagar",
    "alaguem": "alagar",
    "alaguemo": "alagar",
    "alaguemos": "alagar",
    "alagues": "alagar",
    "alagá": "alagar",
    "alagámo": "alagar",
    "alagámos": "alagar",
    "alagáramo": "alagar",
    "alagáramos": "alagar",
    "alagárei": "alagar",
    "alagáreis": "alagar",
    "alagásseis": "alagar",
    "alagássemos": "alagar",
    "alagávamo": "alagar",
    "alagávamos": "alagar",
    "alagávei": "alagar",
    "alagáveis": "alagável",
    "alai": "alar",
    "alais": "alar",
    "alalias": "alalia",
    "alam": "alar",
    "alamanaqueiros": "alamanaqueiro",
    "alamarada": "alamarado",
    "alamaradas": "alamarado",
    "alamarados": "alamarado",
    "alamares": "alamar",
    "alambara": "alambarar",
    "alambarada": "alambarar",
    "alambaradas": "alambarar",
    "alambarado": "alambarar",
    "alambarados": "alambarar",
    "alambarai": "alambarar",
    "alambarais": "alambarar",
    "alambaram": "alambarar",
    "alambaramo": "alambarar",
    "alambaramos": "alambarar",
    "alambarando": "alambarar",
    "alambarara": "alambarar",
    "alambararam": "alambarar",
    "alambararas": "alambarar",
    "alambarardes": "alambarar",
    "alambararei": "alambarar",
    "alambarareis": "alambarar",
    "alambararem": "alambarar",
    "alambararemos": "alambarar",
    "alambarares": "alambarar",
    "alambararia": "alambarar",
    "alambarariam": "alambarar",
    "alambararias": "alambarar",
    "alambararmo": "alambarar",
    "alambararmos": "alambarar",
    "alambarará": "alambarar",
    "alambararás": "alambarar",
    "alambararão": "alambarar",
    "alambararíamos": "alambarar",
    "alambararíeis": "alambarar",
    "alambaras": "alambarar",
    "alambarasse": "alambarar",
    "alambarassem": "alambarar",
    "alambarasses": "alambarar",
    "alambaraste": "alambarar",
    "alambarastes": "alambarar",
    "alambarava": "alambarar",
    "alambaravam": "alambarar",
    "alambaravas": "alambarar",
    "alambare": "alambarar",
    "alambarei": "alambarar",
    "alambareis": "alambarar",
    "alambarem": "alambarar",
    "alambaremo": "alambarar",
    "alambaremos": "alambarar",
    "alambares": "alambarar",
    "alambaro": "alambarar",
    "alambarou": "alambarar",
    "alambarámo": "alambarar",
    "alambarámos": "alambarar",
    "alambaráramo": "alambarar",
    "alambaráramos": "alambarar",
    "alambaráreis": "alambarar",
    "alambarásseis": "alambarar",
    "alambarássemos": "alambarar",
    "alambarávamo": "alambarar",
    "alambarávamos": "alambarar",
    "alambaráveis": "alambarar",
    "alambaza": "alambazar",
    "alambazada": "alambazar",
    "alambazadas": "alambazar",
    "alambazado": "alambazar",
    "alambazados": "alambazar",
    "alambazai": "alambazar",
    "alambazais": "alambazar",
    "alambazam": "alambazar",
    "alambazamo": "alambazar",
    "alambazamos": "alambazar",
    "alambazando": "alambazar",
    "alambazara": "alambazar",
    "alambazaram": "alambazar",
    "alambazaras": "alambazar",
    "alambazarde": "alambazar",
    "alambazardes": "alambazar",
    "alambazare": "alambazar",
    "alambazarei": "alambazar",
    "alambazareis": "alambazar",
    "alambazarem": "alambazar",
    "alambazaremos": "alambazar",
    "alambazares": "alambazar",
    "alambazaria": "alambazar",
    "alambazariam": "alambazar",
    "alambazarias": "alambazar",
    "alambazarmo": "alambazar",
    "alambazarmos": "alambazar",
    "alambazará": "alambazar",
    "alambazarás": "alambazar",
    "alambazarão": "alambazar",
    "alambazaríamos": "alambazar",
    "alambazaríeis": "alambazar",
    "alambazas": "alambazar",
    "alambazasse": "alambazar",
    "alambazassem": "alambazar",
    "alambazasses": "alambazar",
    "alambazaste": "alambazar",
    "alambazastes": "alambazar",
    "alambazava": "alambazar",
    "alambazavam": "alambazar",
    "alambazavas": "alambazar",
    "alambaze": "alambazar",
    "alambazei": "alambazar",
    "alambazeis": "alambazar",
    "alambazem": "alambazar",
    "alambazemo": "alambazar",
    "alambazemos": "alambazar",
    "alambazes": "alambazar",
    "alambazo": "alambazar",
    "alambazou": "alambazar",
    "alambazá": "alambazar",
    "alambazámo": "alambazar",
    "alambazámos": "alambazar",
    "alambazáramo": "alambazar",
    "alambazáramos": "alambazar",
    "alambazárei": "alambazar",
    "alambazáreis": "alambazar",
    "alambazásseis": "alambazar",
    "alambazássemos": "alambazar",
    "alambazávamo": "alambazar",
    "alambazávamos": "alambazar",
    "alambazávei": "alambazar",
    "alambazáveis": "alambazar",
    "alambica": "alambicar",
    "alambicada": "alambicar",
    "alambicadas": "alambicar",
    "alambicado": "alambicar",
    "alambicados": "alambicar",
    "alambicai": "alambicar",
    "alambicais": "alambicar",
    "alambicam": "alambicar",
    "alambicamo": "alambicar",
    "alambicamos": "alambicar",
    "alambicando": "alambicar",
    "alambicara": "alambicar",
    "alambicaram": "alambicar",
    "alambicaras": "alambicar",
    "alambicarde": "alambicar",
    "alambicardes": "alambicar",
    "alambicare": "alambicar",
    "alambicarei": "alambicar",
    "alambicareis": "alambicar",
    "alambicarem": "alambicar",
    "alambicaremos": "alambicar",
    "alambicares": "alambicar",
    "alambicaria": "alambicar",
    "alambicariam": "alambicar",
    "alambicarias": "alambicar",
    "alambicarmo": "alambicar",
    "alambicarmos": "alambicar",
    "alambicará": "alambicar",
    "alambicarás": "alambicar",
    "alambicarão": "alambicar",
    "alambicaríamos": "alambicar",
    "alambicaríeis": "alambicar",
    "alambicas": "alambicar",
    "alambicasse": "alambicar",
    "alambicassem": "alambicar",
    "alambicasses": "alambicar",
    "alambicaste": "alambicar",
    "alambicastes": "alambicar",
    "alambicava": "alambicar",
    "alambicavam": "alambicar",
    "alambicavas": "alambicar",
    "alambico": "alambicar",
    "alambicou": "alambicar",
    "alambicá": "alambicar",
    "alambicámo": "alambicar",
    "alambicámos": "alambicar",
    "alambicáramo": "alambicar",
    "alambicáramos": "alambicar",
    "alambicárei": "alambicar",
    "alambicáreis": "alambicar",
    "alambicásseis": "alambicar",
    "alambicássemos": "alambicar",
    "alambicávamo": "alambicar",
    "alambicávamos": "alambicar",
    "alambicávei": "alambicar",
    "alambicáveis": "alambicar",
    "alambique": "alambicar",
    "alambiquei": "alambicar",
    "alambiqueira": "alambiqueiro",
    "alambiqueiras": "alambiqueiro",
    "alambiqueiros": "alambiqueiro",
    "alambiqueis": "alambicar",
    "alambiquem": "alambicar",
    "alambiquemo": "alambicar",
    "alambiquemos": "alambicar",
    "alambiques": "alambique",
    "alambora": "alamborar",
    "alamborada": "alamborar",
    "alamboradas": "alamborar",
    "alamborado": "alamborar",
    "alamborados": "alamborar",
    "alamborai": "alamborar",
    "alamborais": "alamborar",
    "alamboram": "alamborar",
    "alamboramo": "alamborar",
    "alamboramos": "alamborar",
    "alamborando": "alamborar",
    "alamborara": "alamborar",
    "alamboraram": "alamborar",
    "alamboraras": "alamborar",
    "alamborarde": "alamborar",
    "alamborardes": "alamborar",
    "alamborare": "alamborar",
    "alamborarei": "alamborar",
    "alamborareis": "alamborar",
    "alamborarem": "alamborar",
    "alamboraremos": "alamborar",
    "alamborares": "alamborar",
    "alamboraria": "alamborar",
    "alamborariam": "alamborar",
    "alamborarias": "alamborar",
    "alamborarmo": "alamborar",
    "alamborarmos": "alamborar",
    "alamborará": "alamborar",
    "alamborarás": "alamborar",
    "alamborarão": "alamborar",
    "alamboraríamos": "alamborar",
    "alamboraríeis": "alamborar",
    "alamboras": "alamborar",
    "alamborasse": "alamborar",
    "alamborassem": "alamborar",
    "alamborasses": "alamborar",
    "alamboraste": "alamborar",
    "alamborastes": "alamborar",
    "alamborava": "alamborar",
    "alamboravam": "alamborar",
    "alamboravas": "alamborar",
    "alambore": "alamborar",
    "alamborei": "alamborar",
    "alamboreis": "alamborar",
    "alamborem": "alamborar",
    "alamboremo": "alamborar",
    "alamboremos": "alamborar",
    "alambores": "alamborar",
    "alamboro": "alamborar",
    "alamborou": "alamborar",
    "alamborá": "alamborar",
    "alamborámo": "alamborar",
    "alamborámos": "alamborar",
    "alamboráramo": "alamborar",
    "alamboráramos": "alamborar",
    "alamborárei": "alamborar",
    "alamboráreis": "alamborar",
    "alamborásseis": "alamborar",
    "alamborássemos": "alamborar",
    "alamborávamo": "alamborar",
    "alamborávamos": "alamborar",
    "alamborávei": "alamborar",
    "alamboráveis": "alamborar",
    "alambra": "alambrar",
    "alambrada": "alambrar",
    "alambradas": "alambrar",
    "alambrado": "alambrar",
    "alambradors": "alambrador",
    "alambrados": "alambrar",
    "alambrai": "alambrar",
    "alambrais": "alambrar",
    "alambram": "alambrar",
    "alambramo": "alambrar",
    "alambramos": "alambrar",
    "alambrando": "alambrar",
    "alambrara": "alambrar",
    "alambraram": "alambrar",
    "alambraras": "alambrar",
    "alambrarde": "alambrar",
    "alambrardes": "alambrar",
    "alambrare": "alambrar",
    "alambrarei": "alambrar",
    "alambrareis": "alambrar",
    "alambrarem": "alambrar",
    "alambraremos": "alambrar",
    "alambrares": "alambrar",
    "alambraria": "alambrar",
    "alambrariam": "alambrar",
    "alambrarias": "alambrar",
    "alambrarmo": "alambrar",
    "alambrarmos": "alambrar",
    "alambrará": "alambrar",
    "alambrarás": "alambrar",
    "alambrarão": "alambrar",
    "alambraríamos": "alambrar",
    "alambraríeis": "alambrar",
    "alambras": "alambrar",
    "alambrasse": "alambrar",
    "alambrassem": "alambrar",
    "alambrasses": "alambrar",
    "alambraste": "alambrar",
    "alambrastes": "alambrar",
    "alambrava": "alambrar",
    "alambravam": "alambrar",
    "alambravas": "alambrar",
    "alambre": "alambrar",
    "alambrei": "alambrar",
    "alambreis": "alambrar",
    "alambrem": "alambrar",
    "alambremo": "alambrar",
    "alambremos": "alambrar",
    "alambres": "alambre",
    "alambriada": "alambriado",
    "alambriadas": "alambriado",
    "alambriados": "alambriado",
    "alambro": "alambrar",
    "alambrou": "alambrar",
    "alambrá": "alambrar",
    "alambrámo": "alambrar",
    "alambrámos": "alambrar",
    "alambráramo": "alambrar",
    "alambráramos": "alambrar",
    "alambrárei": "alambrar",
    "alambráreis": "alambrar",
    "alambrásseis": "alambrar",
    "alambrássemos": "alambrar",
    "alambrávamo": "alambrar",
    "alambrávamos": "alambrar",
    "alambrávei": "alambrar",
    "alambráveis": "alambrar",
    "alambéis": "alambel",
    "alameda": "alamedar",
    "alamedada": "alamedar",
    "alamedadas": "alamedar",
    "alamedado": "alamedar",
    "alamedados": "alamedar",
    "alamedai": "alamedar",
    "alamedais": "alamedar",
    "alamedam": "alamedar",
    "alamedamo": "alamedar",
    "alamedamos": "alamedar",
    "alamedando": "alamedar",
    "alamedara": "alamedar",
    "alamedaram": "alamedar",
    "alamedaras": "alamedar",
    "alamedarde": "alamedar",
    "alamedardes": "alamedar",
    "alamedare": "alamedar",
    "alamedarei": "alamedar",
    "alamedareis": "alamedar",
    "alamedarem": "alamedar",
    "alamedaremos": "alamedar",
    "alamedares": "alamedar",
    "alamedaria": "alamedar",
    "alamedariam": "alamedar",
    "alamedarias": "alamedar",
    "alamedarmo": "alamedar",
    "alamedarmos": "alamedar",
    "alamedará": "alamedar",
    "alamedarás": "alamedar",
    "alamedarão": "alamedar",
    "alamedaríamos": "alamedar",
    "alamedaríeis": "alamedar",
    "alamedas": "alamedar",
    "alamedasse": "alamedar",
    "alamedassem": "alamedar",
    "alamedasses": "alamedar",
    "alamedaste": "alamedar",
    "alamedastes": "alamedar",
    "alamedava": "alamedar",
    "alamedavam": "alamedar",
    "alamedavas": "alamedar",
    "alamede": "alamedar",
    "alamedei": "alamedar",
    "alamedeis": "alamedar",
    "alamedem": "alamedar",
    "alamedemo": "alamedar",
    "alamedemos": "alamedar",
    "alamedes": "alamedar",
    "alamedo": "alamedar",
    "alamedou": "alamedar",
    "alamedá": "alamedar",
    "alamedámo": "alamedar",
    "alamedámos": "alamedar",
    "alamedáramo": "alamedar",
    "alamedáramos": "alamedar",
    "alamedárei": "alamedar",
    "alamedáreis": "alamedar",
    "alamedásseis": "alamedar",
    "alamedássemos": "alamedar",
    "alamedávamo": "alamedar",
    "alamedávamos": "alamedar",
    "alamedávei": "alamedar",
    "alamedáveis": "alamedar",
    "alamentos": "alamento",
    "alamires": "alamire",
    "alamo": "alar",
    "alamos": "alar",
    "alampa": "alampar",
    "alampada": "alampar",
    "alampadas": "alampar",
    "alampado": "alampar",
    "alampados": "alampar",
    "alampadários": "alampadário",
    "alampai": "alampar",
    "alampais": "alampar",
    "alampam": "alampar",
    "alampamo": "alampar",
    "alampamos": "alampar",
    "alampando": "alampar",
    "alampara": "alampar",
    "alamparam": "alampar",
    "alamparas": "alampar",
    "alampardes": "alampar",
    "alamparei": "alampar",
    "alampareis": "alampar",
    "alamparem": "alampar",
    "alamparemos": "alampar",
    "alampares": "alampar",
    "alamparia": "alampar",
    "alampariam": "alampar",
    "alamparias": "alampar",
    "alamparmo": "alampar",
    "alamparmos": "alampar",
    "alampará": "alampar",
    "alamparás": "alampar",
    "alamparão": "alampar",
    "alamparíamos": "alampar",
    "alamparíeis": "alampar",
    "alampas": "alampar",
    "alampasse": "alampar",
    "alampassem": "alampar",
    "alampasses": "alampar",
    "alampaste": "alampar",
    "alampastes": "alampar",
    "alampava": "alampar",
    "alampavam": "alampar",
    "alampavas": "alampar",
    "alampe": "alampar",
    "alampei": "alampar",
    "alampeis": "alampar",
    "alampem": "alampar",
    "alampemo": "alampar",
    "alampemos": "alampar",
    "alampes": "alampar",
    "alampo": "alampar",
    "alampou": "alampar",
    "alampámo": "alampar",
    "alampámos": "alampar",
    "alampáramo": "alampar",
    "alampáramos": "alampar",
    "alampáreis": "alampar",
    "alampásseis": "alampar",
    "alampássemos": "alampar",
    "alampávamo": "alampar",
    "alampávamos": "alampar",
    "alampáveis": "alampar",
    "alana": "alano",
    "alanas": "alano",
    "alanca": "alancar",
    "alancada": "alancar",
    "alancadas": "alancar",
    "alancado": "alancar",
    "alancados": "alancar",
    "alancais": "alancar",
    "alancam": "alancar",
    "alancamo": "alancar",
    "alancamos": "alancar",
    "alancando": "alancar",
    "alancara": "alancar",
    "alancaram": "alancar",
    "alancaras": "alancar",
    "alancardes": "alancar",
    "alancarei": "alancar",
    "alancareis": "alancar",
    "alancarem": "alancar",
    "alancaremos": "alancar",
    "alancares": "alancar",
    "alancaria": "alancar",
    "alancariam": "alancar",
    "alancarias": "alancar",
    "alancarmo": "alancar",
    "alancarmos": "alancar",
    "alancará": "alancar",
    "alancarás": "alancar",
    "alancarão": "alancar",
    "alancaríamos": "alancar",
    "alancaríeis": "alancar",
    "alancas": "alancar",
    "alancasse": "alancar",
    "alancassem": "alancar",
    "alancasses": "alancar",
    "alancaste": "alancar",
    "alancastes": "alancar",
    "alancava": "alancar",
    "alancavam": "alancar",
    "alancavas": "alancar",
    "alanceada": "alancear",
    "alanceadas": "alancear",
    "alanceadeira": "alanceador",
    "alanceadeiras": "alanceador",
    "alanceado": "alancear",
    "alanceadora": "alanceador",
    "alanceadoras": "alanceador",
    "alanceadores": "alanceador",
    "alanceados": "alancear",
    "alanceai": "alancear",
    "alanceais": "alancear",
    "alanceamentos": "alanceamento",
    "alanceamo": "alancear",
    "alanceamos": "alancear",
    "alanceando": "alancear",
    "alanceara": "alancear",
    "alancearam": "alancear",
    "alancearas": "alancear",
    "alancearde": "alancear",
    "alanceardes": "alancear",
    "alanceare": "alancear",
    "alancearei": "alancear",
    "alanceareis": "alancear",
    "alancearem": "alancear",
    "alancearemos": "alancear",
    "alanceares": "alancear",
    "alancearia": "alancear",
    "alanceariam": "alancear",
    "alancearias": "alancear",
    "alancearmo": "alancear",
    "alancearmos": "alancear",
    "alanceará": "alancear",
    "alancearás": "alancear",
    "alancearão": "alancear",
    "alancearíamos": "alancear",
    "alancearíeis": "alancear",
    "alanceasse": "alancear",
    "alanceassem": "alancear",
    "alanceasses": "alancear",
    "alanceaste": "alancear",
    "alanceastes": "alancear",
    "alanceava": "alancear",
    "alanceavam": "alancear",
    "alanceavas": "alancear",
    "alanceei": "alancear",
    "alanceeis": "alancear",
    "alanceemo": "alancear",
    "alanceemos": "alancear",
    "alanceia": "alancear",
    "alanceiam": "alancear",
    "alanceias": "alancear",
    "alanceie": "alancear",
    "alanceiem": "alancear",
    "alanceies": "alancear",
    "alanceio": "alancear",
    "alanceou": "alancear",
    "alanceá": "alancear",
    "alanceámo": "alancear",
    "alanceámos": "alancear",
    "alanceáramo": "alancear",
    "alanceáramos": "alancear",
    "alanceárei": "alancear",
    "alanceáreis": "alancear",
    "alanceásseis": "alancear",
    "alanceássemos": "alancear",
    "alanceávamo": "alancear",
    "alanceávamos": "alancear",
    "alanceávei": "alancear",
    "alanceáveis": "alancear",
    "alanco": "alancar",
    "alancos": "alanco",
    "alancou": "alancar",
    "alancámo": "alancar",
    "alancámos": "alancar",
    "alancáramo": "alancar",
    "alancáramos": "alancar",
    "alancáreis": "alancar",
    "alancásseis": "alancar",
    "alancássemos": "alancar",
    "alancávamo": "alancar",
    "alancávamos": "alancar",
    "alancáveis": "alancar",
    "alandeada": "alandeado",
    "alandeadas": "alandeado",
    "alandeados": "alandeado",
    "alando": "alar",
    "alandroais": "alandroal",
    "alandroeiros": "alandroeiro",
    "alandros": "alandro",
    "alangiácea": "alangiáceo",
    "alangiáceas": "alangiáceo",
    "alangiáceos": "alangiáceo",
    "alangiágeas": "alangiágea",
    "alanguida": "alanguidar",
    "alanguidada": "alanguidar",
    "alanguidadas": "alanguidar",
    "alanguidado": "alanguidar",
    "alanguidados": "alanguidar",
    "alanguidai": "alanguidar",
    "alanguidais": "alanguidar",
    "alanguidam": "alanguidar",
    "alanguidamo": "alanguidar",
    "alanguidamos": "alanguidar",
    "alanguidando": "alanguidar",
    "alanguidara": "alanguidar",
    "alanguidaram": "alanguidar",
    "alanguidaras": "alanguidar",
    "alanguidarde": "alanguidar",
    "alanguidardes": "alanguidar",
    "alanguidare": "alanguidar",
    "alanguidarei": "alanguidar",
    "alanguidareis": "alanguidar",
    "alanguidarem": "alanguidar",
    "alanguidaremos": "alanguidar",
    "alanguidares": "alanguidar",
    "alanguidaria": "alanguidar",
    "alanguidariam": "alanguidar",
    "alanguidarias": "alanguidar",
    "alanguidarmo": "alanguidar",
    "alanguidarmos": "alanguidar",
    "alanguidará": "alanguidar",
    "alanguidarás": "alanguidar",
    "alanguidarão": "alanguidar",
    "alanguidaríamos": "alanguidar",
    "alanguidaríeis": "alanguidar",
    "alanguidas": "alanguidar",
    "alanguidasse": "alanguidar",
    "alanguidassem": "alanguidar",
    "alanguidasses": "alanguidar",
    "alanguidaste": "alanguidar",
    "alanguidastes": "alanguidar",
    "alanguidava": "alanguidar",
    "alanguidavam": "alanguidar",
    "alanguidavas": "alanguidar",
    "alanguide": "alanguidar",
    "alanguidei": "alanguidar",
    "alanguideis": "alanguidar",
    "alanguidem": "alanguidar",
    "alanguidemo": "alanguidar",
    "alanguidemos": "alanguidar",
    "alanguides": "alanguidar",
    "alanguido": "alanguidar",
    "alanguidou": "alanguidar",
    "alanguidá": "alanguidar",
    "alanguidámo": "alanguidar",
    "alanguidámos": "alanguidar",
    "alanguidáramo": "alanguidar",
    "alanguidáramos": "alanguidar",
    "alanguidárei": "alanguidar",
    "alanguidáreis": "alanguidar",
    "alanguidásseis": "alanguidar",
    "alanguidássemos": "alanguidar",
    "alanguidávamo": "alanguidar",
    "alanguidávamos": "alanguidar",
    "alanguidávei": "alanguidar",
    "alanguidáveis": "alanguidar",
    "alanha": "alanhar",
    "alanhada": "alanhar",
    "alanhadas": "alanhar",
    "alanhadeira": "alanhador",
    "alanhadeiras": "alanhador",
    "alanhado": "alanhar",
    "alanhadora": "alanhador",
    "alanhadoras": "alanhador",
    "alanhadores": "alanhador",
    "alanhados": "alanhar",
    "alanhai": "alanhar",
    "alanhais": "alanhar",
    "alanham": "alanhar",
    "alanhamentos": "alanhamento",
    "alanhamo": "alanhar",
    "alanhamos": "alanhar",
    "alanhando": "alanhar",
    "alanhara": "alanhar",
    "alanharam": "alanhar",
    "alanharas": "alanhar",
    "alanharde": "alanhar",
    "alanhardes": "alanhar",
    "alanhare": "alanhar",
    "alanharei": "alanhar",
    "alanhareis": "alanhar",
    "alanharem": "alanhar",
    "alanharemos": "alanhar",
    "alanhares": "alanhar",
    "alanharia": "alanhar",
    "alanhariam": "alanhar",
    "alanharias": "alanhar",
    "alanharmo": "alanhar",
    "alanharmos": "alanhar",
    "alanhará": "alanhar",
    "alanharás": "alanhar",
    "alanharão": "alanhar",
    "alanharíamos": "alanhar",
    "alanharíeis": "alanhar",
    "alanhas": "alanhar",
    "alanhasse": "alanhar",
    "alanhassem": "alanhar",
    "alanhasses": "alanhar",
    "alanhaste": "alanhar",
    "alanhastes": "alanhar",
    "alanhava": "alanhar",
    "alanhavam": "alanhar",
    "alanhavas": "alanhar",
    "alanhe": "alanhar",
    "alanhei": "alanhar",
    "alanheis": "alanhar",
    "alanhem": "alanhar",
    "alanhemo": "alanhar",
    "alanhemos": "alanhar",
    "alanhes": "alanhar",
    "alanho": "alanhar",
    "alanhou": "alanhar",
    "alanhá": "alanhar",
    "alanhámo": "alanhar",
    "alanhámos": "alanhar",
    "alanháramo": "alanhar",
    "alanháramos": "alanhar",
    "alanhárei": "alanhar",
    "alanháreis": "alanhar",
    "alanhásseis": "alanhar",
    "alanhássemos": "alanhar",
    "alanhávamo": "alanhar",
    "alanhávamos": "alanhar",
    "alanhávei": "alanhar",
    "alanháveis": "alanhar",
    "alaninas": "alanina",
    "alanites": "alanite",
    "alanos": "alano",
    "alanque": "alancar",
    "alanquei": "alancar",
    "alanqueis": "alancar",
    "alanquem": "alancar",
    "alanquemos": "alancar",
    "alanques": "alancar",
    "alanternas": "alanterna",
    "alantoideias": "alantoideia",
    "alantoídeas": "alantoídea",
    "alantíases": "alantíase",
    "alantóides": "alantóide",
    "alanzoa": "alanzoar",
    "alanzoada": "alanzoar",
    "alanzoadas": "alanzoar",
    "alanzoadeira": "alanzoador",
    "alanzoadeiras": "alanzoador",
    "alanzoado": "alanzoar",
    "alanzoadora": "alanzoador",
    "alanzoadoras": "alanzoador",
    "alanzoadores": "alanzoador",
    "alanzoados": "alanzoar",
    "alanzoai": "alanzoar",
    "alanzoais": "alanzoar",
    "alanzoam": "alanzoar",
    "alanzoamo": "alanzoar",
    "alanzoamos": "alanzoar",
    "alanzoando": "alanzoar",
    "alanzoara": "alanzoar",
    "alanzoaram": "alanzoar",
    "alanzoaras": "alanzoar",
    "alanzoarde": "alanzoar",
    "alanzoardes": "alanzoar",
    "alanzoare": "alanzoar",
    "alanzoarei": "alanzoar",
    "alanzoareis": "alanzoar",
    "alanzoarem": "alanzoar",
    "alanzoaremos": "alanzoar",
    "alanzoares": "alanzoar",
    "alanzoaria": "alanzoar",
    "alanzoariam": "alanzoar",
    "alanzoarias": "alanzoar",
    "alanzoarmo": "alanzoar",
    "alanzoarmos": "alanzoar",
    "alanzoará": "alanzoar",
    "alanzoarás": "alanzoar",
    "alanzoarão": "alanzoar",
    "alanzoaríamos": "alanzoar",
    "alanzoaríeis": "alanzoar",
    "alanzoas": "alanzoar",
    "alanzoasse": "alanzoar",
    "alanzoassem": "alanzoar",
    "alanzoasses": "alanzoar",
    "alanzoaste": "alanzoar",
    "alanzoastes": "alanzoar",
    "alanzoava": "alanzoar",
    "alanzoavam": "alanzoar",
    "alanzoavas": "alanzoar",
    "alanzoe": "alanzoar",
    "alanzoei": "alanzoar",
    "alanzoeira": "alanzoeiro",
    "alanzoeiras": "alanzoeiro",
    "alanzoeiros": "alanzoeiro",
    "alanzoeis": "alanzoar",
    "alanzoem": "alanzoar",
    "alanzoemo": "alanzoar",
    "alanzoemos": "alanzoar",
    "alanzoes": "alanzoar",
    "alanzoo": "alanzoar",
    "alanzoou": "alanzoar",
    "alanzoá": "alanzoar",
    "alanzoámo": "alanzoar",
    "alanzoámos": "alanzoar",
    "alanzoáramo": "alanzoar",
    "alanzoáramos": "alanzoar",
    "alanzoárei": "alanzoar",
    "alanzoáreis": "alanzoar",
    "alanzoásseis": "alanzoar",
    "alanzoássemos": "alanzoar",
    "alanzoávamo": "alanzoar",
    "alanzoávamos": "alanzoar",
    "alanzoávei": "alanzoar",
    "alanzoáveis": "alanzoar",
    "alapa": "alapar",
    "alapada": "alapar",
    "alapadas": "alapar",
    "alapado": "alapar",
    "alapados": "alapar",
    "alapai": "alapar",
    "alapais": "alapar",
    "alapam": "alapar",
    "alapamo": "alapar",
    "alapamos": "alapar",
    "alapando": "alapar",
    "alapara": "alapar",
    "alaparam": "alapar",
    "alaparas": "alapar",
    "alaparda": "alapardar",
    "alapardada": "alapardar",
    "alapardadas": "alapardar",
    "alapardado": "alapardar",
    "alapardados": "alapardar",
    "alapardai": "alapardar",
    "alapardais": "alapardar",
    "alapardam": "alapardar",
    "alapardamo": "alapardar",
    "alapardamos": "alapardar",
    "alapardando": "alapardar",
    "alapardara": "alapardar",
    "alapardaram": "alapardar",
    "alapardaras": "alapardar",
    "alapardarde": "alapardar",
    "alapardardes": "alapardar",
    "alapardare": "alapardar",
    "alapardarei": "alapardar",
    "alapardareis": "alapardar",
    "alapardarem": "alapardar",
    "alapardaremos": "alapardar",
    "alapardares": "alapardar",
    "alapardaria": "alapardar",
    "alapardariam": "alapardar",
    "alapardarias": "alapardar",
    "alapardarmo": "alapardar",
    "alapardarmos": "alapardar",
    "alapardará": "alapardar",
    "alapardarás": "alapardar",
    "alapardarão": "alapardar",
    "alapardaríamos": "alapardar",
    "alapardaríeis": "alapardar",
    "alapardas": "alapardar",
    "alapardasse": "alapardar",
    "alapardassem": "alapardar",
    "alapardasses": "alapardar",
    "alapardaste": "alapardar",
    "alapardastes": "alapardar",
    "alapardava": "alapardar",
    "alapardavam": "alapardar",
    "alapardavas": "alapardar",
    "alaparde": "alapardar",
    "alapardei": "alapardar",
    "alapardeis": "alapardar",
    "alapardem": "alapardar",
    "alapardemo": "alapardar",
    "alapardemos": "alapardar",
    "alapardes": "alapardar",
    "alapardo": "alapardar",
    "alapardou": "alapardar",
    "alapardá": "alapardar",
    "alapardámo": "alapardar",
    "alapardámos": "alapardar",
    "alapardáramo": "alapardar",
    "alapardáramos": "alapardar",
    "alapardárei": "alapardar",
    "alapardáreis": "alapardar",
    "alapardásseis": "alapardar",
    "alapardássemos": "alapardar",
    "alapardávamo": "alapardar",
    "alapardávamos": "alapardar",
    "alapardávei": "alapardar",
    "alapardáveis": "alapardar",
    "alapare": "alapar",
    "alaparei": "alapar",
    "alapareis": "alapar",
    "alaparem": "alapar",
    "alaparemos": "alapar",
    "alapares": "alapar",
    "alaparia": "alapar",
    "alapariam": "alapar",
    "alaparias": "alapar",
    "alaparmo": "alapar",
    "alaparmos": "alapar",
    "alaparotada": "alaparotado",
    "alaparotadas": "alaparotado",
    "alaparotados": "alaparotado",
    "alapará": "alapar",
    "alaparás": "alapar",
    "alaparão": "alapar",
    "alaparíamos": "alapar",
    "alaparíeis": "alapar",
    "alapas": "alapar",
    "alapasse": "alapar",
    "alapassem": "alapar",
    "alapasses": "alapar",
    "alapaste": "alapar",
    "alapastes": "alapar",
    "alapava": "alapar",
    "alapavam": "alapar",
    "alapavas": "alapar",
    "alape": "alapar",
    "alapei": "alapar",
    "alapeis": "alapar",
    "alapem": "alapar",
    "alapemo": "alapar",
    "alapemos": "alapar",
    "alapes": "alapar",
    "alapo": "alapar",
    "alapoada": "alapoado",
    "alapoadas": "alapoado",
    "alapoados": "alapoado",
    "alapou": "alapar",
    "alapuza": "alapuzar",
    "alapuzada": "alapuzar",
    "alapuzadas": "alapuzar",
    "alapuzado": "alapuzar",
    "alapuzados": "alapuzar",
    "alapuzai": "alapuzar",
    "alapuzais": "alapuzar",
    "alapuzam": "alapuzar",
    "alapuzamo": "alapuzar",
    "alapuzamos": "alapuzar",
    "alapuzando": "alapuzar",
    "alapuzara": "alapuzar",
    "alapuzaram": "alapuzar",
    "alapuzaras": "alapuzar",
    "alapuzarde": "alapuzar",
    "alapuzardes": "alapuzar",
    "alapuzare": "alapuzar",
    "alapuzarei": "alapuzar",
    "alapuzareis": "alapuzar",
    "alapuzarem": "alapuzar",
    "alapuzaremos": "alapuzar",
    "alapuzares": "alapuzar",
    "alapuzaria": "alapuzar",
    "alapuzariam": "alapuzar",
    "alapuzarias": "alapuzar",
    "alapuzarmo": "alapuzar",
    "alapuzarmos": "alapuzar",
    "alapuzará": "alapuzar",
    "alapuzarás": "alapuzar",
    "alapuzarão": "alapuzar",
    "alapuzaríamos": "alapuzar",
    "alapuzaríeis": "alapuzar",
    "alapuzas": "alapuzar",
    "alapuzasse": "alapuzar",
    "alapuzassem": "alapuzar",
    "alapuzasses": "alapuzar",
    "alapuzaste": "alapuzar",
    "alapuzastes": "alapuzar",
    "alapuzava": "alapuzar",
    "alapuzavam": "alapuzar",
    "alapuzavas": "alapuzar",
    "alapuze": "alapuzar",
    "alapuzei": "alapuzar",
    "alapuzeis": "alapuzar",
    "alapuzem": "alapuzar",
    "alapuzemo": "alapuzar",
    "alapuzemos": "alapuzar",
    "alapuzes": "alapuzar",
    "alapuzo": "alapuzar",
    "alapuzou": "alapuzar",
    "alapuzá": "alapuzar",
    "alapuzámo": "alapuzar",
    "alapuzámos": "alapuzar",
    "alapuzáramo": "alapuzar",
    "alapuzáramos": "alapuzar",
    "alapuzárei": "alapuzar",
    "alapuzáreis": "alapuzar",
    "alapuzásseis": "alapuzar",
    "alapuzássemos": "alapuzar",
    "alapuzávamo": "alapuzar",
    "alapuzávamos": "alapuzar",
    "alapuzávei": "alapuzar",
    "alapuzáveis": "alapuzar",
    "alapá": "alapar",
    "alapámo": "alapar",
    "alapámos": "alapar",
    "alapáramo": "alapar",
    "alapáramos": "alapar",
    "alapárei": "alapar",
    "alapáreis": "alapar",
    "alapásseis": "alapar",
    "alapássemos": "alapar",
    "alapávamo": "alapar",
    "alapávamos": "alapar",
    "alapávei": "alapar",
    "alapáveis": "alapar",
    "alaque": "alacar",
    "alaquei": "alacar",
    "alaqueis": "alacar",
    "alaquem": "alacar",
    "alaquemos": "alacar",
    "alaques": "alacar",
    "alara": "alarar",
    "alarachada": "alarachado",
    "alarachadas": "alarachado",
    "alarachados": "alarachado",
    "alarada": "alarar",
    "alaradas": "alarar",
    "alarado": "alarar",
    "alarados": "alarar",
    "alarai": "alarar",
    "alarais": "alarar",
    "alaram": "alarar",
    "alaramo": "alarar",
    "alaramos": "alarar",
    "alarando": "alarar",
    "alaranja": "alaranjar",
    "alaranjada": "alaranjar",
    "alaranjadas": "alaranjar",
    "alaranjado": "alaranjar",
    "alaranjados": "alaranjar",
    "alaranjai": "alaranjar",
    "alaranjais": "alaranjar",
    "alaranjam": "alaranjar",
    "alaranjamo": "alaranjar",
    "alaranjamos": "alaranjar",
    "alaranjando": "alaranjar",
    "alaranjara": "alaranjar",
    "alaranjaram": "alaranjar",
    "alaranjaras": "alaranjar",
    "alaranjarde": "alaranjar",
    "alaranjardes": "alaranjar",
    "alaranjare": "alaranjar",
    "alaranjarei": "alaranjar",
    "alaranjareis": "alaranjar",
    "alaranjarem": "alaranjar",
    "alaranjaremos": "alaranjar",
    "alaranjares": "alaranjar",
    "alaranjaria": "alaranjar",
    "alaranjariam": "alaranjar",
    "alaranjarias": "alaranjar",
    "alaranjarmo": "alaranjar",
    "alaranjarmos": "alaranjar",
    "alaranjará": "alaranjar",
    "alaranjarás": "alaranjar",
    "alaranjarão": "alaranjar",
    "alaranjaríamos": "alaranjar",
    "alaranjaríeis": "alaranjar",
    "alaranjas": "alaranjar",
    "alaranjasse": "alaranjar",
    "alaranjassem": "alaranjar",
    "alaranjasses": "alaranjar",
    "alaranjaste": "alaranjar",
    "alaranjastes": "alaranjar",
    "alaranjava": "alaranjar",
    "alaranjavam": "alaranjar",
    "alaranjavas": "alaranjar",
    "alaranje": "alaranjar",
    "alaranjei": "alaranjar",
    "alaranjeis": "alaranjar",
    "alaranjem": "alaranjar",
    "alaranjemo": "alaranjar",
    "alaranjemos": "alaranjar",
    "alaranjes": "alaranjar",
    "alaranjo": "alaranjar",
    "alaranjou": "alaranjar",
    "alaranjá": "alaranjar",
    "alaranjámo": "alaranjar",
    "alaranjámos": "alaranjar",
    "alaranjáramo": "alaranjar",
    "alaranjáramos": "alaranjar",
    "alaranjárei": "alaranjar",
    "alaranjáreis": "alaranjar",
    "alaranjásseis": "alaranjar",
    "alaranjássemos": "alaranjar",
    "alaranjávamo": "alaranjar",
    "alaranjávamos": "alaranjar",
    "alaranjávei": "alaranjar",
    "alaranjáveis": "alaranjar",
    "alarara": "alarar",
    "alararam": "alarar",
    "alararas": "alarar",
    "alararde": "alarar",
    "alarardes": "alarar",
    "alarare": "alarar",
    "alararei": "alarar",
    "alarareis": "alarar",
    "alararem": "alarar",
    "alararemos": "alarar",
    "alarares": "alarar",
    "alararia": "alarar",
    "alarariam": "alarar",
    "alararias": "alarar",
    "alararmo": "alarar",
    "alararmos": "alarar",
    "alarará": "alarar",
    "alararás": "alarar",
    "alararão": "alarar",
    "alararíamos": "alarar",
    "alararíeis": "alarar",
    "alaras": "alarar",
    "alarasse": "alarar",
    "alarassem": "alarar",
    "alarasses": "alarar",
    "alaraste": "alarar",
    "alarastes": "alarar",
    "alarava": "alarar",
    "alaravam": "alarar",
    "alaravas": "alarar",
    "alarde": "alar",
    "alardeada": "alardear",
    "alardeadas": "alardear",
    "alardeadeira": "alardeador",
    "alardeadeiras": "alardeador",
    "alardeado": "alardear",
    "alardeadora": "alardeador",
    "alardeadoras": "alardeador",
    "alardeadores": "alardeador",
    "alardeados": "alardear",
    "alardeai": "alardear",
    "alardeais": "alardear",
    "alardeamentos": "alardeamento",
    "alardeamo": "alardear",
    "alardeamos": "alardear",
    "alardeando": "alardear",
    "alardeara": "alardear",
    "alardearam": "alardear",
    "alardearas": "alardear",
    "alardearde": "alardear",
    "alardeardes": "alardear",
    "alardeare": "alardear",
    "alardearei": "alardear",
    "alardeareis": "alardear",
    "alardearem": "alardear",
    "alardearemos": "alardear",
    "alardeares": "alardear",
    "alardearia": "alardear",
    "alardeariam": "alardear",
    "alardearias": "alardear",
    "alardearmo": "alardear",
    "alardearmos": "alardear",
    "alardeará": "alardear",
    "alardearás": "alardear",
    "alardearão": "alardear",
    "alardearíamos": "alardear",
    "alardearíeis": "alardear",
    "alardeasse": "alardear",
    "alardeassem": "alardear",
    "alardeasses": "alardear",
    "alardeaste": "alardear",
    "alardeastes": "alardear",
    "alardeava": "alardear",
    "alardeavam": "alardear",
    "alardeavas": "alardear",
    "alardeei": "alardear",
    "alardeeis": "alardear",
    "alardeemo": "alardear",
    "alardeemos": "alardear",
    "alardeia": "alardear",
    "alardeiam": "alardear",
    "alardeias": "alardear",
    "alardeie": "alardear",
    "alardeiem": "alardear",
    "alardeies": "alardear",
    "alardeio": "alardear",
    "alardeou": "alardear",
    "alardes": "alarde",
    "alardeá": "alardear",
    "alardeámo": "alardear",
    "alardeámos": "alardear",
    "alardeáramo": "alardear",
    "alardeáramos": "alardear",
    "alardeárei": "alardear",
    "alardeáreis": "alardear",
    "alardeásseis": "alardear",
    "alardeássemos": "alardear",
    "alardeávamo": "alardear",
    "alardeávamos": "alardear",
    "alardeávei": "alardear",
    "alardeáveis": "alardear",
    "alardos": "alardo",
    "alare": "alarar",
    "alarei": "alarar",
    "alareis": "alarar",
    "alarem": "alarar",
    "alaremo": "alarar",
    "alaremos": "alarar",
    "alares": "alarar",
    "alarga": "alargar",
    "alargada": "alargar",
    "alargadas": "alargar",
    "alargadeira": "alargador",
    "alargadeiras": "alargador",
    "alargado": "alargar",
    "alargadora": "alargador",
    "alargadoras": "alargador",
    "alargadores": "alargador",
    "alargados": "alargar",
    "alargadíssima": "alargado",
    "alargadíssimas": "alargado",
    "alargadíssimo": "alargado",
    "alargadíssimos": "alargado",
    "alargai": "alargar",
    "alargais": "alargar",
    "alargam": "alargar",
    "alargamentos": "alargamento",
    "alargamo": "alargar",
    "alargamos": "alargar",
    "alargando": "alargar",
    "alargara": "alargar",
    "alargaram": "alargar",
    "alargaras": "alargar",
    "alargarde": "alargar",
    "alargardes": "alargar",
    "alargare": "alargar",
    "alargarei": "alargar",
    "alargareis": "alargar",
    "alargarem": "alargar",
    "alargaremos": "alargar",
    "alargares": "alargar",
    "alargaria": "alargar",
    "alargariam": "alargar",
    "alargarias": "alargar",
    "alargarmo": "alargar",
    "alargarmos": "alargar",
    "alargará": "alargar",
    "alargarás": "alargar",
    "alargarão": "alargar",
    "alargaríamos": "alargar",
    "alargaríeis": "alargar",
    "alargas": "alargar",
    "alargasse": "alargar",
    "alargassem": "alargar",
    "alargasses": "alargar",
    "alargaste": "alargar",
    "alargastes": "alargar",
    "alargava": "alargar",
    "alargavam": "alargar",
    "alargavas": "alargar",
    "alargo": "alargar",
    "alargou": "alargar",
    "alargue": "alargar",
    "alarguei": "alargar",
    "alargueis": "alargar",
    "alarguem": "alargar",
    "alarguemo": "alargar",
    "alarguemos": "alargar",
    "alargues": "alargar",
    "alargá": "alargar",
    "alargámo": "alargar",
    "alargámos": "alargar",
    "alargáramo": "alargar",
    "alargáramos": "alargar",
    "alargárei": "alargar",
    "alargáreis": "alargar",
    "alargásseis": "alargar",
    "alargássemos": "alargar",
    "alargávamo": "alargar",
    "alargávamos": "alargar",
    "alargávei": "alargar",
    "alargáveis": "alargável",
    "alaria": "alar",
    "alariam": "alar",
    "alarias": "alar",
    "alaridas": "alarida",
    "alaridos": "alarido",
    "alarifes": "alarife",
    "alarizes": "alariz",
    "alarma": "alarmar",
    "alarmada": "alarmar",
    "alarmadas": "alarmar",
    "alarmado": "alarmar",
    "alarmados": "alarmar",
    "alarmadíssima": "alarmado",
    "alarmadíssimas": "alarmado",
    "alarmadíssimo": "alarmado",
    "alarmadíssimos": "alarmado",
    "alarmai": "alarmar",
    "alarmais": "alarmar",
    "alarmam": "alarmar",
    "alarmamo": "alarmar",
    "alarmamos": "alarmar",
    "alarmando": "alarmar",
    "alarmantes": "alarmante",
    "alarmara": "alarmar",
    "alarmaram": "alarmar",
    "alarmaras": "alarmar",
    "alarmarde": "alarmar",
    "alarmardes": "alarmar",
    "alarmare": "alarmar",
    "alarmarei": "alarmar",
    "alarmareis": "alarmar",
    "alarmarem": "alarmar",
    "alarmaremos": "alarmar",
    "alarmares": "alarmar",
    "alarmaria": "alarmar",
    "alarmariam": "alarmar",
    "alarmarias": "alarmar",
    "alarmarmo": "alarmar",
    "alarmarmos": "alarmar",
    "alarmará": "alarmar",
    "alarmarás": "alarmar",
    "alarmarão": "alarmar",
    "alarmaríamos": "alarmar",
    "alarmaríeis": "alarmar",
    "alarmas": "alarmar",
    "alarmasse": "alarmar",
    "alarmassem": "alarmar",
    "alarmasses": "alarmar",
    "alarmaste": "alarmar",
    "alarmastes": "alarmar",
    "alarmava": "alarmar",
    "alarmavam": "alarmar",
    "alarmavas": "alarmar",
    "alarme": "alarmar",
    "alarmei": "alarmar",
    "alarmeis": "alarmar",
    "alarmem": "alarmar",
    "alarmemo": "alarmar",
    "alarmemos": "alarmar",
    "alarmes": "alarme",
    "alarmismos": "alarmismo",
    "alarmistas": "alarmista",
    "alarmo": "alarmar",
    "alarmos": "alar",
    "alarmou": "alarmar",
    "alarmá": "alarmar",
    "alarmámo": "alarmar",
    "alarmámos": "alarmar",
    "alarmáramo": "alarmar",
    "alarmáramos": "alarmar",
    "alarmárei": "alarmar",
    "alarmáreis": "alarmar",
    "alarmásseis": "alarmar",
    "alarmássemos": "alarmar",
    "alarmávamo": "alarmar",
    "alarmávamos": "alarmar",
    "alarmávei": "alarmar",
    "alarmáveis": "alarmar",
    "alaro": "alarar",
    "alarou": "alarar",
    "alarvadas": "alarvada",
    "alarvarias": "alarvaria",
    "alarveja": "alarvejar",
    "alarvejada": "alarvejar",
    "alarvejadas": "alarvejar",
    "alarvejado": "alarvejar",
    "alarvejados": "alarvejar",
    "alarvejai": "alarvejar",
    "alarvejais": "alarvejar",
    "alarvejam": "alarvejar",
    "alarvejamo": "alarvejar",
    "alarvejamos": "alarvejar",
    "alarvejando": "alarvejar",
    "alarvejara": "alarvejar",
    "alarvejaram": "alarvejar",
    "alarvejaras": "alarvejar",
    "alarvejarde": "alarvejar",
    "alarvejardes": "alarvejar",
    "alarvejare": "alarvejar",
    "alarvejarei": "alarvejar",
    "alarvejareis": "alarvejar",
    "alarvejarem": "alarvejar",
    "alarvejaremos": "alarvejar",
    "alarvejares": "alarvejar",
    "alarvejaria": "alarvejar",
    "alarvejariam": "alarvejar",
    "alarvejarias": "alarvejar",
    "alarvejarmo": "alarvejar",
    "alarvejarmos": "alarvejar",
    "alarvejará": "alarvejar",
    "alarvejarás": "alarvejar",
    "alarvejarão": "alarvejar",
    "alarvejaríamos": "alarvejar",
    "alarvejaríeis": "alarvejar",
    "alarvejas": "alarvejar",
    "alarvejasse": "alarvejar",
    "alarvejassem": "alarvejar",
    "alarvejasses": "alarvejar",
    "alarvejaste": "alarvejar",
    "alarvejastes": "alarvejar",
    "alarvejava": "alarvejar",
    "alarvejavam": "alarvejar",
    "alarvejavas": "alarvejar",
    "alarveje": "alarvejar",
    "alarvejei": "alarvejar",
    "alarvejeis": "alarvejar",
    "alarvejem": "alarvejar",
    "alarvejemo": "alarvejar",
    "alarvejemos": "alarvejar",
    "alarvejes": "alarvejar",
    "alarvejo": "alarvejar",
    "alarvejou": "alarvejar",
    "alarvejá": "alarvejar",
    "alarvejámo": "alarvejar",
    "alarvejámos": "alarvejar",
    "alarvejáramo": "alarvejar",
    "alarvejáramos": "alarvejar",
    "alarvejárei": "alarvejar",
    "alarvejáreis": "alarvejar",
    "alarvejásseis": "alarvejar",
    "alarvejássemos": "alarvejar",
    "alarvejávamo": "alarvejar",
    "alarvejávamos": "alarvejar",
    "alarvejávei": "alarvejar",
    "alarvejáveis": "alarvejar",
    "alarves": "alarve",
    "alarvias": "alarvia",
    "alarvices": "alarvice",
    "alarvidades": "alarvidade",
    "alará": "alarar",
    "alarámo": "alarar",
    "alarámos": "alarar",
    "alaráramo": "alarar",
    "alaráramos": "alarar",
    "alarárei": "alarar",
    "alaráreis": "alarar",
    "alarás": "alar",
    "alarásseis": "alarar",
    "alarássemos": "alarar",
    "alarávamo": "alarar",
    "alarávamos": "alarar",
    "alarávei": "alarar",
    "alaráveis": "alarar",
    "alarão": "alar",
    "alaríamos": "alar",
    "alaríeis": "alar",
    "alas": "alar",
    "alasquitos": "alasquito",
    "alassa": "alassar",
    "alassada": "alassar",
    "alassadas": "alassar",
    "alassado": "alassar",
    "alassados": "alassar",
    "alassai": "alassar",
    "alassais": "alassar",
    "alassam": "alassar",
    "alassamo": "alassar",
    "alassamos": "alassar",
    "alassando": "alassar",
    "alassara": "alassar",
    "alassaram": "alassar",
    "alassaras": "alassar",
    "alassarde": "alassar",
    "alassardes": "alassar",
    "alassare": "alassar",
    "alassarei": "alassar",
    "alassareis": "alassar",
    "alassarem": "alassar",
    "alassaremos": "alassar",
    "alassares": "alassar",
    "alassaria": "alassar",
    "alassariam": "alassar",
    "alassarias": "alassar",
    "alassarmo": "alassar",
    "alassarmos": "alassar",
    "alassará": "alassar",
    "alassarás": "alassar",
    "alassarão": "alassar",
    "alassaríamos": "alassar",
    "alassaríeis": "alassar",
    "alassas": "alassar",
    "alassasse": "alassar",
    "alassassem": "alassar",
    "alassasses": "alassar",
    "alassaste": "alassar",
    "alassastes": "alassar",
    "alassava": "alassar",
    "alassavam": "alassar",
    "alassavas": "alassar",
    "alasse": "alassar",
    "alassei": "alassar",
    "alasseis": "alassar",
    "alassem": "alassar",
    "alassemo": "alassar",
    "alassemos": "alassar",
    "alasses": "alassar",
    "alasso": "alassar",
    "alassou": "alassar",
    "alassá": "alassar",
    "alassámo": "alassar",
    "alassámos": "alassar",
    "alassáramo": "alassar",
    "alassáramos": "alassar",
    "alassárei": "alassar",
    "alassáreis": "alassar",
    "alassásseis": "alassar",
    "alassássemos": "alassar",
    "alassávamo": "alassar",
    "alassávamos": "alassar",
    "alassávei": "alassar",
    "alassáveis": "alassar",
    "alaste": "alar",
    "alastes": "alar",
    "alastra": "alastrar",
    "alastrada": "alastrar",
    "alastradas": "alastrar",
    "alastradeira": "alastrador",
    "alastradeiras": "alastrador",
    "alastradeiros": "alastradeiro",
    "alastrado": "alastrar",
    "alastradora": "alastrador",
    "alastradoras": "alastrador",
    "alastradores": "alastrador",
    "alastrados": "alastrar",
    "alastrai": "alastrar",
    "alastrais": "alastrar",
    "alastram": "alastrar",
    "alastramentos": "alastramento",
    "alastramo": "alastrar",
    "alastramos": "alastrar",
    "alastrando": "alastrar",
    "alastrara": "alastrar",
    "alastraram": "alastrar",
    "alastraras": "alastrar",
    "alastrardes": "alastrar",
    "alastrarei": "alastrar",
    "alastrareis": "alastrar",
    "alastrarem": "alastrar",
    "alastraremos": "alastrar",
    "alastrares": "alastrar",
    "alastraria": "alastrar",
    "alastrariam": "alastrar",
    "alastrarias": "alastrar",
    "alastrarmo": "alastrar",
    "alastrarmos": "alastrar",
    "alastrará": "alastrar",
    "alastrarás": "alastrar",
    "alastrarão": "alastrar",
    "alastraríamos": "alastrar",
    "alastraríeis": "alastrar",
    "alastras": "alastrar",
    "alastrasse": "alastrar",
    "alastrassem": "alastrar",
    "alastrasses": "alastrar",
    "alastraste": "alastrar",
    "alastrastes": "alastrar",
    "alastrava": "alastrar",
    "alastravam": "alastrar",
    "alastravas": "alastrar",
    "alastre": "alastrar",
    "alastrei": "alastrar",
    "alastreis": "alastrar",
    "alastrem": "alastrar",
    "alastremo": "alastrar",
    "alastremos": "alastrar",
    "alastres": "alastrar",
    "alastrins": "alastrim",
    "alastro": "alastrar",
    "alastrou": "alastrar",
    "alastrámo": "alastrar",
    "alastrámos": "alastrar",
    "alastráramo": "alastrar",
    "alastráramos": "alastrar",
    "alastráreis": "alastrar",
    "alastrásseis": "alastrar",
    "alastrássemos": "alastrar",
    "alastrávamo": "alastrar",
    "alastrávamos": "alastrar",
    "alastráveis": "alastrar",
    "alatina": "alatinar",
    "alatinada": "alatinar",
    "alatinadas": "alatinar",
    "alatinado": "alatinar",
    "alatinados": "alatinar",
    "alatinai": "alatinar",
    "alatinais": "alatinar",
    "alatinam": "alatinar",
    "alatinamentos": "alatinamento",
    "alatinamo": "alatinar",
    "alatinamos": "alatinar",
    "alatinando": "alatinar",
    "alatinara": "alatinar",
    "alatinaram": "alatinar",
    "alatinaras": "alatinar",
    "alatinarde": "alatinar",
    "alatinardes": "alatinar",
    "alatinare": "alatinar",
    "alatinarei": "alatinar",
    "alatinareis": "alatinar",
    "alatinarem": "alatinar",
    "alatinaremos": "alatinar",
    "alatinares": "alatinar",
    "alatinaria": "alatinar",
    "alatinariam": "alatinar",
    "alatinarias": "alatinar",
    "alatinarmo": "alatinar",
    "alatinarmos": "alatinar",
    "alatinará": "alatinar",
    "alatinarás": "alatinar",
    "alatinarão": "alatinar",
    "alatinaríamos": "alatinar",
    "alatinaríeis": "alatinar",
    "alatinas": "alatinar",
    "alatinasse": "alatinar",
    "alatinassem": "alatinar",
    "alatinasses": "alatinar",
    "alatinaste": "alatinar",
    "alatinastes": "alatinar",
    "alatinava": "alatinar",
    "alatinavam": "alatinar",
    "alatinavas": "alatinar",
    "alatine": "alatinar",
    "alatinei": "alatinar",
    "alatineis": "alatinar",
    "alatinem": "alatinar",
    "alatinemo": "alatinar",
    "alatinemos": "alatinar",
    "alatines": "alatinar",
    "alatino": "alatinar",
    "alatinou": "alatinar",
    "alatiná": "alatinar",
    "alatinámo": "alatinar",
    "alatinámos": "alatinar",
    "alatináramo": "alatinar",
    "alatináramos": "alatinar",
    "alatinárei": "alatinar",
    "alatináreis": "alatinar",
    "alatinásseis": "alatinar",
    "alatinássemos": "alatinar",
    "alatinávamo": "alatinar",
    "alatinávamos": "alatinar",
    "alatinávei": "alatinar",
    "alatináveis": "alatinar",
    "alatoa": "alatoar",
    "alatoada": "alatoar",
    "alatoadas": "alatoar",
    "alatoado": "alatoar",
    "alatoados": "alatoar",
    "alatoai": "alatoar",
    "alatoais": "alatoar",
    "alatoam": "alatoar",
    "alatoamentos": "alatoamento",
    "alatoamo": "alatoar",
    "alatoamos": "alatoar",
    "alatoando": "alatoar",
    "alatoara": "alatoar",
    "alatoaram": "alatoar",
    "alatoaras": "alatoar",
    "alatoarde": "alatoar",
    "alatoardes": "alatoar",
    "alatoare": "alatoar",
    "alatoarei": "alatoar",
    "alatoareis": "alatoar",
    "alatoarem": "alatoar",
    "alatoaremos": "alatoar",
    "alatoares": "alatoar",
    "alatoaria": "alatoar",
    "alatoariam": "alatoar",
    "alatoarias": "alatoar",
    "alatoarmo": "alatoar",
    "alatoarmos": "alatoar",
    "alatoará": "alatoar",
    "alatoarás": "alatoar",
    "alatoarão": "alatoar",
    "alatoaríamos": "alatoar",
    "alatoaríeis": "alatoar",
    "alatoas": "alatoar",
    "alatoasse": "alatoar",
    "alatoassem": "alatoar",
    "alatoasses": "alatoar",
    "alatoaste": "alatoar",
    "alatoastes": "alatoar",
    "alatoava": "alatoar",
    "alatoavam": "alatoar",
    "alatoavas": "alatoar",
    "alatoe": "alatoar",
    "alatoei": "alatoar",
    "alatoeis": "alatoar",
    "alatoem": "alatoar",
    "alatoemo": "alatoar",
    "alatoemos": "alatoar",
    "alatoes": "alatoar",
    "alatoo": "alatoar",
    "alatoou": "alatoar",
    "alatoá": "alatoar",
    "alatoámo": "alatoar",
    "alatoámos": "alatoar",
    "alatoáramo": "alatoar",
    "alatoáramos": "alatoar",
    "alatoárei": "alatoar",
    "alatoáreis": "alatoar",
    "alatoásseis": "alatoar",
    "alatoássemos": "alatoar",
    "alatoávamo": "alatoar",
    "alatoávamos": "alatoar",
    "alatoávei": "alatoar",
    "alatoáveis": "alatoar",
    "alaudidas": "alaudida",
    "alaudinas": "alaudina",
    "alaudistas": "alaudista",
    "alava": "alar",
    "alavam": "alar",
    "alavancas": "alavanca",
    "alavancos": "alavanco",
    "alavarda": "alavardo",
    "alavardas": "alavardo",
    "alavardos": "alavardo",
    "alavas": "alar",
    "alavoeiros": "alavoeiro",
    "alavona": "alavão",
    "alavonas": "alavão",
    "alavões": "alavão",
    "alazarada": "alazarado",
    "alazaradas": "alazarado",
    "alazarados": "alazarado",
    "alazeirada": "alazeirado",
    "alazeiradas": "alazeirado",
    "alazeirados": "alazeirado",
    "alazona": "alazão",
    "alazonas": "alazão",
    "alazões": "alazão",
    "alaúdes": "alaúde",
    "albacares": "albacar",
    "albacoras": "albacora",
    "albacores": "albacor",
    "albafares": "albafar",
    "albaflores": "albaflor",
    "albaforas": "albafora",
    "albafores": "albafor",
    "albana": "albano",
    "albanas": "albano",
    "albanesa": "albanês",
    "albanesas": "albanesa",
    "albaneses": "albanês",
    "albanos": "albano",
    "albarcas": "albarca",
    "albarda": "albardar",
    "albardada": "albardar",
    "albardadas": "albardar",
    "albardado": "albardar",
    "albardados": "albardar",
    "albardaduras": "albardadura",
    "albardai": "albardar",
    "albardais": "albardar",
    "albardam": "albardar",
    "albardamo": "albardar",
    "albardamos": "albardar",
    "albardando": "albardar",
    "albardara": "albardar",
    "albardaram": "albardar",
    "albardaras": "albardar",
    "albardarde": "albardar",
    "albardardes": "albardar",
    "albardare": "albardar",
    "albardarei": "albardar",
    "albardareis": "albardar",
    "albardarem": "albardar",
    "albardaremos": "albardar",
    "albardares": "albardar",
    "albardaria": "albardar",
    "albardariam": "albardar",
    "albardarias": "albardaria",
    "albardarmo": "albardar",
    "albardarmos": "albardar",
    "albardará": "albardar",
    "albardarás": "albardar",
    "albardarão": "albardar",
    "albardaríamos": "albardar",
    "albardaríeis": "albardar",
    "albardas": "albardar",
    "albardasse": "albardar",
    "albardassem": "albardar",
    "albardasses": "albardar",
    "albardaste": "albardar",
    "albardastes": "albardar",
    "albardava": "albardar",
    "albardavam": "albardar",
    "albardavas": "albardar",
    "albarde": "albardar",
    "albardei": "albardar",
    "albardeira": "albardeiro",
    "albardeiras": "albardeiro",
    "albardeiros": "albardeiro",
    "albardeis": "albardar",
    "albardem": "albardar",
    "albardemo": "albardar",
    "albardemos": "albardar",
    "albardes": "albardar",
    "albardilhas": "albardilha",
    "albardo": "albardar",
    "albardona": "albardão",
    "albardonas": "albardão",
    "albardou": "albardar",
    "albardá": "albardar",
    "albardámo": "albardar",
    "albardámos": "albardar",
    "albardáramo": "albardar",
    "albardáramos": "albardar",
    "albardárei": "albardar",
    "albardáreis": "albardar",
    "albardásseis": "albardar",
    "albardássemos": "albardar",
    "albardávamo": "albardar",
    "albardávamos": "albardar",
    "albardávei": "albardar",
    "albardáveis": "albardar",
    "albardões": "albardão",
    "albarelas": "albarela",
    "albarelos": "albarelo",
    "albarrãs": "albarrã",
    "albas": "alba",
    "albatrozes": "albatroz",
    "albedos": "albedo",
    "albenas": "albena",
    "albentes": "albente",
    "albercas": "alberca",
    "alberga": "albergar",
    "albergada": "albergar",
    "albergadas": "albergar",
    "albergado": "albergar",
    "albergados": "albergar",
    "albergagens": "albergagem",
    "albergai": "albergar",
    "albergais": "albergar",
    "albergam": "albergar",
    "albergamentos": "albergamento",
    "albergamo": "albergar",
    "albergamos": "albergar",
    "albergando": "albergar",
    "albergara": "albergar",
    "albergaram": "albergar",
    "albergaras": "albergar",
    "albergarde": "albergar",
    "albergardes": "albergar",
    "albergare": "albergar",
    "albergarei": "albergar",
    "albergareis": "albergar",
    "albergarem": "albergar",
    "albergaremos": "albergar",
    "albergares": "albergar",
    "albergaria": "albergar",
    "albergariam": "albergar",
    "albergarias": "albergaria",
    "albergarmo": "albergar",
    "albergarmos": "albergar",
    "albergará": "albergar",
    "albergarás": "albergar",
    "albergarão": "albergar",
    "albergaríamos": "albergar",
    "albergaríeis": "albergar",
    "albergas": "albergar",
    "albergasse": "albergar",
    "albergassem": "albergar",
    "albergasses": "albergar",
    "albergaste": "albergar",
    "albergastes": "albergar",
    "albergava": "albergar",
    "albergavam": "albergar",
    "albergavas": "albergar",
    "albergo": "albergar",
    "albergou": "albergar",
    "albergue": "albergar",
    "alberguei": "albergar",
    "albergueira": "albergueiro",
    "albergueiras": "albergueiro",
    "albergueiros": "albergueiro",
    "albergueis": "albergar",
    "alberguem": "albergar",
    "alberguemo": "albergar",
    "alberguemos": "albergar",
    "albergues": "albergue",
    "albergá": "albergar",
    "albergámo": "albergar",
    "albergámos": "albergar",
    "albergáramo": "albergar",
    "albergáramos": "albergar",
    "albergárei": "albergar",
    "albergáreis": "albergar",
    "albergásseis": "albergar",
    "albergássemos": "albergar",
    "albergávamo": "albergar",
    "albergávamos": "albergar",
    "albergávei": "albergar",
    "albergáveis": "albergar",
    "albertinhos": "albertinho",
    "albianos": "albiano",
    "albicastrenses": "albicastrense",
    "albicaudes": "albicaude",
    "albicaules": "albicaule",
    "albicoles": "albicole",
    "albicípites": "albicípite",
    "albicórnea": "albicórneo",
    "albicórneas": "albicórneo",
    "albicórneos": "albicórneo",
    "albifica": "albificar",
    "albificada": "albificar",
    "albificadas": "albificar",
    "albificado": "albificar",
    "albificados": "albificar",
    "albificai": "albificar",
    "albificais": "albificar",
    "albificam": "albificar",
    "albificamo": "albificar",
    "albificamos": "albificar",
    "albificando": "albificar",
    "albificara": "albificar",
    "albificaram": "albificar",
    "albificaras": "albificar",
    "albificarde": "albificar",
    "albificardes": "albificar",
    "albificare": "albificar",
    "albificarei": "albificar",
    "albificareis": "albificar",
    "albificarem": "albificar",
    "albificaremos": "albificar",
    "albificares": "albificar",
    "albificaria": "albificar",
    "albificariam": "albificar",
    "albificarias": "albificar",
    "albificarmo": "albificar",
    "albificarmos": "albificar",
    "albificará": "albificar",
    "albificarás": "albificar",
    "albificarão": "albificar",
    "albificaríamos": "albificar",
    "albificaríeis": "albificar",
    "albificas": "albificar",
    "albificasse": "albificar",
    "albificassem": "albificar",
    "albificasses": "albificar",
    "albificaste": "albificar",
    "albificastes": "albificar",
    "albificava": "albificar",
    "albificavam": "albificar",
    "albificavas": "albificar",
    "albificações": "albificação",
    "albifico": "albificar",
    "albificou": "albificar",
    "albificá": "albificar",
    "albificámo": "albificar",
    "albificámos": "albificar",
    "albificáramo": "albificar",
    "albificáramos": "albificar",
    "albificárei": "albificar",
    "albificáreis": "albificar",
    "albificásseis": "albificar",
    "albificássemos": "albificar",
    "albificávamo": "albificar",
    "albificávamos": "albificar",
    "albificávei": "albificar",
    "albificáveis": "albificar",
    "albifique": "albificar",
    "albifiquei": "albificar",
    "albifiqueis": "albificar",
    "albifiquem": "albificar",
    "albifiquemo": "albificar",
    "albifiquemos": "albificar",
    "albifiques": "albificar",
    "albigenses": "albigense",
    "albigíneas": "albigínea",
    "albina": "albino",
    "albinas": "albino",
    "albinias": "albinia",
    "albinos": "albino",
    "albirrosada": "albirrosado",
    "albirrosadas": "albirrosado",
    "albirrosados": "albirrosado",
    "albirrostra": "albirrostro",
    "albirrostras": "albirrostro",
    "albirrostros": "albirrostro",
    "albites": "albite",
    "albititos": "albitito",
    "albitizações": "albitização",
    "albitófiros": "albitófiro",
    "albiventres": "albiventre",
    "albogues": "albogue",
    "alboques": "alboque",
    "alboranitos": "alboranito",
    "alborca": "alborcar",
    "alborcada": "alborcar",
    "alborcadas": "alborcar",
    "alborcado": "alborcar",
    "alborcados": "alborcar",
    "alborcai": "alborcar",
    "alborcais": "alborcar",
    "alborcam": "alborcar",
    "alborcamo": "alborcar",
    "alborcamos": "alborcar",
    "alborcando": "alborcar",
    "alborcara": "alborcar",
    "alborcaram": "alborcar",
    "alborcaras": "alborcar",
    "alborcarde": "alborcar",
    "alborcardes": "alborcar",
    "alborcare": "alborcar",
    "alborcarei": "alborcar",
    "alborcareis": "alborcar",
    "alborcarem": "alborcar",
    "alborcaremos": "alborcar",
    "alborcares": "alborcar",
    "alborcaria": "alborcar",
    "alborcariam": "alborcar",
    "alborcarias": "alborcar",
    "alborcarmo": "alborcar",
    "alborcarmos": "alborcar",
    "alborcará": "alborcar",
    "alborcarás": "alborcar",
    "alborcarão": "alborcar",
    "alborcaríamos": "alborcar",
    "alborcaríeis": "alborcar",
    "alborcas": "alborcar",
    "alborcasse": "alborcar",
    "alborcassem": "alborcar",
    "alborcasses": "alborcar",
    "alborcaste": "alborcar",
    "alborcastes": "alborcar",
    "alborcava": "alborcar",
    "alborcavam": "alborcar",
    "alborcavas": "alborcar",
    "alborco": "alborcar",
    "alborcou": "alborcar",
    "alborcá": "alborcar",
    "alborcámo": "alborcar",
    "alborcámos": "alborcar",
    "alborcáramo": "alborcar",
    "alborcáramos": "alborcar",
    "alborcárei": "alborcar",
    "alborcáreis": "alborcar",
    "alborcásseis": "alborcar",
    "alborcássemos": "alborcar",
    "alborcávamo": "alborcar",
    "alborcávamos": "alborcar",
    "alborcávei": "alborcar",
    "alborcáveis": "alborcar",
    "albores": "albor",
    "albornozes": "albornoz",
    "alboroques": "alboroque",
    "alborota": "alborotar",
    "alborotada": "alborotar",
    "alborotadas": "alborotar",
    "alborotado": "alborotar",
    "alborotados": "alborotar",
    "alborotai": "alborotar",
    "alborotais": "alborotar",
    "alborotam": "alborotar",
    "alborotamo": "alborotar",
    "alborotamos": "alborotar",
    "alborotando": "alborotar",
    "alborotara": "alborotar",
    "alborotaram": "alborotar",
    "alborotaras": "alborotar",
    "alborotarde": "alborotar",
    "alborotardes": "alborotar",
    "alborotare": "alborotar",
    "alborotarei": "alborotar",
    "alborotareis": "alborotar",
    "alborotarem": "alborotar",
    "alborotaremos": "alborotar",
    "alborotares": "alborotar",
    "alborotaria": "alborotar",
    "alborotariam": "alborotar",
    "alborotarias": "alborotar",
    "alborotarmo": "alborotar",
    "alborotarmos": "alborotar",
    "alborotará": "alborotar",
    "alborotarás": "alborotar",
    "alborotarão": "alborotar",
    "alborotaríamos": "alborotar",
    "alborotaríeis": "alborotar",
    "alborotas": "alborotar",
    "alborotasse": "alborotar",
    "alborotassem": "alborotar",
    "alborotasses": "alborotar",
    "alborotaste": "alborotar",
    "alborotastes": "alborotar",
    "alborotava": "alborotar",
    "alborotavam": "alborotar",
    "alborotavas": "alborotar",
    "alborote": "alborotar",
    "alborotei": "alborotar",
    "alboroteis": "alborotar",
    "alborotem": "alborotar",
    "alborotemo": "alborotar",
    "alborotemos": "alborotar",
    "alborotes": "alborotar",
    "alboroto": "alborotar",
    "alborotos": "alboroto",
    "alborotou": "alborotar",
    "alborotá": "alborotar",
    "alborotámo": "alborotar",
    "alborotámos": "alborotar",
    "alborotáramo": "alborotar",
    "alborotáramos": "alborotar",
    "alborotárei": "alborotar",
    "alborotáreis": "alborotar",
    "alborotásseis": "alborotar",
    "alborotássemos": "alborotar",
    "alborotávamo": "alborotar",
    "alborotávamos": "alborotar",
    "alborotávei": "alborotar",
    "alborotáveis": "alborotar",
    "alborque": "alborcar",
    "alborquei": "alborcar",
    "alborqueis": "alborcar",
    "alborquem": "alborcar",
    "alborquemo": "alborcar",
    "alborquemos": "alborcar",
    "alborques": "alborque",
    "albricoqueiros": "albricoqueiro",
    "albricoques": "albricoque",
    "albufagens": "albufagem",
    "albufeira": "albufeirar",
    "albufeirada": "albufeirar",
    "albufeiradas": "albufeirar",
    "albufeirado": "albufeirar",
    "albufeirados": "albufeirar",
    "albufeirai": "albufeirar",
    "albufeirais": "albufeirar",
    "albufeiram": "albufeirar",
    "albufeiramo": "albufeirar",
    "albufeiramos": "albufeirar",
    "albufeirando": "albufeirar",
    "albufeirara": "albufeirar",
    "albufeiraram": "albufeirar",
    "albufeiraras": "albufeirar",
    "albufeirarde": "albufeirar",
    "albufeirardes": "albufeirar",
    "albufeirare": "albufeirar",
    "albufeirarei": "albufeirar",
    "albufeirareis": "albufeirar",
    "albufeirarem": "albufeirar",
    "albufeiraremos": "albufeirar",
    "albufeirares": "albufeirar",
    "albufeiraria": "albufeirar",
    "albufeirariam": "albufeirar",
    "albufeirarias": "albufeirar",
    "albufeirarmo": "albufeirar",
    "albufeirarmos": "albufeirar",
    "albufeirará": "albufeirar",
    "albufeirarás": "albufeirar",
    "albufeirarão": "albufeirar",
    "albufeiraríamos": "albufeirar",
    "albufeiraríeis": "albufeirar",
    "albufeiras": "albufeirar",
    "albufeirasse": "albufeirar",
    "albufeirassem": "albufeirar",
    "albufeirasses": "albufeirar",
    "albufeiraste": "albufeirar",
    "albufeirastes": "albufeirar",
    "albufeirava": "albufeirar",
    "albufeiravam": "albufeirar",
    "albufeiravas": "albufeirar",
    "albufeire": "albufeirar",
    "albufeirei": "albufeirar",
    "albufeireis": "albufeirar",
    "albufeirem": "albufeirar",
    "albufeiremo": "albufeirar",
    "albufeiremos": "albufeirar",
    "albufeires": "albufeirar",
    "albufeiro": "albufeirar",
    "albufeirou": "albufeirar",
    "albufeirá": "albufeirar",
    "albufeirámo": "albufeirar",
    "albufeirámos": "albufeirar",
    "albufeiráramo": "albufeirar",
    "albufeiráramos": "albufeirar",
    "albufeirárei": "albufeirar",
    "albufeiráreis": "albufeirar",
    "albufeirásseis": "albufeirar",
    "albufeirássemos": "albufeirar",
    "albufeirávamo": "albufeirar",
    "albufeirávamos": "albufeirar",
    "albufeirávei": "albufeirar",
    "albufeiráveis": "albufeirar",
    "albugens": "albugem",
    "albuginada": "albuginado",
    "albuginadas": "albuginado",
    "albuginados": "albuginado",
    "albuginea": "albugineo",
    "albugineas": "albugineo",
    "albugineos": "albugineo",
    "albuginites": "albuginite",
    "albuginosa": "albuginoso",
    "albuginosas": "albuginoso",
    "albuginosos": "albuginoso",
    "albugos": "albugo",
    "albumes": "albume",
    "albumina": "albuminar",
    "albuminada": "albuminar",
    "albuminadas": "albuminar",
    "albuminado": "albuminar",
    "albuminados": "albuminar",
    "albuminagens": "albuminagem",
    "albuminai": "albuminar",
    "albuminais": "albuminar",
    "albuminam": "albuminar",
    "albuminamo": "albuminar",
    "albuminamos": "albuminar",
    "albuminando": "albuminar",
    "albuminara": "albuminar",
    "albuminaram": "albuminar",
    "albuminaras": "albuminar",
    "albuminarde": "albuminar",
    "albuminardes": "albuminar",
    "albuminare": "albuminar",
    "albuminarei": "albuminar",
    "albuminareis": "albuminar",
    "albuminarem": "albuminar",
    "albuminaremos": "albuminar",
    "albuminares": "albuminar",
    "albuminaria": "albuminar",
    "albuminariam": "albuminar",
    "albuminarias": "albuminar",
    "albuminarmo": "albuminar",
    "albuminarmos": "albuminar",
    "albuminará": "albuminar",
    "albuminarás": "albuminar",
    "albuminarão": "albuminar",
    "albuminaríamos": "albuminar",
    "albuminaríeis": "albuminar",
    "albuminas": "albuminar",
    "albuminasse": "albuminar",
    "albuminassem": "albuminar",
    "albuminasses": "albuminar",
    "albuminaste": "albuminar",
    "albuminastes": "albuminar",
    "albuminatos": "albuminato",
    "albuminava": "albuminar",
    "albuminavam": "albuminar",
    "albuminavas": "albuminar",
    "albumine": "albuminar",
    "albuminei": "albuminar",
    "albumineis": "albuminar",
    "albuminem": "albuminar",
    "albuminemo": "albuminar",
    "albuminemos": "albuminar",
    "albumines": "albuminar",
    "albuminiformes": "albuminiforme",
    "albumininas": "albuminina",
    "albumino": "albuminar",
    "albuminosa": "albuminoso",
    "albuminosas": "albuminoso",
    "albuminoses": "albuminose",
    "albuminosos": "albuminoso",
    "albuminou": "albuminar",
    "albuminá": "albuminar",
    "albuminámo": "albuminar",
    "albuminámos": "albuminar",
    "albumináramo": "albuminar",
    "albumináramos": "albuminar",
    "albuminárei": "albuminar",
    "albumináreis": "albuminar",
    "albuminásseis": "albuminar",
    "albuminássemos": "albuminar",
    "albuminávamo": "albuminar",
    "albuminávamos": "albuminar",
    "albuminávei": "albuminar",
    "albumináveis": "albuminar",
    "albuminímetros": "albuminímetro",
    "albuminóides": "albuminóide",
    "albuminómetros": "albuminómetro",
    "albuminúrias": "albuminúria",
    "albuminúrica": "albuminúrico",
    "albuminúricas": "albuminúrico",
    "albuminúricos": "albuminúrico",
    "albumoses": "albumose",
    "alburnos": "alburno",
    "albípedes": "albípede",
    "albóios": "albóio",
    "albúmenes": "albúmen",
    "albúmens": "albúmen",
    "alcabozes": "alcaboz",
    "alcabrozes": "alcabroz",
    "alcabóis": "alcabol",
    "alcacerenses": "alcacerense",
    "alcachina": "alcachinar",
    "alcachinada": "alcachinar",
    "alcachinadas": "alcachinar",
    "alcachinado": "alcachinar",
    "alcachinados": "alcachinar",
    "alcachinai": "alcachinar",
    "alcachinais": "alcachinar",
    "alcachinam": "alcachinar",
    "alcachinamo": "alcachinar",
    "alcachinamos": "alcachinar",
    "alcachinando": "alcachinar",
    "alcachinara": "alcachinar",
    "alcachinaram": "alcachinar",
    "alcachinaras": "alcachinar",
    "alcachinarde": "alcachinar",
    "alcachinardes": "alcachinar",
    "alcachinare": "alcachinar",
    "alcachinarei": "alcachinar",
    "alcachinareis": "alcachinar",
    "alcachinarem": "alcachinar",
    "alcachinaremos": "alcachinar",
    "alcachinares": "alcachinar",
    "alcachinaria": "alcachinar",
    "alcachinariam": "alcachinar",
    "alcachinarias": "alcachinar",
    "alcachinarmo": "alcachinar",
    "alcachinarmos": "alcachinar",
    "alcachinará": "alcachinar",
    "alcachinarás": "alcachinar",
    "alcachinarão": "alcachinar",
    "alcachinaríamos": "alcachinar",
    "alcachinaríeis": "alcachinar",
    "alcachinas": "alcachinar",
    "alcachinasse": "alcachinar",
    "alcachinassem": "alcachinar",
    "alcachinasses": "alcachinar",
    "alcachinaste": "alcachinar",
    "alcachinastes": "alcachinar",
    "alcachinava": "alcachinar",
    "alcachinavam": "alcachinar",
    "alcachinavas": "alcachinar",
    "alcachine": "alcachinar",
    "alcachinei": "alcachinar",
    "alcachineis": "alcachinar",
    "alcachinem": "alcachinar",
    "alcachinemo": "alcachinar",
    "alcachinemos": "alcachinar",
    "alcachines": "alcachinar",
    "alcachino": "alcachinar",
    "alcachinou": "alcachinar",
    "alcachiná": "alcachinar",
    "alcachinámo": "alcachinar",
    "alcachinámos": "alcachinar",
    "alcachináramo": "alcachinar",
    "alcachináramos": "alcachinar",
    "alcachinárei": "alcachinar",
    "alcachináreis": "alcachinar",
    "alcachinásseis": "alcachinar",
    "alcachinássemos": "alcachinar",
    "alcachinávamo": "alcachinar",
    "alcachinávamos": "alcachinar",
    "alcachinávei": "alcachinar",
    "alcachináveis": "alcachinar",
    "alcachofas": "alcachofa",
    "alcachofra": "alcachofrar",
    "alcachofrada": "alcachofrar",
    "alcachofradas": "alcachofrar",
    "alcachofrado": "alcachofrar",
    "alcachofrados": "alcachofrar",
    "alcachofrai": "alcachofrar",
    "alcachofrais": "alcachofrar",
    "alcachofram": "alcachofrar",
    "alcachoframo": "alcachofrar",
    "alcachoframos": "alcachofrar",
    "alcachofrando": "alcachofrar",
    "alcachofrara": "alcachofrar",
    "alcachofraram": "alcachofrar",
    "alcachofraras": "alcachofrar",
    "alcachofrarde": "alcachofrar",
    "alcachofrardes": "alcachofrar",
    "alcachofrare": "alcachofrar",
    "alcachofrarei": "alcachofrar",
    "alcachofrareis": "alcachofrar",
    "alcachofrarem": "alcachofrar",
    "alcachofraremos": "alcachofrar",
    "alcachofrares": "alcachofrar",
    "alcachofraria": "alcachofrar",
    "alcachofrariam": "alcachofrar",
    "alcachofrarias": "alcachofrar",
    "alcachofrarmo": "alcachofrar",
    "alcachofrarmos": "alcachofrar",
    "alcachofrará": "alcachofrar",
    "alcachofrarás": "alcachofrar",
    "alcachofrarão": "alcachofrar",
    "alcachofraríamos": "alcachofrar",
    "alcachofraríeis": "alcachofrar",
    "alcachofras": "alcachofrar",
    "alcachofrasse": "alcachofrar",
    "alcachofrassem": "alcachofrar",
    "alcachofrasses": "alcachofrar",
    "alcachofraste": "alcachofrar",
    "alcachofrastes": "alcachofrar",
    "alcachofrava": "alcachofrar",
    "alcachofravam": "alcachofrar",
    "alcachofravas": "alcachofrar",
    "alcachofre": "alcachofrar",
    "alcachofrei": "alcachofrar",
    "alcachofreis": "alcachofrar",
    "alcachofrem": "alcachofrar",
    "alcachofremo": "alcachofrar",
    "alcachofremos": "alcachofrar",
    "alcachofres": "alcachofrar",
    "alcachofro": "alcachofrar",
    "alcachofrou": "alcachofrar",
    "alcachofrá": "alcachofrar",
    "alcachofrámo": "alcachofrar",
    "alcachofrámos": "alcachofrar",
    "alcachofráramo": "alcachofrar",
    "alcachofráramos": "alcachofrar",
    "alcachofrárei": "alcachofrar",
    "alcachofráreis": "alcachofrar",
    "alcachofrásseis": "alcachofrar",
    "alcachofrássemos": "alcachofrar",
    "alcachofrávamo": "alcachofrar",
    "alcachofrávamos": "alcachofrar",
    "alcachofrávei": "alcachofrar",
    "alcachofráveis": "alcachofrar",
    "alcacéis": "alcacel",
    "alcadafes": "alcadafe",
    "alcagueta": "alcaguete",
    "alcaguetas": "alcaguete",
    "alcaguetes": "alcaguete",
    "alcaiatas": "alcaiata",
    "alcaiates": "alcaiate",
    "alcaica": "alcaico",
    "alcaicas": "alcaico",
    "alcaicos": "alcaico",
    "alcaidarias": "alcaidaria",
    "alcaides": "alcaide",
    "alcaidessa": "alcaide",
    "alcaidessas": "alcaide",
    "alcaidias": "alcaidia",
    "alcaiota": "alcaiote",
    "alcaiotada": "alcaiotar",
    "alcaiotadas": "alcaiotar",
    "alcaiotado": "alcaiotar",
    "alcaiotados": "alcaiotar",
    "alcaiotai": "alcaiotar",
    "alcaiotais": "alcaiotar",
    "alcaiotam": "alcaiotar",
    "alcaiotamo": "alcaiotar",
    "alcaiotamos": "alcaiotar",
    "alcaiotando": "alcaiotar",
    "alcaiotara": "alcaiotar",
    "alcaiotaram": "alcaiotar",
    "alcaiotaras": "alcaiotar",
    "alcaiotarde": "alcaiotar",
    "alcaiotardes": "alcaiotar",
    "alcaiotare": "alcaiotar",
    "alcaiotarei": "alcaiotar",
    "alcaiotareis": "alcaiotar",
    "alcaiotarem": "alcaiotar",
    "alcaiotaremos": "alcaiotar",
    "alcaiotares": "alcaiotar",
    "alcaiotaria": "alcaiotar",
    "alcaiotariam": "alcaiotar",
    "alcaiotarias": "alcaiotaria",
    "alcaiotarmo": "alcaiotar",
    "alcaiotarmos": "alcaiotar",
    "alcaiotará": "alcaiotar",
    "alcaiotarás": "alcaiotar",
    "alcaiotarão": "alcaiotar",
    "alcaiotaríamos": "alcaiotar",
    "alcaiotaríeis": "alcaiotar",
    "alcaiotas": "alcaiote",
    "alcaiotasse": "alcaiotar",
    "alcaiotassem": "alcaiotar",
    "alcaiotasses": "alcaiotar",
    "alcaiotaste": "alcaiotar",
    "alcaiotastes": "alcaiotar",
    "alcaiotava": "alcaiotar",
    "alcaiotavam": "alcaiotar",
    "alcaiotavas": "alcaiotar",
    "alcaiote": "alcaiotar",
    "alcaiotei": "alcaiotar",
    "alcaioteis": "alcaiotar",
    "alcaiotem": "alcaiotar",
    "alcaiotemo": "alcaiotar",
    "alcaiotemos": "alcaiotar",
    "alcaiotes": "alcaiote",
    "alcaioto": "alcaiotar",
    "alcaiotou": "alcaiotar",
    "alcaiotá": "alcaiotar",
    "alcaiotámo": "alcaiotar",
    "alcaiotámos": "alcaiotar",
    "alcaiotáramo": "alcaiotar",
    "alcaiotáramos": "alcaiotar",
    "alcaiotárei": "alcaiotar",
    "alcaiotáreis": "alcaiotar",
    "alcaiotásseis": "alcaiotar",
    "alcaiotássemos": "alcaiotar",
    "alcaiotávamo": "alcaiotar",
    "alcaiotávamos": "alcaiotar",
    "alcaiotávei": "alcaiotar",
    "alcaiotáveis": "alcaiotar",
    "alcaixas": "alcaixa",
    "alcalas": "alcala",
    "alcalenas": "alcalena",
    "alcalescentes": "alcalescente",
    "alcalescências": "alcalescência",
    "alcalicidades": "alcalicidade",
    "alcalifica": "alcalificar",
    "alcalificada": "alcalificar",
    "alcalificadas": "alcalificar",
    "alcalificado": "alcalificar",
    "alcalificados": "alcalificar",
    "alcalificai": "alcalificar",
    "alcalificais": "alcalificar",
    "alcalificam": "alcalificar",
    "alcalificamo": "alcalificar",
    "alcalificamos": "alcalificar",
    "alcalificando": "alcalificar",
    "alcalificantes": "alcalificante",
    "alcalificara": "alcalificar",
    "alcalificaram": "alcalificar",
    "alcalificaras": "alcalificar",
    "alcalificarde": "alcalificar",
    "alcalificardes": "alcalificar",
    "alcalificare": "alcalificar",
    "alcalificarei": "alcalificar",
    "alcalificareis": "alcalificar",
    "alcalificarem": "alcalificar",
    "alcalificaremos": "alcalificar",
    "alcalificares": "alcalificar",
    "alcalificaria": "alcalificar",
    "alcalificariam": "alcalificar",
    "alcalificarias": "alcalificar",
    "alcalificarmo": "alcalificar",
    "alcalificarmos": "alcalificar",
    "alcalificará": "alcalificar",
    "alcalificarás": "alcalificar",
    "alcalificarão": "alcalificar",
    "alcalificaríamos": "alcalificar",
    "alcalificaríeis": "alcalificar",
    "alcalificas": "alcalificar",
    "alcalificasse": "alcalificar",
    "alcalificassem": "alcalificar",
    "alcalificasses": "alcalificar",
    "alcalificaste": "alcalificar",
    "alcalificastes": "alcalificar",
    "alcalificava": "alcalificar",
    "alcalificavam": "alcalificar",
    "alcalificavas": "alcalificar",
    "alcalifico": "alcalificar",
    "alcalificou": "alcalificar",
    "alcalificá": "alcalificar",
    "alcalificámo": "alcalificar",
    "alcalificámos": "alcalificar",
    "alcalificáramo": "alcalificar",
    "alcalificáramos": "alcalificar",
    "alcalificárei": "alcalificar",
    "alcalificáreis": "alcalificar",
    "alcalificásseis": "alcalificar",
    "alcalificássemos": "alcalificar",
    "alcalificávamo": "alcalificar",
    "alcalificávamos": "alcalificar",
    "alcalificávei": "alcalificar",
    "alcalificáveis": "alcalificar",
    "alcalifique": "alcalificar",
    "alcalifiquei": "alcalificar",
    "alcalifiqueis": "alcalificar",
    "alcalifiquem": "alcalificar",
    "alcalifiquemo": "alcalificar",
    "alcalifiquemos": "alcalificar",
    "alcalifiques": "alcalificar",
    "alcalimetrias": "alcalimetria",
    "alcalimétrica": "alcalimétrico",
    "alcalimétricas": "alcalimétrico",
    "alcalimétricos": "alcalimétrico",
    "alcalina": "alcalino",
    "alcalinas": "alcalino",
    "alcalinidades": "alcalinidade",
    "alcalinismos": "alcalinismo",
    "alcaliniza": "alcalinizar",
    "alcalinizada": "alcalinizar",
    "alcalinizadas": "alcalinizar",
    "alcalinizado": "alcalinizar",
    "alcalinizados": "alcalinizar",
    "alcalinizai": "alcalinizar",
    "alcalinizais": "alcalinizar",
    "alcalinizam": "alcalinizar",
    "alcalinizamo": "alcalinizar",
    "alcalinizamos": "alcalinizar",
    "alcalinizando": "alcalinizar",
    "alcalinizara": "alcalinizar",
    "alcalinizaram": "alcalinizar",
    "alcalinizaras": "alcalinizar",
    "alcalinizarde": "alcalinizar",
    "alcalinizardes": "alcalinizar",
    "alcalinizare": "alcalinizar",
    "alcalinizarei": "alcalinizar",
    "alcalinizareis": "alcalinizar",
    "alcalinizarem": "alcalinizar",
    "alcalinizaremos": "alcalinizar",
    "alcalinizares": "alcalinizar",
    "alcalinizaria": "alcalinizar",
    "alcalinizariam": "alcalinizar",
    "alcalinizarias": "alcalinizar",
    "alcalinizarmo": "alcalinizar",
    "alcalinizarmos": "alcalinizar",
    "alcalinizará": "alcalinizar",
    "alcalinizarás": "alcalinizar",
    "alcalinizarão": "alcalinizar",
    "alcalinizaríamos": "alcalinizar",
    "alcalinizaríeis": "alcalinizar",
    "alcalinizas": "alcalinizar",
    "alcalinizasse": "alcalinizar",
    "alcalinizassem": "alcalinizar",
    "alcalinizasses": "alcalinizar",
    "alcalinizaste": "alcalinizar",
    "alcalinizastes": "alcalinizar",
    "alcalinizava": "alcalinizar",
    "alcalinizavam": "alcalinizar",
    "alcalinizavas": "alcalinizar",
    "alcalinize": "alcalinizar",
    "alcalinizei": "alcalinizar",
    "alcalinizeis": "alcalinizar",
    "alcalinizem": "alcalinizar",
    "alcalinizemo": "alcalinizar",
    "alcalinizemos": "alcalinizar",
    "alcalinizes": "alcalinizar",
    "alcalinizo": "alcalinizar",
    "alcalinizou": "alcalinizar",
    "alcalinizá": "alcalinizar",
    "alcalinizámo": "alcalinizar",
    "alcalinizámos": "alcalinizar",
    "alcalinizáramo": "alcalinizar",
    "alcalinizáramos": "alcalinizar",
    "alcalinizárei": "alcalinizar",
    "alcalinizáreis": "alcalinizar",
    "alcalinizásseis": "alcalinizar",
    "alcalinizássemos": "alcalinizar",
    "alcalinizávamo": "alcalinizar",
    "alcalinizávamos": "alcalinizar",
    "alcalinizávei": "alcalinizar",
    "alcalinizáveis": "alcalinizar",
    "alcalinos": "alcalino",
    "alcalis": "alcali",
    "alcaliza": "alcalizar",
    "alcalizada": "alcalizar",
    "alcalizadas": "alcalizar",
    "alcalizado": "alcalizar",
    "alcalizados": "alcalizar",
    "alcalizai": "alcalizar",
    "alcalizais": "alcalizar",
    "alcalizam": "alcalizar",
    "alcalizamo": "alcalizar",
    "alcalizamos": "alcalizar",
    "alcalizando": "alcalizar",
    "alcalizara": "alcalizar",
    "alcalizaram": "alcalizar",
    "alcalizaras": "alcalizar",
    "alcalizarde": "alcalizar",
    "alcalizardes": "alcalizar",
    "alcalizare": "alcalizar",
    "alcalizarei": "alcalizar",
    "alcalizareis": "alcalizar",
    "alcalizarem": "alcalizar",
    "alcalizaremos": "alcalizar",
    "alcalizares": "alcalizar",
    "alcalizaria": "alcalizar",
    "alcalizariam": "alcalizar",
    "alcalizarias": "alcalizar",
    "alcalizarmo": "alcalizar",
    "alcalizarmos": "alcalizar",
    "alcalizará": "alcalizar",
    "alcalizarás": "alcalizar",
    "alcalizarão": "alcalizar",
    "alcalizaríamos": "alcalizar",
    "alcalizaríeis": "alcalizar",
    "alcalizas": "alcalizar",
    "alcalizasse": "alcalizar",
    "alcalizassem": "alcalizar",
    "alcalizasses": "alcalizar",
    "alcalizaste": "alcalizar",
    "alcalizastes": "alcalizar",
    "alcalizava": "alcalizar",
    "alcalizavam": "alcalizar",
    "alcalizavas": "alcalizar",
    "alcalizações": "alcalização",
    "alcalize": "alcalizar",
    "alcalizei": "alcalizar",
    "alcalizeis": "alcalizar",
    "alcalizem": "alcalizar",
    "alcalizemo": "alcalizar",
    "alcalizemos": "alcalizar",
    "alcalizes": "alcalizar",
    "alcalizo": "alcalizar",
    "alcalizou": "alcalizar",
    "alcalizá": "alcalizar",
    "alcalizámo": "alcalizar",
    "alcalizámos": "alcalizar",
    "alcalizáramo": "alcalizar",
    "alcalizáramos": "alcalizar",
    "alcalizárei": "alcalizar",
    "alcalizáreis": "alcalizar",
    "alcalizásseis": "alcalizar",
    "alcalizássemos": "alcalizar",
    "alcalizávamo": "alcalizar",
    "alcalizávamos": "alcalizar",
    "alcalizávei": "alcalizar",
    "alcalizáveis": "alcalizar",
    "alcaloses": "alcalose",
    "alcalígena": "alcalígeno",
    "alcalígenas": "alcalígeno",
    "alcalígenos": "alcalígeno",
    "alcalímetros": "alcalímetro",
    "alcalóides": "alcalóide",
    "alcamonias": "alcamonia",
    "alcanas": "alcana",
    "alcancareira": "alcancareiro",
    "alcancareiras": "alcancareiro",
    "alcancareiros": "alcancareiro",
    "alcance": "alcançar",
    "alcancei": "alcançar",
    "alcanceis": "alcançar",
    "alcancem": "alcançar",
    "alcancemo": "alcançar",
    "alcancemos": "alcançar",
    "alcances": "alcance",
    "alcancilhos": "alcancilho",
    "alcandora": "alcandorar",
    "alcandorada": "alcandorar",
    "alcandoradas": "alcandorar",
    "alcandorado": "alcandorar",
    "alcandorados": "alcandorar",
    "alcandorai": "alcandorar",
    "alcandorais": "alcandorar",
    "alcandoram": "alcandorar",
    "alcandoramo": "alcandorar",
    "alcandoramos": "alcandorar",
    "alcandorando": "alcandorar",
    "alcandorara": "alcandorar",
    "alcandoraram": "alcandorar",
    "alcandoraras": "alcandorar",
    "alcandorarde": "alcandorar",
    "alcandorardes": "alcandorar",
    "alcandorare": "alcandorar",
    "alcandorarei": "alcandorar",
    "alcandorareis": "alcandorar",
    "alcandorarem": "alcandorar",
    "alcandoraremos": "alcandorar",
    "alcandorares": "alcandorar",
    "alcandoraria": "alcandorar",
    "alcandorariam": "alcandorar",
    "alcandorarias": "alcandorar",
    "alcandorarmo": "alcandorar",
    "alcandorarmos": "alcandorar",
    "alcandorará": "alcandorar",
    "alcandorarás": "alcandorar",
    "alcandorarão": "alcandorar",
    "alcandoraríamos": "alcandorar",
    "alcandoraríeis": "alcandorar",
    "alcandoras": "alcandorar",
    "alcandorasse": "alcandorar",
    "alcandorassem": "alcandorar",
    "alcandorasses": "alcandorar",
    "alcandoraste": "alcandorar",
    "alcandorastes": "alcandorar",
    "alcandorava": "alcandorar",
    "alcandoravam": "alcandorar",
    "alcandoravas": "alcandorar",
    "alcandore": "alcandorar",
    "alcandorei": "alcandorar",
    "alcandoreis": "alcandorar",
    "alcandorem": "alcandorar",
    "alcandoremo": "alcandorar",
    "alcandoremos": "alcandorar",
    "alcandores": "alcandorar",
    "alcandoro": "alcandorar",
    "alcandorou": "alcandorar",
    "alcandorá": "alcandorar",
    "alcandorámo": "alcandorar",
    "alcandorámos": "alcandorar",
    "alcandoráramo": "alcandorar",
    "alcandoráramos": "alcandorar",
    "alcandorárei": "alcandorar",
    "alcandoráreis": "alcandorar",
    "alcandorásseis": "alcandorar",
    "alcandorássemos": "alcandorar",
    "alcandorávamo": "alcandorar",
    "alcandorávamos": "alcandorar",
    "alcandorávei": "alcandorar",
    "alcandoráveis": "alcandorar",
    "alcanfora": "alcanforar",
    "alcanforada": "alcanforar",
    "alcanforadas": "alcanforar",
    "alcanforado": "alcanforar",
    "alcanforados": "alcanforar",
    "alcanforai": "alcanforar",
    "alcanforais": "alcanforar",
    "alcanforam": "alcanforar",
    "alcanforamo": "alcanforar",
    "alcanforamos": "alcanforar",
    "alcanforando": "alcanforar",
    "alcanforara": "alcanforar",
    "alcanforaram": "alcanforar",
    "alcanforaras": "alcanforar",
    "alcanforarde": "alcanforar",
    "alcanforardes": "alcanforar",
    "alcanforare": "alcanforar",
    "alcanforarei": "alcanforar",
    "alcanforareis": "alcanforar",
    "alcanforarem": "alcanforar",
    "alcanforaremos": "alcanforar",
    "alcanforares": "alcanforar",
    "alcanforaria": "alcanforar",
    "alcanforariam": "alcanforar",
    "alcanforarias": "alcanforar",
    "alcanforarmo": "alcanforar",
    "alcanforarmos": "alcanforar",
    "alcanforará": "alcanforar",
    "alcanforarás": "alcanforar",
    "alcanforarão": "alcanforar",
    "alcanforaríamos": "alcanforar",
    "alcanforaríeis": "alcanforar",
    "alcanforas": "alcanforar",
    "alcanforasse": "alcanforar",
    "alcanforassem": "alcanforar",
    "alcanforasses": "alcanforar",
    "alcanforaste": "alcanforar",
    "alcanforastes": "alcanforar",
    "alcanforava": "alcanforar",
    "alcanforavam": "alcanforar",
    "alcanforavas": "alcanforar",
    "alcanfore": "alcanforar",
    "alcanforei": "alcanforar",
    "alcanforeiras": "alcanforeira",
    "alcanforeiros": "alcanforeiro",
    "alcanforeis": "alcanforar",
    "alcanforem": "alcanforar",
    "alcanforemo": "alcanforar",
    "alcanforemos": "alcanforar",
    "alcanfores": "alcanforar",
    "alcanforo": "alcanforar",
    "alcanforou": "alcanforar",
    "alcanforá": "alcanforar",
    "alcanforámo": "alcanforar",
    "alcanforámos": "alcanforar",
    "alcanforáramo": "alcanforar",
    "alcanforáramos": "alcanforar",
    "alcanforárei": "alcanforar",
    "alcanforáreis": "alcanforar",
    "alcanforásseis": "alcanforar",
    "alcanforássemos": "alcanforar",
    "alcanforávamo": "alcanforar",
    "alcanforávamos": "alcanforar",
    "alcanforávei": "alcanforar",
    "alcanforáveis": "alcanforar",
    "alcanos": "alcano",
    "alcantarenses": "alcantarense",
    "alcantarilhas": "alcantarilha",
    "alcantila": "alcantilar",
    "alcantilada": "alcantilar",
    "alcantiladas": "alcantilar",
    "alcantilado": "alcantilar",
    "alcantilados": "alcantilar",
    "alcantilai": "alcantilar",
    "alcantilais": "alcantilar",
    "alcantilam": "alcantilar",
    "alcantilamo": "alcantilar",
    "alcantilamos": "alcantilar",
    "alcantilando": "alcantilar",
    "alcantilara": "alcantilar",
    "alcantilaram": "alcantilar",
    "alcantilaras": "alcantilar",
    "alcantilarde": "alcantilar",
    "alcantilardes": "alcantilar",
    "alcantilare": "alcantilar",
    "alcantilarei": "alcantilar",
    "alcantilareis": "alcantilar",
    "alcantilarem": "alcantilar",
    "alcantilaremos": "alcantilar",
    "alcantilares": "alcantilar",
    "alcantilaria": "alcantilar",
    "alcantilariam": "alcantilar",
    "alcantilarias": "alcantilar",
    "alcantilarmo": "alcantilar",
    "alcantilarmos": "alcantilar",
    "alcantilará": "alcantilar",
    "alcantilarás": "alcantilar",
    "alcantilarão": "alcantilar",
    "alcantilaríamos": "alcantilar",
    "alcantilaríeis": "alcantilar",
    "alcantilas": "alcantilar",
    "alcantilasse": "alcantilar",
    "alcantilassem": "alcantilar",
    "alcantilasses": "alcantilar",
    "alcantilaste": "alcantilar",
    "alcantilastes": "alcantilar",
    "alcantilava": "alcantilar",
    "alcantilavam": "alcantilar",
    "alcantilavas": "alcantilar",
    "alcantile": "alcantilar",
    "alcantilei": "alcantilar",
    "alcantileis": "alcantilar",
    "alcantilem": "alcantilar",
    "alcantilemo": "alcantilar",
    "alcantilemos": "alcantilar",
    "alcantiles": "alcantilar",
    "alcantilo": "alcantilar",
    "alcantilosa": "alcantiloso",
    "alcantilosas": "alcantiloso",
    "alcantilosos": "alcantiloso",
    "alcantilou": "alcantilar",
    "alcantilá": "alcantilar",
    "alcantilámo": "alcantilar",
    "alcantilámos": "alcantilar",
    "alcantiláramo": "alcantilar",
    "alcantiláramos": "alcantilar",
    "alcantilárei": "alcantilar",
    "alcantiláreis": "alcantilar",
    "alcantilásseis": "alcantilar",
    "alcantilássemos": "alcantilar",
    "alcantilávamo": "alcantilar",
    "alcantilávamos": "alcantilar",
    "alcantilávei": "alcantilar",
    "alcantiláveis": "alcantilar",
    "alcantis": "alcantil",
    "alcanziadas": "alcanziada",
    "alcanzias": "alcanzia",
    "alcança": "alcançar",
    "alcançada": "alcançar",
    "alcançadas": "alcançar",
    "alcançadelas": "alcançadela",
    "alcançadiça": "alcançadiço",
    "alcançadiças": "alcançadiço",
    "alcançadiços": "alcançadiço",
    "alcançado": "alcançar",
    "alcançados": "alcançar",
    "alcançaduras": "alcançadura",
    "alcançai": "alcançar",
    "alcançais": "alcançar",
    "alcançam": "alcançar",
    "alcançamentos": "alcançamento",
    "alcançamo": "alcançar",
    "alcançamos": "alcançar",
    "alcançando": "alcançar",
    "alcançara": "alcançar",
    "alcançaram": "alcançar",
    "alcançaras": "alcançar",
    "alcançarde": "alcançar",
    "alcançardes": "alcançar",
    "alcançare": "alcançar",
    "alcançarei": "alcançar",
    "alcançareis": "alcançar",
    "alcançarem": "alcançar",
    "alcançaremos": "alcançar",
    "alcançares": "alcançar",
    "alcançaria": "alcançar",
    "alcançariam": "alcançar",
    "alcançarias": "alcançar",
    "alcançarmo": "alcançar",
    "alcançarmos": "alcançar",
    "alcançará": "alcançar",
    "alcançarás": "alcançar",
    "alcançarão": "alcançar",
    "alcançaríamos": "alcançar",
    "alcançaríeis": "alcançar",
    "alcanças": "alcançar",
    "alcançasse": "alcançar",
    "alcançassem": "alcançar",
    "alcançasses": "alcançar",
    "alcançaste": "alcançar",
    "alcançastes": "alcançar",
    "alcançava": "alcançar",
    "alcançavam": "alcançar",
    "alcançavas": "alcançar",
    "alcanço": "alcançar",
    "alcanços": "alcanço",
    "alcançou": "alcançar",
    "alcançá": "alcançar",
    "alcançámo": "alcançar",
    "alcançámos": "alcançar",
    "alcançáramo": "alcançar",
    "alcançáramos": "alcançar",
    "alcançárei": "alcançar",
    "alcançáreis": "alcançar",
    "alcançásseis": "alcançar",
    "alcançássemos": "alcançar",
    "alcançávamo": "alcançar",
    "alcançávamos": "alcançar",
    "alcançávei": "alcançar",
    "alcançáveis": "alcançável",
    "alcaparra": "alcaparrar",
    "alcaparrada": "alcaparrar",
    "alcaparradas": "alcaparrar",
    "alcaparrado": "alcaparrar",
    "alcaparrados": "alcaparrar",
    "alcaparrai": "alcaparrar",
    "alcaparrais": "alcaparrar",
    "alcaparram": "alcaparrar",
    "alcaparramo": "alcaparrar",
    "alcaparramos": "alcaparrar",
    "alcaparrando": "alcaparrar",
    "alcaparrara": "alcaparrar",
    "alcaparraram": "alcaparrar",
    "alcaparraras": "alcaparrar",
    "alcaparrarde": "alcaparrar",
    "alcaparrardes": "alcaparrar",
    "alcaparrare": "alcaparrar",
    "alcaparrarei": "alcaparrar",
    "alcaparrareis": "alcaparrar",
    "alcaparrarem": "alcaparrar",
    "alcaparraremos": "alcaparrar",
    "alcaparrares": "alcaparrar",
    "alcaparraria": "alcaparrar",
    "alcaparrariam": "alcaparrar",
    "alcaparrarias": "alcaparrar",
    "alcaparrarmo": "alcaparrar",
    "alcaparrarmos": "alcaparrar",
    "alcaparrará": "alcaparrar",
    "alcaparrarás": "alcaparrar",
    "alcaparrarão": "alcaparrar",
    "alcaparraríamos": "alcaparrar",
    "alcaparraríeis": "alcaparrar",
    "alcaparras": "alcaparrar",
    "alcaparrasse": "alcaparrar",
    "alcaparrassem": "alcaparrar",
    "alcaparrasses": "alcaparrar",
    "alcaparraste": "alcaparrar",
    "alcaparrastes": "alcaparrar",
    "alcaparrava": "alcaparrar",
    "alcaparravam": "alcaparrar",
    "alcaparravas": "alcaparrar",
    "alcaparre": "alcaparrar",
    "alcaparrei": "alcaparrar",
    "alcaparreiras": "alcaparreira",
    "alcaparreiros": "alcaparreiro",
    "alcaparreis": "alcaparrar",
    "alcaparrem": "alcaparrar",
    "alcaparremo": "alcaparrar",
    "alcaparremos": "alcaparrar",
    "alcaparres": "alcaparrar",
    "alcaparro": "alcaparrar",
    "alcaparrou": "alcaparrar",
    "alcaparrá": "alcaparrar",
    "alcaparrámo": "alcaparrar",
    "alcaparrámos": "alcaparrar",
    "alcaparráramo": "alcaparrar",
    "alcaparráramos": "alcaparrar",
    "alcaparrárei": "alcaparrar",
    "alcaparráreis": "alcaparrar",
    "alcaparrásseis": "alcaparrar",
    "alcaparrássemos": "alcaparrar",
    "alcaparrávamo": "alcaparrar",
    "alcaparrávamos": "alcaparrar",
    "alcaparrávei": "alcaparrar",
    "alcaparráveis": "alcaparrar",
    "alcaravias": "alcaravia",
    "alcaravizes": "alcaraviz",
    "alcaravões": "alcaravão",
    "alcares": "alcar",
    "alcariais": "alcarial",
    "alcarias": "alcaria",
    "alcarnaches": "alcarnache",
    "alcarradas": "alcarrada",
    "alcarrazas": "alcarraza",
    "alcarrazes": "alcarraz",
    "alcarroteiras": "alcarroteira",
    "alcarzinas": "alcarzina",
    "alcas": "alca",
    "alcateada": "alcatear",
    "alcateadas": "alcatear",
    "alcateado": "alcatear",
    "alcateados": "alcatear",
    "alcateai": "alcatear",
    "alcateais": "alcatear",
    "alcateamo": "alcatear",
    "alcateamos": "alcatear",
    "alcateando": "alcatear",
    "alcateara": "alcatear",
    "alcatearam": "alcatear",
    "alcatearas": "alcatear",
    "alcatearde": "alcatear",
    "alcateardes": "alcatear",
    "alcateare": "alcatear",
    "alcatearei": "alcatear",
    "alcateareis": "alcatear",
    "alcatearem": "alcatear",
    "alcatearemos": "alcatear",
    "alcateares": "alcatear",
    "alcatearia": "alcatear",
    "alcateariam": "alcatear",
    "alcatearias": "alcatear",
    "alcatearmo": "alcatear",
    "alcatearmos": "alcatear",
    "alcateará": "alcatear",
    "alcatearás": "alcatear",
    "alcatearão": "alcatear",
    "alcatearíamos": "alcatear",
    "alcatearíeis": "alcatear",
    "alcateasse": "alcatear",
    "alcateassem": "alcatear",
    "alcateasses": "alcatear",
    "alcateaste": "alcatear",
    "alcateastes": "alcatear",
    "alcateava": "alcatear",
    "alcateavam": "alcatear",
    "alcateavas": "alcatear",
    "alcateei": "alcatear",
    "alcateeis": "alcatear",
    "alcateemo": "alcatear",
    "alcateemos": "alcatear",
    "alcateia": "alcatear",
    "alcateiam": "alcatear",
    "alcateias": "alcateia",
    "alcateie": "alcatear",
    "alcateiem": "alcatear",
    "alcateies": "alcatear",
    "alcateio": "alcatear",
    "alcateou": "alcatear",
    "alcateá": "alcatear",
    "alcateámo": "alcatear",
    "alcateámos": "alcatear",
    "alcateáramo": "alcatear",
    "alcateáramos": "alcatear",
    "alcateárei": "alcatear",
    "alcateáreis": "alcatear",
    "alcateásseis": "alcatear",
    "alcateássemos": "alcatear",
    "alcateávamo": "alcatear",
    "alcateávamos": "alcatear",
    "alcateávei": "alcatear",
    "alcateáveis": "alcatear",
    "alcatifa": "alcatifar",
    "alcatifada": "alcatifar",
    "alcatifadas": "alcatifar",
    "alcatifado": "alcatifar",
    "alcatifados": "alcatifar",
    "alcatifai": "alcatifar",
    "alcatifais": "alcatifar",
    "alcatifam": "alcatifar",
    "alcatifamo": "alcatifar",
    "alcatifamos": "alcatifar",
    "alcatifando": "alcatifar",
    "alcatifara": "alcatifar",
    "alcatifaram": "alcatifar",
    "alcatifaras": "alcatifar",
    "alcatifarde": "alcatifar",
    "alcatifardes": "alcatifar",
    "alcatifare": "alcatifar",
    "alcatifarei": "alcatifar",
    "alcatifareis": "alcatifar",
    "alcatifarem": "alcatifar",
    "alcatifaremos": "alcatifar",
    "alcatifares": "alcatifar",
    "alcatifaria": "alcatifar",
    "alcatifariam": "alcatifar",
    "alcatifarias": "alcatifar",
    "alcatifarmo": "alcatifar",
    "alcatifarmos": "alcatifar",
    "alcatifará": "alcatifar",
    "alcatifarás": "alcatifar",
    "alcatifarão": "alcatifar",
    "alcatifaríamos": "alcatifar",
    "alcatifaríeis": "alcatifar",
    "alcatifas": "alcatifar",
    "alcatifasse": "alcatifar",
    "alcatifassem": "alcatifar",
    "alcatifasses": "alcatifar",
    "alcatifaste": "alcatifar",
    "alcatifastes": "alcatifar",
    "alcatifava": "alcatifar",
    "alcatifavam": "alcatifar",
    "alcatifavas": "alcatifar",
    "alcatife": "alcatifar",
    "alcatifei": "alcatifar",
    "alcatifeira": "alcatifeiro",
    "alcatifeiras": "alcatifeiro",
    "alcatifeiros": "alcatifeiro",
    "alcatifeis": "alcatifar",
    "alcatifem": "alcatifar",
    "alcatifemo": "alcatifar",
    "alcatifemos": "alcatifar",
    "alcatifes": "alcatifar",
    "alcatifo": "alcatifar",
    "alcatifou": "alcatifar",
    "alcatifá": "alcatifar",
    "alcatifámo": "alcatifar",
    "alcatifámos": "alcatifar",
    "alcatifáramo": "alcatifar",
    "alcatifáramos": "alcatifar",
    "alcatifárei": "alcatifar",
    "alcatifáreis": "alcatifar",
    "alcatifásseis": "alcatifar",
    "alcatifássemos": "alcatifar",
    "alcatifávamo": "alcatifar",
    "alcatifávamos": "alcatifar",
    "alcatifávei": "alcatifar",
    "alcatifáveis": "alcatifar",
    "alcatiras": "alcatira",
    "alcatras": "alcatra",
    "alcatrates": "alcatrate",
    "alcatrazes": "alcatraz",
    "alcatreira": "alcatreiro",
    "alcatreiras": "alcatreiro",
    "alcatreiros": "alcatreiro",
    "alcatroa": "alcatroar",
    "alcatroada": "alcatroar",
    "alcatroadas": "alcatroar",
    "alcatroado": "alcatroar",
    "alcatroados": "alcatroar",
    "alcatroagens": "alcatroagem",
    "alcatroai": "alcatroar",
    "alcatroais": "alcatroar",
    "alcatroam": "alcatroar",
    "alcatroamentos": "alcatroamento",
    "alcatroamo": "alcatroar",
    "alcatroamos": "alcatroar",
    "alcatroando": "alcatroar",
    "alcatroara": "alcatroar",
    "alcatroaram": "alcatroar",
    "alcatroaras": "alcatroar",
    "alcatroarde": "alcatroar",
    "alcatroardes": "alcatroar",
    "alcatroare": "alcatroar",
    "alcatroarei": "alcatroar",
    "alcatroareis": "alcatroar",
    "alcatroarem": "alcatroar",
    "alcatroaremos": "alcatroar",
    "alcatroares": "alcatroar",
    "alcatroaria": "alcatroar",
    "alcatroariam": "alcatroar",
    "alcatroarias": "alcatroar",
    "alcatroarmo": "alcatroar",
    "alcatroarmos": "alcatroar",
    "alcatroará": "alcatroar",
    "alcatroarás": "alcatroar",
    "alcatroarão": "alcatroar",
    "alcatroaríamos": "alcatroar",
    "alcatroaríeis": "alcatroar",
    "alcatroas": "alcatroar",
    "alcatroasse": "alcatroar",
    "alcatroassem": "alcatroar",
    "alcatroasses": "alcatroar",
    "alcatroaste": "alcatroar",
    "alcatroastes": "alcatroar",
    "alcatroava": "alcatroar",
    "alcatroavam": "alcatroar",
    "alcatroavas": "alcatroar",
    "alcatroe": "alcatroar",
    "alcatroei": "alcatroar",
    "alcatroeira": "alcatroeiro",
    "alcatroeiras": "alcatroeiro",
    "alcatroeiros": "alcatroeiro",
    "alcatroeis": "alcatroar",
    "alcatroem": "alcatroar",
    "alcatroemo": "alcatroar",
    "alcatroemos": "alcatroar",
    "alcatroes": "alcatroar",
    "alcatroo": "alcatroar",
    "alcatroou": "alcatroar",
    "alcatroá": "alcatroar",
    "alcatroámo": "alcatroar",
    "alcatroámos": "alcatroar",
    "alcatroáramo": "alcatroar",
    "alcatroáramos": "alcatroar",
    "alcatroárei": "alcatroar",
    "alcatroáreis": "alcatroar",
    "alcatroásseis": "alcatroar",
    "alcatroássemos": "alcatroar",
    "alcatroávamo": "alcatroar",
    "alcatroávamos": "alcatroar",
    "alcatroávei": "alcatroar",
    "alcatroáveis": "alcatroar",
    "alcatruza": "alcatruzar",
    "alcatruzada": "alcatruzar",
    "alcatruzadas": "alcatruzar",
    "alcatruzado": "alcatruzar",
    "alcatruzados": "alcatruzar",
    "alcatruzai": "alcatruzar",
    "alcatruzais": "alcatruzar",
    "alcatruzam": "alcatruzar",
    "alcatruzamo": "alcatruzar",
    "alcatruzamos": "alcatruzar",
    "alcatruzando": "alcatruzar",
    "alcatruzara": "alcatruzar",
    "alcatruzaram": "alcatruzar",
    "alcatruzaras": "alcatruzar",
    "alcatruzarde": "alcatruzar",
    "alcatruzardes": "alcatruzar",
    "alcatruzare": "alcatruzar",
    "alcatruzarei": "alcatruzar",
    "alcatruzareis": "alcatruzar",
    "alcatruzarem": "alcatruzar",
    "alcatruzaremos": "alcatruzar",
    "alcatruzares": "alcatruzar",
    "alcatruzaria": "alcatruzar",
    "alcatruzariam": "alcatruzar",
    "alcatruzarias": "alcatruzar",
    "alcatruzarmo": "alcatruzar",
    "alcatruzarmos": "alcatruzar",
    "alcatruzará": "alcatruzar",
    "alcatruzarás": "alcatruzar",
    "alcatruzarão": "alcatruzar",
    "alcatruzaríamos": "alcatruzar",
    "alcatruzaríeis": "alcatruzar",
    "alcatruzas": "alcatruzar",
    "alcatruzasse": "alcatruzar",
    "alcatruzassem": "alcatruzar",
    "alcatruzasses": "alcatruzar",
    "alcatruzaste": "alcatruzar",
    "alcatruzastes": "alcatruzar",
    "alcatruzava": "alcatruzar",
    "alcatruzavam": "alcatruzar",
    "alcatruzavas": "alcatruzar",
    "alcatruze": "alcatruzar",
    "alcatruzei": "alcatruzar",
    "alcatruzeis": "alcatruzar",
    "alcatruzem": "alcatruzar",
    "alcatruzemo": "alcatruzar",
    "alcatruzemos": "alcatruzar",
    "alcatruzes": "alcatruzar",
    "alcatruzo": "alcatruzar",
    "alcatruzou": "alcatruzar",
    "alcatruzá": "alcatruzar",
    "alcatruzámo": "alcatruzar",
    "alcatruzámos": "alcatruzar",
    "alcatruzáramo": "alcatruzar",
    "alcatruzáramos": "alcatruzar",
    "alcatruzárei": "alcatruzar",
    "alcatruzáreis": "alcatruzar",
    "alcatruzásseis": "alcatruzar",
    "alcatruzássemos": "alcatruzar",
    "alcatruzávamo": "alcatruzar",
    "alcatruzávamos": "alcatruzar",
    "alcatruzávei": "alcatruzar",
    "alcatruzáveis": "alcatruzar",
    "alcatrões": "alcatrão",
    "alcavalas": "alcavala",
    "alcavaleiros": "alcavaleiro",
    "alcaçares": "alcaçar",
    "alcaçarias": "alcaçaria",
    "alcaçuzes": "alcaçuz",
    "alcaçária": "alcaçário",
    "alcaçárias": "alcaçário",
    "alcaçários": "alcaçário",
    "alce": "alçar",
    "alceada": "alcear",
    "alceadas": "alcear",
    "alceado": "alcear",
    "alceados": "alcear",
    "alceai": "alcear",
    "alceais": "alcear",
    "alceamentos": "alceamento",
    "alceamo": "alcear",
    "alceamos": "alcear",
    "alceando": "alcear",
    "alceara": "alcear",
    "alcearam": "alcear",
    "alcearas": "alcear",
    "alcearde": "alcear",
    "alceardes": "alcear",
    "alceare": "alcear",
    "alcearei": "alcear",
    "alceareis": "alcear",
    "alcearem": "alcear",
    "alcearemos": "alcear",
    "alceares": "alcear",
    "alcearia": "alcear",
    "alceariam": "alcear",
    "alcearias": "alcear",
    "alcearmo": "alcear",
    "alcearmos": "alcear",
    "alceará": "alcear",
    "alcearás": "alcear",
    "alcearão": "alcear",
    "alcearíamos": "alcear",
    "alcearíeis": "alcear",
    "alceasse": "alcear",
    "alceassem": "alcear",
    "alceasses": "alcear",
    "alceaste": "alcear",
    "alceastes": "alcear",
    "alceava": "alcear",
    "alceavam": "alcear",
    "alceavas": "alcear",
    "alcedinídea": "alcedinídeo",
    "alcedinídeas": "alcedinídeo",
    "alcedinídeos": "alcedinídeo",
    "alcedínidas": "alcedínida",
    "alceei": "alcear",
    "alceeis": "alcear",
    "alceemo": "alcear",
    "alceemos": "alcear",
    "alcei": "alçar",
    "alceia": "alcear",
    "alceiam": "alcear",
    "alceias": "alcear",
    "alceie": "alcear",
    "alceiem": "alcear",
    "alceies": "alcear",
    "alceio": "alcear",
    "alceis": "alçar",
    "alcem": "alçar",
    "alcemo": "alçar",
    "alcemos": "alçar",
    "alcenos": "alceno",
    "alcenídidas": "alcenídida",
    "alceou": "alcear",
    "alces": "alce",
    "alceá": "alcear",
    "alceámo": "alcear",
    "alceámos": "alcear",
    "alceáramo": "alcear",
    "alceáramos": "alcear",
    "alceárei": "alcear",
    "alceáreis": "alcear",
    "alceásseis": "alcear",
    "alceássemos": "alcear",
    "alceávamo": "alcear",
    "alceávamos": "alcear",
    "alceávei": "alcear",
    "alceáveis": "alcear",
    "alcicornes": "alcicorne",
    "alcinha": "alça",
    "alcinhas": "alça",
    "alcinos": "alcino",
    "alcita": "alça",
    "alcitas": "alça",
    "alciónea": "alcióneo",
    "alcióneas": "alcióneo",
    "alcióneos": "alcióneo",
    "alciões": "alcião",
    "alcmânica": "alcmânico",
    "alcmânicas": "alcmânico",
    "alcmânicos": "alcmânico",
    "alcobacenses": "alcobacense",
    "alcobaças": "alcobaça",
    "alcofa": "alcofar",
    "alcofada": "alcofar",
    "alcofadas": "alcofar",
    "alcofado": "alcofar",
    "alcofados": "alcofar",
    "alcofai": "alcofar",
    "alcofais": "alcofar",
    "alcofam": "alcofar",
    "alcofamo": "alcofar",
    "alcofamos": "alcofar",
    "alcofando": "alcofar",
    "alcofara": "alcofar",
    "alcofaram": "alcofar",
    "alcofaras": "alcofar",
    "alcofarde": "alcofar",
    "alcofardes": "alcofar",
    "alcofare": "alcofar",
    "alcofarei": "alcofar",
    "alcofareis": "alcofar",
    "alcofarem": "alcofar",
    "alcofaremos": "alcofar",
    "alcofares": "alcofar",
    "alcofaria": "alcofar",
    "alcofariam": "alcofar",
    "alcofarias": "alcofar",
    "alcofarmo": "alcofar",
    "alcofarmos": "alcofar",
    "alcofará": "alcofar",
    "alcofarás": "alcofar",
    "alcofarão": "alcofar",
    "alcofaríamos": "alcofar",
    "alcofaríeis": "alcofar",
    "alcofas": "alcofar",
    "alcofasse": "alcofar",
    "alcofassem": "alcofar",
    "alcofasses": "alcofar",
    "alcofaste": "alcofar",
    "alcofastes": "alcofar",
    "alcofava": "alcofar",
    "alcofavam": "alcofar",
    "alcofavas": "alcofar",
    "alcofe": "alcofar",
    "alcofei": "alcofar",
    "alcofeiras": "alcofeira",
    "alcofeis": "alcofar",
    "alcofem": "alcofar",
    "alcofemo": "alcofar",
    "alcofemos": "alcofar",
    "alcofes": "alcofar",
    "alcofinhas": "alcofinha",
    "alcofo": "alcofar",
    "alcofou": "alcofar",
    "alcofá": "alcofar",
    "alcofámo": "alcofar",
    "alcofámos": "alcofar",
    "alcofáramo": "alcofar",
    "alcofáramos": "alcofar",
    "alcofárei": "alcofar",
    "alcofáreis": "alcofar",
    "alcofásseis": "alcofar",
    "alcofássemos": "alcofar",
    "alcofávamo": "alcofar",
    "alcofávamos": "alcofar",
    "alcofávei": "alcofar",
    "alcofáveis": "alcofar",
    "alcoiceira": "alcoiceiro",
    "alcoiceiras": "alcoiceiro",
    "alcoiceiros": "alcoiceiro",
    "alcoices": "alcoice",
    "alcoolatos": "alcoolato",
    "alcoolaturas": "alcoolatura",
    "alcoolifica": "alcoolificar",
    "alcoolificada": "alcoolificar",
    "alcoolificadas": "alcoolificar",
    "alcoolificado": "alcoolificar",
    "alcoolificados": "alcoolificar",
    "alcoolificai": "alcoolificar",
    "alcoolificais": "alcoolificar",
    "alcoolificam": "alcoolificar",
    "alcoolificamo": "alcoolificar",
    "alcoolificamos": "alcoolificar",
    "alcoolificando": "alcoolificar",
    "alcoolificara": "alcoolificar",
    "alcoolificaram": "alcoolificar",
    "alcoolificaras": "alcoolificar",
    "alcoolificarde": "alcoolificar",
    "alcoolificardes": "alcoolificar",
    "alcoolificare": "alcoolificar",
    "alcoolificarei": "alcoolificar",
    "alcoolificareis": "alcoolificar",
    "alcoolificarem": "alcoolificar",
    "alcoolificaremos": "alcoolificar",
    "alcoolificares": "alcoolificar",
    "alcoolificaria": "alcoolificar",
    "alcoolificariam": "alcoolificar",
    "alcoolificarias": "alcoolificar",
    "alcoolificarmo": "alcoolificar",
    "alcoolificarmos": "alcoolificar",
    "alcoolificará": "alcoolificar",
    "alcoolificarás": "alcoolificar",
    "alcoolificarão": "alcoolificar",
    "alcoolificaríamos": "alcoolificar",
    "alcoolificaríeis": "alcoolificar",
    "alcoolificas": "alcoolificar",
    "alcoolificasse": "alcoolificar",
    "alcoolificassem": "alcoolificar",
    "alcoolificasses": "alcoolificar",
    "alcoolificaste": "alcoolificar",
    "alcoolificastes": "alcoolificar",
    "alcoolificava": "alcoolificar",
    "alcoolificavam": "alcoolificar",
    "alcoolificavas": "alcoolificar",
    "alcoolificações": "alcoolificação",
    "alcoolifico": "alcoolificar",
    "alcoolificou": "alcoolificar",
    "alcoolificá": "alcoolificar",
    "alcoolificámo": "alcoolificar",
    "alcoolificámos": "alcoolificar",
    "alcoolificáramo": "alcoolificar",
    "alcoolificáramos": "alcoolificar",
    "alcoolificárei": "alcoolificar",
    "alcoolificáreis": "alcoolificar",
    "alcoolificásseis": "alcoolificar",
    "alcoolificássemos": "alcoolificar",
    "alcoolificávamo": "alcoolificar",
    "alcoolificávamos": "alcoolificar",
    "alcoolificávei": "alcoolificar",
    "alcoolificáveis": "alcoolificar",
    "alcoolifique": "alcoolificar",
    "alcoolifiquei": "alcoolificar",
    "alcoolifiqueis": "alcoolificar",
    "alcoolifiquem": "alcoolificar",
    "alcoolifiquemo": "alcoolificar",
    "alcoolifiquemos": "alcoolificar",
    "alcoolifiques": "alcoolificar",
    "alcoolismos": "alcoolismo",
    "alcooliza": "alcoolizar",
    "alcoolizada": "alcoolizar",
    "alcoolizadas": "alcoolizar",
    "alcoolizado": "alcoolizar",
    "alcoolizados": "alcoolizar",
    "alcoolizai": "alcoolizar",
    "alcoolizais": "alcoolizar",
    "alcoolizam": "alcoolizar",
    "alcoolizamo": "alcoolizar",
    "alcoolizamos": "alcoolizar",
    "alcoolizando": "alcoolizar",
    "alcoolizara": "alcoolizar",
    "alcoolizaram": "alcoolizar",
    "alcoolizaras": "alcoolizar",
    "alcoolizarde": "alcoolizar",
    "alcoolizardes": "alcoolizar",
    "alcoolizare": "alcoolizar",
    "alcoolizarei": "alcoolizar",
    "alcoolizareis": "alcoolizar",
    "alcoolizarem": "alcoolizar",
    "alcoolizaremos": "alcoolizar",
    "alcoolizares": "alcoolizar",
    "alcoolizaria": "alcoolizar",
    "alcoolizariam": "alcoolizar",
    "alcoolizarias": "alcoolizar",
    "alcoolizarmo": "alcoolizar",
    "alcoolizarmos": "alcoolizar",
    "alcoolizará": "alcoolizar",
    "alcoolizarás": "alcoolizar",
    "alcoolizarão": "alcoolizar",
    "alcoolizaríamos": "alcoolizar",
    "alcoolizaríeis": "alcoolizar",
    "alcoolizas": "alcoolizar",
    "alcoolizasse": "alcoolizar",
    "alcoolizassem": "alcoolizar",
    "alcoolizasses": "alcoolizar",
    "alcoolizaste": "alcoolizar",
    "alcoolizastes": "alcoolizar",
    "alcoolizava": "alcoolizar",
    "alcoolizavam": "alcoolizar",
    "alcoolizavas": "alcoolizar",
    "alcoolizações": "alcoolização",
    "alcoolize": "alcoolizar",
    "alcoolizei": "alcoolizar",
    "alcoolizeis": "alcoolizar",
    "alcoolizem": "alcoolizar",
    "alcoolizemo": "alcoolizar",
    "alcoolizemos": "alcoolizar",
    "alcoolizes": "alcoolizar",
    "alcoolizo": "alcoolizar",
    "alcoolizou": "alcoolizar",
    "alcoolizá": "alcoolizar",
    "alcoolizámo": "alcoolizar",
    "alcoolizámos": "alcoolizar",
    "alcoolizáramo": "alcoolizar",
    "alcoolizáramos": "alcoolizar",
    "alcoolizárei": "alcoolizar",
    "alcoolizáreis": "alcoolizar",
    "alcoolizásseis": "alcoolizar",
    "alcoolizássemos": "alcoolizar",
    "alcoolizávamo": "alcoolizar",
    "alcoolizávamos": "alcoolizar",
    "alcoolizávei": "alcoolizar",
    "alcoolizáveis": "alcoolizar",
    "alcoologias": "alcoologia",
    "alcoolémias": "alcoolémia",
    "alcoolómetros": "alcoolómetro",
    "alcooméis": "alcoomel",
    "alcoranistas": "alcoranista",
    "alcorcas": "alcorca",
    "alcorcos": "alcorco",
    "alcorrazes": "alcorraz",
    "alcorânica": "alcorânico",
    "alcorânicas": "alcorânico",
    "alcorânicos": "alcorânico",
    "alcorças": "alcorça",
    "alcoteneja": "alcotenejo",
    "alcotenejas": "alcotenejo",
    "alcotenejos": "alcotenejo",
    "alcouceira": "alcouceiro",
    "alcouceiras": "alcouceiro",
    "alcouceiros": "alcouceiro",
    "alcouces": "alcouce",
    "alcovas": "alcova",
    "alcoveta": "alcoveto",
    "alcovetas": "alcoveto",
    "alcovetos": "alcoveto",
    "alcovistas": "alcovista",
    "alcovita": "alcovitar",
    "alcovitada": "alcovitar",
    "alcovitadas": "alcovitar",
    "alcovitado": "alcovitar",
    "alcovitados": "alcovitar",
    "alcovitagens": "alcovitagem",
    "alcovitai": "alcovitar",
    "alcovitais": "alcovitar",
    "alcovitam": "alcovitar",
    "alcovitamo": "alcovitar",
    "alcovitamos": "alcovitar",
    "alcovitando": "alcovitar",
    "alcovitara": "alcovitar",
    "alcovitaram": "alcovitar",
    "alcovitaras": "alcovitar",
    "alcovitarde": "alcovitar",
    "alcovitardes": "alcovitar",
    "alcovitare": "alcovitar",
    "alcovitarei": "alcovitar",
    "alcovitareis": "alcovitar",
    "alcovitarem": "alcovitar",
    "alcovitaremos": "alcovitar",
    "alcovitares": "alcovitar",
    "alcovitaria": "alcovitar",
    "alcovitariam": "alcovitar",
    "alcovitarias": "alcovitaria",
    "alcovitarmo": "alcovitar",
    "alcovitarmos": "alcovitar",
    "alcovitará": "alcovitar",
    "alcovitarás": "alcovitar",
    "alcovitarão": "alcovitar",
    "alcovitaríamos": "alcovitar",
    "alcovitaríeis": "alcovitar",
    "alcovitas": "alcovitar",
    "alcovitasse": "alcovitar",
    "alcovitassem": "alcovitar",
    "alcovitasses": "alcovitar",
    "alcovitaste": "alcovitar",
    "alcovitastes": "alcovitar",
    "alcovitava": "alcovitar",
    "alcovitavam": "alcovitar",
    "alcovitavas": "alcovitar",
    "alcovite": "alcovitar",
    "alcovitei": "alcovitar",
    "alcoviteira": "alcoviteiro",
    "alcoviteiras": "alcoviteiro",
    "alcoviteirices": "alcoviteirice",
    "alcoviteiros": "alcoviteiro",
    "alcoviteis": "alcovitar",
    "alcovitem": "alcovitar",
    "alcovitemo": "alcovitar",
    "alcovitemos": "alcovitar",
    "alcovites": "alcovitar",
    "alcovitices": "alcovitice",
    "alcovito": "alcovitar",
    "alcovitou": "alcovitar",
    "alcovitá": "alcovitar",
    "alcovitámo": "alcovitar",
    "alcovitámos": "alcovitar",
    "alcovitáramo": "alcovitar",
    "alcovitáramos": "alcovitar",
    "alcovitárei": "alcovitar",
    "alcovitáreis": "alcovitar",
    "alcovitásseis": "alcovitar",
    "alcovitássemos": "alcovitar",
    "alcovitávamo": "alcovitar",
    "alcovitávamos": "alcovitar",
    "alcovitávei": "alcovitar",
    "alcovitáveis": "alcovitar",
    "alcoólases": "alcoólase",
    "alcoólatras": "alcoólatra",
    "alcoólica": "alcoólico",
    "alcoólicas": "alcoólico",
    "alcoólicos": "alcoólico",
    "alcoómetros": "alcoómetro",
    "alcriquetes": "alcriquete",
    "alcunha": "alcunhar",
    "alcunhada": "alcunhar",
    "alcunhadas": "alcunhar",
    "alcunhado": "alcunhar",
    "alcunhados": "alcunhar",
    "alcunhai": "alcunhar",
    "alcunhais": "alcunhar",
    "alcunham": "alcunhar",
    "alcunhamo": "alcunhar",
    "alcunhamos": "alcunhar",
    "alcunhando": "alcunhar",
    "alcunhara": "alcunhar",
    "alcunharam": "alcunhar",
    "alcunharas": "alcunhar",
    "alcunharde": "alcunhar",
    "alcunhardes": "alcunhar",
    "alcunhare": "alcunhar",
    "alcunharei": "alcunhar",
    "alcunhareis": "alcunhar",
    "alcunharem": "alcunhar",
    "alcunharemos": "alcunhar",
    "alcunhares": "alcunhar",
    "alcunharia": "alcunhar",
    "alcunhariam": "alcunhar",
    "alcunharias": "alcunhar",
    "alcunharmo": "alcunhar",
    "alcunharmos": "alcunhar",
    "alcunhará": "alcunhar",
    "alcunharás": "alcunhar",
    "alcunharão": "alcunhar",
    "alcunharíamos": "alcunhar",
    "alcunharíeis": "alcunhar",
    "alcunhas": "alcunhar",
    "alcunhasse": "alcunhar",
    "alcunhassem": "alcunhar",
    "alcunhasses": "alcunhar",
    "alcunhaste": "alcunhar",
    "alcunhastes": "alcunhar",
    "alcunhava": "alcunhar",
    "alcunhavam": "alcunhar",
    "alcunhavas": "alcunhar",
    "alcunhe": "alcunhar",
    "alcunhei": "alcunhar",
    "alcunheis": "alcunhar",
    "alcunhem": "alcunhar",
    "alcunhemo": "alcunhar",
    "alcunhemos": "alcunhar",
    "alcunhes": "alcunhar",
    "alcunho": "alcunhar",
    "alcunhos": "alcunho",
    "alcunhou": "alcunhar",
    "alcunhá": "alcunhar",
    "alcunhámo": "alcunhar",
    "alcunhámos": "alcunhar",
    "alcunháramo": "alcunhar",
    "alcunháramos": "alcunhar",
    "alcunhárei": "alcunhar",
    "alcunháreis": "alcunhar",
    "alcunhásseis": "alcunhar",
    "alcunhássemos": "alcunhar",
    "alcunhávamo": "alcunhar",
    "alcunhávamos": "alcunhar",
    "alcunhávei": "alcunhar",
    "alcunháveis": "alcunhar",
    "alcáceres": "alcácer",
    "alcálica": "alcálico",
    "alcálicas": "alcálico",
    "alcálicos": "alcálico",
    "alcáçovas": "alcáçova",
    "alcânava": "alcânavo",
    "alcânavas": "alcânavo",
    "alcânavos": "alcânavo",
    "alcâncaras": "alcâncara",
    "alcândoras": "alcândora",
    "alcânforas": "alcânfora",
    "alcântaras": "alcântara",
    "alcídea": "alcídeo",
    "alcídeas": "alcídeo",
    "alcídeos": "alcídeo",
    "alcíones": "alcíone",
    "aldazinas": "aldazina",
    "aldeada": "aldear",
    "aldeadas": "aldear",
    "aldeado": "aldear",
    "aldeados": "aldear",
    "aldeaga": "aldeagar",
    "aldeagada": "aldeagar",
    "aldeagadas": "aldeagar",
    "aldeagado": "aldeagar",
    "aldeagados": "aldeagar",
    "aldeagai": "aldeagar",
    "aldeagais": "aldeagar",
    "aldeagam": "aldeagar",
    "aldeagamo": "aldeagar",
    "aldeagamos": "aldeagar",
    "aldeagando": "aldeagar",
    "aldeagantes": "aldeagante",
    "aldeagara": "aldeagar",
    "aldeagaram": "aldeagar",
    "aldeagaras": "aldeagar",
    "aldeagardes": "aldeagar",
    "aldeagarei": "aldeagar",
    "aldeagareis": "aldeagar",
    "aldeagarem": "aldeagar",
    "aldeagaremos": "aldeagar",
    "aldeagares": "aldeagar",
    "aldeagaria": "aldeagar",
    "aldeagariam": "aldeagar",
    "aldeagarias": "aldeagar",
    "aldeagarmo": "aldeagar",
    "aldeagarmos": "aldeagar",
    "aldeagará": "aldeagar",
    "aldeagarás": "aldeagar",
    "aldeagarão": "aldeagar",
    "aldeagaríamos": "aldeagar",
    "aldeagaríeis": "aldeagar",
    "aldeagas": "aldeagar",
    "aldeagasse": "aldeagar",
    "aldeagassem": "aldeagar",
    "aldeagasses": "aldeagar",
    "aldeagaste": "aldeagar",
    "aldeagastes": "aldeagar",
    "aldeagava": "aldeagar",
    "aldeagavam": "aldeagar",
    "aldeagavas": "aldeagar",
    "aldeago": "aldeagar",
    "aldeagou": "aldeagar",
    "aldeague": "aldeagar",
    "aldeaguei": "aldeagar",
    "aldeagueis": "aldeagar",
    "aldeaguem": "aldeagar",
    "aldeaguemo": "aldeagar",
    "aldeaguemos": "aldeagar",
    "aldeagues": "aldeagar",
    "aldeagámo": "aldeagar",
    "aldeagámos": "aldeagar",
    "aldeagáramo": "aldeagar",
    "aldeagáramos": "aldeagar",
    "aldeagáreis": "aldeagar",
    "aldeagásseis": "aldeagar",
    "aldeagássemos": "aldeagar",
    "aldeagávamo": "aldeagar",
    "aldeagávamos": "aldeagar",
    "aldeagáveis": "aldeagar",
    "aldeai": "aldear",
    "aldeais": "aldear",
    "aldeamentos": "aldeamento",
    "aldeamo": "aldear",
    "aldeamos": "aldear",
    "aldeando": "aldear",
    "aldeantes": "aldeante",
    "aldeara": "aldear",
    "aldearam": "aldear",
    "aldearas": "aldear",
    "aldearde": "aldear",
    "aldeardes": "aldear",
    "aldeare": "aldear",
    "aldearei": "aldear",
    "aldeareis": "aldear",
    "aldearem": "aldear",
    "aldearemos": "aldear",
    "aldeares": "aldear",
    "aldearia": "aldear",
    "aldeariam": "aldear",
    "aldearias": "aldear",
    "aldearmo": "aldear",
    "aldearmos": "aldear",
    "aldeará": "aldear",
    "aldearás": "aldear",
    "aldearão": "aldear",
    "aldearíamos": "aldear",
    "aldearíeis": "aldear",
    "aldeasse": "aldear",
    "aldeassem": "aldear",
    "aldeasses": "aldear",
    "aldeaste": "aldear",
    "aldeastes": "aldear",
    "aldeava": "aldear",
    "aldeavam": "aldear",
    "aldeavas": "aldear",
    "aldeei": "aldear",
    "aldeeis": "aldear",
    "aldeemo": "aldear",
    "aldeemos": "aldear",
    "aldegalenses": "aldegalense",
    "aldeia": "aldear",
    "aldeiam": "aldear",
    "aldeias": "aldeia",
    "aldeiazinha": "aldeia",
    "aldeiazinhas": "aldeia",
    "aldeiazita": "aldeia",
    "aldeiazitas": "aldeia",
    "aldeie": "aldear",
    "aldeiem": "aldear",
    "aldeies": "aldear",
    "aldeio": "aldear",
    "aldeolas": "aldeola",
    "aldeotas": "aldeota",
    "aldeou": "aldear",
    "aldeá": "aldear",
    "aldeámo": "aldear",
    "aldeámos": "aldear",
    "aldeáramo": "aldear",
    "aldeáramos": "aldear",
    "aldeárei": "aldear",
    "aldeáreis": "aldear",
    "aldeásseis": "aldear",
    "aldeássemos": "aldear",
    "aldeávamo": "aldear",
    "aldeávamos": "aldear",
    "aldeávei": "aldear",
    "aldeáveis": "aldear",
    "aldeã": "aldeão",
    "aldeães": "aldeão",
    "aldeãos": "aldeão",
    "aldeãs": "aldeão",
    "aldeídos": "aldeído",
    "aldeões": "aldeão",
    "aldina": "aldino",
    "aldinas": "aldino",
    "aldinos": "aldino",
    "aldoses": "aldose",
    "aldraba": "aldrabar",
    "aldrabada": "aldrabar",
    "aldrabadas": "aldrabar",
    "aldrabado": "aldrabar",
    "aldrabados": "aldrabar",
    "aldrabai": "aldrabar",
    "aldrabais": "aldrabar",
    "aldrabam": "aldrabar",
    "aldrabamo": "aldrabar",
    "aldrabamos": "aldrabar",
    "aldrabando": "aldrabar",
    "aldrabara": "aldrabar",
    "aldrabaram": "aldrabar",
    "aldrabaras": "aldrabar",
    "aldrabarde": "aldrabar",
    "aldrabardes": "aldrabar",
    "aldrabare": "aldrabar",
    "aldrabarei": "aldrabar",
    "aldrabareis": "aldrabar",
    "aldrabarem": "aldrabar",
    "aldrabaremos": "aldrabar",
    "aldrabares": "aldrabar",
    "aldrabaria": "aldrabar",
    "aldrabariam": "aldrabar",
    "aldrabarias": "aldrabar",
    "aldrabarmo": "aldrabar",
    "aldrabarmos": "aldrabar",
    "aldrabará": "aldrabar",
    "aldrabarás": "aldrabar",
    "aldrabarão": "aldrabar",
    "aldrabaríamos": "aldrabar",
    "aldrabaríeis": "aldrabar",
    "aldrabas": "aldrabar",
    "aldrabasse": "aldrabar",
    "aldrabassem": "aldrabar",
    "aldrabasses": "aldrabar",
    "aldrabaste": "aldrabar",
    "aldrabastes": "aldrabar",
    "aldrabava": "aldrabar",
    "aldrabavam": "aldrabar",
    "aldrabavas": "aldrabar",
    "aldrabações": "aldrabação",
    "aldrabe": "aldrabar",
    "aldrabei": "aldrabar",
    "aldrabeira": "aldrabeiro",
    "aldrabeiras": "aldrabeiro",
    "aldrabeiros": "aldrabeiro",
    "aldrabeis": "aldrabar",
    "aldrabem": "aldrabar",
    "aldrabemo": "aldrabar",
    "aldrabemos": "aldrabar",
    "aldrabes": "aldrabar",
    "aldrabices": "aldrabice",
    "aldrabo": "aldrabar",
    "aldrabona": "aldrabão",
    "aldrabonas": "aldrabão",
    "aldrabos": "aldrabo",
    "aldrabou": "aldrabar",
    "aldrabá": "aldrabar",
    "aldrabámo": "aldrabar",
    "aldrabámos": "aldrabar",
    "aldrabáramo": "aldrabar",
    "aldrabáramos": "aldrabar",
    "aldrabárei": "aldrabar",
    "aldrabáreis": "aldrabar",
    "aldrabásseis": "aldrabar",
    "aldrabássemos": "aldrabar",
    "aldrabávamo": "aldrabar",
    "aldrabávamos": "aldrabar",
    "aldrabávei": "aldrabar",
    "aldrabáveis": "aldrabável",
    "aldrabões": "aldrabão",
    "aldrava": "aldravar",
    "aldravabas": "aldravaba",
    "aldravada": "aldravar",
    "aldravadas": "aldravar",
    "aldravado": "aldravar",
    "aldravados": "aldravar",
    "aldravai": "aldravar",
    "aldravais": "aldravar",
    "aldravam": "aldravar",
    "aldravamo": "aldravar",
    "aldravamos": "aldravar",
    "aldravando": "aldravar",
    "aldravara": "aldravar",
    "aldravaram": "aldravar",
    "aldravaras": "aldravar",
    "aldravarde": "aldravar",
    "aldravardes": "aldravar",
    "aldravare": "aldravar",
    "aldravarei": "aldravar",
    "aldravareis": "aldravar",
    "aldravarem": "aldravar",
    "aldravaremos": "aldravar",
    "aldravares": "aldravar",
    "aldravaria": "aldravar",
    "aldravariam": "aldravar",
    "aldravarias": "aldravar",
    "aldravarmo": "aldravar",
    "aldravarmos": "aldravar",
    "aldravará": "aldravar",
    "aldravarás": "aldravar",
    "aldravarão": "aldravar",
    "aldravaríamos": "aldravar",
    "aldravaríeis": "aldravar",
    "aldravas": "aldravar",
    "aldravasse": "aldravar",
    "aldravassem": "aldravar",
    "aldravasses": "aldravar",
    "aldravaste": "aldravar",
    "aldravastes": "aldravar",
    "aldravava": "aldravar",
    "aldravavam": "aldravar",
    "aldravavas": "aldravar",
    "aldrave": "aldravar",
    "aldravei": "aldravar",
    "aldraveira": "aldraveiro",
    "aldraveiras": "aldraveiro",
    "aldraveiros": "aldraveiro",
    "aldraveis": "aldravar",
    "aldravem": "aldravar",
    "aldravemo": "aldravar",
    "aldravemos": "aldravar",
    "aldraves": "aldravar",
    "aldravices": "aldravice",
    "aldravo": "aldravar",
    "aldravona": "aldravão",
    "aldravonas": "aldravão",
    "aldravos": "aldravo",
    "aldravou": "aldravar",
    "aldravá": "aldravar",
    "aldravámo": "aldravar",
    "aldravámos": "aldravar",
    "aldraváramo": "aldravar",
    "aldraváramos": "aldravar",
    "aldravárei": "aldravar",
    "aldraváreis": "aldravar",
    "aldravásseis": "aldravar",
    "aldravássemos": "aldravar",
    "aldravávamo": "aldravar",
    "aldravávamos": "aldravar",
    "aldravávei": "aldravar",
    "aldraváveis": "aldravar",
    "aldravões": "aldravão",
    "aldropes": "aldrope",
    "aldrúbia": "aldrúbio",
    "aldrúbias": "aldrúbio",
    "aldrúbios": "aldrúbio",
    "aldóximas": "aldóxima",
    "ale": "alar",
    "aleada": "alear",
    "aleadas": "alear",
    "aleado": "alear",
    "aleados": "alear",
    "aleai": "alear",
    "aleais": "alear",
    "aleamo": "alear",
    "aleamos": "alear",
    "aleando": "alear",
    "aleara": "alear",
    "alearam": "alear",
    "alearas": "alear",
    "aleardes": "alear",
    "alearei": "alear",
    "aleareis": "alear",
    "alearem": "alear",
    "alearemos": "alear",
    "aleares": "alear",
    "alearia": "alear",
    "aleariam": "alear",
    "alearias": "alear",
    "alearmo": "alear",
    "alearmos": "alear",
    "aleará": "alear",
    "alearás": "alear",
    "alearão": "alear",
    "alearíamos": "alear",
    "alearíeis": "alear",
    "aleasse": "alear",
    "aleassem": "alear",
    "aleasses": "alear",
    "aleaste": "alear",
    "aleastes": "alear",
    "aleatoriedades": "aleatoriedade",
    "aleatória": "aleatório",
    "aleatórias": "aleatório",
    "aleatórios": "aleatório",
    "aleava": "alear",
    "aleavam": "alear",
    "aleavas": "alear",
    "alecrineiros": "alecrineiro",
    "alecrins": "alecrim",
    "alecrinzeiros": "alecrinzeiro",
    "alectoromancias": "alectoromancia",
    "alectoromantes": "alectoromante",
    "alectória": "alectório",
    "alectórias": "alectório",
    "alectórios": "alectório",
    "alecítica": "alecítico",
    "alecíticas": "alecítico",
    "alecíticos": "alecítico",
    "aleei": "alear",
    "aleeis": "alear",
    "aleemo": "alear",
    "aleemos": "alear",
    "alefrizes": "alefriz",
    "alefs": "alef",
    "alega": "alegar",
    "alegada": "alegar",
    "alegadas": "alegar",
    "alegado": "alegar",
    "alegados": "alegar",
    "alegai": "alegar",
    "alegais": "alegar",
    "alegam": "alegar",
    "alegamo": "alegar",
    "alegamos": "alegar",
    "alegando": "alegar",
    "alegantes": "alegante",
    "alegara": "alegar",
    "alegaram": "alegar",
    "alegaras": "alegar",
    "alegarde": "alegar",
    "alegardes": "alegar",
    "alegare": "alegar",
    "alegarei": "alegar",
    "alegareis": "alegar",
    "alegarem": "alegar",
    "alegaremos": "alegar",
    "alegares": "alegar",
    "alegaria": "alegar",
    "alegariam": "alegar",
    "alegarias": "alegar",
    "alegarmo": "alegar",
    "alegarmos": "alegar",
    "alegará": "alegar",
    "alegarás": "alegar",
    "alegarão": "alegar",
    "alegaríamos": "alegar",
    "alegaríeis": "alegar",
    "alegas": "alegar",
    "alegasse": "alegar",
    "alegassem": "alegar",
    "alegasses": "alegar",
    "alegaste": "alegar",
    "alegastes": "alegar",
    "alegava": "alegar",
    "alegavam": "alegar",
    "alegavas": "alegar",
    "alegações": "alegação",
    "alego": "alegar",
    "alegorias": "alegoria",
    "alegorismos": "alegorismo",
    "alegoristas": "alegorista",
    "alegoriza": "alegorizar",
    "alegorizada": "alegorizar",
    "alegorizadas": "alegorizar",
    "alegorizado": "alegorizar",
    "alegorizados": "alegorizar",
    "alegorizai": "alegorizar",
    "alegorizais": "alegorizar",
    "alegorizam": "alegorizar",
    "alegorizamo": "alegorizar",
    "alegorizamos": "alegorizar",
    "alegorizando": "alegorizar",
    "alegorizara": "alegorizar",
    "alegorizaram": "alegorizar",
    "alegorizaras": "alegorizar",
    "alegorizarde": "alegorizar",
    "alegorizardes": "alegorizar",
    "alegorizare": "alegorizar",
    "alegorizarei": "alegorizar",
    "alegorizareis": "alegorizar",
    "alegorizarem": "alegorizar",
    "alegorizaremos": "alegorizar",
    "alegorizares": "alegorizar",
    "alegorizaria": "alegorizar",
    "alegorizariam": "alegorizar",
    "alegorizarias": "alegorizar",
    "alegorizarmo": "alegorizar",
    "alegorizarmos": "alegorizar",
    "alegorizará": "alegorizar",
    "alegorizarás": "alegorizar",
    "alegorizarão": "alegorizar",
    "alegorizaríamos": "alegorizar",
    "alegorizaríeis": "alegorizar",
    "alegorizas": "alegorizar",
    "alegorizasse": "alegorizar",
    "alegorizassem": "alegorizar",
    "alegorizasses": "alegorizar",
    "alegorizaste": "alegorizar",
    "alegorizastes": "alegorizar",
    "alegorizava": "alegorizar",
    "alegorizavam": "alegorizar",
    "alegorizavas": "alegorizar",
    "alegorizações": "alegorização",
    "alegorize": "alegorizar",
    "alegorizei": "alegorizar",
    "alegorizeis": "alegorizar",
    "alegorizem": "alegorizar",
    "alegorizemo": "alegorizar",
    "alegorizemos": "alegorizar",
    "alegorizes": "alegorizar",
    "alegorizo": "alegorizar",
    "alegorizou": "alegorizar",
    "alegorizá": "alegorizar",
    "alegorizámo": "alegorizar",
    "alegorizámos": "alegorizar",
    "alegorizáramo": "alegorizar",
    "alegorizáramos": "alegorizar",
    "alegorizárei": "alegorizar",
    "alegorizáreis": "alegorizar",
    "alegorizásseis": "alegorizar",
    "alegorizássemos": "alegorizar",
    "alegorizávamo": "alegorizar",
    "alegorizávamos": "alegorizar",
    "alegorizávei": "alegorizar",
    "alegorizáveis": "alegorizar",
    "alegou": "alegar",
    "alegra": "alegrar",
    "alegrada": "alegrar",
    "alegradas": "alegrar",
    "alegrado": "alegrar",
    "alegradora": "alegrador",
    "alegradoras": "alegrador",
    "alegradores": "alegrador",
    "alegrados": "alegrar",
    "alegrai": "alegrar",
    "alegrais": "alegrar",
    "alegram": "alegrar",
    "alegramentos": "alegramento",
    "alegramo": "alegrar",
    "alegramos": "alegrar",
    "alegrando": "alegrar",
    "alegrara": "alegrar",
    "alegraram": "alegrar",
    "alegraras": "alegrar",
    "alegrarde": "alegrar",
    "alegrardes": "alegrar",
    "alegrare": "alegrar",
    "alegrarei": "alegrar",
    "alegrareis": "alegrar",
    "alegrarem": "alegrar",
    "alegraremos": "alegrar",
    "alegrares": "alegrar",
    "alegraria": "alegrar",
    "alegrariam": "alegrar",
    "alegrarias": "alegrar",
    "alegrarmo": "alegrar",
    "alegrarmos": "alegrar",
    "alegrará": "alegrar",
    "alegrarás": "alegrar",
    "alegrarão": "alegrar",
    "alegraríamos": "alegrar",
    "alegraríeis": "alegrar",
    "alegras": "alegrar",
    "alegrasse": "alegrar",
    "alegrassem": "alegrar",
    "alegrasses": "alegrar",
    "alegraste": "alegrar",
    "alegrastes": "alegrar",
    "alegrava": "alegrar",
    "alegravam": "alegrar",
    "alegravas": "alegrar",
    "alegre": "alegrar",
    "alegrei": "alegrar",
    "alegreis": "alegrar",
    "alegrem": "alegrar",
    "alegremo": "alegrar",
    "alegremos": "alegrar",
    "alegres": "alegre",
    "alegretes": "alegrete",
    "alegretos": "alegreto",
    "alegrias": "alegria",
    "alegrinhos": "alegrinho",
    "alegro": "alegrar",
    "alegrona": "alegrão",
    "alegronas": "alegrão",
    "alegrotes": "alegrote",
    "alegrou": "alegrar",
    "alegrá": "alegrar",
    "alegrámo": "alegrar",
    "alegrámos": "alegrar",
    "alegráramo": "alegrar",
    "alegráramos": "alegrar",
    "alegrárei": "alegrar",
    "alegráreis": "alegrar",
    "alegrásseis": "alegrar",
    "alegrássemos": "alegrar",
    "alegrávamo": "alegrar",
    "alegrávamos": "alegrar",
    "alegrávei": "alegrar",
    "alegráveis": "alegrável",
    "alegrórios": "alegrório",
    "alegrões": "alegrão",
    "alegue": "alegar",
    "aleguei": "alegar",
    "alegueis": "alegar",
    "aleguem": "alegar",
    "aleguemo": "alegar",
    "aleguemos": "alegar",
    "alegues": "alegar",
    "alegá": "alegar",
    "alegámo": "alegar",
    "alegámos": "alegar",
    "alegáramo": "alegar",
    "alegáramos": "alegar",
    "alegárei": "alegar",
    "alegáreis": "alegar",
    "alegásseis": "alegar",
    "alegássemos": "alegar",
    "alegávamo": "alegar",
    "alegávamos": "alegar",
    "alegávei": "alegar",
    "alegáveis": "alegável",
    "alegórica": "alegórico",
    "alegóricas": "alegórico",
    "alegóricos": "alegórico",
    "alei": "alar",
    "aleia": "alear",
    "aleiam": "alear",
    "aleias": "aleia",
    "aleie": "alear",
    "aleiem": "alear",
    "aleies": "alear",
    "aleija": "aleijar",
    "aleijada": "aleijar",
    "aleijadas": "aleijar",
    "aleijadinha": "aleijado",
    "aleijadinhas": "aleijado",
    "aleijadinho": "aleijado",
    "aleijadinhos": "aleijado",
    "aleijadita": "aleijado",
    "aleijaditas": "aleijado",
    "aleijadito": "aleijado",
    "aleijaditos": "aleijado",
    "aleijado": "aleijar",
    "aleijados": "aleijar",
    "aleijai": "aleijar",
    "aleijais": "aleijar",
    "aleijam": "aleijar",
    "aleijamentos": "aleijamento",
    "aleijamo": "aleijar",
    "aleijamos": "aleijar",
    "aleijando": "aleijar",
    "aleijara": "aleijar",
    "aleijaram": "aleijar",
    "aleijaras": "aleijar",
    "aleijarde": "aleijar",
    "aleijardes": "aleijar",
    "aleijare": "aleijar",
    "aleijarei": "aleijar",
    "aleijareis": "aleijar",
    "aleijarem": "aleijar",
    "aleijaremos": "aleijar",
    "aleijares": "aleijar",
    "aleijaria": "aleijar",
    "aleijariam": "aleijar",
    "aleijarias": "aleijar",
    "aleijarmo": "aleijar",
    "aleijarmos": "aleijar",
    "aleijará": "aleijar",
    "aleijarás": "aleijar",
    "aleijarão": "aleijar",
    "aleijaríamos": "aleijar",
    "aleijaríeis": "aleijar",
    "aleijas": "aleijar",
    "aleijasse": "aleijar",
    "aleijassem": "aleijar",
    "aleijasses": "aleijar",
    "aleijaste": "aleijar",
    "aleijastes": "aleijar",
    "aleijava": "aleijar",
    "aleijavam": "aleijar",
    "aleijavas": "aleijar",
    "aleije": "aleijar",
    "aleijei": "aleijar",
    "aleijeis": "aleijar",
    "aleijem": "aleijar",
    "aleijemo": "aleijar",
    "aleijemos": "aleijar",
    "aleijes": "aleijar",
    "aleijo": "aleijar",
    "aleijou": "aleijar",
    "aleijá": "aleijar",
    "aleijámo": "aleijar",
    "aleijámos": "aleijar",
    "aleijáramo": "aleijar",
    "aleijáramos": "aleijar",
    "aleijárei": "aleijar",
    "aleijáreis": "aleijar",
    "aleijásseis": "aleijar",
    "aleijássemos": "aleijar",
    "aleijávamo": "aleijar",
    "aleijávamos": "aleijar",
    "aleijávei": "aleijar",
    "aleijáveis": "aleijar",
    "aleijões": "aleijão",
    "aleio": "alear",
    "aleira": "aleirar",
    "aleirada": "aleirar",
    "aleiradas": "aleirar",
    "aleirado": "aleirar",
    "aleirados": "aleirar",
    "aleirai": "aleirar",
    "aleirais": "aleirar",
    "aleiram": "aleirar",
    "aleiramo": "aleirar",
    "aleiramos": "aleirar",
    "aleirando": "aleirar",
    "aleirara": "aleirar",
    "aleiraram": "aleirar",
    "aleiraras": "aleirar",
    "aleirarde": "aleirar",
    "aleirardes": "aleirar",
    "aleirare": "aleirar",
    "aleirarei": "aleirar",
    "aleirareis": "aleirar",
    "aleirarem": "aleirar",
    "aleiraremos": "aleirar",
    "aleirares": "aleirar",
    "aleiraria": "aleirar",
    "aleirariam": "aleirar",
    "aleirarias": "aleirar",
    "aleirarmo": "aleirar",
    "aleirarmos": "aleirar",
    "aleirará": "aleirar",
    "aleirarás": "aleirar",
    "aleirarão": "aleirar",
    "aleiraríamos": "aleirar",
    "aleiraríeis": "aleirar",
    "aleiras": "aleirar",
    "aleirasse": "aleirar",
    "aleirassem": "aleirar",
    "aleirasses": "aleirar",
    "aleiraste": "aleirar",
    "aleirastes": "aleirar",
    "aleirava": "aleirar",
    "aleiravam": "aleirar",
    "aleiravas": "aleirar",
    "aleire": "aleirar",
    "aleirei": "aleirar",
    "aleireis": "aleirar",
    "aleirem": "aleirar",
    "aleiremo": "aleirar",
    "aleiremos": "aleirar",
    "aleires": "aleirar",
    "aleiro": "aleirar",
    "aleirou": "aleirar",
    "aleirá": "aleirar",
    "aleirámo": "aleirar",
    "aleirámos": "aleirar",
    "aleiráramo": "aleirar",
    "aleiráramos": "aleirar",
    "aleirárei": "aleirar",
    "aleiráreis": "aleirar",
    "aleirásseis": "aleirar",
    "aleirássemos": "aleirar",
    "aleirávamo": "aleirar",
    "aleirávamos": "aleirar",
    "aleirávei": "aleirar",
    "aleiráveis": "aleirar",
    "aleis": "alar",
    "aleita": "aleitar",
    "aleitada": "aleitar",
    "aleitadas": "aleitar",
    "aleitado": "aleitar",
    "aleitados": "aleitar",
    "aleitai": "aleitar",
    "aleitais": "aleitar",
    "aleitam": "aleitar",
    "aleitamentos": "aleitamento",
    "aleitamo": "aleitar",
    "aleitamos": "aleitar",
    "aleitando": "aleitar",
    "aleitantes": "aleitante",
    "aleitara": "aleitar",
    "aleitaram": "aleitar",
    "aleitaras": "aleitar",
    "aleitarde": "aleitar",
    "aleitardes": "aleitar",
    "aleitare": "aleitar",
    "aleitarei": "aleitar",
    "aleitareis": "aleitar",
    "aleitarem": "aleitar",
    "aleitaremos": "aleitar",
    "aleitares": "aleitar",
    "aleitaria": "aleitar",
    "aleitariam": "aleitar",
    "aleitarias": "aleitar",
    "aleitarmo": "aleitar",
    "aleitarmos": "aleitar",
    "aleitará": "aleitar",
    "aleitarás": "aleitar",
    "aleitarão": "aleitar",
    "aleitaríamos": "aleitar",
    "aleitaríeis": "aleitar",
    "aleitas": "aleitar",
    "aleitasse": "aleitar",
    "aleitassem": "aleitar",
    "aleitasses": "aleitar",
    "aleitaste": "aleitar",
    "aleitastes": "aleitar",
    "aleitava": "aleitar",
    "aleitavam": "aleitar",
    "aleitavas": "aleitar",
    "aleitações": "aleitação",
    "aleite": "aleitar",
    "aleitei": "aleitar",
    "aleiteis": "aleitar",
    "aleitem": "aleitar",
    "aleitemo": "aleitar",
    "aleitemos": "aleitar",
    "aleites": "aleitar",
    "aleito": "aleitar",
    "aleitou": "aleitar",
    "aleitá": "aleitar",
    "aleitámo": "aleitar",
    "aleitámos": "aleitar",
    "aleitáramo": "aleitar",
    "aleitáramos": "aleitar",
    "aleitárei": "aleitar",
    "aleitáreis": "aleitar",
    "aleitásseis": "aleitar",
    "aleitássemos": "aleitar",
    "aleitávamo": "aleitar",
    "aleitávamos": "aleitar",
    "aleitávei": "aleitar",
    "aleitáveis": "aleitar",
    "aleives": "aleive",
    "aleivosa": "aleivoso",
    "aleivosas": "aleivoso",
    "aleivosias": "aleivosia",
    "aleivosos": "aleivoso",
    "alelargas": "alelarga",
    "alelis": "aleli",
    "alelomorfa": "alelomorfo",
    "alelomorfas": "alelomorfo",
    "alelomorfos": "alelomorfo",
    "alelomórfica": "alelomórfico",
    "alelomórficas": "alelomórfico",
    "alelomórficos": "alelomórfico",
    "aleluias": "aleluia",
    "aleluiática": "aleluiático",
    "aleluiáticas": "aleluiático",
    "aleluiáticos": "aleluiático",
    "aleluítica": "aleluítico",
    "aleluíticas": "aleluítico",
    "aleluíticos": "aleluítico",
    "alem": "alar",
    "alembra": "alembrar",
    "alembrada": "alembrar",
    "alembradas": "alembrar",
    "alembrado": "alembrar",
    "alembrados": "alembrar",
    "alembrai": "alembrar",
    "alembrais": "alembrar",
    "alembram": "alembrar",
    "alembramo": "alembrar",
    "alembramos": "alembrar",
    "alembrando": "alembrar",
    "alembrara": "alembrar",
    "alembraram": "alembrar",
    "alembraras": "alembrar",
    "alembrarde": "alembrar",
    "alembrardes": "alembrar",
    "alembrare": "alembrar",
    "alembrarei": "alembrar",
    "alembrareis": "alembrar",
    "alembrarem": "alembrar",
    "alembraremos": "alembrar",
    "alembrares": "alembrar",
    "alembraria": "alembrar",
    "alembrariam": "alembrar",
    "alembrarias": "alembrar",
    "alembrarmo": "alembrar",
    "alembrarmos": "alembrar",
    "alembrará": "alembrar",
    "alembrarás": "alembrar",
    "alembrarão": "alembrar",
    "alembraríamos": "alembrar",
    "alembraríeis": "alembrar",
    "alembras": "alembrar",
    "alembrasse": "alembrar",
    "alembrassem": "alembrar",
    "alembrasses": "alembrar",
    "alembraste": "alembrar",
    "alembrastes": "alembrar",
    "alembrava": "alembrar",
    "alembravam": "alembrar",
    "alembravas": "alembrar",
    "alembre": "alembrar",
    "alembrei": "alembrar",
    "alembreis": "alembrar",
    "alembrem": "alembrar",
    "alembremo": "alembrar",
    "alembremos": "alembrar",
    "alembres": "alembrar",
    "alembro": "alembrar",
    "alembrou": "alembrar",
    "alembrá": "alembrar",
    "alembrámo": "alembrar",
    "alembrámos": "alembrar",
    "alembráramo": "alembrar",
    "alembráramos": "alembrar",
    "alembrárei": "alembrar",
    "alembráreis": "alembrar",
    "alembrásseis": "alembrar",
    "alembrássemos": "alembrar",
    "alembrávamo": "alembrar",
    "alembrávamos": "alembrar",
    "alembrávei": "alembrar",
    "alembráveis": "alembrar",
    "alemo": "alar",
    "alemos": "alar",
    "alemânica": "alemânico",
    "alemânicas": "alemânico",
    "alemânicos": "alemânico",
    "alemã": "alemão",
    "alemães": "alemão",
    "alemãs": "alemão",
    "alenquerenses": "alenquerense",
    "alenta": "alentar",
    "alentada": "alentar",
    "alentadas": "alentar",
    "alentado": "alentar",
    "alentadora": "alentador",
    "alentadoras": "alentador",
    "alentadores": "alentador",
    "alentados": "alentar",
    "alentai": "alentar",
    "alentais": "alentar",
    "alentam": "alentar",
    "alentamo": "alentar",
    "alentamos": "alentar",
    "alentando": "alentar",
    "alentara": "alentar",
    "alentaram": "alentar",
    "alentaras": "alentar",
    "alentarde": "alentar",
    "alentardes": "alentar",
    "alentare": "alentar",
    "alentarei": "alentar",
    "alentareis": "alentar",
    "alentarem": "alentar",
    "alentaremos": "alentar",
    "alentares": "alentar",
    "alentaria": "alentar",
    "alentariam": "alentar",
    "alentarias": "alentar",
    "alentarmo": "alentar",
    "alentarmos": "alentar",
    "alentará": "alentar",
    "alentarás": "alentar",
    "alentarão": "alentar",
    "alentaríamos": "alentar",
    "alentaríeis": "alentar",
    "alentas": "alentar",
    "alentasse": "alentar",
    "alentassem": "alentar",
    "alentasses": "alentar",
    "alentaste": "alentar",
    "alentastes": "alentar",
    "alentava": "alentar",
    "alentavam": "alentar",
    "alentavas": "alentar",
    "alente": "alentar",
    "alentece": "alentecer",
    "alentecei": "alentecer",
    "alenteceis": "alentecer",
    "alentecem": "alentecer",
    "alentecemo": "alentecer",
    "alentecemos": "alentecer",
    "alentecendo": "alentecer",
    "alentecera": "alentecer",
    "alenteceram": "alentecer",
    "alenteceras": "alentecer",
    "alentecerde": "alentecer",
    "alentecerdes": "alentecer",
    "alentecere": "alentecer",
    "alentecerei": "alentecer",
    "alentecereis": "alentecer",
    "alentecerem": "alentecer",
    "alenteceremos": "alentecer",
    "alenteceres": "alentecer",
    "alenteceria": "alentecer",
    "alenteceriam": "alentecer",
    "alentecerias": "alentecer",
    "alentecermo": "alentecer",
    "alentecermos": "alentecer",
    "alentecerá": "alentecer",
    "alentecerás": "alentecer",
    "alentecerão": "alentecer",
    "alenteceríamos": "alentecer",
    "alenteceríeis": "alentecer",
    "alenteces": "alentecer",
    "alentecesse": "alentecer",
    "alentecessem": "alentecer",
    "alentecesses": "alentecer",
    "alenteceste": "alentecer",
    "alentecestes": "alentecer",
    "alenteceu": "alentecer",
    "alenteci": "alentecer",
    "alentecia": "alentecer",
    "alenteciam": "alentecer",
    "alentecias": "alentecer",
    "alentecida": "alentecer",
    "alentecidas": "alentecer",
    "alentecido": "alentecer",
    "alentecidos": "alentecer",
    "alentecimentos": "alentecimento",
    "alentecê": "alentecer",
    "alentecêramo": "alentecer",
    "alentecêramos": "alentecer",
    "alentecêrei": "alentecer",
    "alentecêreis": "alentecer",
    "alentecêsseis": "alentecer",
    "alentecêssemos": "alentecer",
    "alentecíamo": "alentecer",
    "alentecíamos": "alentecer",
    "alentecíei": "alentecer",
    "alentecíeis": "alentecer",
    "alentei": "alentar",
    "alenteis": "alentar",
    "alentejana": "alentejano",
    "alentejanas": "alentejano",
    "alentejanos": "alentejano",
    "alentem": "alentar",
    "alentemo": "alentar",
    "alentemos": "alentar",
    "alentes": "alentar",
    "alenteça": "alentecer",
    "alenteçais": "alentecer",
    "alenteçam": "alentecer",
    "alenteçamo": "alentecer",
    "alenteçamos": "alentecer",
    "alenteças": "alentecer",
    "alenteço": "alentecer",
    "alento": "alentar",
    "alentos": "alento",
    "alentou": "alentar",
    "alentá": "alentar",
    "alentámo": "alentar",
    "alentámos": "alentar",
    "alentáramo": "alentar",
    "alentáramos": "alentar",
    "alentárei": "alentar",
    "alentáreis": "alentar",
    "alentásseis": "alentar",
    "alentássemos": "alentar",
    "alentávamo": "alentar",
    "alentávamos": "alentar",
    "alentávei": "alentar",
    "alentáveis": "alentar",
    "aleonada": "aleonado",
    "aleonadas": "aleonado",
    "aleonados": "aleonado",
    "aleopardada": "aleopardado",
    "aleopardadas": "aleopardado",
    "aleopardados": "aleopardado",
    "aleou": "alear",
    "alepidotos": "alepidoto",
    "alepinas": "alepina",
    "alepinos": "alepino",
    "aleptinas": "aleptina",
    "alequiada": "alequiado",
    "alequiadas": "alequiado",
    "alequiados": "alequiado",
    "alerda": "alerdar",
    "alerdada": "alerdar",
    "alerdadas": "alerdar",
    "alerdado": "alerdar",
    "alerdados": "alerdar",
    "alerdai": "alerdar",
    "alerdais": "alerdar",
    "alerdam": "alerdar",
    "alerdamo": "alerdar",
    "alerdamos": "alerdar",
    "alerdando": "alerdar",
    "alerdara": "alerdar",
    "alerdaram": "alerdar",
    "alerdaras": "alerdar",
    "alerdarde": "alerdar",
    "alerdardes": "alerdar",
    "alerdare": "alerdar",
    "alerdarei": "alerdar",
    "alerdareis": "alerdar",
    "alerdarem": "alerdar",
    "alerdaremos": "alerdar",
    "alerdares": "alerdar",
    "alerdaria": "alerdar",
    "alerdariam": "alerdar",
    "alerdarias": "alerdar",
    "alerdarmo": "alerdar",
    "alerdarmos": "alerdar",
    "alerdará": "alerdar",
    "alerdarás": "alerdar",
    "alerdarão": "alerdar",
    "alerdaríamos": "alerdar",
    "alerdaríeis": "alerdar",
    "alerdas": "alerdar",
    "alerdasse": "alerdar",
    "alerdassem": "alerdar",
    "alerdasses": "alerdar",
    "alerdaste": "alerdar",
    "alerdastes": "alerdar",
    "alerdava": "alerdar",
    "alerdavam": "alerdar",
    "alerdavas": "alerdar",
    "alerde": "alerdar",
    "alerdei": "alerdar",
    "alerdeis": "alerdar",
    "alerdem": "alerdar",
    "alerdemo": "alerdar",
    "alerdemos": "alerdar",
    "alerdes": "alerdar",
    "alerdo": "alerdar",
    "alerdou": "alerdar",
    "alerdá": "alerdar",
    "alerdámo": "alerdar",
    "alerdámos": "alerdar",
    "alerdáramo": "alerdar",
    "alerdáramos": "alerdar",
    "alerdárei": "alerdar",
    "alerdáreis": "alerdar",
    "alerdásseis": "alerdar",
    "alerdássemos": "alerdar",
    "alerdávamo": "alerdar",
    "alerdávamos": "alerdar",
    "alerdávei": "alerdar",
    "alerdáveis": "alerdar",
    "alergias": "alergia",
    "alergica": "alergico",
    "alergicas": "alergico",
    "alergicos": "alergico",
    "alergistas": "alergista",
    "alergologa": "alergologo",
    "alergologas": "alergologo",
    "alergologias": "alergologia",
    "alergologos": "alergologo",
    "alergéneos": "alergéneo",
    "alerta": "alertar",
    "alertada": "alertar",
    "alertadas": "alertar",
    "alertado": "alertar",
    "alertados": "alertar",
    "alertadíssima": "alertado",
    "alertadíssimas": "alertado",
    "alertadíssimo": "alertado",
    "alertadíssimos": "alertado",
    "alertai": "alertar",
    "alertais": "alertar",
    "alertam": "alertar",
    "alertamo": "alertar",
    "alertamos": "alertar",
    "alertando": "alertar",
    "alertara": "alertar",
    "alertaram": "alertar",
    "alertaras": "alertar",
    "alertarde": "alertar",
    "alertardes": "alertar",
    "alertare": "alertar",
    "alertarei": "alertar",
    "alertareis": "alertar",
    "alertarem": "alertar",
    "alertaremos": "alertar",
    "alertares": "alertar",
    "alertaria": "alertar",
    "alertariam": "alertar",
    "alertarias": "alertar",
    "alertarmo": "alertar",
    "alertarmos": "alertar",
    "alertará": "alertar",
    "alertarás": "alertar",
    "alertarão": "alertar",
    "alertaríamos": "alertar",
    "alertaríeis": "alertar",
    "alertas": "alertar",
    "alertasse": "alertar",
    "alertassem": "alertar",
    "alertasses": "alertar",
    "alertaste": "alertar",
    "alertastes": "alertar",
    "alertava": "alertar",
    "alertavam": "alertar",
    "alertavas": "alertar",
    "alerte": "alertar",
    "alertei": "alertar",
    "alerteis": "alertar",
    "alertem": "alertar",
    "alertemo": "alertar",
    "alertemos": "alertar",
    "alertes": "alertar",
    "alerto": "alertar",
    "alertou": "alertar",
    "alertá": "alertar",
    "alertámo": "alertar",
    "alertámos": "alertar",
    "alertáramo": "alertar",
    "alertáramos": "alertar",
    "alertárei": "alertar",
    "alertáreis": "alertar",
    "alertásseis": "alertar",
    "alertássemos": "alertar",
    "alertávamo": "alertar",
    "alertávamos": "alertar",
    "alertávei": "alertar",
    "alertáveis": "alertar",
    "ales": "alar",
    "alesma": "alesmar",
    "alesmada": "alesmar",
    "alesmadas": "alesmar",
    "alesmado": "alesmar",
    "alesmados": "alesmar",
    "alesmai": "alesmar",
    "alesmais": "alesmar",
    "alesmam": "alesmar",
    "alesmamo": "alesmar",
    "alesmamos": "alesmar",
    "alesmando": "alesmar",
    "alesmara": "alesmar",
    "alesmaram": "alesmar",
    "alesmaras": "alesmar",
    "alesmarde": "alesmar",
    "alesmardes": "alesmar",
    "alesmare": "alesmar",
    "alesmarei": "alesmar",
    "alesmareis": "alesmar",
    "alesmarem": "alesmar",
    "alesmaremos": "alesmar",
    "alesmares": "alesmar",
    "alesmaria": "alesmar",
    "alesmariam": "alesmar",
    "alesmarias": "alesmar",
    "alesmarmo": "alesmar",
    "alesmarmos": "alesmar",
    "alesmará": "alesmar",
    "alesmarás": "alesmar",
    "alesmarão": "alesmar",
    "alesmaríamos": "alesmar",
    "alesmaríeis": "alesmar",
    "alesmas": "alesmar",
    "alesmasse": "alesmar",
    "alesmassem": "alesmar",
    "alesmasses": "alesmar",
    "alesmaste": "alesmar",
    "alesmastes": "alesmar",
    "alesmava": "alesmar",
    "alesmavam": "alesmar",
    "alesmavas": "alesmar",
    "alesme": "alesmar",
    "alesmei": "alesmar",
    "alesmeis": "alesmar",
    "alesmem": "alesmar",
    "alesmemo": "alesmar",
    "alesmemos": "alesmar",
    "alesmes": "alesmar",
    "alesmo": "alesmar",
    "alesmou": "alesmar",
    "alesmá": "alesmar",
    "alesmámo": "alesmar",
    "alesmámos": "alesmar",
    "alesmáramo": "alesmar",
    "alesmáramos": "alesmar",
    "alesmárei": "alesmar",
    "alesmáreis": "alesmar",
    "alesmásseis": "alesmar",
    "alesmássemos": "alesmar",
    "alesmávamo": "alesmar",
    "alesmávamos": "alesmar",
    "alesmávei": "alesmar",
    "alesmáveis": "alesmar",
    "alestesias": "alestesia",
    "aletarga": "aletargar",
    "aletargada": "aletargar",
    "aletargadas": "aletargar",
    "aletargado": "aletargar",
    "aletargados": "aletargar",
    "aletargai": "aletargar",
    "aletargais": "aletargar",
    "aletargam": "aletargar",
    "aletargamo": "aletargar",
    "aletargamos": "aletargar",
    "aletargando": "aletargar",
    "aletargara": "aletargar",
    "aletargaram": "aletargar",
    "aletargaras": "aletargar",
    "aletargarde": "aletargar",
    "aletargardes": "aletargar",
    "aletargare": "aletargar",
    "aletargarei": "aletargar",
    "aletargareis": "aletargar",
    "aletargarem": "aletargar",
    "aletargaremos": "aletargar",
    "aletargares": "aletargar",
    "aletargaria": "aletargar",
    "aletargariam": "aletargar",
    "aletargarias": "aletargar",
    "aletargarmo": "aletargar",
    "aletargarmos": "aletargar",
    "aletargará": "aletargar",
    "aletargarás": "aletargar",
    "aletargarão": "aletargar",
    "aletargaríamos": "aletargar",
    "aletargaríeis": "aletargar",
    "aletargas": "aletargar",
    "aletargasse": "aletargar",
    "aletargassem": "aletargar",
    "aletargasses": "aletargar",
    "aletargaste": "aletargar",
    "aletargastes": "aletargar",
    "aletargava": "aletargar",
    "aletargavam": "aletargar",
    "aletargavas": "aletargar",
    "aletargo": "aletargar",
    "aletargou": "aletargar",
    "aletargue": "aletargar",
    "aletarguei": "aletargar",
    "aletargueis": "aletargar",
    "aletarguem": "aletargar",
    "aletarguemo": "aletargar",
    "aletarguemos": "aletargar",
    "aletargues": "aletargar",
    "aletargá": "aletargar",
    "aletargámo": "aletargar",
    "aletargámos": "aletargar",
    "aletargáramo": "aletargar",
    "aletargáramos": "aletargar",
    "aletargárei": "aletargar",
    "aletargáreis": "aletargar",
    "aletargásseis": "aletargar",
    "aletargássemos": "aletargar",
    "aletargávamo": "aletargar",
    "aletargávamos": "aletargar",
    "aletargávei": "aletargar",
    "aletargáveis": "aletargar",
    "aletas": "aleta",
    "aletoscópios": "aletoscópio",
    "aletrada": "aletradar",
    "aletradada": "aletradar",
    "aletradadas": "aletradar",
    "aletradado": "aletradar",
    "aletradados": "aletradar",
    "aletradai": "aletradar",
    "aletradais": "aletradar",
    "aletradam": "aletradar",
    "aletradamo": "aletradar",
    "aletradamos": "aletradar",
    "aletradando": "aletradar",
    "aletradara": "aletradar",
    "aletradaram": "aletradar",
    "aletradaras": "aletradar",
    "aletradarde": "aletradar",
    "aletradardes": "aletradar",
    "aletradare": "aletradar",
    "aletradarei": "aletradar",
    "aletradareis": "aletradar",
    "aletradarem": "aletradar",
    "aletradaremos": "aletradar",
    "aletradares": "aletradar",
    "aletradaria": "aletradar",
    "aletradariam": "aletradar",
    "aletradarias": "aletradar",
    "aletradarmo": "aletradar",
    "aletradarmos": "aletradar",
    "aletradará": "aletradar",
    "aletradarás": "aletradar",
    "aletradarão": "aletradar",
    "aletradaríamos": "aletradar",
    "aletradaríeis": "aletradar",
    "aletradas": "aletradar",
    "aletradasse": "aletradar",
    "aletradassem": "aletradar",
    "aletradasses": "aletradar",
    "aletradaste": "aletradar",
    "aletradastes": "aletradar",
    "aletradava": "aletradar",
    "aletradavam": "aletradar",
    "aletradavas": "aletradar",
    "aletrade": "aletradar",
    "aletradei": "aletradar",
    "aletradeis": "aletradar",
    "aletradem": "aletradar",
    "aletrademo": "aletradar",
    "aletrademos": "aletradar",
    "aletrades": "aletradar",
    "aletrado": "aletradar",
    "aletradou": "aletradar",
    "aletradá": "aletradar",
    "aletradámo": "aletradar",
    "aletradámos": "aletradar",
    "aletradáramo": "aletradar",
    "aletradáramos": "aletradar",
    "aletradárei": "aletradar",
    "aletradáreis": "aletradar",
    "aletradásseis": "aletradar",
    "aletradássemos": "aletradar",
    "aletradávamo": "aletradar",
    "aletradávamos": "aletradar",
    "aletradávei": "aletradar",
    "aletradáveis": "aletradar",
    "aletrias": "aletria",
    "aletófila": "aletófilo",
    "aletófilas": "aletófilo",
    "aletófilos": "aletófilo",
    "aleucias": "aleucia",
    "aleuromancias": "aleuromancia",
    "aleuromantes": "aleuromante",
    "aleuronas": "aleurona",
    "aleurómetros": "aleurómetro",
    "aleutes": "aleute",
    "alevadoiros": "alevadoiro",
    "alevadouros": "alevadouro",
    "alevanta": "alevantar",
    "alevantada": "alevantar",
    "alevantadas": "alevantar",
    "alevantadiça": "alevantadiço",
    "alevantadiças": "alevantadiço",
    "alevantadiços": "alevantadiço",
    "alevantado": "alevantar",
    "alevantados": "alevantar",
    "alevantai": "alevantar",
    "alevantais": "alevantar",
    "alevantam": "alevantar",
    "alevantamo": "alevantar",
    "alevantamos": "alevantar",
    "alevantando": "alevantar",
    "alevantara": "alevantar",
    "alevantaram": "alevantar",
    "alevantaras": "alevantar",
    "alevantarde": "alevantar",
    "alevantardes": "alevantar",
    "alevantare": "alevantar",
    "alevantarei": "alevantar",
    "alevantareis": "alevantar",
    "alevantarem": "alevantar",
    "alevantaremos": "alevantar",
    "alevantares": "alevantar",
    "alevantaria": "alevantar",
    "alevantariam": "alevantar",
    "alevantarias": "alevantar",
    "alevantarmo": "alevantar",
    "alevantarmos": "alevantar",
    "alevantará": "alevantar",
    "alevantarás": "alevantar",
    "alevantarão": "alevantar",
    "alevantaríamos": "alevantar",
    "alevantaríeis": "alevantar",
    "alevantas": "alevantar",
    "alevantasse": "alevantar",
    "alevantassem": "alevantar",
    "alevantasses": "alevantar",
    "alevantaste": "alevantar",
    "alevantastes": "alevantar",
    "alevantava": "alevantar",
    "alevantavam": "alevantar",
    "alevantavas": "alevantar",
    "alevante": "alevantar",
    "alevantei": "alevantar",
    "alevanteis": "alevantar",
    "alevantem": "alevantar",
    "alevantemo": "alevantar",
    "alevantemos": "alevantar",
    "alevantes": "alevante",
    "alevanto": "alevantar",
    "alevantos": "alevanto",
    "alevantou": "alevantar",
    "alevantá": "alevantar",
    "alevantámo": "alevantar",
    "alevantámos": "alevantar",
    "alevantáramo": "alevantar",
    "alevantáramos": "alevantar",
    "alevantárei": "alevantar",
    "alevantáreis": "alevantar",
    "alevantásseis": "alevantar",
    "alevantássemos": "alevantar",
    "alevantávamo": "alevantar",
    "alevantávamos": "alevantar",
    "alevantávei": "alevantar",
    "alevantáveis": "alevantar",
    "aleveda": "alevedar",
    "alevedada": "alevedar",
    "alevedadas": "alevedar",
    "alevedado": "alevedar",
    "alevedados": "alevedar",
    "alevedai": "alevedar",
    "alevedais": "alevedar",
    "alevedam": "alevedar",
    "alevedamo": "alevedar",
    "alevedamos": "alevedar",
    "alevedando": "alevedar",
    "alevedara": "alevedar",
    "alevedaram": "alevedar",
    "alevedaras": "alevedar",
    "alevedarde": "alevedar",
    "alevedardes": "alevedar",
    "alevedare": "alevedar",
    "alevedarei": "alevedar",
    "alevedareis": "alevedar",
    "alevedarem": "alevedar",
    "alevedaremos": "alevedar",
    "alevedares": "alevedar",
    "alevedaria": "alevedar",
    "alevedariam": "alevedar",
    "alevedarias": "alevedar",
    "alevedarmo": "alevedar",
    "alevedarmos": "alevedar",
    "alevedará": "alevedar",
    "alevedarás": "alevedar",
    "alevedarão": "alevedar",
    "alevedaríamos": "alevedar",
    "alevedaríeis": "alevedar",
    "alevedas": "alevedar",
    "alevedasse": "alevedar",
    "alevedassem": "alevedar",
    "alevedasses": "alevedar",
    "alevedaste": "alevedar",
    "alevedastes": "alevedar",
    "alevedava": "alevedar",
    "alevedavam": "alevedar",
    "alevedavas": "alevedar",
    "alevede": "alevedar",
    "alevedei": "alevedar",
    "alevedeis": "alevedar",
    "alevedem": "alevedar",
    "alevedemo": "alevedar",
    "alevedemos": "alevedar",
    "alevedes": "alevedar",
    "alevedo": "alevedar",
    "alevedou": "alevedar",
    "alevedá": "alevedar",
    "alevedámo": "alevedar",
    "alevedámos": "alevedar",
    "alevedáramo": "alevedar",
    "alevedáramos": "alevedar",
    "alevedárei": "alevedar",
    "alevedáreis": "alevedar",
    "alevedásseis": "alevedar",
    "alevedássemos": "alevedar",
    "alevedávamo": "alevedar",
    "alevedávamos": "alevedar",
    "alevedávei": "alevedar",
    "alevedáveis": "alevedar",
    "alevins": "alevim",
    "alexandrina": "alexandrino",
    "alexandrinas": "alexandrino",
    "alexandrinos": "alexandrino",
    "alexias": "alexia",
    "alexifármacos": "alexifármaco",
    "alexinas": "alexina",
    "alexânderes": "alexânder",
    "alexíaca": "alexíaco",
    "alexíacas": "alexíaco",
    "alexíacos": "alexíaco",
    "alezeriada": "alezeriado",
    "alezeriadas": "alezeriado",
    "alezeriados": "alezeriado",
    "aleámo": "alear",
    "aleámos": "alear",
    "aleáramo": "alear",
    "aleáramos": "alear",
    "aleáreis": "alear",
    "aleásseis": "alear",
    "aleássemos": "alear",
    "aleávamo": "alear",
    "aleávamos": "alear",
    "aleáveis": "alear",
    "alfa": "alfar",
    "alfabeta": "alfabetar",
    "alfabetada": "alfabetar",
    "alfabetadas": "alfabetar",
    "alfabetado": "alfabetar",
    "alfabetadora": "alfabetador",
    "alfabetadoras": "alfabetador",
    "alfabetadores": "alfabetador",
    "alfabetados": "alfabetar",
    "alfabetai": "alfabetar",
    "alfabetais": "alfabetar",
    "alfabetam": "alfabetar",
    "alfabetamo": "alfabetar",
    "alfabetamos": "alfabetar",
    "alfabetando": "alfabetar",
    "alfabetara": "alfabetar",
    "alfabetaram": "alfabetar",
    "alfabetaras": "alfabetar",
    "alfabetarde": "alfabetar",
    "alfabetardes": "alfabetar",
    "alfabetare": "alfabetar",
    "alfabetarei": "alfabetar",
    "alfabetareis": "alfabetar",
    "alfabetarem": "alfabetar",
    "alfabetaremos": "alfabetar",
    "alfabetares": "alfabetar",
    "alfabetaria": "alfabetar",
    "alfabetariam": "alfabetar",
    "alfabetarias": "alfabetar",
    "alfabetarmo": "alfabetar",
    "alfabetarmos": "alfabetar",
    "alfabetará": "alfabetar",
    "alfabetarás": "alfabetar",
    "alfabetarão": "alfabetar",
    "alfabetaríamos": "alfabetar",
    "alfabetaríeis": "alfabetar",
    "alfabetas": "alfabetar",
    "alfabetasse": "alfabetar",
    "alfabetassem": "alfabetar",
    "alfabetasses": "alfabetar",
    "alfabetaste": "alfabetar",
    "alfabetastes": "alfabetar",
    "alfabetava": "alfabetar",
    "alfabetavam": "alfabetar",
    "alfabetavas": "alfabetar",
    "alfabetações": "alfabetação",
    "alfabete": "alfabetar",
    "alfabetei": "alfabetar",
    "alfabeteis": "alfabetar",
    "alfabetem": "alfabetar",
    "alfabetemo": "alfabetar",
    "alfabetemos": "alfabetar",
    "alfabetes": "alfabetar",
    "alfabetismos": "alfabetismo",
    "alfabetistas": "alfabetista",
    "alfabetiza": "alfabetizar",
    "alfabetizada": "alfabetizar",
    "alfabetizadas": "alfabetizar",
    "alfabetizado": "alfabetizar",
    "alfabetizados": "alfabetizar",
    "alfabetizai": "alfabetizar",
    "alfabetizais": "alfabetizar",
    "alfabetizam": "alfabetizar",
    "alfabetizamo": "alfabetizar",
    "alfabetizamos": "alfabetizar",
    "alfabetizando": "alfabetizar",
    "alfabetizara": "alfabetizar",
    "alfabetizaram": "alfabetizar",
    "alfabetizaras": "alfabetizar",
    "alfabetizarde": "alfabetizar",
    "alfabetizardes": "alfabetizar",
    "alfabetizare": "alfabetizar",
    "alfabetizarei": "alfabetizar",
    "alfabetizareis": "alfabetizar",
    "alfabetizarem": "alfabetizar",
    "alfabetizaremos": "alfabetizar",
    "alfabetizares": "alfabetizar",
    "alfabetizaria": "alfabetizar",
    "alfabetizariam": "alfabetizar",
    "alfabetizarias": "alfabetizar",
    "alfabetizarmo": "alfabetizar",
    "alfabetizarmos": "alfabetizar",
    "alfabetizará": "alfabetizar",
    "alfabetizarás": "alfabetizar",
    "alfabetizarão": "alfabetizar",
    "alfabetizaríamos": "alfabetizar",
    "alfabetizaríeis": "alfabetizar",
    "alfabetizas": "alfabetizar",
    "alfabetizasse": "alfabetizar",
    "alfabetizassem": "alfabetizar",
    "alfabetizasses": "alfabetizar",
    "alfabetizaste": "alfabetizar",
    "alfabetizastes": "alfabetizar",
    "alfabetizava": "alfabetizar",
    "alfabetizavam": "alfabetizar",
    "alfabetizavas": "alfabetizar",
    "alfabetizações": "alfabetização",
    "alfabetize": "alfabetizar",
    "alfabetizei": "alfabetizar",
    "alfabetizeis": "alfabetizar",
    "alfabetizem": "alfabetizar",
    "alfabetizemo": "alfabetizar",
    "alfabetizemos": "alfabetizar",
    "alfabetizes": "alfabetizar",
    "alfabetizo": "alfabetizar",
    "alfabetizou": "alfabetizar",
    "alfabetizá": "alfabetizar",
    "alfabetizámo": "alfabetizar",
    "alfabetizámos": "alfabetizar",
    "alfabetizáramo": "alfabetizar",
    "alfabetizáramos": "alfabetizar",
    "alfabetizárei": "alfabetizar",
    "alfabetizáreis": "alfabetizar",
    "alfabetizásseis": "alfabetizar",
    "alfabetizássemos": "alfabetizar",
    "alfabetizávamo": "alfabetizar",
    "alfabetizávamos": "alfabetizar",
    "alfabetizávei": "alfabetizar",
    "alfabetizáveis": "alfabetizável",
    "alfabeto": "alfabetar",
    "alfabetos": "alfabeto",
    "alfabetou": "alfabetar",
    "alfabetá": "alfabetar",
    "alfabetámo": "alfabetar",
    "alfabetámos": "alfabetar",
    "alfabetáramo": "alfabetar",
    "alfabetáramos": "alfabetar",
    "alfabetárei": "alfabetar",
    "alfabetáreis": "alfabetar",
    "alfabetária": "alfabetário",
    "alfabetárias": "alfabetário",
    "alfabetários": "alfabetário",
    "alfabetásseis": "alfabetar",
    "alfabetássemos": "alfabetar",
    "alfabetávamo": "alfabetar",
    "alfabetávamos": "alfabetar",
    "alfabetávei": "alfabetar",
    "alfabetáveis": "alfabetar",
    "alfabética": "alfabético",
    "alfabéticas": "alfabético",
    "alfabéticos": "alfabético",
    "alfaces": "alface",
    "alfacinhas": "alfacinha",
    "alfacos": "alfaco",
    "alfada": "alfar",
    "alfadas": "alfar",
    "alfado": "alfar",
    "alfados": "alfar",
    "alfafas": "alfafa",
    "alfagemes": "alfageme",
    "alfai": "alfar",
    "alfaia": "alfaiar",
    "alfaiada": "alfaiar",
    "alfaiadas": "alfaiar",
    "alfaiado": "alfaiar",
    "alfaiados": "alfaiar",
    "alfaiai": "alfaiar",
    "alfaiais": "alfaiar",
    "alfaiam": "alfaiar",
    "alfaiamentos": "alfaiamento",
    "alfaiamo": "alfaiar",
    "alfaiamos": "alfaiar",
    "alfaiando": "alfaiar",
    "alfaiara": "alfaiar",
    "alfaiaram": "alfaiar",
    "alfaiaras": "alfaiar",
    "alfaiarde": "alfaiar",
    "alfaiardes": "alfaiar",
    "alfaiare": "alfaiar",
    "alfaiarei": "alfaiar",
    "alfaiareis": "alfaiar",
    "alfaiarem": "alfaiar",
    "alfaiaremos": "alfaiar",
    "alfaiares": "alfaiar",
    "alfaiaria": "alfaiar",
    "alfaiariam": "alfaiar",
    "alfaiarias": "alfaiar",
    "alfaiarmo": "alfaiar",
    "alfaiarmos": "alfaiar",
    "alfaiará": "alfaiar",
    "alfaiarás": "alfaiar",
    "alfaiarão": "alfaiar",
    "alfaiaríamos": "alfaiar",
    "alfaiaríeis": "alfaiar",
    "alfaias": "alfaiar",
    "alfaiasse": "alfaiar",
    "alfaiassem": "alfaiar",
    "alfaiasses": "alfaiar",
    "alfaiaste": "alfaiar",
    "alfaiastes": "alfaiar",
    "alfaiata": "alfaiate",
    "alfaiatada": "alfaiatar",
    "alfaiatadas": "alfaiatar",
    "alfaiatado": "alfaiatar",
    "alfaiatados": "alfaiatar",
    "alfaiatai": "alfaiatar",
    "alfaiatais": "alfaiatar",
    "alfaiatam": "alfaiatar",
    "alfaiatamo": "alfaiatar",
    "alfaiatamos": "alfaiatar",
    "alfaiatando": "alfaiatar",
    "alfaiatara": "alfaiatar",
    "alfaiataram": "alfaiatar",
    "alfaiataras": "alfaiatar",
    "alfaiatardes": "alfaiatar",
    "alfaiatarei": "alfaiatar",
    "alfaiatareis": "alfaiatar",
    "alfaiatarem": "alfaiatar",
    "alfaiataremos": "alfaiatar",
    "alfaiatares": "alfaiatar",
    "alfaiataria": "alfaiatar",
    "alfaiatariam": "alfaiatar",
    "alfaiatarias": "alfaiataria",
    "alfaiatarmo": "alfaiatar",
    "alfaiatarmos": "alfaiatar",
    "alfaiatará": "alfaiatar",
    "alfaiatarás": "alfaiatar",
    "alfaiatarão": "alfaiatar",
    "alfaiataríamos": "alfaiatar",
    "alfaiataríeis": "alfaiatar",
    "alfaiatas": "alfaiate",
    "alfaiatasse": "alfaiatar",
    "alfaiatassem": "alfaiatar",
    "alfaiatasses": "alfaiatar",
    "alfaiataste": "alfaiatar",
    "alfaiatastes": "alfaiatar",
    "alfaiatava": "alfaiatar",
    "alfaiatavam": "alfaiatar",
    "alfaiatavas": "alfaiatar",
    "alfaiate": "alfaiatar",
    "alfaiatei": "alfaiatar",
    "alfaiateis": "alfaiatar",
    "alfaiatem": "alfaiatar",
    "alfaiatemo": "alfaiatar",
    "alfaiatemos": "alfaiatar",
    "alfaiates": "alfaiate",
    "alfaiato": "alfaiatar",
    "alfaiatou": "alfaiatar",
    "alfaiatámo": "alfaiatar",
    "alfaiatámos": "alfaiatar",
    "alfaiatáramo": "alfaiatar",
    "alfaiatáramos": "alfaiatar",
    "alfaiatáreis": "alfaiatar",
    "alfaiatásseis": "alfaiatar",
    "alfaiatássemos": "alfaiatar",
    "alfaiatávamo": "alfaiatar",
    "alfaiatávamos": "alfaiatar",
    "alfaiatáveis": "alfaiatar",
    "alfaiava": "alfaiar",
    "alfaiavam": "alfaiar",
    "alfaiavas": "alfaiar",
    "alfaie": "alfaiar",
    "alfaiei": "alfaiar",
    "alfaieis": "alfaiar",
    "alfaiem": "alfaiar",
    "alfaiemo": "alfaiar",
    "alfaiemos": "alfaiar",
    "alfaies": "alfaiar",
    "alfaio": "alfaiar",
    "alfaiou": "alfaiar",
    "alfais": "alfar",
    "alfaiá": "alfaiar",
    "alfaiámo": "alfaiar",
    "alfaiámos": "alfaiar",
    "alfaiáramo": "alfaiar",
    "alfaiáramos": "alfaiar",
    "alfaiárei": "alfaiar",
    "alfaiáreis": "alfaiar",
    "alfaiásseis": "alfaiar",
    "alfaiássemos": "alfaiar",
    "alfaiávamo": "alfaiar",
    "alfaiávamos": "alfaiar",
    "alfaiávei": "alfaiar",
    "alfaiáveis": "alfaiar",
    "alfalfas": "alfalfa",
    "alfam": "alfar",
    "alfamas": "alfama",
    "alfamenses": "alfamense",
    "alfamistas": "alfamista",
    "alfamo": "alfar",
    "alfamos": "alfar",
    "alfanada": "alfanado",
    "alfanadas": "alfanado",
    "alfanados": "alfanado",
    "alfandega": "alfandegar",
    "alfandegada": "alfandegar",
    "alfandegadas": "alfandegar",
    "alfandegado": "alfandegar",
    "alfandegados": "alfandegar",
    "alfandegagens": "alfandegagem",
    "alfandegai": "alfandegar",
    "alfandegais": "alfandegar",
    "alfandegam": "alfandegar",
    "alfandegamo": "alfandegar",
    "alfandegamos": "alfandegar",
    "alfandegando": "alfandegar",
    "alfandegara": "alfandegar",
    "alfandegaram": "alfandegar",
    "alfandegaras": "alfandegar",
    "alfandegarde": "alfandegar",
    "alfandegardes": "alfandegar",
    "alfandegare": "alfandegar",
    "alfandegarei": "alfandegar",
    "alfandegareis": "alfandegar",
    "alfandegarem": "alfandegar",
    "alfandegaremos": "alfandegar",
    "alfandegares": "alfandegar",
    "alfandegaria": "alfandegar",
    "alfandegariam": "alfandegar",
    "alfandegarias": "alfandegar",
    "alfandegarmo": "alfandegar",
    "alfandegarmos": "alfandegar",
    "alfandegará": "alfandegar",
    "alfandegarás": "alfandegar",
    "alfandegarão": "alfandegar",
    "alfandegaríamos": "alfandegar",
    "alfandegaríeis": "alfandegar",
    "alfandegas": "alfandegar",
    "alfandegasse": "alfandegar",
    "alfandegassem": "alfandegar",
    "alfandegasses": "alfandegar",
    "alfandegaste": "alfandegar",
    "alfandegastes": "alfandegar",
    "alfandegava": "alfandegar",
    "alfandegavam": "alfandegar",
    "alfandegavas": "alfandegar",
    "alfandego": "alfandegar",
    "alfandegou": "alfandegar",
    "alfandegue": "alfandegar",
    "alfandeguei": "alfandegar",
    "alfandegueira": "alfandegueiro",
    "alfandegueiras": "alfandegueiro",
    "alfandegueiros": "alfandegueiro",
    "alfandegueis": "alfandegar",
    "alfandeguem": "alfandegar",
    "alfandeguemo": "alfandegar",
    "alfandeguemos": "alfandegar",
    "alfandegues": "alfandegar",
    "alfandegá": "alfandegar",
    "alfandegámo": "alfandegar",
    "alfandegámos": "alfandegar",
    "alfandegáramo": "alfandegar",
    "alfandegáramos": "alfandegar",
    "alfandegárei": "alfandegar",
    "alfandegáreis": "alfandegar",
    "alfandegária": "alfandegário",
    "alfandegárias": "alfandegário",
    "alfandegários": "alfandegário",
    "alfandegásseis": "alfandegar",
    "alfandegássemos": "alfandegar",
    "alfandegávamo": "alfandegar",
    "alfandegávamos": "alfandegar",
    "alfandegávei": "alfandegar",
    "alfandegáveis": "alfandegar",
    "alfando": "alfar",
    "alfanges": "alfange",
    "alfanjada": "alfanjado",
    "alfanjadas": "alfanjado",
    "alfanjados": "alfanjado",
    "alfanumérica": "alfanumérico",
    "alfanuméricas": "alfanumérico",
    "alfanuméricos": "alfanumérico",
    "alfaqueques": "alfaqueque",
    "alfaques": "alfaque",
    "alfaquetes": "alfaquete",
    "alfaquins": "alfaquim",
    "alfaquiques": "alfaquique",
    "alfaquis": "alfaqui",
    "alfara": "alfar",
    "alfaram": "alfar",
    "alfaras": "alfar",
    "alfarazes": "alfaraz",
    "alfarde": "alfar",
    "alfardes": "alfar",
    "alfare": "alfar",
    "alfarei": "alfar",
    "alfareis": "alfar",
    "alfarem": "alfar",
    "alfaremos": "alfar",
    "alfares": "alfar",
    "alfarges": "alfarge",
    "alfaria": "alfar",
    "alfariam": "alfar",
    "alfarias": "alfar",
    "alfarios": "alfario",
    "alfarjas": "alfarja",
    "alfarmo": "alfar",
    "alfarmos": "alfar",
    "alfarrabistas": "alfarrabista",
    "alfarricoques": "alfarricoque",
    "alfarroba": "alfarrobar",
    "alfarrobada": "alfarrobar",
    "alfarrobadas": "alfarrobar",
    "alfarrobado": "alfarrobar",
    "alfarrobados": "alfarrobar",
    "alfarrobai": "alfarrobar",
    "alfarrobais": "alfarrobar",
    "alfarrobam": "alfarrobar",
    "alfarrobamo": "alfarrobar",
    "alfarrobamos": "alfarrobar",
    "alfarrobando": "alfarrobar",
    "alfarrobara": "alfarrobar",
    "alfarrobaram": "alfarrobar",
    "alfarrobaras": "alfarrobar",
    "alfarrobarde": "alfarrobar",
    "alfarrobardes": "alfarrobar",
    "alfarrobare": "alfarrobar",
    "alfarrobarei": "alfarrobar",
    "alfarrobareis": "alfarrobar",
    "alfarrobarem": "alfarrobar",
    "alfarrobaremos": "alfarrobar",
    "alfarrobares": "alfarrobar",
    "alfarrobaria": "alfarrobar",
    "alfarrobariam": "alfarrobar",
    "alfarrobarias": "alfarrobar",
    "alfarrobarmo": "alfarrobar",
    "alfarrobarmos": "alfarrobar",
    "alfarrobará": "alfarrobar",
    "alfarrobarás": "alfarrobar",
    "alfarrobarão": "alfarrobar",
    "alfarrobaríamos": "alfarrobar",
    "alfarrobaríeis": "alfarrobar",
    "alfarrobas": "alfarrobar",
    "alfarrobasse": "alfarrobar",
    "alfarrobassem": "alfarrobar",
    "alfarrobasses": "alfarrobar",
    "alfarrobaste": "alfarrobar",
    "alfarrobastes": "alfarrobar",
    "alfarrobava": "alfarrobar",
    "alfarrobavam": "alfarrobar",
    "alfarrobavas": "alfarrobar",
    "alfarrobe": "alfarrobar",
    "alfarrobei": "alfarrobar",
    "alfarrobeiras": "alfarrobeira",
    "alfarrobeis": "alfarrobar",
    "alfarrobem": "alfarrobar",
    "alfarrobemo": "alfarrobar",
    "alfarrobemos": "alfarrobar",
    "alfarrobes": "alfarrobar",
    "alfarrobo": "alfarrobar",
    "alfarrobou": "alfarrobar",
    "alfarrobá": "alfarrobar",
    "alfarrobámo": "alfarrobar",
    "alfarrobámos": "alfarrobar",
    "alfarrobáramo": "alfarrobar",
    "alfarrobáramos": "alfarrobar",
    "alfarrobárei": "alfarrobar",
    "alfarrobáreis": "alfarrobar",
    "alfarrobásseis": "alfarrobar",
    "alfarrobássemos": "alfarrobar",
    "alfarrobávamo": "alfarrobar",
    "alfarrobávamos": "alfarrobar",
    "alfarrobávei": "alfarrobar",
    "alfarrobáveis": "alfarrobar",
    "alfarrábios": "alfarrábio",
    "alfará": "alfar",
    "alfarás": "alfar",
    "alfarão": "alfar",
    "alfaríamos": "alfar",
    "alfaríeis": "alfar",
    "alfas": "alfar",
    "alfasse": "alfar",
    "alfassem": "alfar",
    "alfasses": "alfar",
    "alfaste": "alfar",
    "alfastes": "alfar",
    "alfava": "alfar",
    "alfavacas": "alfavaca",
    "alfavam": "alfar",
    "alfavas": "alfar",
    "alfazares": "alfazar",
    "alfazema": "alfazemar",
    "alfazemada": "alfazemar",
    "alfazemadas": "alfazemar",
    "alfazemado": "alfazemar",
    "alfazemados": "alfazemar",
    "alfazemai": "alfazemar",
    "alfazemais": "alfazemar",
    "alfazemam": "alfazemar",
    "alfazemamo": "alfazemar",
    "alfazemamos": "alfazemar",
    "alfazemando": "alfazemar",
    "alfazemara": "alfazemar",
    "alfazemaram": "alfazemar",
    "alfazemaras": "alfazemar",
    "alfazemarde": "alfazemar",
    "alfazemardes": "alfazemar",
    "alfazemare": "alfazemar",
    "alfazemarei": "alfazemar",
    "alfazemareis": "alfazemar",
    "alfazemarem": "alfazemar",
    "alfazemaremos": "alfazemar",
    "alfazemares": "alfazemar",
    "alfazemaria": "alfazemar",
    "alfazemariam": "alfazemar",
    "alfazemarias": "alfazemar",
    "alfazemarmo": "alfazemar",
    "alfazemarmos": "alfazemar",
    "alfazemará": "alfazemar",
    "alfazemarás": "alfazemar",
    "alfazemarão": "alfazemar",
    "alfazemaríamos": "alfazemar",
    "alfazemaríeis": "alfazemar",
    "alfazemas": "alfazemar",
    "alfazemasse": "alfazemar",
    "alfazemassem": "alfazemar",
    "alfazemasses": "alfazemar",
    "alfazemaste": "alfazemar",
    "alfazemastes": "alfazemar",
    "alfazemava": "alfazemar",
    "alfazemavam": "alfazemar",
    "alfazemavas": "alfazemar",
    "alfazeme": "alfazemar",
    "alfazemei": "alfazemar",
    "alfazemeis": "alfazemar",
    "alfazemem": "alfazemar",
    "alfazememo": "alfazemar",
    "alfazememos": "alfazemar",
    "alfazemes": "alfazemar",
    "alfazemo": "alfazemar",
    "alfazemou": "alfazemar",
    "alfazemá": "alfazemar",
    "alfazemámo": "alfazemar",
    "alfazemámos": "alfazemar",
    "alfazemáramo": "alfazemar",
    "alfazemáramos": "alfazemar",
    "alfazemárei": "alfazemar",
    "alfazemáreis": "alfazemar",
    "alfazemásseis": "alfazemar",
    "alfazemássemos": "alfazemar",
    "alfazemávamo": "alfazemar",
    "alfazemávamos": "alfazemar",
    "alfazemávei": "alfazemar",
    "alfazemáveis": "alfazemar",
    "alfaçais": "alfaçal",
    "alfe": "alfar",
    "alfeces": "alfece",
    "alfei": "alfar",
    "alfeiradas": "alfeirada",
    "alfeireira": "alfeireiro",
    "alfeireiras": "alfeireiro",
    "alfeireiros": "alfeireiro",
    "alfeires": "alfeire",
    "alfeirios": "alfeirio",
    "alfeiros": "alfeiro",
    "alfeis": "alfar",
    "alfeizeres": "alfeizer",
    "alfeloeira": "alfeloeiro",
    "alfeloeiras": "alfeloeiro",
    "alfeloeiros": "alfeloeiro",
    "alfem": "alfar",
    "alfemo": "alfar",
    "alfemos": "alfar",
    "alfena": "alfenar",
    "alfenada": "alfenar",
    "alfenadas": "alfenar",
    "alfenado": "alfenar",
    "alfenados": "alfenar",
    "alfenai": "alfenar",
    "alfenais": "alfenar",
    "alfenam": "alfenar",
    "alfenamo": "alfenar",
    "alfenamos": "alfenar",
    "alfenando": "alfenar",
    "alfenara": "alfenar",
    "alfenaram": "alfenar",
    "alfenaras": "alfenar",
    "alfenarde": "alfenar",
    "alfenardes": "alfenar",
    "alfenare": "alfenar",
    "alfenarei": "alfenar",
    "alfenareis": "alfenar",
    "alfenarem": "alfenar",
    "alfenaremos": "alfenar",
    "alfenares": "alfenar",
    "alfenaria": "alfenar",
    "alfenariam": "alfenar",
    "alfenarias": "alfenar",
    "alfenarmo": "alfenar",
    "alfenarmos": "alfenar",
    "alfenará": "alfenar",
    "alfenarás": "alfenar",
    "alfenarão": "alfenar",
    "alfenaríamos": "alfenar",
    "alfenaríeis": "alfenar",
    "alfenas": "alfenar",
    "alfenasse": "alfenar",
    "alfenassem": "alfenar",
    "alfenasses": "alfenar",
    "alfenaste": "alfenar",
    "alfenastes": "alfenar",
    "alfenava": "alfenar",
    "alfenavam": "alfenar",
    "alfenavas": "alfenar",
    "alfene": "alfenar",
    "alfenei": "alfenar",
    "alfeneiros": "alfeneiro",
    "alfeneis": "alfenar",
    "alfenem": "alfenar",
    "alfenemo": "alfenar",
    "alfenemos": "alfenar",
    "alfenes": "alfenar",
    "alfenheiros": "alfenheiro",
    "alfenicada": "alfenicado",
    "alfenicadas": "alfenicado",
    "alfenicados": "alfenicado",
    "alfenides": "alfenide",
    "alfenina": "alfeninar",
    "alfeninada": "alfeninar",
    "alfeninadas": "alfeninar",
    "alfeninado": "alfeninar",
    "alfeninados": "alfeninar",
    "alfeninai": "alfeninar",
    "alfeninais": "alfeninar",
    "alfeninam": "alfeninar",
    "alfeninamo": "alfeninar",
    "alfeninamos": "alfeninar",
    "alfeninando": "alfeninar",
    "alfeninara": "alfeninar",
    "alfeninaram": "alfeninar",
    "alfeninaras": "alfeninar",
    "alfeninarde": "alfeninar",
    "alfeninardes": "alfeninar",
    "alfeninare": "alfeninar",
    "alfeninarei": "alfeninar",
    "alfeninareis": "alfeninar",
    "alfeninarem": "alfeninar",
    "alfeninaremos": "alfeninar",
    "alfeninares": "alfeninar",
    "alfeninaria": "alfeninar",
    "alfeninariam": "alfeninar",
    "alfeninarias": "alfeninar",
    "alfeninarmo": "alfeninar",
    "alfeninarmos": "alfeninar",
    "alfeninará": "alfeninar",
    "alfeninarás": "alfeninar",
    "alfeninarão": "alfeninar",
    "alfeninaríamos": "alfeninar",
    "alfeninaríeis": "alfeninar",
    "alfeninas": "alfeninar",
    "alfeninasse": "alfeninar",
    "alfeninassem": "alfeninar",
    "alfeninasses": "alfeninar",
    "alfeninaste": "alfeninar",
    "alfeninastes": "alfeninar",
    "alfeninava": "alfeninar",
    "alfeninavam": "alfeninar",
    "alfeninavas": "alfeninar",
    "alfenine": "alfeninar",
    "alfeninei": "alfeninar",
    "alfenineis": "alfeninar",
    "alfeninem": "alfeninar",
    "alfeninemo": "alfeninar",
    "alfeninemos": "alfeninar",
    "alfenines": "alfeninar",
    "alfenino": "alfeninar",
    "alfeninou": "alfeninar",
    "alfenins": "alfenim",
    "alfeniná": "alfeninar",
    "alfeninámo": "alfeninar",
    "alfeninámos": "alfeninar",
    "alfenináramo": "alfeninar",
    "alfenináramos": "alfeninar",
    "alfeninárei": "alfeninar",
    "alfenináreis": "alfeninar",
    "alfeninásseis": "alfeninar",
    "alfeninássemos": "alfeninar",
    "alfeninávamo": "alfeninar",
    "alfeninávamos": "alfeninar",
    "alfeninávei": "alfeninar",
    "alfenináveis": "alfeninar",
    "alfeno": "alfenar",
    "alfenou": "alfenar",
    "alfená": "alfenar",
    "alfenámo": "alfenar",
    "alfenámos": "alfenar",
    "alfenáramo": "alfenar",
    "alfenáramos": "alfenar",
    "alfenárei": "alfenar",
    "alfenáreis": "alfenar",
    "alfenásseis": "alfenar",
    "alfenássemos": "alfenar",
    "alfenávamo": "alfenar",
    "alfenávamos": "alfenar",
    "alfenávei": "alfenar",
    "alfenáveis": "alfenar",
    "alferces": "alferce",
    "alferenas": "alferena",
    "alfergas": "alferga",
    "alferças": "alferça",
    "alfes": "alfar",
    "alfeças": "alfeça",
    "alfineta": "alfinetar",
    "alfinetada": "alfinetar",
    "alfinetadas": "alfinetar",
    "alfinetado": "alfinetar",
    "alfinetados": "alfinetar",
    "alfinetai": "alfinetar",
    "alfinetais": "alfinetar",
    "alfinetam": "alfinetar",
    "alfinetamo": "alfinetar",
    "alfinetamos": "alfinetar",
    "alfinetando": "alfinetar",
    "alfinetara": "alfinetar",
    "alfinetaram": "alfinetar",
    "alfinetaras": "alfinetar",
    "alfinetarde": "alfinetar",
    "alfinetardes": "alfinetar",
    "alfinetare": "alfinetar",
    "alfinetarei": "alfinetar",
    "alfinetareis": "alfinetar",
    "alfinetarem": "alfinetar",
    "alfinetaremos": "alfinetar",
    "alfinetares": "alfinetar",
    "alfinetaria": "alfinetar",
    "alfinetariam": "alfinetar",
    "alfinetarias": "alfinetar",
    "alfinetarmo": "alfinetar",
    "alfinetarmos": "alfinetar",
    "alfinetará": "alfinetar",
    "alfinetarás": "alfinetar",
    "alfinetarão": "alfinetar",
    "alfinetaríamos": "alfinetar",
    "alfinetaríeis": "alfinetar",
    "alfinetas": "alfinetar",
    "alfinetasse": "alfinetar",
    "alfinetassem": "alfinetar",
    "alfinetasses": "alfinetar",
    "alfinetaste": "alfinetar",
    "alfinetastes": "alfinetar",
    "alfinetava": "alfinetar",
    "alfinetavam": "alfinetar",
    "alfinetavas": "alfinetar",
    "alfinete": "alfinetar",
    "alfinetei": "alfinetar",
    "alfineteiras": "alfineteira",
    "alfineteis": "alfinetar",
    "alfinetem": "alfinetar",
    "alfinetemo": "alfinetar",
    "alfinetemos": "alfinetar",
    "alfinetes": "alfinete",
    "alfinetezinho": "alfinete",
    "alfinetezinhos": "alfinete",
    "alfinetezito": "alfinete",
    "alfinetezitos": "alfinete",
    "alfinetinho": "alfinete",
    "alfinetinhos": "alfinete",
    "alfinetito": "alfinete",
    "alfinetitos": "alfinete",
    "alfineto": "alfinetar",
    "alfinetou": "alfinetar",
    "alfinetá": "alfinetar",
    "alfinetámo": "alfinetar",
    "alfinetámos": "alfinetar",
    "alfinetáramo": "alfinetar",
    "alfinetáramos": "alfinetar",
    "alfinetárei": "alfinetar",
    "alfinetáreis": "alfinetar",
    "alfinetásseis": "alfinetar",
    "alfinetássemos": "alfinetar",
    "alfinetávamo": "alfinetar",
    "alfinetávamos": "alfinetar",
    "alfinetávei": "alfinetar",
    "alfinetáveis": "alfinetar",
    "alfirmes": "alfirme",
    "alfis": "alfil",
    "alfitetes": "alfitete",
    "alfo": "alfar",
    "alfobres": "alfobre",
    "alfombra": "alfombrar",
    "alfombrada": "alfombrar",
    "alfombradas": "alfombrar",
    "alfombrado": "alfombrar",
    "alfombrados": "alfombrar",
    "alfombrai": "alfombrar",
    "alfombrais": "alfombrar",
    "alfombram": "alfombrar",
    "alfombramo": "alfombrar",
    "alfombramos": "alfombrar",
    "alfombrando": "alfombrar",
    "alfombrara": "alfombrar",
    "alfombraram": "alfombrar",
    "alfombraras": "alfombrar",
    "alfombrarde": "alfombrar",
    "alfombrardes": "alfombrar",
    "alfombrare": "alfombrar",
    "alfombrarei": "alfombrar",
    "alfombrareis": "alfombrar",
    "alfombrarem": "alfombrar",
    "alfombraremos": "alfombrar",
    "alfombrares": "alfombrar",
    "alfombraria": "alfombrar",
    "alfombrariam": "alfombrar",
    "alfombrarias": "alfombrar",
    "alfombrarmo": "alfombrar",
    "alfombrarmos": "alfombrar",
    "alfombrará": "alfombrar",
    "alfombrarás": "alfombrar",
    "alfombrarão": "alfombrar",
    "alfombraríamos": "alfombrar",
    "alfombraríeis": "alfombrar",
    "alfombras": "alfombrar",
    "alfombrasse": "alfombrar",
    "alfombrassem": "alfombrar",
    "alfombrasses": "alfombrar",
    "alfombraste": "alfombrar",
    "alfombrastes": "alfombrar",
    "alfombrava": "alfombrar",
    "alfombravam": "alfombrar",
    "alfombravas": "alfombrar",
    "alfombre": "alfombrar",
    "alfombrei": "alfombrar",
    "alfombreis": "alfombrar",
    "alfombrem": "alfombrar",
    "alfombremo": "alfombrar",
    "alfombremos": "alfombrar",
    "alfombres": "alfombrar",
    "alfombro": "alfombrar",
    "alfombrou": "alfombrar",
    "alfombrá": "alfombrar",
    "alfombrámo": "alfombrar",
    "alfombrámos": "alfombrar",
    "alfombráramo": "alfombrar",
    "alfombráramos": "alfombrar",
    "alfombrárei": "alfombrar",
    "alfombráreis": "alfombrar",
    "alfombrásseis": "alfombrar",
    "alfombrássemos": "alfombrar",
    "alfombrávamo": "alfombrar",
    "alfombrávamos": "alfombrar",
    "alfombrávei": "alfombrar",
    "alfombráveis": "alfombrar",
    "alfonsias": "alfonsia",
    "alfonsiis": "alfonsil",
    "alforbas": "alforba",
    "alforfas": "alforfa",
    "alforgeira": "alforgeiro",
    "alforgeiras": "alforgeiro",
    "alforgeiros": "alforgeiro",
    "alforges": "alforge",
    "alforja": "alforjar",
    "alforjada": "alforjar",
    "alforjadas": "alforjar",
    "alforjado": "alforjar",
    "alforjados": "alforjar",
    "alforjai": "alforjar",
    "alforjais": "alforjar",
    "alforjam": "alforjar",
    "alforjamo": "alforjar",
    "alforjamos": "alforjar",
    "alforjando": "alforjar",
    "alforjara": "alforjar",
    "alforjaram": "alforjar",
    "alforjaras": "alforjar",
    "alforjarde": "alforjar",
    "alforjardes": "alforjar",
    "alforjare": "alforjar",
    "alforjarei": "alforjar",
    "alforjareis": "alforjar",
    "alforjarem": "alforjar",
    "alforjaremos": "alforjar",
    "alforjares": "alforjar",
    "alforjaria": "alforjar",
    "alforjariam": "alforjar",
    "alforjarias": "alforjar",
    "alforjarmo": "alforjar",
    "alforjarmos": "alforjar",
    "alforjará": "alforjar",
    "alforjarás": "alforjar",
    "alforjarão": "alforjar",
    "alforjaríamos": "alforjar",
    "alforjaríeis": "alforjar",
    "alforjas": "alforjar",
    "alforjasse": "alforjar",
    "alforjassem": "alforjar",
    "alforjasses": "alforjar",
    "alforjaste": "alforjar",
    "alforjastes": "alforjar",
    "alforjava": "alforjar",
    "alforjavam": "alforjar",
    "alforjavas": "alforjar",
    "alforje": "alforjar",
    "alforjei": "alforjar",
    "alforjeis": "alforjar",
    "alforjem": "alforjar",
    "alforjemo": "alforjar",
    "alforjemos": "alforjar",
    "alforjes": "alforjar",
    "alforjo": "alforjar",
    "alforjou": "alforjar",
    "alforjá": "alforjar",
    "alforjámo": "alforjar",
    "alforjámos": "alforjar",
    "alforjáramo": "alforjar",
    "alforjáramos": "alforjar",
    "alforjárei": "alforjar",
    "alforjáreis": "alforjar",
    "alforjásseis": "alforjar",
    "alforjássemos": "alforjar",
    "alforjávamo": "alforjar",
    "alforjávamos": "alforjar",
    "alforjávei": "alforjar",
    "alforjáveis": "alforjar",
    "alforques": "alforque",
    "alforra": "alforrar",
    "alforrada": "alforrar",
    "alforradas": "alforrar",
    "alforrado": "alforrar",
    "alforrados": "alforrar",
    "alforrai": "alforrar",
    "alforrais": "alforrar",
    "alforram": "alforrar",
    "alforramo": "alforrar",
    "alforramos": "alforrar",
    "alforrando": "alforrar",
    "alforrara": "alforrar",
    "alforraram": "alforrar",
    "alforraras": "alforrar",
    "alforrardes": "alforrar",
    "alforrarei": "alforrar",
    "alforrareis": "alforrar",
    "alforrarem": "alforrar",
    "alforraremos": "alforrar",
    "alforrares": "alforrar",
    "alforraria": "alforrar",
    "alforrariam": "alforrar",
    "alforrarias": "alforrar",
    "alforrarmo": "alforrar",
    "alforrarmos": "alforrar",
    "alforrará": "alforrar",
    "alforrarás": "alforrar",
    "alforrarão": "alforrar",
    "alforraríamos": "alforrar",
    "alforraríeis": "alforrar",
    "alforras": "alforrar",
    "alforrasse": "alforrar",
    "alforrassem": "alforrar",
    "alforrasses": "alforrar",
    "alforraste": "alforrar",
    "alforrastes": "alforrar",
    "alforrava": "alforrar",
    "alforravam": "alforrar",
    "alforravas": "alforrar",
    "alforre": "alforrar",
    "alforrecas": "alforreca",
    "alforrei": "alforrar",
    "alforreis": "alforrar",
    "alforrem": "alforrar",
    "alforremo": "alforrar",
    "alforremos": "alforrar",
    "alforres": "alforrar",
    "alforria": "alforriar",
    "alforriada": "alforriar",
    "alforriadas": "alforriar",
    "alforriado": "alforriar",
    "alforriados": "alforriar",
    "alforriai": "alforriar",
    "alforriais": "alforriar",
    "alforriam": "alforriar",
    "alforriamo": "alforriar",
    "alforriamos": "alforriar",
    "alforriando": "alforriar",
    "alforriara": "alforriar",
    "alforriaram": "alforriar",
    "alforriaras": "alforriar",
    "alforriarde": "alforriar",
    "alforriardes": "alforriar",
    "alforriare": "alforriar",
    "alforriarei": "alforriar",
    "alforriareis": "alforriar",
    "alforriarem": "alforriar",
    "alforriaremos": "alforriar",
    "alforriares": "alforriar",
    "alforriaria": "alforriar",
    "alforriariam": "alforriar",
    "alforriarias": "alforriar",
    "alforriarmo": "alforriar",
    "alforriarmos": "alforriar",
    "alforriará": "alforriar",
    "alforriarás": "alforriar",
    "alforriarão": "alforriar",
    "alforriaríamos": "alforriar",
    "alforriaríeis": "alforriar",
    "alforrias": "alforriar",
    "alforriasse": "alforriar",
    "alforriassem": "alforriar",
    "alforriasses": "alforriar",
    "alforriaste": "alforriar",
    "alforriastes": "alforriar",
    "alforriava": "alforriar",
    "alforriavam": "alforriar",
    "alforriavas": "alforriar",
    "alforrie": "alforriar",
    "alforriei": "alforriar",
    "alforrieis": "alforriar",
    "alforriem": "alforriar",
    "alforriemo": "alforriar",
    "alforriemos": "alforriar",
    "alforries": "alforriar",
    "alforrio": "alforriar",
    "alforriou": "alforriar",
    "alforriá": "alforriar",
    "alforriámo": "alforriar",
    "alforriámos": "alforriar",
    "alforriáramo": "alforriar",
    "alforriáramos": "alforriar",
    "alforriárei": "alforriar",
    "alforriáreis": "alforriar",
    "alforriásseis": "alforriar",
    "alforriássemos": "alforriar",
    "alforriávamo": "alforriar",
    "alforriávamos": "alforriar",
    "alforriávei": "alforriar",
    "alforriáveis": "alforriar",
    "alforro": "alforrar",
    "alforrou": "alforrar",
    "alforrámo": "alforrar",
    "alforrámos": "alforrar",
    "alforráramo": "alforrar",
    "alforráramos": "alforrar",
    "alforráreis": "alforrar",
    "alforrásseis": "alforrar",
    "alforrássemos": "alforrar",
    "alforrávamo": "alforrar",
    "alforrávamos": "alforrar",
    "alforráveis": "alforrar",
    "alforvas": "alforva",
    "alfou": "alfar",
    "alfozes": "alfoz",
    "alfridárias": "alfridária",
    "alfrocheiras": "alfrocheira",
    "alfrocheiros": "alfrocheiro",
    "alfurjas": "alfurja",
    "alfusqueiros": "alfusqueiro",
    "alfá": "alfar",
    "alfádegas": "alfádega",
    "alfádigas": "alfádiga",
    "alfámo": "alfar",
    "alfámos": "alfar",
    "alfáramo": "alfar",
    "alfáramos": "alfar",
    "alfárei": "alfar",
    "alfáreis": "alfar",
    "alfásseis": "alfar",
    "alfássemos": "alfar",
    "alfávamo": "alfar",
    "alfávamos": "alfar",
    "alfávegas": "alfávega",
    "alfávei": "alfar",
    "alfáveis": "alfar",
    "alfândegas": "alfândega",
    "alféloas": "alféloa",
    "alfénica": "alfénico",
    "alfénicas": "alfénico",
    "alfénicos": "alfénico",
    "alfênicos": "alfênico",
    "algalia": "algaliar",
    "algaliada": "algaliar",
    "algaliadas": "algaliar",
    "algaliado": "algaliar",
    "algaliados": "algaliar",
    "algaliai": "algaliar",
    "algaliais": "algaliar",
    "algaliam": "algaliar",
    "algaliamo": "algaliar",
    "algaliamos": "algaliar",
    "algaliando": "algaliar",
    "algaliara": "algaliar",
    "algaliaram": "algaliar",
    "algaliaras": "algaliar",
    "algaliarde": "algaliar",
    "algaliardes": "algaliar",
    "algaliare": "algaliar",
    "algaliarei": "algaliar",
    "algaliareis": "algaliar",
    "algaliarem": "algaliar",
    "algaliaremos": "algaliar",
    "algaliares": "algaliar",
    "algaliaria": "algaliar",
    "algaliariam": "algaliar",
    "algaliarias": "algaliar",
    "algaliarmo": "algaliar",
    "algaliarmos": "algaliar",
    "algaliará": "algaliar",
    "algaliarás": "algaliar",
    "algaliarão": "algaliar",
    "algaliaríamos": "algaliar",
    "algaliaríeis": "algaliar",
    "algalias": "algaliar",
    "algaliasse": "algaliar",
    "algaliassem": "algaliar",
    "algaliasses": "algaliar",
    "algaliaste": "algaliar",
    "algaliastes": "algaliar",
    "algaliava": "algaliar",
    "algaliavam": "algaliar",
    "algaliavas": "algaliar",
    "algaliações": "algaliação",
    "algalie": "algaliar",
    "algaliei": "algaliar",
    "algalieis": "algaliar",
    "algaliem": "algaliar",
    "algaliemo": "algaliar",
    "algaliemos": "algaliar",
    "algalies": "algaliar",
    "algalio": "algaliar",
    "algaliou": "algaliar",
    "algaliá": "algaliar",
    "algaliámo": "algaliar",
    "algaliámos": "algaliar",
    "algaliáramo": "algaliar",
    "algaliáramos": "algaliar",
    "algaliárei": "algaliar",
    "algaliáreis": "algaliar",
    "algaliásseis": "algaliar",
    "algaliássemos": "algaliar",
    "algaliávamo": "algaliar",
    "algaliávamos": "algaliar",
    "algaliávei": "algaliar",
    "algaliáveis": "algaliar",
    "algalosa": "algaloso",
    "algalosas": "algaloso",
    "algalosos": "algaloso",
    "algaradas": "algarada",
    "algaras": "algara",
    "algaravia": "algaraviar",
    "algaraviada": "algaraviar",
    "algaraviadas": "algaraviar",
    "algaraviado": "algaraviar",
    "algaraviados": "algaraviar",
    "algaraviai": "algaraviar",
    "algaraviais": "algaraviar",
    "algaraviam": "algaraviar",
    "algaraviamo": "algaraviar",
    "algaraviamos": "algaraviar",
    "algaraviando": "algaraviar",
    "algaraviara": "algaraviar",
    "algaraviaram": "algaraviar",
    "algaraviaras": "algaraviar",
    "algaraviardes": "algaraviar",
    "algaraviarei": "algaraviar",
    "algaraviareis": "algaraviar",
    "algaraviarem": "algaraviar",
    "algaraviaremos": "algaraviar",
    "algaraviares": "algaraviar",
    "algaraviaria": "algaraviar",
    "algaraviariam": "algaraviar",
    "algaraviarias": "algaraviar",
    "algaraviarmo": "algaraviar",
    "algaraviarmos": "algaraviar",
    "algaraviará": "algaraviar",
    "algaraviarás": "algaraviar",
    "algaraviarão": "algaraviar",
    "algaraviaríamos": "algaraviar",
    "algaraviaríeis": "algaraviar",
    "algaravias": "algaraviar",
    "algaraviasse": "algaraviar",
    "algaraviassem": "algaraviar",
    "algaraviasses": "algaraviar",
    "algaraviaste": "algaraviar",
    "algaraviastes": "algaraviar",
    "algaraviava": "algaraviar",
    "algaraviavam": "algaraviar",
    "algaraviavas": "algaraviar",
    "algaravie": "algaraviar",
    "algaraviei": "algaraviar",
    "algaravieis": "algaraviar",
    "algaraviem": "algaraviar",
    "algaraviemo": "algaraviar",
    "algaraviemos": "algaraviar",
    "algaravies": "algaraviar",
    "algaravio": "algaraviar",
    "algaraviou": "algaraviar",
    "algaraviámo": "algaraviar",
    "algaraviámos": "algaraviar",
    "algaraviáramo": "algaraviar",
    "algaraviáramos": "algaraviar",
    "algaraviáreis": "algaraviar",
    "algaraviásseis": "algaraviar",
    "algaraviássemos": "algaraviar",
    "algaraviávamo": "algaraviar",
    "algaraviávamos": "algaraviar",
    "algaraviáveis": "algaraviar",
    "algarbes": "algarbe",
    "algarbitos": "algarbito",
    "algarejos": "algarejo",
    "algares": "algar",
    "algarismos": "algarismo",
    "algariças": "algariça",
    "algarochos": "algarocho",
    "algarradas": "algarrada",
    "algarvia": "algarvio",
    "algarvias": "algarvio",
    "algarvienses": "algarviense",
    "algarvios": "algarvio",
    "algarvismos": "algarvismo",
    "algarvites": "algarvite",
    "algas": "alga",
    "algazarra": "algazarrar",
    "algazarrada": "algazarrar",
    "algazarradas": "algazarrar",
    "algazarrado": "algazarrar",
    "algazarrados": "algazarrar",
    "algazarrai": "algazarrar",
    "algazarrais": "algazarrar",
    "algazarram": "algazarrar",
    "algazarramo": "algazarrar",
    "algazarramos": "algazarrar",
    "algazarrando": "algazarrar",
    "algazarrara": "algazarrar",
    "algazarraram": "algazarrar",
    "algazarraras": "algazarrar",
    "algazarrardes": "algazarrar",
    "algazarrarei": "algazarrar",
    "algazarrareis": "algazarrar",
    "algazarrarem": "algazarrar",
    "algazarraremos": "algazarrar",
    "algazarrares": "algazarrar",
    "algazarraria": "algazarrar",
    "algazarrariam": "algazarrar",
    "algazarrarias": "algazarrar",
    "algazarrarmo": "algazarrar",
    "algazarrarmos": "algazarrar",
    "algazarrará": "algazarrar",
    "algazarrarás": "algazarrar",
    "algazarrarão": "algazarrar",
    "algazarraríamos": "algazarrar",
    "algazarraríeis": "algazarrar",
    "algazarras": "algazarrar",
    "algazarrasse": "algazarrar",
    "algazarrassem": "algazarrar",
    "algazarrasses": "algazarrar",
    "algazarraste": "algazarrar",
    "algazarrastes": "algazarrar",
    "algazarrava": "algazarrar",
    "algazarravam": "algazarrar",
    "algazarravas": "algazarrar",
    "algazarre": "algazarrar",
    "algazarreada": "algazarrear",
    "algazarreadas": "algazarrear",
    "algazarreado": "algazarrear",
    "algazarreados": "algazarrear",
    "algazarreai": "algazarrear",
    "algazarreais": "algazarrear",
    "algazarreamo": "algazarrear",
    "algazarreamos": "algazarrear",
    "algazarreando": "algazarrear",
    "algazarreara": "algazarrear",
    "algazarrearam": "algazarrear",
    "algazarrearas": "algazarrear",
    "algazarreardes": "algazarrear",
    "algazarrearei": "algazarrear",
    "algazarreareis": "algazarrear",
    "algazarrearem": "algazarrear",
    "algazarrearemos": "algazarrear",
    "algazarreares": "algazarrear",
    "algazarrearia": "algazarrear",
    "algazarreariam": "algazarrear",
    "algazarrearias": "algazarrear",
    "algazarrearmo": "algazarrear",
    "algazarrearmos": "algazarrear",
    "algazarreará": "algazarrear",
    "algazarrearás": "algazarrear",
    "algazarrearão": "algazarrear",
    "algazarrearíamos": "algazarrear",
    "algazarrearíeis": "algazarrear",
    "algazarreasse": "algazarrear",
    "algazarreassem": "algazarrear",
    "algazarreasses": "algazarrear",
    "algazarreaste": "algazarrear",
    "algazarreastes": "algazarrear",
    "algazarreava": "algazarrear",
    "algazarreavam": "algazarrear",
    "algazarreavas": "algazarrear",
    "algazarreei": "algazarrear",
    "algazarreeis": "algazarrear",
    "algazarreemo": "algazarrear",
    "algazarreemos": "algazarrear",
    "algazarrei": "algazarrar",
    "algazarreia": "algazarrear",
    "algazarreiam": "algazarrear",
    "algazarreias": "algazarrear",
    "algazarreie": "algazarrear",
    "algazarreiem": "algazarrear",
    "algazarreies": "algazarrear",
    "algazarreio": "algazarrear",
    "algazarreis": "algazarrar",
    "algazarrem": "algazarrar",
    "algazarremo": "algazarrar",
    "algazarremos": "algazarrar",
    "algazarreou": "algazarrear",
    "algazarres": "algazarrar",
    "algazarreámo": "algazarrear",
    "algazarreámos": "algazarrear",
    "algazarreáramo": "algazarrear",
    "algazarreáramos": "algazarrear",
    "algazarreáreis": "algazarrear",
    "algazarreásseis": "algazarrear",
    "algazarreássemos": "algazarrear",
    "algazarreávamo": "algazarrear",
    "algazarreávamos": "algazarrear",
    "algazarreáveis": "algazarrear",
    "algazarro": "algazarrar",
    "algazarrou": "algazarrar",
    "algazarrámo": "algazarrar",
    "algazarrámos": "algazarrar",
    "algazarráramo": "algazarrar",
    "algazarráramos": "algazarrar",
    "algazarráreis": "algazarrar",
    "algazarrásseis": "algazarrar",
    "algazarrássemos": "algazarrar",
    "algazarrávamo": "algazarrar",
    "algazarrávamos": "algazarrar",
    "algazarráveis": "algazarrar",
    "algazes": "algaz",
    "algaços": "algaço",
    "algebrados": "algebrado",
    "algebristas": "algebrista",
    "algebriza": "algebrizar",
    "algebrizada": "algebrizar",
    "algebrizadas": "algebrizar",
    "algebrizado": "algebrizar",
    "algebrizados": "algebrizar",
    "algebrizai": "algebrizar",
    "algebrizais": "algebrizar",
    "algebrizam": "algebrizar",
    "algebrizamo": "algebrizar",
    "algebrizamos": "algebrizar",
    "algebrizando": "algebrizar",
    "algebrizara": "algebrizar",
    "algebrizaram": "algebrizar",
    "algebrizaras": "algebrizar",
    "algebrizarde": "algebrizar",
    "algebrizardes": "algebrizar",
    "algebrizare": "algebrizar",
    "algebrizarei": "algebrizar",
    "algebrizareis": "algebrizar",
    "algebrizarem": "algebrizar",
    "algebrizaremos": "algebrizar",
    "algebrizares": "algebrizar",
    "algebrizaria": "algebrizar",
    "algebrizariam": "algebrizar",
    "algebrizarias": "algebrizar",
    "algebrizarmo": "algebrizar",
    "algebrizarmos": "algebrizar",
    "algebrizará": "algebrizar",
    "algebrizarás": "algebrizar",
    "algebrizarão": "algebrizar",
    "algebrizaríamos": "algebrizar",
    "algebrizaríeis": "algebrizar",
    "algebrizas": "algebrizar",
    "algebrizasse": "algebrizar",
    "algebrizassem": "algebrizar",
    "algebrizasses": "algebrizar",
    "algebrizaste": "algebrizar",
    "algebrizastes": "algebrizar",
    "algebrizava": "algebrizar",
    "algebrizavam": "algebrizar",
    "algebrizavas": "algebrizar",
    "algebrize": "algebrizar",
    "algebrizei": "algebrizar",
    "algebrizeis": "algebrizar",
    "algebrizem": "algebrizar",
    "algebrizemo": "algebrizar",
    "algebrizemos": "algebrizar",
    "algebrizes": "algebrizar",
    "algebrizo": "algebrizar",
    "algebrizou": "algebrizar",
    "algebrizá": "algebrizar",
    "algebrizámo": "algebrizar",
    "algebrizámos": "algebrizar",
    "algebrizáramo": "algebrizar",
    "algebrizáramos": "algebrizar",
    "algebrizárei": "algebrizar",
    "algebrizáreis": "algebrizar",
    "algebrizásseis": "algebrizar",
    "algebrizássemos": "algebrizar",
    "algebrizávamo": "algebrizar",
    "algebrizávamos": "algebrizar",
    "algebrizávei": "algebrizar",
    "algebrizáveis": "algebrizar",
    "algebrões": "algebrão",
    "algema": "algemar",
    "algemada": "algemar",
    "algemadas": "algemar",
    "algemado": "algemar",
    "algemados": "algemar",
    "algemai": "algemar",
    "algemais": "algemar",
    "algemam": "algemar",
    "algemamo": "algemar",
    "algemamos": "algemar",
    "algemando": "algemar",
    "algemara": "algemar",
    "algemaram": "algemar",
    "algemaras": "algemar",
    "algemarde": "algemar",
    "algemardes": "algemar",
    "algemare": "algemar",
    "algemarei": "algemar",
    "algemareis": "algemar",
    "algemarem": "algemar",
    "algemaremos": "algemar",
    "algemares": "algemar",
    "algemaria": "algemar",
    "algemariam": "algemar",
    "algemarias": "algemar",
    "algemarmo": "algemar",
    "algemarmos": "algemar",
    "algemará": "algemar",
    "algemarás": "algemar",
    "algemarão": "algemar",
    "algemaríamos": "algemar",
    "algemaríeis": "algemar",
    "algemas": "algemar",
    "algemasse": "algemar",
    "algemassem": "algemar",
    "algemasses": "algemar",
    "algemaste": "algemar",
    "algemastes": "algemar",
    "algemava": "algemar",
    "algemavam": "algemar",
    "algemavas": "algemar",
    "algeme": "algemar",
    "algemei": "algemar",
    "algemeis": "algemar",
    "algemem": "algemar",
    "algememo": "algemar",
    "algememos": "algemar",
    "algemes": "algemar",
    "algemias": "algemia",
    "algemo": "algemar",
    "algemou": "algemar",
    "algemá": "algemar",
    "algemámo": "algemar",
    "algemámos": "algemar",
    "algemáramo": "algemar",
    "algemáramos": "algemar",
    "algemárei": "algemar",
    "algemáreis": "algemar",
    "algemásseis": "algemar",
    "algemássemos": "algemar",
    "algemávamo": "algemar",
    "algemávamos": "algemar",
    "algemávei": "algemar",
    "algemáveis": "algemar",
    "algenis": "algenil",
    "algentes": "algente",
    "algerifes": "algerife",
    "algerozes": "algeroz",
    "algesias": "algesia",
    "algesímetros": "algesímetro",
    "algias": "algia",
    "algibebes": "algibebe",
    "algibeiras": "algibeira",
    "algibes": "algibe",
    "algidezes": "algidez",
    "alginas": "algina",
    "algirões": "algirão",
    "algodoais": "algodoal",
    "algodoarias": "algodoaria",
    "algodoeiros": "algodoeiro",
    "algodoins": "algodoim",
    "algodãozinho": "algodão",
    "algodãozito": "algodão",
    "algodões": "algodão",
    "algodõezinhos": "algodão",
    "algodõezitos": "algodão",
    "algofilias": "algofilia",
    "algofobias": "algofobia",
    "algolagnias": "algolagnia",
    "algolanias": "algolania",
    "algologias": "algologia",
    "algologistas": "algologista",
    "algológica": "algológico",
    "algológicas": "algológico",
    "algológicos": "algológico",
    "algomanias": "algomania",
    "algonquiana": "algonquiano",
    "algonquianas": "algonquiano",
    "algonquianos": "algonquiano",
    "algonquina": "algonquino",
    "algonquinas": "algonquino",
    "algonquinos": "algonquino",
    "algores": "algor",
    "algoritmias": "algoritmia",
    "algoritmos": "algoritmo",
    "algorítmica": "algorítmico",
    "algorítmicas": "algorítmico",
    "algorítmicos": "algorítmico",
    "algospasmos": "algospasmo",
    "algoza": "algozar",
    "algozada": "algozar",
    "algozadas": "algozar",
    "algozado": "algozar",
    "algozados": "algozar",
    "algozai": "algozar",
    "algozais": "algozar",
    "algozam": "algozar",
    "algozamo": "algozar",
    "algozamos": "algozar",
    "algozando": "algozar",
    "algozara": "algozar",
    "algozaram": "algozar",
    "algozaras": "algozar",
    "algozarde": "algozar",
    "algozardes": "algozar",
    "algozare": "algozar",
    "algozarei": "algozar",
    "algozareis": "algozar",
    "algozarem": "algozar",
    "algozaremos": "algozar",
    "algozares": "algozar",
    "algozaria": "algozar",
    "algozariam": "algozar",
    "algozarias": "algozaria",
    "algozarmo": "algozar",
    "algozarmos": "algozar",
    "algozará": "algozar",
    "algozarás": "algozar",
    "algozarão": "algozar",
    "algozaríamos": "algozar",
    "algozaríeis": "algozar",
    "algozas": "algozar",
    "algozasse": "algozar",
    "algozassem": "algozar",
    "algozasses": "algozar",
    "algozaste": "algozar",
    "algozastes": "algozar",
    "algozava": "algozar",
    "algozavam": "algozar",
    "algozavas": "algozar",
    "algoze": "algozar",
    "algozei": "algozar",
    "algozeis": "algozar",
    "algozem": "algozar",
    "algozemo": "algozar",
    "algozemos": "algozar",
    "algozes": "algozar",
    "algozo": "algozar",
    "algozou": "algozar",
    "algozá": "algozar",
    "algozámo": "algozar",
    "algozámos": "algozar",
    "algozáramo": "algozar",
    "algozáramos": "algozar",
    "algozárei": "algozar",
    "algozáreis": "algozar",
    "algozásseis": "algozar",
    "algozássemos": "algozar",
    "algozávamo": "algozar",
    "algozávamos": "algozar",
    "algozávei": "algozar",
    "algozáveis": "algozar",
    "algrabes": "algrabe",
    "algrames": "algrame",
    "algraviadas": "algraviada",
    "algravias": "algravia",
    "algravões": "algravão",
    "algrebes": "algrebe",
    "algremes": "algreme",
    "algrubões": "algrubão",
    "alguerbes": "alguerbe",
    "alguerga": "alguergar",
    "alguergada": "alguergar",
    "alguergadas": "alguergar",
    "alguergado": "alguergar",
    "alguergados": "alguergar",
    "alguergai": "alguergar",
    "alguergais": "alguergar",
    "alguergam": "alguergar",
    "alguergamo": "alguergar",
    "alguergamos": "alguergar",
    "alguergando": "alguergar",
    "alguergara": "alguergar",
    "alguergaram": "alguergar",
    "alguergaras": "alguergar",
    "alguergarde": "alguergar",
    "alguergardes": "alguergar",
    "alguergare": "alguergar",
    "alguergarei": "alguergar",
    "alguergareis": "alguergar",
    "alguergarem": "alguergar",
    "alguergaremos": "alguergar",
    "alguergares": "alguergar",
    "alguergaria": "alguergar",
    "alguergariam": "alguergar",
    "alguergarias": "alguergar",
    "alguergarmo": "alguergar",
    "alguergarmos": "alguergar",
    "alguergará": "alguergar",
    "alguergarás": "alguergar",
    "alguergarão": "alguergar",
    "alguergaríamos": "alguergar",
    "alguergaríeis": "alguergar",
    "alguergas": "alguergar",
    "alguergasse": "alguergar",
    "alguergassem": "alguergar",
    "alguergasses": "alguergar",
    "alguergaste": "alguergar",
    "alguergastes": "alguergar",
    "alguergava": "alguergar",
    "alguergavam": "alguergar",
    "alguergavas": "alguergar",
    "alguergo": "alguergar",
    "alguergou": "alguergar",
    "alguergue": "alguergar",
    "alguerguei": "alguergar",
    "alguergueis": "alguergar",
    "alguerguem": "alguergar",
    "alguerguemo": "alguergar",
    "alguerguemos": "alguergar",
    "alguergues": "alguergue",
    "alguergá": "alguergar",
    "alguergámo": "alguergar",
    "alguergámos": "alguergar",
    "alguergáramo": "alguergar",
    "alguergáramos": "alguergar",
    "alguergárei": "alguergar",
    "alguergáreis": "alguergar",
    "alguergásseis": "alguergar",
    "alguergássemos": "alguergar",
    "alguergávamo": "alguergar",
    "alguergávamos": "alguergar",
    "alguergávei": "alguergar",
    "alguergáveis": "alguergar",
    "alguidaradas": "alguidarada",
    "alguidares": "alguidar",
    "alguirradeiras": "alguirradeira",
    "alguma": "algum",
    "algumas": "algum",
    "alguns": "algum",
    "algácea": "algáceo",
    "algáceas": "algáceo",
    "algáceos": "algáceo",
    "algálias": "algália",
    "algébrica": "algébrico",
    "algébricas": "algébrico",
    "algébricos": "algébrico",
    "algófila": "algófilo",
    "algófilas": "algófilo",
    "algófilos": "algófilo",
    "algófoba": "algófobo",
    "algófobas": "algófobo",
    "algófobos": "algófobo",
    "algóis": "algol",
    "algóloga": "algólogo",
    "algólogas": "algólogo",
    "algólogos": "algólogo",
    "algómana": "algómano",
    "algómanas": "algómano",
    "algómanos": "algómano",
    "algônquica": "algônquico",
    "algônquicas": "algônquico",
    "algônquicos": "algônquico",
    "alha": "alho",
    "alhadas": "alhada",
    "alhais": "alhal",
    "alhana": "alhanar",
    "alhanada": "alhanar",
    "alhanadas": "alhanar",
    "alhanado": "alhanar",
    "alhanados": "alhanar",
    "alhanai": "alhanar",
    "alhanais": "alhanar",
    "alhanam": "alhanar",
    "alhanamo": "alhanar",
    "alhanamos": "alhanar",
    "alhanando": "alhanar",
    "alhanara": "alhanar",
    "alhanaram": "alhanar",
    "alhanaras": "alhanar",
    "alhanarde": "alhanar",
    "alhanardes": "alhanar",
    "alhanare": "alhanar",
    "alhanarei": "alhanar",
    "alhanareis": "alhanar",
    "alhanarem": "alhanar",
    "alhanaremos": "alhanar",
    "alhanares": "alhanar",
    "alhanaria": "alhanar",
    "alhanariam": "alhanar",
    "alhanarias": "alhanar",
    "alhanarmo": "alhanar",
    "alhanarmos": "alhanar",
    "alhanará": "alhanar",
    "alhanarás": "alhanar",
    "alhanarão": "alhanar",
    "alhanaríamos": "alhanar",
    "alhanaríeis": "alhanar",
    "alhanas": "alhanar",
    "alhanasse": "alhanar",
    "alhanassem": "alhanar",
    "alhanasses": "alhanar",
    "alhanaste": "alhanar",
    "alhanastes": "alhanar",
    "alhanava": "alhanar",
    "alhanavam": "alhanar",
    "alhanavas": "alhanar",
    "alhandrenses": "alhandrense",
    "alhane": "alhanar",
    "alhanei": "alhanar",
    "alhaneis": "alhanar",
    "alhanem": "alhanar",
    "alhanemo": "alhanar",
    "alhanemos": "alhanar",
    "alhanes": "alhanar",
    "alhano": "alhanar",
    "alhanou": "alhanar",
    "alhaná": "alhanar",
    "alhanámo": "alhanar",
    "alhanámos": "alhanar",
    "alhanáramo": "alhanar",
    "alhanáramos": "alhanar",
    "alhanárei": "alhanar",
    "alhanáreis": "alhanar",
    "alhanásseis": "alhanar",
    "alhanássemos": "alhanar",
    "alhanávamo": "alhanar",
    "alhanávamos": "alhanar",
    "alhanávei": "alhanar",
    "alhanáveis": "alhanar",
    "alhas": "alho",
    "alhazinha": "alho",
    "alhazinhas": "alho",
    "alhazita": "alho",
    "alhazitas": "alho",
    "alheabilidades": "alheabilidade",
    "alheada": "alhear",
    "alheadas": "alhear",
    "alheado": "alhear",
    "alheadora": "alheador",
    "alheadoras": "alheador",
    "alheadores": "alheador",
    "alheados": "alhear",
    "alheadíssima": "alheado",
    "alheadíssimas": "alheado",
    "alheadíssimo": "alheado",
    "alheadíssimos": "alheado",
    "alheai": "alhear",
    "alheais": "alhear",
    "alheamentos": "alheamento",
    "alheamo": "alhear",
    "alheamos": "alhear",
    "alheando": "alhear",
    "alheara": "alhear",
    "alhearam": "alhear",
    "alhearas": "alhear",
    "alhearde": "alhear",
    "alheardes": "alhear",
    "alheare": "alhear",
    "alhearei": "alhear",
    "alheareis": "alhear",
    "alhearem": "alhear",
    "alhearemos": "alhear",
    "alheares": "alhear",
    "alhearia": "alhear",
    "alheariam": "alhear",
    "alhearias": "alhear",
    "alhearmo": "alhear",
    "alhearmos": "alhear",
    "alheará": "alhear",
    "alhearás": "alhear",
    "alhearão": "alhear",
    "alhearíamos": "alhear",
    "alhearíeis": "alhear",
    "alheasse": "alhear",
    "alheassem": "alhear",
    "alheasses": "alhear",
    "alheaste": "alhear",
    "alheastes": "alhear",
    "alheava": "alhear",
    "alheavam": "alhear",
    "alheavas": "alhear",
    "alheações": "alheação",
    "alheei": "alhear",
    "alheeis": "alhear",
    "alheemo": "alhear",
    "alheemos": "alhear",
    "alheia": "alheio",
    "alheiam": "alhear",
    "alheias": "alheio",
    "alheie": "alhear",
    "alheiem": "alhear",
    "alheies": "alhear",
    "alheio": "alhear",
    "alheios": "alheio",
    "alheira": "alheiro",
    "alheiras": "alheiro",
    "alheiros": "alheiro",
    "alhelas": "alhela",
    "alheou": "alhear",
    "alhetas": "alheta",
    "alheá": "alhear",
    "alheámo": "alhear",
    "alheámos": "alhear",
    "alheáramo": "alhear",
    "alheáramos": "alhear",
    "alheárei": "alhear",
    "alheáreis": "alhear",
    "alheásseis": "alhear",
    "alheássemos": "alhear",
    "alheávamo": "alhear",
    "alheávamos": "alhear",
    "alheávei": "alhear",
    "alheáveis": "alheável",
    "alhinha": "alho",
    "alhinhas": "alho",
    "alhinho": "alho",
    "alhinhos": "alho",
    "alhita": "alho",
    "alhitas": "alho",
    "alhito": "alho",
    "alhitos": "alho",
    "alhorcas": "alhorca",
    "alhos": "alho",
    "alhozinho": "alho",
    "alhozinhos": "alho",
    "alhozito": "alho",
    "alhozitos": "alho",
    "alia": "aliar",
    "aliada": "aliar",
    "aliadas": "aliar",
    "aliado": "aliar",
    "aliadofilias": "aliadofilia",
    "aliadofobias": "aliadofobia",
    "aliados": "aliar",
    "aliadófila": "aliadófilo",
    "aliadófilas": "aliadófilo",
    "aliadófilos": "aliadófilo",
    "aliadófoba": "aliadófobo",
    "aliadófobas": "aliadófobo",
    "aliadófobos": "aliadófobo",
    "aliagens": "aliagem",
    "aliai": "aliar",
    "aliais": "aliar",
    "aliam": "aliar",
    "aliamo": "aliar",
    "aliamos": "aliar",
    "aliance": "aliançar",
    "aliancei": "aliançar",
    "alianceis": "aliançar",
    "aliancem": "aliançar",
    "aliancemo": "aliançar",
    "aliancemos": "aliançar",
    "aliances": "aliançar",
    "aliando": "aliar",
    "aliança": "aliançar",
    "aliançada": "aliançar",
    "aliançadas": "aliançar",
    "aliançado": "aliançar",
    "aliançados": "aliançar",
    "aliançai": "aliançar",
    "aliançais": "aliançar",
    "aliançam": "aliançar",
    "aliançamo": "aliançar",
    "aliançamos": "aliançar",
    "aliançando": "aliançar",
    "aliançara": "aliançar",
    "aliançaram": "aliançar",
    "aliançaras": "aliançar",
    "aliançarde": "aliançar",
    "aliançardes": "aliançar",
    "aliançare": "aliançar",
    "aliançarei": "aliançar",
    "aliançareis": "aliançar",
    "aliançarem": "aliançar",
    "aliançaremos": "aliançar",
    "aliançares": "aliançar",
    "aliançaria": "aliançar",
    "aliançariam": "aliançar",
    "aliançarias": "aliançar",
    "aliançarmo": "aliançar",
    "aliançarmos": "aliançar",
    "aliançará": "aliançar",
    "aliançarás": "aliançar",
    "aliançarão": "aliançar",
    "aliançaríamos": "aliançar",
    "aliançaríeis": "aliançar",
    "alianças": "aliançar",
    "aliançasse": "aliançar",
    "aliançassem": "aliançar",
    "aliançasses": "aliançar",
    "aliançaste": "aliançar",
    "aliançastes": "aliançar",
    "aliançava": "aliançar",
    "aliançavam": "aliançar",
    "aliançavas": "aliançar",
    "alianço": "aliançar",
    "aliançou": "aliançar",
    "aliançá": "aliançar",
    "aliançámo": "aliançar",
    "aliançámos": "aliançar",
    "aliançáramo": "aliançar",
    "aliançáramos": "aliançar",
    "aliançárei": "aliançar",
    "aliançáreis": "aliançar",
    "aliançásseis": "aliançar",
    "aliançássemos": "aliançar",
    "aliançávamo": "aliançar",
    "aliançávamos": "aliançar",
    "aliançávei": "aliançar",
    "aliançáveis": "aliançar",
    "aliara": "aliar",
    "aliaram": "aliar",
    "aliaras": "aliar",
    "aliarde": "aliar",
    "aliardes": "aliar",
    "aliare": "aliar",
    "aliarei": "aliar",
    "aliareis": "aliar",
    "aliarem": "aliar",
    "aliaremos": "aliar",
    "aliares": "aliar",
    "aliaria": "aliar",
    "aliariam": "aliar",
    "aliarias": "aliar",
    "aliarmo": "aliar",
    "aliarmos": "aliar",
    "aliará": "aliar",
    "aliarás": "aliar",
    "aliarão": "aliar",
    "aliaríamos": "aliar",
    "aliaríeis": "aliar",
    "alias": "aliar",
    "aliasse": "aliar",
    "aliassem": "aliar",
    "aliasses": "aliar",
    "aliaste": "aliar",
    "aliastes": "aliar",
    "aliava": "aliar",
    "aliavam": "aliar",
    "aliavas": "aliar",
    "aliazares": "aliazar",
    "alibilidades": "alibilidade",
    "alibis": "alibi",
    "alicantes": "alicante",
    "alicantina": "alicantino",
    "alicantinadora": "alicantinador",
    "alicantinadoras": "alicantinador",
    "alicantinadores": "alicantinador",
    "alicantinas": "alicantino",
    "alicantineira": "alicantineiro",
    "alicantineiras": "alicantineiro",
    "alicantineiros": "alicantineiro",
    "alicantinos": "alicantino",
    "alicates": "alicate",
    "alicatões": "alicatão",
    "alicaída": "alicaído",
    "alicaídas": "alicaído",
    "alicaídos": "alicaído",
    "alicerce": "alicerçar",
    "alicerceada": "alicercear",
    "alicerceadas": "alicercear",
    "alicerceado": "alicercear",
    "alicerceados": "alicercear",
    "alicerceai": "alicercear",
    "alicerceais": "alicercear",
    "alicerceamo": "alicercear",
    "alicerceamos": "alicercear",
    "alicerceando": "alicercear",
    "alicerceara": "alicercear",
    "alicercearam": "alicercear",
    "alicercearas": "alicercear",
    "alicercearde": "alicercear",
    "alicerceardes": "alicercear",
    "alicerceare": "alicercear",
    "alicercearei": "alicercear",
    "alicerceareis": "alicercear",
    "alicercearem": "alicercear",
    "alicercearemos": "alicercear",
    "alicerceares": "alicercear",
    "alicercearia": "alicercear",
    "alicerceariam": "alicercear",
    "alicercearias": "alicercear",
    "alicercearmo": "alicercear",
    "alicercearmos": "alicercear",
    "alicerceará": "alicercear",
    "alicercearás": "alicercear",
    "alicercearão": "alicercear",
    "alicercearíamos": "alicercear",
    "alicercearíeis": "alicercear",
    "alicerceasse": "alicercear",
    "alicerceassem": "alicercear",
    "alicerceasses": "alicercear",
    "alicerceaste": "alicercear",
    "alicerceastes": "alicercear",
    "alicerceava": "alicercear",
    "alicerceavam": "alicercear",
    "alicerceavas": "alicercear",
    "alicerceei": "alicercear",
    "alicerceeis": "alicercear",
    "alicerceemo": "alicercear",
    "alicerceemos": "alicercear",
    "alicercei": "alicerçar",
    "alicerceia": "alicercear",
    "alicerceiam": "alicercear",
    "alicerceias": "alicercear",
    "alicerceie": "alicercear",
    "alicerceiem": "alicercear",
    "alicerceies": "alicercear",
    "alicerceio": "alicercear",
    "alicerceis": "alicerçar",
    "alicercem": "alicerçar",
    "alicercemo": "alicerçar",
    "alicercemos": "alicerçar",
    "alicerceou": "alicercear",
    "alicerces": "alicerce",
    "alicerceá": "alicercear",
    "alicerceámo": "alicercear",
    "alicerceámos": "alicercear",
    "alicerceáramo": "alicercear",
    "alicerceáramos": "alicercear",
    "alicerceárei": "alicercear",
    "alicerceáreis": "alicercear",
    "alicerceásseis": "alicercear",
    "alicerceássemos": "alicercear",
    "alicerceávamo": "alicercear",
    "alicerceávamos": "alicercear",
    "alicerceávei": "alicercear",
    "alicerceáveis": "alicercear",
    "alicerça": "alicerçar",
    "alicerçada": "alicerçar",
    "alicerçadas": "alicerçar",
    "alicerçado": "alicerçar",
    "alicerçados": "alicerçar",
    "alicerçai": "alicerçar",
    "alicerçais": "alicerçar",
    "alicerçam": "alicerçar",
    "alicerçamo": "alicerçar",
    "alicerçamos": "alicerçar",
    "alicerçando": "alicerçar",
    "alicerçara": "alicerçar",
    "alicerçaram": "alicerçar",
    "alicerçaras": "alicerçar",
    "alicerçarde": "alicerçar",
    "alicerçardes": "alicerçar",
    "alicerçare": "alicerçar",
    "alicerçarei": "alicerçar",
    "alicerçareis": "alicerçar",
    "alicerçarem": "alicerçar",
    "alicerçaremos": "alicerçar",
    "alicerçares": "alicerçar",
    "alicerçaria": "alicerçar",
    "alicerçariam": "alicerçar",
    "alicerçarias": "alicerçar",
    "alicerçarmo": "alicerçar",
    "alicerçarmos": "alicerçar",
    "alicerçará": "alicerçar",
    "alicerçarás": "alicerçar",
    "alicerçarão": "alicerçar",
    "alicerçaríamos": "alicerçar",
    "alicerçaríeis": "alicerçar",
    "alicerças": "alicerçar",
    "alicerçasse": "alicerçar",
    "alicerçassem": "alicerçar",
    "alicerçasses": "alicerçar",
    "alicerçaste": "alicerçar",
    "alicerçastes": "alicerçar",
    "alicerçava": "alicerçar",
    "alicerçavam": "alicerçar",
    "alicerçavas": "alicerçar",
    "alicerço": "alicerçar",
    "alicerçou": "alicerçar",
    "alicerçá": "alicerçar",
    "alicerçámo": "alicerçar",
    "alicerçámos": "alicerçar",
    "alicerçáramo": "alicerçar",
    "alicerçáramos": "alicerçar",
    "alicerçárei": "alicerçar",
    "alicerçáreis": "alicerçar",
    "alicerçásseis": "alicerçar",
    "alicerçássemos": "alicerçar",
    "alicerçávamo": "alicerçar",
    "alicerçávamos": "alicerçar",
    "alicerçávei": "alicerçar",
    "alicerçáveis": "alicerçar",
    "alicia": "aliciar",
    "aliciada": "aliciar",
    "aliciadas": "aliciar",
    "aliciado": "aliciar",
    "aliciadora": "aliciador",
    "aliciadoras": "aliciador",
    "aliciadores": "aliciador",
    "aliciados": "aliciar",
    "aliciadíssima": "aliciado",
    "aliciadíssimas": "aliciado",
    "aliciadíssimo": "aliciado",
    "aliciadíssimos": "aliciado",
    "aliciai": "aliciar",
    "aliciais": "aliciar",
    "aliciam": "aliciar",
    "aliciamentos": "aliciamento",
    "aliciamo": "aliciar",
    "aliciamos": "aliciar",
    "aliciando": "aliciar",
    "aliciantes": "aliciante",
    "aliciara": "aliciar",
    "aliciaram": "aliciar",
    "aliciaras": "aliciar",
    "aliciarde": "aliciar",
    "aliciardes": "aliciar",
    "aliciare": "aliciar",
    "aliciarei": "aliciar",
    "aliciareis": "aliciar",
    "aliciarem": "aliciar",
    "aliciaremos": "aliciar",
    "aliciares": "aliciar",
    "aliciaria": "aliciar",
    "aliciariam": "aliciar",
    "aliciarias": "aliciar",
    "aliciarmo": "aliciar",
    "aliciarmos": "aliciar",
    "aliciará": "aliciar",
    "aliciarás": "aliciar",
    "aliciarão": "aliciar",
    "aliciaríamos": "aliciar",
    "aliciaríeis": "aliciar",
    "alicias": "aliciar",
    "aliciasse": "aliciar",
    "aliciassem": "aliciar",
    "aliciasses": "aliciar",
    "aliciaste": "aliciar",
    "aliciastes": "aliciar",
    "aliciava": "aliciar",
    "aliciavam": "aliciar",
    "aliciavas": "aliciar",
    "aliciações": "aliciação",
    "alicie": "aliciar",
    "aliciei": "aliciar",
    "alicieis": "aliciar",
    "aliciem": "aliciar",
    "aliciemo": "aliciar",
    "aliciemos": "aliciar",
    "alicientes": "aliciente",
    "alicies": "aliciar",
    "alicio": "aliciar",
    "aliciou": "aliciar",
    "aliciá": "aliciar",
    "aliciámo": "aliciar",
    "aliciámos": "aliciar",
    "aliciáramo": "aliciar",
    "aliciáramos": "aliciar",
    "aliciárei": "aliciar",
    "aliciáreis": "aliciar",
    "aliciásseis": "aliciar",
    "aliciássemos": "aliciar",
    "aliciávamo": "aliciar",
    "aliciávamos": "aliciar",
    "aliciávei": "aliciar",
    "aliciáveis": "aliciável",
    "alicária": "alicário",
    "alicárias": "alicário",
    "alicários": "alicário",
    "alidadas": "alidada",
    "alidades": "alidade",
    "alie": "aliar",
    "aliei": "aliar",
    "alieis": "aliar",
    "aliem": "aliar",
    "aliemo": "aliar",
    "aliemos": "aliar",
    "aliena": "alienar",
    "alienabilidades": "alienabilidade",
    "alienada": "alienar",
    "alienadas": "alienar",
    "alienado": "alienar",
    "alienados": "alienar",
    "alienadíssima": "alienado",
    "alienadíssimas": "alienado",
    "alienadíssimo": "alienado",
    "alienadíssimos": "alienado",
    "alienai": "alienar",
    "alienais": "alienar",
    "alienam": "alienar",
    "alienamentos": "alienamento",
    "alienamo": "alienar",
    "alienamos": "alienar",
    "alienando": "alienar",
    "alienantes": "alienante",
    "alienara": "alienar",
    "alienaram": "alienar",
    "alienaras": "alienar",
    "alienarde": "alienar",
    "alienardes": "alienar",
    "alienare": "alienar",
    "alienarei": "alienar",
    "alienareis": "alienar",
    "alienarem": "alienar",
    "alienaremos": "alienar",
    "alienares": "alienar",
    "alienaria": "alienar",
    "alienariam": "alienar",
    "alienarias": "alienar",
    "alienarmo": "alienar",
    "alienarmos": "alienar",
    "alienará": "alienar",
    "alienarás": "alienar",
    "alienarão": "alienar",
    "alienaríamos": "alienar",
    "alienaríeis": "alienar",
    "alienas": "alienar",
    "alienasse": "alienar",
    "alienassem": "alienar",
    "alienasses": "alienar",
    "alienaste": "alienar",
    "alienastes": "alienar",
    "alienatária": "alienatário",
    "alienatárias": "alienatário",
    "alienatários": "alienatário",
    "alienatória": "alienatório",
    "alienatórias": "alienatório",
    "alienatórios": "alienatório",
    "alienava": "alienar",
    "alienavam": "alienar",
    "alienavas": "alienar",
    "alienações": "alienação",
    "aliene": "alienar",
    "alienei": "alienar",
    "alieneis": "alienar",
    "alienem": "alienar",
    "alienemo": "alienar",
    "alienemos": "alienar",
    "alienes": "alienar",
    "alienismos": "alienismo",
    "alienistas": "alienista",
    "alieno": "alienar",
    "alienou": "alienar",
    "aliená": "alienar",
    "alienámo": "alienar",
    "alienámos": "alienar",
    "alienáramo": "alienar",
    "alienáramos": "alienar",
    "alienárei": "alienar",
    "alienáreis": "alienar",
    "alienásseis": "alienar",
    "alienássemos": "alienar",
    "alienávamo": "alienar",
    "alienávamos": "alienar",
    "alienávei": "alienar",
    "alienáveis": "alienável",
    "alienígenas": "alienígena",
    "alies": "aliar",
    "alifafes": "alifafe",
    "aliformes": "aliforme",
    "alifática": "alifático",
    "alifáticas": "alifático",
    "alifáticos": "alifático",
    "aliga": "aligar",
    "aligada": "aligar",
    "aligadas": "aligar",
    "aligado": "aligar",
    "aligados": "aligar",
    "aligai": "aligar",
    "aligais": "aligar",
    "aligam": "aligar",
    "aligamo": "aligar",
    "aligamos": "aligar",
    "aligando": "aligar",
    "aligara": "aligar",
    "aligaram": "aligar",
    "aligaras": "aligar",
    "aligarde": "aligar",
    "aligardes": "aligar",
    "aligare": "aligar",
    "aligarei": "aligar",
    "aligareis": "aligar",
    "aligarem": "aligar",
    "aligaremos": "aligar",
    "aligares": "aligar",
    "aligaria": "aligar",
    "aligariam": "aligar",
    "aligarias": "aligar",
    "aligarmo": "aligar",
    "aligarmos": "aligar",
    "aligará": "aligar",
    "aligarás": "aligar",
    "aligarão": "aligar",
    "aligaríamos": "aligar",
    "aligaríeis": "aligar",
    "aligas": "aligar",
    "aligasse": "aligar",
    "aligassem": "aligar",
    "aligasses": "aligar",
    "aligaste": "aligar",
    "aligastes": "aligar",
    "aligava": "aligar",
    "aligavam": "aligar",
    "aligavas": "aligar",
    "aligeira": "aligeirar",
    "aligeirada": "aligeirar",
    "aligeiradas": "aligeirar",
    "aligeirado": "aligeirar",
    "aligeirados": "aligeirar",
    "aligeirai": "aligeirar",
    "aligeirais": "aligeirar",
    "aligeiram": "aligeirar",
    "aligeiramentos": "aligeiramento",
    "aligeiramo": "aligeirar",
    "aligeiramos": "aligeirar",
    "aligeirando": "aligeirar",
    "aligeirara": "aligeirar",
    "aligeiraram": "aligeirar",
    "aligeiraras": "aligeirar",
    "aligeirarde": "aligeirar",
    "aligeirardes": "aligeirar",
    "aligeirare": "aligeirar",
    "aligeirarei": "aligeirar",
    "aligeirareis": "aligeirar",
    "aligeirarem": "aligeirar",
    "aligeiraremos": "aligeirar",
    "aligeirares": "aligeirar",
    "aligeiraria": "aligeirar",
    "aligeirariam": "aligeirar",
    "aligeirarias": "aligeirar",
    "aligeirarmo": "aligeirar",
    "aligeirarmos": "aligeirar",
    "aligeirará": "aligeirar",
    "aligeirarás": "aligeirar",
    "aligeirarão": "aligeirar",
    "aligeiraríamos": "aligeirar",
    "aligeiraríeis": "aligeirar",
    "aligeiras": "aligeirar",
    "aligeirasse": "aligeirar",
    "aligeirassem": "aligeirar",
    "aligeirasses": "aligeirar",
    "aligeiraste": "aligeirar",
    "aligeirastes": "aligeirar",
    "aligeirava": "aligeirar",
    "aligeiravam": "aligeirar",
    "aligeiravas": "aligeirar",
    "aligeire": "aligeirar",
    "aligeirei": "aligeirar",
    "aligeireis": "aligeirar",
    "aligeirem": "aligeirar",
    "aligeiremo": "aligeirar",
    "aligeiremos": "aligeirar",
    "aligeires": "aligeirar",
    "aligeiro": "aligeirar",
    "aligeirou": "aligeirar",
    "aligeirá": "aligeirar",
    "aligeirámo": "aligeirar",
    "aligeirámos": "aligeirar",
    "aligeiráramo": "aligeirar",
    "aligeiráramos": "aligeirar",
    "aligeirárei": "aligeirar",
    "aligeiráreis": "aligeirar",
    "aligeirásseis": "aligeirar",
    "aligeirássemos": "aligeirar",
    "aligeirávamo": "aligeirar",
    "aligeirávamos": "aligeirar",
    "aligeirávei": "aligeirar",
    "aligeiráveis": "aligeirar",
    "aligo": "aligar",
    "aligou": "aligar",
    "aligue": "aligar",
    "aliguei": "aligar",
    "aligueis": "aligar",
    "aliguem": "aligar",
    "aliguemo": "aligar",
    "aliguemos": "aligar",
    "aligues": "aligar",
    "aligá": "aligar",
    "aligámo": "aligar",
    "aligámos": "aligar",
    "aligáramo": "aligar",
    "aligáramos": "aligar",
    "aligárei": "aligar",
    "aligáreis": "aligar",
    "aligásseis": "aligar",
    "aligássemos": "aligar",
    "aligátores": "aligátor",
    "aligávamo": "aligar",
    "aligávamos": "aligar",
    "aligávei": "aligar",
    "aligáveis": "aligar",
    "alija": "alijar",
    "alijada": "alijar",
    "alijadas": "alijar",
    "alijado": "alijar",
    "alijados": "alijar",
    "alijai": "alijar",
    "alijais": "alijar",
    "alijam": "alijar",
    "alijamentos": "alijamento",
    "alijamo": "alijar",
    "alijamos": "alijar",
    "alijando": "alijar",
    "alijara": "alijar",
    "alijaram": "alijar",
    "alijaras": "alijar",
    "alijarde": "alijar",
    "alijardes": "alijar",
    "alijare": "alijar",
    "alijarei": "alijar",
    "alijareis": "alijar",
    "alijarem": "alijar",
    "alijaremos": "alijar",
    "alijares": "alijar",
    "alijaria": "alijar",
    "alijariam": "alijar",
    "alijarias": "alijar",
    "alijarmo": "alijar",
    "alijarmos": "alijar",
    "alijará": "alijar",
    "alijarás": "alijar",
    "alijarão": "alijar",
    "alijaríamos": "alijar",
    "alijaríeis": "alijar",
    "alijas": "alijar",
    "alijasse": "alijar",
    "alijassem": "alijar",
    "alijasses": "alijar",
    "alijaste": "alijar",
    "alijastes": "alijar",
    "alijava": "alijar",
    "alijavam": "alijar",
    "alijavas": "alijar",
    "alije": "alijar",
    "alijei": "alijar",
    "alijeis": "alijar",
    "alijem": "alijar",
    "alijemo": "alijar",
    "alijemos": "alijar",
    "alijes": "alijar",
    "alijo": "alijar",
    "alijos": "alijo",
    "alijou": "alijar",
    "alijá": "alijar",
    "alijámo": "alijar",
    "alijámos": "alijar",
    "alijáramo": "alijar",
    "alijáramos": "alijar",
    "alijárei": "alijar",
    "alijáreis": "alijar",
    "alijásseis": "alijar",
    "alijássemos": "alijar",
    "alijávamo": "alijar",
    "alijávamos": "alijar",
    "alijávei": "alijar",
    "alijáveis": "alijar",
    "alilacetonas": "alilacetona",
    "alilos": "alilo",
    "alimenta": "alimentar",
    "alimentada": "alimentar",
    "alimentadas": "alimentar",
    "alimentado": "alimentar",
    "alimentadora": "alimentador",
    "alimentadoras": "alimentador",
    "alimentadores": "alimentador",
    "alimentados": "alimentar",
    "alimentai": "alimentar",
    "alimentais": "alimentar",
    "alimentam": "alimentar",
    "alimentamo": "alimentar",
    "alimentamos": "alimentar",
    "alimentanda": "alimentando",
    "alimentandas": "alimentando",
    "alimentando": "alimentar",
    "alimentandos": "alimentando",
    "alimentantes": "alimentante",
    "alimentara": "alimentar",
    "alimentaram": "alimentar",
    "alimentaras": "alimentar",
    "alimentarde": "alimentar",
    "alimentardes": "alimentar",
    "alimentare": "alimentar",
    "alimentarei": "alimentar",
    "alimentareis": "alimentar",
    "alimentarem": "alimentar",
    "alimentaremos": "alimentar",
    "alimentares": "alimentar",
    "alimentaria": "alimentar",
    "alimentariam": "alimentar",
    "alimentarias": "alimentar",
    "alimentarmo": "alimentar",
    "alimentarmos": "alimentar",
    "alimentará": "alimentar",
    "alimentarás": "alimentar",
    "alimentarão": "alimentar",
    "alimentaríamos": "alimentar",
    "alimentaríeis": "alimentar",
    "alimentas": "alimentar",
    "alimentasse": "alimentar",
    "alimentassem": "alimentar",
    "alimentasses": "alimentar",
    "alimentaste": "alimentar",
    "alimentastes": "alimentar",
    "alimentava": "alimentar",
    "alimentavam": "alimentar",
    "alimentavas": "alimentar",
    "alimentações": "alimentação",
    "alimente": "alimentar",
    "alimentei": "alimentar",
    "alimenteis": "alimentar",
    "alimentem": "alimentar",
    "alimentemo": "alimentar",
    "alimentemos": "alimentar",
    "alimentes": "alimentar",
    "alimentistas": "alimentista",
    "alimentividades": "alimentividade",
    "alimento": "alimentar",
    "alimentos": "alimento",
    "alimentosa": "alimentoso",
    "alimentosas": "alimentoso",
    "alimentosos": "alimentoso",
    "alimentou": "alimentar",
    "alimentá": "alimentar",
    "alimentámo": "alimentar",
    "alimentámos": "alimentar",
    "alimentáramo": "alimentar",
    "alimentáramos": "alimentar",
    "alimentárei": "alimentar",
    "alimentáreis": "alimentar",
    "alimentásseis": "alimentar",
    "alimentássemos": "alimentar",
    "alimentávamo": "alimentar",
    "alimentávamos": "alimentar",
    "alimentávei": "alimentar",
    "alimentáveis": "alimentável",
    "alimentícia": "alimentício",
    "alimentícias": "alimentício",
    "alimentícios": "alimentício",
    "alimes": "alime",
    "alimpa": "alimpar",
    "alimpada": "alimpar",
    "alimpadas": "alimpar",
    "alimpadeira": "alimpador",
    "alimpadeiras": "alimpador",
    "alimpado": "alimpar",
    "alimpadora": "alimpador",
    "alimpadoras": "alimpador",
    "alimpadores": "alimpador",
    "alimpados": "alimpar",
    "alimpaduras": "alimpadura",
    "alimpai": "alimpar",
    "alimpais": "alimpar",
    "alimpam": "alimpar",
    "alimpamentos": "alimpamento",
    "alimpamo": "alimpar",
    "alimpamos": "alimpar",
    "alimpando": "alimpar",
    "alimpara": "alimpar",
    "alimparam": "alimpar",
    "alimparas": "alimpar",
    "alimparde": "alimpar",
    "alimpardes": "alimpar",
    "alimpare": "alimpar",
    "alimparei": "alimpar",
    "alimpareis": "alimpar",
    "alimparem": "alimpar",
    "alimparemos": "alimpar",
    "alimpares": "alimpar",
    "alimparia": "alimpar",
    "alimpariam": "alimpar",
    "alimparias": "alimpar",
    "alimparmo": "alimpar",
    "alimparmos": "alimpar",
    "alimpará": "alimpar",
    "alimparás": "alimpar",
    "alimparão": "alimpar",
    "alimparíamos": "alimpar",
    "alimparíeis": "alimpar",
    "alimpas": "alimpar",
    "alimpasse": "alimpar",
    "alimpassem": "alimpar",
    "alimpasses": "alimpar",
    "alimpaste": "alimpar",
    "alimpastes": "alimpar",
    "alimpava": "alimpar",
    "alimpavam": "alimpar",
    "alimpavas": "alimpar",
    "alimpe": "alimpar",
    "alimpei": "alimpar",
    "alimpeis": "alimpar",
    "alimpem": "alimpar",
    "alimpemo": "alimpar",
    "alimpemos": "alimpar",
    "alimpes": "alimpar",
    "alimpo": "alimpar",
    "alimpou": "alimpar",
    "alimpá": "alimpar",
    "alimpámo": "alimpar",
    "alimpámos": "alimpar",
    "alimpáramo": "alimpar",
    "alimpáramos": "alimpar",
    "alimpárei": "alimpar",
    "alimpáreis": "alimpar",
    "alimpásseis": "alimpar",
    "alimpássemos": "alimpar",
    "alimpávamo": "alimpar",
    "alimpávamos": "alimpar",
    "alimpávei": "alimpar",
    "alimpáveis": "alimpar",
    "alimárias": "alimária",
    "alinda": "alindar",
    "alindada": "alindar",
    "alindadas": "alindar",
    "alindado": "alindar",
    "alindados": "alindar",
    "alindai": "alindar",
    "alindais": "alindar",
    "alindam": "alindar",
    "alindamentos": "alindamento",
    "alindamo": "alindar",
    "alindamos": "alindar",
    "alindando": "alindar",
    "alindara": "alindar",
    "alindaram": "alindar",
    "alindaras": "alindar",
    "alindarde": "alindar",
    "alindardes": "alindar",
    "alindare": "alindar",
    "alindarei": "alindar",
    "alindareis": "alindar",
    "alindarem": "alindar",
    "alindaremos": "alindar",
    "alindares": "alindar",
    "alindaria": "alindar",
    "alindariam": "alindar",
    "alindarias": "alindar",
    "alindarmo": "alindar",
    "alindarmos": "alindar",
    "alindará": "alindar",
    "alindarás": "alindar",
    "alindarão": "alindar",
    "alindaríamos": "alindar",
    "alindaríeis": "alindar",
    "alindas": "alindar",
    "alindasse": "alindar",
    "alindassem": "alindar",
    "alindasses": "alindar",
    "alindaste": "alindar",
    "alindastes": "alindar",
    "alindava": "alindar",
    "alindavam": "alindar",
    "alindavas": "alindar",
    "alinde": "alindar",
    "alindei": "alindar",
    "alindeis": "alindar",
    "alindem": "alindar",
    "alindemo": "alindar",
    "alindemos": "alindar",
    "alindes": "alindar",
    "alindo": "alindar",
    "alindou": "alindar",
    "alindá": "alindar",
    "alindámo": "alindar",
    "alindámos": "alindar",
    "alindáramo": "alindar",
    "alindáramos": "alindar",
    "alindárei": "alindar",
    "alindáreis": "alindar",
    "alindásseis": "alindar",
    "alindássemos": "alindar",
    "alindávamo": "alindar",
    "alindávamos": "alindar",
    "alindávei": "alindar",
    "alindáveis": "alindar",
    "alineada": "alinear",
    "alineadas": "alinear",
    "alineado": "alinear",
    "alineados": "alinear",
    "alineai": "alinear",
    "alineais": "alinear",
    "alineamo": "alinear",
    "alineamos": "alinear",
    "alineando": "alinear",
    "alineara": "alinear",
    "alinearam": "alinear",
    "alinearas": "alinear",
    "alinearde": "alinear",
    "alineardes": "alinear",
    "alineare": "alinear",
    "alinearei": "alinear",
    "alineareis": "alinear",
    "alinearem": "alinear",
    "alinearemos": "alinear",
    "alineares": "alinear",
    "alinearia": "alinear",
    "alineariam": "alinear",
    "alinearias": "alinear",
    "alinearmo": "alinear",
    "alinearmos": "alinear",
    "alineará": "alinear",
    "alinearás": "alinear",
    "alinearão": "alinear",
    "alinearíamos": "alinear",
    "alinearíeis": "alinear",
    "alineasse": "alinear",
    "alineassem": "alinear",
    "alineasses": "alinear",
    "alineaste": "alinear",
    "alineastes": "alinear",
    "alineava": "alinear",
    "alineavam": "alinear",
    "alineavas": "alinear",
    "alineei": "alinear",
    "alineeis": "alinear",
    "alineemo": "alinear",
    "alineemos": "alinear",
    "alinegra": "alinegro",
    "alinegras": "alinegro",
    "alinegros": "alinegro",
    "alineia": "alinear",
    "alineiam": "alinear",
    "alineias": "alinear",
    "alineie": "alinear",
    "alineiem": "alinear",
    "alineies": "alinear",
    "alineio": "alinear",
    "alineou": "alinear",
    "alineá": "alinear",
    "alineámo": "alinear",
    "alineámos": "alinear",
    "alineáramo": "alinear",
    "alineáramos": "alinear",
    "alineárei": "alinear",
    "alineáreis": "alinear",
    "alineásseis": "alinear",
    "alineássemos": "alinear",
    "alineávamo": "alinear",
    "alineávamos": "alinear",
    "alineávei": "alinear",
    "alineáveis": "alinear",
    "alinguetada": "alinguetado",
    "alinguetadas": "alinguetado",
    "alinguetados": "alinguetado",
    "alinha": "alinhar",
    "alinhada": "alinhar",
    "alinhadas": "alinhar",
    "alinhado": "alinhar",
    "alinhadora": "alinhador",
    "alinhadoras": "alinhador",
    "alinhadores": "alinhador",
    "alinhados": "alinhar",
    "alinhai": "alinhar",
    "alinhais": "alinhar",
    "alinham": "alinhar",
    "alinhamentos": "alinhamento",
    "alinhamo": "alinhar",
    "alinhamos": "alinhar",
    "alinhando": "alinhar",
    "alinhara": "alinhar",
    "alinharam": "alinhar",
    "alinharas": "alinhar",
    "alinharde": "alinhar",
    "alinhardes": "alinhar",
    "alinhare": "alinhar",
    "alinharei": "alinhar",
    "alinhareis": "alinhar",
    "alinharem": "alinhar",
    "alinharemos": "alinhar",
    "alinhares": "alinhar",
    "alinharia": "alinhar",
    "alinhariam": "alinhar",
    "alinharias": "alinhar",
    "alinharmo": "alinhar",
    "alinharmos": "alinhar",
    "alinhará": "alinhar",
    "alinharás": "alinhar",
    "alinharão": "alinhar",
    "alinharíamos": "alinhar",
    "alinharíeis": "alinhar",
    "alinhas": "alinhar",
    "alinhasse": "alinhar",
    "alinhassem": "alinhar",
    "alinhasses": "alinhar",
    "alinhaste": "alinhar",
    "alinhastes": "alinhar",
    "alinhava": "alinhavar",
    "alinhavada": "alinhavar",
    "alinhavadas": "alinhavar",
    "alinhavado": "alinhavar",
    "alinhavados": "alinhavar",
    "alinhavai": "alinhavar",
    "alinhavais": "alinhavar",
    "alinhavam": "alinhavar",
    "alinhavamo": "alinhavar",
    "alinhavamos": "alinhavar",
    "alinhavando": "alinhavar",
    "alinhavara": "alinhavar",
    "alinhavaram": "alinhavar",
    "alinhavaras": "alinhavar",
    "alinhavarde": "alinhavar",
    "alinhavardes": "alinhavar",
    "alinhavare": "alinhavar",
    "alinhavarei": "alinhavar",
    "alinhavareis": "alinhavar",
    "alinhavarem": "alinhavar",
    "alinhavaremos": "alinhavar",
    "alinhavares": "alinhavar",
    "alinhavaria": "alinhavar",
    "alinhavariam": "alinhavar",
    "alinhavarias": "alinhavar",
    "alinhavarmo": "alinhavar",
    "alinhavarmos": "alinhavar",
    "alinhavará": "alinhavar",
    "alinhavarás": "alinhavar",
    "alinhavarão": "alinhavar",
    "alinhavaríamos": "alinhavar",
    "alinhavaríeis": "alinhavar",
    "alinhavas": "alinhavar",
    "alinhavasse": "alinhavar",
    "alinhavassem": "alinhavar",
    "alinhavasses": "alinhavar",
    "alinhavaste": "alinhavar",
    "alinhavastes": "alinhavar",
    "alinhavava": "alinhavar",
    "alinhavavam": "alinhavar",
    "alinhavavas": "alinhavar",
    "alinhave": "alinhavar",
    "alinhavei": "alinhavar",
    "alinhaveis": "alinhavar",
    "alinhavem": "alinhavar",
    "alinhavemo": "alinhavar",
    "alinhavemos": "alinhavar",
    "alinhaves": "alinhavar",
    "alinhavo": "alinhavar",
    "alinhavos": "alinhavo",
    "alinhavou": "alinhavar",
    "alinhavá": "alinhavar",
    "alinhavámo": "alinhavar",
    "alinhavámos": "alinhavar",
    "alinhaváramo": "alinhavar",
    "alinhaváramos": "alinhavar",
    "alinhavárei": "alinhavar",
    "alinhaváreis": "alinhavar",
    "alinhavásseis": "alinhavar",
    "alinhavássemos": "alinhavar",
    "alinhavávamo": "alinhavar",
    "alinhavávamos": "alinhavar",
    "alinhavávei": "alinhavar",
    "alinhaváveis": "alinhavar",
    "alinhe": "alinhar",
    "alinhei": "alinhar",
    "alinheiros": "alinheiro",
    "alinheis": "alinhar",
    "alinhem": "alinhar",
    "alinhemo": "alinhar",
    "alinhemos": "alinhar",
    "alinhes": "alinhar",
    "alinho": "alinhar",
    "alinhos": "alinho",
    "alinhou": "alinhar",
    "alinhá": "alinhar",
    "alinhámo": "alinhar",
    "alinhámos": "alinhar",
    "alinháramo": "alinhar",
    "alinháramos": "alinhar",
    "alinhárei": "alinhar",
    "alinháreis": "alinhar",
    "alinhásseis": "alinhar",
    "alinhássemos": "alinhar",
    "alinhávamo": "alinhar",
    "alinhávamos": "alinhar",
    "alinhávei": "alinhar",
    "alinháveis": "alinhável",
    "alio": "aliar",
    "aliou": "aliar",
    "alipotentes": "alipotente",
    "aliptas": "alipta",
    "aliptérios": "aliptério",
    "aliquantas": "aliquanta",
    "aliquebrada": "aliquebrado",
    "aliquebradas": "aliquebrado",
    "aliquebrados": "aliquebrado",
    "alis": "alil",
    "alisa": "alisar",
    "alisada": "alisar",
    "alisadas": "alisar",
    "alisado": "alisar",
    "alisadora": "alisador",
    "alisadoras": "alisador",
    "alisadores": "alisador",
    "alisados": "alisar",
    "alisai": "alisar",
    "alisais": "alisar",
    "alisam": "alisar",
    "alisamentos": "alisamento",
    "alisamo": "alisar",
    "alisamos": "alisar",
    "alisando": "alisar",
    "alisara": "alisar",
    "alisaram": "alisar",
    "alisaras": "alisar",
    "alisarde": "alisar",
    "alisardes": "alisar",
    "alisare": "alisar",
    "alisarei": "alisar",
    "alisareis": "alisar",
    "alisarem": "alisar",
    "alisaremos": "alisar",
    "alisares": "alisar",
    "alisaria": "alisar",
    "alisariam": "alisar",
    "alisarias": "alisar",
    "alisarmo": "alisar",
    "alisarmos": "alisar",
    "alisará": "alisar",
    "alisarás": "alisar",
    "alisarão": "alisar",
    "alisaríamos": "alisar",
    "alisaríeis": "alisar",
    "alisas": "alisar",
    "alisasse": "alisar",
    "alisassem": "alisar",
    "alisasses": "alisar",
    "alisaste": "alisar",
    "alisastes": "alisar",
    "alisava": "alisar",
    "alisavam": "alisar",
    "alisavas": "alisar",
    "alise": "alisar",
    "alisei": "alisar",
    "aliseis": "alisar",
    "alisem": "alisar",
    "alisemo": "alisar",
    "alisemos": "alisar",
    "alises": "alisar",
    "aliseus": "aliseu",
    "alisfenóides": "alisfenóide",
    "alismatácea": "alismatáceo",
    "alismatáceas": "alismatáceo",
    "alismatáceos": "alismatáceo",
    "alismácea": "alismáceo",
    "alismáceas": "alismáceo",
    "alismáceos": "alismáceo",
    "aliso": "alisar",
    "alisou": "alisar",
    "alista": "alistar",
    "alistada": "alistar",
    "alistadas": "alistar",
    "alistado": "alistar",
    "alistados": "alistar",
    "alistai": "alistar",
    "alistais": "alistar",
    "alistam": "alistar",
    "alistamentos": "alistamento",
    "alistamo": "alistar",
    "alistamos": "alistar",
    "alistando": "alistar",
    "alistara": "alistar",
    "alistaram": "alistar",
    "alistaras": "alistar",
    "alistarde": "alistar",
    "alistardes": "alistar",
    "alistare": "alistar",
    "alistarei": "alistar",
    "alistareis": "alistar",
    "alistarem": "alistar",
    "alistaremos": "alistar",
    "alistares": "alistar",
    "alistaria": "alistar",
    "alistariam": "alistar",
    "alistarias": "alistar",
    "alistarmo": "alistar",
    "alistarmos": "alistar",
    "alistará": "alistar",
    "alistarás": "alistar",
    "alistarão": "alistar",
    "alistaríamos": "alistar",
    "alistaríeis": "alistar",
    "alistas": "alistar",
    "alistasse": "alistar",
    "alistassem": "alistar",
    "alistasses": "alistar",
    "alistaste": "alistar",
    "alistastes": "alistar",
    "alistava": "alistar",
    "alistavam": "alistar",
    "alistavas": "alistar",
    "aliste": "alistar",
    "alistei": "alistar",
    "alisteis": "alistar",
    "alistem": "alistar",
    "alistemo": "alistar",
    "alistemos": "alistar",
    "alistes": "alistar",
    "alisto": "alistar",
    "alistou": "alistar",
    "alistridentes": "alistridente",
    "alistá": "alistar",
    "alistámo": "alistar",
    "alistámos": "alistar",
    "alistáramo": "alistar",
    "alistáramos": "alistar",
    "alistárei": "alistar",
    "alistáreis": "alistar",
    "alistásseis": "alistar",
    "alistássemos": "alistar",
    "alistávamo": "alistar",
    "alistávamos": "alistar",
    "alistávei": "alistar",
    "alistáveis": "alistar",
    "alistões": "alistão",
    "alisá": "alisar",
    "alisámo": "alisar",
    "alisámos": "alisar",
    "alisáramo": "alisar",
    "alisáramos": "alisar",
    "alisárei": "alisar",
    "alisáreis": "alisar",
    "alisásseis": "alisar",
    "alisássemos": "alisar",
    "alisávamo": "alisar",
    "alisávamos": "alisar",
    "alisávei": "alisar",
    "alisáveis": "alisável",
    "alitera": "aliterar",
    "aliterada": "aliterar",
    "aliteradas": "aliterar",
    "aliterado": "aliterar",
    "aliterados": "aliterar",
    "aliterai": "aliterar",
    "aliterais": "aliterar",
    "aliteram": "aliterar",
    "aliteramo": "aliterar",
    "aliteramos": "aliterar",
    "aliterando": "aliterar",
    "aliterantes": "aliterante",
    "aliterara": "aliterar",
    "aliteraram": "aliterar",
    "aliteraras": "aliterar",
    "aliterarde": "aliterar",
    "aliterardes": "aliterar",
    "aliterare": "aliterar",
    "aliterarei": "aliterar",
    "aliterareis": "aliterar",
    "aliterarem": "aliterar",
    "aliteraremos": "aliterar",
    "aliterares": "aliterar",
    "aliteraria": "aliterar",
    "aliterariam": "aliterar",
    "aliterarias": "aliterar",
    "aliterarmo": "aliterar",
    "aliterarmos": "aliterar",
    "aliterará": "aliterar",
    "aliterarás": "aliterar",
    "aliterarão": "aliterar",
    "aliteraríamos": "aliterar",
    "aliteraríeis": "aliterar",
    "aliteras": "aliterar",
    "aliterasse": "aliterar",
    "aliterassem": "aliterar",
    "aliterasses": "aliterar",
    "aliteraste": "aliterar",
    "aliterastes": "aliterar",
    "aliteratada": "aliteratado",
    "aliteratadas": "aliteratado",
    "aliteratados": "aliteratado",
    "aliterava": "aliterar",
    "aliteravam": "aliterar",
    "aliteravas": "aliterar",
    "aliterações": "aliteração",
    "alitere": "aliterar",
    "aliterei": "aliterar",
    "alitereis": "aliterar",
    "aliterem": "aliterar",
    "aliteremo": "aliterar",
    "aliteremos": "aliterar",
    "aliteres": "aliterar",
    "alitero": "aliterar",
    "aliterou": "aliterar",
    "aliterá": "aliterar",
    "aliterámo": "aliterar",
    "aliterámos": "aliterar",
    "aliteráramo": "aliterar",
    "aliteráramos": "aliterar",
    "aliterárei": "aliterar",
    "aliteráreis": "aliterar",
    "aliterásseis": "aliterar",
    "aliterássemos": "aliterar",
    "aliterávamo": "aliterar",
    "aliterávamos": "aliterar",
    "aliterávei": "aliterar",
    "aliteráveis": "aliterar",
    "alitúrgica": "alitúrgico",
    "alitúrgicas": "alitúrgico",
    "alitúrgicos": "alitúrgico",
    "alivelozes": "aliveloz",
    "alivia": "aliviar",
    "aliviada": "aliviar",
    "aliviadas": "aliviar",
    "aliviado": "aliviar",
    "aliviadoiros": "aliviadoiro",
    "aliviadora": "aliviador",
    "aliviadoras": "aliviador",
    "aliviadores": "aliviador",
    "aliviados": "aliviar",
    "aliviadouros": "aliviadouro",
    "aliviai": "aliviar",
    "aliviais": "aliviar",
    "aliviam": "aliviar",
    "aliviamentos": "aliviamento",
    "aliviamo": "aliviar",
    "aliviamos": "aliviar",
    "aliviando": "aliviar",
    "aliviara": "aliviar",
    "aliviaram": "aliviar",
    "aliviaras": "aliviar",
    "aliviarde": "aliviar",
    "aliviardes": "aliviar",
    "aliviare": "aliviar",
    "aliviarei": "aliviar",
    "aliviareis": "aliviar",
    "aliviarem": "aliviar",
    "aliviaremos": "aliviar",
    "aliviares": "aliviar",
    "aliviaria": "aliviar",
    "aliviariam": "aliviar",
    "aliviarias": "aliviar",
    "aliviarmo": "aliviar",
    "aliviarmos": "aliviar",
    "aliviará": "aliviar",
    "aliviarás": "aliviar",
    "aliviarão": "aliviar",
    "aliviaríamos": "aliviar",
    "aliviaríeis": "aliviar",
    "alivias": "aliviar",
    "aliviasse": "aliviar",
    "aliviassem": "aliviar",
    "aliviasses": "aliviar",
    "aliviaste": "aliviar",
    "aliviastes": "aliviar",
    "aliviava": "aliviar",
    "aliviavam": "aliviar",
    "aliviavas": "aliviar",
    "aliviações": "aliviação",
    "alivie": "aliviar",
    "aliviei": "aliviar",
    "alivieis": "aliviar",
    "aliviem": "aliviar",
    "aliviemo": "aliviar",
    "aliviemos": "aliviar",
    "alivies": "aliviar",
    "alivio": "aliviar",
    "aliviosa": "alivioso",
    "aliviosas": "alivioso",
    "aliviosos": "alivioso",
    "aliviou": "aliviar",
    "aliviá": "aliviar",
    "aliviámo": "aliviar",
    "aliviámos": "aliviar",
    "aliviáramo": "aliviar",
    "aliviáramos": "aliviar",
    "aliviárei": "aliviar",
    "aliviáreis": "aliviar",
    "aliviásseis": "aliviar",
    "aliviássemos": "aliviar",
    "aliviávamo": "aliviar",
    "aliviávamos": "aliviar",
    "aliviávei": "aliviar",
    "aliviáveis": "aliviável",
    "alizabas": "alizaba",
    "alizarinas": "alizarina",
    "alizaris": "alizari",
    "aliá": "aliar",
    "aliácea": "aliáceo",
    "aliáceas": "aliáceo",
    "aliáceos": "aliáceo",
    "aliámo": "aliar",
    "aliámos": "aliar",
    "aliáramo": "aliar",
    "aliáramos": "aliar",
    "aliárei": "aliar",
    "aliáreis": "aliar",
    "aliásseis": "aliar",
    "aliássemos": "aliar",
    "aliávamo": "aliar",
    "aliávamos": "aliar",
    "aliávei": "aliar",
    "aliáveis": "aliável",
    "aljafras": "aljafra",
    "aljamias": "aljamia",
    "aljarzes": "aljarze",
    "aljavas": "aljava",
    "aljazares": "aljazar",
    "aljofainas": "aljofaina",
    "aljofara": "aljofarar",
    "aljofarada": "aljofarar",
    "aljofaradas": "aljofarar",
    "aljofarado": "aljofarar",
    "aljofarados": "aljofarar",
    "aljofarai": "aljofarar",
    "aljofarais": "aljofarar",
    "aljofaram": "aljofarar",
    "aljofaramo": "aljofarar",
    "aljofaramos": "aljofarar",
    "aljofarando": "aljofarar",
    "aljofarara": "aljofarar",
    "aljofararam": "aljofarar",
    "aljofararas": "aljofarar",
    "aljofararde": "aljofarar",
    "aljofarardes": "aljofarar",
    "aljofarare": "aljofarar",
    "aljofararei": "aljofarar",
    "aljofarareis": "aljofarar",
    "aljofararem": "aljofarar",
    "aljofararemos": "aljofarar",
    "aljofarares": "aljofarar",
    "aljofararia": "aljofarar",
    "aljofarariam": "aljofarar",
    "aljofararias": "aljofarar",
    "aljofararmo": "aljofarar",
    "aljofararmos": "aljofarar",
    "aljofarará": "aljofarar",
    "aljofararás": "aljofarar",
    "aljofararão": "aljofarar",
    "aljofararíamos": "aljofarar",
    "aljofararíeis": "aljofarar",
    "aljofaras": "aljofarar",
    "aljofarasse": "aljofarar",
    "aljofarassem": "aljofarar",
    "aljofarasses": "aljofarar",
    "aljofaraste": "aljofarar",
    "aljofarastes": "aljofarar",
    "aljofarava": "aljofarar",
    "aljofaravam": "aljofarar",
    "aljofaravas": "aljofarar",
    "aljofare": "aljofarar",
    "aljofarei": "aljofarar",
    "aljofareiras": "aljofareira",
    "aljofareis": "aljofarar",
    "aljofarem": "aljofarar",
    "aljofaremo": "aljofarar",
    "aljofaremos": "aljofarar",
    "aljofares": "aljofarar",
    "aljofaro": "aljofarar",
    "aljofarou": "aljofarar",
    "aljofará": "aljofarar",
    "aljofarámo": "aljofarar",
    "aljofarámos": "aljofarar",
    "aljofaráramo": "aljofarar",
    "aljofaráramos": "aljofarar",
    "aljofarárei": "aljofarar",
    "aljofaráreis": "aljofarar",
    "aljofarásseis": "aljofarar",
    "aljofarássemos": "aljofarar",
    "aljofarávamo": "aljofarar",
    "aljofarávamos": "aljofarar",
    "aljofarávei": "aljofarar",
    "aljofaráveis": "aljofarar",
    "aljofres": "aljofre",
    "aljorces": "aljorce",
    "aljorges": "aljorge",
    "aljorzes": "aljorze",
    "aljubarrotenses": "aljubarrotense",
    "aljubas": "aljuba",
    "aljubeira": "aljubeiro",
    "aljubeiras": "aljubeiro",
    "aljubeiros": "aljubeiro",
    "aljubes": "aljube",
    "aljubetas": "aljubeta",
    "aljubeteira": "aljubeteiro",
    "aljubeteiras": "aljubeteiro",
    "aljubeteiros": "aljubeteiro",
    "aljubetes": "aljubete",
    "aljuzes": "aljuz",
    "aljôfares": "aljôfar",
    "alma": "almo",
    "almadenses": "almadense",
    "almadias": "almadia",
    "almadrabas": "almadraba",
    "almadraques": "almadraque",
    "almadras": "almadra",
    "almadravas": "almadrava",
    "almadraveira": "almadraveiro",
    "almadraveiras": "almadraveiro",
    "almadraveiros": "almadraveiro",
    "almagra": "almagrar",
    "almagrada": "almagrar",
    "almagradas": "almagrar",
    "almagrado": "almagrar",
    "almagrados": "almagrar",
    "almagrai": "almagrar",
    "almagrais": "almagrar",
    "almagram": "almagrar",
    "almagramo": "almagrar",
    "almagramos": "almagrar",
    "almagrando": "almagrar",
    "almagrara": "almagrar",
    "almagraram": "almagrar",
    "almagraras": "almagrar",
    "almagrarde": "almagrar",
    "almagrardes": "almagrar",
    "almagrare": "almagrar",
    "almagrarei": "almagrar",
    "almagrareis": "almagrar",
    "almagrarem": "almagrar",
    "almagraremos": "almagrar",
    "almagrares": "almagrar",
    "almagraria": "almagrar",
    "almagrariam": "almagrar",
    "almagrarias": "almagrar",
    "almagrarmo": "almagrar",
    "almagrarmos": "almagrar",
    "almagrará": "almagrar",
    "almagrarás": "almagrar",
    "almagrarão": "almagrar",
    "almagraríamos": "almagrar",
    "almagraríeis": "almagrar",
    "almagras": "almagrar",
    "almagrasse": "almagrar",
    "almagrassem": "almagrar",
    "almagrasses": "almagrar",
    "almagraste": "almagrar",
    "almagrastes": "almagrar",
    "almagrava": "almagrar",
    "almagravam": "almagrar",
    "almagravas": "almagrar",
    "almagre": "almagrar",
    "almagrei": "almagrar",
    "almagreiras": "almagreira",
    "almagreis": "almagrar",
    "almagrem": "almagrar",
    "almagremo": "almagrar",
    "almagremos": "almagrar",
    "almagres": "almagre",
    "almagro": "almagrar",
    "almagros": "almagro",
    "almagrou": "almagrar",
    "almagrá": "almagrar",
    "almagrámo": "almagrar",
    "almagrámos": "almagrar",
    "almagráramo": "almagrar",
    "almagráramos": "almagrar",
    "almagrárei": "almagrar",
    "almagráreis": "almagrar",
    "almagrásseis": "almagrar",
    "almagrássemos": "almagrar",
    "almagrávamo": "almagrar",
    "almagrávamos": "almagrar",
    "almagrávei": "almagrar",
    "almagráveis": "almagrar",
    "almajarra": "almajarrar",
    "almajarrada": "almajarrar",
    "almajarradas": "almajarrar",
    "almajarrado": "almajarrar",
    "almajarrados": "almajarrar",
    "almajarrai": "almajarrar",
    "almajarrais": "almajarrar",
    "almajarram": "almajarrar",
    "almajarramo": "almajarrar",
    "almajarramos": "almajarrar",
    "almajarrando": "almajarrar",
    "almajarrara": "almajarrar",
    "almajarraram": "almajarrar",
    "almajarraras": "almajarrar",
    "almajarrarde": "almajarrar",
    "almajarrardes": "almajarrar",
    "almajarrare": "almajarrar",
    "almajarrarei": "almajarrar",
    "almajarrareis": "almajarrar",
    "almajarrarem": "almajarrar",
    "almajarraremos": "almajarrar",
    "almajarrares": "almajarrar",
    "almajarraria": "almajarrar",
    "almajarrariam": "almajarrar",
    "almajarrarias": "almajarrar",
    "almajarrarmo": "almajarrar",
    "almajarrarmos": "almajarrar",
    "almajarrará": "almajarrar",
    "almajarrarás": "almajarrar",
    "almajarrarão": "almajarrar",
    "almajarraríamos": "almajarrar",
    "almajarraríeis": "almajarrar",
    "almajarras": "almajarrar",
    "almajarrasse": "almajarrar",
    "almajarrassem": "almajarrar",
    "almajarrasses": "almajarrar",
    "almajarraste": "almajarrar",
    "almajarrastes": "almajarrar",
    "almajarrava": "almajarrar",
    "almajarravam": "almajarrar",
    "almajarravas": "almajarrar",
    "almajarre": "almajarrar",
    "almajarrei": "almajarrar",
    "almajarreis": "almajarrar",
    "almajarrem": "almajarrar",
    "almajarremo": "almajarrar",
    "almajarremos": "almajarrar",
    "almajarres": "almajarrar",
    "almajarro": "almajarrar",
    "almajarrou": "almajarrar",
    "almajarrá": "almajarrar",
    "almajarrámo": "almajarrar",
    "almajarrámos": "almajarrar",
    "almajarráramo": "almajarrar",
    "almajarráramos": "almajarrar",
    "almajarrárei": "almajarrar",
    "almajarráreis": "almajarrar",
    "almajarrásseis": "almajarrar",
    "almajarrássemos": "almajarrar",
    "almajarrávamo": "almajarrar",
    "almajarrávamos": "almajarrar",
    "almajarrávei": "almajarrar",
    "almajarráveis": "almajarrar",
    "almalaguesa": "almalaguês",
    "almalaguesas": "almalaguês",
    "almalagueses": "almalaguês",
    "almalhas": "almalha",
    "almanaques": "almanaque",
    "almandinas": "almandina",
    "almandites": "almandite",
    "almanjarras": "almanjarra",
    "almanxares": "almanxar",
    "almanças": "almança",
    "almarada": "almarado",
    "almaradas": "almarado",
    "almarados": "almarado",
    "almargeada": "almargeado",
    "almargeadas": "almargeado",
    "almargeados": "almargeado",
    "almargeais": "almargeal",
    "almargens": "almargem",
    "almarges": "almarge",
    "almargémias": "almargémia",
    "almas": "almo",
    "almazinha": "alma",
    "almazinhas": "alma",
    "almazita": "alma",
    "almazitas": "alma",
    "almaços": "almaço",
    "almecega": "almecegar",
    "almecegada": "almecegar",
    "almecegadas": "almecegar",
    "almecegado": "almecegar",
    "almecegados": "almecegar",
    "almecegai": "almecegar",
    "almecegais": "almecegar",
    "almecegam": "almecegar",
    "almecegamo": "almecegar",
    "almecegamos": "almecegar",
    "almecegando": "almecegar",
    "almecegara": "almecegar",
    "almecegaram": "almecegar",
    "almecegaras": "almecegar",
    "almecegarde": "almecegar",
    "almecegardes": "almecegar",
    "almecegare": "almecegar",
    "almecegarei": "almecegar",
    "almecegareis": "almecegar",
    "almecegarem": "almecegar",
    "almecegaremos": "almecegar",
    "almecegares": "almecegar",
    "almecegaria": "almecegar",
    "almecegariam": "almecegar",
    "almecegarias": "almecegar",
    "almecegarmo": "almecegar",
    "almecegarmos": "almecegar",
    "almecegará": "almecegar",
    "almecegarás": "almecegar",
    "almecegarão": "almecegar",
    "almecegaríamos": "almecegar",
    "almecegaríeis": "almecegar",
    "almecegas": "almecegar",
    "almecegasse": "almecegar",
    "almecegassem": "almecegar",
    "almecegasses": "almecegar",
    "almecegaste": "almecegar",
    "almecegastes": "almecegar",
    "almecegava": "almecegar",
    "almecegavam": "almecegar",
    "almecegavas": "almecegar",
    "almecego": "almecegar",
    "almecegou": "almecegar",
    "almecegue": "almecegar",
    "almeceguei": "almecegar",
    "almecegueiras": "almecegueira",
    "almecegueis": "almecegar",
    "almeceguem": "almecegar",
    "almeceguemo": "almecegar",
    "almeceguemos": "almecegar",
    "almecegues": "almecegar",
    "almecegá": "almecegar",
    "almecegámo": "almecegar",
    "almecegámos": "almecegar",
    "almecegáramo": "almecegar",
    "almecegáramos": "almecegar",
    "almecegárei": "almecegar",
    "almecegáreis": "almecegar",
    "almecegásseis": "almecegar",
    "almecegássemos": "almecegar",
    "almecegávamo": "almecegar",
    "almecegávamos": "almecegar",
    "almecegávei": "almecegar",
    "almecegáveis": "almecegar",
    "almeces": "almece",
    "almedinas": "almedina",
    "almegues": "almegue",
    "almeias": "almeia",
    "almeidas": "almeida",
    "almeidenses": "almeidense",
    "almeiroas": "almeiroa",
    "almeiros": "almeiro",
    "almeirões": "almeirão",
    "almeja": "almejar",
    "almejada": "almejar",
    "almejadas": "almejar",
    "almejado": "almejar",
    "almejados": "almejar",
    "almejai": "almejar",
    "almejais": "almejar",
    "almejam": "almejar",
    "almejamo": "almejar",
    "almejamos": "almejar",
    "almejando": "almejar",
    "almejantes": "almejante",
    "almejara": "almejar",
    "almejaram": "almejar",
    "almejaras": "almejar",
    "almejarde": "almejar",
    "almejardes": "almejar",
    "almejare": "almejar",
    "almejarei": "almejar",
    "almejareis": "almejar",
    "almejarem": "almejar",
    "almejaremos": "almejar",
    "almejares": "almejar",
    "almejaria": "almejar",
    "almejariam": "almejar",
    "almejarias": "almejar",
    "almejarmo": "almejar",
    "almejarmos": "almejar",
    "almejará": "almejar",
    "almejarás": "almejar",
    "almejarão": "almejar",
    "almejaríamos": "almejar",
    "almejaríeis": "almejar",
    "almejas": "almejar",
    "almejasse": "almejar",
    "almejassem": "almejar",
    "almejasses": "almejar",
    "almejaste": "almejar",
    "almejastes": "almejar",
    "almejava": "almejar",
    "almejavam": "almejar",
    "almejavas": "almejar",
    "almeje": "almejar",
    "almejei": "almejar",
    "almejeis": "almejar",
    "almejem": "almejar",
    "almejemo": "almejar",
    "almejemos": "almejar",
    "almejes": "almejar",
    "almejo": "almejar",
    "almejos": "almejo",
    "almejou": "almejar",
    "almejá": "almejar",
    "almejámo": "almejar",
    "almejámos": "almejar",
    "almejáramo": "almejar",
    "almejáramos": "almejar",
    "almejárei": "almejar",
    "almejáreis": "almejar",
    "almejásseis": "almejar",
    "almejássemos": "almejar",
    "almejávamo": "almejar",
    "almejávamos": "almejar",
    "almejávei": "almejar",
    "almejáveis": "almejar",
    "almenaras": "almenara",
    "almiaras": "almiara",
    "almicantarados": "almicantarado",
    "alminha": "alma",
    "alminhas": "alma",
    "almirantados": "almirantado",
    "almirantas": "almiranta",
    "almirantes": "almirante",
    "almiscara": "almiscarar",
    "almiscarada": "almiscarar",
    "almiscaradas": "almiscarar",
    "almiscarado": "almiscarar",
    "almiscarados": "almiscarar",
    "almiscarai": "almiscarar",
    "almiscarais": "almiscarar",
    "almiscaram": "almiscarar",
    "almiscaramo": "almiscarar",
    "almiscaramos": "almiscarar",
    "almiscarando": "almiscarar",
    "almiscarara": "almiscarar",
    "almiscararam": "almiscarar",
    "almiscararas": "almiscarar",
    "almiscararde": "almiscarar",
    "almiscarardes": "almiscarar",
    "almiscarare": "almiscarar",
    "almiscararei": "almiscarar",
    "almiscarareis": "almiscarar",
    "almiscararem": "almiscarar",
    "almiscararemos": "almiscarar",
    "almiscarares": "almiscarar",
    "almiscararia": "almiscarar",
    "almiscarariam": "almiscarar",
    "almiscararias": "almiscarar",
    "almiscararmo": "almiscarar",
    "almiscararmos": "almiscarar",
    "almiscarará": "almiscarar",
    "almiscararás": "almiscarar",
    "almiscararão": "almiscarar",
    "almiscararíamos": "almiscarar",
    "almiscararíeis": "almiscarar",
    "almiscaras": "almiscarar",
    "almiscarasse": "almiscarar",
    "almiscarassem": "almiscarar",
    "almiscarasses": "almiscarar",
    "almiscaraste": "almiscarar",
    "almiscarastes": "almiscarar",
    "almiscarava": "almiscarar",
    "almiscaravam": "almiscarar",
    "almiscaravas": "almiscarar",
    "almiscare": "almiscarar",
    "almiscarei": "almiscarar",
    "almiscareiras": "almiscareira",
    "almiscareiros": "almiscareiro",
    "almiscareis": "almiscarar",
    "almiscarem": "almiscarar",
    "almiscaremo": "almiscarar",
    "almiscaremos": "almiscarar",
    "almiscares": "almiscarar",
    "almiscaro": "almiscarar",
    "almiscarou": "almiscarar",
    "almiscará": "almiscarar",
    "almiscarámo": "almiscarar",
    "almiscarámos": "almiscarar",
    "almiscaráramo": "almiscarar",
    "almiscaráramos": "almiscarar",
    "almiscarárei": "almiscarar",
    "almiscaráreis": "almiscarar",
    "almiscarásseis": "almiscarar",
    "almiscarássemos": "almiscarar",
    "almiscarávamo": "almiscarar",
    "almiscarávamos": "almiscarar",
    "almiscarávei": "almiscarar",
    "almiscaráveis": "almiscarar",
    "almita": "alma",
    "almitas": "alma",
    "almocadéns": "almocadém",
    "almocafres": "almocafre",
    "almoce": "almoçar",
    "almocei": "almoçar",
    "almoceis": "almoçar",
    "almocelas": "almocela",
    "almocem": "almoçar",
    "almocemo": "almoçar",
    "almocemos": "almoçar",
    "almoces": "almoçar",
    "almocinho": "almoço",
    "almocinhos": "almoço",
    "almocito": "almoço",
    "almocitos": "almoço",
    "almocouvares": "almocouvar",
    "almocreva": "almocrevar",
    "almocrevada": "almocrevar",
    "almocrevadas": "almocrevar",
    "almocrevado": "almocrevar",
    "almocrevados": "almocrevar",
    "almocrevai": "almocrevar",
    "almocrevais": "almocrevar",
    "almocrevam": "almocrevar",
    "almocrevamo": "almocrevar",
    "almocrevamos": "almocrevar",
    "almocrevando": "almocrevar",
    "almocrevara": "almocrevar",
    "almocrevaram": "almocrevar",
    "almocrevaras": "almocrevar",
    "almocrevarde": "almocrevar",
    "almocrevardes": "almocrevar",
    "almocrevare": "almocrevar",
    "almocrevarei": "almocrevar",
    "almocrevareis": "almocrevar",
    "almocrevarem": "almocrevar",
    "almocrevaremos": "almocrevar",
    "almocrevares": "almocrevar",
    "almocrevaria": "almocrevar",
    "almocrevariam": "almocrevar",
    "almocrevarias": "almocrevaria",
    "almocrevarmo": "almocrevar",
    "almocrevarmos": "almocrevar",
    "almocrevará": "almocrevar",
    "almocrevarás": "almocrevar",
    "almocrevarão": "almocrevar",
    "almocrevaríamos": "almocrevar",
    "almocrevaríeis": "almocrevar",
    "almocrevas": "almocrevar",
    "almocrevasse": "almocrevar",
    "almocrevassem": "almocrevar",
    "almocrevasses": "almocrevar",
    "almocrevaste": "almocrevar",
    "almocrevastes": "almocrevar",
    "almocrevava": "almocrevar",
    "almocrevavam": "almocrevar",
    "almocrevavas": "almocrevar",
    "almocreve": "almocrevar",
    "almocrevei": "almocrevar",
    "almocreveis": "almocrevar",
    "almocrevem": "almocrevar",
    "almocrevemo": "almocrevar",
    "almocrevemos": "almocrevar",
    "almocreves": "almocreve",
    "almocrevo": "almocrevar",
    "almocrevou": "almocrevar",
    "almocrevá": "almocrevar",
    "almocrevámo": "almocrevar",
    "almocrevámos": "almocrevar",
    "almocreváramo": "almocrevar",
    "almocreváramos": "almocrevar",
    "almocrevárei": "almocrevar",
    "almocreváreis": "almocrevar",
    "almocrevásseis": "almocrevar",
    "almocrevássemos": "almocrevar",
    "almocrevávamo": "almocrevar",
    "almocrevávamos": "almocrevar",
    "almocrevávei": "almocrevar",
    "almocreváveis": "almocrevar",
    "almocábares": "almocábar",
    "almodovarenses": "almodovarense",
    "almoeda": "almoedar",
    "almoedada": "almoedar",
    "almoedadas": "almoedar",
    "almoedado": "almoedar",
    "almoedados": "almoedar",
    "almoedai": "almoedar",
    "almoedais": "almoedar",
    "almoedam": "almoedar",
    "almoedamo": "almoedar",
    "almoedamos": "almoedar",
    "almoedando": "almoedar",
    "almoedara": "almoedar",
    "almoedaram": "almoedar",
    "almoedaras": "almoedar",
    "almoedarde": "almoedar",
    "almoedardes": "almoedar",
    "almoedare": "almoedar",
    "almoedarei": "almoedar",
    "almoedareis": "almoedar",
    "almoedarem": "almoedar",
    "almoedaremos": "almoedar",
    "almoedares": "almoedar",
    "almoedaria": "almoedar",
    "almoedariam": "almoedar",
    "almoedarias": "almoedar",
    "almoedarmo": "almoedar",
    "almoedarmos": "almoedar",
    "almoedará": "almoedar",
    "almoedarás": "almoedar",
    "almoedarão": "almoedar",
    "almoedaríamos": "almoedar",
    "almoedaríeis": "almoedar",
    "almoedas": "almoedar",
    "almoedasse": "almoedar",
    "almoedassem": "almoedar",
    "almoedasses": "almoedar",
    "almoedaste": "almoedar",
    "almoedastes": "almoedar",
    "almoedava": "almoedar",
    "almoedavam": "almoedar",
    "almoedavas": "almoedar",
    "almoede": "almoedar",
    "almoedei": "almoedar",
    "almoedeiros": "almoedeiro",
    "almoedeis": "almoedar",
    "almoedem": "almoedar",
    "almoedemo": "almoedar",
    "almoedemos": "almoedar",
    "almoedes": "almoedar",
    "almoedo": "almoedar",
    "almoedou": "almoedar",
    "almoedá": "almoedar",
    "almoedámo": "almoedar",
    "almoedámos": "almoedar",
    "almoedáramo": "almoedar",
    "almoedáramos": "almoedar",
    "almoedárei": "almoedar",
    "almoedáreis": "almoedar",
    "almoedásseis": "almoedar",
    "almoedássemos": "almoedar",
    "almoedávamo": "almoedar",
    "almoedávamos": "almoedar",
    "almoedávei": "almoedar",
    "almoedáveis": "almoedar",
    "almoface": "almofaçar",
    "almofacei": "almofaçar",
    "almofaceis": "almofaçar",
    "almofacem": "almofaçar",
    "almofacemo": "almofaçar",
    "almofacemos": "almofaçar",
    "almofaces": "almofaçar",
    "almofada": "almofadar",
    "almofadada": "almofadar",
    "almofadadas": "almofadar",
    "almofadado": "almofadar",
    "almofadados": "almofadar",
    "almofadai": "almofadar",
    "almofadais": "almofadar",
    "almofadam": "almofadar",
    "almofadamo": "almofadar",
    "almofadamos": "almofadar",
    "almofadando": "almofadar",
    "almofadara": "almofadar",
    "almofadaram": "almofadar",
    "almofadaras": "almofadar",
    "almofadarde": "almofadar",
    "almofadardes": "almofadar",
    "almofadare": "almofadar",
    "almofadarei": "almofadar",
    "almofadareis": "almofadar",
    "almofadarem": "almofadar",
    "almofadaremos": "almofadar",
    "almofadares": "almofadar",
    "almofadaria": "almofadar",
    "almofadariam": "almofadar",
    "almofadarias": "almofadar",
    "almofadarmo": "almofadar",
    "almofadarmos": "almofadar",
    "almofadará": "almofadar",
    "almofadarás": "almofadar",
    "almofadarão": "almofadar",
    "almofadaríamos": "almofadar",
    "almofadaríeis": "almofadar",
    "almofadas": "almofadar",
    "almofadasse": "almofadar",
    "almofadassem": "almofadar",
    "almofadasses": "almofadar",
    "almofadaste": "almofadar",
    "almofadastes": "almofadar",
    "almofadava": "almofadar",
    "almofadavam": "almofadar",
    "almofadavas": "almofadar",
    "almofade": "almofadar",
    "almofadei": "almofadar",
    "almofadeis": "almofadar",
    "almofadem": "almofadar",
    "almofademo": "almofadar",
    "almofademos": "almofadar",
    "almofades": "almofadar",
    "almofadilhas": "almofadilha",
    "almofadinha": "almofada",
    "almofadinhas": "almofada",
    "almofadita": "almofada",
    "almofaditas": "almofada",
    "almofado": "almofadar",
    "almofadou": "almofadar",
    "almofadá": "almofadar",
    "almofadámo": "almofadar",
    "almofadámos": "almofadar",
    "almofadáramo": "almofadar",
    "almofadáramos": "almofadar",
    "almofadárei": "almofadar",
    "almofadáreis": "almofadar",
    "almofadásseis": "almofadar",
    "almofadássemos": "almofadar",
    "almofadávamo": "almofadar",
    "almofadávamos": "almofadar",
    "almofadávei": "almofadar",
    "almofadáveis": "almofadar",
    "almofadões": "almofadão",
    "almofarizes": "almofariz",
    "almofates": "almofate",
    "almofaça": "almofaçar",
    "almofaçada": "almofaçar",
    "almofaçadas": "almofaçar",
    "almofaçado": "almofaçar",
    "almofaçados": "almofaçar",
    "almofaçai": "almofaçar",
    "almofaçais": "almofaçar",
    "almofaçam": "almofaçar",
    "almofaçamo": "almofaçar",
    "almofaçamos": "almofaçar",
    "almofaçando": "almofaçar",
    "almofaçara": "almofaçar",
    "almofaçaram": "almofaçar",
    "almofaçaras": "almofaçar",
    "almofaçarde": "almofaçar",
    "almofaçardes": "almofaçar",
    "almofaçare": "almofaçar",
    "almofaçarei": "almofaçar",
    "almofaçareis": "almofaçar",
    "almofaçarem": "almofaçar",
    "almofaçaremos": "almofaçar",
    "almofaçares": "almofaçar",
    "almofaçaria": "almofaçar",
    "almofaçariam": "almofaçar",
    "almofaçarias": "almofaçar",
    "almofaçarmo": "almofaçar",
    "almofaçarmos": "almofaçar",
    "almofaçará": "almofaçar",
    "almofaçarás": "almofaçar",
    "almofaçarão": "almofaçar",
    "almofaçaríamos": "almofaçar",
    "almofaçaríeis": "almofaçar",
    "almofaças": "almofaçar",
    "almofaçasse": "almofaçar",
    "almofaçassem": "almofaçar",
    "almofaçasses": "almofaçar",
    "almofaçaste": "almofaçar",
    "almofaçastes": "almofaçar",
    "almofaçava": "almofaçar",
    "almofaçavam": "almofaçar",
    "almofaçavas": "almofaçar",
    "almofaçilhas": "almofaçilha",
    "almofaço": "almofaçar",
    "almofaçou": "almofaçar",
    "almofaçá": "almofaçar",
    "almofaçámo": "almofaçar",
    "almofaçámos": "almofaçar",
    "almofaçáramo": "almofaçar",
    "almofaçáramos": "almofaçar",
    "almofaçárei": "almofaçar",
    "almofaçáreis": "almofaçar",
    "almofaçásseis": "almofaçar",
    "almofaçássemos": "almofaçar",
    "almofaçávamo": "almofaçar",
    "almofaçávamos": "almofaçar",
    "almofaçávei": "almofaçar",
    "almofaçáveis": "almofaçar",
    "almofeiras": "almofeira",
    "almofias": "almofia",
    "almofreixa": "almofreixar",
    "almofreixada": "almofreixar",
    "almofreixadas": "almofreixar",
    "almofreixado": "almofreixar",
    "almofreixados": "almofreixar",
    "almofreixai": "almofreixar",
    "almofreixais": "almofreixar",
    "almofreixam": "almofreixar",
    "almofreixamo": "almofreixar",
    "almofreixamos": "almofreixar",
    "almofreixando": "almofreixar",
    "almofreixara": "almofreixar",
    "almofreixaram": "almofreixar",
    "almofreixaras": "almofreixar",
    "almofreixarde": "almofreixar",
    "almofreixardes": "almofreixar",
    "almofreixare": "almofreixar",
    "almofreixarei": "almofreixar",
    "almofreixareis": "almofreixar",
    "almofreixarem": "almofreixar",
    "almofreixaremos": "almofreixar",
    "almofreixares": "almofreixar",
    "almofreixaria": "almofreixar",
    "almofreixariam": "almofreixar",
    "almofreixarias": "almofreixar",
    "almofreixarmo": "almofreixar",
    "almofreixarmos": "almofreixar",
    "almofreixará": "almofreixar",
    "almofreixarás": "almofreixar",
    "almofreixarão": "almofreixar",
    "almofreixaríamos": "almofreixar",
    "almofreixaríeis": "almofreixar",
    "almofreixas": "almofreixar",
    "almofreixasse": "almofreixar",
    "almofreixassem": "almofreixar",
    "almofreixasses": "almofreixar",
    "almofreixaste": "almofreixar",
    "almofreixastes": "almofreixar",
    "almofreixava": "almofreixar",
    "almofreixavam": "almofreixar",
    "almofreixavas": "almofreixar",
    "almofreixe": "almofreixar",
    "almofreixei": "almofreixar",
    "almofreixeis": "almofreixar",
    "almofreixem": "almofreixar",
    "almofreixemo": "almofreixar",
    "almofreixemos": "almofreixar",
    "almofreixes": "almofreixe",
    "almofreixo": "almofreixar",
    "almofreixou": "almofreixar",
    "almofreixá": "almofreixar",
    "almofreixámo": "almofreixar",
    "almofreixámos": "almofreixar",
    "almofreixáramo": "almofreixar",
    "almofreixáramos": "almofreixar",
    "almofreixárei": "almofreixar",
    "almofreixáreis": "almofreixar",
    "almofreixásseis": "almofreixar",
    "almofreixássemos": "almofreixar",
    "almofreixávamo": "almofreixar",
    "almofreixávamos": "almofreixar",
    "almofreixávei": "almofreixar",
    "almofreixáveis": "almofreixar",
    "almogavarias": "almogavaria",
    "almogávares": "almogávar",
    "almojávenas": "almojávena",
    "almorávidas": "almorávida",
    "almorávides": "almorávide",
    "almos": "almo",
    "almotace": "almotaçar",
    "almotacei": "almotaçar",
    "almotaceis": "almotaçar",
    "almotacem": "almotaçar",
    "almotacemo": "almotaçar",
    "almotacemos": "almotaçar",
    "almotaces": "almotaçar",
    "almotacéis": "almotacel",
    "almotacés": "almotacé",
    "almotaça": "almotaçar",
    "almotaçada": "almotaçar",
    "almotaçadas": "almotaçar",
    "almotaçado": "almotaçar",
    "almotaçados": "almotaçar",
    "almotaçai": "almotaçar",
    "almotaçais": "almotaçar",
    "almotaçam": "almotaçar",
    "almotaçamo": "almotaçar",
    "almotaçamos": "almotaçar",
    "almotaçando": "almotaçar",
    "almotaçara": "almotaçar",
    "almotaçaram": "almotaçar",
    "almotaçaras": "almotaçar",
    "almotaçarde": "almotaçar",
    "almotaçardes": "almotaçar",
    "almotaçare": "almotaçar",
    "almotaçarei": "almotaçar",
    "almotaçareis": "almotaçar",
    "almotaçarem": "almotaçar",
    "almotaçaremos": "almotaçar",
    "almotaçares": "almotaçar",
    "almotaçaria": "almotaçar",
    "almotaçariam": "almotaçar",
    "almotaçarias": "almotaçaria",
    "almotaçarmo": "almotaçar",
    "almotaçarmos": "almotaçar",
    "almotaçará": "almotaçar",
    "almotaçarás": "almotaçar",
    "almotaçarão": "almotaçar",
    "almotaçaríamos": "almotaçar",
    "almotaçaríeis": "almotaçar",
    "almotaças": "almotaçar",
    "almotaçasse": "almotaçar",
    "almotaçassem": "almotaçar",
    "almotaçasses": "almotaçar",
    "almotaçaste": "almotaçar",
    "almotaçastes": "almotaçar",
    "almotaçava": "almotaçar",
    "almotaçavam": "almotaçar",
    "almotaçavas": "almotaçar",
    "almotaço": "almotaçar",
    "almotaçou": "almotaçar",
    "almotaçá": "almotaçar",
    "almotaçámo": "almotaçar",
    "almotaçámos": "almotaçar",
    "almotaçáramo": "almotaçar",
    "almotaçáramos": "almotaçar",
    "almotaçárei": "almotaçar",
    "almotaçáreis": "almotaçar",
    "almotaçásseis": "almotaçar",
    "almotaçássemos": "almotaçar",
    "almotaçávamo": "almotaçar",
    "almotaçávamos": "almotaçar",
    "almotaçávei": "almotaçar",
    "almotaçáveis": "almotaçar",
    "almotolias": "almotolia",
    "almoxarifados": "almoxarifado",
    "almoxarifes": "almoxarife",
    "almoxatres": "almoxatre",
    "almoça": "almoçar",
    "almoçada": "almoçar",
    "almoçadas": "almoçar",
    "almoçadeiras": "almoçadeira",
    "almoçado": "almoçar",
    "almoçados": "almoçar",
    "almoçai": "almoçar",
    "almoçais": "almoçar",
    "almoçam": "almoçar",
    "almoçamo": "almoçar",
    "almoçamos": "almoçar",
    "almoçando": "almoçar",
    "almoçara": "almoçar",
    "almoçaradas": "almoçarada",
    "almoçaram": "almoçar",
    "almoçaras": "almoçar",
    "almoçardes": "almoçar",
    "almoçarei": "almoçar",
    "almoçareis": "almoçar",
    "almoçarem": "almoçar",
    "almoçaremos": "almoçar",
    "almoçares": "almoçar",
    "almoçaria": "almoçar",
    "almoçariam": "almoçar",
    "almoçarias": "almoçar",
    "almoçarmo": "almoçar",
    "almoçarmos": "almoçar",
    "almoçará": "almoçar",
    "almoçarás": "almoçar",
    "almoçarão": "almoçar",
    "almoçaríamos": "almoçar",
    "almoçaríeis": "almoçar",
    "almoças": "almoçar",
    "almoçasse": "almoçar",
    "almoçassem": "almoçar",
    "almoçasses": "almoçar",
    "almoçaste": "almoçar",
    "almoçastes": "almoçar",
    "almoçava": "almoçar",
    "almoçavam": "almoçar",
    "almoçavas": "almoçar",
    "almoço": "almoçar",
    "almoços": "almoço",
    "almoçou": "almoçar",
    "almoçámo": "almoçar",
    "almoçámos": "almoçar",
    "almoçáramo": "almoçar",
    "almoçáramos": "almoçar",
    "almoçáreis": "almoçar",
    "almoçásseis": "almoçar",
    "almoçássemos": "almoçar",
    "almoçávamo": "almoçar",
    "almoçávamos": "almoçar",
    "almoçáveis": "almoçar",
    "almuadens": "almuadem",
    "almucábalas": "almucábala",
    "almucântaras": "almucântara",
    "almuda": "almudar",
    "almudada": "almudar",
    "almudadas": "almudar",
    "almudado": "almudar",
    "almudados": "almudar",
    "almudai": "almudar",
    "almudais": "almudar",
    "almudam": "almudar",
    "almudamo": "almudar",
    "almudamos": "almudar",
    "almudando": "almudar",
    "almudara": "almudar",
    "almudaram": "almudar",
    "almudaras": "almudar",
    "almudarde": "almudar",
    "almudardes": "almudar",
    "almudare": "almudar",
    "almudarei": "almudar",
    "almudareis": "almudar",
    "almudarem": "almudar",
    "almudaremos": "almudar",
    "almudares": "almudar",
    "almudaria": "almudar",
    "almudariam": "almudar",
    "almudarias": "almudar",
    "almudarmo": "almudar",
    "almudarmos": "almudar",
    "almudará": "almudar",
    "almudarás": "almudar",
    "almudarão": "almudar",
    "almudaríamos": "almudar",
    "almudaríeis": "almudar",
    "almudas": "almudar",
    "almudasse": "almudar",
    "almudassem": "almudar",
    "almudasses": "almudar",
    "almudaste": "almudar",
    "almudastes": "almudar",
    "almudava": "almudar",
    "almudavam": "almudar",
    "almudavas": "almudar",
    "almudações": "almudação",
    "almude": "almudar",
    "almudei": "almudar",
    "almudeira": "almudeiro",
    "almudeiras": "almudeiro",
    "almudeiros": "almudeiro",
    "almudeis": "almudar",
    "almudem": "almudar",
    "almudemo": "almudar",
    "almudemos": "almudar",
    "almudes": "almude",
    "almudo": "almudar",
    "almudou": "almudar",
    "almudá": "almudar",
    "almudámo": "almudar",
    "almudámos": "almudar",
    "almudáramo": "almudar",
    "almudáramos": "almudar",
    "almudárei": "almudar",
    "almudáreis": "almudar",
    "almudásseis": "almudar",
    "almudássemos": "almudar",
    "almudávamo": "almudar",
    "almudávamos": "almudar",
    "almudávei": "almudar",
    "almudáveis": "almudar",
    "almuinhas": "almuinha",
    "almácegas": "almácega",
    "almácegos": "almácego",
    "almádenas": "almádena",
    "almáfegos": "almáfego",
    "almárfegas": "almárfega",
    "almários": "almário",
    "almártagas": "almártaga",
    "almártegas": "almártega",
    "almécegas": "almécega",
    "almêitegas": "almêitega",
    "almêitigas": "almêitiga",
    "almíscares": "almíscar",
    "almóadas": "almóada",
    "almóades": "almóade",
    "almôndegas": "almôndega",
    "alnicos": "alnico",
    "alo": "alar",
    "alocações": "alocação",
    "alocentrismos": "alocentrismo",
    "alocroada": "alocroado",
    "alocroadas": "alocroado",
    "alocroados": "alocroado",
    "alocromatias": "alocromatia",
    "alocromatismos": "alocromatismo",
    "alocromática": "alocromático",
    "alocromáticas": "alocromático",
    "alocromáticos": "alocromático",
    "alocroísmos": "alocroísmo",
    "alocuções": "alocução",
    "alodiais": "alodial",
    "alodialidades": "alodialidade",
    "alodês": "alodê",
    "aloendreiros": "aloendreiro",
    "aloendros": "aloendro",
    "aloetatos": "aloetato",
    "aloetinas": "aloetina",
    "alofanas": "alofana",
    "alofila": "alofilo",
    "alofilas": "alofilo",
    "alofilos": "alofilo",
    "alofones": "alofone",
    "aloftalmias": "aloftalmia",
    "aloftálmica": "aloftálmico",
    "aloftálmicas": "aloftálmico",
    "aloftálmicos": "aloftálmico",
    "alofânios": "alofânio",
    "alogamias": "alogamia",
    "alogiana": "alogiano",
    "alogianas": "alogiano",
    "alogianos": "alogiano",
    "alogias": "alogia",
    "alogismos": "alogismo",
    "alognosias": "alognosia",
    "alografias": "alografia",
    "alográfica": "alográfico",
    "alográficas": "alográfico",
    "alográficos": "alográfico",
    "alogénica": "alogénico",
    "alogénicas": "alogénico",
    "alogénicos": "alogénico",
    "aloilada": "aloilado",
    "aloiladas": "aloilado",
    "aloilados": "aloilado",
    "aloinada": "aloinado",
    "aloinadas": "aloinado",
    "aloinados": "aloinado",
    "aloira": "aloirar",
    "aloirada": "aloirar",
    "aloiradas": "aloirar",
    "aloirado": "aloirar",
    "aloirados": "aloirar",
    "aloirai": "aloirar",
    "aloirais": "aloirar",
    "aloiram": "aloirar",
    "aloiramo": "aloirar",
    "aloiramos": "aloirar",
    "aloirando": "aloirar",
    "aloirara": "aloirar",
    "aloiraram": "aloirar",
    "aloiraras": "aloirar",
    "aloirarde": "aloirar",
    "aloirardes": "aloirar",
    "aloirare": "aloirar",
    "aloirarei": "aloirar",
    "aloirareis": "aloirar",
    "aloirarem": "aloirar",
    "aloiraremos": "aloirar",
    "aloirares": "aloirar",
    "aloiraria": "aloirar",
    "aloirariam": "aloirar",
    "aloirarias": "aloirar",
    "aloirarmo": "aloirar",
    "aloirarmos": "aloirar",
    "aloirará": "aloirar",
    "aloirarás": "aloirar",
    "aloirarão": "aloirar",
    "aloiraríamos": "aloirar",
    "aloiraríeis": "aloirar",
    "aloiras": "aloirar",
    "aloirasse": "aloirar",
    "aloirassem": "aloirar",
    "aloirasses": "aloirar",
    "aloiraste": "aloirar",
    "aloirastes": "aloirar",
    "aloirava": "aloirar",
    "aloiravam": "aloirar",
    "aloiravas": "aloirar",
    "aloire": "aloirar",
    "aloirei": "aloirar",
    "aloireis": "aloirar",
    "aloirem": "aloirar",
    "aloiremo": "aloirar",
    "aloiremos": "aloirar",
    "aloires": "aloirar",
    "aloiro": "aloirar",
    "aloirou": "aloirar",
    "aloirá": "aloirar",
    "aloirámo": "aloirar",
    "aloirámos": "aloirar",
    "aloiráramo": "aloirar",
    "aloiráramos": "aloirar",
    "aloirárei": "aloirar",
    "aloiráreis": "aloirar",
    "aloirásseis": "aloirar",
    "aloirássemos": "aloirar",
    "aloirávamo": "aloirar",
    "aloirávamos": "aloirar",
    "aloirávei": "aloirar",
    "aloiráveis": "aloirar",
    "aloisa": "aloisar",
    "aloisada": "aloisar",
    "aloisadas": "aloisar",
    "aloisado": "aloisar",
    "aloisados": "aloisar",
    "aloisai": "aloisar",
    "aloisais": "aloisar",
    "aloisam": "aloisar",
    "aloisamo": "aloisar",
    "aloisamos": "aloisar",
    "aloisando": "aloisar",
    "aloisara": "aloisar",
    "aloisaram": "aloisar",
    "aloisaras": "aloisar",
    "aloisarde": "aloisar",
    "aloisardes": "aloisar",
    "aloisare": "aloisar",
    "aloisarei": "aloisar",
    "aloisareis": "aloisar",
    "aloisarem": "aloisar",
    "aloisaremos": "aloisar",
    "aloisares": "aloisar",
    "aloisaria": "aloisar",
    "aloisariam": "aloisar",
    "aloisarias": "aloisar",
    "aloisarmo": "aloisar",
    "aloisarmos": "aloisar",
    "aloisará": "aloisar",
    "aloisarás": "aloisar",
    "aloisarão": "aloisar",
    "aloisaríamos": "aloisar",
    "aloisaríeis": "aloisar",
    "aloisas": "aloisar",
    "aloisasse": "aloisar",
    "aloisassem": "aloisar",
    "aloisasses": "aloisar",
    "aloisaste": "aloisar",
    "aloisastes": "aloisar",
    "aloisava": "aloisar",
    "aloisavam": "aloisar",
    "aloisavas": "aloisar",
    "aloise": "aloisar",
    "aloisei": "aloisar",
    "aloiseis": "aloisar",
    "aloisem": "aloisar",
    "aloisemo": "aloisar",
    "aloisemos": "aloisar",
    "aloises": "aloisar",
    "aloiso": "aloisar",
    "aloisou": "aloisar",
    "aloisá": "aloisar",
    "aloisámo": "aloisar",
    "aloisámos": "aloisar",
    "aloisáramo": "aloisar",
    "aloisáramos": "aloisar",
    "aloisárei": "aloisar",
    "aloisáreis": "aloisar",
    "aloisásseis": "aloisar",
    "aloisássemos": "aloisar",
    "aloisávamo": "aloisar",
    "aloisávamos": "aloisar",
    "aloisávei": "aloisar",
    "aloisáveis": "aloisar",
    "aloja": "alojar",
    "alojada": "alojar",
    "alojadas": "alojar",
    "alojado": "alojar",
    "alojadora": "alojador",
    "alojadoras": "alojador",
    "alojadores": "alojador",
    "alojados": "alojar",
    "alojai": "alojar",
    "alojais": "alojar",
    "alojam": "alojar",
    "alojamentos": "alojamento",
    "alojamo": "alojar",
    "alojamos": "alojar",
    "alojando": "alojar",
    "alojara": "alojar",
    "alojaram": "alojar",
    "alojaras": "alojar",
    "alojarde": "alojar",
    "alojardes": "alojar",
    "alojare": "alojar",
    "alojarei": "alojar",
    "alojareis": "alojar",
    "alojarem": "alojar",
    "alojaremos": "alojar",
    "alojares": "alojar",
    "alojaria": "alojar",
    "alojariam": "alojar",
    "alojarias": "alojar",
    "alojarmo": "alojar",
    "alojarmos": "alojar",
    "alojará": "alojar",
    "alojarás": "alojar",
    "alojarão": "alojar",
    "alojaríamos": "alojar",
    "alojaríeis": "alojar",
    "alojas": "alojar",
    "alojasse": "alojar",
    "alojassem": "alojar",
    "alojasses": "alojar",
    "alojaste": "alojar",
    "alojastes": "alojar",
    "alojava": "alojar",
    "alojavam": "alojar",
    "alojavas": "alojar",
    "aloje": "alojar",
    "alojei": "alojar",
    "alojeis": "alojar",
    "alojem": "alojar",
    "alojemo": "alojar",
    "alojemos": "alojar",
    "alojes": "alojar",
    "alojo": "alojar",
    "alojos": "alojo",
    "alojou": "alojar",
    "alojá": "alojar",
    "alojámo": "alojar",
    "alojámos": "alojar",
    "alojáramo": "alojar",
    "alojáramos": "alojar",
    "alojárei": "alojar",
    "alojáreis": "alojar",
    "alojásseis": "alojar",
    "alojássemos": "alojar",
    "alojávamo": "alojar",
    "alojávamos": "alojar",
    "alojávei": "alojar",
    "alojáveis": "alojável",
    "alolaias": "alolaia",
    "alomba": "alombar",
    "alombada": "alombar",
    "alombadas": "alombar",
    "alombado": "alombar",
    "alombados": "alombar",
    "alombai": "alombar",
    "alombais": "alombar",
    "alombam": "alombar",
    "alombamentos": "alombamento",
    "alombamo": "alombar",
    "alombamos": "alombar",
    "alombando": "alombar",
    "alombara": "alombar",
    "alombaram": "alombar",
    "alombaras": "alombar",
    "alombarde": "alombar",
    "alombardes": "alombar",
    "alombare": "alombar",
    "alombarei": "alombar",
    "alombareis": "alombar",
    "alombarem": "alombar",
    "alombaremos": "alombar",
    "alombares": "alombar",
    "alombaria": "alombar",
    "alombariam": "alombar",
    "alombarias": "alombar",
    "alombarmo": "alombar",
    "alombarmos": "alombar",
    "alombará": "alombar",
    "alombarás": "alombar",
    "alombarão": "alombar",
    "alombaríamos": "alombar",
    "alombaríeis": "alombar",
    "alombas": "alombar",
    "alombasse": "alombar",
    "alombassem": "alombar",
    "alombasses": "alombar",
    "alombaste": "alombar",
    "alombastes": "alombar",
    "alombava": "alombar",
    "alombavam": "alombar",
    "alombavas": "alombar",
    "alombe": "alombar",
    "alombei": "alombar",
    "alombeis": "alombar",
    "alombem": "alombar",
    "alombemo": "alombar",
    "alombemos": "alombar",
    "alombes": "alombar",
    "alombo": "alombar",
    "alombora": "alomborar",
    "alomborada": "alomborar",
    "alomboradas": "alomborar",
    "alomborado": "alomborar",
    "alomborados": "alomborar",
    "alomborai": "alomborar",
    "alomborais": "alomborar",
    "alomboram": "alomborar",
    "alomboramo": "alomborar",
    "alomboramos": "alomborar",
    "alomborando": "alomborar",
    "alomborara": "alomborar",
    "alomboraram": "alomborar",
    "alomboraras": "alomborar",
    "alomborarde": "alomborar",
    "alomborardes": "alomborar",
    "alomborare": "alomborar",
    "alomborarei": "alomborar",
    "alomborareis": "alomborar",
    "alomborarem": "alomborar",
    "alomboraremos": "alomborar",
    "alomborares": "alomborar",
    "alomboraria": "alomborar",
    "alomborariam": "alomborar",
    "alomborarias": "alomborar",
    "alomborarmo": "alomborar",
    "alomborarmos": "alomborar",
    "alomborará": "alomborar",
    "alomborarás": "alomborar",
    "alomborarão": "alomborar",
    "alomboraríamos": "alomborar",
    "alomboraríeis": "alomborar",
    "alomboras": "alomborar",
    "alomborasse": "alomborar",
    "alomborassem": "alomborar",
    "alomborasses": "alomborar",
    "alomboraste": "alomborar",
    "alomborastes": "alomborar",
    "alomborava": "alomborar",
    "alomboravam": "alomborar",
    "alomboravas": "alomborar",
    "alombore": "alomborar",
    "alomborei": "alomborar",
    "alomboreis": "alomborar",
    "alomborem": "alomborar",
    "alomboremo": "alomborar",
    "alomboremos": "alomborar",
    "alombores": "alomborar",
    "alomboro": "alomborar",
    "alomborou": "alomborar",
    "alomborá": "alomborar",
    "alomborámo": "alomborar",
    "alomborámos": "alomborar",
    "alomboráramo": "alomborar",
    "alomboráramos": "alomborar",
    "alomborárei": "alomborar",
    "alomboráreis": "alomborar",
    "alomborásseis": "alomborar",
    "alomborássemos": "alomborar",
    "alomborávamo": "alomborar",
    "alomborávamos": "alomborar",
    "alomborávei": "alomborar",
    "alomboráveis": "alomborar",
    "alombou": "alombar",
    "alombá": "alombar",
    "alombámo": "alombar",
    "alombámos": "alombar",
    "alombáramo": "alombar",
    "alombáramos": "alombar",
    "alombárei": "alombar",
    "alombáreis": "alombar",
    "alombásseis": "alombar",
    "alombássemos": "alombar",
    "alombávamo": "alombar",
    "alombávamos": "alombar",
    "alombávei": "alombar",
    "alombáveis": "alombar",
    "alometrias": "alometria",
    "alomorfes": "alomorfe",
    "alomorfias": "alomorfia",
    "alomorfismos": "alomorfismo",
    "alomórfica": "alomórfico",
    "alomórficas": "alomórfico",
    "alomórficos": "alomórfico",
    "alonga": "alongar",
    "alongada": "alongar",
    "alongadas": "alongar",
    "alongado": "alongar",
    "alongados": "alongar",
    "alongai": "alongar",
    "alongais": "alongar",
    "alongam": "alongar",
    "alongamentos": "alongamento",
    "alongamo": "alongar",
    "alongamos": "alongar",
    "alongando": "alongar",
    "alongara": "alongar",
    "alongaram": "alongar",
    "alongaras": "alongar",
    "alongarde": "alongar",
    "alongardes": "alongar",
    "alongare": "alongar",
    "alongarei": "alongar",
    "alongareis": "alongar",
    "alongarem": "alongar",
    "alongaremos": "alongar",
    "alongares": "alongar",
    "alongaria": "alongar",
    "alongariam": "alongar",
    "alongarias": "alongar",
    "alongarmo": "alongar",
    "alongarmos": "alongar",
    "alongará": "alongar",
    "alongarás": "alongar",
    "alongarão": "alongar",
    "alongaríamos": "alongar",
    "alongaríeis": "alongar",
    "alongas": "alongar",
    "alongasse": "alongar",
    "alongassem": "alongar",
    "alongasses": "alongar",
    "alongaste": "alongar",
    "alongastes": "alongar",
    "alongava": "alongar",
    "alongavam": "alongar",
    "alongavas": "alongar",
    "alongo": "alongar",
    "alongou": "alongar",
    "alongue": "alongar",
    "alonguei": "alongar",
    "alongueis": "alongar",
    "alonguem": "alongar",
    "alonguemo": "alongar",
    "alonguemos": "alongar",
    "alongues": "alongar",
    "alongá": "alongar",
    "alongámo": "alongar",
    "alongámos": "alongar",
    "alongáramo": "alongar",
    "alongáramos": "alongar",
    "alongárei": "alongar",
    "alongáreis": "alongar",
    "alongásseis": "alongar",
    "alongássemos": "alongar",
    "alongávamo": "alongar",
    "alongávamos": "alongar",
    "alongávei": "alongar",
    "alongáveis": "alongável",
    "alonsa": "alonso",
    "alonsas": "alonso",
    "alonsos": "alonso",
    "alopatas": "alopata",
    "alopatias": "alopatia",
    "alopatiza": "alopatizar",
    "alopatizada": "alopatizar",
    "alopatizadas": "alopatizar",
    "alopatizado": "alopatizar",
    "alopatizados": "alopatizar",
    "alopatizai": "alopatizar",
    "alopatizais": "alopatizar",
    "alopatizam": "alopatizar",
    "alopatizamo": "alopatizar",
    "alopatizamos": "alopatizar",
    "alopatizando": "alopatizar",
    "alopatizara": "alopatizar",
    "alopatizaram": "alopatizar",
    "alopatizaras": "alopatizar",
    "alopatizarde": "alopatizar",
    "alopatizardes": "alopatizar",
    "alopatizare": "alopatizar",
    "alopatizarei": "alopatizar",
    "alopatizareis": "alopatizar",
    "alopatizarem": "alopatizar",
    "alopatizaremos": "alopatizar",
    "alopatizares": "alopatizar",
    "alopatizaria": "alopatizar",
    "alopatizariam": "alopatizar",
    "alopatizarias": "alopatizar",
    "alopatizarmo": "alopatizar",
    "alopatizarmos": "alopatizar",
    "alopatizará": "alopatizar",
    "alopatizarás": "alopatizar",
    "alopatizarão": "alopatizar",
    "alopatizaríamos": "alopatizar",
    "alopatizaríeis": "alopatizar",
    "alopatizas": "alopatizar",
    "alopatizasse": "alopatizar",
    "alopatizassem": "alopatizar",
    "alopatizasses": "alopatizar",
    "alopatizaste": "alopatizar",
    "alopatizastes": "alopatizar",
    "alopatizava": "alopatizar",
    "alopatizavam": "alopatizar",
    "alopatizavas": "alopatizar",
    "alopatize": "alopatizar",
    "alopatizei": "alopatizar",
    "alopatizeis": "alopatizar",
    "alopatizem": "alopatizar",
    "alopatizemo": "alopatizar",
    "alopatizemos": "alopatizar",
    "alopatizes": "alopatizar",
    "alopatizo": "alopatizar",
    "alopatizou": "alopatizar",
    "alopatizá": "alopatizar",
    "alopatizámo": "alopatizar",
    "alopatizámos": "alopatizar",
    "alopatizáramo": "alopatizar",
    "alopatizáramos": "alopatizar",
    "alopatizárei": "alopatizar",
    "alopatizáreis": "alopatizar",
    "alopatizásseis": "alopatizar",
    "alopatizássemos": "alopatizar",
    "alopatizávamo": "alopatizar",
    "alopatizávamos": "alopatizar",
    "alopatizávei": "alopatizar",
    "alopatizáveis": "alopatizar",
    "alopecias": "alopecia",
    "aloplastias": "aloplastia",
    "alopática": "alopático",
    "alopáticas": "alopático",
    "alopáticos": "alopático",
    "alopécica": "alopécico",
    "alopécicas": "alopécico",
    "alopécicos": "alopécico",
    "alopética": "alopético",
    "alopéticas": "alopético",
    "alopéticos": "alopético",
    "aloquetes": "aloquete",
    "alores": "alor",
    "alorpada": "alorpado",
    "alorpadas": "alorpado",
    "alorpados": "alorpado",
    "alosnas": "alosna",
    "alossomos": "alossomo",
    "alota": "alotar",
    "alotada": "alotar",
    "alotadas": "alotar",
    "alotado": "alotar",
    "alotados": "alotar",
    "alotai": "alotar",
    "alotais": "alotar",
    "alotam": "alotar",
    "alotamo": "alotar",
    "alotamos": "alotar",
    "alotando": "alotar",
    "alotara": "alotar",
    "alotaram": "alotar",
    "alotaras": "alotar",
    "alotarde": "alotar",
    "alotardes": "alotar",
    "alotare": "alotar",
    "alotarei": "alotar",
    "alotareis": "alotar",
    "alotarem": "alotar",
    "alotaremos": "alotar",
    "alotares": "alotar",
    "alotaria": "alotar",
    "alotariam": "alotar",
    "alotarias": "alotar",
    "alotarmo": "alotar",
    "alotarmos": "alotar",
    "alotará": "alotar",
    "alotarás": "alotar",
    "alotarão": "alotar",
    "alotaríamos": "alotar",
    "alotaríeis": "alotar",
    "alotas": "alotar",
    "alotasse": "alotar",
    "alotassem": "alotar",
    "alotasses": "alotar",
    "alotaste": "alotar",
    "alotastes": "alotar",
    "alotava": "alotar",
    "alotavam": "alotar",
    "alotavas": "alotar",
    "alote": "alotar",
    "alotei": "alotar",
    "aloteis": "alotar",
    "alotem": "alotar",
    "alotemo": "alotar",
    "alotemos": "alotar",
    "alotes": "alote",
    "alotigénica": "alotigénico",
    "alotigénicas": "alotigénico",
    "alotigénicos": "alotigénico",
    "aloto": "alotar",
    "alotou": "alotar",
    "alotriodontias": "alotriodontia",
    "alotriofagias": "alotriofagia",
    "alotriomorfa": "alotriomorfo",
    "alotriomorfas": "alotriomorfo",
    "alotriomorfos": "alotriomorfo",
    "alotriomórfica": "alotriomórfico",
    "alotriomórficas": "alotriomórfico",
    "alotriomórficos": "alotriomórfico",
    "alotropias": "alotropia",
    "alotrópica": "alotrópico",
    "alotrópicas": "alotrópico",
    "alotrópicos": "alotrópico",
    "alotá": "alotar",
    "alotámo": "alotar",
    "alotámos": "alotar",
    "alotáramo": "alotar",
    "alotáramos": "alotar",
    "alotárei": "alotar",
    "alotáreis": "alotar",
    "alotásseis": "alotar",
    "alotássemos": "alotar",
    "alotávamo": "alotar",
    "alotávamos": "alotar",
    "alotávei": "alotar",
    "alotáveis": "alotar",
    "alotígena": "alotígeno",
    "alotígenas": "alotígeno",
    "alotígenos": "alotígeno",
    "alou": "alar",
    "alouca": "aloucar",
    "aloucada": "aloucar",
    "aloucadas": "aloucar",
    "aloucado": "aloucar",
    "aloucados": "aloucar",
    "aloucai": "aloucar",
    "aloucais": "aloucar",
    "aloucam": "aloucar",
    "aloucamo": "aloucar",
    "aloucamos": "aloucar",
    "aloucando": "aloucar",
    "aloucara": "aloucar",
    "aloucaram": "aloucar",
    "aloucaras": "aloucar",
    "aloucarde": "aloucar",
    "aloucardes": "aloucar",
    "aloucare": "aloucar",
    "aloucarei": "aloucar",
    "aloucareis": "aloucar",
    "aloucarem": "aloucar",
    "aloucaremos": "aloucar",
    "aloucares": "aloucar",
    "aloucaria": "aloucar",
    "aloucariam": "aloucar",
    "aloucarias": "aloucar",
    "aloucarmo": "aloucar",
    "aloucarmos": "aloucar",
    "aloucará": "aloucar",
    "aloucarás": "aloucar",
    "aloucarão": "aloucar",
    "aloucaríamos": "aloucar",
    "aloucaríeis": "aloucar",
    "aloucas": "aloucar",
    "aloucasse": "aloucar",
    "aloucassem": "aloucar",
    "aloucasses": "aloucar",
    "aloucaste": "aloucar",
    "aloucastes": "aloucar",
    "aloucava": "aloucar",
    "aloucavam": "aloucar",
    "aloucavas": "aloucar",
    "alouco": "aloucar",
    "aloucou": "aloucar",
    "aloucá": "aloucar",
    "aloucámo": "aloucar",
    "aloucámos": "aloucar",
    "aloucáramo": "aloucar",
    "aloucáramos": "aloucar",
    "aloucárei": "aloucar",
    "aloucáreis": "aloucar",
    "aloucásseis": "aloucar",
    "aloucássemos": "aloucar",
    "aloucávamo": "aloucar",
    "aloucávamos": "aloucar",
    "aloucávei": "aloucar",
    "aloucáveis": "aloucar",
    "alouque": "aloucar",
    "alouquei": "aloucar",
    "alouqueis": "aloucar",
    "alouquem": "aloucar",
    "alouquemo": "aloucar",
    "alouquemos": "aloucar",
    "alouques": "aloucar",
    "aloura": "alourar",
    "alourada": "alourar",
    "alouradas": "alourar",
    "alourado": "alourar",
    "alourados": "alourar",
    "alourai": "alourar",
    "alourais": "alourar",
    "alouram": "alourar",
    "alouramo": "alourar",
    "alouramos": "alourar",
    "alourando": "alourar",
    "alourara": "alourar",
    "alouraram": "alourar",
    "alouraras": "alourar",
    "alourarde": "alourar",
    "alourardes": "alourar",
    "alourare": "alourar",
    "alourarei": "alourar",
    "alourareis": "alourar",
    "alourarem": "alourar",
    "alouraremos": "alourar",
    "alourares": "alourar",
    "alouraria": "alourar",
    "alourariam": "alourar",
    "alourarias": "alourar",
    "alourarmo": "alourar",
    "alourarmos": "alourar",
    "alourará": "alourar",
    "alourarás": "alourar",
    "alourarão": "alourar",
    "alouraríamos": "alourar",
    "alouraríeis": "alourar",
    "alouras": "alourar",
    "alourasse": "alourar",
    "alourassem": "alourar",
    "alourasses": "alourar",
    "alouraste": "alourar",
    "alourastes": "alourar",
    "alourava": "alourar",
    "alouravam": "alourar",
    "alouravas": "alourar",
    "aloure": "alourar",
    "alourei": "alourar",
    "aloureis": "alourar",
    "alourem": "alourar",
    "alouremo": "alourar",
    "alouremos": "alourar",
    "aloures": "alourar",
    "alouro": "alourar",
    "alourou": "alourar",
    "alourá": "alourar",
    "alourámo": "alourar",
    "alourámos": "alourar",
    "alouráramo": "alourar",
    "alouráramos": "alourar",
    "alourárei": "alourar",
    "alouráreis": "alourar",
    "alourásseis": "alourar",
    "alourássemos": "alourar",
    "alourávamo": "alourar",
    "alourávamos": "alourar",
    "alourávei": "alourar",
    "alouráveis": "alourar",
    "alousa": "alousar",
    "alousada": "alousar",
    "alousadas": "alousar",
    "alousado": "alousar",
    "alousados": "alousar",
    "alousai": "alousar",
    "alousais": "alousar",
    "alousam": "alousar",
    "alousamo": "alousar",
    "alousamos": "alousar",
    "alousando": "alousar",
    "alousara": "alousar",
    "alousaram": "alousar",
    "alousaras": "alousar",
    "alousarde": "alousar",
    "alousardes": "alousar",
    "alousare": "alousar",
    "alousarei": "alousar",
    "alousareis": "alousar",
    "alousarem": "alousar",
    "alousaremos": "alousar",
    "alousares": "alousar",
    "alousaria": "alousar",
    "alousariam": "alousar",
    "alousarias": "alousar",
    "alousarmo": "alousar",
    "alousarmos": "alousar",
    "alousará": "alousar",
    "alousarás": "alousar",
    "alousarão": "alousar",
    "alousaríamos": "alousar",
    "alousaríeis": "alousar",
    "alousas": "alousar",
    "alousasse": "alousar",
    "alousassem": "alousar",
    "alousasses": "alousar",
    "alousaste": "alousar",
    "alousastes": "alousar",
    "alousava": "alousar",
    "alousavam": "alousar",
    "alousavas": "alousar",
    "alouse": "alousar",
    "alousei": "alousar",
    "alouseis": "alousar",
    "alousem": "alousar",
    "alousemo": "alousar",
    "alousemos": "alousar",
    "alouses": "alousar",
    "alouso": "alousar",
    "alousou": "alousar",
    "alousá": "alousar",
    "alousámo": "alousar",
    "alousámos": "alousar",
    "alousáramo": "alousar",
    "alousáramos": "alousar",
    "alousárei": "alousar",
    "alousáreis": "alousar",
    "alousásseis": "alousar",
    "alousássemos": "alousar",
    "alousávamo": "alousar",
    "alousávamos": "alousar",
    "alousávei": "alousar",
    "alousáveis": "alousar",
    "aloés": "aloé",
    "aloética": "aloético",
    "aloéticas": "aloético",
    "aloéticos": "aloético",
    "aloínas": "aloína",
    "alpacas": "alpaca",
    "alparcas": "alparca",
    "alparcatas": "alparcata",
    "alparcateira": "alparcateiro",
    "alparcateiras": "alparcateiro",
    "alparcateiros": "alparcateiro",
    "alparcheiros": "alparcheiro",
    "alpardece": "alpardecer",
    "alpardecei": "alpardecer",
    "alpardeceis": "alpardecer",
    "alpardecem": "alpardecer",
    "alpardecemo": "alpardecer",
    "alpardecemos": "alpardecer",
    "alpardecendo": "alpardecer",
    "alpardecera": "alpardecer",
    "alpardeceram": "alpardecer",
    "alpardeceras": "alpardecer",
    "alpardecerdes": "alpardecer",
    "alpardecerei": "alpardecer",
    "alpardecereis": "alpardecer",
    "alpardecerem": "alpardecer",
    "alpardeceremos": "alpardecer",
    "alpardeceres": "alpardecer",
    "alpardeceria": "alpardecer",
    "alpardeceriam": "alpardecer",
    "alpardecerias": "alpardecer",
    "alpardecermo": "alpardecer",
    "alpardecermos": "alpardecer",
    "alpardecerá": "alpardecer",
    "alpardecerás": "alpardecer",
    "alpardecerão": "alpardecer",
    "alpardeceríamos": "alpardecer",
    "alpardeceríeis": "alpardecer",
    "alpardeces": "alpardecer",
    "alpardecesse": "alpardecer",
    "alpardecessem": "alpardecer",
    "alpardecesses": "alpardecer",
    "alpardeceste": "alpardecer",
    "alpardecestes": "alpardecer",
    "alpardeceu": "alpardecer",
    "alpardeci": "alpardecer",
    "alpardecia": "alpardecer",
    "alpardeciam": "alpardecer",
    "alpardecias": "alpardecer",
    "alpardecida": "alpardecer",
    "alpardecidas": "alpardecer",
    "alpardecido": "alpardecer",
    "alpardecidos": "alpardecer",
    "alpardecêramo": "alpardecer",
    "alpardecêramos": "alpardecer",
    "alpardecêreis": "alpardecer",
    "alpardecêsseis": "alpardecer",
    "alpardecêssemos": "alpardecer",
    "alpardecíamo": "alpardecer",
    "alpardecíamos": "alpardecer",
    "alpardecíeis": "alpardecer",
    "alpardeça": "alpardecer",
    "alpardeçais": "alpardecer",
    "alpardeçam": "alpardecer",
    "alpardeçamo": "alpardecer",
    "alpardeçamos": "alpardecer",
    "alpardeças": "alpardecer",
    "alpardeço": "alpardecer",
    "alpargatas": "alpargata",
    "alparqueira": "alparqueiro",
    "alparqueiras": "alparqueiro",
    "alparqueiros": "alparqueiro",
    "alpechins": "alpechim",
    "alpendoradas": "alpendorada",
    "alpendra": "alpendrar",
    "alpendrada": "alpendrar",
    "alpendradas": "alpendrar",
    "alpendrado": "alpendrar",
    "alpendrados": "alpendrar",
    "alpendrai": "alpendrar",
    "alpendrais": "alpendrar",
    "alpendram": "alpendrar",
    "alpendramo": "alpendrar",
    "alpendramos": "alpendrar",
    "alpendrando": "alpendrar",
    "alpendrara": "alpendrar",
    "alpendraram": "alpendrar",
    "alpendraras": "alpendrar",
    "alpendrarde": "alpendrar",
    "alpendrardes": "alpendrar",
    "alpendrare": "alpendrar",
    "alpendrarei": "alpendrar",
    "alpendrareis": "alpendrar",
    "alpendrarem": "alpendrar",
    "alpendraremos": "alpendrar",
    "alpendrares": "alpendrar",
    "alpendraria": "alpendrar",
    "alpendrariam": "alpendrar",
    "alpendrarias": "alpendrar",
    "alpendrarmo": "alpendrar",
    "alpendrarmos": "alpendrar",
    "alpendrará": "alpendrar",
    "alpendrarás": "alpendrar",
    "alpendrarão": "alpendrar",
    "alpendraríamos": "alpendrar",
    "alpendraríeis": "alpendrar",
    "alpendras": "alpendrar",
    "alpendrasse": "alpendrar",
    "alpendrassem": "alpendrar",
    "alpendrasses": "alpendrar",
    "alpendraste": "alpendrar",
    "alpendrastes": "alpendrar",
    "alpendrava": "alpendrar",
    "alpendravam": "alpendrar",
    "alpendravas": "alpendrar",
    "alpendre": "alpendrar",
    "alpendrei": "alpendrar",
    "alpendreis": "alpendrar",
    "alpendrem": "alpendrar",
    "alpendremo": "alpendrar",
    "alpendremos": "alpendrar",
    "alpendres": "alpendre",
    "alpendro": "alpendrar",
    "alpendroadas": "alpendroada",
    "alpendrou": "alpendrar",
    "alpendrá": "alpendrar",
    "alpendrámo": "alpendrar",
    "alpendrámos": "alpendrar",
    "alpendráramo": "alpendrar",
    "alpendráramos": "alpendrar",
    "alpendrárei": "alpendrar",
    "alpendráreis": "alpendrar",
    "alpendrásseis": "alpendrar",
    "alpendrássemos": "alpendrar",
    "alpendrávamo": "alpendrar",
    "alpendrávamos": "alpendrar",
    "alpendrávei": "alpendrar",
    "alpendráveis": "alpendrar",
    "alpenses": "alpense",
    "alpercatas": "alpercata",
    "alpercateira": "alpercateiro",
    "alpercateiras": "alpercateiro",
    "alpercateiros": "alpercateiro",
    "alperceiros": "alperceiro",
    "alperces": "alperce",
    "alpercheiros": "alpercheiro",
    "alperches": "alperche",
    "alpergatas": "alpergata",
    "alpestra": "alpestrar",
    "alpestrada": "alpestrar",
    "alpestradas": "alpestrar",
    "alpestrado": "alpestrar",
    "alpestrados": "alpestrar",
    "alpestrai": "alpestrar",
    "alpestrais": "alpestrar",
    "alpestram": "alpestrar",
    "alpestramo": "alpestrar",
    "alpestramos": "alpestrar",
    "alpestrando": "alpestrar",
    "alpestrara": "alpestrar",
    "alpestraram": "alpestrar",
    "alpestraras": "alpestrar",
    "alpestrarde": "alpestrar",
    "alpestrardes": "alpestrar",
    "alpestrare": "alpestrar",
    "alpestrarei": "alpestrar",
    "alpestrareis": "alpestrar",
    "alpestrarem": "alpestrar",
    "alpestraremos": "alpestrar",
    "alpestrares": "alpestrar",
    "alpestraria": "alpestrar",
    "alpestrariam": "alpestrar",
    "alpestrarias": "alpestrar",
    "alpestrarmo": "alpestrar",
    "alpestrarmos": "alpestrar",
    "alpestrará": "alpestrar",
    "alpestrarás": "alpestrar",
    "alpestrarão": "alpestrar",
    "alpestraríamos": "alpestrar",
    "alpestraríeis": "alpestrar",
    "alpestras": "alpestrar",
    "alpestrasse": "alpestrar",
    "alpestrassem": "alpestrar",
    "alpestrasses": "alpestrar",
    "alpestraste": "alpestrar",
    "alpestrastes": "alpestrar",
    "alpestrava": "alpestrar",
    "alpestravam": "alpestrar",
    "alpestravas": "alpestrar",
    "alpestre": "alpestrar",
    "alpestrei": "alpestrar",
    "alpestreis": "alpestrar",
    "alpestrem": "alpestrar",
    "alpestremo": "alpestrar",
    "alpestremos": "alpestrar",
    "alpestres": "alpestre",
    "alpestro": "alpestrar",
    "alpestrou": "alpestrar",
    "alpestrá": "alpestrar",
    "alpestrámo": "alpestrar",
    "alpestrámos": "alpestrar",
    "alpestráramo": "alpestrar",
    "alpestráramos": "alpestrar",
    "alpestrárei": "alpestrar",
    "alpestráreis": "alpestrar",
    "alpestrásseis": "alpestrar",
    "alpestrássemos": "alpestrar",
    "alpestrávamo": "alpestrar",
    "alpestrávamos": "alpestrar",
    "alpestrávei": "alpestrar",
    "alpestráveis": "alpestrar",
    "alpina": "alpino",
    "alpinada": "alpinar",
    "alpinadas": "alpinar",
    "alpinado": "alpinar",
    "alpinados": "alpinar",
    "alpinai": "alpinar",
    "alpinais": "alpinar",
    "alpinam": "alpinar",
    "alpinamo": "alpinar",
    "alpinamos": "alpinar",
    "alpinando": "alpinar",
    "alpinara": "alpinar",
    "alpinaram": "alpinar",
    "alpinaras": "alpinar",
    "alpinardes": "alpinar",
    "alpinarei": "alpinar",
    "alpinareis": "alpinar",
    "alpinarem": "alpinar",
    "alpinaremos": "alpinar",
    "alpinares": "alpinar",
    "alpinaria": "alpinar",
    "alpinariam": "alpinar",
    "alpinarias": "alpinar",
    "alpinarmo": "alpinar",
    "alpinarmos": "alpinar",
    "alpinará": "alpinar",
    "alpinarás": "alpinar",
    "alpinarão": "alpinar",
    "alpinaríamos": "alpinar",
    "alpinaríeis": "alpinar",
    "alpinas": "alpino",
    "alpinasse": "alpinar",
    "alpinassem": "alpinar",
    "alpinasses": "alpinar",
    "alpinaste": "alpinar",
    "alpinastes": "alpinar",
    "alpinava": "alpinar",
    "alpinavam": "alpinar",
    "alpinavas": "alpinar",
    "alpine": "alpinar",
    "alpinei": "alpinar",
    "alpineis": "alpinar",
    "alpinem": "alpinar",
    "alpinemo": "alpinar",
    "alpinemos": "alpinar",
    "alpines": "alpinar",
    "alpinismos": "alpinismo",
    "alpinistas": "alpinista",
    "alpino": "alpinar",
    "alpinopolenses": "alpinopolense",
    "alpinos": "alpino",
    "alpinou": "alpinar",
    "alpinámo": "alpinar",
    "alpinámos": "alpinar",
    "alpináramo": "alpinar",
    "alpináramos": "alpinar",
    "alpináreis": "alpinar",
    "alpinásseis": "alpinar",
    "alpinássemos": "alpinar",
    "alpinávamo": "alpinar",
    "alpinávamos": "alpinar",
    "alpináveis": "alpinar",
    "alpistas": "alpista",
    "alpisteiros": "alpisteiro",
    "alpistes": "alpiste",
    "alpistos": "alpisto",
    "alpivres": "alpivre",
    "alporca": "alporcar",
    "alporcada": "alporcar",
    "alporcadas": "alporcar",
    "alporcado": "alporcar",
    "alporcados": "alporcar",
    "alporcai": "alporcar",
    "alporcais": "alporcar",
    "alporcam": "alporcar",
    "alporcamo": "alporcar",
    "alporcamos": "alporcar",
    "alporcando": "alporcar",
    "alporcara": "alporcar",
    "alporcaram": "alporcar",
    "alporcaras": "alporcar",
    "alporcarde": "alporcar",
    "alporcardes": "alporcar",
    "alporcare": "alporcar",
    "alporcarei": "alporcar",
    "alporcareis": "alporcar",
    "alporcarem": "alporcar",
    "alporcaremos": "alporcar",
    "alporcares": "alporcar",
    "alporcaria": "alporcar",
    "alporcariam": "alporcar",
    "alporcarias": "alporcar",
    "alporcarmo": "alporcar",
    "alporcarmos": "alporcar",
    "alporcará": "alporcar",
    "alporcarás": "alporcar",
    "alporcarão": "alporcar",
    "alporcaríamos": "alporcar",
    "alporcaríeis": "alporcar",
    "alporcas": "alporcar",
    "alporcasse": "alporcar",
    "alporcassem": "alporcar",
    "alporcasses": "alporcar",
    "alporcaste": "alporcar",
    "alporcastes": "alporcar",
    "alporcava": "alporcar",
    "alporcavam": "alporcar",
    "alporcavas": "alporcar",
    "alporco": "alporcar",
    "alporcou": "alporcar",
    "alporcá": "alporcar",
    "alporcámo": "alporcar",
    "alporcámos": "alporcar",
    "alporcáramo": "alporcar",
    "alporcáramos": "alporcar",
    "alporcárei": "alporcar",
    "alporcáreis": "alporcar",
    "alporcásseis": "alporcar",
    "alporcássemos": "alporcar",
    "alporcávamo": "alporcar",
    "alporcávamos": "alporcar",
    "alporcávei": "alporcar",
    "alporcáveis": "alporcar",
    "alporque": "alporcar",
    "alporquei": "alporcar",
    "alporqueis": "alporcar",
    "alporquem": "alporcar",
    "alporquemo": "alporcar",
    "alporquemos": "alporcar",
    "alporquenta": "alporquento",
    "alporquentas": "alporquento",
    "alporquentos": "alporquento",
    "alporques": "alporque",
    "alporquias": "alporquia",
    "alporões": "alporão",
    "alpostizes": "alpostiz",
    "alpícolas": "alpícola",
    "alpípenes": "alpípene",
    "alquebra": "alquebrar",
    "alquebrada": "alquebrar",
    "alquebradas": "alquebrar",
    "alquebrado": "alquebrar",
    "alquebrados": "alquebrar",
    "alquebradíssima": "alquebrado",
    "alquebradíssimas": "alquebrado",
    "alquebradíssimo": "alquebrado",
    "alquebradíssimos": "alquebrado",
    "alquebrai": "alquebrar",
    "alquebrais": "alquebrar",
    "alquebram": "alquebrar",
    "alquebramentos": "alquebramento",
    "alquebramo": "alquebrar",
    "alquebramos": "alquebrar",
    "alquebrando": "alquebrar",
    "alquebrara": "alquebrar",
    "alquebraram": "alquebrar",
    "alquebraras": "alquebrar",
    "alquebrarde": "alquebrar",
    "alquebrardes": "alquebrar",
    "alquebrare": "alquebrar",
    "alquebrarei": "alquebrar",
    "alquebrareis": "alquebrar",
    "alquebrarem": "alquebrar",
    "alquebraremos": "alquebrar",
    "alquebrares": "alquebrar",
    "alquebraria": "alquebrar",
    "alquebrariam": "alquebrar",
    "alquebrarias": "alquebrar",
    "alquebrarmo": "alquebrar",
    "alquebrarmos": "alquebrar",
    "alquebrará": "alquebrar",
    "alquebrarás": "alquebrar",
    "alquebrarão": "alquebrar",
    "alquebraríamos": "alquebrar",
    "alquebraríeis": "alquebrar",
    "alquebras": "alquebrar",
    "alquebrasse": "alquebrar",
    "alquebrassem": "alquebrar",
    "alquebrasses": "alquebrar",
    "alquebraste": "alquebrar",
    "alquebrastes": "alquebrar",
    "alquebrava": "alquebrar",
    "alquebravam": "alquebrar",
    "alquebravas": "alquebrar",
    "alquebre": "alquebrar",
    "alquebrei": "alquebrar",
    "alquebreis": "alquebrar",
    "alquebrem": "alquebrar",
    "alquebremo": "alquebrar",
    "alquebremos": "alquebrar",
    "alquebres": "alquebrar",
    "alquebro": "alquebrar",
    "alquebrou": "alquebrar",
    "alquebrá": "alquebrar",
    "alquebrámo": "alquebrar",
    "alquebrámos": "alquebrar",
    "alquebráramo": "alquebrar",
    "alquebráramos": "alquebrar",
    "alquebrárei": "alquebrar",
    "alquebráreis": "alquebrar",
    "alquebrásseis": "alquebrar",
    "alquebrássemos": "alquebrar",
    "alquebrávamo": "alquebrar",
    "alquebrávamos": "alquebrar",
    "alquebrávei": "alquebrar",
    "alquebráveis": "alquebrar",
    "alqueimões": "alqueimão",
    "alqueira": "alqueirar",
    "alqueirada": "alqueirar",
    "alqueiradas": "alqueirar",
    "alqueirado": "alqueirar",
    "alqueirados": "alqueirar",
    "alqueirai": "alqueirar",
    "alqueirais": "alqueirar",
    "alqueiram": "alqueirar",
    "alqueiramentos": "alqueiramento",
    "alqueiramo": "alqueirar",
    "alqueiramos": "alqueirar",
    "alqueirando": "alqueirar",
    "alqueirara": "alqueirar",
    "alqueiraram": "alqueirar",
    "alqueiraras": "alqueirar",
    "alqueirarde": "alqueirar",
    "alqueirardes": "alqueirar",
    "alqueirare": "alqueirar",
    "alqueirarei": "alqueirar",
    "alqueirareis": "alqueirar",
    "alqueirarem": "alqueirar",
    "alqueiraremos": "alqueirar",
    "alqueirares": "alqueirar",
    "alqueiraria": "alqueirar",
    "alqueirariam": "alqueirar",
    "alqueirarias": "alqueirar",
    "alqueirarmo": "alqueirar",
    "alqueirarmos": "alqueirar",
    "alqueirará": "alqueirar",
    "alqueirarás": "alqueirar",
    "alqueirarão": "alqueirar",
    "alqueiraríamos": "alqueirar",
    "alqueiraríeis": "alqueirar",
    "alqueiras": "alqueirar",
    "alqueirasse": "alqueirar",
    "alqueirassem": "alqueirar",
    "alqueirasses": "alqueirar",
    "alqueiraste": "alqueirar",
    "alqueirastes": "alqueirar",
    "alqueirava": "alqueirar",
    "alqueiravam": "alqueirar",
    "alqueiravas": "alqueirar",
    "alqueire": "alqueirar",
    "alqueirei": "alqueirar",
    "alqueireira": "alqueireiro",
    "alqueireiras": "alqueireiro",
    "alqueireiros": "alqueireiro",
    "alqueireis": "alqueirar",
    "alqueirem": "alqueirar",
    "alqueiremo": "alqueirar",
    "alqueiremos": "alqueirar",
    "alqueires": "alqueire",
    "alqueiro": "alqueirar",
    "alqueirou": "alqueirar",
    "alqueirá": "alqueirar",
    "alqueirámo": "alqueirar",
    "alqueirámos": "alqueirar",
    "alqueiráramo": "alqueirar",
    "alqueiráramos": "alqueirar",
    "alqueirárei": "alqueirar",
    "alqueiráreis": "alqueirar",
    "alqueirásseis": "alqueirar",
    "alqueirássemos": "alqueirar",
    "alqueirávamo": "alqueirar",
    "alqueirávamos": "alqueirar",
    "alqueirávei": "alqueirar",
    "alqueiráveis": "alqueirar",
    "alqueirões": "alqueirão",
    "alqueiva": "alqueivar",
    "alqueivada": "alqueivar",
    "alqueivadas": "alqueivar",
    "alqueivado": "alqueivar",
    "alqueivados": "alqueivar",
    "alqueivai": "alqueivar",
    "alqueivais": "alqueivar",
    "alqueivam": "alqueivar",
    "alqueivamo": "alqueivar",
    "alqueivamos": "alqueivar",
    "alqueivando": "alqueivar",
    "alqueivara": "alqueivar",
    "alqueivaram": "alqueivar",
    "alqueivaras": "alqueivar",
    "alqueivarde": "alqueivar",
    "alqueivardes": "alqueivar",
    "alqueivare": "alqueivar",
    "alqueivarei": "alqueivar",
    "alqueivareis": "alqueivar",
    "alqueivarem": "alqueivar",
    "alqueivaremos": "alqueivar",
    "alqueivares": "alqueivar",
    "alqueivaria": "alqueivar",
    "alqueivariam": "alqueivar",
    "alqueivarias": "alqueivar",
    "alqueivarmo": "alqueivar",
    "alqueivarmos": "alqueivar",
    "alqueivará": "alqueivar",
    "alqueivarás": "alqueivar",
    "alqueivarão": "alqueivar",
    "alqueivaríamos": "alqueivar",
    "alqueivaríeis": "alqueivar",
    "alqueivas": "alqueivar",
    "alqueivasse": "alqueivar",
    "alqueivassem": "alqueivar",
    "alqueivasses": "alqueivar",
    "alqueivaste": "alqueivar",
    "alqueivastes": "alqueivar",
    "alqueivava": "alqueivar",
    "alqueivavam": "alqueivar",
    "alqueivavas": "alqueivar",
    "alqueive": "alqueivar",
    "alqueivei": "alqueivar",
    "alqueiveis": "alqueivar",
    "alqueivem": "alqueivar",
    "alqueivemo": "alqueivar",
    "alqueivemos": "alqueivar",
    "alqueives": "alqueive",
    "alqueivo": "alqueivar",
    "alqueivou": "alqueivar",
    "alqueivá": "alqueivar",
    "alqueivámo": "alqueivar",
    "alqueivámos": "alqueivar",
    "alqueiváramo": "alqueivar",
    "alqueiváramos": "alqueivar",
    "alqueivárei": "alqueivar",
    "alqueiváreis": "alqueivar",
    "alqueivásseis": "alqueivar",
    "alqueivássemos": "alqueivar",
    "alqueivávamo": "alqueivar",
    "alqueivávamos": "alqueivar",
    "alqueivávei": "alqueivar",
    "alqueiváveis": "alqueivar",
    "alquequenges": "alquequenge",
    "alquifas": "alquifa",
    "alquila": "alquilar",
    "alquilada": "alquilar",
    "alquiladas": "alquilar",
    "alquilado": "alquilar",
    "alquiladora": "alquilador",
    "alquiladoras": "alquilador",
    "alquiladores": "alquilador",
    "alquilados": "alquilar",
    "alquilai": "alquilar",
    "alquilais": "alquilar",
    "alquilam": "alquilar",
    "alquilamo": "alquilar",
    "alquilamos": "alquilar",
    "alquilando": "alquilar",
    "alquilara": "alquilar",
    "alquilaram": "alquilar",
    "alquilaras": "alquilar",
    "alquilarde": "alquilar",
    "alquilardes": "alquilar",
    "alquilare": "alquilar",
    "alquilarei": "alquilar",
    "alquilareis": "alquilar",
    "alquilarem": "alquilar",
    "alquilaremos": "alquilar",
    "alquilares": "alquilar",
    "alquilaria": "alquilar",
    "alquilariam": "alquilar",
    "alquilarias": "alquilaria",
    "alquilarmo": "alquilar",
    "alquilarmos": "alquilar",
    "alquilará": "alquilar",
    "alquilarás": "alquilar",
    "alquilarão": "alquilar",
    "alquilaríamos": "alquilar",
    "alquilaríeis": "alquilar",
    "alquilas": "alquilar",
    "alquilasse": "alquilar",
    "alquilassem": "alquilar",
    "alquilasses": "alquilar",
    "alquilaste": "alquilar",
    "alquilastes": "alquilar",
    "alquilatos": "alquilato",
    "alquilava": "alquilar",
    "alquilavam": "alquilar",
    "alquilavas": "alquilar",
    "alquile": "alquilar",
    "alquilei": "alquilar",
    "alquileis": "alquilar",
    "alquilem": "alquilar",
    "alquilemo": "alquilar",
    "alquilemos": "alquilar",
    "alquileres": "alquiler",
    "alquiles": "alquilar",
    "alquilo": "alquilar",
    "alquilos": "alquilo",
    "alquilou": "alquilar",
    "alquilá": "alquilar",
    "alquilámo": "alquilar",
    "alquilámos": "alquilar",
    "alquiláramo": "alquilar",
    "alquiláramos": "alquilar",
    "alquilárei": "alquilar",
    "alquiláreis": "alquilar",
    "alquilásseis": "alquilar",
    "alquilássemos": "alquilar",
    "alquilávamo": "alquilar",
    "alquilávamos": "alquilar",
    "alquilávei": "alquilar",
    "alquiláveis": "alquilar",
    "alquilés": "alquilé",
    "alquimes": "alquime",
    "alquimia": "alquimiar",
    "alquimiada": "alquimiar",
    "alquimiadas": "alquimiar",
    "alquimiado": "alquimiar",
    "alquimiados": "alquimiar",
    "alquimiai": "alquimiar",
    "alquimiais": "alquimiar",
    "alquimiam": "alquimiar",
    "alquimiamo": "alquimiar",
    "alquimiamos": "alquimiar",
    "alquimiando": "alquimiar",
    "alquimiara": "alquimiar",
    "alquimiaram": "alquimiar",
    "alquimiaras": "alquimiar",
    "alquimiardes": "alquimiar",
    "alquimiarei": "alquimiar",
    "alquimiareis": "alquimiar",
    "alquimiarem": "alquimiar",
    "alquimiaremos": "alquimiar",
    "alquimiares": "alquimiar",
    "alquimiaria": "alquimiar",
    "alquimiariam": "alquimiar",
    "alquimiarias": "alquimiar",
    "alquimiarmo": "alquimiar",
    "alquimiarmos": "alquimiar",
    "alquimiará": "alquimiar",
    "alquimiarás": "alquimiar",
    "alquimiarão": "alquimiar",
    "alquimiaríamos": "alquimiar",
    "alquimiaríeis": "alquimiar",
    "alquimias": "alquimiar",
    "alquimiasse": "alquimiar",
    "alquimiassem": "alquimiar",
    "alquimiasses": "alquimiar",
    "alquimiaste": "alquimiar",
    "alquimiastes": "alquimiar",
    "alquimiava": "alquimiar",
    "alquimiavam": "alquimiar",
    "alquimiavas": "alquimiar",
    "alquimie": "alquimiar",
    "alquimiei": "alquimiar",
    "alquimieis": "alquimiar",
    "alquimiem": "alquimiar",
    "alquimiemo": "alquimiar",
    "alquimiemos": "alquimiar",
    "alquimies": "alquimiar",
    "alquimio": "alquimiar",
    "alquimiou": "alquimiar",
    "alquimistas": "alquimista",
    "alquimiámo": "alquimiar",
    "alquimiámos": "alquimiar",
    "alquimiáramo": "alquimiar",
    "alquimiáramos": "alquimiar",
    "alquimiáreis": "alquimiar",
    "alquimiásseis": "alquimiar",
    "alquimiássemos": "alquimiar",
    "alquimiávamo": "alquimiar",
    "alquimiávamos": "alquimiar",
    "alquimiáveis": "alquimiar",
    "alquitaras": "alquitara",
    "alquitarras": "alquitarra",
    "alquitetes": "alquitete",
    "alquitiras": "alquitira",
    "alquitraves": "alquitrave",
    "alquílios": "alquílio",
    "alquímica": "alquímico",
    "alquímicas": "alquímico",
    "alquímicos": "alquímico",
    "alrutes": "alrute",
    "alsaciana": "alsaciano",
    "alsacianas": "alsaciano",
    "alsacianos": "alsaciano",
    "alsonómetros": "alsonómetro",
    "alsásias": "alsásia",
    "alta": "alto",
    "altabaixos": "altabaixo",
    "altaformas": "altaforma",
    "altamada": "altamado",
    "altamadas": "altamado",
    "altamados": "altamado",
    "altana": "altanar",
    "altanada": "altanar",
    "altanadas": "altanar",
    "altanado": "altanar",
    "altanados": "altanar",
    "altanai": "altanar",
    "altanais": "altanar",
    "altanam": "altanar",
    "altanamo": "altanar",
    "altanamos": "altanar",
    "altanando": "altanar",
    "altanara": "altanar",
    "altanaram": "altanar",
    "altanaras": "altanar",
    "altanarde": "altanar",
    "altanardes": "altanar",
    "altanare": "altanar",
    "altanarei": "altanar",
    "altanareis": "altanar",
    "altanarem": "altanar",
    "altanaremos": "altanar",
    "altanares": "altanar",
    "altanaria": "altanar",
    "altanariam": "altanar",
    "altanarias": "altanaria",
    "altanarmo": "altanar",
    "altanarmos": "altanar",
    "altanará": "altanar",
    "altanarás": "altanar",
    "altanarão": "altanar",
    "altanaríamos": "altanar",
    "altanaríeis": "altanar",
    "altanas": "altanar",
    "altanasse": "altanar",
    "altanassem": "altanar",
    "altanasses": "altanar",
    "altanaste": "altanar",
    "altanastes": "altanar",
    "altanava": "altanar",
    "altanavam": "altanar",
    "altanavas": "altanar",
    "altane": "altanar",
    "altanei": "altanar",
    "altaneira": "altaneiro",
    "altaneiras": "altaneiro",
    "altaneiros": "altaneiro",
    "altaneis": "altanar",
    "altanem": "altanar",
    "altanemo": "altanar",
    "altanemos": "altanar",
    "altanes": "altanar",
    "altanias": "altania",
    "altano": "altanar",
    "altanou": "altanar",
    "altaná": "altanar",
    "altanámo": "altanar",
    "altanámos": "altanar",
    "altanáramo": "altanar",
    "altanáramos": "altanar",
    "altanárei": "altanar",
    "altanáreis": "altanar",
    "altanásseis": "altanar",
    "altanássemos": "altanar",
    "altanávamo": "altanar",
    "altanávamos": "altanar",
    "altanávei": "altanar",
    "altanáveis": "altanar",
    "altares": "altar",
    "altarzinho": "altar",
    "altarzinhos": "altar",
    "altarzito": "altar",
    "altarzitos": "altar",
    "altas": "alto",
    "altazimutes": "altazimute",
    "alteada": "altear",
    "alteadas": "altear",
    "alteado": "altear",
    "alteadora": "alteador",
    "alteadoras": "alteador",
    "alteadores": "alteador",
    "alteados": "altear",
    "alteai": "altear",
    "alteais": "altear",
    "alteamentos": "alteamento",
    "alteamo": "altear",
    "alteamos": "altear",
    "alteando": "altear",
    "alteara": "altear",
    "altearam": "altear",
    "altearas": "altear",
    "altearde": "altear",
    "alteardes": "altear",
    "alteare": "altear",
    "altearei": "altear",
    "alteareis": "altear",
    "altearem": "altear",
    "altearemos": "altear",
    "alteares": "altear",
    "altearia": "altear",
    "alteariam": "altear",
    "altearias": "altear",
    "altearmo": "altear",
    "altearmos": "altear",
    "alteará": "altear",
    "altearás": "altear",
    "altearão": "altear",
    "altearíamos": "altear",
    "altearíeis": "altear",
    "alteasse": "altear",
    "alteassem": "altear",
    "alteasses": "altear",
    "alteaste": "altear",
    "alteastes": "altear",
    "alteava": "altear",
    "alteavam": "altear",
    "alteavas": "altear",
    "alteações": "alteação",
    "alteei": "altear",
    "alteeis": "altear",
    "alteemo": "altear",
    "alteemos": "altear",
    "alteia": "altear",
    "alteiam": "altear",
    "alteias": "alteia",
    "alteie": "altear",
    "alteiem": "altear",
    "alteies": "altear",
    "alteio": "altear",
    "alteou": "altear",
    "altera": "alterar",
    "alterabilidades": "alterabilidade",
    "alterada": "alterar",
    "alteradas": "alterar",
    "alterado": "alterar",
    "alteradora": "alterador",
    "alteradoras": "alterador",
    "alteradores": "alterador",
    "alterados": "alterar",
    "alteradíssima": "alterado",
    "alteradíssimas": "alterado",
    "alteradíssimo": "alterado",
    "alteradíssimos": "alterado",
    "alterai": "alterar",
    "alterais": "alterar",
    "alteram": "alterar",
    "alteramo": "alterar",
    "alteramos": "alterar",
    "alterando": "alterar",
    "alterantes": "alterante",
    "alterara": "alterar",
    "alteraram": "alterar",
    "alteraras": "alterar",
    "alterarde": "alterar",
    "alterardes": "alterar",
    "alterare": "alterar",
    "alterarei": "alterar",
    "alterareis": "alterar",
    "alterarem": "alterar",
    "alteraremos": "alterar",
    "alterares": "alterar",
    "alteraria": "alterar",
    "alterariam": "alterar",
    "alterarias": "alterar",
    "alterarmo": "alterar",
    "alterarmos": "alterar",
    "alterará": "alterar",
    "alterarás": "alterar",
    "alterarão": "alterar",
    "alteraríamos": "alterar",
    "alteraríeis": "alterar",
    "alteras": "alterar",
    "alterasse": "alterar",
    "alterassem": "alterar",
    "alterasses": "alterar",
    "alteraste": "alterar",
    "alterastes": "alterar",
    "alterava": "alterar",
    "alteravam": "alterar",
    "alteravas": "alterar",
    "alterações": "alteração",
    "alterca": "altercar",
    "altercada": "altercar",
    "altercadas": "altercar",
    "altercado": "altercar",
    "altercadora": "altercador",
    "altercadoras": "altercador",
    "altercadores": "altercador",
    "altercados": "altercar",
    "altercais": "altercar",
    "altercam": "altercar",
    "altercamo": "altercar",
    "altercamos": "altercar",
    "altercando": "altercar",
    "altercara": "altercar",
    "altercaram": "altercar",
    "altercaras": "altercar",
    "altercardes": "altercar",
    "altercarei": "altercar",
    "altercareis": "altercar",
    "altercarem": "altercar",
    "altercaremos": "altercar",
    "altercares": "altercar",
    "altercaria": "altercar",
    "altercariam": "altercar",
    "altercarias": "altercar",
    "altercarmo": "altercar",
    "altercarmos": "altercar",
    "altercará": "altercar",
    "altercarás": "altercar",
    "altercarão": "altercar",
    "altercaríamos": "altercar",
    "altercaríeis": "altercar",
    "altercas": "altercar",
    "altercasse": "altercar",
    "altercassem": "altercar",
    "altercasses": "altercar",
    "altercaste": "altercar",
    "altercastes": "altercar",
    "altercava": "altercar",
    "altercavam": "altercar",
    "altercavas": "altercar",
    "altercações": "altercação",
    "alterco": "altercar",
    "altercos": "alterco",
    "altercou": "altercar",
    "altercámo": "altercar",
    "altercámos": "altercar",
    "altercáramo": "altercar",
    "altercáramos": "altercar",
    "altercáreis": "altercar",
    "altercásseis": "altercar",
    "altercássemos": "altercar",
    "altercávamo": "altercar",
    "altercávamos": "altercar",
    "altercáveis": "altercar",
    "altere": "alterar",
    "alterei": "alterar",
    "altereis": "alterar",
    "alterem": "alterar",
    "alteremo": "alterar",
    "alteremos": "alterar",
    "alterenses": "alterense",
    "alteres": "alterar",
    "alteridades": "alteridade",
    "alterna": "alterno",
    "alternada": "alternar",
    "alternadas": "alternar",
    "alternado": "alternar",
    "alternadora": "alternador",
    "alternadoras": "alternador",
    "alternadores": "alternador",
    "alternados": "alternar",
    "alternai": "alternar",
    "alternais": "alternar",
    "alternam": "alternar",
    "alternamo": "alternar",
    "alternamos": "alternar",
    "alternando": "alternar",
    "alternantes": "alternante",
    "alternara": "alternar",
    "alternaram": "alternar",
    "alternaras": "alternar",
    "alternarde": "alternar",
    "alternardes": "alternar",
    "alternare": "alternar",
    "alternarei": "alternar",
    "alternareis": "alternar",
    "alternarem": "alternar",
    "alternaremos": "alternar",
    "alternares": "alternar",
    "alternaria": "alternar",
    "alternariam": "alternar",
    "alternarias": "alternar",
    "alternarmo": "alternar",
    "alternarmos": "alternar",
    "alternará": "alternar",
    "alternarás": "alternar",
    "alternarão": "alternar",
    "alternaríamos": "alternar",
    "alternaríeis": "alternar",
    "alternas": "alterno",
    "alternasse": "alternar",
    "alternassem": "alternar",
    "alternasses": "alternar",
    "alternaste": "alternar",
    "alternastes": "alternar",
    "alternativa": "alternativo",
    "alternativas": "alternativo",
    "alternativos": "alternativo",
    "alternatos": "alternato",
    "alternava": "alternar",
    "alternavam": "alternar",
    "alternavas": "alternar",
    "alternações": "alternação",
    "alterne": "alternar",
    "alternei": "alternar",
    "alterneis": "alternar",
    "alternem": "alternar",
    "alternemo": "alternar",
    "alternemos": "alternar",
    "alternes": "alternar",
    "alternidades": "alternidade",
    "alterniflora": "alternifloro",
    "alternifloras": "alternifloro",
    "alternifloros": "alternifloro",
    "alterniflórea": "alterniflóreo",
    "alterniflóreas": "alterniflóreo",
    "alterniflóreos": "alterniflóreo",
    "alternipétala": "alternipétalo",
    "alternipétalas": "alternipétalo",
    "alternipétalos": "alternipétalo",
    "alternissépala": "alternissépalo",
    "alternissépalas": "alternissépalo",
    "alternissépalos": "alternissépalo",
    "alterno": "alternar",
    "alternomotores": "alternomotor",
    "alternos": "alterno",
    "alternou": "alternar",
    "alterná": "alternar",
    "alternámo": "alternar",
    "alternámos": "alternar",
    "alternáramo": "alternar",
    "alternáramos": "alternar",
    "alternárei": "alternar",
    "alternáreis": "alternar",
    "alternásseis": "alternar",
    "alternássemos": "alternar",
    "alternávamo": "alternar",
    "alternávamos": "alternar",
    "alternávei": "alternar",
    "alternáveis": "alternável",
    "alternâncias": "alternância",
    "alternípedes": "alternípede",
    "altero": "alterar",
    "alterosa": "alteroso",
    "alterosas": "alteroso",
    "alterosos": "alteroso",
    "alterou": "alterar",
    "alterque": "altercar",
    "alterquei": "altercar",
    "alterqueis": "altercar",
    "alterquem": "altercar",
    "alterquemos": "altercar",
    "alterques": "altercar",
    "alterá": "alterar",
    "alterámo": "alterar",
    "alterámos": "alterar",
    "alteráramo": "alterar",
    "alteráramos": "alterar",
    "alterárei": "alterar",
    "alteráreis": "alterar",
    "alterásseis": "alterar",
    "alterássemos": "alterar",
    "alterávamo": "alterar",
    "alterávamos": "alterar",
    "alterávei": "alterar",
    "alteráveis": "alterável",
    "altezas": "alteza",
    "alteá": "altear",
    "alteámo": "altear",
    "alteámos": "altear",
    "alteáramo": "altear",
    "alteáramos": "altear",
    "alteárei": "altear",
    "alteáreis": "altear",
    "alteásseis": "altear",
    "alteássemos": "altear",
    "alteávamo": "altear",
    "alteávamos": "altear",
    "alteávei": "altear",
    "alteáveis": "altear",
    "alteínas": "alteína",
    "alticolúnia": "alticolúnio",
    "alticolúnias": "alticolúnio",
    "alticolúnios": "alticolúnio",
    "alticornígera": "alticornígero",
    "alticornígeras": "alticornígero",
    "alticornígeros": "alticornígero",
    "altifalantes": "altifalante",
    "altiloquentes": "altiloquente",
    "altiloquias": "altiloquia",
    "altiloquências": "altiloquência",
    "altilóquios": "altilóquio",
    "altimurada": "altimurado",
    "altimuradas": "altimurado",
    "altimurados": "altimurado",
    "altinho": "alto",
    "altinhos": "alto",
    "altiplanos": "altiplano",
    "altipotentes": "altipotente",
    "altirrostros": "altirrostro",
    "altissonantes": "altissonante",
    "altissonâncias": "altissonância",
    "altistas": "altista",
    "altito": "alto",
    "altitonantes": "altitonante",
    "altitos": "alto",
    "altitudes": "altitude",
    "altiva": "altivo",
    "altivas": "altivo",
    "altivezes": "altivez",
    "altivolantes": "altivolante",
    "altivos": "altivo",
    "altora": "altor",
    "altoras": "altor",
    "altores": "altor",
    "altos": "alto",
    "altosas": "altosa",
    "altruistas": "altruista",
    "altruísmos": "altruísmo",
    "altruístas": "altruísta",
    "altruística": "altruístico",
    "altruísticas": "altruístico",
    "altruísticos": "altruístico",
    "alturas": "altura",
    "altâncaras": "altâncara",
    "altâncaros": "altâncaro",
    "altíloqua": "altíloquo",
    "altíloquas": "altíloquo",
    "altíloquos": "altíloquo",
    "altímetros": "altímetro",
    "altíssima": "alto",
    "altíssimas": "alto",
    "altíssimo": "alto",
    "altíssimos": "alto",
    "altíssona": "altíssono",
    "altíssonas": "altíssono",
    "altíssonos": "altíssono",
    "altívaga": "altívago",
    "altívagas": "altívago",
    "altívagos": "altívago",
    "altívola": "altívolo",
    "altívolas": "altívolo",
    "altívolos": "altívolo",
    "alua": "aluir",
    "aluada": "aluar",
    "aluadas": "aluar",
    "aluado": "aluar",
    "aluados": "aluar",
    "aluadíssima": "aluado",
    "aluadíssimas": "aluado",
    "aluadíssimo": "aluado",
    "aluadíssimos": "aluado",
    "aluai": "aluar",
    "aluais": "aluir",
    "aluam": "aluir",
    "aluamentos": "aluamento",
    "aluamo": "aluir",
    "aluamos": "aluir",
    "aluando": "aluar",
    "aluara": "aluar",
    "aluarada": "aluarado",
    "aluaradas": "aluarado",
    "aluarados": "aluarado",
    "aluaram": "aluar",
    "aluaras": "aluar",
    "aluarde": "aluar",
    "aluardes": "aluar",
    "aluare": "aluar",
    "aluarei": "aluar",
    "aluareis": "aluar",
    "aluarem": "aluar",
    "aluaremos": "aluar",
    "aluares": "aluar",
    "aluaria": "aluar",
    "aluariam": "aluar",
    "aluarias": "aluar",
    "aluarmo": "aluar",
    "aluarmos": "aluar",
    "aluará": "aluar",
    "aluarás": "aluar",
    "aluarão": "aluar",
    "aluaríamos": "aluar",
    "aluaríeis": "aluar",
    "aluas": "aluir",
    "aluasse": "aluar",
    "aluassem": "aluar",
    "aluasses": "aluar",
    "aluaste": "aluar",
    "aluastes": "aluar",
    "aluava": "aluar",
    "aluavam": "aluar",
    "aluavas": "aluar",
    "alucina": "alucinar",
    "alucinada": "alucinar",
    "alucinadas": "alucinar",
    "alucinado": "alucinar",
    "alucinados": "alucinar",
    "alucinadíssima": "alucinado",
    "alucinadíssimas": "alucinado",
    "alucinadíssimo": "alucinado",
    "alucinadíssimos": "alucinado",
    "alucinai": "alucinar",
    "alucinais": "alucinar",
    "alucinam": "alucinar",
    "alucinamo": "alucinar",
    "alucinamos": "alucinar",
    "alucinando": "alucinar",
    "alucinantes": "alucinante",
    "alucinara": "alucinar",
    "alucinaram": "alucinar",
    "alucinaras": "alucinar",
    "alucinarde": "alucinar",
    "alucinardes": "alucinar",
    "alucinare": "alucinar",
    "alucinarei": "alucinar",
    "alucinareis": "alucinar",
    "alucinarem": "alucinar",
    "alucinaremos": "alucinar",
    "alucinares": "alucinar",
    "alucinaria": "alucinar",
    "alucinariam": "alucinar",
    "alucinarias": "alucinar",
    "alucinarmo": "alucinar",
    "alucinarmos": "alucinar",
    "alucinará": "alucinar",
    "alucinarás": "alucinar",
    "alucinarão": "alucinar",
    "alucinaríamos": "alucinar",
    "alucinaríeis": "alucinar",
    "alucinas": "alucinar",
    "alucinasse": "alucinar",
    "alucinassem": "alucinar",
    "alucinasses": "alucinar",
    "alucinaste": "alucinar",
    "alucinastes": "alucinar",
    "alucinatória": "alucinatório",
    "alucinatórias": "alucinatório",
    "alucinatórios": "alucinatório",
    "alucinava": "alucinar",
    "alucinavam": "alucinar",
    "alucinavas": "alucinar",
    "alucinações": "alucinação",
    "alucine": "alucinar",
    "alucinei": "alucinar",
    "alucineis": "alucinar",
    "alucinem": "alucinar",
    "alucinemo": "alucinar",
    "alucinemos": "alucinar",
    "alucines": "alucinar",
    "alucino": "alucinar",
    "alucinogénea": "alucinogéneo",
    "alucinogéneas": "alucinogéneo",
    "alucinogéneos": "alucinogéneo",
    "alucinou": "alucinar",
    "aluciná": "alucinar",
    "alucinámo": "alucinar",
    "alucinámos": "alucinar",
    "alucináramo": "alucinar",
    "alucináramos": "alucinar",
    "alucinárei": "alucinar",
    "alucináreis": "alucinar",
    "alucinásseis": "alucinar",
    "alucinássemos": "alucinar",
    "alucinávamo": "alucinar",
    "alucinávamos": "alucinar",
    "alucinávei": "alucinar",
    "alucináveis": "alucinar",
    "alucitas": "alucita",
    "aluda": "aludir",
    "aludais": "aludir",
    "aludam": "aludir",
    "aludamo": "aludir",
    "aludamos": "aludir",
    "aludas": "aludir",
    "alude": "aludir",
    "aludem": "aludir",
    "aludes": "aludir",
    "aludi": "aludir",
    "aludia": "aludir",
    "aludiam": "aludir",
    "aludias": "aludir",
    "aludida": "aludir",
    "aludidas": "aludir",
    "aludido": "aludir",
    "aludidos": "aludir",
    "aludimo": "aludir",
    "aludimos": "aludir",
    "aludindo": "aludir",
    "aludira": "aludir",
    "aludiram": "aludir",
    "aludiras": "aludir",
    "aludirdes": "aludir",
    "aludirei": "aludir",
    "aludireis": "aludir",
    "aludirem": "aludir",
    "aludiremos": "aludir",
    "aludires": "aludir",
    "aludiria": "aludir",
    "aludiriam": "aludir",
    "aludirias": "aludir",
    "aludirmo": "aludir",
    "aludirmos": "aludir",
    "aludirá": "aludir",
    "aludirás": "aludir",
    "aludirão": "aludir",
    "aludiríamos": "aludir",
    "aludiríeis": "aludir",
    "aludis": "aludir",
    "aludisse": "aludir",
    "aludissem": "aludir",
    "aludisses": "aludir",
    "aludiste": "aludir",
    "aludistes": "aludir",
    "aludiu": "aludir",
    "aludo": "aludir",
    "aludéis": "aludel",
    "aludíamo": "aludir",
    "aludíamos": "aludir",
    "aludíeis": "aludir",
    "aludíramo": "aludir",
    "aludíramos": "aludir",
    "aludíreis": "aludir",
    "aludísseis": "aludir",
    "aludíssemos": "aludir",
    "alue": "aluar",
    "aluei": "aluar",
    "alueiros": "alueiro",
    "alueis": "aluar",
    "aluem": "aluir",
    "aluemo": "aluar",
    "aluemos": "aluar",
    "alues": "aluar",
    "aluga": "alugar",
    "alugada": "alugar",
    "alugadas": "alugar",
    "alugado": "alugar",
    "alugadora": "alugador",
    "alugadoras": "alugador",
    "alugadores": "alugador",
    "alugados": "alugar",
    "alugai": "alugar",
    "alugais": "alugar",
    "alugam": "alugar",
    "alugamentos": "alugamento",
    "alugamo": "alugar",
    "alugamos": "alugar",
    "alugando": "alugar",
    "alugara": "alugar",
    "alugaram": "alugar",
    "alugaras": "alugar",
    "alugarde": "alugar",
    "alugardes": "alugar",
    "alugare": "alugar",
    "alugarei": "alugar",
    "alugareis": "alugar",
    "alugarem": "alugar",
    "alugaremos": "alugar",
    "alugares": "alugar",
    "alugaria": "alugar",
    "alugariam": "alugar",
    "alugarias": "alugar",
    "alugarmo": "alugar",
    "alugarmos": "alugar",
    "alugará": "alugar",
    "alugarás": "alugar",
    "alugarão": "alugar",
    "alugaríamos": "alugar",
    "alugaríeis": "alugar",
    "alugas": "alugar",
    "alugasse": "alugar",
    "alugassem": "alugar",
    "alugasses": "alugar",
    "alugaste": "alugar",
    "alugastes": "alugar",
    "alugatária": "alugatário",
    "alugatárias": "alugatário",
    "alugatários": "alugatário",
    "alugava": "alugar",
    "alugavam": "alugar",
    "alugavas": "alugar",
    "alugações": "alugação",
    "alugo": "alugar",
    "alugou": "alugar",
    "alugue": "alugar",
    "aluguei": "alugar",
    "alugueis": "alugar",
    "aluguem": "alugar",
    "aluguemo": "alugar",
    "aluguemos": "alugar",
    "alugueres": "aluguer",
    "alugues": "alugar",
    "aluguéis": "aluguel",
    "alugá": "alugar",
    "alugámo": "alugar",
    "alugámos": "alugar",
    "alugáramo": "alugar",
    "alugáramos": "alugar",
    "alugárei": "alugar",
    "alugáreis": "alugar",
    "alugásseis": "alugar",
    "alugássemos": "alugar",
    "alugávamo": "alugar",
    "alugávamos": "alugar",
    "alugávei": "alugar",
    "alugáveis": "alugável",
    "alui": "aluir",
    "aluimentos": "aluimento",
    "aluindo": "aluir",
    "aluirde": "aluir",
    "aluirdes": "aluir",
    "aluirei": "aluir",
    "aluireis": "aluir",
    "aluiremos": "aluir",
    "aluiria": "aluir",
    "aluiriam": "aluir",
    "aluirias": "aluir",
    "aluirmo": "aluir",
    "aluirmos": "aluir",
    "aluirá": "aluir",
    "aluirás": "aluir",
    "aluirão": "aluir",
    "aluiríamos": "aluir",
    "aluiríeis": "aluir",
    "aluis": "aluir",
    "aluiu": "aluir",
    "aluições": "aluição",
    "alumagens": "alumagem",
    "alumbramentos": "alumbramento",
    "alumia": "alumiar",
    "alumiada": "alumiar",
    "alumiadas": "alumiar",
    "alumiado": "alumiar",
    "alumiadora": "alumiador",
    "alumiadoras": "alumiador",
    "alumiadores": "alumiador",
    "alumiados": "alumiar",
    "alumiai": "alumiar",
    "alumiais": "alumiar",
    "alumiam": "alumiar",
    "alumiamentos": "alumiamento",
    "alumiamo": "alumiar",
    "alumiamos": "alumiar",
    "alumiando": "alumiar",
    "alumiara": "alumiar",
    "alumiaram": "alumiar",
    "alumiaras": "alumiar",
    "alumiarde": "alumiar",
    "alumiardes": "alumiar",
    "alumiare": "alumiar",
    "alumiarei": "alumiar",
    "alumiareis": "alumiar",
    "alumiarem": "alumiar",
    "alumiaremos": "alumiar",
    "alumiares": "alumiar",
    "alumiaria": "alumiar",
    "alumiariam": "alumiar",
    "alumiarias": "alumiar",
    "alumiarmo": "alumiar",
    "alumiarmos": "alumiar",
    "alumiará": "alumiar",
    "alumiarás": "alumiar",
    "alumiarão": "alumiar",
    "alumiaríamos": "alumiar",
    "alumiaríeis": "alumiar",
    "alumias": "alumiar",
    "alumiasse": "alumiar",
    "alumiassem": "alumiar",
    "alumiasses": "alumiar",
    "alumiaste": "alumiar",
    "alumiastes": "alumiar",
    "alumiava": "alumiar",
    "alumiavam": "alumiar",
    "alumiavas": "alumiar",
    "alumiações": "alumiação",
    "alumie": "alumiar",
    "alumiei": "alumiar",
    "alumieis": "alumiar",
    "alumiem": "alumiar",
    "alumiemo": "alumiar",
    "alumiemos": "alumiar",
    "alumies": "alumiar",
    "alumina": "aluminar",
    "aluminada": "aluminar",
    "aluminadas": "aluminar",
    "aluminado": "aluminar",
    "aluminados": "aluminar",
    "aluminagens": "aluminagem",
    "aluminai": "aluminar",
    "aluminais": "aluminar",
    "aluminam": "aluminar",
    "aluminamo": "aluminar",
    "aluminamos": "aluminar",
    "aluminando": "aluminar",
    "aluminara": "aluminar",
    "aluminaram": "aluminar",
    "aluminaras": "aluminar",
    "aluminarde": "aluminar",
    "aluminardes": "aluminar",
    "aluminare": "aluminar",
    "aluminarei": "aluminar",
    "aluminareis": "aluminar",
    "aluminarem": "aluminar",
    "aluminaremos": "aluminar",
    "aluminares": "aluminar",
    "aluminaria": "aluminar",
    "aluminariam": "aluminar",
    "aluminarias": "aluminar",
    "aluminarmo": "aluminar",
    "aluminarmos": "aluminar",
    "aluminará": "aluminar",
    "aluminarás": "aluminar",
    "aluminarão": "aluminar",
    "aluminaríamos": "aluminar",
    "aluminaríeis": "aluminar",
    "aluminas": "aluminar",
    "aluminasse": "aluminar",
    "aluminassem": "aluminar",
    "aluminasses": "aluminar",
    "aluminaste": "aluminar",
    "aluminastes": "aluminar",
    "aluminatos": "aluminato",
    "aluminava": "aluminar",
    "aluminavam": "aluminar",
    "aluminavas": "aluminar",
    "aluminações": "aluminação",
    "alumine": "aluminar",
    "aluminei": "aluminar",
    "alumineis": "aluminar",
    "aluminem": "aluminar",
    "aluminemo": "aluminar",
    "aluminemos": "aluminar",
    "alumines": "aluminar",
    "aluminites": "aluminite",
    "aluminizações": "aluminização",
    "alumino": "aluminar",
    "aluminografias": "aluminografia",
    "aluminosa": "aluminoso",
    "aluminosas": "aluminoso",
    "aluminoses": "aluminose",
    "aluminosos": "aluminoso",
    "aluminotermias": "aluminotermia",
    "aluminou": "aluminar",
    "aluminá": "aluminar",
    "aluminámo": "aluminar",
    "aluminámos": "aluminar",
    "alumináramo": "aluminar",
    "alumináramos": "aluminar",
    "aluminárei": "aluminar",
    "alumináreis": "aluminar",
    "aluminásseis": "aluminar",
    "aluminássemos": "aluminar",
    "aluminávamo": "aluminar",
    "aluminávamos": "aluminar",
    "aluminávei": "aluminar",
    "alumináveis": "aluminar",
    "aluminífera": "aluminífero",
    "aluminíferas": "aluminífero",
    "aluminíferos": "aluminífero",
    "alumio": "alumiar",
    "alumiou": "alumiar",
    "alumiá": "alumiar",
    "alumiámo": "alumiar",
    "alumiámos": "alumiar",
    "alumiáramo": "alumiar",
    "alumiáramos": "alumiar",
    "alumiárei": "alumiar",
    "alumiáreis": "alumiar",
    "alumiásseis": "alumiar",
    "alumiássemos": "alumiar",
    "alumiávamo": "alumiar",
    "alumiávamos": "alumiar",
    "alumiávei": "alumiar",
    "alumiáveis": "alumiar",
    "alumínica": "alumínico",
    "alumínicas": "alumínico",
    "alumínicos": "alumínico",
    "alumínios": "alumínio",
    "aluna": "aluno",
    "alunada": "alunar",
    "alunadas": "alunar",
    "alunado": "alunar",
    "alunados": "alunar",
    "alunagens": "alunagem",
    "alunai": "alunar",
    "alunais": "alunar",
    "alunam": "alunar",
    "alunamo": "alunar",
    "alunamos": "alunar",
    "alunando": "alunar",
    "alunara": "alunar",
    "alunaram": "alunar",
    "alunaras": "alunar",
    "alunardes": "alunar",
    "alunarei": "alunar",
    "alunareis": "alunar",
    "alunarem": "alunar",
    "alunaremos": "alunar",
    "alunares": "alunar",
    "alunaria": "alunar",
    "alunariam": "alunar",
    "alunarias": "alunar",
    "alunarmo": "alunar",
    "alunarmos": "alunar",
    "alunará": "alunar",
    "alunarás": "alunar",
    "alunarão": "alunar",
    "alunaríamos": "alunar",
    "alunaríeis": "alunar",
    "alunas": "aluno",
    "alunasse": "alunar",
    "alunassem": "alunar",
    "alunasses": "alunar",
    "alunaste": "alunar",
    "alunastes": "alunar",
    "alunava": "alunar",
    "alunavam": "alunar",
    "alunavas": "alunar",
    "alundos": "alundo",
    "alune": "alunar",
    "alunei": "alunar",
    "aluneis": "alunar",
    "alunem": "alunar",
    "alunemo": "alunar",
    "alunemos": "alunar",
    "alunes": "alunar",
    "alunissagens": "alunissagem",
    "aluno": "alunar",
    "alunos": "aluno",
    "alunou": "alunar",
    "alunámo": "alunar",
    "alunámos": "alunar",
    "alunáramo": "alunar",
    "alunáramos": "alunar",
    "alunáreis": "alunar",
    "alunásseis": "alunar",
    "alunássemos": "alunar",
    "alunávamo": "alunar",
    "alunávamos": "alunar",
    "alunáveis": "alunar",
    "aluo": "aluir",
    "aluou": "aluar",
    "alusitanada": "alusitanado",
    "alusitanadas": "alusitanado",
    "alusitanados": "alusitanado",
    "alusiva": "alusivo",
    "alusivas": "alusivo",
    "alusivos": "alusivo",
    "alusões": "alusão",
    "aluta": "alutar",
    "alutada": "alutar",
    "alutadas": "alutar",
    "alutado": "alutar",
    "alutados": "alutar",
    "alutai": "alutar",
    "alutais": "alutar",
    "alutam": "alutar",
    "alutamo": "alutar",
    "alutamos": "alutar",
    "alutando": "alutar",
    "alutara": "alutar",
    "alutaram": "alutar",
    "alutaras": "alutar",
    "alutarde": "alutar",
    "alutardes": "alutar",
    "alutare": "alutar",
    "alutarei": "alutar",
    "alutareis": "alutar",
    "alutarem": "alutar",
    "alutaremos": "alutar",
    "alutares": "alutar",
    "alutaria": "alutar",
    "alutariam": "alutar",
    "alutarias": "alutar",
    "alutarmo": "alutar",
    "alutarmos": "alutar",
    "alutará": "alutar",
    "alutarás": "alutar",
    "alutarão": "alutar",
    "alutaríamos": "alutar",
    "alutaríeis": "alutar",
    "alutas": "alutar",
    "alutasse": "alutar",
    "alutassem": "alutar",
    "alutasses": "alutar",
    "alutaste": "alutar",
    "alutastes": "alutar",
    "alutava": "alutar",
    "alutavam": "alutar",
    "alutavas": "alutar",
    "alute": "alutar",
    "alutei": "alutar",
    "aluteis": "alutar",
    "alutem": "alutar",
    "alutemo": "alutar",
    "alutemos": "alutar",
    "alutes": "alutar",
    "aluto": "alutar",
    "alutou": "alutar",
    "alutá": "alutar",
    "alutámo": "alutar",
    "alutámos": "alutar",
    "alutáramo": "alutar",
    "alutáramos": "alutar",
    "alutárei": "alutar",
    "alutáreis": "alutar",
    "alutásseis": "alutar",
    "alutássemos": "alutar",
    "alutávamo": "alutar",
    "alutávamos": "alutar",
    "alutávei": "alutar",
    "alutáveis": "alutar",
    "aluvia": "aluviar",
    "aluviada": "aluviar",
    "aluviadas": "aluviar",
    "aluviado": "aluviar",
    "aluviados": "aluviar",
    "aluviai": "aluviar",
    "aluviais": "aluviar",
    "aluviam": "aluviar",
    "aluviamentos": "aluviamento",
    "aluviamo": "aluviar",
    "aluviamos": "aluviar",
    "aluviana": "aluviano",
    "aluvianas": "aluviano",
    "aluviando": "aluviar",
    "aluvianos": "aluviano",
    "aluviara": "aluviar",
    "aluviaram": "aluviar",
    "aluviaras": "aluviar",
    "aluviarde": "aluviar",
    "aluviardes": "aluviar",
    "aluviare": "aluviar",
    "aluviarei": "aluviar",
    "aluviareis": "aluviar",
    "aluviarem": "aluviar",
    "aluviaremos": "aluviar",
    "aluviares": "aluviar",
    "aluviaria": "aluviar",
    "aluviariam": "aluviar",
    "aluviarias": "aluviar",
    "aluviarmo": "aluviar",
    "aluviarmos": "aluviar",
    "aluviará": "aluviar",
    "aluviarás": "aluviar",
    "aluviarão": "aluviar",
    "aluviaríamos": "aluviar",
    "aluviaríeis": "aluviar",
    "aluvias": "aluviar",
    "aluviasse": "aluviar",
    "aluviassem": "aluviar",
    "aluviasses": "aluviar",
    "aluviaste": "aluviar",
    "aluviastes": "aluviar",
    "aluviava": "aluviar",
    "aluviavam": "aluviar",
    "aluviavas": "aluviar",
    "aluvie": "aluviar",
    "aluviei": "aluviar",
    "aluvieis": "aluviar",
    "aluviem": "aluviar",
    "aluviemo": "aluviar",
    "aluviemos": "aluviar",
    "aluvies": "aluviar",
    "aluvio": "aluviar",
    "aluvionares": "aluvionar",
    "aluviou": "aluviar",
    "aluviá": "aluviar",
    "aluviámo": "aluviar",
    "aluviámos": "aluviar",
    "aluviáramo": "aluviar",
    "aluviáramos": "aluviar",
    "aluviárei": "aluviar",
    "aluviáreis": "aluviar",
    "aluviásseis": "aluviar",
    "aluviássemos": "aluviar",
    "aluviávamo": "aluviar",
    "aluviávamos": "aluviar",
    "aluviávei": "aluviar",
    "aluviáveis": "aluviar",
    "aluviónica": "aluviónico",
    "aluviónicas": "aluviónico",
    "aluviónicos": "aluviónico",
    "aluviões": "aluvião",
    "aluxa": "aluxar",
    "aluxada": "aluxar",
    "aluxadas": "aluxar",
    "aluxado": "aluxar",
    "aluxados": "aluxar",
    "aluxai": "aluxar",
    "aluxais": "aluxar",
    "aluxam": "aluxar",
    "aluxamo": "aluxar",
    "aluxamos": "aluxar",
    "aluxando": "aluxar",
    "aluxara": "aluxar",
    "aluxaram": "aluxar",
    "aluxaras": "aluxar",
    "aluxarde": "aluxar",
    "aluxardes": "aluxar",
    "aluxare": "aluxar",
    "aluxarei": "aluxar",
    "aluxareis": "aluxar",
    "aluxarem": "aluxar",
    "aluxaremos": "aluxar",
    "aluxares": "aluxar",
    "aluxaria": "aluxar",
    "aluxariam": "aluxar",
    "aluxarias": "aluxar",
    "aluxarmo": "aluxar",
    "aluxarmos": "aluxar",
    "aluxará": "aluxar",
    "aluxarás": "aluxar",
    "aluxarão": "aluxar",
    "aluxaríamos": "aluxar",
    "aluxaríeis": "aluxar",
    "aluxas": "aluxar",
    "aluxasse": "aluxar",
    "aluxassem": "aluxar",
    "aluxasses": "aluxar",
    "aluxaste": "aluxar",
    "aluxastes": "aluxar",
    "aluxava": "aluxar",
    "aluxavam": "aluxar",
    "aluxavas": "aluxar",
    "aluxe": "aluxar",
    "aluxei": "aluxar",
    "aluxeis": "aluxar",
    "aluxem": "aluxar",
    "aluxemo": "aluxar",
    "aluxemos": "aluxar",
    "aluxes": "aluxar",
    "aluxo": "aluxar",
    "aluxou": "aluxar",
    "aluxá": "aluxar",
    "aluxámo": "aluxar",
    "aluxámos": "aluxar",
    "aluxáramo": "aluxar",
    "aluxáramos": "aluxar",
    "aluxárei": "aluxar",
    "aluxáreis": "aluxar",
    "aluxásseis": "aluxar",
    "aluxássemos": "aluxar",
    "aluxávamo": "aluxar",
    "aluxávamos": "aluxar",
    "aluxávei": "aluxar",
    "aluxáveis": "aluxar",
    "aluá": "aluar",
    "aluámo": "aluar",
    "aluámos": "aluar",
    "aluáramo": "aluar",
    "aluáramos": "aluar",
    "aluárei": "aluar",
    "aluáreis": "aluar",
    "aluásseis": "aluar",
    "aluássemos": "aluar",
    "aluávamo": "aluar",
    "aluávamos": "aluar",
    "aluávei": "aluar",
    "aluáveis": "aluar",
    "aluí": "aluir",
    "aluía": "aluir",
    "aluíam": "aluir",
    "aluíamo": "aluir",
    "aluíamos": "aluir",
    "aluías": "aluir",
    "aluída": "aluir",
    "aluídas": "aluir",
    "aluído": "aluir",
    "aluídos": "aluir",
    "aluíei": "aluir",
    "aluíeis": "aluir",
    "aluímo": "aluir",
    "aluímos": "aluir",
    "aluíra": "aluir",
    "aluíram": "aluir",
    "aluíramo": "aluir",
    "aluíramos": "aluir",
    "aluíras": "aluir",
    "aluíre": "aluir",
    "aluírei": "aluir",
    "aluíreis": "aluir",
    "aluírem": "aluir",
    "aluíres": "aluir",
    "aluís": "aluir",
    "aluísse": "aluir",
    "aluísseis": "aluir",
    "aluíssem": "aluir",
    "aluíssemos": "aluir",
    "aluísses": "aluir",
    "aluíste": "aluir",
    "aluístes": "aluir",
    "alva": "alvo",
    "alvacenta": "alvacento",
    "alvacentada": "alvacentar",
    "alvacentadas": "alvacentar",
    "alvacentado": "alvacentar",
    "alvacentados": "alvacentar",
    "alvacentai": "alvacentar",
    "alvacentais": "alvacentar",
    "alvacentam": "alvacentar",
    "alvacentamo": "alvacentar",
    "alvacentamos": "alvacentar",
    "alvacentando": "alvacentar",
    "alvacentara": "alvacentar",
    "alvacentaram": "alvacentar",
    "alvacentaras": "alvacentar",
    "alvacentarde": "alvacentar",
    "alvacentardes": "alvacentar",
    "alvacentare": "alvacentar",
    "alvacentarei": "alvacentar",
    "alvacentareis": "alvacentar",
    "alvacentarem": "alvacentar",
    "alvacentaremos": "alvacentar",
    "alvacentares": "alvacentar",
    "alvacentaria": "alvacentar",
    "alvacentariam": "alvacentar",
    "alvacentarias": "alvacentar",
    "alvacentarmo": "alvacentar",
    "alvacentarmos": "alvacentar",
    "alvacentará": "alvacentar",
    "alvacentarás": "alvacentar",
    "alvacentarão": "alvacentar",
    "alvacentaríamos": "alvacentar",
    "alvacentaríeis": "alvacentar",
    "alvacentas": "alvacento",
    "alvacentasse": "alvacentar",
    "alvacentassem": "alvacentar",
    "alvacentasses": "alvacentar",
    "alvacentaste": "alvacentar",
    "alvacentastes": "alvacentar",
    "alvacentava": "alvacentar",
    "alvacentavam": "alvacentar",
    "alvacentavas": "alvacentar",
    "alvacente": "alvacentar",
    "alvacentei": "alvacentar",
    "alvacenteis": "alvacentar",
    "alvacentem": "alvacentar",
    "alvacentemo": "alvacentar",
    "alvacentemos": "alvacentar",
    "alvacentes": "alvacentar",
    "alvacento": "alvacentar",
    "alvacentos": "alvacento",
    "alvacentou": "alvacentar",
    "alvacentá": "alvacentar",
    "alvacentámo": "alvacentar",
    "alvacentámos": "alvacentar",
    "alvacentáramo": "alvacentar",
    "alvacentáramos": "alvacentar",
    "alvacentárei": "alvacentar",
    "alvacentáreis": "alvacentar",
    "alvacentásseis": "alvacentar",
    "alvacentássemos": "alvacentar",
    "alvacentávamo": "alvacentar",
    "alvacentávamos": "alvacentar",
    "alvacentávei": "alvacentar",
    "alvacentáveis": "alvacentar",
    "alvacins": "alvacim",
    "alvacoras": "alvacora",
    "alvacás": "alvacá",
    "alvadas": "alvada",
    "alvadia": "alvadio",
    "alvadias": "alvadio",
    "alvadios": "alvadio",
    "alvados": "alvado",
    "alvadurões": "alvadurão",
    "alvaiada": "alvaiadar",
    "alvaiadada": "alvaiadar",
    "alvaiadadas": "alvaiadar",
    "alvaiadado": "alvaiadar",
    "alvaiadados": "alvaiadar",
    "alvaiadai": "alvaiadar",
    "alvaiadais": "alvaiadar",
    "alvaiadam": "alvaiadar",
    "alvaiadamo": "alvaiadar",
    "alvaiadamos": "alvaiadar",
    "alvaiadando": "alvaiadar",
    "alvaiadara": "alvaiadar",
    "alvaiadaram": "alvaiadar",
    "alvaiadaras": "alvaiadar",
    "alvaiadarde": "alvaiadar",
    "alvaiadardes": "alvaiadar",
    "alvaiadare": "alvaiadar",
    "alvaiadarei": "alvaiadar",
    "alvaiadareis": "alvaiadar",
    "alvaiadarem": "alvaiadar",
    "alvaiadaremos": "alvaiadar",
    "alvaiadares": "alvaiadar",
    "alvaiadaria": "alvaiadar",
    "alvaiadariam": "alvaiadar",
    "alvaiadarias": "alvaiadar",
    "alvaiadarmo": "alvaiadar",
    "alvaiadarmos": "alvaiadar",
    "alvaiadará": "alvaiadar",
    "alvaiadarás": "alvaiadar",
    "alvaiadarão": "alvaiadar",
    "alvaiadaríamos": "alvaiadar",
    "alvaiadaríeis": "alvaiadar",
    "alvaiadas": "alvaiadar",
    "alvaiadasse": "alvaiadar",
    "alvaiadassem": "alvaiadar",
    "alvaiadasses": "alvaiadar",
    "alvaiadaste": "alvaiadar",
    "alvaiadastes": "alvaiadar",
    "alvaiadava": "alvaiadar",
    "alvaiadavam": "alvaiadar",
    "alvaiadavas": "alvaiadar",
    "alvaiade": "alvaiadar",
    "alvaiadei": "alvaiadar",
    "alvaiadeis": "alvaiadar",
    "alvaiadem": "alvaiadar",
    "alvaiademo": "alvaiadar",
    "alvaiademos": "alvaiadar",
    "alvaiades": "alvaiade",
    "alvaiado": "alvaiadar",
    "alvaiados": "alvaiado",
    "alvaiadou": "alvaiadar",
    "alvaiadá": "alvaiadar",
    "alvaiadámo": "alvaiadar",
    "alvaiadámos": "alvaiadar",
    "alvaiadáramo": "alvaiadar",
    "alvaiadáramos": "alvaiadar",
    "alvaiadárei": "alvaiadar",
    "alvaiadáreis": "alvaiadar",
    "alvaiadásseis": "alvaiadar",
    "alvaiadássemos": "alvaiadar",
    "alvaiadávamo": "alvaiadar",
    "alvaiadávamos": "alvaiadar",
    "alvaiadávei": "alvaiadar",
    "alvaiadáveis": "alvaiadar",
    "alvalades": "alvalade",
    "alvaneiras": "alvaneira",
    "alvanesas": "alvanesa",
    "alvanhais": "alvanhal",
    "alvanéis": "alvanel",
    "alvanéus": "alvanéu",
    "alvarazes": "alvaraz",
    "alvarazos": "alvarazo",
    "alvaraças": "alvaraça",
    "alvaraços": "alvaraço",
    "alvarejas": "alvareja",
    "alvarelhas": "alvarelha",
    "alvarelhões": "alvarelhão",
    "alvarengas": "alvarenga",
    "alvares": "alvar",
    "alvarinha": "alvarinho",
    "alvarinhas": "alvarinho",
    "alvarinhos": "alvarinho",
    "alvarrais": "alvarral",
    "alvarudões": "alvarudão",
    "alvarás": "alvará",
    "alvas": "alvo",
    "alvazelhas": "alvazelha",
    "alvazis": "alvazil",
    "alvaçuzes": "alvaçuz",
    "alvações": "alvação",
    "alveada": "alvear",
    "alveadas": "alvear",
    "alveado": "alvear",
    "alveadora": "alveador",
    "alveadoras": "alveador",
    "alveadores": "alveador",
    "alveados": "alvear",
    "alveai": "alvear",
    "alveais": "alvear",
    "alveamentos": "alveamento",
    "alveamo": "alvear",
    "alveamos": "alvear",
    "alveando": "alvear",
    "alveara": "alvear",
    "alvearam": "alvear",
    "alvearas": "alvear",
    "alvearde": "alvear",
    "alveardes": "alvear",
    "alveare": "alvear",
    "alvearei": "alvear",
    "alveareis": "alvear",
    "alvearem": "alvear",
    "alvearemos": "alvear",
    "alveares": "alvear",
    "alvearia": "alvear",
    "alveariam": "alvear",
    "alvearias": "alvear",
    "alvearmo": "alvear",
    "alvearmos": "alvear",
    "alveará": "alvear",
    "alvearás": "alvear",
    "alvearão": "alvear",
    "alvearíamos": "alvear",
    "alvearíeis": "alvear",
    "alveasse": "alvear",
    "alveassem": "alvear",
    "alveasses": "alvear",
    "alveaste": "alvear",
    "alveastes": "alvear",
    "alveava": "alvear",
    "alveavam": "alvear",
    "alveavas": "alvear",
    "alvedrios": "alvedrio",
    "alveei": "alvear",
    "alveeis": "alvear",
    "alveemo": "alvear",
    "alveemos": "alvear",
    "alveia": "alvear",
    "alveiam": "alvear",
    "alveias": "alvear",
    "alveie": "alvear",
    "alveiem": "alvear",
    "alveies": "alvear",
    "alveio": "alvear",
    "alveira": "alveiro",
    "alveiras": "alveiro",
    "alveiros": "alveiro",
    "alveitara": "alveitarar",
    "alveitarada": "alveitarar",
    "alveitaradas": "alveitarar",
    "alveitarado": "alveitarar",
    "alveitarados": "alveitarar",
    "alveitarai": "alveitarar",
    "alveitarais": "alveitarar",
    "alveitaram": "alveitarar",
    "alveitaramo": "alveitarar",
    "alveitaramos": "alveitarar",
    "alveitarando": "alveitarar",
    "alveitarara": "alveitarar",
    "alveitararam": "alveitarar",
    "alveitararas": "alveitarar",
    "alveitarardes": "alveitarar",
    "alveitararei": "alveitarar",
    "alveitarareis": "alveitarar",
    "alveitararem": "alveitarar",
    "alveitararemos": "alveitarar",
    "alveitarares": "alveitarar",
    "alveitararia": "alveitarar",
    "alveitarariam": "alveitarar",
    "alveitararias": "alveitarar",
    "alveitararmo": "alveitarar",
    "alveitararmos": "alveitarar",
    "alveitarará": "alveitarar",
    "alveitararás": "alveitarar",
    "alveitararão": "alveitarar",
    "alveitararíamos": "alveitarar",
    "alveitararíeis": "alveitarar",
    "alveitaras": "alveitarar",
    "alveitarasse": "alveitarar",
    "alveitarassem": "alveitarar",
    "alveitarasses": "alveitarar",
    "alveitaraste": "alveitarar",
    "alveitarastes": "alveitarar",
    "alveitarava": "alveitarar",
    "alveitaravam": "alveitarar",
    "alveitaravas": "alveitarar",
    "alveitare": "alveitarar",
    "alveitarei": "alveitarar",
    "alveitareis": "alveitarar",
    "alveitarem": "alveitarar",
    "alveitaremo": "alveitarar",
    "alveitaremos": "alveitarar",
    "alveitares": "alveitarar",
    "alveitarias": "alveitaria",
    "alveitaro": "alveitarar",
    "alveitarou": "alveitarar",
    "alveitarámo": "alveitarar",
    "alveitarámos": "alveitarar",
    "alveitaráramo": "alveitarar",
    "alveitaráramos": "alveitarar",
    "alveitaráreis": "alveitarar",
    "alveitarásseis": "alveitarar",
    "alveitarássemos": "alveitarar",
    "alveitarávamo": "alveitarar",
    "alveitarávamos": "alveitarar",
    "alveitaráveis": "alveitarar",
    "alveja": "alvejar",
    "alvejada": "alvejar",
    "alvejadas": "alvejar",
    "alvejado": "alvejar",
    "alvejados": "alvejar",
    "alvejai": "alvejar",
    "alvejais": "alvejar",
    "alvejam": "alvejar",
    "alvejamo": "alvejar",
    "alvejamos": "alvejar",
    "alvejando": "alvejar",
    "alvejantes": "alvejante",
    "alvejara": "alvejar",
    "alvejaram": "alvejar",
    "alvejaras": "alvejar",
    "alvejarde": "alvejar",
    "alvejardes": "alvejar",
    "alvejare": "alvejar",
    "alvejarei": "alvejar",
    "alvejareis": "alvejar",
    "alvejarem": "alvejar",
    "alvejaremos": "alvejar",
    "alvejares": "alvejar",
    "alvejaria": "alvejar",
    "alvejariam": "alvejar",
    "alvejarias": "alvejar",
    "alvejarmo": "alvejar",
    "alvejarmos": "alvejar",
    "alvejará": "alvejar",
    "alvejarás": "alvejar",
    "alvejarão": "alvejar",
    "alvejaríamos": "alvejar",
    "alvejaríeis": "alvejar",
    "alvejas": "alvejar",
    "alvejasse": "alvejar",
    "alvejassem": "alvejar",
    "alvejasses": "alvejar",
    "alvejaste": "alvejar",
    "alvejastes": "alvejar",
    "alvejava": "alvejar",
    "alvejavam": "alvejar",
    "alvejavas": "alvejar",
    "alveje": "alvejar",
    "alvejei": "alvejar",
    "alvejeis": "alvejar",
    "alvejem": "alvejar",
    "alvejemo": "alvejar",
    "alvejemos": "alvejar",
    "alvejes": "alvejar",
    "alvejo": "alvejar",
    "alvejou": "alvejar",
    "alvejá": "alvejar",
    "alvejámo": "alvejar",
    "alvejámos": "alvejar",
    "alvejáramo": "alvejar",
    "alvejáramos": "alvejar",
    "alvejárei": "alvejar",
    "alvejáreis": "alvejar",
    "alvejásseis": "alvejar",
    "alvejássemos": "alvejar",
    "alvejávamo": "alvejar",
    "alvejávamos": "alvejar",
    "alvejávei": "alvejar",
    "alvejáveis": "alvejável",
    "alvelas": "alvela",
    "alveliços": "alveliço",
    "alvenarias": "alvenaria",
    "alveneres": "alvener",
    "alvenéis": "alvenel",
    "alvenéus": "alvenéu",
    "alveolada": "alveolado",
    "alveoladas": "alveolado",
    "alveolados": "alveolado",
    "alveolares": "alveolar",
    "alveoliformes": "alveoliforme",
    "alveolites": "alveolite",
    "alveolífera": "alveolífero",
    "alveolíferas": "alveolífero",
    "alveolíferos": "alveolífero",
    "alveou": "alvear",
    "alvercadas": "alvercada",
    "alvercas": "alverca",
    "alvergues": "alvergue",
    "alvesce": "alvescer",
    "alvescei": "alvescer",
    "alvesceis": "alvescer",
    "alvescem": "alvescer",
    "alvescemo": "alvescer",
    "alvescemos": "alvescer",
    "alvescendo": "alvescer",
    "alvescentes": "alvescente",
    "alvescera": "alvescer",
    "alvesceram": "alvescer",
    "alvesceras": "alvescer",
    "alvescerdes": "alvescer",
    "alvescerei": "alvescer",
    "alvescereis": "alvescer",
    "alvescerem": "alvescer",
    "alvesceremos": "alvescer",
    "alvesceres": "alvescer",
    "alvesceria": "alvescer",
    "alvesceriam": "alvescer",
    "alvescerias": "alvescer",
    "alvescermo": "alvescer",
    "alvescermos": "alvescer",
    "alvescerá": "alvescer",
    "alvescerás": "alvescer",
    "alvescerão": "alvescer",
    "alvesceríamos": "alvescer",
    "alvesceríeis": "alvescer",
    "alvesces": "alvescer",
    "alvescesse": "alvescer",
    "alvescessem": "alvescer",
    "alvescesses": "alvescer",
    "alvesceste": "alvescer",
    "alvescestes": "alvescer",
    "alvesceu": "alvescer",
    "alvesci": "alvescer",
    "alvescia": "alvescer",
    "alvesciam": "alvescer",
    "alvescias": "alvescer",
    "alvescida": "alvescer",
    "alvescidas": "alvescer",
    "alvescido": "alvescer",
    "alvescidos": "alvescer",
    "alvescêramo": "alvescer",
    "alvescêramos": "alvescer",
    "alvescêreis": "alvescer",
    "alvescêsseis": "alvescer",
    "alvescêssemos": "alvescer",
    "alvescíamo": "alvescer",
    "alvescíamos": "alvescer",
    "alvescíeis": "alvescer",
    "alvesça": "alvescer",
    "alvesçais": "alvescer",
    "alvesçam": "alvescer",
    "alvesçamo": "alvescer",
    "alvesçamos": "alvescer",
    "alvesças": "alvescer",
    "alvesço": "alvescer",
    "alveá": "alvear",
    "alveámo": "alvear",
    "alveámos": "alvear",
    "alveáramo": "alvear",
    "alveáramos": "alvear",
    "alveárei": "alvear",
    "alveáreis": "alvear",
    "alveários": "alveário",
    "alveásseis": "alvear",
    "alveássemos": "alvear",
    "alveávamo": "alvear",
    "alveávamos": "alvear",
    "alveávei": "alvear",
    "alveáveis": "alvear",
    "alvidra": "alvidrar",
    "alvidrada": "alvidrar",
    "alvidradas": "alvidrar",
    "alvidrado": "alvidrar",
    "alvidradora": "alvidrador",
    "alvidradoras": "alvidrador",
    "alvidradores": "alvidrador",
    "alvidrados": "alvidrar",
    "alvidrai": "alvidrar",
    "alvidrais": "alvidrar",
    "alvidram": "alvidrar",
    "alvidramentos": "alvidramento",
    "alvidramo": "alvidrar",
    "alvidramos": "alvidrar",
    "alvidrando": "alvidrar",
    "alvidrara": "alvidrar",
    "alvidraram": "alvidrar",
    "alvidraras": "alvidrar",
    "alvidrarde": "alvidrar",
    "alvidrardes": "alvidrar",
    "alvidrare": "alvidrar",
    "alvidrarei": "alvidrar",
    "alvidrareis": "alvidrar",
    "alvidrarem": "alvidrar",
    "alvidraremos": "alvidrar",
    "alvidrares": "alvidrar",
    "alvidraria": "alvidrar",
    "alvidrariam": "alvidrar",
    "alvidrarias": "alvidrar",
    "alvidrarmo": "alvidrar",
    "alvidrarmos": "alvidrar",
    "alvidrará": "alvidrar",
    "alvidrarás": "alvidrar",
    "alvidrarão": "alvidrar",
    "alvidraríamos": "alvidrar",
    "alvidraríeis": "alvidrar",
    "alvidras": "alvidrar",
    "alvidrasse": "alvidrar",
    "alvidrassem": "alvidrar",
    "alvidrasses": "alvidrar",
    "alvidraste": "alvidrar",
    "alvidrastes": "alvidrar",
    "alvidrava": "alvidrar",
    "alvidravam": "alvidrar",
    "alvidravas": "alvidrar",
    "alvidre": "alvidrar",
    "alvidrei": "alvidrar",
    "alvidreis": "alvidrar",
    "alvidrem": "alvidrar",
    "alvidremo": "alvidrar",
    "alvidremos": "alvidrar",
    "alvidres": "alvidrar",
    "alvidro": "alvidrar",
    "alvidrou": "alvidrar",
    "alvidrá": "alvidrar",
    "alvidrámo": "alvidrar",
    "alvidrámos": "alvidrar",
    "alvidráramo": "alvidrar",
    "alvidráramos": "alvidrar",
    "alvidrárei": "alvidrar",
    "alvidráreis": "alvidrar",
    "alvidrásseis": "alvidrar",
    "alvidrássemos": "alvidrar",
    "alvidrávamo": "alvidrar",
    "alvidrávamos": "alvidrar",
    "alvidrávei": "alvidrar",
    "alvidráveis": "alvidrar",
    "alvidúlcida": "alvidúlcido",
    "alvidúlcidas": "alvidúlcido",
    "alvidúlcidos": "alvidúlcido",
    "alvina": "alvino",
    "alvinas": "alvino",
    "alvinitentes": "alvinitente",
    "alvinitências": "alvinitência",
    "alvinos": "alvino",
    "alvirrubra": "alvirrubro",
    "alvirrubras": "alvirrubro",
    "alvirrubros": "alvirrubro",
    "alvissara": "alvissarar",
    "alvissarada": "alvissarar",
    "alvissaradas": "alvissarar",
    "alvissarado": "alvissarar",
    "alvissarados": "alvissarar",
    "alvissarai": "alvissarar",
    "alvissarais": "alvissarar",
    "alvissaram": "alvissarar",
    "alvissaramo": "alvissarar",
    "alvissaramos": "alvissarar",
    "alvissarando": "alvissarar",
    "alvissarara": "alvissarar",
    "alvissararam": "alvissarar",
    "alvissararas": "alvissarar",
    "alvissararde": "alvissarar",
    "alvissarardes": "alvissarar",
    "alvissarare": "alvissarar",
    "alvissararei": "alvissarar",
    "alvissarareis": "alvissarar",
    "alvissararem": "alvissarar",
    "alvissararemos": "alvissarar",
    "alvissarares": "alvissarar",
    "alvissararia": "alvissarar",
    "alvissarariam": "alvissarar",
    "alvissararias": "alvissarar",
    "alvissararmo": "alvissarar",
    "alvissararmos": "alvissarar",
    "alvissarará": "alvissarar",
    "alvissararás": "alvissarar",
    "alvissararão": "alvissarar",
    "alvissararíamos": "alvissarar",
    "alvissararíeis": "alvissarar",
    "alvissaras": "alvissarar",
    "alvissarasse": "alvissarar",
    "alvissarassem": "alvissarar",
    "alvissarasses": "alvissarar",
    "alvissaraste": "alvissarar",
    "alvissarastes": "alvissarar",
    "alvissarava": "alvissarar",
    "alvissaravam": "alvissarar",
    "alvissaravas": "alvissarar",
    "alvissare": "alvissarar",
    "alvissarei": "alvissarar",
    "alvissareira": "alvissareiro",
    "alvissareiras": "alvissareiro",
    "alvissareiros": "alvissareiro",
    "alvissareis": "alvissarar",
    "alvissarem": "alvissarar",
    "alvissaremo": "alvissarar",
    "alvissaremos": "alvissarar",
    "alvissares": "alvissarar",
    "alvissaro": "alvissarar",
    "alvissarou": "alvissarar",
    "alvissará": "alvissarar",
    "alvissarámo": "alvissarar",
    "alvissarámos": "alvissarar",
    "alvissaráramo": "alvissarar",
    "alvissaráramos": "alvissarar",
    "alvissarárei": "alvissarar",
    "alvissaráreis": "alvissarar",
    "alvissarásseis": "alvissarar",
    "alvissarássemos": "alvissarar",
    "alvissarávamo": "alvissarar",
    "alvissarávamos": "alvissarar",
    "alvissarávei": "alvissarar",
    "alvissaráveis": "alvissarar",
    "alvitanada": "alvitanado",
    "alvitanadas": "alvitanado",
    "alvitanados": "alvitanado",
    "alvitanas": "alvitana",
    "alvitra": "alvitrar",
    "alvitrada": "alvitrar",
    "alvitradas": "alvitrar",
    "alvitrado": "alvitrar",
    "alvitradora": "alvitrador",
    "alvitradoras": "alvitrador",
    "alvitradores": "alvitrador",
    "alvitrados": "alvitrar",
    "alvitrai": "alvitrar",
    "alvitrais": "alvitrar",
    "alvitrajada": "alvitrajado",
    "alvitrajadas": "alvitrajado",
    "alvitrajados": "alvitrajado",
    "alvitram": "alvitrar",
    "alvitramentos": "alvitramento",
    "alvitramo": "alvitrar",
    "alvitramos": "alvitrar",
    "alvitrando": "alvitrar",
    "alvitrara": "alvitrar",
    "alvitraram": "alvitrar",
    "alvitraras": "alvitrar",
    "alvitrarde": "alvitrar",
    "alvitrardes": "alvitrar",
    "alvitrare": "alvitrar",
    "alvitrarei": "alvitrar",
    "alvitrareis": "alvitrar",
    "alvitrarem": "alvitrar",
    "alvitraremos": "alvitrar",
    "alvitrares": "alvitrar",
    "alvitraria": "alvitrar",
    "alvitrariam": "alvitrar",
    "alvitrarias": "alvitrar",
    "alvitrarmo": "alvitrar",
    "alvitrarmos": "alvitrar",
    "alvitrará": "alvitrar",
    "alvitrarás": "alvitrar",
    "alvitrarão": "alvitrar",
    "alvitraríamos": "alvitrar",
    "alvitraríeis": "alvitrar",
    "alvitras": "alvitrar",
    "alvitrasse": "alvitrar",
    "alvitrassem": "alvitrar",
    "alvitrasses": "alvitrar",
    "alvitraste": "alvitrar",
    "alvitrastes": "alvitrar",
    "alvitrava": "alvitrar",
    "alvitravam": "alvitrar",
    "alvitravas": "alvitrar",
    "alvitre": "alvitrar",
    "alvitrei": "alvitrar",
    "alvitreira": "alvitreiro",
    "alvitreiras": "alvitreiro",
    "alvitreiros": "alvitreiro",
    "alvitreis": "alvitrar",
    "alvitrem": "alvitrar",
    "alvitremo": "alvitrar",
    "alvitremos": "alvitrar",
    "alvitres": "alvitre",
    "alvitristas": "alvitrista",
    "alvitro": "alvitrar",
    "alvitrou": "alvitrar",
    "alvitrá": "alvitrar",
    "alvitrámo": "alvitrar",
    "alvitrámos": "alvitrar",
    "alvitráramo": "alvitrar",
    "alvitráramos": "alvitrar",
    "alvitrárei": "alvitrar",
    "alvitráreis": "alvitrar",
    "alvitrásseis": "alvitrar",
    "alvitrássemos": "alvitrar",
    "alvitrávamo": "alvitrar",
    "alvitrávamos": "alvitrar",
    "alvitrávei": "alvitrar",
    "alvitráveis": "alvitrar",
    "alviões": "alvião",
    "alvora": "alvorar",
    "alvorace": "alvoraçar",
    "alvoracei": "alvoraçar",
    "alvoraceis": "alvoraçar",
    "alvoracem": "alvoraçar",
    "alvoracemo": "alvoraçar",
    "alvoracemos": "alvoraçar",
    "alvoraces": "alvoraçar",
    "alvorada": "alvorar",
    "alvoradas": "alvorar",
    "alvorado": "alvorar",
    "alvorados": "alvorar",
    "alvorai": "alvorar",
    "alvorais": "alvorar",
    "alvoram": "alvorar",
    "alvoramo": "alvorar",
    "alvoramos": "alvorar",
    "alvorando": "alvorar",
    "alvorara": "alvorar",
    "alvoraram": "alvorar",
    "alvoraras": "alvorar",
    "alvorarde": "alvorar",
    "alvorardes": "alvorar",
    "alvorare": "alvorar",
    "alvorarei": "alvorar",
    "alvorareis": "alvorar",
    "alvorarem": "alvorar",
    "alvoraremos": "alvorar",
    "alvorares": "alvorar",
    "alvoraria": "alvorar",
    "alvorariam": "alvorar",
    "alvorarias": "alvorar",
    "alvorarmo": "alvorar",
    "alvorarmos": "alvorar",
    "alvorará": "alvorar",
    "alvorarás": "alvorar",
    "alvorarão": "alvorar",
    "alvoraríamos": "alvorar",
    "alvoraríeis": "alvorar",
    "alvoras": "alvorar",
    "alvorasse": "alvorar",
    "alvorassem": "alvorar",
    "alvorasses": "alvorar",
    "alvoraste": "alvorar",
    "alvorastes": "alvorar",
    "alvorava": "alvorar",
    "alvoravam": "alvorar",
    "alvoravas": "alvorar",
    "alvoraça": "alvoraçar",
    "alvoraçada": "alvoraçar",
    "alvoraçadas": "alvoraçar",
    "alvoraçado": "alvoraçar",
    "alvoraçados": "alvoraçar",
    "alvoraçai": "alvoraçar",
    "alvoraçais": "alvoraçar",
    "alvoraçam": "alvoraçar",
    "alvoraçamo": "alvoraçar",
    "alvoraçamos": "alvoraçar",
    "alvoraçando": "alvoraçar",
    "alvoraçara": "alvoraçar",
    "alvoraçaram": "alvoraçar",
    "alvoraçaras": "alvoraçar",
    "alvoraçarde": "alvoraçar",
    "alvoraçardes": "alvoraçar",
    "alvoraçare": "alvoraçar",
    "alvoraçarei": "alvoraçar",
    "alvoraçareis": "alvoraçar",
    "alvoraçarem": "alvoraçar",
    "alvoraçaremos": "alvoraçar",
    "alvoraçares": "alvoraçar",
    "alvoraçaria": "alvoraçar",
    "alvoraçariam": "alvoraçar",
    "alvoraçarias": "alvoraçar",
    "alvoraçarmo": "alvoraçar",
    "alvoraçarmos": "alvoraçar",
    "alvoraçará": "alvoraçar",
    "alvoraçarás": "alvoraçar",
    "alvoraçarão": "alvoraçar",
    "alvoraçaríamos": "alvoraçar",
    "alvoraçaríeis": "alvoraçar",
    "alvoraças": "alvoraçar",
    "alvoraçasse": "alvoraçar",
    "alvoraçassem": "alvoraçar",
    "alvoraçasses": "alvoraçar",
    "alvoraçaste": "alvoraçar",
    "alvoraçastes": "alvoraçar",
    "alvoraçava": "alvoraçar",
    "alvoraçavam": "alvoraçar",
    "alvoraçavas": "alvoraçar",
    "alvoraço": "alvoraçar",
    "alvoraçou": "alvoraçar",
    "alvoraçá": "alvoraçar",
    "alvoraçámo": "alvoraçar",
    "alvoraçámos": "alvoraçar",
    "alvoraçáramo": "alvoraçar",
    "alvoraçáramos": "alvoraçar",
    "alvoraçárei": "alvoraçar",
    "alvoraçáreis": "alvoraçar",
    "alvoraçásseis": "alvoraçar",
    "alvoraçássemos": "alvoraçar",
    "alvoraçávamo": "alvoraçar",
    "alvoraçávamos": "alvoraçar",
    "alvoraçávei": "alvoraçar",
    "alvoraçáveis": "alvoraçar",
    "alvore": "alvorar",
    "alvoreada": "alvorear",
    "alvoreadas": "alvorear",
    "alvoreado": "alvorear",
    "alvoreados": "alvorear",
    "alvoreai": "alvorear",
    "alvoreais": "alvorear",
    "alvoreamo": "alvorear",
    "alvoreamos": "alvorear",
    "alvoreando": "alvorear",
    "alvoreara": "alvorear",
    "alvorearam": "alvorear",
    "alvorearas": "alvorear",
    "alvoreardes": "alvorear",
    "alvorearei": "alvorear",
    "alvoreareis": "alvorear",
    "alvorearem": "alvorear",
    "alvorearemos": "alvorear",
    "alvoreares": "alvorear",
    "alvorearia": "alvorear",
    "alvoreariam": "alvorear",
    "alvorearias": "alvorear",
    "alvorearmo": "alvorear",
    "alvorearmos": "alvorear",
    "alvoreará": "alvorear",
    "alvorearás": "alvorear",
    "alvorearão": "alvorear",
    "alvorearíamos": "alvorear",
    "alvorearíeis": "alvorear",
    "alvoreasse": "alvorear",
    "alvoreassem": "alvorear",
    "alvoreasses": "alvorear",
    "alvoreaste": "alvorear",
    "alvoreastes": "alvorear",
    "alvoreava": "alvorear",
    "alvoreavam": "alvorear",
    "alvoreavas": "alvorear",
    "alvorece": "alvorecer",
    "alvorecei": "alvorecer",
    "alvoreceis": "alvorecer",
    "alvorecem": "alvorecer",
    "alvorecemo": "alvorecer",
    "alvorecemos": "alvorecer",
    "alvorecendo": "alvorecer",
    "alvorecera": "alvorecer",
    "alvoreceram": "alvorecer",
    "alvoreceras": "alvorecer",
    "alvorecerdes": "alvorecer",
    "alvorecerei": "alvorecer",
    "alvorecereis": "alvorecer",
    "alvorecerem": "alvorecer",
    "alvoreceremos": "alvorecer",
    "alvoreceres": "alvorecer",
    "alvoreceria": "alvorecer",
    "alvoreceriam": "alvorecer",
    "alvorecerias": "alvorecer",
    "alvorecermo": "alvorecer",
    "alvorecermos": "alvorecer",
    "alvorecerá": "alvorecer",
    "alvorecerás": "alvorecer",
    "alvorecerão": "alvorecer",
    "alvoreceríamos": "alvorecer",
    "alvoreceríeis": "alvorecer",
    "alvoreces": "alvorecer",
    "alvorecesse": "alvorecer",
    "alvorecessem": "alvorecer",
    "alvorecesses": "alvorecer",
    "alvoreceste": "alvorecer",
    "alvorecestes": "alvorecer",
    "alvoreceu": "alvorecer",
    "alvoreci": "alvorecer",
    "alvorecia": "alvorecer",
    "alvoreciam": "alvorecer",
    "alvorecias": "alvorecer",
    "alvorecida": "alvorecer",
    "alvorecidas": "alvorecer",
    "alvorecido": "alvorecer",
    "alvorecidos": "alvorecer",
    "alvorecêramo": "alvorecer",
    "alvorecêramos": "alvorecer",
    "alvorecêreis": "alvorecer",
    "alvorecêsseis": "alvorecer",
    "alvorecêssemos": "alvorecer",
    "alvorecíamo": "alvorecer",
    "alvorecíamos": "alvorecer",
    "alvorecíeis": "alvorecer",
    "alvoredos": "alvoredo",
    "alvoreei": "alvorear",
    "alvoreeis": "alvorear",
    "alvoreemo": "alvorear",
    "alvoreemos": "alvorear",
    "alvorei": "alvorar",
    "alvoreia": "alvorear",
    "alvoreiam": "alvorear",
    "alvoreias": "alvorear",
    "alvoreie": "alvorear",
    "alvoreiem": "alvorear",
    "alvoreies": "alvorear",
    "alvoreio": "alvorear",
    "alvoreis": "alvorar",
    "alvoreja": "alvorejar",
    "alvorejada": "alvorejar",
    "alvorejadas": "alvorejar",
    "alvorejado": "alvorejar",
    "alvorejados": "alvorejar",
    "alvorejai": "alvorejar",
    "alvorejais": "alvorejar",
    "alvorejam": "alvorejar",
    "alvorejamo": "alvorejar",
    "alvorejamos": "alvorejar",
    "alvorejando": "alvorejar",
    "alvorejantes": "alvorejante",
    "alvorejara": "alvorejar",
    "alvorejaram": "alvorejar",
    "alvorejaras": "alvorejar",
    "alvorejardes": "alvorejar",
    "alvorejarei": "alvorejar",
    "alvorejareis": "alvorejar",
    "alvorejarem": "alvorejar",
    "alvorejaremos": "alvorejar",
    "alvorejares": "alvorejar",
    "alvorejaria": "alvorejar",
    "alvorejariam": "alvorejar",
    "alvorejarias": "alvorejar",
    "alvorejarmo": "alvorejar",
    "alvorejarmos": "alvorejar",
    "alvorejará": "alvorejar",
    "alvorejarás": "alvorejar",
    "alvorejarão": "alvorejar",
    "alvorejaríamos": "alvorejar",
    "alvorejaríeis": "alvorejar",
    "alvorejas": "alvorejar",
    "alvorejasse": "alvorejar",
    "alvorejassem": "alvorejar",
    "alvorejasses": "alvorejar",
    "alvorejaste": "alvorejar",
    "alvorejastes": "alvorejar",
    "alvorejava": "alvorejar",
    "alvorejavam": "alvorejar",
    "alvorejavas": "alvorejar",
    "alvoreje": "alvorejar",
    "alvorejei": "alvorejar",
    "alvorejeis": "alvorejar",
    "alvorejem": "alvorejar",
    "alvorejemo": "alvorejar",
    "alvorejemos": "alvorejar",
    "alvorejes": "alvorejar",
    "alvorejo": "alvorejar",
    "alvorejou": "alvorejar",
    "alvorejámo": "alvorejar",
    "alvorejámos": "alvorejar",
    "alvorejáramo": "alvorejar",
    "alvorejáramos": "alvorejar",
    "alvorejáreis": "alvorejar",
    "alvorejásseis": "alvorejar",
    "alvorejássemos": "alvorejar",
    "alvorejávamo": "alvorejar",
    "alvorejávamos": "alvorejar",
    "alvorejáveis": "alvorejar",
    "alvorem": "alvorar",
    "alvoremo": "alvorar",
    "alvoremos": "alvorar",
    "alvoreou": "alvorear",
    "alvores": "alvorar",
    "alvoreámo": "alvorear",
    "alvoreámos": "alvorear",
    "alvoreáramo": "alvorear",
    "alvoreáramos": "alvorear",
    "alvoreáreis": "alvorear",
    "alvoreásseis": "alvorear",
    "alvoreássemos": "alvorear",
    "alvoreávamo": "alvorear",
    "alvoreávamos": "alvorear",
    "alvoreáveis": "alvorear",
    "alvoreça": "alvorecer",
    "alvoreçais": "alvorecer",
    "alvoreçam": "alvorecer",
    "alvoreçamo": "alvorecer",
    "alvoreçamos": "alvorecer",
    "alvoreças": "alvorecer",
    "alvoreço": "alvorecer",
    "alvorice": "alvoriçar",
    "alvoricei": "alvoriçar",
    "alvoriceis": "alvoriçar",
    "alvoricem": "alvoriçar",
    "alvoricemo": "alvoriçar",
    "alvoricemos": "alvoriçar",
    "alvorices": "alvoriçar",
    "alvoriça": "alvoriçar",
    "alvoriçada": "alvoriçar",
    "alvoriçadas": "alvoriçar",
    "alvoriçado": "alvoriçar",
    "alvoriçados": "alvoriçar",
    "alvoriçai": "alvoriçar",
    "alvoriçais": "alvoriçar",
    "alvoriçam": "alvoriçar",
    "alvoriçamo": "alvoriçar",
    "alvoriçamos": "alvoriçar",
    "alvoriçando": "alvoriçar",
    "alvoriçara": "alvoriçar",
    "alvoriçaram": "alvoriçar",
    "alvoriçaras": "alvoriçar",
    "alvoriçarde": "alvoriçar",
    "alvoriçardes": "alvoriçar",
    "alvoriçare": "alvoriçar",
    "alvoriçarei": "alvoriçar",
    "alvoriçareis": "alvoriçar",
    "alvoriçarem": "alvoriçar",
    "alvoriçaremos": "alvoriçar",
    "alvoriçares": "alvoriçar",
    "alvoriçaria": "alvoriçar",
    "alvoriçariam": "alvoriçar",
    "alvoriçarias": "alvoriçar",
    "alvoriçarmo": "alvoriçar",
    "alvoriçarmos": "alvoriçar",
    "alvoriçará": "alvoriçar",
    "alvoriçarás": "alvoriçar",
    "alvoriçarão": "alvoriçar",
    "alvoriçaríamos": "alvoriçar",
    "alvoriçaríeis": "alvoriçar",
    "alvoriças": "alvoriçar",
    "alvoriçasse": "alvoriçar",
    "alvoriçassem": "alvoriçar",
    "alvoriçasses": "alvoriçar",
    "alvoriçaste": "alvoriçar",
    "alvoriçastes": "alvoriçar",
    "alvoriçava": "alvoriçar",
    "alvoriçavam": "alvoriçar",
    "alvoriçavas": "alvoriçar",
    "alvoriço": "alvoriçar",
    "alvoriços": "alvoriço",
    "alvoriçou": "alvoriçar",
    "alvoriçá": "alvoriçar",
    "alvoriçámo": "alvoriçar",
    "alvoriçámos": "alvoriçar",
    "alvoriçáramo": "alvoriçar",
    "alvoriçáramos": "alvoriçar",
    "alvoriçárei": "alvoriçar",
    "alvoriçáreis": "alvoriçar",
    "alvoriçásseis": "alvoriçar",
    "alvoriçássemos": "alvoriçar",
    "alvoriçávamo": "alvoriçar",
    "alvoriçávamos": "alvoriçar",
    "alvoriçávei": "alvoriçar",
    "alvoriçáveis": "alvoriçar",
    "alvoro": "alvorar",
    "alvoroce": "alvoroçar",
    "alvorocei": "alvoroçar",
    "alvoroceis": "alvoroçar",
    "alvorocem": "alvoroçar",
    "alvorocemo": "alvoroçar",
    "alvorocemos": "alvoroçar",
    "alvoroces": "alvoroçar",
    "alvorota": "alvorotar",
    "alvorotada": "alvorotar",
    "alvorotadas": "alvorotar",
    "alvorotado": "alvorotar",
    "alvorotadora": "alvorotador",
    "alvorotadoras": "alvorotador",
    "alvorotadores": "alvorotador",
    "alvorotados": "alvorotar",
    "alvorotai": "alvorotar",
    "alvorotais": "alvorotar",
    "alvorotam": "alvorotar",
    "alvorotamentos": "alvorotamento",
    "alvorotamo": "alvorotar",
    "alvorotamos": "alvorotar",
    "alvorotando": "alvorotar",
    "alvorotara": "alvorotar",
    "alvorotaram": "alvorotar",
    "alvorotaras": "alvorotar",
    "alvorotarde": "alvorotar",
    "alvorotardes": "alvorotar",
    "alvorotare": "alvorotar",
    "alvorotarei": "alvorotar",
    "alvorotareis": "alvorotar",
    "alvorotarem": "alvorotar",
    "alvorotaremos": "alvorotar",
    "alvorotares": "alvorotar",
    "alvorotaria": "alvorotar",
    "alvorotariam": "alvorotar",
    "alvorotarias": "alvorotar",
    "alvorotarmo": "alvorotar",
    "alvorotarmos": "alvorotar",
    "alvorotará": "alvorotar",
    "alvorotarás": "alvorotar",
    "alvorotarão": "alvorotar",
    "alvorotaríamos": "alvorotar",
    "alvorotaríeis": "alvorotar",
    "alvorotas": "alvorotar",
    "alvorotasse": "alvorotar",
    "alvorotassem": "alvorotar",
    "alvorotasses": "alvorotar",
    "alvorotaste": "alvorotar",
    "alvorotastes": "alvorotar",
    "alvorotava": "alvorotar",
    "alvorotavam": "alvorotar",
    "alvorotavas": "alvorotar",
    "alvorote": "alvorotar",
    "alvorotei": "alvorotar",
    "alvoroteis": "alvorotar",
    "alvorotem": "alvorotar",
    "alvorotemo": "alvorotar",
    "alvorotemos": "alvorotar",
    "alvorotes": "alvorotar",
    "alvoroto": "alvorotar",
    "alvorotos": "alvoroto",
    "alvorotou": "alvorotar",
    "alvorotá": "alvorotar",
    "alvorotámo": "alvorotar",
    "alvorotámos": "alvorotar",
    "alvorotáramo": "alvorotar",
    "alvorotáramos": "alvorotar",
    "alvorotárei": "alvorotar",
    "alvorotáreis": "alvorotar",
    "alvorotásseis": "alvorotar",
    "alvorotássemos": "alvorotar",
    "alvorotávamo": "alvorotar",
    "alvorotávamos": "alvorotar",
    "alvorotávei": "alvorotar",
    "alvorotáveis": "alvorotar",
    "alvorou": "alvorar",
    "alvoroça": "alvoroçar",
    "alvoroçada": "alvoroçar",
    "alvoroçadas": "alvoroçar",
    "alvoroçado": "alvoroçar",
    "alvoroçadora": "alvoroçador",
    "alvoroçadoras": "alvoroçador",
    "alvoroçadores": "alvoroçador",
    "alvoroçados": "alvoroçar",
    "alvoroçadíssima": "alvoroçado",
    "alvoroçadíssimas": "alvoroçado",
    "alvoroçadíssimo": "alvoroçado",
    "alvoroçadíssimos": "alvoroçado",
    "alvoroçai": "alvoroçar",
    "alvoroçais": "alvoroçar",
    "alvoroçam": "alvoroçar",
    "alvoroçamentos": "alvoroçamento",
    "alvoroçamo": "alvoroçar",
    "alvoroçamos": "alvoroçar",
    "alvoroçando": "alvoroçar",
    "alvoroçantes": "alvoroçante",
    "alvoroçara": "alvoroçar",
    "alvoroçaram": "alvoroçar",
    "alvoroçaras": "alvoroçar",
    "alvoroçarde": "alvoroçar",
    "alvoroçardes": "alvoroçar",
    "alvoroçare": "alvoroçar",
    "alvoroçarei": "alvoroçar",
    "alvoroçareis": "alvoroçar",
    "alvoroçarem": "alvoroçar",
    "alvoroçaremos": "alvoroçar",
    "alvoroçares": "alvoroçar",
    "alvoroçaria": "alvoroçar",
    "alvoroçariam": "alvoroçar",
    "alvoroçarias": "alvoroçar",
    "alvoroçarmo": "alvoroçar",
    "alvoroçarmos": "alvoroçar",
    "alvoroçará": "alvoroçar",
    "alvoroçarás": "alvoroçar",
    "alvoroçarão": "alvoroçar",
    "alvoroçaríamos": "alvoroçar",
    "alvoroçaríeis": "alvoroçar",
    "alvoroças": "alvoroçar",
    "alvoroçasse": "alvoroçar",
    "alvoroçassem": "alvoroçar",
    "alvoroçasses": "alvoroçar",
    "alvoroçaste": "alvoroçar",
    "alvoroçastes": "alvoroçar",
    "alvoroçava": "alvoroçar",
    "alvoroçavam": "alvoroçar",
    "alvoroçavas": "alvoroçar",
    "alvoroço": "alvoroçar",
    "alvoroços": "alvoroço",
    "alvoroçou": "alvoroçar",
    "alvoroçá": "alvoroçar",
    "alvoroçámo": "alvoroçar",
    "alvoroçámos": "alvoroçar",
    "alvoroçáramo": "alvoroçar",
    "alvoroçáramos": "alvoroçar",
    "alvoroçárei": "alvoroçar",
    "alvoroçáreis": "alvoroçar",
    "alvoroçásseis": "alvoroçar",
    "alvoroçássemos": "alvoroçar",
    "alvoroçávamo": "alvoroçar",
    "alvoroçávamos": "alvoroçar",
    "alvoroçávei": "alvoroçar",
    "alvoroçáveis": "alvoroçar",
    "alvorá": "alvorar",
    "alvorámo": "alvorar",
    "alvorámos": "alvorar",
    "alvoráramo": "alvorar",
    "alvoráramos": "alvorar",
    "alvorárei": "alvorar",
    "alvoráreis": "alvorar",
    "alvorária": "alvorário",
    "alvorárias": "alvorário",
    "alvorários": "alvorário",
    "alvorásseis": "alvorar",
    "alvorássemos": "alvorar",
    "alvorávamo": "alvorar",
    "alvorávamos": "alvorar",
    "alvorávei": "alvorar",
    "alvoráveis": "alvorar",
    "alvos": "alvo",
    "alvuras": "alvura",
    "alvéloas": "alvéloa",
    "alvéolas": "alvéola",
    "alvéolos": "alvéolo",
    "alvíssima": "alvo",
    "alvíssimas": "alvo",
    "alvíssimo": "alvo",
    "alvíssimos": "alvo",
    "alzaquis": "alzaqui",
    "alá": "alar",
    "alámo": "alar",
    "alámos": "alar",
    "aláramo": "alar",
    "aláramos": "alar",
    "alárei": "alar",
    "aláreis": "alar",
    "alásseis": "alar",
    "alássemos": "alar",
    "alávamo": "alar",
    "alávamos": "alar",
    "alávei": "alar",
    "aláveis": "alar",
    "alâmpadas": "alâmpada",
    "alça": "alçar",
    "alçada": "alçar",
    "alçadas": "alçar",
    "alçadeiras": "alçadeira",
    "alçado": "alçar",
    "alçadora": "alçador",
    "alçadoras": "alçador",
    "alçadores": "alçador",
    "alçados": "alçar",
    "alçaduras": "alçadura",
    "alçagens": "alçagem",
    "alçai": "alçar",
    "alçais": "alçar",
    "alçam": "alçar",
    "alçamentos": "alçamento",
    "alçamo": "alçar",
    "alçamos": "alçar",
    "alçando": "alçar",
    "alçapremas": "alçaprema",
    "alçapões": "alçapão",
    "alçara": "alçar",
    "alçaram": "alçar",
    "alçaras": "alçar",
    "alçarde": "alçar",
    "alçardes": "alçar",
    "alçare": "alçar",
    "alçarei": "alçar",
    "alçareis": "alçar",
    "alçarem": "alçar",
    "alçaremos": "alçar",
    "alçares": "alçar",
    "alçaria": "alçar",
    "alçariam": "alçar",
    "alçarias": "alçar",
    "alçarmo": "alçar",
    "alçarmos": "alçar",
    "alçará": "alçar",
    "alçarás": "alçar",
    "alçarão": "alçar",
    "alçaríamos": "alçar",
    "alçaríeis": "alçar",
    "alças": "alçar",
    "alçasse": "alçar",
    "alçassem": "alçar",
    "alçasses": "alçar",
    "alçaste": "alçar",
    "alçastes": "alçar",
    "alçava": "alçar",
    "alçavam": "alçar",
    "alçavas": "alçar",
    "alçações": "alçação",
    "alço": "alçar",
    "alçou": "alçar",
    "alçá": "alçar",
    "alçámo": "alçar",
    "alçámos": "alçar",
    "alçáramo": "alçar",
    "alçáramos": "alçar",
    "alçárei": "alçar",
    "alçáreis": "alçar",
    "alçásseis": "alçar",
    "alçássemos": "alçar",
    "alçávamo": "alçar",
    "alçávamos": "alçar",
    "alçávei": "alçar",
    "alçáveis": "alçar",
    "alções": "alção",
    "alécita": "alécito",
    "alécitas": "alécito",
    "alécitos": "alécito",
    "alérgica": "alérgico",
    "alérgicas": "alérgico",
    "alérgicos": "alérgico",
    "aléus": "aléu",
    "aléxica": "aléxico",
    "aléxicas": "aléxico",
    "aléxicos": "aléxico",
    "alíbis": "alíbil",
    "alículas": "alícula",
    "alífuga": "alífugo",
    "alífugas": "alífugo",
    "alífugos": "alífugo",
    "alígera": "alígero",
    "alígeras": "alígero",
    "alígeros": "alígero",
    "alílios": "alílio",
    "alíneas": "alínea",
    "alípedes": "alípede",
    "alíptica": "alíptico",
    "alípticas": "alíptico",
    "alípticos": "alíptico",
    "alíquotas": "alíquota",
    "alísia": "alísio",
    "alísias": "alísio",
    "alísios": "alísio",
    "alívios": "alívio",
    "alóbara": "alóbaro",
    "alóbaras": "alóbaro",
    "alóbaros": "alóbaro",
    "alócta": "alócto",
    "alóctas": "alócto",
    "alóctones": "alóctone",
    "alóctos": "alócto",
    "alóctunes": "alóctune",
    "alódios": "alódio",
    "alófila": "alófilo",
    "alófilas": "alófilo",
    "alófilos": "alófilo",
    "alógama": "alógamo",
    "alógamas": "alógamo",
    "alógamos": "alógamo",
    "alógena": "alógeno",
    "alógenas": "alógeno",
    "alógenos": "alógeno",
    "alógica": "alógico",
    "alógicas": "alógico",
    "alógicos": "alógico",
    "alómana": "alómano",
    "alómanas": "alómano",
    "alómanos": "alómano",
    "alónimos": "alónimo",
    "alótipos": "alótipo",
    "alótropa": "alótropo",
    "alótropas": "alótropo",
    "alótropos": "alótropo",
    "alôs": "alô",
    "alões": "alão",
    "alúmenes": "alúmen",
    "alúmens": "alúmen",
    "alúmes": "alúme",
    "ama": "amo",
    "amabilidades": "amabilidade",
    "amabilíssima": "amável",
    "amabilíssimas": "amável",
    "amabilíssimo": "amável",
    "amabilíssimos": "amável",
    "amacaca": "amacacar",
    "amacacada": "amacacar",
    "amacacadas": "amacacar",
    "amacacado": "amacacar",
    "amacacados": "amacacar",
    "amacacai": "amacacar",
    "amacacais": "amacacar",
    "amacacam": "amacacar",
    "amacacamo": "amacacar",
    "amacacamos": "amacacar",
    "amacacando": "amacacar",
    "amacacara": "amacacar",
    "amacacaram": "amacacar",
    "amacacaras": "amacacar",
    "amacacarde": "amacacar",
    "amacacardes": "amacacar",
    "amacacare": "amacacar",
    "amacacarei": "amacacar",
    "amacacareis": "amacacar",
    "amacacarem": "amacacar",
    "amacacaremos": "amacacar",
    "amacacares": "amacacar",
    "amacacaria": "amacacar",
    "amacacariam": "amacacar",
    "amacacarias": "amacacar",
    "amacacarmo": "amacacar",
    "amacacarmos": "amacacar",
    "amacacará": "amacacar",
    "amacacarás": "amacacar",
    "amacacarão": "amacacar",
    "amacacaríamos": "amacacar",
    "amacacaríeis": "amacacar",
    "amacacas": "amacacar",
    "amacacasse": "amacacar",
    "amacacassem": "amacacar",
    "amacacasses": "amacacar",
    "amacacaste": "amacacar",
    "amacacastes": "amacacar",
    "amacacava": "amacacar",
    "amacacavam": "amacacar",
    "amacacavas": "amacacar",
    "amacaco": "amacacar",
    "amacacou": "amacacar",
    "amacacá": "amacacar",
    "amacacámo": "amacacar",
    "amacacámos": "amacacar",
    "amacacáramo": "amacacar",
    "amacacáramos": "amacacar",
    "amacacárei": "amacacar",
    "amacacáreis": "amacacar",
    "amacacásseis": "amacacar",
    "amacacássemos": "amacacar",
    "amacacávamo": "amacacar",
    "amacacávamos": "amacacar",
    "amacacávei": "amacacar",
    "amacacáveis": "amacacar",
    "amacaque": "amacacar",
    "amacaquei": "amacacar",
    "amacaqueis": "amacacar",
    "amacaquem": "amacacar",
    "amacaquemo": "amacacar",
    "amacaquemos": "amacacar",
    "amacaques": "amacacar",
    "amace": "amaçar",
    "amacei": "amaçar",
    "amaceis": "amaçar",
    "amacem": "amaçar",
    "amacemo": "amaçar",
    "amacemos": "amaçar",
    "amaces": "amaçar",
    "amachuca": "amachucar",
    "amachucada": "amachucar",
    "amachucadas": "amachucar",
    "amachucadelas": "amachucadela",
    "amachucado": "amachucar",
    "amachucados": "amachucar",
    "amachucadíssima": "amachucado",
    "amachucadíssimas": "amachucado",
    "amachucadíssimo": "amachucado",
    "amachucadíssimos": "amachucado",
    "amachucai": "amachucar",
    "amachucais": "amachucar",
    "amachucam": "amachucar",
    "amachucamo": "amachucar",
    "amachucamos": "amachucar",
    "amachucando": "amachucar",
    "amachucara": "amachucar",
    "amachucaram": "amachucar",
    "amachucaras": "amachucar",
    "amachucarde": "amachucar",
    "amachucardes": "amachucar",
    "amachucare": "amachucar",
    "amachucarei": "amachucar",
    "amachucareis": "amachucar",
    "amachucarem": "amachucar",
    "amachucaremos": "amachucar",
    "amachucares": "amachucar",
    "amachucaria": "amachucar",
    "amachucariam": "amachucar",
    "amachucarias": "amachucar",
    "amachucarmo": "amachucar",
    "amachucarmos": "amachucar",
    "amachucará": "amachucar",
    "amachucarás": "amachucar",
    "amachucarão": "amachucar",
    "amachucaríamos": "amachucar",
    "amachucaríeis": "amachucar",
    "amachucas": "amachucar",
    "amachucasse": "amachucar",
    "amachucassem": "amachucar",
    "amachucasses": "amachucar",
    "amachucaste": "amachucar",
    "amachucastes": "amachucar",
    "amachucava": "amachucar",
    "amachucavam": "amachucar",
    "amachucavas": "amachucar",
    "amachuco": "amachucar",
    "amachucou": "amachucar",
    "amachucá": "amachucar",
    "amachucámo": "amachucar",
    "amachucámos": "amachucar",
    "amachucáramo": "amachucar",
    "amachucáramos": "amachucar",
    "amachucárei": "amachucar",
    "amachucáreis": "amachucar",
    "amachucásseis": "amachucar",
    "amachucássemos": "amachucar",
    "amachucávamo": "amachucar",
    "amachucávamos": "amachucar",
    "amachucávei": "amachucar",
    "amachucáveis": "amachucável",
    "amachuque": "amachucar",
    "amachuquei": "amachucar",
    "amachuqueis": "amachucar",
    "amachuquem": "amachucar",
    "amachuquemo": "amachucar",
    "amachuquemos": "amachucar",
    "amachuques": "amachucar",
    "amacia": "amaciar",
    "amaciada": "amaciar",
    "amaciadas": "amaciar",
    "amaciadelas": "amaciadela",
    "amaciado": "amaciar",
    "amaciadora": "amaciador",
    "amaciadoras": "amaciador",
    "amaciadores": "amaciador",
    "amaciadors": "amaciador",
    "amaciados": "amaciar",
    "amaciai": "amaciar",
    "amaciais": "amaciar",
    "amaciam": "amaciar",
    "amaciamo": "amaciar",
    "amaciamos": "amaciar",
    "amaciando": "amaciar",
    "amaciara": "amaciar",
    "amaciaram": "amaciar",
    "amaciaras": "amaciar",
    "amaciarde": "amaciar",
    "amaciardes": "amaciar",
    "amaciare": "amaciar",
    "amaciarei": "amaciar",
    "amaciareis": "amaciar",
    "amaciarem": "amaciar",
    "amaciaremos": "amaciar",
    "amaciares": "amaciar",
    "amaciaria": "amaciar",
    "amaciariam": "amaciar",
    "amaciarias": "amaciar",
    "amaciarmo": "amaciar",
    "amaciarmos": "amaciar",
    "amaciará": "amaciar",
    "amaciarás": "amaciar",
    "amaciarão": "amaciar",
    "amaciaríamos": "amaciar",
    "amaciaríeis": "amaciar",
    "amacias": "amaciar",
    "amaciasse": "amaciar",
    "amaciassem": "amaciar",
    "amaciasses": "amaciar",
    "amaciaste": "amaciar",
    "amaciastes": "amaciar",
    "amaciava": "amaciar",
    "amaciavam": "amaciar",
    "amaciavas": "amaciar",
    "amacie": "amaciar",
    "amaciei": "amaciar",
    "amacieis": "amaciar",
    "amaciem": "amaciar",
    "amaciemo": "amaciar",
    "amaciemos": "amaciar",
    "amacies": "amaciar",
    "amacio": "amaciar",
    "amaciou": "amaciar",
    "amaciá": "amaciar",
    "amaciámo": "amaciar",
    "amaciámos": "amaciar",
    "amaciáramo": "amaciar",
    "amaciáramos": "amaciar",
    "amaciárei": "amaciar",
    "amaciáreis": "amaciar",
    "amaciásseis": "amaciar",
    "amaciássemos": "amaciar",
    "amaciávamo": "amaciar",
    "amaciávamos": "amaciar",
    "amaciávei": "amaciar",
    "amaciáveis": "amaciar",
    "amada": "amar",
    "amadas": "amar",
    "amadeira": "amadeirar",
    "amadeirada": "amadeirar",
    "amadeiradas": "amadeirar",
    "amadeirado": "amadeirar",
    "amadeirados": "amadeirar",
    "amadeirai": "amadeirar",
    "amadeirais": "amadeirar",
    "amadeiram": "amadeirar",
    "amadeiramo": "amadeirar",
    "amadeiramos": "amadeirar",
    "amadeirando": "amadeirar",
    "amadeirara": "amadeirar",
    "amadeiraram": "amadeirar",
    "amadeiraras": "amadeirar",
    "amadeirarde": "amadeirar",
    "amadeirardes": "amadeirar",
    "amadeirare": "amadeirar",
    "amadeirarei": "amadeirar",
    "amadeirareis": "amadeirar",
    "amadeirarem": "amadeirar",
    "amadeiraremos": "amadeirar",
    "amadeirares": "amadeirar",
    "amadeiraria": "amadeirar",
    "amadeirariam": "amadeirar",
    "amadeirarias": "amadeirar",
    "amadeirarmo": "amadeirar",
    "amadeirarmos": "amadeirar",
    "amadeirará": "amadeirar",
    "amadeirarás": "amadeirar",
    "amadeirarão": "amadeirar",
    "amadeiraríamos": "amadeirar",
    "amadeiraríeis": "amadeirar",
    "amadeiras": "amadeirar",
    "amadeirasse": "amadeirar",
    "amadeirassem": "amadeirar",
    "amadeirasses": "amadeirar",
    "amadeiraste": "amadeirar",
    "amadeirastes": "amadeirar",
    "amadeirava": "amadeirar",
    "amadeiravam": "amadeirar",
    "amadeiravas": "amadeirar",
    "amadeire": "amadeirar",
    "amadeirei": "amadeirar",
    "amadeireis": "amadeirar",
    "amadeirem": "amadeirar",
    "amadeiremo": "amadeirar",
    "amadeiremos": "amadeirar",
    "amadeires": "amadeirar",
    "amadeiro": "amadeirar",
    "amadeirou": "amadeirar",
    "amadeirá": "amadeirar",
    "amadeirámo": "amadeirar",
    "amadeirámos": "amadeirar",
    "amadeiráramo": "amadeirar",
    "amadeiráramos": "amadeirar",
    "amadeirárei": "amadeirar",
    "amadeiráreis": "amadeirar",
    "amadeirásseis": "amadeirar",
    "amadeirássemos": "amadeirar",
    "amadeirávamo": "amadeirar",
    "amadeirávamos": "amadeirar",
    "amadeirávei": "amadeirar",
    "amadeiráveis": "amadeirar",
    "amadeístas": "amadeísta",
    "amadias": "amadia",
    "amadises": "amadis",
    "amado": "amar",
    "amadoira": "amadoiro",
    "amadoiras": "amadoiro",
    "amadoiros": "amadoiro",
    "amadora": "amador",
    "amadoras": "amador",
    "amadorenses": "amadorense",
    "amadores": "amador",
    "amadorismos": "amadorismo",
    "amadorna": "amadornar",
    "amadornada": "amadornar",
    "amadornadas": "amadornar",
    "amadornado": "amadornar",
    "amadornados": "amadornar",
    "amadornai": "amadornar",
    "amadornais": "amadornar",
    "amadornam": "amadornar",
    "amadornamo": "amadornar",
    "amadornamos": "amadornar",
    "amadornando": "amadornar",
    "amadornara": "amadornar",
    "amadornaram": "amadornar",
    "amadornaras": "amadornar",
    "amadornarde": "amadornar",
    "amadornardes": "amadornar",
    "amadornare": "amadornar",
    "amadornarei": "amadornar",
    "amadornareis": "amadornar",
    "amadornarem": "amadornar",
    "amadornaremos": "amadornar",
    "amadornares": "amadornar",
    "amadornaria": "amadornar",
    "amadornariam": "amadornar",
    "amadornarias": "amadornar",
    "amadornarmo": "amadornar",
    "amadornarmos": "amadornar",
    "amadornará": "amadornar",
    "amadornarás": "amadornar",
    "amadornarão": "amadornar",
    "amadornaríamos": "amadornar",
    "amadornaríeis": "amadornar",
    "amadornas": "amadornar",
    "amadornasse": "amadornar",
    "amadornassem": "amadornar",
    "amadornasses": "amadornar",
    "amadornaste": "amadornar",
    "amadornastes": "amadornar",
    "amadornava": "amadornar",
    "amadornavam": "amadornar",
    "amadornavas": "amadornar",
    "amadorne": "amadornar",
    "amadornei": "amadornar",
    "amadorneis": "amadornar",
    "amadornem": "amadornar",
    "amadornemo": "amadornar",
    "amadornemos": "amadornar",
    "amadornes": "amadornar",
    "amadorno": "amadornar",
    "amadornou": "amadornar",
    "amadorná": "amadornar",
    "amadornámo": "amadornar",
    "amadornámos": "amadornar",
    "amadornáramo": "amadornar",
    "amadornáramos": "amadornar",
    "amadornárei": "amadornar",
    "amadornáreis": "amadornar",
    "amadornásseis": "amadornar",
    "amadornássemos": "amadornar",
    "amadornávamo": "amadornar",
    "amadornávamos": "amadornar",
    "amadornávei": "amadornar",
    "amadornáveis": "amadornar",
    "amadorra": "amadorrar",
    "amadorrada": "amadorrar",
    "amadorradas": "amadorrar",
    "amadorrado": "amadorrar",
    "amadorrados": "amadorrar",
    "amadorrai": "amadorrar",
    "amadorrais": "amadorrar",
    "amadorram": "amadorrar",
    "amadorramo": "amadorrar",
    "amadorramos": "amadorrar",
    "amadorrando": "amadorrar",
    "amadorrara": "amadorrar",
    "amadorraram": "amadorrar",
    "amadorraras": "amadorrar",
    "amadorrarde": "amadorrar",
    "amadorrardes": "amadorrar",
    "amadorrare": "amadorrar",
    "amadorrarei": "amadorrar",
    "amadorrareis": "amadorrar",
    "amadorrarem": "amadorrar",
    "amadorraremos": "amadorrar",
    "amadorrares": "amadorrar",
    "amadorraria": "amadorrar",
    "amadorrariam": "amadorrar",
    "amadorrarias": "amadorrar",
    "amadorrarmo": "amadorrar",
    "amadorrarmos": "amadorrar",
    "amadorrará": "amadorrar",
    "amadorrarás": "amadorrar",
    "amadorrarão": "amadorrar",
    "amadorraríamos": "amadorrar",
    "amadorraríeis": "amadorrar",
    "amadorras": "amadorrar",
    "amadorrasse": "amadorrar",
    "amadorrassem": "amadorrar",
    "amadorrasses": "amadorrar",
    "amadorraste": "amadorrar",
    "amadorrastes": "amadorrar",
    "amadorrava": "amadorrar",
    "amadorravam": "amadorrar",
    "amadorravas": "amadorrar",
    "amadorre": "amadorrar",
    "amadorrei": "amadorrar",
    "amadorreis": "amadorrar",
    "amadorrem": "amadorrar",
    "amadorremo": "amadorrar",
    "amadorremos": "amadorrar",
    "amadorres": "amadorrar",
    "amadorro": "amadorrar",
    "amadorrou": "amadorrar",
    "amadorrá": "amadorrar",
    "amadorrámo": "amadorrar",
    "amadorrámos": "amadorrar",
    "amadorráramo": "amadorrar",
    "amadorráramos": "amadorrar",
    "amadorrárei": "amadorrar",
    "amadorráreis": "amadorrar",
    "amadorrásseis": "amadorrar",
    "amadorrássemos": "amadorrar",
    "amadorrávamo": "amadorrar",
    "amadorrávamos": "amadorrar",
    "amadorrávei": "amadorrar",
    "amadorráveis": "amadorrar",
    "amadorística": "amadorístico",
    "amadorísticas": "amadorístico",
    "amadorísticos": "amadorístico",
    "amados": "amar",
    "amadrinha": "amadrinhar",
    "amadrinhada": "amadrinhar",
    "amadrinhadas": "amadrinhar",
    "amadrinhado": "amadrinhar",
    "amadrinhadora": "amadrinhador",
    "amadrinhadoras": "amadrinhador",
    "amadrinhadores": "amadrinhador",
    "amadrinhados": "amadrinhar",
    "amadrinhai": "amadrinhar",
    "amadrinhais": "amadrinhar",
    "amadrinham": "amadrinhar",
    "amadrinhamo": "amadrinhar",
    "amadrinhamos": "amadrinhar",
    "amadrinhando": "amadrinhar",
    "amadrinhara": "amadrinhar",
    "amadrinharam": "amadrinhar",
    "amadrinharas": "amadrinhar",
    "amadrinharde": "amadrinhar",
    "amadrinhardes": "amadrinhar",
    "amadrinhare": "amadrinhar",
    "amadrinharei": "amadrinhar",
    "amadrinhareis": "amadrinhar",
    "amadrinharem": "amadrinhar",
    "amadrinharemos": "amadrinhar",
    "amadrinhares": "amadrinhar",
    "amadrinharia": "amadrinhar",
    "amadrinhariam": "amadrinhar",
    "amadrinharias": "amadrinhar",
    "amadrinharmo": "amadrinhar",
    "amadrinharmos": "amadrinhar",
    "amadrinhará": "amadrinhar",
    "amadrinharás": "amadrinhar",
    "amadrinharão": "amadrinhar",
    "amadrinharíamos": "amadrinhar",
    "amadrinharíeis": "amadrinhar",
    "amadrinhas": "amadrinhar",
    "amadrinhasse": "amadrinhar",
    "amadrinhassem": "amadrinhar",
    "amadrinhasses": "amadrinhar",
    "amadrinhaste": "amadrinhar",
    "amadrinhastes": "amadrinhar",
    "amadrinhava": "amadrinhar",
    "amadrinhavam": "amadrinhar",
    "amadrinhavas": "amadrinhar",
    "amadrinhe": "amadrinhar",
    "amadrinhei": "amadrinhar",
    "amadrinheis": "amadrinhar",
    "amadrinhem": "amadrinhar",
    "amadrinhemo": "amadrinhar",
    "amadrinhemos": "amadrinhar",
    "amadrinhes": "amadrinhar",
    "amadrinho": "amadrinhar",
    "amadrinhou": "amadrinhar",
    "amadrinhá": "amadrinhar",
    "amadrinhámo": "amadrinhar",
    "amadrinhámos": "amadrinhar",
    "amadrinháramo": "amadrinhar",
    "amadrinháramos": "amadrinhar",
    "amadrinhárei": "amadrinhar",
    "amadrinháreis": "amadrinhar",
    "amadrinhásseis": "amadrinhar",
    "amadrinhássemos": "amadrinhar",
    "amadrinhávamo": "amadrinhar",
    "amadrinhávamos": "amadrinhar",
    "amadrinhávei": "amadrinhar",
    "amadrinháveis": "amadrinhar",
    "amadura": "amadurar",
    "amadurada": "amadurar",
    "amaduradas": "amadurar",
    "amadurado": "amadurar",
    "amadurados": "amadurar",
    "amadurai": "amadurar",
    "amadurais": "amadurar",
    "amaduram": "amadurar",
    "amaduramo": "amadurar",
    "amaduramos": "amadurar",
    "amadurando": "amadurar",
    "amadurara": "amadurar",
    "amaduraram": "amadurar",
    "amaduraras": "amadurar",
    "amadurarde": "amadurar",
    "amadurardes": "amadurar",
    "amadurare": "amadurar",
    "amadurarei": "amadurar",
    "amadurareis": "amadurar",
    "amadurarem": "amadurar",
    "amaduraremos": "amadurar",
    "amadurares": "amadurar",
    "amaduraria": "amadurar",
    "amadurariam": "amadurar",
    "amadurarias": "amadurar",
    "amadurarmo": "amadurar",
    "amadurarmos": "amadurar",
    "amadurará": "amadurar",
    "amadurarás": "amadurar",
    "amadurarão": "amadurar",
    "amaduraríamos": "amadurar",
    "amaduraríeis": "amadurar",
    "amaduras": "amadurar",
    "amadurasse": "amadurar",
    "amadurassem": "amadurar",
    "amadurasses": "amadurar",
    "amaduraste": "amadurar",
    "amadurastes": "amadurar",
    "amadurava": "amadurar",
    "amaduravam": "amadurar",
    "amaduravas": "amadurar",
    "amadure": "amadurar",
    "amadurece": "amadurecer",
    "amadurecei": "amadurecer",
    "amadureceis": "amadurecer",
    "amadurecem": "amadurecer",
    "amadurecemo": "amadurecer",
    "amadurecemos": "amadurecer",
    "amadurecendo": "amadurecer",
    "amadurecera": "amadurecer",
    "amadureceram": "amadurecer",
    "amadureceras": "amadurecer",
    "amadurecerde": "amadurecer",
    "amadurecerdes": "amadurecer",
    "amadurecere": "amadurecer",
    "amadurecerei": "amadurecer",
    "amadurecereis": "amadurecer",
    "amadurecerem": "amadurecer",
    "amadureceremos": "amadurecer",
    "amadureceres": "amadurecer",
    "amadureceria": "amadurecer",
    "amadureceriam": "amadurecer",
    "amadurecerias": "amadurecer",
    "amadurecermo": "amadurecer",
    "amadurecermos": "amadurecer",
    "amadurecerá": "amadurecer",
    "amadurecerás": "amadurecer",
    "amadurecerão": "amadurecer",
    "amadureceríamos": "amadurecer",
    "amadureceríeis": "amadurecer",
    "amadureces": "amadurecer",
    "amadurecesse": "amadurecer",
    "amadurecessem": "amadurecer",
    "amadurecesses": "amadurecer",
    "amadureceste": "amadurecer",
    "amadurecestes": "amadurecer",
    "amadureceu": "amadurecer",
    "amadureci": "amadurecer",
    "amadurecia": "amadurecer",
    "amadureciam": "amadurecer",
    "amadurecias": "amadurecer",
    "amadurecida": "amadurecido",
    "amadurecidas": "amadurecido",
    "amadurecido": "amadurecer",
    "amadurecidos": "amadurecido",
    "amadurecimentos": "amadurecimento",
    "amadurecê": "amadurecer",
    "amadurecêramo": "amadurecer",
    "amadurecêramos": "amadurecer",
    "amadurecêrei": "amadurecer",
    "amadurecêreis": "amadurecer",
    "amadurecêsseis": "amadurecer",
    "amadurecêssemos": "amadurecer",
    "amadurecíamo": "amadurecer",
    "amadurecíamos": "amadurecer",
    "amadurecíei": "amadurecer",
    "amadurecíeis": "amadurecer",
    "amadurei": "amadurar",
    "amadureis": "amadurar",
    "amadurem": "amadurar",
    "amaduremo": "amadurar",
    "amaduremos": "amadurar",
    "amadures": "amadurar",
    "amadureça": "amadurecer",
    "amadureçais": "amadurecer",
    "amadureçam": "amadurecer",
    "amadureçamo": "amadurecer",
    "amadureçamos": "amadurecer",
    "amadureças": "amadurecer",
    "amadureço": "amadurecer",
    "amaduro": "amadurar",
    "amadurou": "amadurar",
    "amadurá": "amadurar",
    "amadurámo": "amadurar",
    "amadurámos": "amadurar",
    "amaduráramo": "amadurar",
    "amaduráramos": "amadurar",
    "amadurárei": "amadurar",
    "amaduráreis": "amadurar",
    "amadurásseis": "amadurar",
    "amadurássemos": "amadurar",
    "amadurávamo": "amadurar",
    "amadurávamos": "amadurar",
    "amadurávei": "amadurar",
    "amaduráveis": "amadurar",
    "amadíssima": "amado",
    "amadíssimas": "amado",
    "amadíssimo": "amado",
    "amadíssimos": "amado",
    "amaga": "amagar",
    "amagada": "amagar",
    "amagadas": "amagar",
    "amagado": "amagar",
    "amagados": "amagar",
    "amagai": "amagar",
    "amagais": "amagar",
    "amagam": "amagar",
    "amagamo": "amagar",
    "amagamos": "amagar",
    "amagando": "amagar",
    "amagara": "amagar",
    "amagaram": "amagar",
    "amagaras": "amagar",
    "amagarde": "amagar",
    "amagardes": "amagar",
    "amagare": "amagar",
    "amagarei": "amagar",
    "amagareis": "amagar",
    "amagarem": "amagar",
    "amagaremos": "amagar",
    "amagares": "amagar",
    "amagaria": "amagar",
    "amagariam": "amagar",
    "amagarias": "amagar",
    "amagarmo": "amagar",
    "amagarmos": "amagar",
    "amagará": "amagar",
    "amagarás": "amagar",
    "amagarão": "amagar",
    "amagaríamos": "amagar",
    "amagaríeis": "amagar",
    "amagas": "amagar",
    "amagasse": "amagar",
    "amagassem": "amagar",
    "amagasses": "amagar",
    "amagaste": "amagar",
    "amagastes": "amagar",
    "amagava": "amagar",
    "amagavam": "amagar",
    "amagavas": "amagar",
    "amago": "amagar",
    "amagota": "amagotar",
    "amagotada": "amagotar",
    "amagotadas": "amagotar",
    "amagotado": "amagotar",
    "amagotados": "amagotar",
    "amagotai": "amagotar",
    "amagotais": "amagotar",
    "amagotam": "amagotar",
    "amagotamo": "amagotar",
    "amagotamos": "amagotar",
    "amagotando": "amagotar",
    "amagotara": "amagotar",
    "amagotaram": "amagotar",
    "amagotaras": "amagotar",
    "amagotarde": "amagotar",
    "amagotardes": "amagotar",
    "amagotare": "amagotar",
    "amagotarei": "amagotar",
    "amagotareis": "amagotar",
    "amagotarem": "amagotar",
    "amagotaremos": "amagotar",
    "amagotares": "amagotar",
    "amagotaria": "amagotar",
    "amagotariam": "amagotar",
    "amagotarias": "amagotar",
    "amagotarmo": "amagotar",
    "amagotarmos": "amagotar",
    "amagotará": "amagotar",
    "amagotarás": "amagotar",
    "amagotarão": "amagotar",
    "amagotaríamos": "amagotar",
    "amagotaríeis": "amagotar",
    "amagotas": "amagotar",
    "amagotasse": "amagotar",
    "amagotassem": "amagotar",
    "amagotasses": "amagotar",
    "amagotaste": "amagotar",
    "amagotastes": "amagotar",
    "amagotava": "amagotar",
    "amagotavam": "amagotar",
    "amagotavas": "amagotar",
    "amagote": "amagotar",
    "amagotei": "amagotar",
    "amagoteis": "amagotar",
    "amagotem": "amagotar",
    "amagotemo": "amagotar",
    "amagotemos": "amagotar",
    "amagotes": "amagotar",
    "amagoto": "amagotar",
    "amagotou": "amagotar",
    "amagotá": "amagotar",
    "amagotámo": "amagotar",
    "amagotámos": "amagotar",
    "amagotáramo": "amagotar",
    "amagotáramos": "amagotar",
    "amagotárei": "amagotar",
    "amagotáreis": "amagotar",
    "amagotásseis": "amagotar",
    "amagotássemos": "amagotar",
    "amagotávamo": "amagotar",
    "amagotávamos": "amagotar",
    "amagotávei": "amagotar",
    "amagotáveis": "amagotar",
    "amagou": "amagar",
    "amague": "amagar",
    "amaguei": "amagar",
    "amagueis": "amagar",
    "amaguem": "amagar",
    "amaguemo": "amagar",
    "amaguemos": "amagar",
    "amagues": "amagar",
    "amagá": "amagar",
    "amagámo": "amagar",
    "amagámos": "amagar",
    "amagáramo": "amagar",
    "amagáramos": "amagar",
    "amagárei": "amagar",
    "amagáreis": "amagar",
    "amagásseis": "amagar",
    "amagássemos": "amagar",
    "amagávamo": "amagar",
    "amagávamos": "amagar",
    "amagávei": "amagar",
    "amagáveis": "amagar",
    "amai": "amar",
    "amaina": "amainar",
    "amainada": "amainar",
    "amainadas": "amainar",
    "amainado": "amainar",
    "amainados": "amainar",
    "amainai": "amainar",
    "amainais": "amainar",
    "amainam": "amainar",
    "amainamo": "amainar",
    "amainamos": "amainar",
    "amainando": "amainar",
    "amainara": "amainar",
    "amainaram": "amainar",
    "amainaras": "amainar",
    "amainardes": "amainar",
    "amainarei": "amainar",
    "amainareis": "amainar",
    "amainarem": "amainar",
    "amainaremos": "amainar",
    "amainares": "amainar",
    "amainaria": "amainar",
    "amainariam": "amainar",
    "amainarias": "amainar",
    "amainarmo": "amainar",
    "amainarmos": "amainar",
    "amainará": "amainar",
    "amainarás": "amainar",
    "amainarão": "amainar",
    "amainaríamos": "amainar",
    "amainaríeis": "amainar",
    "amainas": "amainar",
    "amainasse": "amainar",
    "amainassem": "amainar",
    "amainasses": "amainar",
    "amainaste": "amainar",
    "amainastes": "amainar",
    "amainava": "amainar",
    "amainavam": "amainar",
    "amainavas": "amainar",
    "amaine": "amainar",
    "amainei": "amainar",
    "amaineis": "amainar",
    "amainem": "amainar",
    "amainemo": "amainar",
    "amainemos": "amainar",
    "amaines": "amainar",
    "amaino": "amainar",
    "amainou": "amainar",
    "amainámo": "amainar",
    "amainámos": "amainar",
    "amaináramo": "amainar",
    "amaináramos": "amainar",
    "amaináreis": "amainar",
    "amainásseis": "amainar",
    "amainássemos": "amainar",
    "amainávamo": "amainar",
    "amainávamos": "amainar",
    "amaináveis": "amainar",
    "amais": "amar",
    "amalandra": "amalandrar",
    "amalandrada": "amalandrar",
    "amalandradas": "amalandrar",
    "amalandrado": "amalandrar",
    "amalandrados": "amalandrar",
    "amalandrai": "amalandrar",
    "amalandrais": "amalandrar",
    "amalandram": "amalandrar",
    "amalandramo": "amalandrar",
    "amalandramos": "amalandrar",
    "amalandrando": "amalandrar",
    "amalandrara": "amalandrar",
    "amalandraram": "amalandrar",
    "amalandraras": "amalandrar",
    "amalandrarde": "amalandrar",
    "amalandrardes": "amalandrar",
    "amalandrare": "amalandrar",
    "amalandrarei": "amalandrar",
    "amalandrareis": "amalandrar",
    "amalandrarem": "amalandrar",
    "amalandraremos": "amalandrar",
    "amalandrares": "amalandrar",
    "amalandraria": "amalandrar",
    "amalandrariam": "amalandrar",
    "amalandrarias": "amalandrar",
    "amalandrarmo": "amalandrar",
    "amalandrarmos": "amalandrar",
    "amalandrará": "amalandrar",
    "amalandrarás": "amalandrar",
    "amalandrarão": "amalandrar",
    "amalandraríamos": "amalandrar",
    "amalandraríeis": "amalandrar",
    "amalandras": "amalandrar",
    "amalandrasse": "amalandrar",
    "amalandrassem": "amalandrar",
    "amalandrasses": "amalandrar",
    "amalandraste": "amalandrar",
    "amalandrastes": "amalandrar",
    "amalandrava": "amalandrar",
    "amalandravam": "amalandrar",
    "amalandravas": "amalandrar",
    "amalandre": "amalandrar",
    "amalandrei": "amalandrar",
    "amalandreis": "amalandrar",
    "amalandrem": "amalandrar",
    "amalandremo": "amalandrar",
    "amalandremos": "amalandrar",
    "amalandres": "amalandrar",
    "amalandro": "amalandrar",
    "amalandrou": "amalandrar",
    "amalandrá": "amalandrar",
    "amalandrámo": "amalandrar",
    "amalandrámos": "amalandrar",
    "amalandráramo": "amalandrar",
    "amalandráramos": "amalandrar",
    "amalandrárei": "amalandrar",
    "amalandráreis": "amalandrar",
    "amalandrásseis": "amalandrar",
    "amalandrássemos": "amalandrar",
    "amalandrávamo": "amalandrar",
    "amalandrávamos": "amalandrar",
    "amalandrávei": "amalandrar",
    "amalandráveis": "amalandrar",
    "amaldiçoa": "amaldiçoar",
    "amaldiçoada": "amaldiçoar",
    "amaldiçoadas": "amaldiçoar",
    "amaldiçoado": "amaldiçoar",
    "amaldiçoados": "amaldiçoar",
    "amaldiçoai": "amaldiçoar",
    "amaldiçoais": "amaldiçoar",
    "amaldiçoam": "amaldiçoar",
    "amaldiçoamo": "amaldiçoar",
    "amaldiçoamos": "amaldiçoar",
    "amaldiçoando": "amaldiçoar",
    "amaldiçoara": "amaldiçoar",
    "amaldiçoaram": "amaldiçoar",
    "amaldiçoaras": "amaldiçoar",
    "amaldiçoarde": "amaldiçoar",
    "amaldiçoardes": "amaldiçoar",
    "amaldiçoare": "amaldiçoar",
    "amaldiçoarei": "amaldiçoar",
    "amaldiçoareis": "amaldiçoar",
    "amaldiçoarem": "amaldiçoar",
    "amaldiçoaremos": "amaldiçoar",
    "amaldiçoares": "amaldiçoar",
    "amaldiçoaria": "amaldiçoar",
    "amaldiçoariam": "amaldiçoar",
    "amaldiçoarias": "amaldiçoar",
    "amaldiçoarmo": "amaldiçoar",
    "amaldiçoarmos": "amaldiçoar",
    "amaldiçoará": "amaldiçoar",
    "amaldiçoarás": "amaldiçoar",
    "amaldiçoarão": "amaldiçoar",
    "amaldiçoaríamos": "amaldiçoar",
    "amaldiçoaríeis": "amaldiçoar",
    "amaldiçoas": "amaldiçoar",
    "amaldiçoasse": "amaldiçoar",
    "amaldiçoassem": "amaldiçoar",
    "amaldiçoasses": "amaldiçoar",
    "amaldiçoaste": "amaldiçoar",
    "amaldiçoastes": "amaldiçoar",
    "amaldiçoava": "amaldiçoar",
    "amaldiçoavam": "amaldiçoar",
    "amaldiçoavas": "amaldiçoar",
    "amaldiçoe": "amaldiçoar",
    "amaldiçoei": "amaldiçoar",
    "amaldiçoeis": "amaldiçoar",
    "amaldiçoem": "amaldiçoar",
    "amaldiçoemo": "amaldiçoar",
    "amaldiçoemos": "amaldiçoar",
    "amaldiçoes": "amaldiçoar",
    "amaldiçoo": "amaldiçoar",
    "amaldiçoou": "amaldiçoar",
    "amaldiçoá": "amaldiçoar",
    "amaldiçoámo": "amaldiçoar",
    "amaldiçoámos": "amaldiçoar",
    "amaldiçoáramo": "amaldiçoar",
    "amaldiçoáramos": "amaldiçoar",
    "amaldiçoárei": "amaldiçoar",
    "amaldiçoáreis": "amaldiçoar",
    "amaldiçoásseis": "amaldiçoar",
    "amaldiçoássemos": "amaldiçoar",
    "amaldiçoávamo": "amaldiçoar",
    "amaldiçoávamos": "amaldiçoar",
    "amaldiçoávei": "amaldiçoar",
    "amaldiçoáveis": "amaldiçoar",
    "amaleitada": "amaleitado",
    "amaleitadas": "amaleitado",
    "amaleitados": "amaleitado",
    "amaleitadíssima": "amaleitado",
    "amaleitadíssimas": "amaleitado",
    "amaleitadíssimo": "amaleitado",
    "amaleitadíssimos": "amaleitado",
    "amalgama": "amalgamar",
    "amalgamada": "amalgamar",
    "amalgamadas": "amalgamar",
    "amalgamado": "amalgamar",
    "amalgamados": "amalgamar",
    "amalgamai": "amalgamar",
    "amalgamais": "amalgamar",
    "amalgamam": "amalgamar",
    "amalgamamentos": "amalgamamento",
    "amalgamamo": "amalgamar",
    "amalgamamos": "amalgamar",
    "amalgamando": "amalgamar",
    "amalgamara": "amalgamar",
    "amalgamaram": "amalgamar",
    "amalgamaras": "amalgamar",
    "amalgamarde": "amalgamar",
    "amalgamardes": "amalgamar",
    "amalgamare": "amalgamar",
    "amalgamarei": "amalgamar",
    "amalgamareis": "amalgamar",
    "amalgamarem": "amalgamar",
    "amalgamaremos": "amalgamar",
    "amalgamares": "amalgamar",
    "amalgamaria": "amalgamar",
    "amalgamariam": "amalgamar",
    "amalgamarias": "amalgamar",
    "amalgamarmo": "amalgamar",
    "amalgamarmos": "amalgamar",
    "amalgamará": "amalgamar",
    "amalgamarás": "amalgamar",
    "amalgamarão": "amalgamar",
    "amalgamaríamos": "amalgamar",
    "amalgamaríeis": "amalgamar",
    "amalgamas": "amalgamar",
    "amalgamasse": "amalgamar",
    "amalgamassem": "amalgamar",
    "amalgamasses": "amalgamar",
    "amalgamaste": "amalgamar",
    "amalgamastes": "amalgamar",
    "amalgamava": "amalgamar",
    "amalgamavam": "amalgamar",
    "amalgamavas": "amalgamar",
    "amalgamações": "amalgamação",
    "amalgame": "amalgamar",
    "amalgamei": "amalgamar",
    "amalgameis": "amalgamar",
    "amalgamem": "amalgamar",
    "amalgamemo": "amalgamar",
    "amalgamemos": "amalgamar",
    "amalgamentos": "amalgamento",
    "amalgames": "amalgamar",
    "amalgamo": "amalgamar",
    "amalgamou": "amalgamar",
    "amalgamá": "amalgamar",
    "amalgamámo": "amalgamar",
    "amalgamámos": "amalgamar",
    "amalgamáramo": "amalgamar",
    "amalgamáramos": "amalgamar",
    "amalgamárei": "amalgamar",
    "amalgamáreis": "amalgamar",
    "amalgamásseis": "amalgamar",
    "amalgamássemos": "amalgamar",
    "amalgamávamo": "amalgamar",
    "amalgamávamos": "amalgamar",
    "amalgamávei": "amalgamar",
    "amalgamáveis": "amalgamar",
    "amalha": "amalhar",
    "amalhada": "amalhar",
    "amalhadas": "amalhar",
    "amalhadeiras": "amalhadeira",
    "amalhado": "amalhar",
    "amalhados": "amalhar",
    "amalhai": "amalhar",
    "amalhais": "amalhar",
    "amalham": "amalhar",
    "amalhamo": "amalhar",
    "amalhamos": "amalhar",
    "amalhando": "amalhar",
    "amalhara": "amalhar",
    "amalharam": "amalhar",
    "amalharas": "amalhar",
    "amalharde": "amalhar",
    "amalhardes": "amalhar",
    "amalhare": "amalhar",
    "amalharei": "amalhar",
    "amalhareis": "amalhar",
    "amalharem": "amalhar",
    "amalharemos": "amalhar",
    "amalhares": "amalhar",
    "amalharia": "amalhar",
    "amalhariam": "amalhar",
    "amalharias": "amalhar",
    "amalharmo": "amalhar",
    "amalharmos": "amalhar",
    "amalhará": "amalhar",
    "amalharás": "amalhar",
    "amalharão": "amalhar",
    "amalharíamos": "amalhar",
    "amalharíeis": "amalhar",
    "amalhas": "amalhar",
    "amalhasse": "amalhar",
    "amalhassem": "amalhar",
    "amalhasses": "amalhar",
    "amalhaste": "amalhar",
    "amalhastes": "amalhar",
    "amalhava": "amalhar",
    "amalhavam": "amalhar",
    "amalhavas": "amalhar",
    "amalhe": "amalhar",
    "amalhei": "amalhar",
    "amalheis": "amalhar",
    "amalhem": "amalhar",
    "amalhemo": "amalhar",
    "amalhemos": "amalhar",
    "amalhes": "amalhar",
    "amalho": "amalhar",
    "amalhoa": "amalhoar",
    "amalhoada": "amalhoar",
    "amalhoadas": "amalhoar",
    "amalhoado": "amalhoar",
    "amalhoados": "amalhoar",
    "amalhoai": "amalhoar",
    "amalhoais": "amalhoar",
    "amalhoam": "amalhoar",
    "amalhoamo": "amalhoar",
    "amalhoamos": "amalhoar",
    "amalhoando": "amalhoar",
    "amalhoara": "amalhoar",
    "amalhoaram": "amalhoar",
    "amalhoaras": "amalhoar",
    "amalhoarde": "amalhoar",
    "amalhoardes": "amalhoar",
    "amalhoare": "amalhoar",
    "amalhoarei": "amalhoar",
    "amalhoareis": "amalhoar",
    "amalhoarem": "amalhoar",
    "amalhoaremos": "amalhoar",
    "amalhoares": "amalhoar",
    "amalhoaria": "amalhoar",
    "amalhoariam": "amalhoar",
    "amalhoarias": "amalhoar",
    "amalhoarmo": "amalhoar",
    "amalhoarmos": "amalhoar",
    "amalhoará": "amalhoar",
    "amalhoarás": "amalhoar",
    "amalhoarão": "amalhoar",
    "amalhoaríamos": "amalhoar",
    "amalhoaríeis": "amalhoar",
    "amalhoas": "amalhoar",
    "amalhoasse": "amalhoar",
    "amalhoassem": "amalhoar",
    "amalhoasses": "amalhoar",
    "amalhoaste": "amalhoar",
    "amalhoastes": "amalhoar",
    "amalhoava": "amalhoar",
    "amalhoavam": "amalhoar",
    "amalhoavas": "amalhoar",
    "amalhoe": "amalhoar",
    "amalhoei": "amalhoar",
    "amalhoeis": "amalhoar",
    "amalhoem": "amalhoar",
    "amalhoemo": "amalhoar",
    "amalhoemos": "amalhoar",
    "amalhoes": "amalhoar",
    "amalhoo": "amalhoar",
    "amalhoou": "amalhoar",
    "amalhou": "amalhar",
    "amalhoá": "amalhoar",
    "amalhoámo": "amalhoar",
    "amalhoámos": "amalhoar",
    "amalhoáramo": "amalhoar",
    "amalhoáramos": "amalhoar",
    "amalhoárei": "amalhoar",
    "amalhoáreis": "amalhoar",
    "amalhoásseis": "amalhoar",
    "amalhoássemos": "amalhoar",
    "amalhoávamo": "amalhoar",
    "amalhoávamos": "amalhoar",
    "amalhoávei": "amalhoar",
    "amalhoáveis": "amalhoar",
    "amalhá": "amalhar",
    "amalhámo": "amalhar",
    "amalhámos": "amalhar",
    "amalháramo": "amalhar",
    "amalháramos": "amalhar",
    "amalhárei": "amalhar",
    "amalháreis": "amalhar",
    "amalhásseis": "amalhar",
    "amalhássemos": "amalhar",
    "amalhávamo": "amalhar",
    "amalhávamos": "amalhar",
    "amalhávei": "amalhar",
    "amalháveis": "amalhar",
    "amaloca": "amalocar",
    "amalocada": "amalocar",
    "amalocadas": "amalocar",
    "amalocado": "amalocar",
    "amalocados": "amalocar",
    "amalocai": "amalocar",
    "amalocais": "amalocar",
    "amalocam": "amalocar",
    "amalocamo": "amalocar",
    "amalocamos": "amalocar",
    "amalocando": "amalocar",
    "amalocara": "amalocar",
    "amalocaram": "amalocar",
    "amalocaras": "amalocar",
    "amalocarde": "amalocar",
    "amalocardes": "amalocar",
    "amalocare": "amalocar",
    "amalocarei": "amalocar",
    "amalocareis": "amalocar",
    "amalocarem": "amalocar",
    "amalocaremos": "amalocar",
    "amalocares": "amalocar",
    "amalocaria": "amalocar",
    "amalocariam": "amalocar",
    "amalocarias": "amalocar",
    "amalocarmo": "amalocar",
    "amalocarmos": "amalocar",
    "amalocará": "amalocar",
    "amalocarás": "amalocar",
    "amalocarão": "amalocar",
    "amalocaríamos": "amalocar",
    "amalocaríeis": "amalocar",
    "amalocas": "amalocar",
    "amalocasse": "amalocar",
    "amalocassem": "amalocar",
    "amalocasses": "amalocar",
    "amalocaste": "amalocar",
    "amalocastes": "amalocar",
    "amalocava": "amalocar",
    "amalocavam": "amalocar",
    "amalocavas": "amalocar",
    "amaloco": "amalocar",
    "amalocou": "amalocar",
    "amalocá": "amalocar",
    "amalocámo": "amalocar",
    "amalocámos": "amalocar",
    "amalocáramo": "amalocar",
    "amalocáramos": "amalocar",
    "amalocárei": "amalocar",
    "amalocáreis": "amalocar",
    "amalocásseis": "amalocar",
    "amalocássemos": "amalocar",
    "amalocávamo": "amalocar",
    "amalocávamos": "amalocar",
    "amalocávei": "amalocar",
    "amalocáveis": "amalocar",
    "amaloque": "amalocar",
    "amaloquei": "amalocar",
    "amaloqueis": "amalocar",
    "amaloquem": "amalocar",
    "amaloquemo": "amalocar",
    "amaloquemos": "amalocar",
    "amaloques": "amalocar",
    "amalta": "amaltar",
    "amaltada": "amaltar",
    "amaltadas": "amaltar",
    "amaltado": "amaltar",
    "amaltados": "amaltar",
    "amaltai": "amaltar",
    "amaltais": "amaltar",
    "amaltam": "amaltar",
    "amaltamo": "amaltar",
    "amaltamos": "amaltar",
    "amaltando": "amaltar",
    "amaltara": "amaltar",
    "amaltaram": "amaltar",
    "amaltaras": "amaltar",
    "amaltarde": "amaltar",
    "amaltardes": "amaltar",
    "amaltare": "amaltar",
    "amaltarei": "amaltar",
    "amaltareis": "amaltar",
    "amaltarem": "amaltar",
    "amaltaremos": "amaltar",
    "amaltares": "amaltar",
    "amaltaria": "amaltar",
    "amaltariam": "amaltar",
    "amaltarias": "amaltar",
    "amaltarmo": "amaltar",
    "amaltarmos": "amaltar",
    "amaltará": "amaltar",
    "amaltarás": "amaltar",
    "amaltarão": "amaltar",
    "amaltaríamos": "amaltar",
    "amaltaríeis": "amaltar",
    "amaltas": "amaltar",
    "amaltasse": "amaltar",
    "amaltassem": "amaltar",
    "amaltasses": "amaltar",
    "amaltaste": "amaltar",
    "amaltastes": "amaltar",
    "amaltava": "amaltar",
    "amaltavam": "amaltar",
    "amaltavas": "amaltar",
    "amalte": "amaltar",
    "amaltei": "amaltar",
    "amalteias": "amalteia",
    "amalteis": "amaltar",
    "amaltem": "amaltar",
    "amaltemo": "amaltar",
    "amaltemos": "amaltar",
    "amaltes": "amaltar",
    "amalto": "amaltar",
    "amaltou": "amaltar",
    "amaltá": "amaltar",
    "amaltámo": "amaltar",
    "amaltámos": "amaltar",
    "amaltáramo": "amaltar",
    "amaltáramos": "amaltar",
    "amaltárei": "amaltar",
    "amaltáreis": "amaltar",
    "amaltásseis": "amaltar",
    "amaltássemos": "amaltar",
    "amaltávamo": "amaltar",
    "amaltávamos": "amaltar",
    "amaltávei": "amaltar",
    "amaltáveis": "amaltar",
    "amaluca": "amalucar",
    "amalucada": "amalucar",
    "amalucadas": "amalucar",
    "amalucado": "amalucar",
    "amalucados": "amalucar",
    "amalucai": "amalucar",
    "amalucais": "amalucar",
    "amalucam": "amalucar",
    "amalucamo": "amalucar",
    "amalucamos": "amalucar",
    "amalucando": "amalucar",
    "amalucara": "amalucar",
    "amalucaram": "amalucar",
    "amalucaras": "amalucar",
    "amalucarde": "amalucar",
    "amalucardes": "amalucar",
    "amalucare": "amalucar",
    "amalucarei": "amalucar",
    "amalucareis": "amalucar",
    "amalucarem": "amalucar",
    "amalucaremos": "amalucar",
    "amalucares": "amalucar",
    "amalucaria": "amalucar",
    "amalucariam": "amalucar",
    "amalucarias": "amalucar",
    "amalucarmo": "amalucar",
    "amalucarmos": "amalucar",
    "amalucará": "amalucar",
    "amalucarás": "amalucar",
    "amalucarão": "amalucar",
    "amalucaríamos": "amalucar",
    "amalucaríeis": "amalucar",
    "amalucas": "amalucar",
    "amalucasse": "amalucar",
    "amalucassem": "amalucar",
    "amalucasses": "amalucar",
    "amalucaste": "amalucar",
    "amalucastes": "amalucar",
    "amalucava": "amalucar",
    "amalucavam": "amalucar",
    "amalucavas": "amalucar",
    "amaluco": "amalucar",
    "amalucou": "amalucar",
    "amalucá": "amalucar",
    "amalucámo": "amalucar",
    "amalucámos": "amalucar",
    "amalucáramo": "amalucar",
    "amalucáramos": "amalucar",
    "amalucárei": "amalucar",
    "amalucáreis": "amalucar",
    "amalucásseis": "amalucar",
    "amalucássemos": "amalucar",
    "amalucávamo": "amalucar",
    "amalucávamos": "amalucar",
    "amalucávei": "amalucar",
    "amalucáveis": "amalucar",
    "amaluque": "amalucar",
    "amaluquei": "amalucar",
    "amaluqueis": "amalucar",
    "amaluquem": "amalucar",
    "amaluquemo": "amalucar",
    "amaluquemos": "amalucar",
    "amaluques": "amalucar",
    "amam": "amar",
    "amamenta": "amamentar",
    "amamentada": "amamentar",
    "amamentadas": "amamentar",
    "amamentadeira": "amamentador",
    "amamentadeiras": "amamentador",
    "amamentado": "amamentar",
    "amamentadora": "amamentador",
    "amamentadoras": "amamentador",
    "amamentadores": "amamentador",
    "amamentados": "amamentar",
    "amamentai": "amamentar",
    "amamentais": "amamentar",
    "amamentam": "amamentar",
    "amamentamo": "amamentar",
    "amamentamos": "amamentar",
    "amamentando": "amamentar",
    "amamentara": "amamentar",
    "amamentaram": "amamentar",
    "amamentaras": "amamentar",
    "amamentarde": "amamentar",
    "amamentardes": "amamentar",
    "amamentare": "amamentar",
    "amamentarei": "amamentar",
    "amamentareis": "amamentar",
    "amamentarem": "amamentar",
    "amamentaremos": "amamentar",
    "amamentares": "amamentar",
    "amamentaria": "amamentar",
    "amamentariam": "amamentar",
    "amamentarias": "amamentar",
    "amamentarmo": "amamentar",
    "amamentarmos": "amamentar",
    "amamentará": "amamentar",
    "amamentarás": "amamentar",
    "amamentarão": "amamentar",
    "amamentaríamos": "amamentar",
    "amamentaríeis": "amamentar",
    "amamentas": "amamentar",
    "amamentasse": "amamentar",
    "amamentassem": "amamentar",
    "amamentasses": "amamentar",
    "amamentaste": "amamentar",
    "amamentastes": "amamentar",
    "amamentava": "amamentar",
    "amamentavam": "amamentar",
    "amamentavas": "amamentar",
    "amamentações": "amamentação",
    "amamente": "amamentar",
    "amamentei": "amamentar",
    "amamenteis": "amamentar",
    "amamentem": "amamentar",
    "amamentemo": "amamentar",
    "amamentemos": "amamentar",
    "amamentes": "amamentar",
    "amamento": "amamentar",
    "amamentou": "amamentar",
    "amamentá": "amamentar",
    "amamentámo": "amamentar",
    "amamentámos": "amamentar",
    "amamentáramo": "amamentar",
    "amamentáramos": "amamentar",
    "amamentárei": "amamentar",
    "amamentáreis": "amamentar",
    "amamentásseis": "amamentar",
    "amamentássemos": "amamentar",
    "amamentávamo": "amamentar",
    "amamentávamos": "amamentar",
    "amamentávei": "amamentar",
    "amamentáveis": "amamentável",
    "amames": "amame",
    "amamo": "amar",
    "amamos": "amar",
    "amanceba": "amancebar",
    "amancebada": "amancebar",
    "amancebadas": "amancebar",
    "amancebado": "amancebar",
    "amancebados": "amancebar",
    "amancebadíssima": "amancebado",
    "amancebadíssimas": "amancebado",
    "amancebadíssimo": "amancebado",
    "amancebadíssimos": "amancebado",
    "amancebai": "amancebar",
    "amancebais": "amancebar",
    "amancebam": "amancebar",
    "amancebamentos": "amancebamento",
    "amancebamo": "amancebar",
    "amancebamos": "amancebar",
    "amancebando": "amancebar",
    "amancebara": "amancebar",
    "amancebaram": "amancebar",
    "amancebaras": "amancebar",
    "amancebarde": "amancebar",
    "amancebardes": "amancebar",
    "amancebare": "amancebar",
    "amancebarei": "amancebar",
    "amancebareis": "amancebar",
    "amancebarem": "amancebar",
    "amancebaremos": "amancebar",
    "amancebares": "amancebar",
    "amancebaria": "amancebar",
    "amancebariam": "amancebar",
    "amancebarias": "amancebar",
    "amancebarmo": "amancebar",
    "amancebarmos": "amancebar",
    "amancebará": "amancebar",
    "amancebarás": "amancebar",
    "amancebarão": "amancebar",
    "amancebaríamos": "amancebar",
    "amancebaríeis": "amancebar",
    "amancebas": "amancebar",
    "amancebasse": "amancebar",
    "amancebassem": "amancebar",
    "amancebasses": "amancebar",
    "amancebaste": "amancebar",
    "amancebastes": "amancebar",
    "amancebava": "amancebar",
    "amancebavam": "amancebar",
    "amancebavas": "amancebar",
    "amancebe": "amancebar",
    "amancebei": "amancebar",
    "amancebeis": "amancebar",
    "amancebem": "amancebar",
    "amancebemo": "amancebar",
    "amancebemos": "amancebar",
    "amancebes": "amancebar",
    "amancebo": "amancebar",
    "amancebou": "amancebar",
    "amancebá": "amancebar",
    "amancebámo": "amancebar",
    "amancebámos": "amancebar",
    "amancebáramo": "amancebar",
    "amancebáramos": "amancebar",
    "amancebárei": "amancebar",
    "amancebáreis": "amancebar",
    "amancebásseis": "amancebar",
    "amancebássemos": "amancebar",
    "amancebávamo": "amancebar",
    "amancebávamos": "amancebar",
    "amancebávei": "amancebar",
    "amancebáveis": "amancebar",
    "amancha": "amanchar",
    "amanchada": "amanchar",
    "amanchadas": "amanchar",
    "amanchado": "amanchar",
    "amanchados": "amanchar",
    "amanchai": "amanchar",
    "amanchais": "amanchar",
    "amancham": "amanchar",
    "amanchamo": "amanchar",
    "amanchamos": "amanchar",
    "amanchando": "amanchar",
    "amanchara": "amanchar",
    "amancharam": "amanchar",
    "amancharas": "amanchar",
    "amancharde": "amanchar",
    "amanchardes": "amanchar",
    "amanchare": "amanchar",
    "amancharei": "amanchar",
    "amanchareis": "amanchar",
    "amancharem": "amanchar",
    "amancharemos": "amanchar",
    "amanchares": "amanchar",
    "amancharia": "amanchar",
    "amanchariam": "amanchar",
    "amancharias": "amanchar",
    "amancharmo": "amanchar",
    "amancharmos": "amanchar",
    "amanchará": "amanchar",
    "amancharás": "amanchar",
    "amancharão": "amanchar",
    "amancharíamos": "amanchar",
    "amancharíeis": "amanchar",
    "amanchas": "amanchar",
    "amanchasse": "amanchar",
    "amanchassem": "amanchar",
    "amanchasses": "amanchar",
    "amanchaste": "amanchar",
    "amanchastes": "amanchar",
    "amanchava": "amanchar",
    "amanchavam": "amanchar",
    "amanchavas": "amanchar",
    "amanche": "amanchar",
    "amanchei": "amanchar",
    "amancheis": "amanchar",
    "amanchem": "amanchar",
    "amanchemo": "amanchar",
    "amanchemos": "amanchar",
    "amanches": "amanchar",
    "amancho": "amanchar",
    "amanchou": "amanchar",
    "amanchá": "amanchar",
    "amanchámo": "amanchar",
    "amanchámos": "amanchar",
    "amancháramo": "amanchar",
    "amancháramos": "amanchar",
    "amanchárei": "amanchar",
    "amancháreis": "amanchar",
    "amanchásseis": "amanchar",
    "amanchássemos": "amanchar",
    "amanchávamo": "amanchar",
    "amanchávamos": "amanchar",
    "amanchávei": "amanchar",
    "amancháveis": "amanchar",
    "amando": "amar",
    "amaneira": "amaneirar",
    "amaneirada": "amaneirar",
    "amaneiradas": "amaneirar",
    "amaneirado": "amaneirar",
    "amaneirados": "amaneirar",
    "amaneirai": "amaneirar",
    "amaneirais": "amaneirar",
    "amaneiram": "amaneirar",
    "amaneiramentos": "amaneiramento",
    "amaneiramo": "amaneirar",
    "amaneiramos": "amaneirar",
    "amaneirando": "amaneirar",
    "amaneirara": "amaneirar",
    "amaneiraram": "amaneirar",
    "amaneiraras": "amaneirar",
    "amaneirarde": "amaneirar",
    "amaneirardes": "amaneirar",
    "amaneirare": "amaneirar",
    "amaneirarei": "amaneirar",
    "amaneirareis": "amaneirar",
    "amaneirarem": "amaneirar",
    "amaneiraremos": "amaneirar",
    "amaneirares": "amaneirar",
    "amaneiraria": "amaneirar",
    "amaneirariam": "amaneirar",
    "amaneirarias": "amaneirar",
    "amaneirarmo": "amaneirar",
    "amaneirarmos": "amaneirar",
    "amaneirará": "amaneirar",
    "amaneirarás": "amaneirar",
    "amaneirarão": "amaneirar",
    "amaneiraríamos": "amaneirar",
    "amaneiraríeis": "amaneirar",
    "amaneiras": "amaneirar",
    "amaneirasse": "amaneirar",
    "amaneirassem": "amaneirar",
    "amaneirasses": "amaneirar",
    "amaneiraste": "amaneirar",
    "amaneirastes": "amaneirar",
    "amaneirava": "amaneirar",
    "amaneiravam": "amaneirar",
    "amaneiravas": "amaneirar",
    "amaneire": "amaneirar",
    "amaneirei": "amaneirar",
    "amaneireis": "amaneirar",
    "amaneirem": "amaneirar",
    "amaneiremo": "amaneirar",
    "amaneiremos": "amaneirar",
    "amaneires": "amaneirar",
    "amaneiro": "amaneirar",
    "amaneirou": "amaneirar",
    "amaneirá": "amaneirar",
    "amaneirámo": "amaneirar",
    "amaneirámos": "amaneirar",
    "amaneiráramo": "amaneirar",
    "amaneiráramos": "amaneirar",
    "amaneirárei": "amaneirar",
    "amaneiráreis": "amaneirar",
    "amaneirásseis": "amaneirar",
    "amaneirássemos": "amaneirar",
    "amaneirávamo": "amaneirar",
    "amaneirávamos": "amaneirar",
    "amaneirávei": "amaneirar",
    "amaneiráveis": "amaneirar",
    "amanha": "amanhar",
    "amanhada": "amanhar",
    "amanhadas": "amanhar",
    "amanhado": "amanhar",
    "amanhados": "amanhar",
    "amanhai": "amanhar",
    "amanhais": "amanhar",
    "amanham": "amanhar",
    "amanhamo": "amanhar",
    "amanhamos": "amanhar",
    "amanhando": "amanhar",
    "amanhara": "amanhar",
    "amanharam": "amanhar",
    "amanharas": "amanhar",
    "amanharde": "amanhar",
    "amanhardes": "amanhar",
    "amanhare": "amanhar",
    "amanharei": "amanhar",
    "amanhareis": "amanhar",
    "amanharem": "amanhar",
    "amanharemos": "amanhar",
    "amanhares": "amanhar",
    "amanharia": "amanhar",
    "amanhariam": "amanhar",
    "amanharias": "amanhar",
    "amanharmo": "amanhar",
    "amanharmos": "amanhar",
    "amanhará": "amanhar",
    "amanharás": "amanhar",
    "amanharão": "amanhar",
    "amanharíamos": "amanhar",
    "amanharíeis": "amanhar",
    "amanhas": "amanhar",
    "amanhasse": "amanhar",
    "amanhassem": "amanhar",
    "amanhasses": "amanhar",
    "amanhaste": "amanhar",
    "amanhastes": "amanhar",
    "amanhava": "amanhar",
    "amanhavam": "amanhar",
    "amanhavas": "amanhar",
    "amanhe": "amanhar",
    "amanhece": "amanhecer",
    "amanhecei": "amanhecer",
    "amanheceis": "amanhecer",
    "amanhecem": "amanhecer",
    "amanhecemo": "amanhecer",
    "amanhecemos": "amanhecer",
    "amanhecendo": "amanhecer",
    "amanhecera": "amanhecer",
    "amanheceram": "amanhecer",
    "amanheceras": "amanhecer",
    "amanhecerdes": "amanhecer",
    "amanhecerei": "amanhecer",
    "amanhecereis": "amanhecer",
    "amanhecerem": "amanhecer",
    "amanheceremos": "amanhecer",
    "amanheceres": "amanhecer",
    "amanheceria": "amanhecer",
    "amanheceriam": "amanhecer",
    "amanhecerias": "amanhecer",
    "amanhecermo": "amanhecer",
    "amanhecermos": "amanhecer",
    "amanhecerá": "amanhecer",
    "amanhecerás": "amanhecer",
    "amanhecerão": "amanhecer",
    "amanheceríamos": "amanhecer",
    "amanheceríeis": "amanhecer",
    "amanheces": "amanhecer",
    "amanhecesse": "amanhecer",
    "amanhecessem": "amanhecer",
    "amanhecesses": "amanhecer",
    "amanheceste": "amanhecer",
    "amanhecestes": "amanhecer",
    "amanheceu": "amanhecer",
    "amanheci": "amanhecer",
    "amanhecia": "amanhecer",
    "amanheciam": "amanhecer",
    "amanhecias": "amanhecer",
    "amanhecida": "amanhecer",
    "amanhecidas": "amanhecida",
    "amanhecido": "amanhecer",
    "amanhecidos": "amanhecer",
    "amanhecêramo": "amanhecer",
    "amanhecêramos": "amanhecer",
    "amanhecêreis": "amanhecer",
    "amanhecêsseis": "amanhecer",
    "amanhecêssemos": "amanhecer",
    "amanhecíamo": "amanhecer",
    "amanhecíamos": "amanhecer",
    "amanhecíeis": "amanhecer",
    "amanhei": "amanhar",
    "amanheis": "amanhar",
    "amanhem": "amanhar",
    "amanhemo": "amanhar",
    "amanhemos": "amanhar",
    "amanhes": "amanhar",
    "amanheça": "amanhecer",
    "amanheçais": "amanhecer",
    "amanheçam": "amanhecer",
    "amanheçamo": "amanhecer",
    "amanheçamos": "amanhecer",
    "amanheças": "amanhecer",
    "amanheço": "amanhecer",
    "amanho": "amanhar",
    "amanhos": "amanho",
    "amanhou": "amanhar",
    "amanhouvada": "amanhouvado",
    "amanhouvadas": "amanhouvado",
    "amanhouvados": "amanhouvado",
    "amanhouvadíssima": "amanhouvado",
    "amanhouvadíssimas": "amanhouvado",
    "amanhouvadíssimo": "amanhouvado",
    "amanhouvadíssimos": "amanhouvado",
    "amanhuce": "amanhuçar",
    "amanhucei": "amanhuçar",
    "amanhuceis": "amanhuçar",
    "amanhucem": "amanhuçar",
    "amanhucemo": "amanhuçar",
    "amanhucemos": "amanhuçar",
    "amanhuces": "amanhuçar",
    "amanhuça": "amanhuçar",
    "amanhuçada": "amanhuçar",
    "amanhuçadas": "amanhuçar",
    "amanhuçado": "amanhuçar",
    "amanhuçados": "amanhuçar",
    "amanhuçai": "amanhuçar",
    "amanhuçais": "amanhuçar",
    "amanhuçam": "amanhuçar",
    "amanhuçamo": "amanhuçar",
    "amanhuçamos": "amanhuçar",
    "amanhuçando": "amanhuçar",
    "amanhuçara": "amanhuçar",
    "amanhuçaram": "amanhuçar",
    "amanhuçaras": "amanhuçar",
    "amanhuçarde": "amanhuçar",
    "amanhuçardes": "amanhuçar",
    "amanhuçare": "amanhuçar",
    "amanhuçarei": "amanhuçar",
    "amanhuçareis": "amanhuçar",
    "amanhuçarem": "amanhuçar",
    "amanhuçaremos": "amanhuçar",
    "amanhuçares": "amanhuçar",
    "amanhuçaria": "amanhuçar",
    "amanhuçariam": "amanhuçar",
    "amanhuçarias": "amanhuçar",
    "amanhuçarmo": "amanhuçar",
    "amanhuçarmos": "amanhuçar",
    "amanhuçará": "amanhuçar",
    "amanhuçarás": "amanhuçar",
    "amanhuçarão": "amanhuçar",
    "amanhuçaríamos": "amanhuçar",
    "amanhuçaríeis": "amanhuçar",
    "amanhuças": "amanhuçar",
    "amanhuçasse": "amanhuçar",
    "amanhuçassem": "amanhuçar",
    "amanhuçasses": "amanhuçar",
    "amanhuçaste": "amanhuçar",
    "amanhuçastes": "amanhuçar",
    "amanhuçava": "amanhuçar",
    "amanhuçavam": "amanhuçar",
    "amanhuçavas": "amanhuçar",
    "amanhuço": "amanhuçar",
    "amanhuçou": "amanhuçar",
    "amanhuçá": "amanhuçar",
    "amanhuçámo": "amanhuçar",
    "amanhuçámos": "amanhuçar",
    "amanhuçáramo": "amanhuçar",
    "amanhuçáramos": "amanhuçar",
    "amanhuçárei": "amanhuçar",
    "amanhuçáreis": "amanhuçar",
    "amanhuçásseis": "amanhuçar",
    "amanhuçássemos": "amanhuçar",
    "amanhuçávamo": "amanhuçar",
    "amanhuçávamos": "amanhuçar",
    "amanhuçávei": "amanhuçar",
    "amanhuçáveis": "amanhuçar",
    "amanhá": "amanhar",
    "amanhámo": "amanhar",
    "amanhámos": "amanhar",
    "amanháramo": "amanhar",
    "amanháramos": "amanhar",
    "amanhárei": "amanhar",
    "amanháreis": "amanhar",
    "amanhásseis": "amanhar",
    "amanhássemos": "amanhar",
    "amanhávamo": "amanhar",
    "amanhávamos": "amanhar",
    "amanhávei": "amanhar",
    "amanháveis": "amanhar",
    "amanhãs": "amanhã",
    "amanitas": "amanita",
    "amanitinas": "amanitina",
    "amansa": "amansar",
    "amansada": "amansar",
    "amansadas": "amansar",
    "amansadelas": "amansadela",
    "amansado": "amansar",
    "amansadora": "amansador",
    "amansadoras": "amansador",
    "amansadores": "amansador",
    "amansados": "amansar",
    "amansai": "amansar",
    "amansais": "amansar",
    "amansam": "amansar",
    "amansamentos": "amansamento",
    "amansamo": "amansar",
    "amansamos": "amansar",
    "amansando": "amansar",
    "amansara": "amansar",
    "amansaram": "amansar",
    "amansaras": "amansar",
    "amansardada": "amansardado",
    "amansardadas": "amansardado",
    "amansardados": "amansardado",
    "amansarde": "amansar",
    "amansardes": "amansar",
    "amansare": "amansar",
    "amansarei": "amansar",
    "amansareis": "amansar",
    "amansarem": "amansar",
    "amansaremos": "amansar",
    "amansares": "amansar",
    "amansaria": "amansar",
    "amansariam": "amansar",
    "amansarias": "amansar",
    "amansarmo": "amansar",
    "amansarmos": "amansar",
    "amansará": "amansar",
    "amansarás": "amansar",
    "amansarão": "amansar",
    "amansaríamos": "amansar",
    "amansaríeis": "amansar",
    "amansas": "amansar",
    "amansasse": "amansar",
    "amansassem": "amansar",
    "amansasses": "amansar",
    "amansaste": "amansar",
    "amansastes": "amansar",
    "amansava": "amansar",
    "amansavam": "amansar",
    "amansavas": "amansar",
    "amanse": "amansar",
    "amansei": "amansar",
    "amanseis": "amansar",
    "amansem": "amansar",
    "amansemo": "amansar",
    "amansemos": "amansar",
    "amanses": "amansar",
    "amansias": "amansia",
    "amanso": "amansar",
    "amansou": "amansar",
    "amansá": "amansar",
    "amansámo": "amansar",
    "amansámos": "amansar",
    "amansáramo": "amansar",
    "amansáramos": "amansar",
    "amansárei": "amansar",
    "amansáreis": "amansar",
    "amansásseis": "amansar",
    "amansássemos": "amansar",
    "amansávamo": "amansar",
    "amansávamos": "amansar",
    "amansávei": "amansar",
    "amansáveis": "amansar",
    "amanta": "amantar",
    "amantada": "amantar",
    "amantadas": "amantar",
    "amantado": "amantar",
    "amantados": "amantar",
    "amantai": "amantar",
    "amantais": "amantar",
    "amantam": "amantar",
    "amantamo": "amantar",
    "amantamos": "amantar",
    "amantando": "amantar",
    "amantara": "amantar",
    "amantaram": "amantar",
    "amantaras": "amantar",
    "amantarde": "amantar",
    "amantardes": "amantar",
    "amantare": "amantar",
    "amantarei": "amantar",
    "amantareis": "amantar",
    "amantarem": "amantar",
    "amantaremos": "amantar",
    "amantares": "amantar",
    "amantaria": "amantar",
    "amantariam": "amantar",
    "amantarias": "amantar",
    "amantarmo": "amantar",
    "amantarmos": "amantar",
    "amantará": "amantar",
    "amantarás": "amantar",
    "amantarão": "amantar",
    "amantaríamos": "amantar",
    "amantaríeis": "amantar",
    "amantas": "amantar",
    "amantasse": "amantar",
    "amantassem": "amantar",
    "amantasses": "amantar",
    "amantaste": "amantar",
    "amantastes": "amantar",
    "amantava": "amantar",
    "amantavam": "amantar",
    "amantavas": "amantar",
    "amante": "amantar",
    "amantei": "amantar",
    "amanteigada": "amanteigado",
    "amanteigadas": "amanteigado",
    "amanteigados": "amanteigado",
    "amanteigadíssima": "amanteigado",
    "amanteigadíssimas": "amanteigado",
    "amanteigadíssimo": "amanteigado",
    "amanteigadíssimos": "amanteigado",
    "amanteis": "amantar",
    "amantela": "amantelar",
    "amantelada": "amantelar",
    "amanteladas": "amantelar",
    "amantelado": "amantelar",
    "amantelados": "amantelar",
    "amantelai": "amantelar",
    "amantelais": "amantelar",
    "amantelam": "amantelar",
    "amantelamo": "amantelar",
    "amantelamos": "amantelar",
    "amantelando": "amantelar",
    "amantelara": "amantelar",
    "amantelaram": "amantelar",
    "amantelaras": "amantelar",
    "amantelarde": "amantelar",
    "amantelardes": "amantelar",
    "amantelare": "amantelar",
    "amantelarei": "amantelar",
    "amantelareis": "amantelar",
    "amantelarem": "amantelar",
    "amantelaremos": "amantelar",
    "amantelares": "amantelar",
    "amantelaria": "amantelar",
    "amantelariam": "amantelar",
    "amantelarias": "amantelar",
    "amantelarmo": "amantelar",
    "amantelarmos": "amantelar",
    "amantelará": "amantelar",
    "amantelarás": "amantelar",
    "amantelarão": "amantelar",
    "amantelaríamos": "amantelar",
    "amantelaríeis": "amantelar",
    "amantelas": "amantelar",
    "amantelasse": "amantelar",
    "amantelassem": "amantelar",
    "amantelasses": "amantelar",
    "amantelaste": "amantelar",
    "amantelastes": "amantelar",
    "amantelava": "amantelar",
    "amantelavam": "amantelar",
    "amantelavas": "amantelar",
    "amantele": "amantelar",
    "amantelei": "amantelar",
    "amanteleis": "amantelar",
    "amantelem": "amantelar",
    "amantelemo": "amantelar",
    "amantelemos": "amantelar",
    "amanteles": "amantelar",
    "amantelo": "amantelar",
    "amantelou": "amantelar",
    "amantelá": "amantelar",
    "amantelámo": "amantelar",
    "amantelámos": "amantelar",
    "amanteláramo": "amantelar",
    "amanteláramos": "amantelar",
    "amantelárei": "amantelar",
    "amanteláreis": "amantelar",
    "amantelásseis": "amantelar",
    "amantelássemos": "amantelar",
    "amantelávamo": "amantelar",
    "amantelávamos": "amantelar",
    "amantelávei": "amantelar",
    "amanteláveis": "amantelar",
    "amantem": "amantar",
    "amantemo": "amantar",
    "amantemos": "amantar",
    "amantes": "amante",
    "amantilha": "amantilhar",
    "amantilhada": "amantilhar",
    "amantilhadas": "amantilhar",
    "amantilhado": "amantilhar",
    "amantilhados": "amantilhar",
    "amantilhai": "amantilhar",
    "amantilhais": "amantilhar",
    "amantilham": "amantilhar",
    "amantilhamo": "amantilhar",
    "amantilhamos": "amantilhar",
    "amantilhando": "amantilhar",
    "amantilhara": "amantilhar",
    "amantilharam": "amantilhar",
    "amantilharas": "amantilhar",
    "amantilharde": "amantilhar",
    "amantilhardes": "amantilhar",
    "amantilhare": "amantilhar",
    "amantilharei": "amantilhar",
    "amantilhareis": "amantilhar",
    "amantilharem": "amantilhar",
    "amantilharemos": "amantilhar",
    "amantilhares": "amantilhar",
    "amantilharia": "amantilhar",
    "amantilhariam": "amantilhar",
    "amantilharias": "amantilhar",
    "amantilharmo": "amantilhar",
    "amantilharmos": "amantilhar",
    "amantilhará": "amantilhar",
    "amantilharás": "amantilhar",
    "amantilharão": "amantilhar",
    "amantilharíamos": "amantilhar",
    "amantilharíeis": "amantilhar",
    "amantilhas": "amantilhar",
    "amantilhasse": "amantilhar",
    "amantilhassem": "amantilhar",
    "amantilhasses": "amantilhar",
    "amantilhaste": "amantilhar",
    "amantilhastes": "amantilhar",
    "amantilhava": "amantilhar",
    "amantilhavam": "amantilhar",
    "amantilhavas": "amantilhar",
    "amantilhe": "amantilhar",
    "amantilhei": "amantilhar",
    "amantilheis": "amantilhar",
    "amantilhem": "amantilhar",
    "amantilhemo": "amantilhar",
    "amantilhemos": "amantilhar",
    "amantilhes": "amantilhar",
    "amantilho": "amantilhar",
    "amantilhos": "amantilho",
    "amantilhou": "amantilhar",
    "amantilhá": "amantilhar",
    "amantilhámo": "amantilhar",
    "amantilhámos": "amantilhar",
    "amantilháramo": "amantilhar",
    "amantilháramos": "amantilhar",
    "amantilhárei": "amantilhar",
    "amantilháreis": "amantilhar",
    "amantilhásseis": "amantilhar",
    "amantilhássemos": "amantilhar",
    "amantilhávamo": "amantilhar",
    "amantilhávamos": "amantilhar",
    "amantilhávei": "amantilhar",
    "amantilháveis": "amantilhar",
    "amantiza": "amantizar",
    "amantizada": "amantizar",
    "amantizadas": "amantizar",
    "amantizado": "amantizar",
    "amantizados": "amantizar",
    "amantizai": "amantizar",
    "amantizais": "amantizar",
    "amantizam": "amantizar",
    "amantizamo": "amantizar",
    "amantizamos": "amantizar",
    "amantizando": "amantizar",
    "amantizara": "amantizar",
    "amantizaram": "amantizar",
    "amantizaras": "amantizar",
    "amantizarde": "amantizar",
    "amantizardes": "amantizar",
    "amantizare": "amantizar",
    "amantizarei": "amantizar",
    "amantizareis": "amantizar",
    "amantizarem": "amantizar",
    "amantizaremos": "amantizar",
    "amantizares": "amantizar",
    "amantizaria": "amantizar",
    "amantizariam": "amantizar",
    "amantizarias": "amantizar",
    "amantizarmo": "amantizar",
    "amantizarmos": "amantizar",
    "amantizará": "amantizar",
    "amantizarás": "amantizar",
    "amantizarão": "amantizar",
    "amantizaríamos": "amantizar",
    "amantizaríeis": "amantizar",
    "amantizas": "amantizar",
    "amantizasse": "amantizar",
    "amantizassem": "amantizar",
    "amantizasses": "amantizar",
    "amantizaste": "amantizar",
    "amantizastes": "amantizar",
    "amantizava": "amantizar",
    "amantizavam": "amantizar",
    "amantizavas": "amantizar",
    "amantize": "amantizar",
    "amantizei": "amantizar",
    "amantizeis": "amantizar",
    "amantizem": "amantizar",
    "amantizemo": "amantizar",
    "amantizemos": "amantizar",
    "amantizes": "amantizar",
    "amantizo": "amantizar",
    "amantizou": "amantizar",
    "amantizá": "amantizar",
    "amantizámo": "amantizar",
    "amantizámos": "amantizar",
    "amantizáramo": "amantizar",
    "amantizáramos": "amantizar",
    "amantizárei": "amantizar",
    "amantizáreis": "amantizar",
    "amantizásseis": "amantizar",
    "amantizássemos": "amantizar",
    "amantizávamo": "amantizar",
    "amantizávamos": "amantizar",
    "amantizávei": "amantizar",
    "amantizáveis": "amantizar",
    "amanto": "amantar",
    "amantou": "amantar",
    "amantá": "amantar",
    "amantámo": "amantar",
    "amantámos": "amantar",
    "amantáramo": "amantar",
    "amantáramos": "amantar",
    "amantárei": "amantar",
    "amantáreis": "amantar",
    "amantásseis": "amantar",
    "amantássemos": "amantar",
    "amantávamo": "amantar",
    "amantávamos": "amantar",
    "amantávei": "amantar",
    "amantáveis": "amantar",
    "amantética": "amantético",
    "amantéticas": "amantético",
    "amantéticos": "amantético",
    "amanuenses": "amanuense",
    "amanunha": "amanunhar",
    "amanunhada": "amanunhar",
    "amanunhadas": "amanunhar",
    "amanunhado": "amanunhar",
    "amanunhados": "amanunhar",
    "amanunhai": "amanunhar",
    "amanunhais": "amanunhar",
    "amanunham": "amanunhar",
    "amanunhamo": "amanunhar",
    "amanunhamos": "amanunhar",
    "amanunhando": "amanunhar",
    "amanunhara": "amanunhar",
    "amanunharam": "amanunhar",
    "amanunharas": "amanunhar",
    "amanunharde": "amanunhar",
    "amanunhardes": "amanunhar",
    "amanunhare": "amanunhar",
    "amanunharei": "amanunhar",
    "amanunhareis": "amanunhar",
    "amanunharem": "amanunhar",
    "amanunharemos": "amanunhar",
    "amanunhares": "amanunhar",
    "amanunharia": "amanunhar",
    "amanunhariam": "amanunhar",
    "amanunharias": "amanunhar",
    "amanunharmo": "amanunhar",
    "amanunharmos": "amanunhar",
    "amanunhará": "amanunhar",
    "amanunharás": "amanunhar",
    "amanunharão": "amanunhar",
    "amanunharíamos": "amanunhar",
    "amanunharíeis": "amanunhar",
    "amanunhas": "amanunhar",
    "amanunhasse": "amanunhar",
    "amanunhassem": "amanunhar",
    "amanunhasses": "amanunhar",
    "amanunhaste": "amanunhar",
    "amanunhastes": "amanunhar",
    "amanunhava": "amanunhar",
    "amanunhavam": "amanunhar",
    "amanunhavas": "amanunhar",
    "amanunhe": "amanunhar",
    "amanunhei": "amanunhar",
    "amanunheis": "amanunhar",
    "amanunhem": "amanunhar",
    "amanunhemo": "amanunhar",
    "amanunhemos": "amanunhar",
    "amanunhes": "amanunhar",
    "amanunho": "amanunhar",
    "amanunhou": "amanunhar",
    "amanunhá": "amanunhar",
    "amanunhámo": "amanunhar",
    "amanunhámos": "amanunhar",
    "amanunháramo": "amanunhar",
    "amanunháramos": "amanunhar",
    "amanunhárei": "amanunhar",
    "amanunháreis": "amanunhar",
    "amanunhásseis": "amanunhar",
    "amanunhássemos": "amanunhar",
    "amanunhávamo": "amanunhar",
    "amanunhávamos": "amanunhar",
    "amanunhávei": "amanunhar",
    "amanunháveis": "amanunhar",
    "amapolas": "amapola",
    "amaquia": "amaquiar",
    "amaquiada": "amaquiar",
    "amaquiadas": "amaquiar",
    "amaquiado": "amaquiar",
    "amaquiados": "amaquiar",
    "amaquiai": "amaquiar",
    "amaquiais": "amaquiar",
    "amaquiam": "amaquiar",
    "amaquiamo": "amaquiar",
    "amaquiamos": "amaquiar",
    "amaquiando": "amaquiar",
    "amaquiara": "amaquiar",
    "amaquiaram": "amaquiar",
    "amaquiaras": "amaquiar",
    "amaquiarde": "amaquiar",
    "amaquiardes": "amaquiar",
    "amaquiare": "amaquiar",
    "amaquiarei": "amaquiar",
    "amaquiareis": "amaquiar",
    "amaquiarem": "amaquiar",
    "amaquiaremos": "amaquiar",
    "amaquiares": "amaquiar",
    "amaquiaria": "amaquiar",
    "amaquiariam": "amaquiar",
    "amaquiarias": "amaquiar",
    "amaquiarmo": "amaquiar",
    "amaquiarmos": "amaquiar",
    "amaquiará": "amaquiar",
    "amaquiarás": "amaquiar",
    "amaquiarão": "amaquiar",
    "amaquiaríamos": "amaquiar",
    "amaquiaríeis": "amaquiar",
    "amaquias": "amaquiar",
    "amaquiasse": "amaquiar",
    "amaquiassem": "amaquiar",
    "amaquiasses": "amaquiar",
    "amaquiaste": "amaquiar",
    "amaquiastes": "amaquiar",
    "amaquiava": "amaquiar",
    "amaquiavam": "amaquiar",
    "amaquiavas": "amaquiar",
    "amaquie": "amaquiar",
    "amaquiei": "amaquiar",
    "amaquieis": "amaquiar",
    "amaquiem": "amaquiar",
    "amaquiemo": "amaquiar",
    "amaquiemos": "amaquiar",
    "amaquies": "amaquiar",
    "amaquio": "amaquiar",
    "amaquiou": "amaquiar",
    "amaquiá": "amaquiar",
    "amaquiámo": "amaquiar",
    "amaquiámos": "amaquiar",
    "amaquiáramo": "amaquiar",
    "amaquiáramos": "amaquiar",
    "amaquiárei": "amaquiar",
    "amaquiáreis": "amaquiar",
    "amaquiásseis": "amaquiar",
    "amaquiássemos": "amaquiar",
    "amaquiávamo": "amaquiar",
    "amaquiávamos": "amaquiar",
    "amaquiávei": "amaquiar",
    "amaquiáveis": "amaquiar",
    "amara": "amaro",
    "amarada": "amarar",
    "amaradas": "amarar",
    "amarado": "amarar",
    "amarados": "amarar",
    "amaragens": "amaragem",
    "amarai": "amarar",
    "amarais": "amarar",
    "amaram": "amarar",
    "amaramo": "amarar",
    "amaramos": "amarar",
    "amarando": "amarar",
    "amarantina": "amarantino",
    "amarantinas": "amarantino",
    "amarantinos": "amarantino",
    "amarantos": "amaranto",
    "amarantácea": "amarantáceo",
    "amarantáceas": "amarantáceo",
    "amarantáceos": "amarantáceo",
    "amarara": "amarar",
    "amararam": "amarar",
    "amararas": "amarar",
    "amararde": "amarar",
    "amarardes": "amarar",
    "amarare": "amarar",
    "amararei": "amarar",
    "amarareis": "amarar",
    "amararem": "amarar",
    "amararemos": "amarar",
    "amarares": "amarar",
    "amararia": "amarar",
    "amarariam": "amarar",
    "amararias": "amarar",
    "amararmo": "amarar",
    "amararmos": "amarar",
    "amarará": "amarar",
    "amararás": "amarar",
    "amararão": "amarar",
    "amararíamos": "amarar",
    "amararíeis": "amarar",
    "amaras": "amaro",
    "amarasma": "amarasmar",
    "amarasmada": "amarasmar",
    "amarasmadas": "amarasmar",
    "amarasmado": "amarasmar",
    "amarasmados": "amarasmar",
    "amarasmai": "amarasmar",
    "amarasmais": "amarasmar",
    "amarasmam": "amarasmar",
    "amarasmamo": "amarasmar",
    "amarasmamos": "amarasmar",
    "amarasmando": "amarasmar",
    "amarasmara": "amarasmar",
    "amarasmaram": "amarasmar",
    "amarasmaras": "amarasmar",
    "amarasmardes": "amarasmar",
    "amarasmarei": "amarasmar",
    "amarasmareis": "amarasmar",
    "amarasmarem": "amarasmar",
    "amarasmaremos": "amarasmar",
    "amarasmares": "amarasmar",
    "amarasmaria": "amarasmar",
    "amarasmariam": "amarasmar",
    "amarasmarias": "amarasmar",
    "amarasmarmo": "amarasmar",
    "amarasmarmos": "amarasmar",
    "amarasmará": "amarasmar",
    "amarasmarás": "amarasmar",
    "amarasmarão": "amarasmar",
    "amarasmaríamos": "amarasmar",
    "amarasmaríeis": "amarasmar",
    "amarasmas": "amarasmar",
    "amarasmasse": "amarasmar",
    "amarasmassem": "amarasmar",
    "amarasmasses": "amarasmar",
    "amarasmaste": "amarasmar",
    "amarasmastes": "amarasmar",
    "amarasmava": "amarasmar",
    "amarasmavam": "amarasmar",
    "amarasmavas": "amarasmar",
    "amarasme": "amarasmar",
    "amarasmei": "amarasmar",
    "amarasmeis": "amarasmar",
    "amarasmem": "amarasmar",
    "amarasmemo": "amarasmar",
    "amarasmemos": "amarasmar",
    "amarasmes": "amarasmar",
    "amarasmo": "amarasmar",
    "amarasmou": "amarasmar",
    "amarasmámo": "amarasmar",
    "amarasmámos": "amarasmar",
    "amarasmáramo": "amarasmar",
    "amarasmáramos": "amarasmar",
    "amarasmáreis": "amarasmar",
    "amarasmásseis": "amarasmar",
    "amarasmássemos": "amarasmar",
    "amarasmávamo": "amarasmar",
    "amarasmávamos": "amarasmar",
    "amarasmáveis": "amarasmar",
    "amarasse": "amarar",
    "amarassem": "amarar",
    "amarasses": "amarar",
    "amaraste": "amarar",
    "amarastes": "amarar",
    "amarava": "amarar",
    "amaravam": "amarar",
    "amaravas": "amarar",
    "amarde": "amar",
    "amardes": "amar",
    "amare": "amarar",
    "amarei": "amarar",
    "amareis": "amarar",
    "amarela": "amarelo",
    "amarelada": "amarelar",
    "amareladas": "amarelar",
    "amarelado": "amarelar",
    "amarelados": "amarelar",
    "amareladíssima": "amarelado",
    "amareladíssimas": "amarelado",
    "amareladíssimo": "amarelado",
    "amareladíssimos": "amarelado",
    "amarelai": "amarelar",
    "amarelais": "amarelar",
    "amarelam": "amarelar",
    "amarelamo": "amarelar",
    "amarelamos": "amarelar",
    "amarelando": "amarelar",
    "amarelantes": "amarelante",
    "amarelara": "amarelar",
    "amarelaram": "amarelar",
    "amarelaras": "amarelar",
    "amarelarde": "amarelar",
    "amarelardes": "amarelar",
    "amarelare": "amarelar",
    "amarelarei": "amarelar",
    "amarelareis": "amarelar",
    "amarelarem": "amarelar",
    "amarelaremos": "amarelar",
    "amarelares": "amarelar",
    "amarelaria": "amarelar",
    "amarelariam": "amarelar",
    "amarelarias": "amarelar",
    "amarelarmo": "amarelar",
    "amarelarmos": "amarelar",
    "amarelará": "amarelar",
    "amarelarás": "amarelar",
    "amarelarão": "amarelar",
    "amarelaríamos": "amarelar",
    "amarelaríeis": "amarelar",
    "amarelas": "amarelo",
    "amarelasse": "amarelar",
    "amarelassem": "amarelar",
    "amarelasses": "amarelar",
    "amarelaste": "amarelar",
    "amarelastes": "amarelar",
    "amarelava": "amarelar",
    "amarelavam": "amarelar",
    "amarelavas": "amarelar",
    "amarele": "amarelar",
    "amarelece": "amarelecer",
    "amarelecei": "amarelecer",
    "amareleceis": "amarelecer",
    "amarelecem": "amarelecer",
    "amarelecemo": "amarelecer",
    "amarelecemos": "amarelecer",
    "amarelecendo": "amarelecer",
    "amarelecera": "amarelecer",
    "amareleceram": "amarelecer",
    "amareleceras": "amarelecer",
    "amarelecerde": "amarelecer",
    "amarelecerdes": "amarelecer",
    "amarelecere": "amarelecer",
    "amarelecerei": "amarelecer",
    "amarelecereis": "amarelecer",
    "amarelecerem": "amarelecer",
    "amareleceremos": "amarelecer",
    "amareleceres": "amarelecer",
    "amareleceria": "amarelecer",
    "amareleceriam": "amarelecer",
    "amarelecerias": "amarelecer",
    "amarelecermo": "amarelecer",
    "amarelecermos": "amarelecer",
    "amarelecerá": "amarelecer",
    "amarelecerás": "amarelecer",
    "amarelecerão": "amarelecer",
    "amareleceríamos": "amarelecer",
    "amareleceríeis": "amarelecer",
    "amareleces": "amarelecer",
    "amarelecesse": "amarelecer",
    "amarelecessem": "amarelecer",
    "amarelecesses": "amarelecer",
    "amareleceste": "amarelecer",
    "amarelecestes": "amarelecer",
    "amareleceu": "amarelecer",
    "amareleci": "amarelecer",
    "amarelecia": "amarelecer",
    "amareleciam": "amarelecer",
    "amarelecias": "amarelecer",
    "amarelecida": "amarelecido",
    "amarelecidas": "amarelecido",
    "amarelecido": "amarelecer",
    "amarelecidos": "amarelecido",
    "amarelecimentos": "amarelecimento",
    "amarelecê": "amarelecer",
    "amarelecêramo": "amarelecer",
    "amarelecêramos": "amarelecer",
    "amarelecêrei": "amarelecer",
    "amarelecêreis": "amarelecer",
    "amarelecêsseis": "amarelecer",
    "amarelecêssemos": "amarelecer",
    "amarelecíamo": "amarelecer",
    "amarelecíamos": "amarelecer",
    "amarelecíei": "amarelecer",
    "amarelecíeis": "amarelecer",
    "amarelei": "amarelar",
    "amareleis": "amarelar",
    "amareleja": "amarelejar",
    "amarelejada": "amarelejar",
    "amarelejadas": "amarelejar",
    "amarelejado": "amarelejar",
    "amarelejados": "amarelejar",
    "amarelejai": "amarelejar",
    "amarelejais": "amarelejar",
    "amarelejam": "amarelejar",
    "amarelejamo": "amarelejar",
    "amarelejamos": "amarelejar",
    "amarelejando": "amarelejar",
    "amarelejara": "amarelejar",
    "amarelejaram": "amarelejar",
    "amarelejaras": "amarelejar",
    "amarelejardes": "amarelejar",
    "amarelejarei": "amarelejar",
    "amarelejareis": "amarelejar",
    "amarelejarem": "amarelejar",
    "amarelejaremos": "amarelejar",
    "amarelejares": "amarelejar",
    "amarelejaria": "amarelejar",
    "amarelejariam": "amarelejar",
    "amarelejarias": "amarelejar",
    "amarelejarmo": "amarelejar",
    "amarelejarmos": "amarelejar",
    "amarelejará": "amarelejar",
    "amarelejarás": "amarelejar",
    "amarelejarão": "amarelejar",
    "amarelejaríamos": "amarelejar",
    "amarelejaríeis": "amarelejar",
    "amarelejas": "amarelejar",
    "amarelejasse": "amarelejar",
    "amarelejassem": "amarelejar",
    "amarelejasses": "amarelejar",
    "amarelejaste": "amarelejar",
    "amarelejastes": "amarelejar",
    "amarelejava": "amarelejar",
    "amarelejavam": "amarelejar",
    "amarelejavas": "amarelejar",
    "amareleje": "amarelejar",
    "amarelejei": "amarelejar",
    "amarelejeis": "amarelejar",
    "amarelejem": "amarelejar",
    "amarelejemo": "amarelejar",
    "amarelejemos": "amarelejar",
    "amarelejes": "amarelejar",
    "amarelejo": "amarelejar",
    "amarelejou": "amarelejar",
    "amarelejámo": "amarelejar",
    "amarelejámos": "amarelejar",
    "amarelejáramo": "amarelejar",
    "amarelejáramos": "amarelejar",
    "amarelejáreis": "amarelejar",
    "amarelejásseis": "amarelejar",
    "amarelejássemos": "amarelejar",
    "amarelejávamo": "amarelejar",
    "amarelejávamos": "amarelejar",
    "amarelejáveis": "amarelejar",
    "amarelem": "amarelar",
    "amarelemo": "amarelar",
    "amarelemos": "amarelar",
    "amarelenta": "amarelento",
    "amarelentas": "amarelento",
    "amarelentos": "amarelento",
    "amareles": "amarelar",
    "amareleça": "amarelecer",
    "amareleçais": "amarelecer",
    "amareleçam": "amarelecer",
    "amareleçamo": "amarelecer",
    "amareleçamos": "amarelecer",
    "amareleças": "amarelecer",
    "amareleço": "amarelecer",
    "amarelidões": "amarelidão",
    "amarelinha": "amarelo",
    "amarelinhas": "amarelo",
    "amarelinho": "amarelo",
    "amarelinhos": "amarelo",
    "amarelita": "amarelo",
    "amarelitas": "amarelo",
    "amarelito": "amarelo",
    "amarelitos": "amarelo",
    "amarelo": "amarelar",
    "amarelos": "amarelo",
    "amarelou": "amarelar",
    "amarelá": "amarelar",
    "amarelámo": "amarelar",
    "amarelámos": "amarelar",
    "amareláramo": "amarelar",
    "amareláramos": "amarelar",
    "amarelárei": "amarelar",
    "amareláreis": "amarelar",
    "amarelásseis": "amarelar",
    "amarelássemos": "amarelar",
    "amarelávamo": "amarelar",
    "amarelávamos": "amarelar",
    "amarelávei": "amarelar",
    "amareláveis": "amarelar",
    "amarelíssima": "amarelo",
    "amarelíssimas": "amarelo",
    "amarelíssimo": "amarelo",
    "amarelíssimos": "amarelo",
    "amarelões": "amarelão",
    "amarem": "amarar",
    "amaremo": "amarar",
    "amaremos": "amarar",
    "amares": "amarar",
    "amarescentes": "amarescente",
    "amarfalha": "amarfalhar",
    "amarfalhada": "amarfalhar",
    "amarfalhadas": "amarfalhar",
    "amarfalhado": "amarfalhar",
    "amarfalhados": "amarfalhar",
    "amarfalhai": "amarfalhar",
    "amarfalhais": "amarfalhar",
    "amarfalham": "amarfalhar",
    "amarfalhamo": "amarfalhar",
    "amarfalhamos": "amarfalhar",
    "amarfalhando": "amarfalhar",
    "amarfalhara": "amarfalhar",
    "amarfalharam": "amarfalhar",
    "amarfalharas": "amarfalhar",
    "amarfalharde": "amarfalhar",
    "amarfalhardes": "amarfalhar",
    "amarfalhare": "amarfalhar",
    "amarfalharei": "amarfalhar",
    "amarfalhareis": "amarfalhar",
    "amarfalharem": "amarfalhar",
    "amarfalharemos": "amarfalhar",
    "amarfalhares": "amarfalhar",
    "amarfalharia": "amarfalhar",
    "amarfalhariam": "amarfalhar",
    "amarfalharias": "amarfalhar",
    "amarfalharmo": "amarfalhar",
    "amarfalharmos": "amarfalhar",
    "amarfalhará": "amarfalhar",
    "amarfalharás": "amarfalhar",
    "amarfalharão": "amarfalhar",
    "amarfalharíamos": "amarfalhar",
    "amarfalharíeis": "amarfalhar",
    "amarfalhas": "amarfalhar",
    "amarfalhasse": "amarfalhar",
    "amarfalhassem": "amarfalhar",
    "amarfalhasses": "amarfalhar",
    "amarfalhaste": "amarfalhar",
    "amarfalhastes": "amarfalhar",
    "amarfalhava": "amarfalhar",
    "amarfalhavam": "amarfalhar",
    "amarfalhavas": "amarfalhar",
    "amarfalhe": "amarfalhar",
    "amarfalhei": "amarfalhar",
    "amarfalheis": "amarfalhar",
    "amarfalhem": "amarfalhar",
    "amarfalhemo": "amarfalhar",
    "amarfalhemos": "amarfalhar",
    "amarfalhes": "amarfalhar",
    "amarfalho": "amarfalhar",
    "amarfalhou": "amarfalhar",
    "amarfalhá": "amarfalhar",
    "amarfalhámo": "amarfalhar",
    "amarfalhámos": "amarfalhar",
    "amarfalháramo": "amarfalhar",
    "amarfalháramos": "amarfalhar",
    "amarfalhárei": "amarfalhar",
    "amarfalháreis": "amarfalhar",
    "amarfalhásseis": "amarfalhar",
    "amarfalhássemos": "amarfalhar",
    "amarfalhávamo": "amarfalhar",
    "amarfalhávamos": "amarfalhar",
    "amarfalhávei": "amarfalhar",
    "amarfalháveis": "amarfalhar",
    "amarfanha": "amarfanhar",
    "amarfanhada": "amarfanhar",
    "amarfanhadas": "amarfanhar",
    "amarfanhado": "amarfanhar",
    "amarfanhados": "amarfanhar",
    "amarfanhadíssima": "amarfanhado",
    "amarfanhadíssimas": "amarfanhado",
    "amarfanhadíssimo": "amarfanhado",
    "amarfanhadíssimos": "amarfanhado",
    "amarfanhai": "amarfanhar",
    "amarfanhais": "amarfanhar",
    "amarfanham": "amarfanhar",
    "amarfanhamo": "amarfanhar",
    "amarfanhamos": "amarfanhar",
    "amarfanhando": "amarfanhar",
    "amarfanhara": "amarfanhar",
    "amarfanharam": "amarfanhar",
    "amarfanharas": "amarfanhar",
    "amarfanharde": "amarfanhar",
    "amarfanhardes": "amarfanhar",
    "amarfanhare": "amarfanhar",
    "amarfanharei": "amarfanhar",
    "amarfanhareis": "amarfanhar",
    "amarfanharem": "amarfanhar",
    "amarfanharemos": "amarfanhar",
    "amarfanhares": "amarfanhar",
    "amarfanharia": "amarfanhar",
    "amarfanhariam": "amarfanhar",
    "amarfanharias": "amarfanhar",
    "amarfanharmo": "amarfanhar",
    "amarfanharmos": "amarfanhar",
    "amarfanhará": "amarfanhar",
    "amarfanharás": "amarfanhar",
    "amarfanharão": "amarfanhar",
    "amarfanharíamos": "amarfanhar",
    "amarfanharíeis": "amarfanhar",
    "amarfanhas": "amarfanhar",
    "amarfanhasse": "amarfanhar",
    "amarfanhassem": "amarfanhar",
    "amarfanhasses": "amarfanhar",
    "amarfanhaste": "amarfanhar",
    "amarfanhastes": "amarfanhar",
    "amarfanhava": "amarfanhar",
    "amarfanhavam": "amarfanhar",
    "amarfanhavas": "amarfanhar",
    "amarfanhe": "amarfanhar",
    "amarfanhei": "amarfanhar",
    "amarfanheis": "amarfanhar",
    "amarfanhem": "amarfanhar",
    "amarfanhemo": "amarfanhar",
    "amarfanhemos": "amarfanhar",
    "amarfanhes": "amarfanhar",
    "amarfanho": "amarfanhar",
    "amarfanhou": "amarfanhar",
    "amarfanhá": "amarfanhar",
    "amarfanhámo": "amarfanhar",
    "amarfanhámos": "amarfanhar",
    "amarfanháramo": "amarfanhar",
    "amarfanháramos": "amarfanhar",
    "amarfanhárei": "amarfanhar",
    "amarfanháreis": "amarfanhar",
    "amarfanhásseis": "amarfanhar",
    "amarfanhássemos": "amarfanhar",
    "amarfanhávamo": "amarfanhar",
    "amarfanhávamos": "amarfanhar",
    "amarfanhávei": "amarfanhar",
    "amarfanháveis": "amarfanhar",
    "amarfinada": "amarfinado",
    "amarfinadas": "amarfinado",
    "amarfinados": "amarfinado",
    "amarga": "amargo",
    "amargada": "amargar",
    "amargadas": "amargar",
    "amargado": "amargar",
    "amargados": "amargar",
    "amargadíssima": "amargado",
    "amargadíssimas": "amargado",
    "amargadíssimo": "amargado",
    "amargadíssimos": "amargado",
    "amargai": "amargar",
    "amargais": "amargar",
    "amargam": "amargar",
    "amargamo": "amargar",
    "amargamos": "amargar",
    "amargando": "amargar",
    "amargara": "amargar",
    "amargaram": "amargar",
    "amargaras": "amargar",
    "amargardes": "amargar",
    "amargarei": "amargar",
    "amargareis": "amargar",
    "amargarem": "amargar",
    "amargaremos": "amargar",
    "amargares": "amargar",
    "amargaria": "amargar",
    "amargariam": "amargar",
    "amargarias": "amargar",
    "amargarmo": "amargar",
    "amargarmos": "amargar",
    "amargará": "amargar",
    "amargarás": "amargar",
    "amargarão": "amargar",
    "amargaríamos": "amargar",
    "amargaríeis": "amargar",
    "amargas": "amargo",
    "amargasse": "amargar",
    "amargassem": "amargar",
    "amargasses": "amargar",
    "amargaste": "amargar",
    "amargastes": "amargar",
    "amargava": "amargar",
    "amargavam": "amargar",
    "amargavas": "amargar",
    "amargo": "amargar",
    "amargores": "amargor",
    "amargos": "amargo",
    "amargosa": "amargoso",
    "amargosas": "amargoso",
    "amargoseiras": "amargoseira",
    "amargosos": "amargoso",
    "amargou": "amargar",
    "amargue": "amargar",
    "amarguei": "amargar",
    "amargueis": "amargar",
    "amarguem": "amargar",
    "amarguemo": "amargar",
    "amarguemos": "amargar",
    "amargues": "amargar",
    "amarguinha": "amargo",
    "amarguinhas": "amargo",
    "amarguinho": "amargo",
    "amarguinhos": "amargo",
    "amarguita": "amargo",
    "amarguitas": "amargo",
    "amarguito": "amargo",
    "amarguitos": "amargo",
    "amargura": "amargurar",
    "amargurada": "amargurar",
    "amarguradas": "amargurar",
    "amargurado": "amargurar",
    "amargurados": "amargurar",
    "amarguradíssima": "amargurado",
    "amarguradíssimas": "amargurado",
    "amarguradíssimo": "amargurado",
    "amarguradíssimos": "amargurado",
    "amargurai": "amargurar",
    "amargurais": "amargurar",
    "amarguram": "amargurar",
    "amarguramo": "amargurar",
    "amarguramos": "amargurar",
    "amargurando": "amargurar",
    "amargurara": "amargurar",
    "amarguraram": "amargurar",
    "amarguraras": "amargurar",
    "amargurarde": "amargurar",
    "amargurardes": "amargurar",
    "amargurare": "amargurar",
    "amargurarei": "amargurar",
    "amargurareis": "amargurar",
    "amargurarem": "amargurar",
    "amarguraremos": "amargurar",
    "amargurares": "amargurar",
    "amarguraria": "amargurar",
    "amargurariam": "amargurar",
    "amargurarias": "amargurar",
    "amargurarmo": "amargurar",
    "amargurarmos": "amargurar",
    "amargurará": "amargurar",
    "amargurarás": "amargurar",
    "amargurarão": "amargurar",
    "amarguraríamos": "amargurar",
    "amarguraríeis": "amargurar",
    "amarguras": "amargurar",
    "amargurasse": "amargurar",
    "amargurassem": "amargurar",
    "amargurasses": "amargurar",
    "amarguraste": "amargurar",
    "amargurastes": "amargurar",
    "amargurava": "amargurar",
    "amarguravam": "amargurar",
    "amarguravas": "amargurar",
    "amargure": "amargurar",
    "amargurei": "amargurar",
    "amargureis": "amargurar",
    "amargurem": "amargurar",
    "amarguremo": "amargurar",
    "amarguremos": "amargurar",
    "amargures": "amargurar",
    "amarguro": "amargurar",
    "amargurou": "amargurar",
    "amargurá": "amargurar",
    "amargurámo": "amargurar",
    "amargurámos": "amargurar",
    "amarguráramo": "amargurar",
    "amarguráramos": "amargurar",
    "amargurárei": "amargurar",
    "amarguráreis": "amargurar",
    "amargurásseis": "amargurar",
    "amargurássemos": "amargurar",
    "amargurávamo": "amargurar",
    "amargurávamos": "amargurar",
    "amargurávei": "amargurar",
    "amarguráveis": "amargurar",
    "amarguíssima": "amargo",
    "amarguíssimas": "amargo",
    "amarguíssimo": "amargo",
    "amarguíssimos": "amargo",
    "amargámo": "amargar",
    "amargámos": "amargar",
    "amargáramo": "amargar",
    "amargáramos": "amargar",
    "amargáreis": "amargar",
    "amargásseis": "amargar",
    "amargássemos": "amargar",
    "amargávamo": "amargar",
    "amargávamos": "amargar",
    "amargáveis": "amargar",
    "amaria": "amar",
    "amariam": "amar",
    "amarias": "amar",
    "amarica": "amaricar",
    "amaricada": "amaricar",
    "amaricadas": "amaricar",
    "amaricado": "amaricar",
    "amaricados": "amaricar",
    "amaricai": "amaricar",
    "amaricais": "amaricar",
    "amaricam": "amaricar",
    "amaricamo": "amaricar",
    "amaricamos": "amaricar",
    "amaricando": "amaricar",
    "amaricara": "amaricar",
    "amaricaram": "amaricar",
    "amaricaras": "amaricar",
    "amaricarde": "amaricar",
    "amaricardes": "amaricar",
    "amaricare": "amaricar",
    "amaricarei": "amaricar",
    "amaricareis": "amaricar",
    "amaricarem": "amaricar",
    "amaricaremos": "amaricar",
    "amaricares": "amaricar",
    "amaricaria": "amaricar",
    "amaricariam": "amaricar",
    "amaricarias": "amaricar",
    "amaricarmo": "amaricar",
    "amaricarmos": "amaricar",
    "amaricará": "amaricar",
    "amaricarás": "amaricar",
    "amaricarão": "amaricar",
    "amaricaríamos": "amaricar",
    "amaricaríeis": "amaricar",
    "amaricas": "amaricar",
    "amaricasse": "amaricar",
    "amaricassem": "amaricar",
    "amaricasses": "amaricar",
    "amaricaste": "amaricar",
    "amaricastes": "amaricar",
    "amaricava": "amaricar",
    "amaricavam": "amaricar",
    "amaricavas": "amaricar",
    "amarice": "amariçar",
    "amaricei": "amariçar",
    "amariceis": "amariçar",
    "amaricem": "amariçar",
    "amaricemo": "amariçar",
    "amaricemos": "amariçar",
    "amarices": "amariçar",
    "amarico": "amaricar",
    "amaricou": "amaricar",
    "amaricá": "amaricar",
    "amaricámo": "amaricar",
    "amaricámos": "amaricar",
    "amaricáramo": "amaricar",
    "amaricáramos": "amaricar",
    "amaricárei": "amaricar",
    "amaricáreis": "amaricar",
    "amaricásseis": "amaricar",
    "amaricássemos": "amaricar",
    "amaricávamo": "amaricar",
    "amaricávamos": "amaricar",
    "amaricávei": "amaricar",
    "amaricáveis": "amaricar",
    "amarida": "amaridar",
    "amaridada": "amaridar",
    "amaridadas": "amaridar",
    "amaridado": "amaridar",
    "amaridados": "amaridar",
    "amaridai": "amaridar",
    "amaridais": "amaridar",
    "amaridam": "amaridar",
    "amaridamo": "amaridar",
    "amaridamos": "amaridar",
    "amaridando": "amaridar",
    "amaridara": "amaridar",
    "amaridaram": "amaridar",
    "amaridaras": "amaridar",
    "amaridarde": "amaridar",
    "amaridardes": "amaridar",
    "amaridare": "amaridar",
    "amaridarei": "amaridar",
    "amaridareis": "amaridar",
    "amaridarem": "amaridar",
    "amaridaremos": "amaridar",
    "amaridares": "amaridar",
    "amaridaria": "amaridar",
    "amaridariam": "amaridar",
    "amaridarias": "amaridar",
    "amaridarmo": "amaridar",
    "amaridarmos": "amaridar",
    "amaridará": "amaridar",
    "amaridarás": "amaridar",
    "amaridarão": "amaridar",
    "amaridaríamos": "amaridar",
    "amaridaríeis": "amaridar",
    "amaridas": "amaridar",
    "amaridasse": "amaridar",
    "amaridassem": "amaridar",
    "amaridasses": "amaridar",
    "amaridaste": "amaridar",
    "amaridastes": "amaridar",
    "amaridava": "amaridar",
    "amaridavam": "amaridar",
    "amaridavas": "amaridar",
    "amaride": "amaridar",
    "amaridei": "amaridar",
    "amarideis": "amaridar",
    "amaridem": "amaridar",
    "amaridemo": "amaridar",
    "amaridemos": "amaridar",
    "amarides": "amaridar",
    "amarido": "amaridar",
    "amaridou": "amaridar",
    "amaridá": "amaridar",
    "amaridámo": "amaridar",
    "amaridámos": "amaridar",
    "amaridáramo": "amaridar",
    "amaridáramos": "amaridar",
    "amaridárei": "amaridar",
    "amaridáreis": "amaridar",
    "amaridásseis": "amaridar",
    "amaridássemos": "amaridar",
    "amaridávamo": "amaridar",
    "amaridávamos": "amaridar",
    "amaridávei": "amaridar",
    "amaridáveis": "amaridar",
    "amariladácea": "amariladáceo",
    "amariladáceas": "amariladáceo",
    "amariladáceos": "amariladáceo",
    "amarilhas": "amarilha",
    "amarilidáceas": "amarilidácea",
    "amarinas": "amarina",
    "amarinha": "amarinhar",
    "amarinhada": "amarinhar",
    "amarinhadas": "amarinhar",
    "amarinhado": "amarinhar",
    "amarinhados": "amarinhar",
    "amarinhai": "amarinhar",
    "amarinhais": "amarinhar",
    "amarinham": "amarinhar",
    "amarinhamo": "amarinhar",
    "amarinhamos": "amarinhar",
    "amarinhando": "amarinhar",
    "amarinhara": "amarinhar",
    "amarinharam": "amarinhar",
    "amarinharas": "amarinhar",
    "amarinharde": "amarinhar",
    "amarinhardes": "amarinhar",
    "amarinhare": "amarinhar",
    "amarinharei": "amarinhar",
    "amarinhareis": "amarinhar",
    "amarinharem": "amarinhar",
    "amarinharemos": "amarinhar",
    "amarinhares": "amarinhar",
    "amarinharia": "amarinhar",
    "amarinhariam": "amarinhar",
    "amarinharias": "amarinhar",
    "amarinharmo": "amarinhar",
    "amarinharmos": "amarinhar",
    "amarinhará": "amarinhar",
    "amarinharás": "amarinhar",
    "amarinharão": "amarinhar",
    "amarinharíamos": "amarinhar",
    "amarinharíeis": "amarinhar",
    "amarinhas": "amarinhar",
    "amarinhasse": "amarinhar",
    "amarinhassem": "amarinhar",
    "amarinhasses": "amarinhar",
    "amarinhaste": "amarinhar",
    "amarinhastes": "amarinhar",
    "amarinhava": "amarinhar",
    "amarinhavam": "amarinhar",
    "amarinhavas": "amarinhar",
    "amarinhe": "amarinhar",
    "amarinhei": "amarinhar",
    "amarinheis": "amarinhar",
    "amarinhem": "amarinhar",
    "amarinhemo": "amarinhar",
    "amarinhemos": "amarinhar",
    "amarinhes": "amarinhar",
    "amarinho": "amarinhar",
    "amarinhou": "amarinhar",
    "amarinhá": "amarinhar",
    "amarinhámo": "amarinhar",
    "amarinhámos": "amarinhar",
    "amarinháramo": "amarinhar",
    "amarinháramos": "amarinhar",
    "amarinhárei": "amarinhar",
    "amarinháreis": "amarinhar",
    "amarinhásseis": "amarinhar",
    "amarinhássemos": "amarinhar",
    "amarinhávamo": "amarinhar",
    "amarinhávamos": "amarinhar",
    "amarinhávei": "amarinhar",
    "amarinháveis": "amarinhar",
    "amarique": "amaricar",
    "amariquei": "amaricar",
    "amariqueis": "amaricar",
    "amariquem": "amaricar",
    "amariquemo": "amaricar",
    "amariquemos": "amaricar",
    "amariques": "amaricar",
    "amaritudes": "amaritude",
    "amariça": "amariçar",
    "amariçada": "amariçar",
    "amariçadas": "amariçar",
    "amariçado": "amariçar",
    "amariçados": "amariçar",
    "amariçai": "amariçar",
    "amariçais": "amariçar",
    "amariçam": "amariçar",
    "amariçamo": "amariçar",
    "amariçamos": "amariçar",
    "amariçando": "amariçar",
    "amariçara": "amariçar",
    "amariçaram": "amariçar",
    "amariçaras": "amariçar",
    "amariçardes": "amariçar",
    "amariçarei": "amariçar",
    "amariçareis": "amariçar",
    "amariçarem": "amariçar",
    "amariçaremos": "amariçar",
    "amariçares": "amariçar",
    "amariçaria": "amariçar",
    "amariçariam": "amariçar",
    "amariçarias": "amariçar",
    "amariçarmo": "amariçar",
    "amariçarmos": "amariçar",
    "amariçará": "amariçar",
    "amariçarás": "amariçar",
    "amariçarão": "amariçar",
    "amariçaríamos": "amariçar",
    "amariçaríeis": "amariçar",
    "amariças": "amariçar",
    "amariçasse": "amariçar",
    "amariçassem": "amariçar",
    "amariçasses": "amariçar",
    "amariçaste": "amariçar",
    "amariçastes": "amariçar",
    "amariçava": "amariçar",
    "amariçavam": "amariçar",
    "amariçavas": "amariçar",
    "amariço": "amariçar",
    "amariçou": "amariçar",
    "amariçámo": "amariçar",
    "amariçámos": "amariçar",
    "amariçáramo": "amariçar",
    "amariçáramos": "amariçar",
    "amariçáreis": "amariçar",
    "amariçásseis": "amariçar",
    "amariçássemos": "amariçar",
    "amariçávamo": "amariçar",
    "amariçávamos": "amariçar",
    "amariçáveis": "amariçar",
    "amarmo": "amar",
    "amarmos": "amar",
    "amaro": "amarar",
    "amaros": "amaro",
    "amarota": "amarotar",
    "amarotada": "amarotar",
    "amarotadas": "amarotar",
    "amarotado": "amarotar",
    "amarotados": "amarotar",
    "amarotai": "amarotar",
    "amarotais": "amarotar",
    "amarotam": "amarotar",
    "amarotamo": "amarotar",
    "amarotamos": "amarotar",
    "amarotando": "amarotar",
    "amarotara": "amarotar",
    "amarotaram": "amarotar",
    "amarotaras": "amarotar",
    "amarotarde": "amarotar",
    "amarotardes": "amarotar",
    "amarotare": "amarotar",
    "amarotarei": "amarotar",
    "amarotareis": "amarotar",
    "amarotarem": "amarotar",
    "amarotaremos": "amarotar",
    "amarotares": "amarotar",
    "amarotaria": "amarotar",
    "amarotariam": "amarotar",
    "amarotarias": "amarotar",
    "amarotarmo": "amarotar",
    "amarotarmos": "amarotar",
    "amarotará": "amarotar",
    "amarotarás": "amarotar",
    "amarotarão": "amarotar",
    "amarotaríamos": "amarotar",
    "amarotaríeis": "amarotar",
    "amarotas": "amarotar",
    "amarotasse": "amarotar",
    "amarotassem": "amarotar",
    "amarotasses": "amarotar",
    "amarotaste": "amarotar",
    "amarotastes": "amarotar",
    "amarotava": "amarotar",
    "amarotavam": "amarotar",
    "amarotavas": "amarotar",
    "amarote": "amarotar",
    "amarotei": "amarotar",
    "amaroteis": "amarotar",
    "amarotem": "amarotar",
    "amarotemo": "amarotar",
    "amarotemos": "amarotar",
    "amarotes": "amarotar",
    "amaroto": "amarotar",
    "amarotou": "amarotar",
    "amarotá": "amarotar",
    "amarotámo": "amarotar",
    "amarotámos": "amarotar",
    "amarotáramo": "amarotar",
    "amarotáramos": "amarotar",
    "amarotárei": "amarotar",
    "amarotáreis": "amarotar",
    "amarotásseis": "amarotar",
    "amarotássemos": "amarotar",
    "amarotávamo": "amarotar",
    "amarotávamos": "amarotar",
    "amarotávei": "amarotar",
    "amarotáveis": "amarotar",
    "amarou": "amarar",
    "amarra": "amarrar",
    "amarrada": "amarrar",
    "amarradas": "amarrar",
    "amarrado": "amarrar",
    "amarradoiros": "amarradoiro",
    "amarradora": "amarrador",
    "amarradoras": "amarrador",
    "amarradores": "amarrador",
    "amarrados": "amarrar",
    "amarradouros": "amarradouro",
    "amarraduras": "amarradura",
    "amarrai": "amarrar",
    "amarrais": "amarrar",
    "amarram": "amarrar",
    "amarramo": "amarrar",
    "amarramos": "amarrar",
    "amarrando": "amarrar",
    "amarrara": "amarrar",
    "amarraram": "amarrar",
    "amarraras": "amarrar",
    "amarrarde": "amarrar",
    "amarrardes": "amarrar",
    "amarrare": "amarrar",
    "amarrarei": "amarrar",
    "amarrareis": "amarrar",
    "amarrarem": "amarrar",
    "amarraremos": "amarrar",
    "amarrares": "amarrar",
    "amarraria": "amarrar",
    "amarrariam": "amarrar",
    "amarrarias": "amarrar",
    "amarrarmo": "amarrar",
    "amarrarmos": "amarrar",
    "amarrará": "amarrar",
    "amarrarás": "amarrar",
    "amarrarão": "amarrar",
    "amarraríamos": "amarrar",
    "amarraríeis": "amarrar",
    "amarras": "amarrar",
    "amarrasse": "amarrar",
    "amarrassem": "amarrar",
    "amarrasses": "amarrar",
    "amarraste": "amarrar",
    "amarrastes": "amarrar",
    "amarrava": "amarrar",
    "amarravam": "amarrar",
    "amarravas": "amarrar",
    "amarrações": "amarração",
    "amarre": "amarrar",
    "amarreca": "amarrecar",
    "amarrecada": "amarrecar",
    "amarrecadas": "amarrecar",
    "amarrecado": "amarrecar",
    "amarrecados": "amarrecar",
    "amarrecai": "amarrecar",
    "amarrecais": "amarrecar",
    "amarrecam": "amarrecar",
    "amarrecamo": "amarrecar",
    "amarrecamos": "amarrecar",
    "amarrecando": "amarrecar",
    "amarrecara": "amarrecar",
    "amarrecaram": "amarrecar",
    "amarrecaras": "amarrecar",
    "amarrecarde": "amarrecar",
    "amarrecardes": "amarrecar",
    "amarrecare": "amarrecar",
    "amarrecarei": "amarrecar",
    "amarrecareis": "amarrecar",
    "amarrecarem": "amarrecar",
    "amarrecaremos": "amarrecar",
    "amarrecares": "amarrecar",
    "amarrecaria": "amarrecar",
    "amarrecariam": "amarrecar",
    "amarrecarias": "amarrecar",
    "amarrecarmo": "amarrecar",
    "amarrecarmos": "amarrecar",
    "amarrecará": "amarrecar",
    "amarrecarás": "amarrecar",
    "amarrecarão": "amarrecar",
    "amarrecaríamos": "amarrecar",
    "amarrecaríeis": "amarrecar",
    "amarrecas": "amarrecar",
    "amarrecasse": "amarrecar",
    "amarrecassem": "amarrecar",
    "amarrecasses": "amarrecar",
    "amarrecaste": "amarrecar",
    "amarrecastes": "amarrecar",
    "amarrecava": "amarrecar",
    "amarrecavam": "amarrecar",
    "amarrecavas": "amarrecar",
    "amarreco": "amarrecar",
    "amarrecou": "amarrecar",
    "amarrecá": "amarrecar",
    "amarrecámo": "amarrecar",
    "amarrecámos": "amarrecar",
    "amarrecáramo": "amarrecar",
    "amarrecáramos": "amarrecar",
    "amarrecárei": "amarrecar",
    "amarrecáreis": "amarrecar",
    "amarrecásseis": "amarrecar",
    "amarrecássemos": "amarrecar",
    "amarrecávamo": "amarrecar",
    "amarrecávamos": "amarrecar",
    "amarrecávei": "amarrecar",
    "amarrecáveis": "amarrecar",
    "amarrei": "amarrar",
    "amarreis": "amarrar",
    "amarrem": "amarrar",
    "amarremo": "amarrar",
    "amarremos": "amarrar",
    "amarreque": "amarrecar",
    "amarrequei": "amarrecar",
    "amarrequeis": "amarrecar",
    "amarrequem": "amarrecar",
    "amarrequemo": "amarrecar",
    "amarrequemos": "amarrecar",
    "amarreques": "amarrecar",
    "amarres": "amarrar",
    "amarretas": "amarreta",
    "amarrilhos": "amarrilho",
    "amarro": "amarrar",
    "amarroa": "amarroar",
    "amarroada": "amarroar",
    "amarroadas": "amarroar",
    "amarroado": "amarroar",
    "amarroados": "amarroar",
    "amarroai": "amarroar",
    "amarroais": "amarroar",
    "amarroam": "amarroar",
    "amarroamo": "amarroar",
    "amarroamos": "amarroar",
    "amarroando": "amarroar",
    "amarroara": "amarroar",
    "amarroaram": "amarroar",
    "amarroaras": "amarroar",
    "amarroarde": "amarroar",
    "amarroardes": "amarroar",
    "amarroare": "amarroar",
    "amarroarei": "amarroar",
    "amarroareis": "amarroar",
    "amarroarem": "amarroar",
    "amarroaremos": "amarroar",
    "amarroares": "amarroar",
    "amarroaria": "amarroar",
    "amarroariam": "amarroar",
    "amarroarias": "amarroar",
    "amarroarmo": "amarroar",
    "amarroarmos": "amarroar",
    "amarroará": "amarroar",
    "amarroarás": "amarroar",
    "amarroarão": "amarroar",
    "amarroaríamos": "amarroar",
    "amarroaríeis": "amarroar",
    "amarroas": "amarroar",
    "amarroasse": "amarroar",
    "amarroassem": "amarroar",
    "amarroasses": "amarroar",
    "amarroaste": "amarroar",
    "amarroastes": "amarroar",
    "amarroava": "amarroar",
    "amarroavam": "amarroar",
    "amarroavas": "amarroar",
    "amarroe": "amarroar",
    "amarroei": "amarroar",
    "amarroeis": "amarroar",
    "amarroem": "amarroar",
    "amarroemo": "amarroar",
    "amarroemos": "amarroar",
    "amarroes": "amarroar",
    "amarroo": "amarroar",
    "amarroou": "amarroar",
    "amarroquinada": "amarroquinado",
    "amarroquinadas": "amarroquinado",
    "amarroquinados": "amarroquinado",
    "amarrota": "amarrotar",
    "amarrotada": "amarrotar",
    "amarrotadas": "amarrotar",
    "amarrotado": "amarrotar",
    "amarrotados": "amarrotar",
    "amarrotadíssima": "amarrotado",
    "amarrotadíssimas": "amarrotado",
    "amarrotadíssimo": "amarrotado",
    "amarrotadíssimos": "amarrotado",
    "amarrotai": "amarrotar",
    "amarrotais": "amarrotar",
    "amarrotam": "amarrotar",
    "amarrotamentos": "amarrotamento",
    "amarrotamo": "amarrotar",
    "amarrotamos": "amarrotar",
    "amarrotando": "amarrotar",
    "amarrotara": "amarrotar",
    "amarrotaram": "amarrotar",
    "amarrotaras": "amarrotar",
    "amarrotarde": "amarrotar",
    "amarrotardes": "amarrotar",
    "amarrotare": "amarrotar",
    "amarrotarei": "amarrotar",
    "amarrotareis": "amarrotar",
    "amarrotarem": "amarrotar",
    "amarrotaremos": "amarrotar",
    "amarrotares": "amarrotar",
    "amarrotaria": "amarrotar",
    "amarrotariam": "amarrotar",
    "amarrotarias": "amarrotar",
    "amarrotarmo": "amarrotar",
    "amarrotarmos": "amarrotar",
    "amarrotará": "amarrotar",
    "amarrotarás": "amarrotar",
    "amarrotarão": "amarrotar",
    "amarrotaríamos": "amarrotar",
    "amarrotaríeis": "amarrotar",
    "amarrotas": "amarrotar",
    "amarrotasse": "amarrotar",
    "amarrotassem": "amarrotar",
    "amarrotasses": "amarrotar",
    "amarrotaste": "amarrotar",
    "amarrotastes": "amarrotar",
    "amarrotava": "amarrotar",
    "amarrotavam": "amarrotar",
    "amarrotavas": "amarrotar",
    "amarrote": "amarrotar",
    "amarrotei": "amarrotar",
    "amarroteis": "amarrotar",
    "amarrotem": "amarrotar",
    "amarrotemo": "amarrotar",
    "amarrotemos": "amarrotar",
    "amarrotes": "amarrotar",
    "amarroto": "amarrotar",
    "amarrotou": "amarrotar",
    "amarrotá": "amarrotar",
    "amarrotámo": "amarrotar",
    "amarrotámos": "amarrotar",
    "amarrotáramo": "amarrotar",
    "amarrotáramos": "amarrotar",
    "amarrotárei": "amarrotar",
    "amarrotáreis": "amarrotar",
    "amarrotásseis": "amarrotar",
    "amarrotássemos": "amarrotar",
    "amarrotávamo": "amarrotar",
    "amarrotávamos": "amarrotar",
    "amarrotávei": "amarrotar",
    "amarrotáveis": "amarrotável",
    "amarrou": "amarrar",
    "amarroá": "amarroar",
    "amarroámo": "amarroar",
    "amarroámos": "amarroar",
    "amarroáramo": "amarroar",
    "amarroáramos": "amarroar",
    "amarroárei": "amarroar",
    "amarroáreis": "amarroar",
    "amarroásseis": "amarroar",
    "amarroássemos": "amarroar",
    "amarroávamo": "amarroar",
    "amarroávamos": "amarroar",
    "amarroávei": "amarroar",
    "amarroáveis": "amarroar",
    "amarrá": "amarrar",
    "amarrámo": "amarrar",
    "amarrámos": "amarrar",
    "amarráramo": "amarrar",
    "amarráramos": "amarrar",
    "amarrárei": "amarrar",
    "amarráreis": "amarrar",
    "amarrásseis": "amarrar",
    "amarrássemos": "amarrar",
    "amarrávamo": "amarrar",
    "amarrávamos": "amarrar",
    "amarrávei": "amarrar",
    "amarráveis": "amarrar",
    "amartela": "amartelar",
    "amartelada": "amartelar",
    "amarteladas": "amartelar",
    "amartelado": "amartelar",
    "amartelados": "amartelar",
    "amartelai": "amartelar",
    "amartelais": "amartelar",
    "amartelam": "amartelar",
    "amartelamo": "amartelar",
    "amartelamos": "amartelar",
    "amartelando": "amartelar",
    "amartelara": "amartelar",
    "amartelaram": "amartelar",
    "amartelaras": "amartelar",
    "amartelarde": "amartelar",
    "amartelardes": "amartelar",
    "amartelare": "amartelar",
    "amartelarei": "amartelar",
    "amartelareis": "amartelar",
    "amartelarem": "amartelar",
    "amartelaremos": "amartelar",
    "amartelares": "amartelar",
    "amartelaria": "amartelar",
    "amartelariam": "amartelar",
    "amartelarias": "amartelar",
    "amartelarmo": "amartelar",
    "amartelarmos": "amartelar",
    "amartelará": "amartelar",
    "amartelarás": "amartelar",
    "amartelarão": "amartelar",
    "amartelaríamos": "amartelar",
    "amartelaríeis": "amartelar",
    "amartelas": "amartelar",
    "amartelasse": "amartelar",
    "amartelassem": "amartelar",
    "amartelasses": "amartelar",
    "amartelaste": "amartelar",
    "amartelastes": "amartelar",
    "amartelava": "amartelar",
    "amartelavam": "amartelar",
    "amartelavas": "amartelar",
    "amartele": "amartelar",
    "amartelei": "amartelar",
    "amarteleis": "amartelar",
    "amartelem": "amartelar",
    "amartelemo": "amartelar",
    "amartelemos": "amartelar",
    "amarteles": "amartelar",
    "amartelo": "amartelar",
    "amartelou": "amartelar",
    "amartelá": "amartelar",
    "amartelámo": "amartelar",
    "amartelámos": "amartelar",
    "amarteláramo": "amartelar",
    "amarteláramos": "amartelar",
    "amartelárei": "amartelar",
    "amarteláreis": "amartelar",
    "amartelásseis": "amartelar",
    "amartelássemos": "amartelar",
    "amartelávamo": "amartelar",
    "amartelávamos": "amartelar",
    "amartelávei": "amartelar",
    "amarteláveis": "amartelar",
    "amarugens": "amarugem",
    "amarugenta": "amarugento",
    "amarugentas": "amarugento",
    "amarugentos": "amarugento",
    "amaruja": "amarujar",
    "amarujada": "amarujar",
    "amarujadas": "amarujar",
    "amarujado": "amarujar",
    "amarujados": "amarujar",
    "amarujai": "amarujar",
    "amarujais": "amarujar",
    "amarujam": "amarujar",
    "amarujamo": "amarujar",
    "amarujamos": "amarujar",
    "amarujando": "amarujar",
    "amarujara": "amarujar",
    "amarujaram": "amarujar",
    "amarujaras": "amarujar",
    "amarujardes": "amarujar",
    "amarujarei": "amarujar",
    "amarujareis": "amarujar",
    "amarujarem": "amarujar",
    "amarujaremos": "amarujar",
    "amarujares": "amarujar",
    "amarujaria": "amarujar",
    "amarujariam": "amarujar",
    "amarujarias": "amarujar",
    "amarujarmo": "amarujar",
    "amarujarmos": "amarujar",
    "amarujará": "amarujar",
    "amarujarás": "amarujar",
    "amarujarão": "amarujar",
    "amarujaríamos": "amarujar",
    "amarujaríeis": "amarujar",
    "amarujas": "amarujar",
    "amarujasse": "amarujar",
    "amarujassem": "amarujar",
    "amarujasses": "amarujar",
    "amarujaste": "amarujar",
    "amarujastes": "amarujar",
    "amarujava": "amarujar",
    "amarujavam": "amarujar",
    "amarujavas": "amarujar",
    "amaruje": "amarujar",
    "amarujei": "amarujar",
    "amarujeis": "amarujar",
    "amarujem": "amarujar",
    "amarujemo": "amarujar",
    "amarujemos": "amarujar",
    "amarujes": "amarujar",
    "amarujo": "amarujar",
    "amarujou": "amarujar",
    "amarujámo": "amarujar",
    "amarujámos": "amarujar",
    "amarujáramo": "amarujar",
    "amarujáramos": "amarujar",
    "amarujáreis": "amarujar",
    "amarujásseis": "amarujar",
    "amarujássemos": "amarujar",
    "amarujávamo": "amarujar",
    "amarujávamos": "amarujar",
    "amarujáveis": "amarujar",
    "amarulenta": "amarulento",
    "amarulentas": "amarulento",
    "amarulentos": "amarulento",
    "amarumes": "amarume",
    "amará": "amarar",
    "amarámo": "amarar",
    "amarámos": "amarar",
    "amaráramo": "amarar",
    "amaráramos": "amarar",
    "amarárei": "amarar",
    "amaráreis": "amarar",
    "amarás": "amar",
    "amarásseis": "amarar",
    "amarássemos": "amarar",
    "amarávamo": "amarar",
    "amarávamos": "amarar",
    "amarávei": "amarar",
    "amaráveis": "amarar",
    "amarão": "amar",
    "amaríamos": "amar",
    "amaríeis": "amar",
    "amarílides": "amarílide",
    "amarínea": "amaríneo",
    "amaríneas": "amaríneo",
    "amaríneos": "amaríneo",
    "amaríssima": "amaro",
    "amaríssimas": "amaro",
    "amaríssimo": "amaro",
    "amaríssimos": "amaro",
    "amas": "amo",
    "amasia": "amasiar",
    "amasiada": "amasiar",
    "amasiadas": "amasiar",
    "amasiado": "amasiar",
    "amasiados": "amasiar",
    "amasiai": "amasiar",
    "amasiais": "amasiar",
    "amasiam": "amasiar",
    "amasiamo": "amasiar",
    "amasiamos": "amasiar",
    "amasiando": "amasiar",
    "amasiara": "amasiar",
    "amasiaram": "amasiar",
    "amasiaras": "amasiar",
    "amasiarde": "amasiar",
    "amasiardes": "amasiar",
    "amasiare": "amasiar",
    "amasiarei": "amasiar",
    "amasiareis": "amasiar",
    "amasiarem": "amasiar",
    "amasiaremos": "amasiar",
    "amasiares": "amasiar",
    "amasiaria": "amasiar",
    "amasiariam": "amasiar",
    "amasiarias": "amasiar",
    "amasiarmo": "amasiar",
    "amasiarmos": "amasiar",
    "amasiará": "amasiar",
    "amasiarás": "amasiar",
    "amasiarão": "amasiar",
    "amasiaríamos": "amasiar",
    "amasiaríeis": "amasiar",
    "amasias": "amasiar",
    "amasiasse": "amasiar",
    "amasiassem": "amasiar",
    "amasiasses": "amasiar",
    "amasiaste": "amasiar",
    "amasiastes": "amasiar",
    "amasiava": "amasiar",
    "amasiavam": "amasiar",
    "amasiavas": "amasiar",
    "amasie": "amasiar",
    "amasiei": "amasiar",
    "amasieis": "amasiar",
    "amasiem": "amasiar",
    "amasiemo": "amasiar",
    "amasiemos": "amasiar",
    "amasies": "amasiar",
    "amasio": "amasiar",
    "amasiou": "amasiar",
    "amasiá": "amasiar",
    "amasiámo": "amasiar",
    "amasiámos": "amasiar",
    "amasiáramo": "amasiar",
    "amasiáramos": "amasiar",
    "amasiárei": "amasiar",
    "amasiáreis": "amasiar",
    "amasiásseis": "amasiar",
    "amasiássemos": "amasiar",
    "amasiávamo": "amasiar",
    "amasiávamos": "amasiar",
    "amasiávei": "amasiar",
    "amasiáveis": "amasiar",
    "amassa": "amassar",
    "amassada": "amassar",
    "amassadas": "amassar",
    "amassadeira": "amassador",
    "amassadeiras": "amassador",
    "amassadelas": "amassadela",
    "amassadias": "amassadia",
    "amassado": "amassar",
    "amassadoiros": "amassadoiro",
    "amassadora": "amassador",
    "amassadoras": "amassador",
    "amassadores": "amassador",
    "amassados": "amassar",
    "amassadouros": "amassadouro",
    "amassaduras": "amassadura",
    "amassai": "amassar",
    "amassais": "amassar",
    "amassam": "amassar",
    "amassamo": "amassar",
    "amassamos": "amassar",
    "amassando": "amassar",
    "amassara": "amassar",
    "amassaram": "amassar",
    "amassaras": "amassar",
    "amassarde": "amassar",
    "amassardes": "amassar",
    "amassare": "amassar",
    "amassarei": "amassar",
    "amassareis": "amassar",
    "amassarem": "amassar",
    "amassaremos": "amassar",
    "amassares": "amassar",
    "amassaria": "amassar",
    "amassariam": "amassar",
    "amassarias": "amassaria",
    "amassarmo": "amassar",
    "amassarmos": "amassar",
    "amassará": "amassar",
    "amassarás": "amassar",
    "amassarão": "amassar",
    "amassaríamos": "amassar",
    "amassaríeis": "amassar",
    "amassas": "amassar",
    "amassasse": "amassar",
    "amassassem": "amassar",
    "amassasses": "amassar",
    "amassaste": "amassar",
    "amassastes": "amassar",
    "amassava": "amassar",
    "amassavam": "amassar",
    "amassavas": "amassar",
    "amasse": "amassar",
    "amassei": "amassar",
    "amasseis": "amassar",
    "amassem": "amassar",
    "amassemo": "amassar",
    "amassemos": "amassar",
    "amasses": "amassar",
    "amassilhos": "amassilho",
    "amasso": "amassar",
    "amassou": "amassar",
    "amassá": "amassar",
    "amassámo": "amassar",
    "amassámos": "amassar",
    "amassáramo": "amassar",
    "amassáramos": "amassar",
    "amassárei": "amassar",
    "amassáreis": "amassar",
    "amassásseis": "amassar",
    "amassássemos": "amassar",
    "amassávamo": "amassar",
    "amassávamos": "amassar",
    "amassávei": "amassar",
    "amassáveis": "amassar",
    "amaste": "amar",
    "amastes": "amar",
    "amastias": "amastia",
    "amastozoários": "amastozoário",
    "amasónias": "amasónia",
    "amatala": "amatalar",
    "amatalada": "amatalar",
    "amataladas": "amatalar",
    "amatalado": "amatalar",
    "amatalados": "amatalar",
    "amatalai": "amatalar",
    "amatalais": "amatalar",
    "amatalam": "amatalar",
    "amatalamo": "amatalar",
    "amatalamos": "amatalar",
    "amatalando": "amatalar",
    "amatalara": "amatalar",
    "amatalaram": "amatalar",
    "amatalaras": "amatalar",
    "amatalarde": "amatalar",
    "amatalardes": "amatalar",
    "amatalare": "amatalar",
    "amatalarei": "amatalar",
    "amatalareis": "amatalar",
    "amatalarem": "amatalar",
    "amatalaremos": "amatalar",
    "amatalares": "amatalar",
    "amatalaria": "amatalar",
    "amatalariam": "amatalar",
    "amatalarias": "amatalar",
    "amatalarmo": "amatalar",
    "amatalarmos": "amatalar",
    "amatalará": "amatalar",
    "amatalarás": "amatalar",
    "amatalarão": "amatalar",
    "amatalaríamos": "amatalar",
    "amatalaríeis": "amatalar",
    "amatalas": "amatalar",
    "amatalasse": "amatalar",
    "amatalassem": "amatalar",
    "amatalasses": "amatalar",
    "amatalaste": "amatalar",
    "amatalastes": "amatalar",
    "amatalava": "amatalar",
    "amatalavam": "amatalar",
    "amatalavas": "amatalar",
    "amatale": "amatalar",
    "amatalei": "amatalar",
    "amataleis": "amatalar",
    "amatalem": "amatalar",
    "amatalemo": "amatalar",
    "amatalemos": "amatalar",
    "amatales": "amatalar",
    "amatalo": "amatalar",
    "amatalota": "amatalotar",
    "amatalotada": "amatalotar",
    "amatalotadas": "amatalotar",
    "amatalotado": "amatalotar",
    "amatalotados": "amatalotar",
    "amatalotai": "amatalotar",
    "amatalotais": "amatalotar",
    "amatalotam": "amatalotar",
    "amatalotamo": "amatalotar",
    "amatalotamos": "amatalotar",
    "amatalotando": "amatalotar",
    "amatalotara": "amatalotar",
    "amatalotaram": "amatalotar",
    "amatalotaras": "amatalotar",
    "amatalotarde": "amatalotar",
    "amatalotardes": "amatalotar",
    "amatalotare": "amatalotar",
    "amatalotarei": "amatalotar",
    "amatalotareis": "amatalotar",
    "amatalotarem": "amatalotar",
    "amatalotaremos": "amatalotar",
    "amatalotares": "amatalotar",
    "amatalotaria": "amatalotar",
    "amatalotariam": "amatalotar",
    "amatalotarias": "amatalotar",
    "amatalotarmo": "amatalotar",
    "amatalotarmos": "amatalotar",
    "amatalotará": "amatalotar",
    "amatalotarás": "amatalotar",
    "amatalotarão": "amatalotar",
    "amatalotaríamos": "amatalotar",
    "amatalotaríeis": "amatalotar",
    "amatalotas": "amatalotar",
    "amatalotasse": "amatalotar",
    "amatalotassem": "amatalotar",
    "amatalotasses": "amatalotar",
    "amatalotaste": "amatalotar",
    "amatalotastes": "amatalotar",
    "amatalotava": "amatalotar",
    "amatalotavam": "amatalotar",
    "amatalotavas": "amatalotar",
    "amatalote": "amatalotar",
    "amatalotei": "amatalotar",
    "amataloteis": "amatalotar",
    "amatalotem": "amatalotar",
    "amatalotemo": "amatalotar",
    "amatalotemos": "amatalotar",
    "amatalotes": "amatalotar",
    "amataloto": "amatalotar",
    "amatalotou": "amatalotar",
    "amatalotá": "amatalotar",
    "amatalotámo": "amatalotar",
    "amatalotámos": "amatalotar",
    "amatalotáramo": "amatalotar",
    "amatalotáramos": "amatalotar",
    "amatalotárei": "amatalotar",
    "amatalotáreis": "amatalotar",
    "amatalotásseis": "amatalotar",
    "amatalotássemos": "amatalotar",
    "amatalotávamo": "amatalotar",
    "amatalotávamos": "amatalotar",
    "amatalotávei": "amatalotar",
    "amatalotáveis": "amatalotar",
    "amatalou": "amatalar",
    "amatalá": "amatalar",
    "amatalámo": "amatalar",
    "amatalámos": "amatalar",
    "amataláramo": "amatalar",
    "amataláramos": "amatalar",
    "amatalárei": "amatalar",
    "amataláreis": "amatalar",
    "amatalásseis": "amatalar",
    "amatalássemos": "amatalar",
    "amatalávamo": "amatalar",
    "amatalávamos": "amatalar",
    "amatalávei": "amatalar",
    "amataláveis": "amatalar",
    "amatilha": "amatilhar",
    "amatilhada": "amatilhar",
    "amatilhadas": "amatilhar",
    "amatilhado": "amatilhar",
    "amatilhados": "amatilhar",
    "amatilhai": "amatilhar",
    "amatilhais": "amatilhar",
    "amatilham": "amatilhar",
    "amatilhamo": "amatilhar",
    "amatilhamos": "amatilhar",
    "amatilhando": "amatilhar",
    "amatilhara": "amatilhar",
    "amatilharam": "amatilhar",
    "amatilharas": "amatilhar",
    "amatilharde": "amatilhar",
    "amatilhardes": "amatilhar",
    "amatilhare": "amatilhar",
    "amatilharei": "amatilhar",
    "amatilhareis": "amatilhar",
    "amatilharem": "amatilhar",
    "amatilharemos": "amatilhar",
    "amatilhares": "amatilhar",
    "amatilharia": "amatilhar",
    "amatilhariam": "amatilhar",
    "amatilharias": "amatilhar",
    "amatilharmo": "amatilhar",
    "amatilharmos": "amatilhar",
    "amatilhará": "amatilhar",
    "amatilharás": "amatilhar",
    "amatilharão": "amatilhar",
    "amatilharíamos": "amatilhar",
    "amatilharíeis": "amatilhar",
    "amatilhas": "amatilhar",
    "amatilhasse": "amatilhar",
    "amatilhassem": "amatilhar",
    "amatilhasses": "amatilhar",
    "amatilhaste": "amatilhar",
    "amatilhastes": "amatilhar",
    "amatilhava": "amatilhar",
    "amatilhavam": "amatilhar",
    "amatilhavas": "amatilhar",
    "amatilhe": "amatilhar",
    "amatilhei": "amatilhar",
    "amatilheis": "amatilhar",
    "amatilhem": "amatilhar",
    "amatilhemo": "amatilhar",
    "amatilhemos": "amatilhar",
    "amatilhes": "amatilhar",
    "amatilho": "amatilhar",
    "amatilhou": "amatilhar",
    "amatilhá": "amatilhar",
    "amatilhámo": "amatilhar",
    "amatilhámos": "amatilhar",
    "amatilháramo": "amatilhar",
    "amatilháramos": "amatilhar",
    "amatilhárei": "amatilhar",
    "amatilháreis": "amatilhar",
    "amatilhásseis": "amatilhar",
    "amatilhássemos": "amatilhar",
    "amatilhávamo": "amatilhar",
    "amatilhávamos": "amatilhar",
    "amatilhávei": "amatilhar",
    "amatilháveis": "amatilhar",
    "amativa": "amativo",
    "amativas": "amativo",
    "amatividades": "amatividade",
    "amativos": "amativo",
    "amatula": "amatular",
    "amatulada": "amatular",
    "amatuladas": "amatular",
    "amatulado": "amatular",
    "amatulados": "amatular",
    "amatulai": "amatular",
    "amatulais": "amatular",
    "amatulam": "amatular",
    "amatulamo": "amatular",
    "amatulamos": "amatular",
    "amatulando": "amatular",
    "amatulara": "amatular",
    "amatularam": "amatular",
    "amatularas": "amatular",
    "amatularde": "amatular",
    "amatulardes": "amatular",
    "amatulare": "amatular",
    "amatularei": "amatular",
    "amatulareis": "amatular",
    "amatularem": "amatular",
    "amatularemos": "amatular",
    "amatulares": "amatular",
    "amatularia": "amatular",
    "amatulariam": "amatular",
    "amatularias": "amatular",
    "amatularmo": "amatular",
    "amatularmos": "amatular",
    "amatulará": "amatular",
    "amatularás": "amatular",
    "amatularão": "amatular",
    "amatularíamos": "amatular",
    "amatularíeis": "amatular",
    "amatulas": "amatular",
    "amatulasse": "amatular",
    "amatulassem": "amatular",
    "amatulasses": "amatular",
    "amatulaste": "amatular",
    "amatulastes": "amatular",
    "amatulava": "amatular",
    "amatulavam": "amatular",
    "amatulavas": "amatular",
    "amatule": "amatular",
    "amatulei": "amatular",
    "amatuleis": "amatular",
    "amatulem": "amatular",
    "amatulemo": "amatular",
    "amatulemos": "amatular",
    "amatules": "amatular",
    "amatulo": "amatular",
    "amatulou": "amatular",
    "amatulá": "amatular",
    "amatulámo": "amatular",
    "amatulámos": "amatular",
    "amatuláramo": "amatular",
    "amatuláramos": "amatular",
    "amatulárei": "amatular",
    "amatuláreis": "amatular",
    "amatulásseis": "amatular",
    "amatulássemos": "amatular",
    "amatulávamo": "amatular",
    "amatulávamos": "amatular",
    "amatulávei": "amatular",
    "amatuláveis": "amatular",
    "amatuta": "amatutar",
    "amatutada": "amatutar",
    "amatutadas": "amatutar",
    "amatutado": "amatutar",
    "amatutados": "amatutar",
    "amatutai": "amatutar",
    "amatutais": "amatutar",
    "amatutam": "amatutar",
    "amatutamo": "amatutar",
    "amatutamos": "amatutar",
    "amatutando": "amatutar",
    "amatutara": "amatutar",
    "amatutaram": "amatutar",
    "amatutaras": "amatutar",
    "amatutarde": "amatutar",
    "amatutardes": "amatutar",
    "amatutare": "amatutar",
    "amatutarei": "amatutar",
    "amatutareis": "amatutar",
    "amatutarem": "amatutar",
    "amatutaremos": "amatutar",
    "amatutares": "amatutar",
    "amatutaria": "amatutar",
    "amatutariam": "amatutar",
    "amatutarias": "amatutar",
    "amatutarmo": "amatutar",
    "amatutarmos": "amatutar",
    "amatutará": "amatutar",
    "amatutarás": "amatutar",
    "amatutarão": "amatutar",
    "amatutaríamos": "amatutar",
    "amatutaríeis": "amatutar",
    "amatutas": "amatutar",
    "amatutasse": "amatutar",
    "amatutassem": "amatutar",
    "amatutasses": "amatutar",
    "amatutaste": "amatutar",
    "amatutastes": "amatutar",
    "amatutava": "amatutar",
    "amatutavam": "amatutar",
    "amatutavas": "amatutar",
    "amatute": "amatutar",
    "amatutei": "amatutar",
    "amatuteis": "amatutar",
    "amatutem": "amatutar",
    "amatutemo": "amatutar",
    "amatutemos": "amatutar",
    "amatutes": "amatutar",
    "amatuto": "amatutar",
    "amatutou": "amatutar",
    "amatutá": "amatutar",
    "amatutámo": "amatutar",
    "amatutámos": "amatutar",
    "amatutáramo": "amatutar",
    "amatutáramos": "amatutar",
    "amatutárei": "amatutar",
    "amatutáreis": "amatutar",
    "amatutásseis": "amatutar",
    "amatutássemos": "amatutar",
    "amatutávamo": "amatutar",
    "amatutávamos": "amatutar",
    "amatutávei": "amatutar",
    "amatutáveis": "amatutar",
    "amatória": "amatório",
    "amatórias": "amatório",
    "amatórios": "amatório",
    "amauroses": "amaurose",
    "amaurótica": "amaurótico",
    "amauróticas": "amaurótico",
    "amauróticos": "amaurótico",
    "amava": "amar",
    "amavam": "amar",
    "amavas": "amar",
    "amaveizinhas": "amável",
    "amaveizinhos": "amável",
    "amaveizitas": "amável",
    "amaveizitos": "amável",
    "amavelzinha": "amável",
    "amavelzinho": "amável",
    "amavelzita": "amável",
    "amavelzito": "amável",
    "amavios": "amavio",
    "amaviosa": "amavioso",
    "amaviosas": "amavioso",
    "amaviosos": "amavioso",
    "amaviosíssima": "amavioso",
    "amaviosíssimas": "amavioso",
    "amaviosíssimo": "amavioso",
    "amaviosíssimos": "amavioso",
    "amaxofobias": "amaxofobia",
    "amaxófoba": "amaxófobo",
    "amaxófobas": "amaxófobo",
    "amaxófobos": "amaxófobo",
    "amazela": "amazelar",
    "amazelada": "amazelar",
    "amazeladas": "amazelar",
    "amazelado": "amazelar",
    "amazelados": "amazelar",
    "amazelai": "amazelar",
    "amazelais": "amazelar",
    "amazelam": "amazelar",
    "amazelamo": "amazelar",
    "amazelamos": "amazelar",
    "amazelando": "amazelar",
    "amazelara": "amazelar",
    "amazelaram": "amazelar",
    "amazelaras": "amazelar",
    "amazelarde": "amazelar",
    "amazelardes": "amazelar",
    "amazelare": "amazelar",
    "amazelarei": "amazelar",
    "amazelareis": "amazelar",
    "amazelarem": "amazelar",
    "amazelaremos": "amazelar",
    "amazelares": "amazelar",
    "amazelaria": "amazelar",
    "amazelariam": "amazelar",
    "amazelarias": "amazelar",
    "amazelarmo": "amazelar",
    "amazelarmos": "amazelar",
    "amazelará": "amazelar",
    "amazelarás": "amazelar",
    "amazelarão": "amazelar",
    "amazelaríamos": "amazelar",
    "amazelaríeis": "amazelar",
    "amazelas": "amazelar",
    "amazelasse": "amazelar",
    "amazelassem": "amazelar",
    "amazelasses": "amazelar",
    "amazelaste": "amazelar",
    "amazelastes": "amazelar",
    "amazelava": "amazelar",
    "amazelavam": "amazelar",
    "amazelavas": "amazelar",
    "amazele": "amazelar",
    "amazelei": "amazelar",
    "amazeleis": "amazelar",
    "amazelem": "amazelar",
    "amazelemo": "amazelar",
    "amazelemos": "amazelar",
    "amazeles": "amazelar",
    "amazelo": "amazelar",
    "amazelou": "amazelar",
    "amazelá": "amazelar",
    "amazelámo": "amazelar",
    "amazelámos": "amazelar",
    "amazeláramo": "amazelar",
    "amazeláramos": "amazelar",
    "amazelárei": "amazelar",
    "amazeláreis": "amazelar",
    "amazelásseis": "amazelar",
    "amazelássemos": "amazelar",
    "amazelávamo": "amazelar",
    "amazelávamos": "amazelar",
    "amazelávei": "amazelar",
    "amazeláveis": "amazelar",
    "amazias": "amazia",
    "amazonas": "amazona",
    "amazonenses": "amazonense",
    "amazonites": "amazonite",
    "amazorrada": "amazorrado",
    "amazorradas": "amazorrado",
    "amazorrados": "amazorrado",
    "amazónia": "amazónio",
    "amazónias": "amazónio",
    "amazónica": "amazónico",
    "amazónicas": "amazónico",
    "amazónicos": "amazónico",
    "amazónidas": "amazónida",
    "amazónios": "amazónio",
    "amaça": "amaçar",
    "amaçada": "amaçar",
    "amaçadas": "amaçar",
    "amaçado": "amaçar",
    "amaçadora": "amaçador",
    "amaçadoras": "amaçador",
    "amaçadores": "amaçador",
    "amaçados": "amaçar",
    "amaçai": "amaçar",
    "amaçais": "amaçar",
    "amaçam": "amaçar",
    "amaçamo": "amaçar",
    "amaçamos": "amaçar",
    "amaçando": "amaçar",
    "amaçara": "amaçar",
    "amaçaram": "amaçar",
    "amaçaras": "amaçar",
    "amaçarde": "amaçar",
    "amaçardes": "amaçar",
    "amaçare": "amaçar",
    "amaçarei": "amaçar",
    "amaçareis": "amaçar",
    "amaçarem": "amaçar",
    "amaçaremos": "amaçar",
    "amaçares": "amaçar",
    "amaçaria": "amaçar",
    "amaçariam": "amaçar",
    "amaçarias": "amaçar",
    "amaçarmo": "amaçar",
    "amaçarmos": "amaçar",
    "amaçaroca": "arocar",
    "amaçarocada": "amaçarocar",
    "amaçarocadas": "amaçarocar",
    "amaçarocado": "amaçarocar",
    "amaçarocados": "amaçarocar",
    "amaçarocai": "amaçarocar",
    "amaçarocais": "amaçarocar",
    "amaçarocam": "amaçarocar",
    "amaçarocamo": "amaçarocar",
    "amaçarocamos": "amaçarocar",
    "amaçarocando": "amaçarocar",
    "amaçarocar": "arocar",
    "amaçarocara": "arocar",
    "amaçarocaram": "arocar",
    "amaçarocaras": "amaçarocar",
    "amaçarocarde": "amaçarocar",
    "amaçarocardes": "amaçarocar",
    "amaçarocare": "amaçarocar",
    "amaçarocarei": "amaçarocar",
    "amaçarocareis": "amaçarocar",
    "amaçarocarem": "arocar",
    "amaçarocaremos": "amaçarocar",
    "amaçarocares": "amaçarocar",
    "amaçarocaria": "arocar",
    "amaçarocariam": "amaçarocar",
    "amaçarocarias": "amaçarocar",
    "amaçarocarmo": "amaçarocar",
    "amaçarocarmos": "amaçarocar",
    "amaçarocará": "amaçarocar",
    "amaçarocarás": "amaçarocar",
    "amaçarocarão": "amaçarocar",
    "amaçarocaríamos": "amaçarocar",
    "amaçarocaríeis": "amaçarocar",
    "amaçarocas": "amaçarocar",
    "amaçarocasse": "arocar",
    "amaçarocassem": "amaçarocar",
    "amaçarocasses": "amaçarocar",
    "amaçarocaste": "amaçarocar",
    "amaçarocastes": "amaçarocar",
    "amaçarocava": "arocar",
    "amaçarocavam": "amaçarocar",
    "amaçarocavas": "amaçarocar",
    "amaçaroco": "amaçarocar",
    "amaçarocou": "amaçarocar",
    "amaçarocá": "arocar",
    "amaçarocámo": "amaçarocar",
    "amaçarocámos": "amaçarocar",
    "amaçarocáramo": "amaçarocar",
    "amaçarocáramos": "amaçarocar",
    "amaçarocárei": "amaçarocar",
    "amaçarocáreis": "amaçarocar",
    "amaçarocásseis": "amaçarocar",
    "amaçarocássemos": "amaçarocar",
    "amaçarocávamo": "amaçarocar",
    "amaçarocávamos": "amaçarocar",
    "amaçarocávei": "amaçarocar",
    "amaçarocáveis": "amaçarocar",
    "amaçaroque": "arocar",
    "amaçaroquei": "amaçarocar",
    "amaçaroqueis": "amaçarocar",
    "amaçaroquem": "arocar",
    "amaçaroquemo": "amaçarocar",
    "amaçaroquemos": "amaçarocar",
    "amaçaroques": "amaçarocar",
    "amaçará": "amaçar",
    "amaçarás": "amaçar",
    "amaçarão": "amaçar",
    "amaçaríamos": "amaçar",
    "amaçaríeis": "amaçar",
    "amaças": "amaçar",
    "amaçasse": "amaçar",
    "amaçassem": "amaçar",
    "amaçasses": "amaçar",
    "amaçaste": "amaçar",
    "amaçastes": "amaçar",
    "amaçava": "amaçar",
    "amaçavam": "amaçar",
    "amaçavas": "amaçar",
    "amaço": "amaçar",
    "amaçou": "amaçar",
    "amaçá": "amaçar",
    "amaçámo": "amaçar",
    "amaçámos": "amaçar",
    "amaçáramo": "amaçar",
    "amaçáramos": "amaçar",
    "amaçárei": "amaçar",
    "amaçáreis": "amaçar",
    "amaçásseis": "amaçar",
    "amaçássemos": "amaçar",
    "amaçávamo": "amaçar",
    "amaçávamos": "amaçar",
    "amaçávei": "amaçar",
    "amaçáveis": "amaçar",
    "ambacas": "ambaca",
    "ambagiosa": "ambagioso",
    "ambagiosas": "ambagioso",
    "ambagiosos": "ambagioso",
    "ambalaus": "ambalau",
    "ambaquistas": "ambaquista",
    "ambarada": "ambarado",
    "ambaradas": "ambarado",
    "ambarados": "ambarado",
    "ambarina": "ambarino",
    "ambarinas": "ambarino",
    "ambarinos": "ambarino",
    "ambas": "ambos",
    "ambes": "ambe",
    "ambiciona": "ambicionar",
    "ambicionada": "ambicionar",
    "ambicionadas": "ambicionar",
    "ambicionado": "ambicionar",
    "ambicionados": "ambicionar",
    "ambicionai": "ambicionar",
    "ambicionais": "ambicionar",
    "ambicionam": "ambicionar",
    "ambicionamo": "ambicionar",
    "ambicionamos": "ambicionar",
    "ambicionando": "ambicionar",
    "ambicionara": "ambicionar",
    "ambicionaram": "ambicionar",
    "ambicionaras": "ambicionar",
    "ambicionarde": "ambicionar",
    "ambicionardes": "ambicionar",
    "ambicionare": "ambicionar",
    "ambicionarei": "ambicionar",
    "ambicionareis": "ambicionar",
    "ambicionarem": "ambicionar",
    "ambicionaremos": "ambicionar",
    "ambicionares": "ambicionar",
    "ambicionaria": "ambicionar",
    "ambicionariam": "ambicionar",
    "ambicionarias": "ambicionar",
    "ambicionarmo": "ambicionar",
    "ambicionarmos": "ambicionar",
    "ambicionará": "ambicionar",
    "ambicionarás": "ambicionar",
    "ambicionarão": "ambicionar",
    "ambicionaríamos": "ambicionar",
    "ambicionaríeis": "ambicionar",
    "ambicionas": "ambicionar",
    "ambicionasse": "ambicionar",
    "ambicionassem": "ambicionar",
    "ambicionasses": "ambicionar",
    "ambicionaste": "ambicionar",
    "ambicionastes": "ambicionar",
    "ambicionava": "ambicionar",
    "ambicionavam": "ambicionar",
    "ambicionavas": "ambicionar",
    "ambicione": "ambicionar",
    "ambicionei": "ambicionar",
    "ambicioneis": "ambicionar",
    "ambicionem": "ambicionar",
    "ambicionemo": "ambicionar",
    "ambicionemos": "ambicionar",
    "ambiciones": "ambicionar",
    "ambiciono": "ambicionar",
    "ambicionou": "ambicionar",
    "ambicioná": "ambicionar",
    "ambicionámo": "ambicionar",
    "ambicionámos": "ambicionar",
    "ambicionáramo": "ambicionar",
    "ambicionáramos": "ambicionar",
    "ambicionárei": "ambicionar",
    "ambicionáreis": "ambicionar",
    "ambicionásseis": "ambicionar",
    "ambicionássemos": "ambicionar",
    "ambicionávamo": "ambicionar",
    "ambicionávamos": "ambicionar",
    "ambicionávei": "ambicionar",
    "ambicionáveis": "ambicionável",
    "ambiciosa": "ambicioso",
    "ambiciosas": "ambicioso",
    "ambiciosos": "ambicioso",
    "ambiciúnculas": "ambiciúncula",
    "ambidestra": "ambidestro",
    "ambidestras": "ambidestro",
    "ambidestrina": "ambidestrino",
    "ambidestrinas": "ambidestrino",
    "ambidestrinos": "ambidestrino",
    "ambidestrismos": "ambidestrismo",
    "ambidestros": "ambidestro",
    "ambidextra": "ambidextro",
    "ambidextras": "ambidextro",
    "ambidextrias": "ambidextria",
    "ambidextrismos": "ambidextrismo",
    "ambidextros": "ambidextro",
    "ambienta": "ambientar",
    "ambientada": "ambientar",
    "ambientadas": "ambientar",
    "ambientado": "ambientar",
    "ambientados": "ambientar",
    "ambientai": "ambientar",
    "ambientais": "ambientar",
    "ambientalistas": "ambientalista",
    "ambientam": "ambientar",
    "ambientamo": "ambientar",
    "ambientamos": "ambientar",
    "ambientando": "ambientar",
    "ambientara": "ambientar",
    "ambientaram": "ambientar",
    "ambientaras": "ambientar",
    "ambientarde": "ambientar",
    "ambientardes": "ambientar",
    "ambientare": "ambientar",
    "ambientarei": "ambientar",
    "ambientareis": "ambientar",
    "ambientarem": "ambientar",
    "ambientaremos": "ambientar",
    "ambientares": "ambientar",
    "ambientaria": "ambientar",
    "ambientariam": "ambientar",
    "ambientarias": "ambientar",
    "ambientarmo": "ambientar",
    "ambientarmos": "ambientar",
    "ambientará": "ambientar",
    "ambientarás": "ambientar",
    "ambientarão": "ambientar",
    "ambientaríamos": "ambientar",
    "ambientaríeis": "ambientar",
    "ambientas": "ambientar",
    "ambientasse": "ambientar",
    "ambientassem": "ambientar",
    "ambientasses": "ambientar",
    "ambientaste": "ambientar",
    "ambientastes": "ambientar",
    "ambientava": "ambientar",
    "ambientavam": "ambientar",
    "ambientavas": "ambientar",
    "ambientações": "ambientação",
    "ambiente": "ambientar",
    "ambientees": "ambiente",
    "ambientei": "ambientar",
    "ambienteis": "ambientar",
    "ambientem": "ambientar",
    "ambientemo": "ambientar",
    "ambientemos": "ambientar",
    "ambientes": "ambientar",
    "ambiento": "ambientar",
    "ambientou": "ambientar",
    "ambientá": "ambientar",
    "ambientámo": "ambientar",
    "ambientámos": "ambientar",
    "ambientáramo": "ambientar",
    "ambientáramos": "ambientar",
    "ambientárei": "ambientar",
    "ambientáreis": "ambientar",
    "ambientásseis": "ambientar",
    "ambientássemos": "ambientar",
    "ambientávamo": "ambientar",
    "ambientávamos": "ambientar",
    "ambientávei": "ambientar",
    "ambientáveis": "ambientar",
    "ambiesquerda": "ambiesquerdo",
    "ambiesquerdas": "ambiesquerdo",
    "ambiesquerdos": "ambiesquerdo",
    "ambigenias": "ambigenia",
    "ambiguidades": "ambiguidade",
    "ambiguíssima": "ambíguo",
    "ambiguíssimas": "ambíguo",
    "ambiguíssimo": "ambíguo",
    "ambiguíssimos": "ambíguo",
    "ambilas": "ambila",
    "ambiopias": "ambiopia",
    "ambisséxua": "ambisséxuo",
    "ambisséxuas": "ambisséxuo",
    "ambisséxuos": "ambisséxuo",
    "ambivalentes": "ambivalente",
    "ambivalências": "ambivalência",
    "ambiversões": "ambiversão",
    "ambições": "ambição",
    "ambiências": "ambiência",
    "ambligonites": "ambligonite",
    "ambliopes": "ambliope",
    "ambliopias": "ambliopia",
    "amblígonos": "amblígono",
    "amborés": "amboré",
    "ambotraços": "ambotraço",
    "ambra": "ambrar",
    "ambrada": "ambrar",
    "ambradas": "ambrar",
    "ambrado": "ambrar",
    "ambrados": "ambrar",
    "ambrai": "ambrar",
    "ambrais": "ambrar",
    "ambram": "ambrar",
    "ambramo": "ambrar",
    "ambramos": "ambrar",
    "ambrando": "ambrar",
    "ambrara": "ambrar",
    "ambraram": "ambrar",
    "ambraras": "ambrar",
    "ambrarde": "ambrar",
    "ambrardes": "ambrar",
    "ambrare": "ambrar",
    "ambrarei": "ambrar",
    "ambrareis": "ambrar",
    "ambrarem": "ambrar",
    "ambraremos": "ambrar",
    "ambrares": "ambrar",
    "ambraria": "ambrar",
    "ambrariam": "ambrar",
    "ambrarias": "ambrar",
    "ambrarmo": "ambrar",
    "ambrarmos": "ambrar",
    "ambrará": "ambrar",
    "ambrarás": "ambrar",
    "ambrarão": "ambrar",
    "ambraríamos": "ambrar",
    "ambraríeis": "ambrar",
    "ambras": "ambrar",
    "ambrasse": "ambrar",
    "ambrassem": "ambrar",
    "ambrasses": "ambrar",
    "ambraste": "ambrar",
    "ambrastes": "ambrar",
    "ambrava": "ambrar",
    "ambravam": "ambrar",
    "ambravas": "ambrar",
    "ambre": "ambrar",
    "ambreada": "ambrear",
    "ambreadas": "ambrear",
    "ambreado": "ambrear",
    "ambreados": "ambrear",
    "ambreai": "ambrear",
    "ambreais": "ambrear",
    "ambreamo": "ambrear",
    "ambreamos": "ambrear",
    "ambreando": "ambrear",
    "ambreara": "ambrear",
    "ambrearam": "ambrear",
    "ambrearas": "ambrear",
    "ambrearde": "ambrear",
    "ambreardes": "ambrear",
    "ambreare": "ambrear",
    "ambrearei": "ambrear",
    "ambreareis": "ambrear",
    "ambrearem": "ambrear",
    "ambrearemos": "ambrear",
    "ambreares": "ambrear",
    "ambrearia": "ambrear",
    "ambreariam": "ambrear",
    "ambrearias": "ambrear",
    "ambrearmo": "ambrear",
    "ambrearmos": "ambrear",
    "ambreará": "ambrear",
    "ambrearás": "ambrear",
    "ambrearão": "ambrear",
    "ambrearíamos": "ambrear",
    "ambrearíeis": "ambrear",
    "ambreasse": "ambrear",
    "ambreassem": "ambrear",
    "ambreasses": "ambrear",
    "ambreaste": "ambrear",
    "ambreastes": "ambrear",
    "ambreava": "ambrear",
    "ambreavam": "ambrear",
    "ambreavas": "ambrear",
    "ambreei": "ambrear",
    "ambreeis": "ambrear",
    "ambreemo": "ambrear",
    "ambreemos": "ambrear",
    "ambrei": "ambrar",
    "ambreia": "ambrear",
    "ambreiam": "ambrear",
    "ambreias": "ambrear",
    "ambreie": "ambrear",
    "ambreiem": "ambrear",
    "ambreies": "ambrear",
    "ambreio": "ambrear",
    "ambreis": "ambrar",
    "ambrem": "ambrar",
    "ambremo": "ambrar",
    "ambremos": "ambrar",
    "ambreou": "ambrear",
    "ambres": "ambrar",
    "ambretas": "ambreta",
    "ambreá": "ambrear",
    "ambreámo": "ambrear",
    "ambreámos": "ambrear",
    "ambreáramo": "ambrear",
    "ambreáramos": "ambrear",
    "ambreárei": "ambrear",
    "ambreáreis": "ambrear",
    "ambreásseis": "ambrear",
    "ambreássemos": "ambrear",
    "ambreávamo": "ambrear",
    "ambreávamos": "ambrear",
    "ambreávei": "ambrear",
    "ambreáveis": "ambrear",
    "ambritas": "ambrita",
    "ambrites": "ambrite",
    "ambro": "ambrar",
    "ambrosiana": "ambrosiano",
    "ambrosianas": "ambrosiano",
    "ambrosianos": "ambrosiano",
    "ambrosias": "ambrosia",
    "ambrosina": "ambrosino",
    "ambrosinas": "ambrosino",
    "ambrosinos": "ambrosino",
    "ambrosiácea": "ambrosiáceo",
    "ambrosiáceas": "ambrosiáceo",
    "ambrosiáceos": "ambrosiáceo",
    "ambrosíaca": "ambrosíaco",
    "ambrosíacas": "ambrosíaco",
    "ambrosíacos": "ambrosíaco",
    "ambrosínea": "ambrosíneo",
    "ambrosíneas": "ambrosíneo",
    "ambrosíneos": "ambrosíneo",
    "ambrou": "ambrar",
    "ambrozós": "ambrozó",
    "ambroínas": "ambroína",
    "ambrá": "ambrar",
    "ambrámo": "ambrar",
    "ambrámos": "ambrar",
    "ambráramo": "ambrar",
    "ambráramos": "ambrar",
    "ambrárei": "ambrar",
    "ambráreis": "ambrar",
    "ambrásseis": "ambrar",
    "ambrássemos": "ambrar",
    "ambrávamo": "ambrar",
    "ambrávamos": "ambrar",
    "ambrávei": "ambrar",
    "ambráveis": "ambrar",
    "ambrósia": "ambrósio",
    "ambrósias": "ambrósio",
    "ambrósios": "ambrósio",
    "ambula": "ambular",
    "ambulacros": "ambulacro",
    "ambulacrários": "ambulacrário",
    "ambulada": "ambular",
    "ambuladas": "ambular",
    "ambulado": "ambular",
    "ambulados": "ambular",
    "ambulai": "ambular",
    "ambulais": "ambular",
    "ambulam": "ambular",
    "ambulamo": "ambular",
    "ambulamos": "ambular",
    "ambulando": "ambular",
    "ambulantes": "ambulante",
    "ambulara": "ambular",
    "ambularam": "ambular",
    "ambularas": "ambular",
    "ambulardes": "ambular",
    "ambularei": "ambular",
    "ambulareis": "ambular",
    "ambularem": "ambular",
    "ambularemos": "ambular",
    "ambulares": "ambular",
    "ambularia": "ambular",
    "ambulariam": "ambular",
    "ambularias": "ambular",
    "ambularmo": "ambular",
    "ambularmos": "ambular",
    "ambulará": "ambular",
    "ambularás": "ambular",
    "ambularão": "ambular",
    "ambularíamos": "ambular",
    "ambularíeis": "ambular",
    "ambulas": "ambular",
    "ambulasse": "ambular",
    "ambulassem": "ambular",
    "ambulasses": "ambular",
    "ambulaste": "ambular",
    "ambulastes": "ambular",
    "ambulativa": "ambulativo",
    "ambulativas": "ambulativo",
    "ambulativos": "ambulativo",
    "ambulatrizes": "ambulatriz",
    "ambulatória": "ambulatório",
    "ambulatórias": "ambulatório",
    "ambulatórios": "ambulatório",
    "ambulava": "ambular",
    "ambulavam": "ambular",
    "ambulavas": "ambular",
    "ambulações": "ambulação",
    "ambule": "ambular",
    "ambulei": "ambular",
    "ambuleis": "ambular",
    "ambulem": "ambular",
    "ambulemo": "ambular",
    "ambulemos": "ambular",
    "ambules": "ambular",
    "ambulo": "ambular",
    "ambulou": "ambular",
    "ambulámo": "ambular",
    "ambulámos": "ambular",
    "ambuláramo": "ambular",
    "ambuláramos": "ambular",
    "ambuláreis": "ambular",
    "ambulásseis": "ambular",
    "ambulássemos": "ambular",
    "ambulávamo": "ambular",
    "ambulávamos": "ambular",
    "ambuláveis": "ambular",
    "ambulâncias": "ambulância",
    "ambulípedes": "ambulípede",
    "amburiais": "amburial",
    "ambustões": "ambustão",
    "ambárica": "ambárico",
    "ambáricas": "ambárico",
    "ambáricos": "ambárico",
    "ambígena": "ambígeno",
    "ambígenas": "ambígeno",
    "ambígenos": "ambígeno",
    "ambígua": "ambíguo",
    "ambíguas": "ambíguo",
    "ambíguos": "ambíguo",
    "ambíopes": "ambíope",
    "ambípara": "ambíparo",
    "ambíparas": "ambíparo",
    "ambíparos": "ambíparo",
    "ambívia": "ambívio",
    "ambívias": "ambívio",
    "ambívios": "ambívio",
    "ambós": "ambó",
    "ambões": "ambão",
    "ame": "amar",
    "ameace": "ameaçar",
    "ameacei": "ameaçar",
    "ameaceis": "ameaçar",
    "ameacem": "ameaçar",
    "ameacemo": "ameaçar",
    "ameacemos": "ameaçar",
    "ameaces": "ameaçar",
    "ameada": "amear",
    "ameadas": "amear",
    "ameado": "amear",
    "ameados": "amear",
    "ameai": "amear",
    "ameais": "amear",
    "amealha": "amealhar",
    "amealhada": "amealhar",
    "amealhadas": "amealhar",
    "amealhado": "amealhar",
    "amealhadora": "amealhador",
    "amealhadoras": "amealhador",
    "amealhadores": "amealhador",
    "amealhados": "amealhar",
    "amealhai": "amealhar",
    "amealhais": "amealhar",
    "amealham": "amealhar",
    "amealhamo": "amealhar",
    "amealhamos": "amealhar",
    "amealhando": "amealhar",
    "amealhara": "amealhar",
    "amealharam": "amealhar",
    "amealharas": "amealhar",
    "amealharde": "amealhar",
    "amealhardes": "amealhar",
    "amealhare": "amealhar",
    "amealharei": "amealhar",
    "amealhareis": "amealhar",
    "amealharem": "amealhar",
    "amealharemos": "amealhar",
    "amealhares": "amealhar",
    "amealharia": "amealhar",
    "amealhariam": "amealhar",
    "amealharias": "amealhar",
    "amealharmo": "amealhar",
    "amealharmos": "amealhar",
    "amealhará": "amealhar",
    "amealharás": "amealhar",
    "amealharão": "amealhar",
    "amealharíamos": "amealhar",
    "amealharíeis": "amealhar",
    "amealhas": "amealhar",
    "amealhasse": "amealhar",
    "amealhassem": "amealhar",
    "amealhasses": "amealhar",
    "amealhaste": "amealhar",
    "amealhastes": "amealhar",
    "amealhava": "amealhar",
    "amealhavam": "amealhar",
    "amealhavas": "amealhar",
    "amealhe": "amealhar",
    "amealhei": "amealhar",
    "amealheis": "amealhar",
    "amealhem": "amealhar",
    "amealhemo": "amealhar",
    "amealhemos": "amealhar",
    "amealhes": "amealhar",
    "amealho": "amealhar",
    "amealhou": "amealhar",
    "amealhá": "amealhar",
    "amealhámo": "amealhar",
    "amealhámos": "amealhar",
    "amealháramo": "amealhar",
    "amealháramos": "amealhar",
    "amealhárei": "amealhar",
    "amealháreis": "amealhar",
    "amealhásseis": "amealhar",
    "amealhássemos": "amealhar",
    "amealhávamo": "amealhar",
    "amealhávamos": "amealhar",
    "amealhávei": "amealhar",
    "amealháveis": "amealhar",
    "ameamo": "amear",
    "ameamos": "amear",
    "ameando": "amear",
    "ameara": "amear",
    "amearam": "amear",
    "amearas": "amear",
    "amearde": "amear",
    "ameardes": "amear",
    "ameare": "amear",
    "amearei": "amear",
    "ameareis": "amear",
    "amearem": "amear",
    "amearemos": "amear",
    "ameares": "amear",
    "amearia": "amear",
    "ameariam": "amear",
    "amearias": "amear",
    "amearmo": "amear",
    "amearmos": "amear",
    "ameará": "amear",
    "amearás": "amear",
    "amearão": "amear",
    "amearíamos": "amear",
    "amearíeis": "amear",
    "ameasse": "amear",
    "ameassem": "amear",
    "ameasses": "amear",
    "ameaste": "amear",
    "ameastes": "amear",
    "ameava": "amear",
    "ameavam": "amear",
    "ameavas": "amear",
    "ameaça": "ameaçar",
    "ameaçada": "ameaçar",
    "ameaçadas": "ameaçar",
    "ameaçado": "ameaçar",
    "ameaçadora": "ameaçador",
    "ameaçadoras": "ameaçador",
    "ameaçadores": "ameaçador",
    "ameaçados": "ameaçar",
    "ameaçai": "ameaçar",
    "ameaçais": "ameaçar",
    "ameaçam": "ameaçar",
    "ameaçamo": "ameaçar",
    "ameaçamos": "ameaçar",
    "ameaçando": "ameaçar",
    "ameaçantes": "ameaçante",
    "ameaçara": "ameaçar",
    "ameaçaram": "ameaçar",
    "ameaçaras": "ameaçar",
    "ameaçarde": "ameaçar",
    "ameaçardes": "ameaçar",
    "ameaçare": "ameaçar",
    "ameaçarei": "ameaçar",
    "ameaçareis": "ameaçar",
    "ameaçarem": "ameaçar",
    "ameaçaremos": "ameaçar",
    "ameaçares": "ameaçar",
    "ameaçaria": "ameaçar",
    "ameaçariam": "ameaçar",
    "ameaçarias": "ameaçar",
    "ameaçarmo": "ameaçar",
    "ameaçarmos": "ameaçar",
    "ameaçará": "ameaçar",
    "ameaçarás": "ameaçar",
    "ameaçarão": "ameaçar",
    "ameaçaríamos": "ameaçar",
    "ameaçaríeis": "ameaçar",
    "ameaças": "ameaçar",
    "ameaçasse": "ameaçar",
    "ameaçassem": "ameaçar",
    "ameaçasses": "ameaçar",
    "ameaçaste": "ameaçar",
    "ameaçastes": "ameaçar",
    "ameaçava": "ameaçar",
    "ameaçavam": "ameaçar",
    "ameaçavas": "ameaçar",
    "ameaço": "ameaçar",
    "ameaços": "ameaço",
    "ameaçou": "ameaçar",
    "ameaçá": "ameaçar",
    "ameaçámo": "ameaçar",
    "ameaçámos": "ameaçar",
    "ameaçáramo": "ameaçar",
    "ameaçáramos": "ameaçar",
    "ameaçárei": "ameaçar",
    "ameaçáreis": "ameaçar",
    "ameaçásseis": "ameaçar",
    "ameaçássemos": "ameaçar",
    "ameaçávamo": "ameaçar",
    "ameaçávamos": "ameaçar",
    "ameaçávei": "ameaçar",
    "ameaçáveis": "ameaçar",
    "amebas": "ameba",
    "amebeus": "amebeu",
    "amebiformes": "amebiforme",
    "amebíases": "amebíase",
    "amebóides": "amebóide",
    "amedalha": "amedalhar",
    "amedalhada": "amedalhar",
    "amedalhadas": "amedalhar",
    "amedalhado": "amedalhar",
    "amedalhados": "amedalhar",
    "amedalhai": "amedalhar",
    "amedalhais": "amedalhar",
    "amedalham": "amedalhar",
    "amedalhamo": "amedalhar",
    "amedalhamos": "amedalhar",
    "amedalhando": "amedalhar",
    "amedalhara": "amedalhar",
    "amedalharam": "amedalhar",
    "amedalharas": "amedalhar",
    "amedalharde": "amedalhar",
    "amedalhardes": "amedalhar",
    "amedalhare": "amedalhar",
    "amedalharei": "amedalhar",
    "amedalhareis": "amedalhar",
    "amedalharem": "amedalhar",
    "amedalharemos": "amedalhar",
    "amedalhares": "amedalhar",
    "amedalharia": "amedalhar",
    "amedalhariam": "amedalhar",
    "amedalharias": "amedalhar",
    "amedalharmo": "amedalhar",
    "amedalharmos": "amedalhar",
    "amedalhará": "amedalhar",
    "amedalharás": "amedalhar",
    "amedalharão": "amedalhar",
    "amedalharíamos": "amedalhar",
    "amedalharíeis": "amedalhar",
    "amedalhas": "amedalhar",
    "amedalhasse": "amedalhar",
    "amedalhassem": "amedalhar",
    "amedalhasses": "amedalhar",
    "amedalhaste": "amedalhar",
    "amedalhastes": "amedalhar",
    "amedalhava": "amedalhar",
    "amedalhavam": "amedalhar",
    "amedalhavas": "amedalhar",
    "amedalhe": "amedalhar",
    "amedalhei": "amedalhar",
    "amedalheis": "amedalhar",
    "amedalhem": "amedalhar",
    "amedalhemo": "amedalhar",
    "amedalhemos": "amedalhar",
    "amedalhes": "amedalhar",
    "amedalho": "amedalhar",
    "amedalhou": "amedalhar",
    "amedalhá": "amedalhar",
    "amedalhámo": "amedalhar",
    "amedalhámos": "amedalhar",
    "amedalháramo": "amedalhar",
    "amedalháramos": "amedalhar",
    "amedalhárei": "amedalhar",
    "amedalháreis": "amedalhar",
    "amedalhásseis": "amedalhar",
    "amedalhássemos": "amedalhar",
    "amedalhávamo": "amedalhar",
    "amedalhávamos": "amedalhar",
    "amedalhávei": "amedalhar",
    "amedalháveis": "amedalhar",
    "amedronta": "amedrontar",
    "amedrontada": "amedrontar",
    "amedrontadas": "amedrontar",
    "amedrontado": "amedrontar",
    "amedrontadora": "amedrontador",
    "amedrontadoras": "amedrontador",
    "amedrontadores": "amedrontador",
    "amedrontados": "amedrontar",
    "amedrontadíssima": "amedrontado",
    "amedrontadíssimas": "amedrontado",
    "amedrontadíssimo": "amedrontado",
    "amedrontadíssimos": "amedrontado",
    "amedrontai": "amedrontar",
    "amedrontais": "amedrontar",
    "amedrontam": "amedrontar",
    "amedrontamentos": "amedrontamento",
    "amedrontamo": "amedrontar",
    "amedrontamos": "amedrontar",
    "amedrontando": "amedrontar",
    "amedrontara": "amedrontar",
    "amedrontaram": "amedrontar",
    "amedrontaras": "amedrontar",
    "amedrontarde": "amedrontar",
    "amedrontardes": "amedrontar",
    "amedrontare": "amedrontar",
    "amedrontarei": "amedrontar",
    "amedrontareis": "amedrontar",
    "amedrontarem": "amedrontar",
    "amedrontaremos": "amedrontar",
    "amedrontares": "amedrontar",
    "amedrontaria": "amedrontar",
    "amedrontariam": "amedrontar",
    "amedrontarias": "amedrontar",
    "amedrontarmo": "amedrontar",
    "amedrontarmos": "amedrontar",
    "amedrontará": "amedrontar",
    "amedrontarás": "amedrontar",
    "amedrontarão": "amedrontar",
    "amedrontaríamos": "amedrontar",
    "amedrontaríeis": "amedrontar",
    "amedrontas": "amedrontar",
    "amedrontasse": "amedrontar",
    "amedrontassem": "amedrontar",
    "amedrontasses": "amedrontar",
    "amedrontaste": "amedrontar",
    "amedrontastes": "amedrontar",
    "amedrontava": "amedrontar",
    "amedrontavam": "amedrontar",
    "amedrontavas": "amedrontar",
    "amedronte": "amedrontar",
    "amedrontei": "amedrontar",
    "amedronteis": "amedrontar",
    "amedrontem": "amedrontar",
    "amedrontemo": "amedrontar",
    "amedrontemos": "amedrontar",
    "amedrontes": "amedrontar",
    "amedronto": "amedrontar",
    "amedrontou": "amedrontar",
    "amedrontá": "amedrontar",
    "amedrontámo": "amedrontar",
    "amedrontámos": "amedrontar",
    "amedrontáramo": "amedrontar",
    "amedrontáramos": "amedrontar",
    "amedrontárei": "amedrontar",
    "amedrontáreis": "amedrontar",
    "amedrontásseis": "amedrontar",
    "amedrontássemos": "amedrontar",
    "amedrontávamo": "amedrontar",
    "amedrontávamos": "amedrontar",
    "amedrontávei": "amedrontar",
    "amedrontáveis": "amedrontar",
    "ameei": "amear",
    "ameeis": "amear",
    "ameemo": "amear",
    "ameemos": "amear",
    "amei": "amar",
    "ameia": "ameiar",
    "ameiada": "ameiar",
    "ameiadas": "ameiar",
    "ameiado": "ameiar",
    "ameiados": "ameiar",
    "ameiai": "ameiar",
    "ameiais": "ameiar",
    "ameiam": "ameiar",
    "ameiamo": "ameiar",
    "ameiamos": "ameiar",
    "ameiando": "ameiar",
    "ameiara": "ameiar",
    "ameiaram": "ameiar",
    "ameiaras": "ameiar",
    "ameiarde": "ameiar",
    "ameiardes": "ameiar",
    "ameiare": "ameiar",
    "ameiarei": "ameiar",
    "ameiareis": "ameiar",
    "ameiarem": "ameiar",
    "ameiaremos": "ameiar",
    "ameiares": "ameiar",
    "ameiaria": "ameiar",
    "ameiariam": "ameiar",
    "ameiarias": "ameiar",
    "ameiarmo": "ameiar",
    "ameiarmos": "ameiar",
    "ameiará": "ameiar",
    "ameiarás": "ameiar",
    "ameiarão": "ameiar",
    "ameiaríamos": "ameiar",
    "ameiaríeis": "ameiar",
    "ameias": "ameiar",
    "ameiasse": "ameiar",
    "ameiassem": "ameiar",
    "ameiasses": "ameiar",
    "ameiaste": "ameiar",
    "ameiastes": "ameiar",
    "ameiava": "ameiar",
    "ameiavam": "ameiar",
    "ameiavas": "ameiar",
    "ameie": "ameiar",
    "ameiei": "ameiar",
    "ameieis": "ameiar",
    "ameiem": "ameiar",
    "ameiemo": "ameiar",
    "ameiemos": "ameiar",
    "ameies": "ameiar",
    "ameiga": "ameigar",
    "ameigada": "ameigar",
    "ameigadas": "ameigar",
    "ameigado": "ameigar",
    "ameigadora": "ameigador",
    "ameigadoras": "ameigador",
    "ameigadores": "ameigador",
    "ameigados": "ameigar",
    "ameigai": "ameigar",
    "ameigais": "ameigar",
    "ameigam": "ameigar",
    "ameigamo": "ameigar",
    "ameigamos": "ameigar",
    "ameigando": "ameigar",
    "ameigara": "ameigar",
    "ameigaram": "ameigar",
    "ameigaras": "ameigar",
    "ameigarde": "ameigar",
    "ameigardes": "ameigar",
    "ameigare": "ameigar",
    "ameigarei": "ameigar",
    "ameigareis": "ameigar",
    "ameigarem": "ameigar",
    "ameigaremos": "ameigar",
    "ameigares": "ameigar",
    "ameigaria": "ameigar",
    "ameigariam": "ameigar",
    "ameigarias": "ameigar",
    "ameigarmo": "ameigar",
    "ameigarmos": "ameigar",
    "ameigará": "ameigar",
    "ameigarás": "ameigar",
    "ameigarão": "ameigar",
    "ameigaríamos": "ameigar",
    "ameigaríeis": "ameigar",
    "ameigas": "ameigar",
    "ameigasse": "ameigar",
    "ameigassem": "ameigar",
    "ameigasses": "ameigar",
    "ameigaste": "ameigar",
    "ameigastes": "ameigar",
    "ameigava": "ameigar",
    "ameigavam": "ameigar",
    "ameigavas": "ameigar",
    "ameigo": "ameigar",
    "ameigou": "ameigar",
    "ameigue": "ameigar",
    "ameiguei": "ameigar",
    "ameigueis": "ameigar",
    "ameiguem": "ameigar",
    "ameiguemo": "ameigar",
    "ameiguemos": "ameigar",
    "ameigues": "ameigar",
    "ameigá": "ameigar",
    "ameigámo": "ameigar",
    "ameigámos": "ameigar",
    "ameigáramo": "ameigar",
    "ameigáramos": "ameigar",
    "ameigárei": "ameigar",
    "ameigáreis": "ameigar",
    "ameigásseis": "ameigar",
    "ameigássemos": "ameigar",
    "ameigávamo": "ameigar",
    "ameigávamos": "ameigar",
    "ameigávei": "ameigar",
    "ameigáveis": "ameigar",
    "ameijoa": "ameijoar",
    "ameijoada": "ameijoar",
    "ameijoadas": "ameijoar",
    "ameijoado": "ameijoar",
    "ameijoados": "ameijoar",
    "ameijoai": "ameijoar",
    "ameijoais": "ameijoar",
    "ameijoam": "ameijoar",
    "ameijoamo": "ameijoar",
    "ameijoamos": "ameijoar",
    "ameijoando": "ameijoar",
    "ameijoara": "ameijoar",
    "ameijoaram": "ameijoar",
    "ameijoaras": "ameijoar",
    "ameijoarde": "ameijoar",
    "ameijoardes": "ameijoar",
    "ameijoare": "ameijoar",
    "ameijoarei": "ameijoar",
    "ameijoareis": "ameijoar",
    "ameijoarem": "ameijoar",
    "ameijoaremos": "ameijoar",
    "ameijoares": "ameijoar",
    "ameijoaria": "ameijoar",
    "ameijoariam": "ameijoar",
    "ameijoarias": "ameijoar",
    "ameijoarmo": "ameijoar",
    "ameijoarmos": "ameijoar",
    "ameijoará": "ameijoar",
    "ameijoarás": "ameijoar",
    "ameijoarão": "ameijoar",
    "ameijoaríamos": "ameijoar",
    "ameijoaríeis": "ameijoar",
    "ameijoas": "ameijoar",
    "ameijoasse": "ameijoar",
    "ameijoassem": "ameijoar",
    "ameijoasses": "ameijoar",
    "ameijoaste": "ameijoar",
    "ameijoastes": "ameijoar",
    "ameijoava": "ameijoar",
    "ameijoavam": "ameijoar",
    "ameijoavas": "ameijoar",
    "ameijoe": "ameijoar",
    "ameijoei": "ameijoar",
    "ameijoeiras": "ameijoeira",
    "ameijoeis": "ameijoar",
    "ameijoem": "ameijoar",
    "ameijoemo": "ameijoar",
    "ameijoemos": "ameijoar",
    "ameijoes": "ameijoar",
    "ameijoo": "ameijoar",
    "ameijoou": "ameijoar",
    "ameijoá": "ameijoar",
    "ameijoámo": "ameijoar",
    "ameijoámos": "ameijoar",
    "ameijoáramo": "ameijoar",
    "ameijoáramos": "ameijoar",
    "ameijoárei": "ameijoar",
    "ameijoáreis": "ameijoar",
    "ameijoásseis": "ameijoar",
    "ameijoássemos": "ameijoar",
    "ameijoávamo": "ameijoar",
    "ameijoávamos": "ameijoar",
    "ameijoávei": "ameijoar",
    "ameijoáveis": "ameijoar",
    "ameio": "ameiar",
    "ameiou": "ameiar",
    "ameis": "amar",
    "ameixais": "ameixal",
    "ameixas": "ameixa",
    "ameixeiras": "ameixeira",
    "ameixiais": "ameixial",
    "ameixieiras": "ameixieira",
    "ameixoais": "ameixoal",
    "ameixoeiras": "ameixoeira",
    "ameiá": "ameiar",
    "ameiámo": "ameiar",
    "ameiámos": "ameiar",
    "ameiáramo": "ameiar",
    "ameiáramos": "ameiar",
    "ameiárei": "ameiar",
    "ameiáreis": "ameiar",
    "ameiásseis": "ameiar",
    "ameiássemos": "ameiar",
    "ameiávamo": "ameiar",
    "ameiávamos": "ameiar",
    "ameiávei": "ameiar",
    "ameiáveis": "ameiar",
    "amelace": "amelaçar",
    "amelacei": "amelaçar",
    "amelaceis": "amelaçar",
    "amelacem": "amelaçar",
    "amelacemo": "amelaçar",
    "amelacemos": "amelaçar",
    "amelaces": "amelaçar",
    "amelada": "amelado",
    "ameladas": "amelado",
    "amelados": "amelado",
    "amelaça": "amelaçar",
    "amelaçada": "amelaçar",
    "amelaçadas": "amelaçar",
    "amelaçado": "amelaçar",
    "amelaçados": "amelaçar",
    "amelaçai": "amelaçar",
    "amelaçais": "amelaçar",
    "amelaçam": "amelaçar",
    "amelaçamo": "amelaçar",
    "amelaçamos": "amelaçar",
    "amelaçando": "amelaçar",
    "amelaçara": "amelaçar",
    "amelaçaram": "amelaçar",
    "amelaçaras": "amelaçar",
    "amelaçarde": "amelaçar",
    "amelaçardes": "amelaçar",
    "amelaçare": "amelaçar",
    "amelaçarei": "amelaçar",
    "amelaçareis": "amelaçar",
    "amelaçarem": "amelaçar",
    "amelaçaremos": "amelaçar",
    "amelaçares": "amelaçar",
    "amelaçaria": "amelaçar",
    "amelaçariam": "amelaçar",
    "amelaçarias": "amelaçar",
    "amelaçarmo": "amelaçar",
    "amelaçarmos": "amelaçar",
    "amelaçará": "amelaçar",
    "amelaçarás": "amelaçar",
    "amelaçarão": "amelaçar",
    "amelaçaríamos": "amelaçar",
    "amelaçaríeis": "amelaçar",
    "amelaças": "amelaçar",
    "amelaçasse": "amelaçar",
    "amelaçassem": "amelaçar",
    "amelaçasses": "amelaçar",
    "amelaçaste": "amelaçar",
    "amelaçastes": "amelaçar",
    "amelaçava": "amelaçar",
    "amelaçavam": "amelaçar",
    "amelaçavas": "amelaçar",
    "amelaço": "amelaçar",
    "amelaçou": "amelaçar",
    "amelaçá": "amelaçar",
    "amelaçámo": "amelaçar",
    "amelaçámos": "amelaçar",
    "amelaçáramo": "amelaçar",
    "amelaçáramos": "amelaçar",
    "amelaçárei": "amelaçar",
    "amelaçáreis": "amelaçar",
    "amelaçásseis": "amelaçar",
    "amelaçássemos": "amelaçar",
    "amelaçávamo": "amelaçar",
    "amelaçávamos": "amelaçar",
    "amelaçávei": "amelaçar",
    "amelaçáveis": "amelaçar",
    "ameloada": "ameloado",
    "ameloadas": "ameloado",
    "ameloados": "ameloado",
    "amelopias": "amelopia",
    "amelópica": "amelópico",
    "amelópicas": "amelópico",
    "amelópicos": "amelópico",
    "amem": "amar",
    "amembranados": "amembranado",
    "amemo": "amar",
    "amemos": "amar",
    "amena": "ameno",
    "amenas": "ameno",
    "amendinas": "amendina",
    "amendoada": "amendoado",
    "amendoadas": "amendoado",
    "amendoados": "amendoado",
    "amendoais": "amendoal",
    "amendoeiras": "amendoeira",
    "amendoinha": "amêndoa",
    "amendoinhas": "amêndoa",
    "amendoins": "amendoim",
    "amendoita": "amêndoa",
    "amendoitas": "amêndoa",
    "amendoínas": "amendoína",
    "amenias": "amenia",
    "amenidades": "amenidade",
    "amenina": "ameninar",
    "ameninada": "ameninar",
    "ameninadas": "ameninar",
    "ameninado": "ameninar",
    "ameninados": "ameninar",
    "ameninai": "ameninar",
    "ameninais": "ameninar",
    "ameninam": "ameninar",
    "ameninamo": "ameninar",
    "ameninamos": "ameninar",
    "ameninando": "ameninar",
    "ameninara": "ameninar",
    "ameninaram": "ameninar",
    "ameninaras": "ameninar",
    "ameninarde": "ameninar",
    "ameninardes": "ameninar",
    "ameninare": "ameninar",
    "ameninarei": "ameninar",
    "ameninareis": "ameninar",
    "ameninarem": "ameninar",
    "ameninaremos": "ameninar",
    "ameninares": "ameninar",
    "ameninaria": "ameninar",
    "ameninariam": "ameninar",
    "ameninarias": "ameninar",
    "ameninarmo": "ameninar",
    "ameninarmos": "ameninar",
    "ameninará": "ameninar",
    "ameninarás": "ameninar",
    "ameninarão": "ameninar",
    "ameninaríamos": "ameninar",
    "ameninaríeis": "ameninar",
    "ameninas": "ameninar",
    "ameninasse": "ameninar",
    "ameninassem": "ameninar",
    "ameninasses": "ameninar",
    "ameninaste": "ameninar",
    "ameninastes": "ameninar",
    "ameninava": "ameninar",
    "ameninavam": "ameninar",
    "ameninavas": "ameninar",
    "amenine": "ameninar",
    "ameninei": "ameninar",
    "amenineis": "ameninar",
    "ameninem": "ameninar",
    "ameninemo": "ameninar",
    "ameninemos": "ameninar",
    "amenines": "ameninar",
    "amenino": "ameninar",
    "ameninou": "ameninar",
    "ameniná": "ameninar",
    "ameninámo": "ameninar",
    "ameninámos": "ameninar",
    "amenináramo": "ameninar",
    "amenináramos": "ameninar",
    "ameninárei": "ameninar",
    "amenináreis": "ameninar",
    "ameninásseis": "ameninar",
    "ameninássemos": "ameninar",
    "ameninávamo": "ameninar",
    "ameninávamos": "ameninar",
    "ameninávei": "ameninar",
    "amenináveis": "ameninar",
    "amenistas": "amenista",
    "ameniza": "amenizar",
    "amenizada": "amenizar",
    "amenizadas": "amenizar",
    "amenizado": "amenizar",
    "amenizadora": "amenizador",
    "amenizadoras": "amenizador",
    "amenizadores": "amenizador",
    "amenizados": "amenizar",
    "amenizai": "amenizar",
    "amenizais": "amenizar",
    "amenizam": "amenizar",
    "amenizamo": "amenizar",
    "amenizamos": "amenizar",
    "amenizando": "amenizar",
    "amenizara": "amenizar",
    "amenizaram": "amenizar",
    "amenizaras": "amenizar",
    "amenizarde": "amenizar",
    "amenizardes": "amenizar",
    "amenizare": "amenizar",
    "amenizarei": "amenizar",
    "amenizareis": "amenizar",
    "amenizarem": "amenizar",
    "amenizaremos": "amenizar",
    "amenizares": "amenizar",
    "amenizaria": "amenizar",
    "amenizariam": "amenizar",
    "amenizarias": "amenizar",
    "amenizarmo": "amenizar",
    "amenizarmos": "amenizar",
    "amenizará": "amenizar",
    "amenizarás": "amenizar",
    "amenizarão": "amenizar",
    "amenizaríamos": "amenizar",
    "amenizaríeis": "amenizar",
    "amenizas": "amenizar",
    "amenizasse": "amenizar",
    "amenizassem": "amenizar",
    "amenizasses": "amenizar",
    "amenizaste": "amenizar",
    "amenizastes": "amenizar",
    "amenizava": "amenizar",
    "amenizavam": "amenizar",
    "amenizavas": "amenizar",
    "amenize": "amenizar",
    "amenizei": "amenizar",
    "amenizeis": "amenizar",
    "amenizem": "amenizar",
    "amenizemo": "amenizar",
    "amenizemos": "amenizar",
    "amenizes": "amenizar",
    "amenizo": "amenizar",
    "amenizou": "amenizar",
    "amenizá": "amenizar",
    "amenizámo": "amenizar",
    "amenizámos": "amenizar",
    "amenizáramo": "amenizar",
    "amenizáramos": "amenizar",
    "amenizárei": "amenizar",
    "amenizáreis": "amenizar",
    "amenizásseis": "amenizar",
    "amenizássemos": "amenizar",
    "amenizávamo": "amenizar",
    "amenizávamos": "amenizar",
    "amenizávei": "amenizar",
    "amenizáveis": "amenizar",
    "amenomanias": "amenomania",
    "amenomaníaca": "amenomaníaco",
    "amenomaníacas": "amenomaníaco",
    "amenomaníacos": "amenomaníaco",
    "amenorreias": "amenorreia",
    "amenorreica": "amenorreico",
    "amenorreicas": "amenorreico",
    "amenorreicos": "amenorreico",
    "amenos": "ameno",
    "amens": "amen",
    "amenta": "amentar",
    "amentada": "amentar",
    "amentadas": "amentar",
    "amentado": "amentar",
    "amentadora": "amentador",
    "amentadoras": "amentador",
    "amentadores": "amentador",
    "amentados": "amentar",
    "amentai": "amentar",
    "amentais": "amentar",
    "amentam": "amentar",
    "amentamo": "amentar",
    "amentamos": "amentar",
    "amentando": "amentar",
    "amentara": "amentar",
    "amentaram": "amentar",
    "amentaras": "amentar",
    "amentarde": "amentar",
    "amentardes": "amentar",
    "amentare": "amentar",
    "amentarei": "amentar",
    "amentareis": "amentar",
    "amentarem": "amentar",
    "amentaremos": "amentar",
    "amentares": "amentar",
    "amentaria": "amentar",
    "amentariam": "amentar",
    "amentarias": "amentar",
    "amentarmo": "amentar",
    "amentarmos": "amentar",
    "amentará": "amentar",
    "amentarás": "amentar",
    "amentarão": "amentar",
    "amentaríamos": "amentar",
    "amentaríeis": "amentar",
    "amentas": "amentar",
    "amentasse": "amentar",
    "amentassem": "amentar",
    "amentasses": "amentar",
    "amentaste": "amentar",
    "amentastes": "amentar",
    "amentava": "amentar",
    "amentavam": "amentar",
    "amentavas": "amentar",
    "amente": "amentar",
    "amentei": "amentar",
    "amenteis": "amentar",
    "amentem": "amentar",
    "amentemo": "amentar",
    "amentemos": "amentar",
    "amentes": "amentar",
    "amentiformes": "amentiforme",
    "amentilhos": "amentilho",
    "amento": "amentar",
    "amentos": "amento",
    "amentou": "amentar",
    "amentá": "amentar",
    "amentácea": "amentáceo",
    "amentáceas": "amentáceo",
    "amentáceos": "amentáceo",
    "amentámo": "amentar",
    "amentámos": "amentar",
    "amentáramo": "amentar",
    "amentáramos": "amentar",
    "amentárei": "amentar",
    "amentáreis": "amentar",
    "amentásseis": "amentar",
    "amentássemos": "amentar",
    "amentávamo": "amentar",
    "amentávamos": "amentar",
    "amentávei": "amentar",
    "amentáveis": "amentar",
    "amentífera": "amentífero",
    "amentíferas": "amentífero",
    "amentíferos": "amentífero",
    "ameníssima": "ameno",
    "ameníssimas": "ameno",
    "ameníssimo": "ameno",
    "ameníssimos": "ameno",
    "amenómana": "amenómano",
    "amenómanas": "amenómano",
    "amenómanos": "amenómano",
    "ameou": "amear",
    "amerceada": "amercear",
    "amerceadas": "amercear",
    "amerceado": "amercear",
    "amerceadora": "amerceador",
    "amerceadoras": "amerceador",
    "amerceadores": "amerceador",
    "amerceados": "amercear",
    "amerceai": "amercear",
    "amerceais": "amercear",
    "amerceamentos": "amerceamento",
    "amerceamo": "amercear",
    "amerceamos": "amercear",
    "amerceando": "amercear",
    "amerceara": "amercear",
    "amercearam": "amercear",
    "amercearas": "amercear",
    "amercearde": "amercear",
    "amerceardes": "amercear",
    "amerceare": "amercear",
    "amercearei": "amercear",
    "amerceareis": "amercear",
    "amercearem": "amercear",
    "amercearemos": "amercear",
    "amerceares": "amercear",
    "amercearia": "amercear",
    "amerceariam": "amercear",
    "amercearias": "amercear",
    "amercearmo": "amercear",
    "amercearmos": "amercear",
    "amerceará": "amercear",
    "amercearás": "amercear",
    "amercearão": "amercear",
    "amercearíamos": "amercear",
    "amercearíeis": "amercear",
    "amerceasse": "amercear",
    "amerceassem": "amercear",
    "amerceasses": "amercear",
    "amerceaste": "amercear",
    "amerceastes": "amercear",
    "amerceava": "amercear",
    "amerceavam": "amercear",
    "amerceavas": "amercear",
    "amerceei": "amercear",
    "amerceeis": "amercear",
    "amerceemo": "amercear",
    "amerceemos": "amercear",
    "amerceia": "amercear",
    "amerceiam": "amercear",
    "amerceias": "amercear",
    "amerceie": "amercear",
    "amerceiem": "amercear",
    "amerceies": "amercear",
    "amerceio": "amercear",
    "amerceou": "amercear",
    "amerceá": "amercear",
    "amerceámo": "amercear",
    "amerceámos": "amercear",
    "amerceáramo": "amercear",
    "amerceáramos": "amercear",
    "amerceárei": "amercear",
    "amerceáreis": "amercear",
    "amerceásseis": "amercear",
    "amerceássemos": "amercear",
    "amerceávamo": "amercear",
    "amerceávamos": "amercear",
    "amerceávei": "amercear",
    "amerceáveis": "amercear",
    "americana": "americano",
    "americanadas": "americanada",
    "americanas": "americano",
    "americanices": "americanice",
    "americanidades": "americanidade",
    "americanismos": "americanismo",
    "americanistas": "americanista",
    "americanites": "americanite",
    "americaniza": "americanizar",
    "americanizada": "americanizar",
    "americanizadas": "americanizar",
    "americanizado": "americanizar",
    "americanizados": "americanizar",
    "americanizadíssima": "americanizado",
    "americanizadíssimas": "americanizado",
    "americanizadíssimo": "americanizado",
    "americanizadíssimos": "americanizado",
    "americanizai": "americanizar",
    "americanizais": "americanizar",
    "americanizam": "americanizar",
    "americanizamo": "americanizar",
    "americanizamos": "americanizar",
    "americanizando": "americanizar",
    "americanizara": "americanizar",
    "americanizaram": "americanizar",
    "americanizaras": "americanizar",
    "americanizarde": "americanizar",
    "americanizardes": "americanizar",
    "americanizare": "americanizar",
    "americanizarei": "americanizar",
    "americanizareis": "americanizar",
    "americanizarem": "americanizar",
    "americanizaremos": "americanizar",
    "americanizares": "americanizar",
    "americanizaria": "americanizar",
    "americanizariam": "americanizar",
    "americanizarias": "americanizar",
    "americanizarmo": "americanizar",
    "americanizarmos": "americanizar",
    "americanizará": "americanizar",
    "americanizarás": "americanizar",
    "americanizarão": "americanizar",
    "americanizaríamos": "americanizar",
    "americanizaríeis": "americanizar",
    "americanizas": "americanizar",
    "americanizasse": "americanizar",
    "americanizassem": "americanizar",
    "americanizasses": "americanizar",
    "americanizaste": "americanizar",
    "americanizastes": "americanizar",
    "americanizava": "americanizar",
    "americanizavam": "americanizar",
    "americanizavas": "americanizar",
    "americanizações": "americanização",
    "americanize": "americanizar",
    "americanizei": "americanizar",
    "americanizeis": "americanizar",
    "americanizem": "americanizar",
    "americanizemo": "americanizar",
    "americanizemos": "americanizar",
    "americanizes": "americanizar",
    "americanizo": "americanizar",
    "americanizou": "americanizar",
    "americanizá": "americanizar",
    "americanizámo": "americanizar",
    "americanizámos": "americanizar",
    "americanizáramo": "americanizar",
    "americanizáramos": "americanizar",
    "americanizárei": "americanizar",
    "americanizáreis": "americanizar",
    "americanizásseis": "americanizar",
    "americanizássemos": "americanizar",
    "americanizávamo": "americanizar",
    "americanizávamos": "americanizar",
    "americanizávei": "americanizar",
    "americanizáveis": "americanizável",
    "americanofilias": "americanofilia",
    "americanofobias": "americanofobia",
    "americanos": "americano",
    "americanófila": "americanófilo",
    "americanófilas": "americanófilo",
    "americanófilos": "americanófilo",
    "americanófoba": "americanófobo",
    "americanófobas": "americanófobo",
    "americanófobos": "americanófobo",
    "americomanias": "americomania",
    "amerissa": "amerissar",
    "amerissada": "amerissar",
    "amerissadas": "amerissar",
    "amerissado": "amerissar",
    "amerissados": "amerissar",
    "amerissai": "amerissar",
    "amerissais": "amerissar",
    "amerissam": "amerissar",
    "amerissamo": "amerissar",
    "amerissamos": "amerissar",
    "amerissando": "amerissar",
    "amerissara": "amerissar",
    "amerissaram": "amerissar",
    "amerissaras": "amerissar",
    "amerissarde": "amerissar",
    "amerissardes": "amerissar",
    "amerissare": "amerissar",
    "amerissarei": "amerissar",
    "amerissareis": "amerissar",
    "amerissarem": "amerissar",
    "amerissaremos": "amerissar",
    "amerissares": "amerissar",
    "amerissaria": "amerissar",
    "amerissariam": "amerissar",
    "amerissarias": "amerissar",
    "amerissarmo": "amerissar",
    "amerissarmos": "amerissar",
    "amerissará": "amerissar",
    "amerissarás": "amerissar",
    "amerissarão": "amerissar",
    "amerissaríamos": "amerissar",
    "amerissaríeis": "amerissar",
    "amerissas": "amerissar",
    "amerissasse": "amerissar",
    "amerissassem": "amerissar",
    "amerissasses": "amerissar",
    "amerissaste": "amerissar",
    "amerissastes": "amerissar",
    "amerissava": "amerissar",
    "amerissavam": "amerissar",
    "amerissavas": "amerissar",
    "amerisse": "amerissar",
    "amerissei": "amerissar",
    "amerisseis": "amerissar",
    "amerissem": "amerissar",
    "amerissemo": "amerissar",
    "amerissemos": "amerissar",
    "amerisses": "amerissar",
    "amerisso": "amerissar",
    "amerissou": "amerissar",
    "amerissá": "amerissar",
    "amerissámo": "amerissar",
    "amerissámos": "amerissar",
    "amerissáramo": "amerissar",
    "amerissáramos": "amerissar",
    "amerissárei": "amerissar",
    "amerissáreis": "amerissar",
    "amerissásseis": "amerissar",
    "amerissássemos": "amerissar",
    "amerissávamo": "amerissar",
    "amerissávamos": "amerissar",
    "amerissávei": "amerissar",
    "amerissáveis": "amerissar",
    "ameritas": "amerita",
    "ameruja": "amerujar",
    "amerujada": "amerujar",
    "amerujadas": "amerujar",
    "amerujado": "amerujar",
    "amerujados": "amerujar",
    "amerujai": "amerujar",
    "amerujais": "amerujar",
    "amerujam": "amerujar",
    "amerujamo": "amerujar",
    "amerujamos": "amerujar",
    "amerujando": "amerujar",
    "amerujara": "amerujar",
    "amerujaram": "amerujar",
    "amerujaras": "amerujar",
    "amerujardes": "amerujar",
    "amerujarei": "amerujar",
    "amerujareis": "amerujar",
    "amerujarem": "amerujar",
    "amerujaremos": "amerujar",
    "amerujares": "amerujar",
    "amerujaria": "amerujar",
    "amerujariam": "amerujar",
    "amerujarias": "amerujar",
    "amerujarmo": "amerujar",
    "amerujarmos": "amerujar",
    "amerujará": "amerujar",
    "amerujarás": "amerujar",
    "amerujarão": "amerujar",
    "amerujaríamos": "amerujar",
    "amerujaríeis": "amerujar",
    "amerujas": "amerujar",
    "amerujasse": "amerujar",
    "amerujassem": "amerujar",
    "amerujasses": "amerujar",
    "amerujaste": "amerujar",
    "amerujastes": "amerujar",
    "amerujava": "amerujar",
    "amerujavam": "amerujar",
    "amerujavas": "amerujar",
    "ameruje": "amerujar",
    "amerujei": "amerujar",
    "amerujeis": "amerujar",
    "amerujem": "amerujar",
    "amerujemo": "amerujar",
    "amerujemos": "amerujar",
    "amerujes": "amerujar",
    "amerujo": "amerujar",
    "amerujou": "amerujar",
    "amerujámo": "amerujar",
    "amerujámos": "amerujar",
    "amerujáramo": "amerujar",
    "amerujáramos": "amerujar",
    "amerujáreis": "amerujar",
    "amerujásseis": "amerujar",
    "amerujássemos": "amerujar",
    "amerujávamo": "amerujar",
    "amerujávamos": "amerujar",
    "amerujáveis": "amerujar",
    "amerícios": "amerício",
    "ameríndia": "ameríndio",
    "ameríndias": "ameríndio",
    "ameríndios": "ameríndio",
    "ames": "amar",
    "amesenda": "amesendar",
    "amesendada": "amesendar",
    "amesendadas": "amesendar",
    "amesendado": "amesendar",
    "amesendados": "amesendar",
    "amesendai": "amesendar",
    "amesendais": "amesendar",
    "amesendam": "amesendar",
    "amesendamo": "amesendar",
    "amesendamos": "amesendar",
    "amesendando": "amesendar",
    "amesendara": "amesendar",
    "amesendaram": "amesendar",
    "amesendaras": "amesendar",
    "amesendarde": "amesendar",
    "amesendardes": "amesendar",
    "amesendare": "amesendar",
    "amesendarei": "amesendar",
    "amesendareis": "amesendar",
    "amesendarem": "amesendar",
    "amesendaremos": "amesendar",
    "amesendares": "amesendar",
    "amesendaria": "amesendar",
    "amesendariam": "amesendar",
    "amesendarias": "amesendar",
    "amesendarmo": "amesendar",
    "amesendarmos": "amesendar",
    "amesendará": "amesendar",
    "amesendarás": "amesendar",
    "amesendarão": "amesendar",
    "amesendaríamos": "amesendar",
    "amesendaríeis": "amesendar",
    "amesendas": "amesendar",
    "amesendasse": "amesendar",
    "amesendassem": "amesendar",
    "amesendasses": "amesendar",
    "amesendaste": "amesendar",
    "amesendastes": "amesendar",
    "amesendava": "amesendar",
    "amesendavam": "amesendar",
    "amesendavas": "amesendar",
    "amesende": "amesendar",
    "amesendei": "amesendar",
    "amesendeis": "amesendar",
    "amesendem": "amesendar",
    "amesendemo": "amesendar",
    "amesendemos": "amesendar",
    "amesendes": "amesendar",
    "amesendo": "amesendar",
    "amesendou": "amesendar",
    "amesendá": "amesendar",
    "amesendámo": "amesendar",
    "amesendámos": "amesendar",
    "amesendáramo": "amesendar",
    "amesendáramos": "amesendar",
    "amesendárei": "amesendar",
    "amesendáreis": "amesendar",
    "amesendásseis": "amesendar",
    "amesendássemos": "amesendar",
    "amesendávamo": "amesendar",
    "amesendávamos": "amesendar",
    "amesendávei": "amesendar",
    "amesendáveis": "amesendar",
    "amesquinha": "amesquinhar",
    "amesquinhada": "amesquinhar",
    "amesquinhadas": "amesquinhar",
    "amesquinhado": "amesquinhar",
    "amesquinhadora": "amesquinhador",
    "amesquinhadoras": "amesquinhador",
    "amesquinhadores": "amesquinhador",
    "amesquinhados": "amesquinhar",
    "amesquinhadíssima": "amesquinhado",
    "amesquinhadíssimas": "amesquinhado",
    "amesquinhadíssimo": "amesquinhado",
    "amesquinhadíssimos": "amesquinhado",
    "amesquinhai": "amesquinhar",
    "amesquinhais": "amesquinhar",
    "amesquinham": "amesquinhar",
    "amesquinhamentos": "amesquinhamento",
    "amesquinhamo": "amesquinhar",
    "amesquinhamos": "amesquinhar",
    "amesquinhando": "amesquinhar",
    "amesquinhara": "amesquinhar",
    "amesquinharam": "amesquinhar",
    "amesquinharas": "amesquinhar",
    "amesquinharde": "amesquinhar",
    "amesquinhardes": "amesquinhar",
    "amesquinhare": "amesquinhar",
    "amesquinharei": "amesquinhar",
    "amesquinhareis": "amesquinhar",
    "amesquinharem": "amesquinhar",
    "amesquinharemos": "amesquinhar",
    "amesquinhares": "amesquinhar",
    "amesquinharia": "amesquinhar",
    "amesquinhariam": "amesquinhar",
    "amesquinharias": "amesquinhar",
    "amesquinharmo": "amesquinhar",
    "amesquinharmos": "amesquinhar",
    "amesquinhará": "amesquinhar",
    "amesquinharás": "amesquinhar",
    "amesquinharão": "amesquinhar",
    "amesquinharíamos": "amesquinhar",
    "amesquinharíeis": "amesquinhar",
    "amesquinhas": "amesquinhar",
    "amesquinhasse": "amesquinhar",
    "amesquinhassem": "amesquinhar",
    "amesquinhasses": "amesquinhar",
    "amesquinhaste": "amesquinhar",
    "amesquinhastes": "amesquinhar",
    "amesquinhava": "amesquinhar",
    "amesquinhavam": "amesquinhar",
    "amesquinhavas": "amesquinhar",
    "amesquinhe": "amesquinhar",
    "amesquinhei": "amesquinhar",
    "amesquinheis": "amesquinhar",
    "amesquinhem": "amesquinhar",
    "amesquinhemo": "amesquinhar",
    "amesquinhemos": "amesquinhar",
    "amesquinhes": "amesquinhar",
    "amesquinho": "amesquinhar",
    "amesquinhou": "amesquinhar",
    "amesquinhá": "amesquinhar",
    "amesquinhámo": "amesquinhar",
    "amesquinhámos": "amesquinhar",
    "amesquinháramo": "amesquinhar",
    "amesquinháramos": "amesquinhar",
    "amesquinhárei": "amesquinhar",
    "amesquinháreis": "amesquinhar",
    "amesquinhásseis": "amesquinhar",
    "amesquinhássemos": "amesquinhar",
    "amesquinhávamo": "amesquinhar",
    "amesquinhávamos": "amesquinhar",
    "amesquinhávei": "amesquinhar",
    "amesquinháveis": "amesquinhar",
    "amestra": "amestrar",
    "amestrada": "amestrar",
    "amestradas": "amestrar",
    "amestrado": "amestrar",
    "amestradora": "amestrador",
    "amestradoras": "amestrador",
    "amestradores": "amestrador",
    "amestrados": "amestrar",
    "amestradíssima": "amestrado",
    "amestradíssimas": "amestrado",
    "amestradíssimo": "amestrado",
    "amestradíssimos": "amestrado",
    "amestrai": "amestrar",
    "amestrais": "amestrar",
    "amestram": "amestrar",
    "amestramo": "amestrar",
    "amestramos": "amestrar",
    "amestrando": "amestrar",
    "amestrara": "amestrar",
    "amestraram": "amestrar",
    "amestraras": "amestrar",
    "amestrarde": "amestrar",
    "amestrardes": "amestrar",
    "amestrare": "amestrar",
    "amestrarei": "amestrar",
    "amestrareis": "amestrar",
    "amestrarem": "amestrar",
    "amestraremos": "amestrar",
    "amestrares": "amestrar",
    "amestraria": "amestrar",
    "amestrariam": "amestrar",
    "amestrarias": "amestrar",
    "amestrarmo": "amestrar",
    "amestrarmos": "amestrar",
    "amestrará": "amestrar",
    "amestrarás": "amestrar",
    "amestrarão": "amestrar",
    "amestraríamos": "amestrar",
    "amestraríeis": "amestrar",
    "amestras": "amestrar",
    "amestrasse": "amestrar",
    "amestrassem": "amestrar",
    "amestrasses": "amestrar",
    "amestraste": "amestrar",
    "amestrastes": "amestrar",
    "amestrava": "amestrar",
    "amestravam": "amestrar",
    "amestravas": "amestrar",
    "amestre": "amestrar",
    "amestrei": "amestrar",
    "amestreis": "amestrar",
    "amestrem": "amestrar",
    "amestremo": "amestrar",
    "amestremos": "amestrar",
    "amestres": "amestrar",
    "amestro": "amestrar",
    "amestrou": "amestrar",
    "amestrá": "amestrar",
    "amestrámo": "amestrar",
    "amestrámos": "amestrar",
    "amestráramo": "amestrar",
    "amestráramos": "amestrar",
    "amestrárei": "amestrar",
    "amestráreis": "amestrar",
    "amestrásseis": "amestrar",
    "amestrássemos": "amestrar",
    "amestrávamo": "amestrar",
    "amestrávamos": "amestrar",
    "amestrávei": "amestrar",
    "amestráveis": "amestrar",
    "ametais": "ametal",
    "ametala": "ametalar",
    "ametalada": "ametalar",
    "ametaladas": "ametalar",
    "ametalado": "ametalar",
    "ametalados": "ametalar",
    "ametalai": "ametalar",
    "ametalais": "ametalar",
    "ametalam": "ametalar",
    "ametalamo": "ametalar",
    "ametalamos": "ametalar",
    "ametalando": "ametalar",
    "ametalara": "ametalar",
    "ametalaram": "ametalar",
    "ametalaras": "ametalar",
    "ametalarde": "ametalar",
    "ametalardes": "ametalar",
    "ametalare": "ametalar",
    "ametalarei": "ametalar",
    "ametalareis": "ametalar",
    "ametalarem": "ametalar",
    "ametalaremos": "ametalar",
    "ametalares": "ametalar",
    "ametalaria": "ametalar",
    "ametalariam": "ametalar",
    "ametalarias": "ametalar",
    "ametalarmo": "ametalar",
    "ametalarmos": "ametalar",
    "ametalará": "ametalar",
    "ametalarás": "ametalar",
    "ametalarão": "ametalar",
    "ametalaríamos": "ametalar",
    "ametalaríeis": "ametalar",
    "ametalas": "ametalar",
    "ametalasse": "ametalar",
    "ametalassem": "ametalar",
    "ametalasses": "ametalar",
    "ametalaste": "ametalar",
    "ametalastes": "ametalar",
    "ametalava": "ametalar",
    "ametalavam": "ametalar",
    "ametalavas": "ametalar",
    "ametale": "ametalar",
    "ametalei": "ametalar",
    "ametaleis": "ametalar",
    "ametalem": "ametalar",
    "ametalemo": "ametalar",
    "ametalemos": "ametalar",
    "ametales": "ametalar",
    "ametalo": "ametalar",
    "ametalou": "ametalar",
    "ametalá": "ametalar",
    "ametalámo": "ametalar",
    "ametalámos": "ametalar",
    "ametaláramo": "ametalar",
    "ametaláramos": "ametalar",
    "ametalárei": "ametalar",
    "ametaláreis": "ametalar",
    "ametalásseis": "ametalar",
    "ametalássemos": "ametalar",
    "ametalávamo": "ametalar",
    "ametalávamos": "ametalar",
    "ametalávei": "ametalar",
    "ametaláveis": "ametalar",
    "ametistas": "ametista",
    "ametrias": "ametria",
    "ametropes": "ametrope",
    "ametropias": "ametropia",
    "ametísteas": "ametístea",
    "ametística": "ametístico",
    "ametísticas": "ametístico",
    "ametísticos": "ametístico",
    "amezinha": "amezinhar",
    "amezinhada": "amezinhar",
    "amezinhadas": "amezinhar",
    "amezinhado": "amezinhar",
    "amezinhadora": "amezinhador",
    "amezinhadoras": "amezinhador",
    "amezinhadores": "amezinhador",
    "amezinhados": "amezinhar",
    "amezinhai": "amezinhar",
    "amezinhais": "amezinhar",
    "amezinham": "amezinhar",
    "amezinhamo": "amezinhar",
    "amezinhamos": "amezinhar",
    "amezinhando": "amezinhar",
    "amezinhara": "amezinhar",
    "amezinharam": "amezinhar",
    "amezinharas": "amezinhar",
    "amezinharde": "amezinhar",
    "amezinhardes": "amezinhar",
    "amezinhare": "amezinhar",
    "amezinharei": "amezinhar",
    "amezinhareis": "amezinhar",
    "amezinharem": "amezinhar",
    "amezinharemos": "amezinhar",
    "amezinhares": "amezinhar",
    "amezinharia": "amezinhar",
    "amezinhariam": "amezinhar",
    "amezinharias": "amezinhar",
    "amezinharmo": "amezinhar",
    "amezinharmos": "amezinhar",
    "amezinhará": "amezinhar",
    "amezinharás": "amezinhar",
    "amezinharão": "amezinhar",
    "amezinharíamos": "amezinhar",
    "amezinharíeis": "amezinhar",
    "amezinhas": "amezinhar",
    "amezinhasse": "amezinhar",
    "amezinhassem": "amezinhar",
    "amezinhasses": "amezinhar",
    "amezinhaste": "amezinhar",
    "amezinhastes": "amezinhar",
    "amezinhava": "amezinhar",
    "amezinhavam": "amezinhar",
    "amezinhavas": "amezinhar",
    "amezinhe": "amezinhar",
    "amezinhei": "amezinhar",
    "amezinheis": "amezinhar",
    "amezinhem": "amezinhar",
    "amezinhemo": "amezinhar",
    "amezinhemos": "amezinhar",
    "amezinhes": "amezinhar",
    "amezinho": "amezinhar",
    "amezinhou": "amezinhar",
    "amezinhá": "amezinhar",
    "amezinhámo": "amezinhar",
    "amezinhámos": "amezinhar",
    "amezinháramo": "amezinhar",
    "amezinháramos": "amezinhar",
    "amezinhárei": "amezinhar",
    "amezinháreis": "amezinhar",
    "amezinhásseis": "amezinhar",
    "amezinhássemos": "amezinhar",
    "amezinhávamo": "amezinhar",
    "amezinhávamos": "amezinhar",
    "amezinhávei": "amezinhar",
    "amezinháveis": "amezinhável",
    "ameá": "amear",
    "ameámo": "amear",
    "ameámos": "amear",
    "ameáramo": "amear",
    "ameáramos": "amear",
    "ameárei": "amear",
    "ameáreis": "amear",
    "ameásseis": "amear",
    "ameássemos": "amear",
    "ameávamo": "amear",
    "ameávamos": "amear",
    "ameávei": "amear",
    "ameáveis": "amear",
    "amiais": "amial",
    "amiantina": "amiantino",
    "amiantinas": "amiantino",
    "amiantinos": "amiantino",
    "amiantos": "amianto",
    "amiantácea": "amiantáceo",
    "amiantáceas": "amiantáceo",
    "amiantáceos": "amiantáceo",
    "amiantóides": "amiantóide",
    "amibas": "amiba",
    "amicais": "amical",
    "amichela": "amichelar",
    "amichelada": "amichelar",
    "amicheladas": "amichelar",
    "amichelado": "amichelar",
    "amichelados": "amichelar",
    "amichelai": "amichelar",
    "amichelais": "amichelar",
    "amichelam": "amichelar",
    "amichelamo": "amichelar",
    "amichelamos": "amichelar",
    "amichelando": "amichelar",
    "amichelara": "amichelar",
    "amichelaram": "amichelar",
    "amichelaras": "amichelar",
    "amichelarde": "amichelar",
    "amichelardes": "amichelar",
    "amichelare": "amichelar",
    "amichelarei": "amichelar",
    "amichelareis": "amichelar",
    "amichelarem": "amichelar",
    "amichelaremos": "amichelar",
    "amichelares": "amichelar",
    "amichelaria": "amichelar",
    "amichelariam": "amichelar",
    "amichelarias": "amichelar",
    "amichelarmo": "amichelar",
    "amichelarmos": "amichelar",
    "amichelará": "amichelar",
    "amichelarás": "amichelar",
    "amichelarão": "amichelar",
    "amichelaríamos": "amichelar",
    "amichelaríeis": "amichelar",
    "amichelas": "amichelar",
    "amichelasse": "amichelar",
    "amichelassem": "amichelar",
    "amichelasses": "amichelar",
    "amichelaste": "amichelar",
    "amichelastes": "amichelar",
    "amichelava": "amichelar",
    "amichelavam": "amichelar",
    "amichelavas": "amichelar",
    "amichele": "amichelar",
    "amichelei": "amichelar",
    "amicheleis": "amichelar",
    "amichelem": "amichelar",
    "amichelemo": "amichelar",
    "amichelemos": "amichelar",
    "amicheles": "amichelar",
    "amichelo": "amichelar",
    "amichelou": "amichelar",
    "amichelá": "amichelar",
    "amichelámo": "amichelar",
    "amichelámos": "amichelar",
    "amicheláramo": "amichelar",
    "amicheláramos": "amichelar",
    "amichelárei": "amichelar",
    "amicheláreis": "amichelar",
    "amichelásseis": "amichelar",
    "amichelássemos": "amichelar",
    "amichelávamo": "amichelar",
    "amichelávamos": "amichelar",
    "amichelávei": "amichelar",
    "amicheláveis": "amichelar",
    "amictos": "amicto",
    "amictória": "amictório",
    "amictórias": "amictório",
    "amictórios": "amictório",
    "amicíssima": "amigo",
    "amicíssimas": "amigo",
    "amicíssimo": "amigo",
    "amicíssimos": "amigo",
    "amida": "amidar",
    "amidada": "amidar",
    "amidadas": "amidar",
    "amidado": "amidar",
    "amidados": "amidar",
    "amidai": "amidar",
    "amidais": "amidar",
    "amidalites": "amidalite",
    "amidam": "amidar",
    "amidamo": "amidar",
    "amidamos": "amidar",
    "amidando": "amidar",
    "amidara": "amidar",
    "amidaram": "amidar",
    "amidaras": "amidar",
    "amidarde": "amidar",
    "amidardes": "amidar",
    "amidare": "amidar",
    "amidarei": "amidar",
    "amidareis": "amidar",
    "amidarem": "amidar",
    "amidaremos": "amidar",
    "amidares": "amidar",
    "amidaria": "amidar",
    "amidariam": "amidar",
    "amidarias": "amidar",
    "amidarmo": "amidar",
    "amidarmos": "amidar",
    "amidará": "amidar",
    "amidarás": "amidar",
    "amidarão": "amidar",
    "amidaríamos": "amidar",
    "amidaríeis": "amidar",
    "amidas": "amidar",
    "amidasse": "amidar",
    "amidassem": "amidar",
    "amidasses": "amidar",
    "amidaste": "amidar",
    "amidastes": "amidar",
    "amidava": "amidar",
    "amidavam": "amidar",
    "amidavas": "amidar",
    "amide": "amidar",
    "amidei": "amidar",
    "amideis": "amidar",
    "amidem": "amidar",
    "amidemo": "amidar",
    "amidemos": "amidar",
    "amides": "amidar",
    "amidinas": "amidina",
    "amido": "amidar",
    "amidogénios": "amidogénio",
    "amidoleucitos": "amidoleucito",
    "amidoplastídia": "amidoplastídio",
    "amidoplastídias": "amidoplastídio",
    "amidoplastídios": "amidoplastídio",
    "amidos": "amido",
    "amidou": "amidar",
    "amidá": "amidar",
    "amidálica": "amidálico",
    "amidálicas": "amidálico",
    "amidálicos": "amidálico",
    "amidámo": "amidar",
    "amidámos": "amidar",
    "amidáramo": "amidar",
    "amidáramos": "amidar",
    "amidárei": "amidar",
    "amidáreis": "amidar",
    "amidásseis": "amidar",
    "amidássemos": "amidar",
    "amidávamo": "amidar",
    "amidávamos": "amidar",
    "amidávei": "amidar",
    "amidáveis": "amidar",
    "amidóis": "amidol",
    "amieirais": "amieiral",
    "amieiras": "amieira",
    "amieiros": "amieiro",
    "amielencefalias": "amielencefalia",
    "amielencéfala": "amielencéfalo",
    "amielencéfalas": "amielencéfalo",
    "amielencéfalos": "amielencéfalo",
    "amielias": "amielia",
    "amielotrofias": "amielotrofia",
    "amiga": "amigo",
    "amigada": "amigar",
    "amigadas": "amigar",
    "amigado": "amigar",
    "amigados": "amigar",
    "amigai": "amigar",
    "amigais": "amigar",
    "amigalhaça": "amigalhaço",
    "amigalhaças": "amigalhaço",
    "amigalhaços": "amigalhaço",
    "amigalhona": "amigalhão",
    "amigalhonas": "amigalhão",
    "amigalhota": "amigalhote",
    "amigalhotas": "amigalhote",
    "amigalhotes": "amigalhote",
    "amigalhões": "amigalhão",
    "amigam": "amigar",
    "amigamo": "amigar",
    "amigamos": "amigar",
    "amigando": "amigar",
    "amiganços": "amiganço",
    "amigara": "amigar",
    "amigaram": "amigar",
    "amigaras": "amigar",
    "amigarde": "amigar",
    "amigardes": "amigar",
    "amigare": "amigar",
    "amigarei": "amigar",
    "amigareis": "amigar",
    "amigarem": "amigar",
    "amigaremos": "amigar",
    "amigares": "amigar",
    "amigaria": "amigar",
    "amigariam": "amigar",
    "amigarias": "amigar",
    "amigarmo": "amigar",
    "amigarmos": "amigar",
    "amigará": "amigar",
    "amigarás": "amigar",
    "amigarão": "amigar",
    "amigaríamos": "amigar",
    "amigaríeis": "amigar",
    "amigas": "amigo",
    "amigasse": "amigar",
    "amigassem": "amigar",
    "amigasses": "amigar",
    "amigaste": "amigar",
    "amigastes": "amigar",
    "amigava": "amigar",
    "amigavam": "amigar",
    "amigavas": "amigar",
    "amigaça": "amigaço",
    "amigaças": "amigaço",
    "amigaços": "amigaço",
    "amigações": "amigação",
    "amigdala": "amigdalar",
    "amigdalada": "amigdalar",
    "amigdaladas": "amigdalar",
    "amigdalado": "amigdalar",
    "amigdalados": "amigdalar",
    "amigdalai": "amigdalar",
    "amigdalais": "amigdalar",
    "amigdalam": "amigdalar",
    "amigdalamo": "amigdalar",
    "amigdalamos": "amigdalar",
    "amigdalando": "amigdalar",
    "amigdalara": "amigdalar",
    "amigdalaram": "amigdalar",
    "amigdalaras": "amigdalar",
    "amigdalarde": "amigdalar",
    "amigdalardes": "amigdalar",
    "amigdalare": "amigdalar",
    "amigdalarei": "amigdalar",
    "amigdalareis": "amigdalar",
    "amigdalarem": "amigdalar",
    "amigdalaremos": "amigdalar",
    "amigdalares": "amigdalar",
    "amigdalaria": "amigdalar",
    "amigdalariam": "amigdalar",
    "amigdalarias": "amigdalar",
    "amigdalarmo": "amigdalar",
    "amigdalarmos": "amigdalar",
    "amigdalará": "amigdalar",
    "amigdalarás": "amigdalar",
    "amigdalarão": "amigdalar",
    "amigdalaríamos": "amigdalar",
    "amigdalaríeis": "amigdalar",
    "amigdalas": "amigdalar",
    "amigdalasse": "amigdalar",
    "amigdalassem": "amigdalar",
    "amigdalasses": "amigdalar",
    "amigdalaste": "amigdalar",
    "amigdalastes": "amigdalar",
    "amigdalava": "amigdalar",
    "amigdalavam": "amigdalar",
    "amigdalavas": "amigdalar",
    "amigdale": "amigdalar",
    "amigdalectomias": "amigdalectomia",
    "amigdalei": "amigdalar",
    "amigdaleis": "amigdalar",
    "amigdalem": "amigdalar",
    "amigdalemo": "amigdalar",
    "amigdalemos": "amigdalar",
    "amigdales": "amigdalar",
    "amigdaliana": "amigdaliano",
    "amigdalianas": "amigdaliano",
    "amigdalianos": "amigdaliano",
    "amigdaliformes": "amigdaliforme",
    "amigdalina": "amigdalino",
    "amigdalinas": "amigdalino",
    "amigdalinos": "amigdalino",
    "amigdalites": "amigdalite",
    "amigdalo": "amigdalar",
    "amigdalotomias": "amigdalotomia",
    "amigdalou": "amigdalar",
    "amigdalá": "amigdalar",
    "amigdalácea": "amigdaláceo",
    "amigdaláceas": "amigdaláceo",
    "amigdaláceos": "amigdaláceo",
    "amigdalámo": "amigdalar",
    "amigdalámos": "amigdalar",
    "amigdaláramo": "amigdalar",
    "amigdaláramos": "amigdalar",
    "amigdalárei": "amigdalar",
    "amigdaláreis": "amigdalar",
    "amigdalásseis": "amigdalar",
    "amigdalássemos": "amigdalar",
    "amigdalávamo": "amigdalar",
    "amigdalávamos": "amigdalar",
    "amigdalávei": "amigdalar",
    "amigdaláveis": "amigdalar",
    "amigdalífera": "amigdalífero",
    "amigdalíferas": "amigdalífero",
    "amigdalíferos": "amigdalífero",
    "amigdalótomos": "amigdalótomo",
    "amigdáleas": "amigdálea",
    "amigdália": "amigdálio",
    "amigdálias": "amigdálio",
    "amigdálica": "amigdálico",
    "amigdálicas": "amigdálico",
    "amigdálicos": "amigdálico",
    "amigdálios": "amigdálio",
    "amigo": "amigar",
    "amigos": "amigo",
    "amigou": "amigar",
    "amigue": "amigar",
    "amiguei": "amigar",
    "amigueis": "amigar",
    "amiguem": "amigar",
    "amiguemo": "amigar",
    "amiguemos": "amigar",
    "amigues": "amigar",
    "amiguetes": "amiguete",
    "amiguinha": "amigo",
    "amiguinhas": "amigo",
    "amiguinho": "amigo",
    "amiguinhos": "amigo",
    "amiguita": "amigo",
    "amiguitas": "amigo",
    "amiguito": "amigo",
    "amiguitos": "amigo",
    "amiguíssima": "amigo",
    "amiguíssimas": "amigo",
    "amiguíssimo": "amigo",
    "amiguíssimos": "amigo",
    "amigá": "amigar",
    "amigámo": "amigar",
    "amigámos": "amigar",
    "amigáramo": "amigar",
    "amigáramos": "amigar",
    "amigárei": "amigar",
    "amigáreis": "amigar",
    "amigásseis": "amigar",
    "amigássemos": "amigar",
    "amigávamo": "amigar",
    "amigávamos": "amigar",
    "amigávei": "amigar",
    "amigáveis": "amigável",
    "amigões": "amigão",
    "amilha": "amilhar",
    "amilhada": "amilhar",
    "amilhadas": "amilhar",
    "amilhado": "amilhar",
    "amilhados": "amilhar",
    "amilhai": "amilhar",
    "amilhais": "amilhar",
    "amilham": "amilhar",
    "amilhamo": "amilhar",
    "amilhamos": "amilhar",
    "amilhando": "amilhar",
    "amilhara": "amilhar",
    "amilharam": "amilhar",
    "amilharas": "amilhar",
    "amilharde": "amilhar",
    "amilhardes": "amilhar",
    "amilhare": "amilhar",
    "amilharei": "amilhar",
    "amilhareis": "amilhar",
    "amilharem": "amilhar",
    "amilharemos": "amilhar",
    "amilhares": "amilhar",
    "amilharia": "amilhar",
    "amilhariam": "amilhar",
    "amilharias": "amilhar",
    "amilharmo": "amilhar",
    "amilharmos": "amilhar",
    "amilhará": "amilhar",
    "amilharás": "amilhar",
    "amilharão": "amilhar",
    "amilharíamos": "amilhar",
    "amilharíeis": "amilhar",
    "amilhas": "amilhar",
    "amilhasse": "amilhar",
    "amilhassem": "amilhar",
    "amilhasses": "amilhar",
    "amilhaste": "amilhar",
    "amilhastes": "amilhar",
    "amilhava": "amilhar",
    "amilhavam": "amilhar",
    "amilhavas": "amilhar",
    "amilhe": "amilhar",
    "amilhei": "amilhar",
    "amilheis": "amilhar",
    "amilhem": "amilhar",
    "amilhemo": "amilhar",
    "amilhemos": "amilhar",
    "amilhes": "amilhar",
    "amilho": "amilhar",
    "amilhou": "amilhar",
    "amilhá": "amilhar",
    "amilhámo": "amilhar",
    "amilhámos": "amilhar",
    "amilháramo": "amilhar",
    "amilháramos": "amilhar",
    "amilhárei": "amilhar",
    "amilháreis": "amilhar",
    "amilhásseis": "amilhar",
    "amilhássemos": "amilhar",
    "amilhávamo": "amilhar",
    "amilhávamos": "amilhar",
    "amilhávei": "amilhar",
    "amilháveis": "amilhar",
    "amiloleucitos": "amiloleucito",
    "amiloplastas": "amiloplasta",
    "amiloplastídia": "amiloplastídio",
    "amiloplastídias": "amiloplastídio",
    "amiloplastídios": "amiloplastídio",
    "amilopsinas": "amilopsina",
    "amilos": "amilo",
    "amiloses": "amilose",
    "amilácea": "amiláceo",
    "amiláceas": "amiláceo",
    "amiláceos": "amiláceo",
    "amilífera": "amilífero",
    "amilíferas": "amilífero",
    "amilíferos": "amilífero",
    "amilóides": "amilóide",
    "amilólises": "amilólise",
    "amima": "amimar",
    "amimada": "amimar",
    "amimadas": "amimar",
    "amimado": "amimar",
    "amimadora": "amimador",
    "amimadoras": "amimador",
    "amimadores": "amimador",
    "amimados": "amimar",
    "amimai": "amimar",
    "amimais": "amimar",
    "amimalha": "amimalhar",
    "amimalhada": "amimalhar",
    "amimalhadas": "amimalhar",
    "amimalhado": "amimalhar",
    "amimalhados": "amimalhar",
    "amimalhai": "amimalhar",
    "amimalhais": "amimalhar",
    "amimalham": "amimalhar",
    "amimalhamo": "amimalhar",
    "amimalhamos": "amimalhar",
    "amimalhando": "amimalhar",
    "amimalhara": "amimalhar",
    "amimalharam": "amimalhar",
    "amimalharas": "amimalhar",
    "amimalharde": "amimalhar",
    "amimalhardes": "amimalhar",
    "amimalhare": "amimalhar",
    "amimalharei": "amimalhar",
    "amimalhareis": "amimalhar",
    "amimalharem": "amimalhar",
    "amimalharemos": "amimalhar",
    "amimalhares": "amimalhar",
    "amimalharia": "amimalhar",
    "amimalhariam": "amimalhar",
    "amimalharias": "amimalhar",
    "amimalharmo": "amimalhar",
    "amimalharmos": "amimalhar",
    "amimalhará": "amimalhar",
    "amimalharás": "amimalhar",
    "amimalharão": "amimalhar",
    "amimalharíamos": "amimalhar",
    "amimalharíeis": "amimalhar",
    "amimalhas": "amimalhar",
    "amimalhasse": "amimalhar",
    "amimalhassem": "amimalhar",
    "amimalhasses": "amimalhar",
    "amimalhaste": "amimalhar",
    "amimalhastes": "amimalhar",
    "amimalhava": "amimalhar",
    "amimalhavam": "amimalhar",
    "amimalhavas": "amimalhar",
    "amimalhe": "amimalhar",
    "amimalhei": "amimalhar",
    "amimalheis": "amimalhar",
    "amimalhem": "amimalhar",
    "amimalhemo": "amimalhar",
    "amimalhemos": "amimalhar",
    "amimalhes": "amimalhar",
    "amimalho": "amimalhar",
    "amimalhou": "amimalhar",
    "amimalhá": "amimalhar",
    "amimalhámo": "amimalhar",
    "amimalhámos": "amimalhar",
    "amimalháramo": "amimalhar",
    "amimalháramos": "amimalhar",
    "amimalhárei": "amimalhar",
    "amimalháreis": "amimalhar",
    "amimalhásseis": "amimalhar",
    "amimalhássemos": "amimalhar",
    "amimalhávamo": "amimalhar",
    "amimalhávamos": "amimalhar",
    "amimalhávei": "amimalhar",
    "amimalháveis": "amimalhar",
    "amimam": "amimar",
    "amimamo": "amimar",
    "amimamos": "amimar",
    "amimando": "amimar",
    "amimara": "amimar",
    "amimaram": "amimar",
    "amimaras": "amimar",
    "amimarde": "amimar",
    "amimardes": "amimar",
    "amimare": "amimar",
    "amimarei": "amimar",
    "amimareis": "amimar",
    "amimarem": "amimar",
    "amimaremos": "amimar",
    "amimares": "amimar",
    "amimaria": "amimar",
    "amimariam": "amimar",
    "amimarias": "amimar",
    "amimarmo": "amimar",
    "amimarmos": "amimar",
    "amimará": "amimar",
    "amimarás": "amimar",
    "amimarão": "amimar",
    "amimaríamos": "amimar",
    "amimaríeis": "amimar",
    "amimas": "amimar",
    "amimasse": "amimar",
    "amimassem": "amimar",
    "amimasses": "amimar",
    "amimaste": "amimar",
    "amimastes": "amimar",
    "amimava": "amimar",
    "amimavam": "amimar",
    "amimavas": "amimar",
    "amime": "amimar",
    "amimei": "amimar",
    "amimeis": "amimar",
    "amimem": "amimar",
    "amimemo": "amimar",
    "amimemos": "amimar",
    "amimes": "amimar",
    "amimias": "amimia",
    "amimo": "amimar",
    "amimou": "amimar",
    "amimá": "amimar",
    "amimámo": "amimar",
    "amimámos": "amimar",
    "amimáramo": "amimar",
    "amimáramos": "amimar",
    "amimárei": "amimar",
    "amimáreis": "amimar",
    "amimásseis": "amimar",
    "amimássemos": "amimar",
    "amimávamo": "amimar",
    "amimávamos": "amimar",
    "amimávei": "amimar",
    "amimáveis": "amimar",
    "aminas": "amina",
    "aminoácidos": "aminoácido",
    "aminácidos": "aminácido",
    "aminóis": "aminol",
    "amiostasias": "amiostasia",
    "amiotaxias": "amiotaxia",
    "amisera": "amiserar",
    "amiserada": "amiserar",
    "amiseradas": "amiserar",
    "amiserado": "amiserar",
    "amiserados": "amiserar",
    "amiserai": "amiserar",
    "amiserais": "amiserar",
    "amiseram": "amiserar",
    "amiseramo": "amiserar",
    "amiseramos": "amiserar",
    "amiserando": "amiserar",
    "amiserara": "amiserar",
    "amiseraram": "amiserar",
    "amiseraras": "amiserar",
    "amiserarde": "amiserar",
    "amiserardes": "amiserar",
    "amiserare": "amiserar",
    "amiserarei": "amiserar",
    "amiserareis": "amiserar",
    "amiserarem": "amiserar",
    "amiseraremos": "amiserar",
    "amiserares": "amiserar",
    "amiseraria": "amiserar",
    "amiserariam": "amiserar",
    "amiserarias": "amiserar",
    "amiserarmo": "amiserar",
    "amiserarmos": "amiserar",
    "amiserará": "amiserar",
    "amiserarás": "amiserar",
    "amiserarão": "amiserar",
    "amiseraríamos": "amiserar",
    "amiseraríeis": "amiserar",
    "amiseras": "amiserar",
    "amiserasse": "amiserar",
    "amiserassem": "amiserar",
    "amiserasses": "amiserar",
    "amiseraste": "amiserar",
    "amiserastes": "amiserar",
    "amiserava": "amiserar",
    "amiseravam": "amiserar",
    "amiseravas": "amiserar",
    "amisere": "amiserar",
    "amiserei": "amiserar",
    "amisereis": "amiserar",
    "amiserem": "amiserar",
    "amiseremo": "amiserar",
    "amiseremos": "amiserar",
    "amiseres": "amiserar",
    "amisero": "amiserar",
    "amiserou": "amiserar",
    "amiserá": "amiserar",
    "amiserámo": "amiserar",
    "amiserámos": "amiserar",
    "amiseráramo": "amiserar",
    "amiseráramos": "amiserar",
    "amiserárei": "amiserar",
    "amiseráreis": "amiserar",
    "amiserásseis": "amiserar",
    "amiserássemos": "amiserar",
    "amiserávamo": "amiserar",
    "amiserávamos": "amiserar",
    "amiserávei": "amiserar",
    "amiseráveis": "amiserar",
    "amissibilidades": "amissibilidade",
    "amissíveis": "amissível",
    "amissões": "amissão",
    "amista": "amistar",
    "amistada": "amistar",
    "amistadas": "amistar",
    "amistado": "amistar",
    "amistados": "amistar",
    "amistai": "amistar",
    "amistais": "amistar",
    "amistam": "amistar",
    "amistamo": "amistar",
    "amistamos": "amistar",
    "amistando": "amistar",
    "amistara": "amistar",
    "amistaram": "amistar",
    "amistaras": "amistar",
    "amistarde": "amistar",
    "amistardes": "amistar",
    "amistare": "amistar",
    "amistarei": "amistar",
    "amistareis": "amistar",
    "amistarem": "amistar",
    "amistaremos": "amistar",
    "amistares": "amistar",
    "amistaria": "amistar",
    "amistariam": "amistar",
    "amistarias": "amistar",
    "amistarmo": "amistar",
    "amistarmos": "amistar",
    "amistará": "amistar",
    "amistarás": "amistar",
    "amistarão": "amistar",
    "amistaríamos": "amistar",
    "amistaríeis": "amistar",
    "amistas": "amistar",
    "amistasse": "amistar",
    "amistassem": "amistar",
    "amistasses": "amistar",
    "amistaste": "amistar",
    "amistastes": "amistar",
    "amistava": "amistar",
    "amistavam": "amistar",
    "amistavas": "amistar",
    "amiste": "amistar",
    "amistei": "amistar",
    "amisteis": "amistar",
    "amistem": "amistar",
    "amistemo": "amistar",
    "amistemos": "amistar",
    "amistes": "amistar",
    "amisto": "amistar",
    "amistosa": "amistoso",
    "amistosas": "amistoso",
    "amistosos": "amistoso",
    "amistosíssima": "amistoso",
    "amistosíssimas": "amistoso",
    "amistosíssimo": "amistoso",
    "amistosíssimos": "amistoso",
    "amistou": "amistar",
    "amistá": "amistar",
    "amistámo": "amistar",
    "amistámos": "amistar",
    "amistáramo": "amistar",
    "amistáramos": "amistar",
    "amistárei": "amistar",
    "amistáreis": "amistar",
    "amistásseis": "amistar",
    "amistássemos": "amistar",
    "amistávamo": "amistar",
    "amistávamos": "amistar",
    "amistávei": "amistar",
    "amistáveis": "amistar",
    "amitoses": "amitose",
    "amiudada": "amiudar",
    "amiudadas": "amiudar",
    "amiudado": "amiudar",
    "amiudados": "amiudar",
    "amiudai": "amiudar",
    "amiudais": "amiudar",
    "amiudamo": "amiudar",
    "amiudamos": "amiudar",
    "amiudando": "amiudar",
    "amiudara": "amiudar",
    "amiudaram": "amiudar",
    "amiudaras": "amiudar",
    "amiudarde": "amiudar",
    "amiudardes": "amiudar",
    "amiudare": "amiudar",
    "amiudarei": "amiudar",
    "amiudareis": "amiudar",
    "amiudarem": "amiudar",
    "amiudaremos": "amiudar",
    "amiudares": "amiudar",
    "amiudaria": "amiudar",
    "amiudariam": "amiudar",
    "amiudarias": "amiudar",
    "amiudarmo": "amiudar",
    "amiudarmos": "amiudar",
    "amiudará": "amiudar",
    "amiudarás": "amiudar",
    "amiudarão": "amiudar",
    "amiudaríamos": "amiudar",
    "amiudaríeis": "amiudar",
    "amiudasse": "amiudar",
    "amiudassem": "amiudar",
    "amiudasses": "amiudar",
    "amiudaste": "amiudar",
    "amiudastes": "amiudar",
    "amiudava": "amiudar",
    "amiudavam": "amiudar",
    "amiudavas": "amiudar",
    "amiudei": "amiudar",
    "amiudeis": "amiudar",
    "amiudemo": "amiudar",
    "amiudemos": "amiudar",
    "amiudou": "amiudar",
    "amiudá": "amiudar",
    "amiudámo": "amiudar",
    "amiudámos": "amiudar",
    "amiudáramo": "amiudar",
    "amiudáramos": "amiudar",
    "amiudárei": "amiudar",
    "amiudáreis": "amiudar",
    "amiudásseis": "amiudar",
    "amiudássemos": "amiudar",
    "amiudávamo": "amiudar",
    "amiudávamos": "amiudar",
    "amiudávei": "amiudar",
    "amiudáveis": "amiudar",
    "amixias": "amixia",
    "amixorreias": "amixorreia",
    "amizades": "amizade",
    "amiélica": "amiélico",
    "amiélicas": "amiélico",
    "amiélicos": "amiélico",
    "amiéstias": "amiéstia",
    "amiúda": "amiudar",
    "amiúdam": "amiudar",
    "amiúdas": "amiudar",
    "amiúde": "amiudar",
    "amiúdem": "amiudar",
    "amiúdes": "amiudar",
    "amiúdo": "amiudar",
    "amnesia": "amnesiar",
    "amnesiada": "amnesiar",
    "amnesiadas": "amnesiar",
    "amnesiado": "amnesiar",
    "amnesiados": "amnesiar",
    "amnesiai": "amnesiar",
    "amnesiais": "amnesiar",
    "amnesiam": "amnesiar",
    "amnesiamo": "amnesiar",
    "amnesiamos": "amnesiar",
    "amnesiando": "amnesiar",
    "amnesiara": "amnesiar",
    "amnesiaram": "amnesiar",
    "amnesiaras": "amnesiar",
    "amnesiarde": "amnesiar",
    "amnesiardes": "amnesiar",
    "amnesiare": "amnesiar",
    "amnesiarei": "amnesiar",
    "amnesiareis": "amnesiar",
    "amnesiarem": "amnesiar",
    "amnesiaremos": "amnesiar",
    "amnesiares": "amnesiar",
    "amnesiaria": "amnesiar",
    "amnesiariam": "amnesiar",
    "amnesiarias": "amnesiar",
    "amnesiarmo": "amnesiar",
    "amnesiarmos": "amnesiar",
    "amnesiará": "amnesiar",
    "amnesiarás": "amnesiar",
    "amnesiarão": "amnesiar",
    "amnesiaríamos": "amnesiar",
    "amnesiaríeis": "amnesiar",
    "amnesias": "amnesiar",
    "amnesiasse": "amnesiar",
    "amnesiassem": "amnesiar",
    "amnesiasses": "amnesiar",
    "amnesiaste": "amnesiar",
    "amnesiastes": "amnesiar",
    "amnesiava": "amnesiar",
    "amnesiavam": "amnesiar",
    "amnesiavas": "amnesiar",
    "amnesie": "amnesiar",
    "amnesiei": "amnesiar",
    "amnesieis": "amnesiar",
    "amnesiem": "amnesiar",
    "amnesiemo": "amnesiar",
    "amnesiemos": "amnesiar",
    "amnesies": "amnesiar",
    "amnesio": "amnesiar",
    "amnesiou": "amnesiar",
    "amnesiá": "amnesiar",
    "amnesiámo": "amnesiar",
    "amnesiámos": "amnesiar",
    "amnesiáramo": "amnesiar",
    "amnesiáramos": "amnesiar",
    "amnesiárei": "amnesiar",
    "amnesiáreis": "amnesiar",
    "amnesiásseis": "amnesiar",
    "amnesiássemos": "amnesiar",
    "amnesiávamo": "amnesiar",
    "amnesiávamos": "amnesiar",
    "amnesiávei": "amnesiar",
    "amnesiáveis": "amnesiar",
    "amniada": "amniado",
    "amniadas": "amniado",
    "amniados": "amniado",
    "amniocenteses": "amniocentese",
    "amniotas": "amniota",
    "amnistia": "amnistiar",
    "amnistiada": "amnistiar",
    "amnistiadas": "amnistiar",
    "amnistiado": "amnistiar",
    "amnistiados": "amnistiar",
    "amnistiai": "amnistiar",
    "amnistiais": "amnistiar",
    "amnistiam": "amnistiar",
    "amnistiamo": "amnistiar",
    "amnistiamos": "amnistiar",
    "amnistiando": "amnistiar",
    "amnistiara": "amnistiar",
    "amnistiaram": "amnistiar",
    "amnistiaras": "amnistiar",
    "amnistiarde": "amnistiar",
    "amnistiardes": "amnistiar",
    "amnistiare": "amnistiar",
    "amnistiarei": "amnistiar",
    "amnistiareis": "amnistiar",
    "amnistiarem": "amnistiar",
    "amnistiaremos": "amnistiar",
    "amnistiares": "amnistiar",
    "amnistiaria": "amnistiar",
    "amnistiariam": "amnistiar",
    "amnistiarias": "amnistiar",
    "amnistiarmo": "amnistiar",
    "amnistiarmos": "amnistiar",
    "amnistiará": "amnistiar",
    "amnistiarás": "amnistiar",
    "amnistiarão": "amnistiar",
    "amnistiaríamos": "amnistiar",
    "amnistiaríeis": "amnistiar",
    "amnistias": "amnistiar",
    "amnistiasse": "amnistiar",
    "amnistiassem": "amnistiar",
    "amnistiasses": "amnistiar",
    "amnistiaste": "amnistiar",
    "amnistiastes": "amnistiar",
    "amnistiava": "amnistiar",
    "amnistiavam": "amnistiar",
    "amnistiavas": "amnistiar",
    "amnistie": "amnistiar",
    "amnistiei": "amnistiar",
    "amnistieis": "amnistiar",
    "amnistiem": "amnistiar",
    "amnistiemo": "amnistiar",
    "amnistiemos": "amnistiar",
    "amnisties": "amnistiar",
    "amnistio": "amnistiar",
    "amnistiou": "amnistiar",
    "amnistiá": "amnistiar",
    "amnistiámo": "amnistiar",
    "amnistiámos": "amnistiar",
    "amnistiáramo": "amnistiar",
    "amnistiáramos": "amnistiar",
    "amnistiárei": "amnistiar",
    "amnistiáreis": "amnistiar",
    "amnistiásseis": "amnistiar",
    "amnistiássemos": "amnistiar",
    "amnistiávamo": "amnistiar",
    "amnistiávamos": "amnistiar",
    "amnistiávei": "amnistiar",
    "amnistiáveis": "amnistiável",
    "amniótica": "amniótico",
    "amnióticas": "amniótico",
    "amnióticos": "amniótico",
    "amnésias": "amnésia",
    "amnésica": "amnésico",
    "amnésicas": "amnésico",
    "amnésicos": "amnésico",
    "amnéstica": "amnéstico",
    "amnésticas": "amnéstico",
    "amnésticos": "amnéstico",
    "amnícolas": "amnícola",
    "amo": "amar",
    "amoca": "amocar",
    "amocada": "amocar",
    "amocadas": "amocar",
    "amocado": "amocar",
    "amocados": "amocar",
    "amocai": "amocar",
    "amocais": "amocar",
    "amocam": "amocar",
    "amocamba": "amocambar",
    "amocambada": "amocambar",
    "amocambadas": "amocambar",
    "amocambado": "amocambar",
    "amocambados": "amocambar",
    "amocambai": "amocambar",
    "amocambais": "amocambar",
    "amocambam": "amocambar",
    "amocambamo": "amocambar",
    "amocambamos": "amocambar",
    "amocambando": "amocambar",
    "amocambara": "amocambar",
    "amocambaram": "amocambar",
    "amocambaras": "amocambar",
    "amocambarde": "amocambar",
    "amocambardes": "amocambar",
    "amocambare": "amocambar",
    "amocambarei": "amocambar",
    "amocambareis": "amocambar",
    "amocambarem": "amocambar",
    "amocambaremos": "amocambar",
    "amocambares": "amocambar",
    "amocambaria": "amocambar",
    "amocambariam": "amocambar",
    "amocambarias": "amocambar",
    "amocambarmo": "amocambar",
    "amocambarmos": "amocambar",
    "amocambará": "amocambar",
    "amocambarás": "amocambar",
    "amocambarão": "amocambar",
    "amocambaríamos": "amocambar",
    "amocambaríeis": "amocambar",
    "amocambas": "amocambar",
    "amocambasse": "amocambar",
    "amocambassem": "amocambar",
    "amocambasses": "amocambar",
    "amocambaste": "amocambar",
    "amocambastes": "amocambar",
    "amocambava": "amocambar",
    "amocambavam": "amocambar",
    "amocambavas": "amocambar",
    "amocambe": "amocambar",
    "amocambei": "amocambar",
    "amocambeis": "amocambar",
    "amocambem": "amocambar",
    "amocambemo": "amocambar",
    "amocambemos": "amocambar",
    "amocambes": "amocambar",
    "amocambo": "amocambar",
    "amocambou": "amocambar",
    "amocambá": "amocambar",
    "amocambámo": "amocambar",
    "amocambámos": "amocambar",
    "amocambáramo": "amocambar",
    "amocambáramos": "amocambar",
    "amocambárei": "amocambar",
    "amocambáreis": "amocambar",
    "amocambásseis": "amocambar",
    "amocambássemos": "amocambar",
    "amocambávamo": "amocambar",
    "amocambávamos": "amocambar",
    "amocambávei": "amocambar",
    "amocambáveis": "amocambar",
    "amocamo": "amocar",
    "amocamos": "amocar",
    "amocando": "amocar",
    "amocara": "amocar",
    "amocaram": "amocar",
    "amocaras": "amocar",
    "amocarde": "amocar",
    "amocardes": "amocar",
    "amocare": "amocar",
    "amocarei": "amocar",
    "amocareis": "amocar",
    "amocarem": "amocar",
    "amocaremos": "amocar",
    "amocares": "amocar",
    "amocaria": "amocar",
    "amocariam": "amocar",
    "amocarias": "amocar",
    "amocarmo": "amocar",
    "amocarmos": "amocar",
    "amocará": "amocar",
    "amocarás": "amocar",
    "amocarão": "amocar",
    "amocaríamos": "amocar",
    "amocaríeis": "amocar",
    "amocas": "amocar",
    "amocasse": "amocar",
    "amocassem": "amocar",
    "amocasses": "amocar",
    "amocaste": "amocar",
    "amocastes": "amocar",
    "amocava": "amocar",
    "amocavam": "amocar",
    "amocavas": "amocar",
    "amocha": "amochar",
    "amochada": "amochar",
    "amochadas": "amochar",
    "amochado": "amochar",
    "amochados": "amochar",
    "amochai": "amochar",
    "amochais": "amochar",
    "amocham": "amochar",
    "amochamo": "amochar",
    "amochamos": "amochar",
    "amochando": "amochar",
    "amochara": "amochar",
    "amocharam": "amochar",
    "amocharas": "amochar",
    "amochardes": "amochar",
    "amocharei": "amochar",
    "amochareis": "amochar",
    "amocharem": "amochar",
    "amocharemos": "amochar",
    "amochares": "amochar",
    "amocharia": "amochar",
    "amochariam": "amochar",
    "amocharias": "amochar",
    "amocharmo": "amochar",
    "amocharmos": "amochar",
    "amochará": "amochar",
    "amocharás": "amochar",
    "amocharão": "amochar",
    "amocharíamos": "amochar",
    "amocharíeis": "amochar",
    "amochas": "amochar",
    "amochasse": "amochar",
    "amochassem": "amochar",
    "amochasses": "amochar",
    "amochaste": "amochar",
    "amochastes": "amochar",
    "amochava": "amochar",
    "amochavam": "amochar",
    "amochavas": "amochar",
    "amoche": "amochar",
    "amochei": "amochar",
    "amocheis": "amochar",
    "amochem": "amochar",
    "amochemo": "amochar",
    "amochemos": "amochar",
    "amoches": "amochar",
    "amochila": "amochilar",
    "amochilada": "amochilar",
    "amochiladas": "amochilar",
    "amochilado": "amochilar",
    "amochilados": "amochilar",
    "amochilai": "amochilar",
    "amochilais": "amochilar",
    "amochilam": "amochilar",
    "amochilamo": "amochilar",
    "amochilamos": "amochilar",
    "amochilando": "amochilar",
    "amochilara": "amochilar",
    "amochilaram": "amochilar",
    "amochilaras": "amochilar",
    "amochilarde": "amochilar",
    "amochilardes": "amochilar",
    "amochilare": "amochilar",
    "amochilarei": "amochilar",
    "amochilareis": "amochilar",
    "amochilarem": "amochilar",
    "amochilaremos": "amochilar",
    "amochilares": "amochilar",
    "amochilaria": "amochilar",
    "amochilariam": "amochilar",
    "amochilarias": "amochilar",
    "amochilarmo": "amochilar",
    "amochilarmos": "amochilar",
    "amochilará": "amochilar",
    "amochilarás": "amochilar",
    "amochilarão": "amochilar",
    "amochilaríamos": "amochilar",
    "amochilaríeis": "amochilar",
    "amochilas": "amochilar",
    "amochilasse": "amochilar",
    "amochilassem": "amochilar",
    "amochilasses": "amochilar",
    "amochilaste": "amochilar",
    "amochilastes": "amochilar",
    "amochilava": "amochilar",
    "amochilavam": "amochilar",
    "amochilavas": "amochilar",
    "amochile": "amochilar",
    "amochilei": "amochilar",
    "amochileis": "amochilar",
    "amochilem": "amochilar",
    "amochilemo": "amochilar",
    "amochilemos": "amochilar",
    "amochiles": "amochilar",
    "amochilo": "amochilar",
    "amochilou": "amochilar",
    "amochilá": "amochilar",
    "amochilámo": "amochilar",
    "amochilámos": "amochilar",
    "amochiláramo": "amochilar",
    "amochiláramos": "amochilar",
    "amochilárei": "amochilar",
    "amochiláreis": "amochilar",
    "amochilásseis": "amochilar",
    "amochilássemos": "amochilar",
    "amochilávamo": "amochilar",
    "amochilávamos": "amochilar",
    "amochilávei": "amochilar",
    "amochiláveis": "amochilar",
    "amocho": "amochar",
    "amochou": "amochar",
    "amochámo": "amochar",
    "amochámos": "amochar",
    "amocháramo": "amochar",
    "amocháramos": "amochar",
    "amocháreis": "amochar",
    "amochásseis": "amochar",
    "amochássemos": "amochar",
    "amochávamo": "amochar",
    "amochávamos": "amochar",
    "amocháveis": "amochar",
    "amoco": "amocar",
    "amocou": "amocar",
    "amocá": "amocar",
    "amocámo": "amocar",
    "amocámos": "amocar",
    "amocáramo": "amocar",
    "amocáramos": "amocar",
    "amocárei": "amocar",
    "amocáreis": "amocar",
    "amocásseis": "amocar",
    "amocássemos": "amocar",
    "amocávamo": "amocar",
    "amocávamos": "amocar",
    "amocávei": "amocar",
    "amocáveis": "amocar",
    "amoderna": "amodernar",
    "amodernada": "amodernar",
    "amodernadas": "amodernar",
    "amodernado": "amodernar",
    "amodernados": "amodernar",
    "amodernai": "amodernar",
    "amodernais": "amodernar",
    "amodernam": "amodernar",
    "amodernamo": "amodernar",
    "amodernamos": "amodernar",
    "amodernando": "amodernar",
    "amodernara": "amodernar",
    "amodernaram": "amodernar",
    "amodernaras": "amodernar",
    "amodernarde": "amodernar",
    "amodernardes": "amodernar",
    "amodernare": "amodernar",
    "amodernarei": "amodernar",
    "amodernareis": "amodernar",
    "amodernarem": "amodernar",
    "amodernaremos": "amodernar",
    "amodernares": "amodernar",
    "amodernaria": "amodernar",
    "amodernariam": "amodernar",
    "amodernarias": "amodernar",
    "amodernarmo": "amodernar",
    "amodernarmos": "amodernar",
    "amodernará": "amodernar",
    "amodernarás": "amodernar",
    "amodernarão": "amodernar",
    "amodernaríamos": "amodernar",
    "amodernaríeis": "amodernar",
    "amodernas": "amodernar",
    "amodernasse": "amodernar",
    "amodernassem": "amodernar",
    "amodernasses": "amodernar",
    "amodernaste": "amodernar",
    "amodernastes": "amodernar",
    "amodernava": "amodernar",
    "amodernavam": "amodernar",
    "amodernavas": "amodernar",
    "amoderne": "amodernar",
    "amodernei": "amodernar",
    "amoderneis": "amodernar",
    "amodernem": "amodernar",
    "amodernemo": "amodernar",
    "amodernemos": "amodernar",
    "amodernes": "amodernar",
    "amoderno": "amodernar",
    "amodernou": "amodernar",
    "amoderná": "amodernar",
    "amodernámo": "amodernar",
    "amodernámos": "amodernar",
    "amodernáramo": "amodernar",
    "amodernáramos": "amodernar",
    "amodernárei": "amodernar",
    "amodernáreis": "amodernar",
    "amodernásseis": "amodernar",
    "amodernássemos": "amodernar",
    "amodernávamo": "amodernar",
    "amodernávamos": "amodernar",
    "amodernávei": "amodernar",
    "amodernáveis": "amodernar",
    "amoditídea": "amoditídeo",
    "amoditídeas": "amoditídeo",
    "amoditídeos": "amoditídeo",
    "amodorra": "amodorrar",
    "amodorrada": "amodorrar",
    "amodorradas": "amodorrar",
    "amodorrado": "amodorrar",
    "amodorrados": "amodorrar",
    "amodorrai": "amodorrar",
    "amodorrais": "amodorrar",
    "amodorram": "amodorrar",
    "amodorramo": "amodorrar",
    "amodorramos": "amodorrar",
    "amodorrando": "amodorrar",
    "amodorrara": "amodorrar",
    "amodorraram": "amodorrar",
    "amodorraras": "amodorrar",
    "amodorrarde": "amodorrar",
    "amodorrardes": "amodorrar",
    "amodorrare": "amodorrar",
    "amodorrarei": "amodorrar",
    "amodorrareis": "amodorrar",
    "amodorrarem": "amodorrar",
    "amodorraremos": "amodorrar",
    "amodorrares": "amodorrar",
    "amodorraria": "amodorrar",
    "amodorrariam": "amodorrar",
    "amodorrarias": "amodorrar",
    "amodorrarmo": "amodorrar",
    "amodorrarmos": "amodorrar",
    "amodorrará": "amodorrar",
    "amodorrarás": "amodorrar",
    "amodorrarão": "amodorrar",
    "amodorraríamos": "amodorrar",
    "amodorraríeis": "amodorrar",
    "amodorras": "amodorrar",
    "amodorrasse": "amodorrar",
    "amodorrassem": "amodorrar",
    "amodorrasses": "amodorrar",
    "amodorraste": "amodorrar",
    "amodorrastes": "amodorrar",
    "amodorrava": "amodorrar",
    "amodorravam": "amodorrar",
    "amodorravas": "amodorrar",
    "amodorre": "amodorrar",
    "amodorrei": "amodorrar",
    "amodorreis": "amodorrar",
    "amodorrem": "amodorrar",
    "amodorremo": "amodorrar",
    "amodorremos": "amodorrar",
    "amodorres": "amodorrar",
    "amodorro": "amodorrar",
    "amodorrou": "amodorrar",
    "amodorrá": "amodorrar",
    "amodorrámo": "amodorrar",
    "amodorrámos": "amodorrar",
    "amodorráramo": "amodorrar",
    "amodorráramos": "amodorrar",
    "amodorrárei": "amodorrar",
    "amodorráreis": "amodorrar",
    "amodorrásseis": "amodorrar",
    "amodorrássemos": "amodorrar",
    "amodorrávamo": "amodorrar",
    "amodorrávamos": "amodorrar",
    "amodorrávei": "amodorrar",
    "amodorráveis": "amodorrar",
    "amodítidas": "amodítida",
    "amoeda": "amoedar",
    "amoedada": "amoedar",
    "amoedadas": "amoedar",
    "amoedado": "amoedar",
    "amoedados": "amoedar",
    "amoedai": "amoedar",
    "amoedais": "amoedar",
    "amoedam": "amoedar",
    "amoedamo": "amoedar",
    "amoedamos": "amoedar",
    "amoedando": "amoedar",
    "amoedara": "amoedar",
    "amoedaram": "amoedar",
    "amoedaras": "amoedar",
    "amoedarde": "amoedar",
    "amoedardes": "amoedar",
    "amoedare": "amoedar",
    "amoedarei": "amoedar",
    "amoedareis": "amoedar",
    "amoedarem": "amoedar",
    "amoedaremos": "amoedar",
    "amoedares": "amoedar",
    "amoedaria": "amoedar",
    "amoedariam": "amoedar",
    "amoedarias": "amoedar",
    "amoedarmo": "amoedar",
    "amoedarmos": "amoedar",
    "amoedará": "amoedar",
    "amoedarás": "amoedar",
    "amoedarão": "amoedar",
    "amoedaríamos": "amoedar",
    "amoedaríeis": "amoedar",
    "amoedas": "amoedar",
    "amoedasse": "amoedar",
    "amoedassem": "amoedar",
    "amoedasses": "amoedar",
    "amoedaste": "amoedar",
    "amoedastes": "amoedar",
    "amoedava": "amoedar",
    "amoedavam": "amoedar",
    "amoedavas": "amoedar",
    "amoedações": "amoedação",
    "amoede": "amoedar",
    "amoedei": "amoedar",
    "amoedeis": "amoedar",
    "amoedem": "amoedar",
    "amoedemo": "amoedar",
    "amoedemos": "amoedar",
    "amoedes": "amoedar",
    "amoedo": "amoedar",
    "amoedou": "amoedar",
    "amoedá": "amoedar",
    "amoedámo": "amoedar",
    "amoedámos": "amoedar",
    "amoedáramo": "amoedar",
    "amoedáramos": "amoedar",
    "amoedárei": "amoedar",
    "amoedáreis": "amoedar",
    "amoedásseis": "amoedar",
    "amoedássemos": "amoedar",
    "amoedávamo": "amoedar",
    "amoedávamos": "amoedar",
    "amoedávei": "amoedar",
    "amoedáveis": "amoedável",
    "amofina": "amofinar",
    "amofinada": "amofinar",
    "amofinadas": "amofinar",
    "amofinado": "amofinar",
    "amofinadora": "amofinador",
    "amofinadoras": "amofinador",
    "amofinadores": "amofinador",
    "amofinados": "amofinar",
    "amofinadíssima": "amofinado",
    "amofinadíssimas": "amofinado",
    "amofinadíssimo": "amofinado",
    "amofinadíssimos": "amofinado",
    "amofinai": "amofinar",
    "amofinais": "amofinar",
    "amofinam": "amofinar",
    "amofinamo": "amofinar",
    "amofinamos": "amofinar",
    "amofinando": "amofinar",
    "amofinara": "amofinar",
    "amofinaram": "amofinar",
    "amofinaras": "amofinar",
    "amofinarde": "amofinar",
    "amofinardes": "amofinar",
    "amofinare": "amofinar",
    "amofinarei": "amofinar",
    "amofinareis": "amofinar",
    "amofinarem": "amofinar",
    "amofinaremos": "amofinar",
    "amofinares": "amofinar",
    "amofinaria": "amofinar",
    "amofinariam": "amofinar",
    "amofinarias": "amofinar",
    "amofinarmo": "amofinar",
    "amofinarmos": "amofinar",
    "amofinará": "amofinar",
    "amofinarás": "amofinar",
    "amofinarão": "amofinar",
    "amofinaríamos": "amofinar",
    "amofinaríeis": "amofinar",
    "amofinas": "amofinar",
    "amofinasse": "amofinar",
    "amofinassem": "amofinar",
    "amofinasses": "amofinar",
    "amofinaste": "amofinar",
    "amofinastes": "amofinar",
    "amofinativa": "amofinativo",
    "amofinativas": "amofinativo",
    "amofinativos": "amofinativo",
    "amofinava": "amofinar",
    "amofinavam": "amofinar",
    "amofinavas": "amofinar",
    "amofinações": "amofinação",
    "amofine": "amofinar",
    "amofinei": "amofinar",
    "amofineis": "amofinar",
    "amofinem": "amofinar",
    "amofinemo": "amofinar",
    "amofinemos": "amofinar",
    "amofines": "amofinar",
    "amofino": "amofinar",
    "amofinou": "amofinar",
    "amofiná": "amofinar",
    "amofinámo": "amofinar",
    "amofinámos": "amofinar",
    "amofináramo": "amofinar",
    "amofináramos": "amofinar",
    "amofinárei": "amofinar",
    "amofináreis": "amofinar",
    "amofinásseis": "amofinar",
    "amofinássemos": "amofinar",
    "amofinávamo": "amofinar",
    "amofinávamos": "amofinar",
    "amofinávei": "amofinar",
    "amofináveis": "amofinar",
    "amoina": "amoinar",
    "amoinada": "amoinar",
    "amoinadas": "amoinar",
    "amoinado": "amoinar",
    "amoinados": "amoinar",
    "amoinai": "amoinar",
    "amoinais": "amoinar",
    "amoinam": "amoinar",
    "amoinamo": "amoinar",
    "amoinamos": "amoinar",
    "amoinando": "amoinar",
    "amoinara": "amoinar",
    "amoinaram": "amoinar",
    "amoinaras": "amoinar",
    "amoinardes": "amoinar",
    "amoinarei": "amoinar",
    "amoinareis": "amoinar",
    "amoinarem": "amoinar",
    "amoinaremos": "amoinar",
    "amoinares": "amoinar",
    "amoinaria": "amoinar",
    "amoinariam": "amoinar",
    "amoinarias": "amoinar",
    "amoinarmo": "amoinar",
    "amoinarmos": "amoinar",
    "amoinará": "amoinar",
    "amoinarás": "amoinar",
    "amoinarão": "amoinar",
    "amoinaríamos": "amoinar",
    "amoinaríeis": "amoinar",
    "amoinas": "amoinar",
    "amoinasse": "amoinar",
    "amoinassem": "amoinar",
    "amoinasses": "amoinar",
    "amoinaste": "amoinar",
    "amoinastes": "amoinar",
    "amoinava": "amoinar",
    "amoinavam": "amoinar",
    "amoinavas": "amoinar",
    "amoine": "amoinar",
    "amoinei": "amoinar",
    "amoineis": "amoinar",
    "amoinem": "amoinar",
    "amoinemo": "amoinar",
    "amoinemos": "amoinar",
    "amoines": "amoinar",
    "amoino": "amoinar",
    "amoinou": "amoinar",
    "amoinámo": "amoinar",
    "amoinámos": "amoinar",
    "amoináramo": "amoinar",
    "amoináramos": "amoinar",
    "amoináreis": "amoinar",
    "amoinásseis": "amoinar",
    "amoinássemos": "amoinar",
    "amoinávamo": "amoinar",
    "amoinávamos": "amoinar",
    "amoináveis": "amoinar",
    "amoira": "amoirar",
    "amoirada": "amoirar",
    "amoiradas": "amoirar",
    "amoirado": "amoirar",
    "amoirados": "amoirar",
    "amoirai": "amoirar",
    "amoirais": "amoirar",
    "amoiram": "amoirar",
    "amoiramo": "amoirar",
    "amoiramos": "amoirar",
    "amoirando": "amoirar",
    "amoirara": "amoirar",
    "amoiraram": "amoirar",
    "amoiraras": "amoirar",
    "amoirarde": "amoirar",
    "amoirardes": "amoirar",
    "amoirare": "amoirar",
    "amoirarei": "amoirar",
    "amoirareis": "amoirar",
    "amoirarem": "amoirar",
    "amoiraremos": "amoirar",
    "amoirares": "amoirar",
    "amoiraria": "amoirar",
    "amoirariam": "amoirar",
    "amoirarias": "amoirar",
    "amoirarmo": "amoirar",
    "amoirarmos": "amoirar",
    "amoirará": "amoirar",
    "amoirarás": "amoirar",
    "amoirarão": "amoirar",
    "amoiraríamos": "amoirar",
    "amoiraríeis": "amoirar",
    "amoiras": "amoirar",
    "amoirasse": "amoirar",
    "amoirassem": "amoirar",
    "amoirasses": "amoirar",
    "amoiraste": "amoirar",
    "amoirastes": "amoirar",
    "amoirava": "amoirar",
    "amoiravam": "amoirar",
    "amoiravas": "amoirar",
    "amoire": "amoirar",
    "amoirei": "amoirar",
    "amoireis": "amoirar",
    "amoirem": "amoirar",
    "amoiremo": "amoirar",
    "amoiremos": "amoirar",
    "amoires": "amoirar",
    "amoirisca": "amoiriscar",
    "amoiriscada": "amoiriscar",
    "amoiriscadas": "amoiriscar",
    "amoiriscado": "amoiriscar",
    "amoiriscados": "amoiriscar",
    "amoiriscai": "amoiriscar",
    "amoiriscais": "amoiriscar",
    "amoiriscam": "amoiriscar",
    "amoiriscamo": "amoiriscar",
    "amoiriscamos": "amoiriscar",
    "amoiriscando": "amoiriscar",
    "amoiriscara": "amoiriscar",
    "amoiriscaram": "amoiriscar",
    "amoiriscaras": "amoiriscar",
    "amoiriscarde": "amoiriscar",
    "amoiriscardes": "amoiriscar",
    "amoiriscare": "amoiriscar",
    "amoiriscarei": "amoiriscar",
    "amoiriscareis": "amoiriscar",
    "amoiriscarem": "amoiriscar",
    "amoiriscaremos": "amoiriscar",
    "amoiriscares": "amoiriscar",
    "amoiriscaria": "amoiriscar",
    "amoiriscariam": "amoiriscar",
    "amoiriscarias": "amoiriscar",
    "amoiriscarmo": "amoiriscar",
    "amoiriscarmos": "amoiriscar",
    "amoiriscará": "amoiriscar",
    "amoiriscarás": "amoiriscar",
    "amoiriscarão": "amoiriscar",
    "amoiriscaríamos": "amoiriscar",
    "amoiriscaríeis": "amoiriscar",
    "amoiriscas": "amoiriscar",
    "amoiriscasse": "amoiriscar",
    "amoiriscassem": "amoiriscar",
    "amoiriscasses": "amoiriscar",
    "amoiriscaste": "amoiriscar",
    "amoiriscastes": "amoiriscar",
    "amoiriscava": "amoiriscar",
    "amoiriscavam": "amoiriscar",
    "amoiriscavas": "amoiriscar",
    "amoirisco": "amoiriscar",
    "amoiriscou": "amoiriscar",
    "amoiriscá": "amoiriscar",
    "amoiriscámo": "amoiriscar",
    "amoiriscámos": "amoiriscar",
    "amoiriscáramo": "amoiriscar",
    "amoiriscáramos": "amoiriscar",
    "amoiriscárei": "amoiriscar",
    "amoiriscáreis": "amoiriscar",
    "amoiriscásseis": "amoiriscar",
    "amoiriscássemos": "amoiriscar",
    "amoiriscávamo": "amoiriscar",
    "amoiriscávamos": "amoiriscar",
    "amoiriscávei": "amoiriscar",
    "amoiriscáveis": "amoiriscar",
    "amoirisque": "amoiriscar",
    "amoirisquei": "amoiriscar",
    "amoirisqueis": "amoiriscar",
    "amoirisquem": "amoiriscar",
    "amoirisquemo": "amoiriscar",
    "amoirisquemos": "amoiriscar",
    "amoirisques": "amoiriscar",
    "amoiro": "amoirar",
    "amoirou": "amoirar",
    "amoirá": "amoirar",
    "amoirámo": "amoirar",
    "amoirámos": "amoirar",
    "amoiráramo": "amoirar",
    "amoiráramos": "amoirar",
    "amoirárei": "amoirar",
    "amoiráreis": "amoirar",
    "amoirásseis": "amoirar",
    "amoirássemos": "amoirar",
    "amoirávamo": "amoirar",
    "amoirávamos": "amoirar",
    "amoirávei": "amoirar",
    "amoiráveis": "amoirar",
    "amoita": "amoitar",
    "amoitada": "amoitar",
    "amoitadas": "amoitar",
    "amoitado": "amoitar",
    "amoitados": "amoitar",
    "amoitai": "amoitar",
    "amoitais": "amoitar",
    "amoitam": "amoitar",
    "amoitamo": "amoitar",
    "amoitamos": "amoitar",
    "amoitando": "amoitar",
    "amoitara": "amoitar",
    "amoitaram": "amoitar",
    "amoitaras": "amoitar",
    "amoitarde": "amoitar",
    "amoitardes": "amoitar",
    "amoitare": "amoitar",
    "amoitarei": "amoitar",
    "amoitareis": "amoitar",
    "amoitarem": "amoitar",
    "amoitaremos": "amoitar",
    "amoitares": "amoitar",
    "amoitaria": "amoitar",
    "amoitariam": "amoitar",
    "amoitarias": "amoitar",
    "amoitarmo": "amoitar",
    "amoitarmos": "amoitar",
    "amoitará": "amoitar",
    "amoitarás": "amoitar",
    "amoitarão": "amoitar",
    "amoitaríamos": "amoitar",
    "amoitaríeis": "amoitar",
    "amoitas": "amoitar",
    "amoitasse": "amoitar",
    "amoitassem": "amoitar",
    "amoitasses": "amoitar",
    "amoitaste": "amoitar",
    "amoitastes": "amoitar",
    "amoitava": "amoitar",
    "amoitavam": "amoitar",
    "amoitavas": "amoitar",
    "amoite": "amoitar",
    "amoitei": "amoitar",
    "amoiteis": "amoitar",
    "amoitem": "amoitar",
    "amoitemo": "amoitar",
    "amoitemos": "amoitar",
    "amoites": "amoitar",
    "amoito": "amoitar",
    "amoitou": "amoitar",
    "amoitá": "amoitar",
    "amoitámo": "amoitar",
    "amoitámos": "amoitar",
    "amoitáramo": "amoitar",
    "amoitáramos": "amoitar",
    "amoitárei": "amoitar",
    "amoitáreis": "amoitar",
    "amoitásseis": "amoitar",
    "amoitássemos": "amoitar",
    "amoitávamo": "amoitar",
    "amoitávamos": "amoitar",
    "amoitávei": "amoitar",
    "amoitáveis": "amoitar",
    "amoja": "amojar",
    "amojada": "amojar",
    "amojadas": "amojar",
    "amojado": "amojar",
    "amojados": "amojar",
    "amojai": "amojar",
    "amojais": "amojar",
    "amojam": "amojar",
    "amojamo": "amojar",
    "amojamos": "amojar",
    "amojando": "amojar",
    "amojara": "amojar",
    "amojaram": "amojar",
    "amojaras": "amojar",
    "amojarde": "amojar",
    "amojardes": "amojar",
    "amojare": "amojar",
    "amojarei": "amojar",
    "amojareis": "amojar",
    "amojarem": "amojar",
    "amojaremos": "amojar",
    "amojares": "amojar",
    "amojaria": "amojar",
    "amojariam": "amojar",
    "amojarias": "amojar",
    "amojarmo": "amojar",
    "amojarmos": "amojar",
    "amojará": "amojar",
    "amojarás": "amojar",
    "amojarão": "amojar",
    "amojaríamos": "amojar",
    "amojaríeis": "amojar",
    "amojas": "amojar",
    "amojasse": "amojar",
    "amojassem": "amojar",
    "amojasses": "amojar",
    "amojaste": "amojar",
    "amojastes": "amojar",
    "amojava": "amojar",
    "amojavam": "amojar",
    "amojavas": "amojar",
    "amoje": "amojar",
    "amojei": "amojar",
    "amojeis": "amojar",
    "amojem": "amojar",
    "amojemo": "amojar",
    "amojemos": "amojar",
    "amojes": "amojar",
    "amojo": "amojar",
    "amojos": "amojo",
    "amojou": "amojar",
    "amojuda": "amojudo",
    "amojudas": "amojudo",
    "amojudos": "amojudo",
    "amojá": "amojar",
    "amojámo": "amojar",
    "amojámos": "amojar",
    "amojáramo": "amojar",
    "amojáramos": "amojar",
    "amojárei": "amojar",
    "amojáreis": "amojar",
    "amojásseis": "amojar",
    "amojássemos": "amojar",
    "amojávamo": "amojar",
    "amojávamos": "amojar",
    "amojávei": "amojar",
    "amojáveis": "amojar",
    "amola": "amolar",
    "amolada": "amolar",
    "amoladas": "amolar",
    "amoladeira": "amoladeiro",
    "amoladeiras": "amoladeiro",
    "amoladeiros": "amoladeiro",
    "amoladelas": "amoladela",
    "amolado": "amolar",
    "amoladora": "amolador",
    "amoladoras": "amolador",
    "amoladores": "amolador",
    "amolados": "amolar",
    "amoladuras": "amoladura",
    "amolai": "amolar",
    "amolais": "amolar",
    "amolam": "amolar",
    "amolamo": "amolar",
    "amolamos": "amolar",
    "amolanca": "amolancar",
    "amolancada": "amolancar",
    "amolancadas": "amolancar",
    "amolancado": "amolancar",
    "amolancados": "amolancar",
    "amolancai": "amolancar",
    "amolancais": "amolancar",
    "amolancam": "amolancar",
    "amolancamo": "amolancar",
    "amolancamos": "amolancar",
    "amolancando": "amolancar",
    "amolancara": "amolancar",
    "amolancaram": "amolancar",
    "amolancaras": "amolancar",
    "amolancarde": "amolancar",
    "amolancardes": "amolancar",
    "amolancare": "amolancar",
    "amolancarei": "amolancar",
    "amolancareis": "amolancar",
    "amolancarem": "amolancar",
    "amolancaremos": "amolancar",
    "amolancares": "amolancar",
    "amolancaria": "amolancar",
    "amolancariam": "amolancar",
    "amolancarias": "amolancar",
    "amolancarmo": "amolancar",
    "amolancarmos": "amolancar",
    "amolancará": "amolancar",
    "amolancarás": "amolancar",
    "amolancarão": "amolancar",
    "amolancaríamos": "amolancar",
    "amolancaríeis": "amolancar",
    "amolancas": "amolancar",
    "amolancasse": "amolancar",
    "amolancassem": "amolancar",
    "amolancasses": "amolancar",
    "amolancaste": "amolancar",
    "amolancastes": "amolancar",
    "amolancava": "amolancar",
    "amolancavam": "amolancar",
    "amolancavas": "amolancar",
    "amolanco": "amolancar",
    "amolancou": "amolancar",
    "amolancá": "amolancar",
    "amolancámo": "amolancar",
    "amolancámos": "amolancar",
    "amolancáramo": "amolancar",
    "amolancáramos": "amolancar",
    "amolancárei": "amolancar",
    "amolancáreis": "amolancar",
    "amolancásseis": "amolancar",
    "amolancássemos": "amolancar",
    "amolancávamo": "amolancar",
    "amolancávamos": "amolancar",
    "amolancávei": "amolancar",
    "amolancáveis": "amolancar",
    "amolando": "amolar",
    "amolanque": "amolancar",
    "amolanquei": "amolancar",
    "amolanqueis": "amolancar",
    "amolanquem": "amolancar",
    "amolanquemo": "amolancar",
    "amolanquemos": "amolancar",
    "amolanques": "amolancar",
    "amolara": "amolar",
    "amolaram": "amolar",
    "amolaras": "amolar",
    "amolarde": "amolar",
    "amolardes": "amolar",
    "amolare": "amolar",
    "amolarei": "amolar",
    "amolareis": "amolar",
    "amolarem": "amolar",
    "amolaremos": "amolar",
    "amolares": "amolar",
    "amolaria": "amolar",
    "amolariam": "amolar",
    "amolarias": "amolar",
    "amolarmo": "amolar",
    "amolarmos": "amolar",
    "amolará": "amolar",
    "amolarás": "amolar",
    "amolarão": "amolar",
    "amolaríamos": "amolar",
    "amolaríeis": "amolar",
    "amolas": "amolar",
    "amolasse": "amolar",
    "amolassem": "amolar",
    "amolasses": "amolar",
    "amolaste": "amolar",
    "amolastes": "amolar",
    "amolava": "amolar",
    "amolavam": "amolar",
    "amolavas": "amolar",
    "amolaxa": "amolaxar",
    "amolaxada": "amolaxar",
    "amolaxadas": "amolaxar",
    "amolaxado": "amolaxar",
    "amolaxados": "amolaxar",
    "amolaxai": "amolaxar",
    "amolaxais": "amolaxar",
    "amolaxam": "amolaxar",
    "amolaxamo": "amolaxar",
    "amolaxamos": "amolaxar",
    "amolaxando": "amolaxar",
    "amolaxara": "amolaxar",
    "amolaxaram": "amolaxar",
    "amolaxaras": "amolaxar",
    "amolaxarde": "amolaxar",
    "amolaxardes": "amolaxar",
    "amolaxare": "amolaxar",
    "amolaxarei": "amolaxar",
    "amolaxareis": "amolaxar",
    "amolaxarem": "amolaxar",
    "amolaxaremos": "amolaxar",
    "amolaxares": "amolaxar",
    "amolaxaria": "amolaxar",
    "amolaxariam": "amolaxar",
    "amolaxarias": "amolaxar",
    "amolaxarmo": "amolaxar",
    "amolaxarmos": "amolaxar",
    "amolaxará": "amolaxar",
    "amolaxarás": "amolaxar",
    "amolaxarão": "amolaxar",
    "amolaxaríamos": "amolaxar",
    "amolaxaríeis": "amolaxar",
    "amolaxas": "amolaxar",
    "amolaxasse": "amolaxar",
    "amolaxassem": "amolaxar",
    "amolaxasses": "amolaxar",
    "amolaxaste": "amolaxar",
    "amolaxastes": "amolaxar",
    "amolaxava": "amolaxar",
    "amolaxavam": "amolaxar",
    "amolaxavas": "amolaxar",
    "amolaxe": "amolaxar",
    "amolaxei": "amolaxar",
    "amolaxeis": "amolaxar",
    "amolaxem": "amolaxar",
    "amolaxemo": "amolaxar",
    "amolaxemos": "amolaxar",
    "amolaxes": "amolaxar",
    "amolaxo": "amolaxar",
    "amolaxou": "amolaxar",
    "amolaxá": "amolaxar",
    "amolaxámo": "amolaxar",
    "amolaxámos": "amolaxar",
    "amolaxáramo": "amolaxar",
    "amolaxáramos": "amolaxar",
    "amolaxárei": "amolaxar",
    "amolaxáreis": "amolaxar",
    "amolaxásseis": "amolaxar",
    "amolaxássemos": "amolaxar",
    "amolaxávamo": "amolaxar",
    "amolaxávamos": "amolaxar",
    "amolaxávei": "amolaxar",
    "amolaxáveis": "amolaxar",
    "amolações": "amolação",
    "amolda": "amoldar",
    "amoldada": "amoldar",
    "amoldadas": "amoldar",
    "amoldado": "amoldar",
    "amoldados": "amoldar",
    "amoldai": "amoldar",
    "amoldais": "amoldar",
    "amoldam": "amoldar",
    "amoldamo": "amoldar",
    "amoldamos": "amoldar",
    "amoldando": "amoldar",
    "amoldara": "amoldar",
    "amoldaram": "amoldar",
    "amoldaras": "amoldar",
    "amoldarde": "amoldar",
    "amoldardes": "amoldar",
    "amoldare": "amoldar",
    "amoldarei": "amoldar",
    "amoldareis": "amoldar",
    "amoldarem": "amoldar",
    "amoldaremos": "amoldar",
    "amoldares": "amoldar",
    "amoldaria": "amoldar",
    "amoldariam": "amoldar",
    "amoldarias": "amoldar",
    "amoldarmo": "amoldar",
    "amoldarmos": "amoldar",
    "amoldará": "amoldar",
    "amoldarás": "amoldar",
    "amoldarão": "amoldar",
    "amoldaríamos": "amoldar",
    "amoldaríeis": "amoldar",
    "amoldas": "amoldar",
    "amoldasse": "amoldar",
    "amoldassem": "amoldar",
    "amoldasses": "amoldar",
    "amoldaste": "amoldar",
    "amoldastes": "amoldar",
    "amoldava": "amoldar",
    "amoldavam": "amoldar",
    "amoldavas": "amoldar",
    "amolde": "amoldar",
    "amoldei": "amoldar",
    "amoldeis": "amoldar",
    "amoldem": "amoldar",
    "amoldemo": "amoldar",
    "amoldemos": "amoldar",
    "amoldes": "amoldar",
    "amoldo": "amoldar",
    "amoldou": "amoldar",
    "amoldura": "amoldurar",
    "amoldurada": "amoldurar",
    "amolduradas": "amoldurar",
    "amoldurado": "amoldurar",
    "amoldurados": "amoldurar",
    "amoldurai": "amoldurar",
    "amoldurais": "amoldurar",
    "amolduram": "amoldurar",
    "amolduramo": "amoldurar",
    "amolduramos": "amoldurar",
    "amoldurando": "amoldurar",
    "amoldurara": "amoldurar",
    "amolduraram": "amoldurar",
    "amolduraras": "amoldurar",
    "amoldurarde": "amoldurar",
    "amoldurardes": "amoldurar",
    "amoldurare": "amoldurar",
    "amoldurarei": "amoldurar",
    "amoldurareis": "amoldurar",
    "amoldurarem": "amoldurar",
    "amolduraremos": "amoldurar",
    "amoldurares": "amoldurar",
    "amolduraria": "amoldurar",
    "amoldurariam": "amoldurar",
    "amoldurarias": "amoldurar",
    "amoldurarmo": "amoldurar",
    "amoldurarmos": "amoldurar",
    "amoldurará": "amoldurar",
    "amoldurarás": "amoldurar",
    "amoldurarão": "amoldurar",
    "amolduraríamos": "amoldurar",
    "amolduraríeis": "amoldurar",
    "amolduras": "amoldurar",
    "amoldurasse": "amoldurar",
    "amoldurassem": "amoldurar",
    "amoldurasses": "amoldurar",
    "amolduraste": "amoldurar",
    "amoldurastes": "amoldurar",
    "amoldurava": "amoldurar",
    "amolduravam": "amoldurar",
    "amolduravas": "amoldurar",
    "amoldure": "amoldurar",
    "amoldurei": "amoldurar",
    "amoldureis": "amoldurar",
    "amoldurem": "amoldurar",
    "amolduremo": "amoldurar",
    "amolduremos": "amoldurar",
    "amoldures": "amoldurar",
    "amolduro": "amoldurar",
    "amoldurou": "amoldurar",
    "amoldurá": "amoldurar",
    "amoldurámo": "amoldurar",
    "amoldurámos": "amoldurar",
    "amolduráramo": "amoldurar",
    "amolduráramos": "amoldurar",
    "amoldurárei": "amoldurar",
    "amolduráreis": "amoldurar",
    "amoldurásseis": "amoldurar",
    "amoldurássemos": "amoldurar",
    "amoldurávamo": "amoldurar",
    "amoldurávamos": "amoldurar",
    "amoldurávei": "amoldurar",
    "amolduráveis": "amoldurar",
    "amoldá": "amoldar",
    "amoldámo": "amoldar",
    "amoldámos": "amoldar",
    "amoldáramo": "amoldar",
    "amoldáramos": "amoldar",
    "amoldárei": "amoldar",
    "amoldáreis": "amoldar",
    "amoldásseis": "amoldar",
    "amoldássemos": "amoldar",
    "amoldávamo": "amoldar",
    "amoldávamos": "amoldar",
    "amoldávei": "amoldar",
    "amoldáveis": "amoldável",
    "amole": "amolar",
    "amoleca": "amolecar",
    "amolecada": "amolecar",
    "amolecadas": "amolecar",
    "amolecado": "amolecar",
    "amolecados": "amolecar",
    "amolecai": "amolecar",
    "amolecais": "amolecar",
    "amolecam": "amolecar",
    "amolecamo": "amolecar",
    "amolecamos": "amolecar",
    "amolecando": "amolecar",
    "amolecara": "amolecar",
    "amolecaram": "amolecar",
    "amolecaras": "amolecar",
    "amolecarde": "amolecar",
    "amolecardes": "amolecar",
    "amolecare": "amolecar",
    "amolecarei": "amolecar",
    "amolecareis": "amolecar",
    "amolecarem": "amolecar",
    "amolecaremos": "amolecar",
    "amolecares": "amolecar",
    "amolecaria": "amolecar",
    "amolecariam": "amolecar",
    "amolecarias": "amolecar",
    "amolecarmo": "amolecar",
    "amolecarmos": "amolecar",
    "amolecará": "amolecar",
    "amolecarás": "amolecar",
    "amolecarão": "amolecar",
    "amolecaríamos": "amolecar",
    "amolecaríeis": "amolecar",
    "amolecas": "amolecar",
    "amolecasse": "amolecar",
    "amolecassem": "amolecar",
    "amolecasses": "amolecar",
    "amolecaste": "amolecar",
    "amolecastes": "amolecar",
    "amolecava": "amolecar",
    "amolecavam": "amolecar",
    "amolecavas": "amolecar",
    "amolece": "amolecer",
    "amolecedora": "amolecedor",
    "amolecedoras": "amolecedor",
    "amolecedores": "amolecedor",
    "amolecei": "amolecer",
    "amoleceis": "amolecer",
    "amolecem": "amolecer",
    "amolecemo": "amolecer",
    "amolecemos": "amolecer",
    "amolecendo": "amolecer",
    "amolecera": "amolecer",
    "amoleceram": "amolecer",
    "amoleceras": "amolecer",
    "amolecerde": "amolecer",
    "amolecerdes": "amolecer",
    "amolecere": "amolecer",
    "amolecerei": "amolecer",
    "amolecereis": "amolecer",
    "amolecerem": "amolecer",
    "amoleceremos": "amolecer",
    "amoleceres": "amolecer",
    "amoleceria": "amolecer",
    "amoleceriam": "amolecer",
    "amolecerias": "amolecer",
    "amolecermo": "amolecer",
    "amolecermos": "amolecer",
    "amolecerá": "amolecer",
    "amolecerás": "amolecer",
    "amolecerão": "amolecer",
    "amoleceríamos": "amolecer",
    "amoleceríeis": "amolecer",
    "amoleces": "amolecer",
    "amolecesse": "amolecer",
    "amolecessem": "amolecer",
    "amolecesses": "amolecer",
    "amoleceste": "amolecer",
    "amolecestes": "amolecer",
    "amoleceu": "amolecer",
    "amoleci": "amolecer",
    "amolecia": "amolecer",
    "amoleciam": "amolecer",
    "amolecias": "amolecer",
    "amolecida": "amolecido",
    "amolecidas": "amolecido",
    "amolecido": "amolecer",
    "amolecidos": "amolecido",
    "amolecidíssima": "amolecido",
    "amolecidíssimas": "amolecido",
    "amolecidíssimo": "amolecido",
    "amolecidíssimos": "amolecido",
    "amolecimentos": "amolecimento",
    "amoleco": "amolecar",
    "amolecou": "amolecar",
    "amolecá": "amolecar",
    "amolecámo": "amolecar",
    "amolecámos": "amolecar",
    "amolecáramo": "amolecar",
    "amolecáramos": "amolecar",
    "amolecárei": "amolecar",
    "amolecáreis": "amolecar",
    "amolecásseis": "amolecar",
    "amolecássemos": "amolecar",
    "amolecávamo": "amolecar",
    "amolecávamos": "amolecar",
    "amolecávei": "amolecar",
    "amolecáveis": "amolecar",
    "amolecê": "amolecer",
    "amolecêramo": "amolecer",
    "amolecêramos": "amolecer",
    "amolecêrei": "amolecer",
    "amolecêreis": "amolecer",
    "amolecêsseis": "amolecer",
    "amolecêssemos": "amolecer",
    "amolecíamo": "amolecer",
    "amolecíamos": "amolecer",
    "amolecíei": "amolecer",
    "amolecíeis": "amolecer",
    "amolega": "amolegar",
    "amolegada": "amolegar",
    "amolegadas": "amolegar",
    "amolegado": "amolegar",
    "amolegados": "amolegar",
    "amolegai": "amolegar",
    "amolegais": "amolegar",
    "amolegam": "amolegar",
    "amolegamo": "amolegar",
    "amolegamos": "amolegar",
    "amolegando": "amolegar",
    "amolegara": "amolegar",
    "amolegaram": "amolegar",
    "amolegaras": "amolegar",
    "amolegarde": "amolegar",
    "amolegardes": "amolegar",
    "amolegare": "amolegar",
    "amolegarei": "amolegar",
    "amolegareis": "amolegar",
    "amolegarem": "amolegar",
    "amolegaremos": "amolegar",
    "amolegares": "amolegar",
    "amolegaria": "amolegar",
    "amolegariam": "amolegar",
    "amolegarias": "amolegar",
    "amolegarmo": "amolegar",
    "amolegarmos": "amolegar",
    "amolegará": "amolegar",
    "amolegarás": "amolegar",
    "amolegarão": "amolegar",
    "amolegaríamos": "amolegar",
    "amolegaríeis": "amolegar",
    "amolegas": "amolegar",
    "amolegasse": "amolegar",
    "amolegassem": "amolegar",
    "amolegasses": "amolegar",
    "amolegaste": "amolegar",
    "amolegastes": "amolegar",
    "amolegava": "amolegar",
    "amolegavam": "amolegar",
    "amolegavas": "amolegar",
    "amolego": "amolegar",
    "amolegou": "amolegar",
    "amolegue": "amolegar",
    "amoleguei": "amolegar",
    "amolegueis": "amolegar",
    "amoleguem": "amolegar",
    "amoleguemo": "amolegar",
    "amoleguemos": "amolegar",
    "amolegues": "amolegar",
    "amolegá": "amolegar",
    "amolegámo": "amolegar",
    "amolegámos": "amolegar",
    "amolegáramo": "amolegar",
    "amolegáramos": "amolegar",
    "amolegárei": "amolegar",
    "amolegáreis": "amolegar",
    "amolegásseis": "amolegar",
    "amolegássemos": "amolegar",
    "amolegávamo": "amolegar",
    "amolegávamos": "amolegar",
    "amolegávei": "amolegar",
    "amolegáveis": "amolegar",
    "amolei": "amolar",
    "amoleis": "amolar",
    "amolem": "amolar",
    "amolemo": "amolar",
    "amolemos": "amolar",
    "amolenga": "amolengar",
    "amolengada": "amolengar",
    "amolengadas": "amolengar",
    "amolengado": "amolengar",
    "amolengados": "amolengar",
    "amolengai": "amolengar",
    "amolengais": "amolengar",
    "amolengam": "amolengar",
    "amolengamo": "amolengar",
    "amolengamos": "amolengar",
    "amolengando": "amolengar",
    "amolengara": "amolengar",
    "amolengaram": "amolengar",
    "amolengaras": "amolengar",
    "amolengarde": "amolengar",
    "amolengardes": "amolengar",
    "amolengare": "amolengar",
    "amolengarei": "amolengar",
    "amolengareis": "amolengar",
    "amolengarem": "amolengar",
    "amolengaremos": "amolengar",
    "amolengares": "amolengar",
    "amolengaria": "amolengar",
    "amolengariam": "amolengar",
    "amolengarias": "amolengar",
    "amolengarmo": "amolengar",
    "amolengarmos": "amolengar",
    "amolengará": "amolengar",
    "amolengarás": "amolengar",
    "amolengarão": "amolengar",
    "amolengaríamos": "amolengar",
    "amolengaríeis": "amolengar",
    "amolengas": "amolengar",
    "amolengasse": "amolengar",
    "amolengassem": "amolengar",
    "amolengasses": "amolengar",
    "amolengaste": "amolengar",
    "amolengastes": "amolengar",
    "amolengava": "amolengar",
    "amolengavam": "amolengar",
    "amolengavas": "amolengar",
    "amolengo": "amolengar",
    "amolengou": "amolengar",
    "amolengue": "amolengar",
    "amolenguei": "amolengar",
    "amolengueis": "amolengar",
    "amolenguem": "amolengar",
    "amolenguemo": "amolengar",
    "amolenguemos": "amolengar",
    "amolengues": "amolengar",
    "amolengá": "amolengar",
    "amolengámo": "amolengar",
    "amolengámos": "amolengar",
    "amolengáramo": "amolengar",
    "amolengáramos": "amolengar",
    "amolengárei": "amolengar",
    "amolengáreis": "amolengar",
    "amolengásseis": "amolengar",
    "amolengássemos": "amolengar",
    "amolengávamo": "amolengar",
    "amolengávamos": "amolengar",
    "amolengávei": "amolengar",
    "amolengáveis": "amolengar",
    "amolenta": "amolentar",
    "amolentada": "amolentar",
    "amolentadas": "amolentar",
    "amolentado": "amolentar",
    "amolentados": "amolentar",
    "amolentai": "amolentar",
    "amolentais": "amolentar",
    "amolentam": "amolentar",
    "amolentamo": "amolentar",
    "amolentamos": "amolentar",
    "amolentando": "amolentar",
    "amolentara": "amolentar",
    "amolentaram": "amolentar",
    "amolentaras": "amolentar",
    "amolentarde": "amolentar",
    "amolentardes": "amolentar",
    "amolentare": "amolentar",
    "amolentarei": "amolentar",
    "amolentareis": "amolentar",
    "amolentarem": "amolentar",
    "amolentaremos": "amolentar",
    "amolentares": "amolentar",
    "amolentaria": "amolentar",
    "amolentariam": "amolentar",
    "amolentarias": "amolentar",
    "amolentarmo": "amolentar",
    "amolentarmos": "amolentar",
    "amolentará": "amolentar",
    "amolentarás": "amolentar",
    "amolentarão": "amolentar",
    "amolentaríamos": "amolentar",
    "amolentaríeis": "amolentar",
    "amolentas": "amolentar",
    "amolentasse": "amolentar",
    "amolentassem": "amolentar",
    "amolentasses": "amolentar",
    "amolentaste": "amolentar",
    "amolentastes": "amolentar",
    "amolentava": "amolentar",
    "amolentavam": "amolentar",
    "amolentavas": "amolentar",
    "amolente": "amolentar",
    "amolentei": "amolentar",
    "amolenteis": "amolentar",
    "amolentem": "amolentar",
    "amolentemo": "amolentar",
    "amolentemos": "amolentar",
    "amolentes": "amolentar",
    "amolento": "amolentar",
    "amolentou": "amolentar",
    "amolentá": "amolentar",
    "amolentámo": "amolentar",
    "amolentámos": "amolentar",
    "amolentáramo": "amolentar",
    "amolentáramos": "amolentar",
    "amolentárei": "amolentar",
    "amolentáreis": "amolentar",
    "amolentásseis": "amolentar",
    "amolentássemos": "amolentar",
    "amolentávamo": "amolentar",
    "amolentávamos": "amolentar",
    "amolentávei": "amolentar",
    "amolentáveis": "amolentar",
    "amoleque": "amolecar",
    "amolequei": "amolecar",
    "amolequeis": "amolecar",
    "amolequem": "amolecar",
    "amolequemo": "amolecar",
    "amolequemos": "amolecar",
    "amoleques": "amolecar",
    "amoles": "amolar",
    "amoleça": "amolecer",
    "amoleçais": "amolecer",
    "amoleçam": "amolecer",
    "amoleçamo": "amolecer",
    "amoleçamos": "amolecer",
    "amoleças": "amolecer",
    "amoleço": "amolecer",
    "amolga": "amolgar",
    "amolgada": "amolgar",
    "amolgadas": "amolgar",
    "amolgadelas": "amolgadela",
    "amolgado": "amolgar",
    "amolgados": "amolgar",
    "amolgaduras": "amolgadura",
    "amolgadíssima": "amolgado",
    "amolgadíssimas": "amolgado",
    "amolgadíssimo": "amolgado",
    "amolgadíssimos": "amolgado",
    "amolgai": "amolgar",
    "amolgais": "amolgar",
    "amolgam": "amolgar",
    "amolgamentos": "amolgamento",
    "amolgamo": "amolgar",
    "amolgamos": "amolgar",
    "amolgando": "amolgar",
    "amolgara": "amolgar",
    "amolgaram": "amolgar",
    "amolgaras": "amolgar",
    "amolgarde": "amolgar",
    "amolgardes": "amolgar",
    "amolgare": "amolgar",
    "amolgarei": "amolgar",
    "amolgareis": "amolgar",
    "amolgarem": "amolgar",
    "amolgaremos": "amolgar",
    "amolgares": "amolgar",
    "amolgaria": "amolgar",
    "amolgariam": "amolgar",
    "amolgarias": "amolgar",
    "amolgarmo": "amolgar",
    "amolgarmos": "amolgar",
    "amolgará": "amolgar",
    "amolgarás": "amolgar",
    "amolgarão": "amolgar",
    "amolgaríamos": "amolgar",
    "amolgaríeis": "amolgar",
    "amolgas": "amolgar",
    "amolgasse": "amolgar",
    "amolgassem": "amolgar",
    "amolgasses": "amolgar",
    "amolgaste": "amolgar",
    "amolgastes": "amolgar",
    "amolgava": "amolgar",
    "amolgavam": "amolgar",
    "amolgavas": "amolgar",
    "amolgo": "amolgar",
    "amolgou": "amolgar",
    "amolgue": "amolgar",
    "amolguei": "amolgar",
    "amolgueis": "amolgar",
    "amolguem": "amolgar",
    "amolguemo": "amolgar",
    "amolguemos": "amolgar",
    "amolgues": "amolgar",
    "amolgá": "amolgar",
    "amolgámo": "amolgar",
    "amolgámos": "amolgar",
    "amolgáramo": "amolgar",
    "amolgáramos": "amolgar",
    "amolgárei": "amolgar",
    "amolgáreis": "amolgar",
    "amolgásseis": "amolgar",
    "amolgássemos": "amolgar",
    "amolgávamo": "amolgar",
    "amolgávamos": "amolgar",
    "amolgávei": "amolgar",
    "amolgáveis": "amolgável",
    "amolo": "amolar",
    "amolou": "amolar",
    "amolá": "amolar",
    "amolámo": "amolar",
    "amolámos": "amolar",
    "amoláramo": "amolar",
    "amoláramos": "amolar",
    "amolárei": "amolar",
    "amoláreis": "amolar",
    "amolásseis": "amolar",
    "amolássemos": "amolar",
    "amolávamo": "amolar",
    "amolávamos": "amolar",
    "amolávei": "amolar",
    "amoláveis": "amolar",
    "amomos": "amomo",
    "amomácea": "amomáceo",
    "amomáceas": "amomáceo",
    "amomáceos": "amomáceo",
    "amonais": "amonal",
    "amoniacada": "amoniacado",
    "amoniacadas": "amoniacado",
    "amoniacados": "amoniacado",
    "amoniacais": "amoniacal",
    "amonitas": "amonita",
    "amonites": "amonite",
    "amonizantes": "amonizante",
    "amoniúrias": "amoniúria",
    "amonta": "amontar",
    "amontada": "amontar",
    "amontadas": "amontar",
    "amontado": "amontar",
    "amontados": "amontar",
    "amontai": "amontar",
    "amontais": "amontar",
    "amontam": "amontar",
    "amontamo": "amontar",
    "amontamos": "amontar",
    "amontando": "amontar",
    "amontanha": "amontanhar",
    "amontanhada": "amontanhar",
    "amontanhadas": "amontanhar",
    "amontanhado": "amontanhar",
    "amontanhados": "amontanhar",
    "amontanhai": "amontanhar",
    "amontanhais": "amontanhar",
    "amontanham": "amontanhar",
    "amontanhamo": "amontanhar",
    "amontanhamos": "amontanhar",
    "amontanhando": "amontanhar",
    "amontanhara": "amontanhar",
    "amontanharam": "amontanhar",
    "amontanharas": "amontanhar",
    "amontanharde": "amontanhar",
    "amontanhardes": "amontanhar",
    "amontanhare": "amontanhar",
    "amontanharei": "amontanhar",
    "amontanhareis": "amontanhar",
    "amontanharem": "amontanhar",
    "amontanharemos": "amontanhar",
    "amontanhares": "amontanhar",
    "amontanharia": "amontanhar",
    "amontanhariam": "amontanhar",
    "amontanharias": "amontanhar",
    "amontanharmo": "amontanhar",
    "amontanharmos": "amontanhar",
    "amontanhará": "amontanhar",
    "amontanharás": "amontanhar",
    "amontanharão": "amontanhar",
    "amontanharíamos": "amontanhar",
    "amontanharíeis": "amontanhar",
    "amontanhas": "amontanhar",
    "amontanhasse": "amontanhar",
    "amontanhassem": "amontanhar",
    "amontanhasses": "amontanhar",
    "amontanhaste": "amontanhar",
    "amontanhastes": "amontanhar",
    "amontanhava": "amontanhar",
    "amontanhavam": "amontanhar",
    "amontanhavas": "amontanhar",
    "amontanhe": "amontanhar",
    "amontanhei": "amontanhar",
    "amontanheis": "amontanhar",
    "amontanhem": "amontanhar",
    "amontanhemo": "amontanhar",
    "amontanhemos": "amontanhar",
    "amontanhes": "amontanhar",
    "amontanho": "amontanhar",
    "amontanhou": "amontanhar",
    "amontanhá": "amontanhar",
    "amontanhámo": "amontanhar",
    "amontanhámos": "amontanhar",
    "amontanháramo": "amontanhar",
    "amontanháramos": "amontanhar",
    "amontanhárei": "amontanhar",
    "amontanháreis": "amontanhar",
    "amontanhásseis": "amontanhar",
    "amontanhássemos": "amontanhar",
    "amontanhávamo": "amontanhar",
    "amontanhávamos": "amontanhar",
    "amontanhávei": "amontanhar",
    "amontanháveis": "amontanhar",
    "amontara": "amontar",
    "amontaram": "amontar",
    "amontaras": "amontar",
    "amontarde": "amontar",
    "amontardes": "amontar",
    "amontare": "amontar",
    "amontarei": "amontar",
    "amontareis": "amontar",
    "amontarem": "amontar",
    "amontaremos": "amontar",
    "amontares": "amontar",
    "amontaria": "amontar",
    "amontariam": "amontar",
    "amontarias": "amontar",
    "amontarmo": "amontar",
    "amontarmos": "amontar",
    "amontará": "amontar",
    "amontarás": "amontar",
    "amontarão": "amontar",
    "amontaríamos": "amontar",
    "amontaríeis": "amontar",
    "amontas": "amontar",
    "amontasse": "amontar",
    "amontassem": "amontar",
    "amontasses": "amontar",
    "amontaste": "amontar",
    "amontastes": "amontar",
    "amontava": "amontar",
    "amontavam": "amontar",
    "amontavas": "amontar",
    "amonte": "amontar",
    "amontei": "amontar",
    "amonteis": "amontar",
    "amontem": "amontar",
    "amontemo": "amontar",
    "amontemos": "amontar",
    "amontes": "amontar",
    "amontija": "amontijar",
    "amontijada": "amontijar",
    "amontijadas": "amontijar",
    "amontijado": "amontijar",
    "amontijados": "amontijar",
    "amontijai": "amontijar",
    "amontijais": "amontijar",
    "amontijam": "amontijar",
    "amontijamo": "amontijar",
    "amontijamos": "amontijar",
    "amontijando": "amontijar",
    "amontijara": "amontijar",
    "amontijaram": "amontijar",
    "amontijaras": "amontijar",
    "amontijarde": "amontijar",
    "amontijardes": "amontijar",
    "amontijare": "amontijar",
    "amontijarei": "amontijar",
    "amontijareis": "amontijar",
    "amontijarem": "amontijar",
    "amontijaremos": "amontijar",
    "amontijares": "amontijar",
    "amontijaria": "amontijar",
    "amontijariam": "amontijar",
    "amontijarias": "amontijar",
    "amontijarmo": "amontijar",
    "amontijarmos": "amontijar",
    "amontijará": "amontijar",
    "amontijarás": "amontijar",
    "amontijarão": "amontijar",
    "amontijaríamos": "amontijar",
    "amontijaríeis": "amontijar",
    "amontijas": "amontijar",
    "amontijasse": "amontijar",
    "amontijassem": "amontijar",
    "amontijasses": "amontijar",
    "amontijaste": "amontijar",
    "amontijastes": "amontijar",
    "amontijava": "amontijar",
    "amontijavam": "amontijar",
    "amontijavas": "amontijar",
    "amontije": "amontijar",
    "amontijei": "amontijar",
    "amontijeis": "amontijar",
    "amontijem": "amontijar",
    "amontijemo": "amontijar",
    "amontijemos": "amontijar",
    "amontijes": "amontijar",
    "amontijo": "amontijar",
    "amontijou": "amontijar",
    "amontijá": "amontijar",
    "amontijámo": "amontijar",
    "amontijámos": "amontijar",
    "amontijáramo": "amontijar",
    "amontijáramos": "amontijar",
    "amontijárei": "amontijar",
    "amontijáreis": "amontijar",
    "amontijásseis": "amontijar",
    "amontijássemos": "amontijar",
    "amontijávamo": "amontijar",
    "amontijávamos": "amontijar",
    "amontijávei": "amontijar",
    "amontijáveis": "amontijar",
    "amontilha": "amontilhar",
    "amontilhada": "amontilhar",
    "amontilhadas": "amontilhar",
    "amontilhado": "amontilhar",
    "amontilhados": "amontilhar",
    "amontilhai": "amontilhar",
    "amontilhais": "amontilhar",
    "amontilham": "amontilhar",
    "amontilhamo": "amontilhar",
    "amontilhamos": "amontilhar",
    "amontilhando": "amontilhar",
    "amontilhara": "amontilhar",
    "amontilharam": "amontilhar",
    "amontilharas": "amontilhar",
    "amontilharde": "amontilhar",
    "amontilhardes": "amontilhar",
    "amontilhare": "amontilhar",
    "amontilharei": "amontilhar",
    "amontilhareis": "amontilhar",
    "amontilharem": "amontilhar",
    "amontilharemos": "amontilhar",
    "amontilhares": "amontilhar",
    "amontilharia": "amontilhar",
    "amontilhariam": "amontilhar",
    "amontilharias": "amontilhar",
    "amontilharmo": "amontilhar",
    "amontilharmos": "amontilhar",
    "amontilhará": "amontilhar",
    "amontilharás": "amontilhar",
    "amontilharão": "amontilhar",
    "amontilharíamos": "amontilhar",
    "amontilharíeis": "amontilhar",
    "amontilhas": "amontilhar",
    "amontilhasse": "amontilhar",
    "amontilhassem": "amontilhar",
    "amontilhasses": "amontilhar",
    "amontilhaste": "amontilhar",
    "amontilhastes": "amontilhar",
    "amontilhava": "amontilhar",
    "amontilhavam": "amontilhar",
    "amontilhavas": "amontilhar",
    "amontilhe": "amontilhar",
    "amontilhei": "amontilhar",
    "amontilheis": "amontilhar",
    "amontilhem": "amontilhar",
    "amontilhemo": "amontilhar",
    "amontilhemos": "amontilhar",
    "amontilhes": "amontilhar",
    "amontilho": "amontilhar",
    "amontilhou": "amontilhar",
    "amontilhá": "amontilhar",
    "amontilhámo": "amontilhar",
    "amontilhámos": "amontilhar",
    "amontilháramo": "amontilhar",
    "amontilháramos": "amontilhar",
    "amontilhárei": "amontilhar",
    "amontilháreis": "amontilhar",
    "amontilhásseis": "amontilhar",
    "amontilhássemos": "amontilhar",
    "amontilhávamo": "amontilhar",
    "amontilhávamos": "amontilhar",
    "amontilhávei": "amontilhar",
    "amontilháveis": "amontilhar",
    "amonto": "amontar",
    "amontoa": "amontoar",
    "amontoada": "amontoar",
    "amontoadas": "amontoar",
    "amontoado": "amontoar",
    "amontoadora": "amontoador",
    "amontoadoras": "amontoador",
    "amontoadores": "amontoador",
    "amontoados": "amontoar",
    "amontoai": "amontoar",
    "amontoais": "amontoar",
    "amontoam": "amontoar",
    "amontoamentos": "amontoamento",
    "amontoamo": "amontoar",
    "amontoamos": "amontoar",
    "amontoando": "amontoar",
    "amontoara": "amontoar",
    "amontoaram": "amontoar",
    "amontoaras": "amontoar",
    "amontoarde": "amontoar",
    "amontoardes": "amontoar",
    "amontoare": "amontoar",
    "amontoarei": "amontoar",
    "amontoareis": "amontoar",
    "amontoarem": "amontoar",
    "amontoaremos": "amontoar",
    "amontoares": "amontoar",
    "amontoaria": "amontoar",
    "amontoariam": "amontoar",
    "amontoarias": "amontoar",
    "amontoarmo": "amontoar",
    "amontoarmos": "amontoar",
    "amontoará": "amontoar",
    "amontoarás": "amontoar",
    "amontoarão": "amontoar",
    "amontoaríamos": "amontoar",
    "amontoaríeis": "amontoar",
    "amontoas": "amontoar",
    "amontoasse": "amontoar",
    "amontoassem": "amontoar",
    "amontoasses": "amontoar",
    "amontoaste": "amontoar",
    "amontoastes": "amontoar",
    "amontoava": "amontoar",
    "amontoavam": "amontoar",
    "amontoavas": "amontoar",
    "amontoações": "amontoação",
    "amontoe": "amontoar",
    "amontoei": "amontoar",
    "amontoeis": "amontoar",
    "amontoem": "amontoar",
    "amontoemo": "amontoar",
    "amontoemos": "amontoar",
    "amontoes": "amontoar",
    "amontoo": "amontoar",
    "amontoou": "amontoar",
    "amontou": "amontar",
    "amontoá": "amontoar",
    "amontoámo": "amontoar",
    "amontoámos": "amontoar",
    "amontoáramo": "amontoar",
    "amontoáramos": "amontoar",
    "amontoárei": "amontoar",
    "amontoáreis": "amontoar",
    "amontoásseis": "amontoar",
    "amontoássemos": "amontoar",
    "amontoávamo": "amontoar",
    "amontoávamos": "amontoar",
    "amontoávei": "amontoar",
    "amontoáveis": "amontoável",
    "amontura": "amonturar",
    "amonturada": "amonturar",
    "amonturadas": "amonturar",
    "amonturado": "amonturar",
    "amonturados": "amonturar",
    "amonturai": "amonturar",
    "amonturais": "amonturar",
    "amonturam": "amonturar",
    "amonturamo": "amonturar",
    "amonturamos": "amonturar",
    "amonturando": "amonturar",
    "amonturara": "amonturar",
    "amonturaram": "amonturar",
    "amonturaras": "amonturar",
    "amonturarde": "amonturar",
    "amonturardes": "amonturar",
    "amonturare": "amonturar",
    "amonturarei": "amonturar",
    "amonturareis": "amonturar",
    "amonturarem": "amonturar",
    "amonturaremos": "amonturar",
    "amonturares": "amonturar",
    "amonturaria": "amonturar",
    "amonturariam": "amonturar",
    "amonturarias": "amonturar",
    "amonturarmo": "amonturar",
    "amonturarmos": "amonturar",
    "amonturará": "amonturar",
    "amonturarás": "amonturar",
    "amonturarão": "amonturar",
    "amonturaríamos": "amonturar",
    "amonturaríeis": "amonturar",
    "amonturas": "amonturar",
    "amonturasse": "amonturar",
    "amonturassem": "amonturar",
    "amonturasses": "amonturar",
    "amonturaste": "amonturar",
    "amonturastes": "amonturar",
    "amonturava": "amonturar",
    "amonturavam": "amonturar",
    "amonturavas": "amonturar",
    "amonture": "amonturar",
    "amonturei": "amonturar",
    "amontureis": "amonturar",
    "amonturem": "amonturar",
    "amonturemo": "amonturar",
    "amonturemos": "amonturar",
    "amontures": "amonturar",
    "amonturo": "amonturar",
    "amonturou": "amonturar",
    "amonturá": "amonturar",
    "amonturámo": "amonturar",
    "amonturámos": "amonturar",
    "amonturáramo": "amonturar",
    "amonturáramos": "amonturar",
    "amonturárei": "amonturar",
    "amonturáreis": "amonturar",
    "amonturásseis": "amonturar",
    "amonturássemos": "amonturar",
    "amonturávamo": "amonturar",
    "amonturávamos": "amonturar",
    "amonturávei": "amonturar",
    "amonturáveis": "amonturar",
    "amontá": "amontar",
    "amontámo": "amontar",
    "amontámos": "amontar",
    "amontáramo": "amontar",
    "amontáramos": "amontar",
    "amontárei": "amontar",
    "amontáreis": "amontar",
    "amontásseis": "amontar",
    "amontássemos": "amontar",
    "amontávamo": "amontar",
    "amontávamos": "amontar",
    "amontávei": "amontar",
    "amontáveis": "amontar",
    "amoníacos": "amoníaco",
    "amonímetros": "amonímetro",
    "amonóides": "amonóide",
    "amonólises": "amonólise",
    "amoque": "amocar",
    "amoqueca": "amoquecar",
    "amoquecada": "amoquecar",
    "amoquecadas": "amoquecar",
    "amoquecado": "amoquecar",
    "amoquecados": "amoquecar",
    "amoquecai": "amoquecar",
    "amoquecais": "amoquecar",
    "amoquecam": "amoquecar",
    "amoquecamo": "amoquecar",
    "amoquecamos": "amoquecar",
    "amoquecando": "amoquecar",
    "amoquecara": "amoquecar",
    "amoquecaram": "amoquecar",
    "amoquecaras": "amoquecar",
    "amoquecarde": "amoquecar",
    "amoquecardes": "amoquecar",
    "amoquecare": "amoquecar",
    "amoquecarei": "amoquecar",
    "amoquecareis": "amoquecar",
    "amoquecarem": "amoquecar",
    "amoquecaremos": "amoquecar",
    "amoquecares": "amoquecar",
    "amoquecaria": "amoquecar",
    "amoquecariam": "amoquecar",
    "amoquecarias": "amoquecar",
    "amoquecarmo": "amoquecar",
    "amoquecarmos": "amoquecar",
    "amoquecará": "amoquecar",
    "amoquecarás": "amoquecar",
    "amoquecarão": "amoquecar",
    "amoquecaríamos": "amoquecar",
    "amoquecaríeis": "amoquecar",
    "amoquecas": "amoquecar",
    "amoquecasse": "amoquecar",
    "amoquecassem": "amoquecar",
    "amoquecasses": "amoquecar",
    "amoquecaste": "amoquecar",
    "amoquecastes": "amoquecar",
    "amoquecava": "amoquecar",
    "amoquecavam": "amoquecar",
    "amoquecavas": "amoquecar",
    "amoqueco": "amoquecar",
    "amoquecou": "amoquecar",
    "amoquecá": "amoquecar",
    "amoquecámo": "amoquecar",
    "amoquecámos": "amoquecar",
    "amoquecáramo": "amoquecar",
    "amoquecáramos": "amoquecar",
    "amoquecárei": "amoquecar",
    "amoquecáreis": "amoquecar",
    "amoquecásseis": "amoquecar",
    "amoquecássemos": "amoquecar",
    "amoquecávamo": "amoquecar",
    "amoquecávamos": "amoquecar",
    "amoquecávei": "amoquecar",
    "amoquecáveis": "amoquecar",
    "amoquei": "amocar",
    "amoqueis": "amocar",
    "amoquem": "amocar",
    "amoquemo": "amocar",
    "amoquemos": "amocar",
    "amoqueque": "amoquecar",
    "amoquequei": "amoquecar",
    "amoquequeis": "amoquecar",
    "amoquequem": "amoquecar",
    "amoquequemo": "amoquecar",
    "amoquequemos": "amoquecar",
    "amoqueques": "amoquecar",
    "amoques": "amoque",
    "amorada": "amorado",
    "amoradas": "amorado",
    "amorados": "amorado",
    "amorais": "amoral",
    "amoralidades": "amoralidade",
    "amoralismos": "amoralismo",
    "amoraliza": "amoralizar",
    "amoralizada": "amoralizar",
    "amoralizadas": "amoralizar",
    "amoralizado": "amoralizar",
    "amoralizados": "amoralizar",
    "amoralizai": "amoralizar",
    "amoralizais": "amoralizar",
    "amoralizam": "amoralizar",
    "amoralizamo": "amoralizar",
    "amoralizamos": "amoralizar",
    "amoralizando": "amoralizar",
    "amoralizara": "amoralizar",
    "amoralizaram": "amoralizar",
    "amoralizaras": "amoralizar",
    "amoralizarde": "amoralizar",
    "amoralizardes": "amoralizar",
    "amoralizare": "amoralizar",
    "amoralizarei": "amoralizar",
    "amoralizareis": "amoralizar",
    "amoralizarem": "amoralizar",
    "amoralizaremos": "amoralizar",
    "amoralizares": "amoralizar",
    "amoralizaria": "amoralizar",
    "amoralizariam": "amoralizar",
    "amoralizarias": "amoralizar",
    "amoralizarmo": "amoralizar",
    "amoralizarmos": "amoralizar",
    "amoralizará": "amoralizar",
    "amoralizarás": "amoralizar",
    "amoralizarão": "amoralizar",
    "amoralizaríamos": "amoralizar",
    "amoralizaríeis": "amoralizar",
    "amoralizas": "amoralizar",
    "amoralizasse": "amoralizar",
    "amoralizassem": "amoralizar",
    "amoralizasses": "amoralizar",
    "amoralizaste": "amoralizar",
    "amoralizastes": "amoralizar",
    "amoralizava": "amoralizar",
    "amoralizavam": "amoralizar",
    "amoralizavas": "amoralizar",
    "amoralize": "amoralizar",
    "amoralizei": "amoralizar",
    "amoralizeis": "amoralizar",
    "amoralizem": "amoralizar",
    "amoralizemo": "amoralizar",
    "amoralizemos": "amoralizar",
    "amoralizes": "amoralizar",
    "amoralizo": "amoralizar",
    "amoralizou": "amoralizar",
    "amoralizá": "amoralizar",
    "amoralizámo": "amoralizar",
    "amoralizámos": "amoralizar",
    "amoralizáramo": "amoralizar",
    "amoralizáramos": "amoralizar",
    "amoralizárei": "amoralizar",
    "amoralizáreis": "amoralizar",
    "amoralizásseis": "amoralizar",
    "amoralizássemos": "amoralizar",
    "amoralizávamo": "amoralizar",
    "amoralizávamos": "amoralizar",
    "amoralizávei": "amoralizar",
    "amoralizáveis": "amoralizar",
    "amorangada": "amorangado",
    "amorangadas": "amorangado",
    "amorangados": "amorangado",
    "amoras": "amora",
    "amorcega": "amorcegar",
    "amorcegada": "amorcegar",
    "amorcegadas": "amorcegar",
    "amorcegado": "amorcegar",
    "amorcegados": "amorcegar",
    "amorcegai": "amorcegar",
    "amorcegais": "amorcegar",
    "amorcegam": "amorcegar",
    "amorcegamo": "amorcegar",
    "amorcegamos": "amorcegar",
    "amorcegando": "amorcegar",
    "amorcegara": "amorcegar",
    "amorcegaram": "amorcegar",
    "amorcegaras": "amorcegar",
    "amorcegarde": "amorcegar",
    "amorcegardes": "amorcegar",
    "amorcegare": "amorcegar",
    "amorcegarei": "amorcegar",
    "amorcegareis": "amorcegar",
    "amorcegarem": "amorcegar",
    "amorcegaremos": "amorcegar",
    "amorcegares": "amorcegar",
    "amorcegaria": "amorcegar",
    "amorcegariam": "amorcegar",
    "amorcegarias": "amorcegar",
    "amorcegarmo": "amorcegar",
    "amorcegarmos": "amorcegar",
    "amorcegará": "amorcegar",
    "amorcegarás": "amorcegar",
    "amorcegarão": "amorcegar",
    "amorcegaríamos": "amorcegar",
    "amorcegaríeis": "amorcegar",
    "amorcegas": "amorcegar",
    "amorcegasse": "amorcegar",
    "amorcegassem": "amorcegar",
    "amorcegasses": "amorcegar",
    "amorcegaste": "amorcegar",
    "amorcegastes": "amorcegar",
    "amorcegava": "amorcegar",
    "amorcegavam": "amorcegar",
    "amorcegavas": "amorcegar",
    "amorcego": "amorcegar",
    "amorcegou": "amorcegar",
    "amorcegue": "amorcegar",
    "amorceguei": "amorcegar",
    "amorcegueis": "amorcegar",
    "amorceguem": "amorcegar",
    "amorceguemo": "amorcegar",
    "amorceguemos": "amorcegar",
    "amorcegues": "amorcegar",
    "amorcegá": "amorcegar",
    "amorcegámo": "amorcegar",
    "amorcegámos": "amorcegar",
    "amorcegáramo": "amorcegar",
    "amorcegáramos": "amorcegar",
    "amorcegárei": "amorcegar",
    "amorcegáreis": "amorcegar",
    "amorcegásseis": "amorcegar",
    "amorcegássemos": "amorcegar",
    "amorcegávamo": "amorcegar",
    "amorcegávamos": "amorcegar",
    "amorcegávei": "amorcegar",
    "amorcegáveis": "amorcegar",
    "amordace": "amordaçar",
    "amordacei": "amordaçar",
    "amordaceis": "amordaçar",
    "amordacem": "amordaçar",
    "amordacemo": "amordaçar",
    "amordacemos": "amordaçar",
    "amordaces": "amordaçar",
    "amordaça": "amordaçar",
    "amordaçada": "amordaçar",
    "amordaçadas": "amordaçar",
    "amordaçado": "amordaçar",
    "amordaçados": "amordaçar",
    "amordaçai": "amordaçar",
    "amordaçais": "amordaçar",
    "amordaçam": "amordaçar",
    "amordaçamo": "amordaçar",
    "amordaçamos": "amordaçar",
    "amordaçando": "amordaçar",
    "amordaçara": "amordaçar",
    "amordaçaram": "amordaçar",
    "amordaçaras": "amordaçar",
    "amordaçarde": "amordaçar",
    "amordaçardes": "amordaçar",
    "amordaçare": "amordaçar",
    "amordaçarei": "amordaçar",
    "amordaçareis": "amordaçar",
    "amordaçarem": "amordaçar",
    "amordaçaremos": "amordaçar",
    "amordaçares": "amordaçar",
    "amordaçaria": "amordaçar",
    "amordaçariam": "amordaçar",
    "amordaçarias": "amordaçar",
    "amordaçarmo": "amordaçar",
    "amordaçarmos": "amordaçar",
    "amordaçará": "amordaçar",
    "amordaçarás": "amordaçar",
    "amordaçarão": "amordaçar",
    "amordaçaríamos": "amordaçar",
    "amordaçaríeis": "amordaçar",
    "amordaças": "amordaçar",
    "amordaçasse": "amordaçar",
    "amordaçassem": "amordaçar",
    "amordaçasses": "amordaçar",
    "amordaçaste": "amordaçar",
    "amordaçastes": "amordaçar",
    "amordaçava": "amordaçar",
    "amordaçavam": "amordaçar",
    "amordaçavas": "amordaçar",
    "amordaço": "amordaçar",
    "amordaçou": "amordaçar",
    "amordaçá": "amordaçar",
    "amordaçámo": "amordaçar",
    "amordaçámos": "amordaçar",
    "amordaçáramo": "amordaçar",
    "amordaçáramos": "amordaçar",
    "amordaçárei": "amordaçar",
    "amordaçáreis": "amordaçar",
    "amordaçásseis": "amordaçar",
    "amordaçássemos": "amordaçar",
    "amordaçávamo": "amordaçar",
    "amordaçávamos": "amordaçar",
    "amordaçávei": "amordaçar",
    "amordaçáveis": "amordaçar",
    "amorecos": "amoreco",
    "amoreias": "amoreia",
    "amoreirais": "amoreiral",
    "amoreiras": "amoreira",
    "amorena": "amorenar",
    "amorenada": "amorenar",
    "amorenadas": "amorenar",
    "amorenado": "amorenar",
    "amorenados": "amorenar",
    "amorenai": "amorenar",
    "amorenais": "amorenar",
    "amorenam": "amorenar",
    "amorenamo": "amorenar",
    "amorenamos": "amorenar",
    "amorenando": "amorenar",
    "amorenara": "amorenar",
    "amorenaram": "amorenar",
    "amorenaras": "amorenar",
    "amorenarde": "amorenar",
    "amorenardes": "amorenar",
    "amorenare": "amorenar",
    "amorenarei": "amorenar",
    "amorenareis": "amorenar",
    "amorenarem": "amorenar",
    "amorenaremos": "amorenar",
    "amorenares": "amorenar",
    "amorenaria": "amorenar",
    "amorenariam": "amorenar",
    "amorenarias": "amorenar",
    "amorenarmo": "amorenar",
    "amorenarmos": "amorenar",
    "amorenará": "amorenar",
    "amorenarás": "amorenar",
    "amorenarão": "amorenar",
    "amorenaríamos": "amorenar",
    "amorenaríeis": "amorenar",
    "amorenas": "amorenar",
    "amorenasse": "amorenar",
    "amorenassem": "amorenar",
    "amorenasses": "amorenar",
    "amorenaste": "amorenar",
    "amorenastes": "amorenar",
    "amorenava": "amorenar",
    "amorenavam": "amorenar",
    "amorenavas": "amorenar",
    "amorene": "amorenar",
    "amorenei": "amorenar",
    "amoreneis": "amorenar",
    "amorenem": "amorenar",
    "amorenemo": "amorenar",
    "amorenemos": "amorenar",
    "amorenes": "amorenar",
    "amoreno": "amorenar",
    "amorenou": "amorenar",
    "amorená": "amorenar",
    "amorenámo": "amorenar",
    "amorenámos": "amorenar",
    "amorenáramo": "amorenar",
    "amorenáramos": "amorenar",
    "amorenárei": "amorenar",
    "amorenáreis": "amorenar",
    "amorenásseis": "amorenar",
    "amorenássemos": "amorenar",
    "amorenávamo": "amorenar",
    "amorenávamos": "amorenar",
    "amorenávei": "amorenar",
    "amorenáveis": "amorenar",
    "amores": "amor",
    "amorfa": "amorfo",
    "amorfas": "amorfo",
    "amorfias": "amorfia",
    "amorfismos": "amorfismo",
    "amorfos": "amorfo",
    "amoricos": "amorico",
    "amorins": "amorim",
    "amorios": "amorio",
    "amorisca": "amoriscar",
    "amoriscada": "amoriscar",
    "amoriscadas": "amoriscar",
    "amoriscado": "amoriscar",
    "amoriscados": "amoriscar",
    "amoriscai": "amoriscar",
    "amoriscais": "amoriscar",
    "amoriscam": "amoriscar",
    "amoriscamo": "amoriscar",
    "amoriscamos": "amoriscar",
    "amoriscando": "amoriscar",
    "amoriscara": "amoriscar",
    "amoriscaram": "amoriscar",
    "amoriscaras": "amoriscar",
    "amoriscarde": "amoriscar",
    "amoriscardes": "amoriscar",
    "amoriscare": "amoriscar",
    "amoriscarei": "amoriscar",
    "amoriscareis": "amoriscar",
    "amoriscarem": "amoriscar",
    "amoriscaremos": "amoriscar",
    "amoriscares": "amoriscar",
    "amoriscaria": "amoriscar",
    "amoriscariam": "amoriscar",
    "amoriscarias": "amoriscar",
    "amoriscarmo": "amoriscar",
    "amoriscarmos": "amoriscar",
    "amoriscará": "amoriscar",
    "amoriscarás": "amoriscar",
    "amoriscarão": "amoriscar",
    "amoriscaríamos": "amoriscar",
    "amoriscaríeis": "amoriscar",
    "amoriscas": "amoriscar",
    "amoriscasse": "amoriscar",
    "amoriscassem": "amoriscar",
    "amoriscasses": "amoriscar",
    "amoriscaste": "amoriscar",
    "amoriscastes": "amoriscar",
    "amoriscava": "amoriscar",
    "amoriscavam": "amoriscar",
    "amoriscavas": "amoriscar",
    "amorisco": "amoriscar",
    "amoriscou": "amoriscar",
    "amoriscá": "amoriscar",
    "amoriscámo": "amoriscar",
    "amoriscámos": "amoriscar",
    "amoriscáramo": "amoriscar",
    "amoriscáramos": "amoriscar",
    "amoriscárei": "amoriscar",
    "amoriscáreis": "amoriscar",
    "amoriscásseis": "amoriscar",
    "amoriscássemos": "amoriscar",
    "amoriscávamo": "amoriscar",
    "amoriscávamos": "amoriscar",
    "amoriscávei": "amoriscar",
    "amoriscáveis": "amoriscar",
    "amorismos": "amorismo",
    "amorisque": "amoriscar",
    "amorisquei": "amoriscar",
    "amorisqueis": "amoriscar",
    "amorisquem": "amoriscar",
    "amorisquemo": "amoriscar",
    "amorisquemos": "amoriscar",
    "amorisques": "amoriscar",
    "amormada": "amormado",
    "amormadas": "amormado",
    "amormados": "amormado",
    "amorna": "amornar",
    "amornada": "amornar",
    "amornadas": "amornar",
    "amornado": "amornar",
    "amornados": "amornar",
    "amornai": "amornar",
    "amornais": "amornar",
    "amornam": "amornar",
    "amornamo": "amornar",
    "amornamos": "amornar",
    "amornando": "amornar",
    "amornara": "amornar",
    "amornaram": "amornar",
    "amornaras": "amornar",
    "amornarde": "amornar",
    "amornardes": "amornar",
    "amornare": "amornar",
    "amornarei": "amornar",
    "amornareis": "amornar",
    "amornarem": "amornar",
    "amornaremos": "amornar",
    "amornares": "amornar",
    "amornaria": "amornar",
    "amornariam": "amornar",
    "amornarias": "amornar",
    "amornarmo": "amornar",
    "amornarmos": "amornar",
    "amornará": "amornar",
    "amornarás": "amornar",
    "amornarão": "amornar",
    "amornaríamos": "amornar",
    "amornaríeis": "amornar",
    "amornas": "amornar",
    "amornasse": "amornar",
    "amornassem": "amornar",
    "amornasses": "amornar",
    "amornaste": "amornar",
    "amornastes": "amornar",
    "amornava": "amornar",
    "amornavam": "amornar",
    "amornavas": "amornar",
    "amorne": "amornar",
    "amornece": "amornecer",
    "amornecei": "amornecer",
    "amorneceis": "amornecer",
    "amornecem": "amornecer",
    "amornecemo": "amornecer",
    "amornecemos": "amornecer",
    "amornecendo": "amornecer",
    "amornecera": "amornecer",
    "amorneceram": "amornecer",
    "amorneceras": "amornecer",
    "amornecerde": "amornecer",
    "amornecerdes": "amornecer",
    "amornecere": "amornecer",
    "amornecerei": "amornecer",
    "amornecereis": "amornecer",
    "amornecerem": "amornecer",
    "amorneceremos": "amornecer",
    "amorneceres": "amornecer",
    "amorneceria": "amornecer",
    "amorneceriam": "amornecer",
    "amornecerias": "amornecer",
    "amornecermo": "amornecer",
    "amornecermos": "amornecer",
    "amornecerá": "amornecer",
    "amornecerás": "amornecer",
    "amornecerão": "amornecer",
    "amorneceríamos": "amornecer",
    "amorneceríeis": "amornecer",
    "amorneces": "amornecer",
    "amornecesse": "amornecer",
    "amornecessem": "amornecer",
    "amornecesses": "amornecer",
    "amorneceste": "amornecer",
    "amornecestes": "amornecer",
    "amorneceu": "amornecer",
    "amorneci": "amornecer",
    "amornecia": "amornecer",
    "amorneciam": "amornecer",
    "amornecias": "amornecer",
    "amornecida": "amornecer",
    "amornecidas": "amornecer",
    "amornecido": "amornecer",
    "amornecidos": "amornecer",
    "amornecê": "amornecer",
    "amornecêramo": "amornecer",
    "amornecêramos": "amornecer",
    "amornecêrei": "amornecer",
    "amornecêreis": "amornecer",
    "amornecêsseis": "amornecer",
    "amornecêssemos": "amornecer",
    "amornecíamo": "amornecer",
    "amornecíamos": "amornecer",
    "amornecíei": "amornecer",
    "amornecíeis": "amornecer",
    "amornei": "amornar",
    "amorneis": "amornar",
    "amornem": "amornar",
    "amornemo": "amornar",
    "amornemos": "amornar",
    "amornes": "amornar",
    "amorneça": "amornecer",
    "amorneçais": "amornecer",
    "amorneçam": "amornecer",
    "amorneçamo": "amornecer",
    "amorneçamos": "amornecer",
    "amorneças": "amornecer",
    "amorneço": "amornecer",
    "amorno": "amornar",
    "amornou": "amornar",
    "amorná": "amornar",
    "amornámo": "amornar",
    "amornámos": "amornar",
    "amornáramo": "amornar",
    "amornáramos": "amornar",
    "amornárei": "amornar",
    "amornáreis": "amornar",
    "amornásseis": "amornar",
    "amornássemos": "amornar",
    "amornávamo": "amornar",
    "amornávamos": "amornar",
    "amornávei": "amornar",
    "amornáveis": "amornar",
    "amorosa": "amoroso",
    "amorosas": "amoroso",
    "amorosidades": "amorosidade",
    "amorosinha": "amorosinho",
    "amorosinhas": "amorosinho",
    "amorosinhos": "amorosinho",
    "amorosos": "amoroso",
    "amorosíssima": "amoroso",
    "amorosíssimas": "amoroso",
    "amorosíssimo": "amoroso",
    "amorosíssimos": "amoroso",
    "amorrinha": "amorrinhar",
    "amorrinhada": "amorrinhar",
    "amorrinhadas": "amorrinhar",
    "amorrinhado": "amorrinhar",
    "amorrinhados": "amorrinhar",
    "amorrinhai": "amorrinhar",
    "amorrinhais": "amorrinhar",
    "amorrinham": "amorrinhar",
    "amorrinhamo": "amorrinhar",
    "amorrinhamos": "amorrinhar",
    "amorrinhando": "amorrinhar",
    "amorrinhara": "amorrinhar",
    "amorrinharam": "amorrinhar",
    "amorrinharas": "amorrinhar",
    "amorrinhardes": "amorrinhar",
    "amorrinharei": "amorrinhar",
    "amorrinhareis": "amorrinhar",
    "amorrinharem": "amorrinhar",
    "amorrinharemos": "amorrinhar",
    "amorrinhares": "amorrinhar",
    "amorrinharia": "amorrinhar",
    "amorrinhariam": "amorrinhar",
    "amorrinharias": "amorrinhar",
    "amorrinharmo": "amorrinhar",
    "amorrinharmos": "amorrinhar",
    "amorrinhará": "amorrinhar",
    "amorrinharás": "amorrinhar",
    "amorrinharão": "amorrinhar",
    "amorrinharíamos": "amorrinhar",
    "amorrinharíeis": "amorrinhar",
    "amorrinhas": "amorrinhar",
    "amorrinhasse": "amorrinhar",
    "amorrinhassem": "amorrinhar",
    "amorrinhasses": "amorrinhar",
    "amorrinhaste": "amorrinhar",
    "amorrinhastes": "amorrinhar",
    "amorrinhava": "amorrinhar",
    "amorrinhavam": "amorrinhar",
    "amorrinhavas": "amorrinhar",
    "amorrinhe": "amorrinhar",
    "amorrinhei": "amorrinhar",
    "amorrinheis": "amorrinhar",
    "amorrinhem": "amorrinhar",
    "amorrinhemo": "amorrinhar",
    "amorrinhemos": "amorrinhar",
    "amorrinhes": "amorrinhar",
    "amorrinho": "amorrinhar",
    "amorrinhou": "amorrinhar",
    "amorrinhámo": "amorrinhar",
    "amorrinhámos": "amorrinhar",
    "amorrinháramo": "amorrinhar",
    "amorrinháramos": "amorrinhar",
    "amorrinháreis": "amorrinhar",
    "amorrinhásseis": "amorrinhar",
    "amorrinhássemos": "amorrinhar",
    "amorrinhávamo": "amorrinhar",
    "amorrinhávamos": "amorrinhar",
    "amorrinháveis": "amorrinhar",
    "amorroa": "amorroar",
    "amorroada": "amorroar",
    "amorroadas": "amorroar",
    "amorroado": "amorroar",
    "amorroados": "amorroar",
    "amorroai": "amorroar",
    "amorroais": "amorroar",
    "amorroam": "amorroar",
    "amorroamo": "amorroar",
    "amorroamos": "amorroar",
    "amorroando": "amorroar",
    "amorroara": "amorroar",
    "amorroaram": "amorroar",
    "amorroaras": "amorroar",
    "amorroardes": "amorroar",
    "amorroarei": "amorroar",
    "amorroareis": "amorroar",
    "amorroarem": "amorroar",
    "amorroaremos": "amorroar",
    "amorroares": "amorroar",
    "amorroaria": "amorroar",
    "amorroariam": "amorroar",
    "amorroarias": "amorroar",
    "amorroarmo": "amorroar",
    "amorroarmos": "amorroar",
    "amorroará": "amorroar",
    "amorroarás": "amorroar",
    "amorroarão": "amorroar",
    "amorroaríamos": "amorroar",
    "amorroaríeis": "amorroar",
    "amorroas": "amorroar",
    "amorroasse": "amorroar",
    "amorroassem": "amorroar",
    "amorroasses": "amorroar",
    "amorroaste": "amorroar",
    "amorroastes": "amorroar",
    "amorroava": "amorroar",
    "amorroavam": "amorroar",
    "amorroavas": "amorroar",
    "amorroe": "amorroar",
    "amorroei": "amorroar",
    "amorroeis": "amorroar",
    "amorroem": "amorroar",
    "amorroemo": "amorroar",
    "amorroemos": "amorroar",
    "amorroes": "amorroar",
    "amorroo": "amorroar",
    "amorroou": "amorroar",
    "amorroámo": "amorroar",
    "amorroámos": "amorroar",
    "amorroáramo": "amorroar",
    "amorroáramos": "amorroar",
    "amorroáreis": "amorroar",
    "amorroásseis": "amorroar",
    "amorroássemos": "amorroar",
    "amorroávamo": "amorroar",
    "amorroávamos": "amorroar",
    "amorroáveis": "amorroar",
    "amorsega": "amorsegar",
    "amorsegada": "amorsegar",
    "amorsegadas": "amorsegar",
    "amorsegado": "amorsegar",
    "amorsegados": "amorsegar",
    "amorsegai": "amorsegar",
    "amorsegais": "amorsegar",
    "amorsegam": "amorsegar",
    "amorsegamo": "amorsegar",
    "amorsegamos": "amorsegar",
    "amorsegando": "amorsegar",
    "amorsegara": "amorsegar",
    "amorsegaram": "amorsegar",
    "amorsegaras": "amorsegar",
    "amorsegarde": "amorsegar",
    "amorsegardes": "amorsegar",
    "amorsegare": "amorsegar",
    "amorsegarei": "amorsegar",
    "amorsegareis": "amorsegar",
    "amorsegarem": "amorsegar",
    "amorsegaremos": "amorsegar",
    "amorsegares": "amorsegar",
    "amorsegaria": "amorsegar",
    "amorsegariam": "amorsegar",
    "amorsegarias": "amorsegar",
    "amorsegarmo": "amorsegar",
    "amorsegarmos": "amorsegar",
    "amorsegará": "amorsegar",
    "amorsegarás": "amorsegar",
    "amorsegarão": "amorsegar",
    "amorsegaríamos": "amorsegar",
    "amorsegaríeis": "amorsegar",
    "amorsegas": "amorsegar",
    "amorsegasse": "amorsegar",
    "amorsegassem": "amorsegar",
    "amorsegasses": "amorsegar",
    "amorsegaste": "amorsegar",
    "amorsegastes": "amorsegar",
    "amorsegava": "amorsegar",
    "amorsegavam": "amorsegar",
    "amorsegavas": "amorsegar",
    "amorsego": "amorsegar",
    "amorsegou": "amorsegar",
    "amorsegue": "amorsegar",
    "amorseguei": "amorsegar",
    "amorsegueis": "amorsegar",
    "amorseguem": "amorsegar",
    "amorseguemo": "amorsegar",
    "amorseguemos": "amorsegar",
    "amorsegues": "amorsegar",
    "amorsegá": "amorsegar",
    "amorsegámo": "amorsegar",
    "amorsegámos": "amorsegar",
    "amorsegáramo": "amorsegar",
    "amorsegáramos": "amorsegar",
    "amorsegárei": "amorsegar",
    "amorsegáreis": "amorsegar",
    "amorsegásseis": "amorsegar",
    "amorsegássemos": "amorsegar",
    "amorsegávamo": "amorsegar",
    "amorsegávamos": "amorsegar",
    "amorsegávei": "amorsegar",
    "amorsegáveis": "amorsegar",
    "amortalha": "amortalhar",
    "amortalhada": "amortalhar",
    "amortalhadas": "amortalhar",
    "amortalhadeira": "amortalhador",
    "amortalhadeiras": "amortalhador",
    "amortalhado": "amortalhar",
    "amortalhadora": "amortalhador",
    "amortalhadoras": "amortalhador",
    "amortalhadores": "amortalhador",
    "amortalhados": "amortalhar",
    "amortalhai": "amortalhar",
    "amortalhais": "amortalhar",
    "amortalham": "amortalhar",
    "amortalhamentos": "amortalhamento",
    "amortalhamo": "amortalhar",
    "amortalhamos": "amortalhar",
    "amortalhando": "amortalhar",
    "amortalhara": "amortalhar",
    "amortalharam": "amortalhar",
    "amortalharas": "amortalhar",
    "amortalharde": "amortalhar",
    "amortalhardes": "amortalhar",
    "amortalhare": "amortalhar",
    "amortalharei": "amortalhar",
    "amortalhareis": "amortalhar",
    "amortalharem": "amortalhar",
    "amortalharemos": "amortalhar",
    "amortalhares": "amortalhar",
    "amortalharia": "amortalhar",
    "amortalhariam": "amortalhar",
    "amortalharias": "amortalhar",
    "amortalharmo": "amortalhar",
    "amortalharmos": "amortalhar",
    "amortalhará": "amortalhar",
    "amortalharás": "amortalhar",
    "amortalharão": "amortalhar",
    "amortalharíamos": "amortalhar",
    "amortalharíeis": "amortalhar",
    "amortalhas": "amortalhar",
    "amortalhasse": "amortalhar",
    "amortalhassem": "amortalhar",
    "amortalhasses": "amortalhar",
    "amortalhaste": "amortalhar",
    "amortalhastes": "amortalhar",
    "amortalhava": "amortalhar",
    "amortalhavam": "amortalhar",
    "amortalhavas": "amortalhar",
    "amortalhe": "amortalhar",
    "amortalhei": "amortalhar",
    "amortalheis": "amortalhar",
    "amortalhem": "amortalhar",
    "amortalhemo": "amortalhar",
    "amortalhemos": "amortalhar",
    "amortalhes": "amortalhar",
    "amortalho": "amortalhar",
    "amortalhou": "amortalhar",
    "amortalhá": "amortalhar",
    "amortalhámo": "amortalhar",
    "amortalhámos": "amortalhar",
    "amortalháramo": "amortalhar",
    "amortalháramos": "amortalhar",
    "amortalhárei": "amortalhar",
    "amortalháreis": "amortalhar",
    "amortalhásseis": "amortalhar",
    "amortalhássemos": "amortalhar",
    "amortalhávamo": "amortalhar",
    "amortalhávamos": "amortalhar",
    "amortalhávei": "amortalhar",
    "amortalháveis": "amortalhar",
    "amortece": "amortecer",
    "amortecedora": "amortecedor",
    "amortecedoras": "amortecedor",
    "amortecedores": "amortecedor",
    "amortecei": "amortecer",
    "amorteceis": "amortecer",
    "amortecem": "amortecer",
    "amortecemo": "amortecer",
    "amortecemos": "amortecer",
    "amortecendo": "amortecer",
    "amortecera": "amortecer",
    "amorteceram": "amortecer",
    "amorteceras": "amortecer",
    "amortecerde": "amortecer",
    "amortecerdes": "amortecer",
    "amortecere": "amortecer",
    "amortecerei": "amortecer",
    "amortecereis": "amortecer",
    "amortecerem": "amortecer",
    "amorteceremos": "amortecer",
    "amorteceres": "amortecer",
    "amorteceria": "amortecer",
    "amorteceriam": "amortecer",
    "amortecerias": "amortecer",
    "amortecermo": "amortecer",
    "amortecermos": "amortecer",
    "amortecerá": "amortecer",
    "amortecerás": "amortecer",
    "amortecerão": "amortecer",
    "amorteceríamos": "amortecer",
    "amorteceríeis": "amortecer",
    "amorteces": "amortecer",
    "amortecesse": "amortecer",
    "amortecessem": "amortecer",
    "amortecesses": "amortecer",
    "amorteceste": "amortecer",
    "amortecestes": "amortecer",
    "amorteceu": "amortecer",
    "amorteci": "amortecer",
    "amortecia": "amortecer",
    "amorteciam": "amortecer",
    "amortecias": "amortecer",
    "amortecida": "amortecido",
    "amortecidas": "amortecido",
    "amortecido": "amortecer",
    "amortecidos": "amortecido",
    "amortecimentos": "amortecimento",
    "amortecê": "amortecer",
    "amortecêramo": "amortecer",
    "amortecêramos": "amortecer",
    "amortecêrei": "amortecer",
    "amortecêreis": "amortecer",
    "amortecêsseis": "amortecer",
    "amortecêssemos": "amortecer",
    "amortecíamo": "amortecer",
    "amortecíamos": "amortecer",
    "amortecíei": "amortecer",
    "amortecíeis": "amortecer",
    "amorteça": "amortecer",
    "amorteçais": "amortecer",
    "amorteçam": "amortecer",
    "amorteçamo": "amortecer",
    "amorteçamos": "amortecer",
    "amorteças": "amortecer",
    "amorteço": "amortecer",
    "amortice": "amortiçar",
    "amorticei": "amortiçar",
    "amorticeis": "amortiçar",
    "amorticem": "amortiçar",
    "amorticemo": "amortiçar",
    "amorticemos": "amortiçar",
    "amortices": "amortiçar",
    "amortiza": "amortizar",
    "amortizada": "amortizar",
    "amortizadas": "amortizar",
    "amortizado": "amortizar",
    "amortizados": "amortizar",
    "amortizadíssima": "amortizado",
    "amortizadíssimas": "amortizado",
    "amortizadíssimo": "amortizado",
    "amortizadíssimos": "amortizado",
    "amortizai": "amortizar",
    "amortizais": "amortizar",
    "amortizam": "amortizar",
    "amortizamo": "amortizar",
    "amortizamos": "amortizar",
    "amortizando": "amortizar",
    "amortizara": "amortizar",
    "amortizaram": "amortizar",
    "amortizaras": "amortizar",
    "amortizarde": "amortizar",
    "amortizardes": "amortizar",
    "amortizare": "amortizar",
    "amortizarei": "amortizar",
    "amortizareis": "amortizar",
    "amortizarem": "amortizar",
    "amortizaremos": "amortizar",
    "amortizares": "amortizar",
    "amortizaria": "amortizar",
    "amortizariam": "amortizar",
    "amortizarias": "amortizar",
    "amortizarmo": "amortizar",
    "amortizarmos": "amortizar",
    "amortizará": "amortizar",
    "amortizarás": "amortizar",
    "amortizarão": "amortizar",
    "amortizaríamos": "amortizar",
    "amortizaríeis": "amortizar",
    "amortizas": "amortizar",
    "amortizasse": "amortizar",
    "amortizassem": "amortizar",
    "amortizasses": "amortizar",
    "amortizaste": "amortizar",
    "amortizastes": "amortizar",
    "amortizava": "amortizar",
    "amortizavam": "amortizar",
    "amortizavas": "amortizar",
    "amortizações": "amortização",
    "amortize": "amortizar",
    "amortizei": "amortizar",
    "amortizeis": "amortizar",
    "amortizem": "amortizar",
    "amortizemo": "amortizar",
    "amortizemos": "amortizar",
    "amortizes": "amortizar",
    "amortizo": "amortizar",
    "amortizou": "amortizar",
    "amortizá": "amortizar",
    "amortizámo": "amortizar",
    "amortizámos": "amortizar",
    "amortizáramo": "amortizar",
    "amortizáramos": "amortizar",
    "amortizárei": "amortizar",
    "amortizáreis": "amortizar",
    "amortizásseis": "amortizar",
    "amortizássemos": "amortizar",
    "amortizávamo": "amortizar",
    "amortizávamos": "amortizar",
    "amortizávei": "amortizar",
    "amortizáveis": "amortizável",
    "amortiça": "amortiçar",
    "amortiçada": "amortiçar",
    "amortiçadas": "amortiçar",
    "amortiçado": "amortiçar",
    "amortiçados": "amortiçar",
    "amortiçai": "amortiçar",
    "amortiçais": "amortiçar",
    "amortiçam": "amortiçar",
    "amortiçamo": "amortiçar",
    "amortiçamos": "amortiçar",
    "amortiçando": "amortiçar",
    "amortiçara": "amortiçar",
    "amortiçaram": "amortiçar",
    "amortiçaras": "amortiçar",
    "amortiçarde": "amortiçar",
    "amortiçardes": "amortiçar",
    "amortiçare": "amortiçar",
    "amortiçarei": "amortiçar",
    "amortiçareis": "amortiçar",
    "amortiçarem": "amortiçar",
    "amortiçaremos": "amortiçar",
    "amortiçares": "amortiçar",
    "amortiçaria": "amortiçar",
    "amortiçariam": "amortiçar",
    "amortiçarias": "amortiçar",
    "amortiçarmo": "amortiçar",
    "amortiçarmos": "amortiçar",
    "amortiçará": "amortiçar",
    "amortiçarás": "amortiçar",
    "amortiçarão": "amortiçar",
    "amortiçaríamos": "amortiçar",
    "amortiçaríeis": "amortiçar",
    "amortiças": "amortiçar",
    "amortiçasse": "amortiçar",
    "amortiçassem": "amortiçar",
    "amortiçasses": "amortiçar",
    "amortiçaste": "amortiçar",
    "amortiçastes": "amortiçar",
    "amortiçava": "amortiçar",
    "amortiçavam": "amortiçar",
    "amortiçavas": "amortiçar",
    "amortiço": "amortiçar",
    "amortiçou": "amortiçar",
    "amortiçá": "amortiçar",
    "amortiçámo": "amortiçar",
    "amortiçámos": "amortiçar",
    "amortiçáramo": "amortiçar",
    "amortiçáramos": "amortiçar",
    "amortiçárei": "amortiçar",
    "amortiçáreis": "amortiçar",
    "amortiçásseis": "amortiçar",
    "amortiçássemos": "amortiçar",
    "amortiçávamo": "amortiçar",
    "amortiçávamos": "amortiçar",
    "amortiçávei": "amortiçar",
    "amortiçáveis": "amortiçar",
    "amoruda": "amorudo",
    "amorudas": "amorudo",
    "amorudos": "amorudo",
    "amorudíssima": "amorudo",
    "amorudíssimas": "amorudo",
    "amorudíssimo": "amorudo",
    "amorudíssimos": "amorudo",
    "amorzeira": "amorzeiro",
    "amorzeiras": "amorzeiro",
    "amorzeiros": "amorzeiro",
    "amorzinho": "amor",
    "amorzinhos": "amor",
    "amorzito": "amor",
    "amorzitos": "amor",
    "amoráveis": "amorável",
    "amorífera": "amorífero",
    "amoríferas": "amorífero",
    "amoríferos": "amorífero",
    "amos": "amo",
    "amossa": "amossar",
    "amossada": "amossar",
    "amossadas": "amossar",
    "amossadelas": "amossadela",
    "amossado": "amossar",
    "amossados": "amossar",
    "amossai": "amossar",
    "amossais": "amossar",
    "amossam": "amossar",
    "amossamo": "amossar",
    "amossamos": "amossar",
    "amossando": "amossar",
    "amossara": "amossar",
    "amossaram": "amossar",
    "amossaras": "amossar",
    "amossarde": "amossar",
    "amossardes": "amossar",
    "amossare": "amossar",
    "amossarei": "amossar",
    "amossareis": "amossar",
    "amossarem": "amossar",
    "amossaremos": "amossar",
    "amossares": "amossar",
    "amossaria": "amossar",
    "amossariam": "amossar",
    "amossarias": "amossar",
    "amossarmo": "amossar",
    "amossarmos": "amossar",
    "amossará": "amossar",
    "amossarás": "amossar",
    "amossarão": "amossar",
    "amossaríamos": "amossar",
    "amossaríeis": "amossar",
    "amossas": "amossar",
    "amossasse": "amossar",
    "amossassem": "amossar",
    "amossasses": "amossar",
    "amossaste": "amossar",
    "amossastes": "amossar",
    "amossava": "amossar",
    "amossavam": "amossar",
    "amossavas": "amossar",
    "amosse": "amossar",
    "amossega": "amossegar",
    "amossegada": "amossegar",
    "amossegadas": "amossegar",
    "amossegado": "amossegar",
    "amossegados": "amossegar",
    "amossegai": "amossegar",
    "amossegais": "amossegar",
    "amossegam": "amossegar",
    "amossegamo": "amossegar",
    "amossegamos": "amossegar",
    "amossegando": "amossegar",
    "amossegara": "amossegar",
    "amossegaram": "amossegar",
    "amossegaras": "amossegar",
    "amossegarde": "amossegar",
    "amossegardes": "amossegar",
    "amossegare": "amossegar",
    "amossegarei": "amossegar",
    "amossegareis": "amossegar",
    "amossegarem": "amossegar",
    "amossegaremos": "amossegar",
    "amossegares": "amossegar",
    "amossegaria": "amossegar",
    "amossegariam": "amossegar",
    "amossegarias": "amossegar",
    "amossegarmo": "amossegar",
    "amossegarmos": "amossegar",
    "amossegará": "amossegar",
    "amossegarás": "amossegar",
    "amossegarão": "amossegar",
    "amossegaríamos": "amossegar",
    "amossegaríeis": "amossegar",
    "amossegas": "amossegar",
    "amossegasse": "amossegar",
    "amossegassem": "amossegar",
    "amossegasses": "amossegar",
    "amossegaste": "amossegar",
    "amossegastes": "amossegar",
    "amossegava": "amossegar",
    "amossegavam": "amossegar",
    "amossegavas": "amossegar",
    "amossego": "amossegar",
    "amossegou": "amossegar",
    "amossegue": "amossegar",
    "amosseguei": "amossegar",
    "amossegueis": "amossegar",
    "amosseguem": "amossegar",
    "amosseguemo": "amossegar",
    "amosseguemos": "amossegar",
    "amossegues": "amossegar",
    "amossegá": "amossegar",
    "amossegámo": "amossegar",
    "amossegámos": "amossegar",
    "amossegáramo": "amossegar",
    "amossegáramos": "amossegar",
    "amossegárei": "amossegar",
    "amossegáreis": "amossegar",
    "amossegásseis": "amossegar",
    "amossegássemos": "amossegar",
    "amossegávamo": "amossegar",
    "amossegávamos": "amossegar",
    "amossegávei": "amossegar",
    "amossegáveis": "amossegar",
    "amossei": "amossar",
    "amosseis": "amossar",
    "amossem": "amossar",
    "amossemo": "amossar",
    "amossemos": "amossar",
    "amosses": "amossar",
    "amosso": "amossar",
    "amossou": "amossar",
    "amossá": "amossar",
    "amossámo": "amossar",
    "amossámos": "amossar",
    "amossáramo": "amossar",
    "amossáramos": "amossar",
    "amossárei": "amossar",
    "amossáreis": "amossar",
    "amossásseis": "amossar",
    "amossássemos": "amossar",
    "amossávamo": "amossar",
    "amossávamos": "amossar",
    "amossávei": "amossar",
    "amossáveis": "amossar",
    "amostada": "amostado",
    "amostadas": "amostado",
    "amostados": "amostado",
    "amostarda": "amostardar",
    "amostardada": "amostardar",
    "amostardadas": "amostardar",
    "amostardado": "amostardar",
    "amostardados": "amostardar",
    "amostardai": "amostardar",
    "amostardais": "amostardar",
    "amostardam": "amostardar",
    "amostardamo": "amostardar",
    "amostardamos": "amostardar",
    "amostardando": "amostardar",
    "amostardara": "amostardar",
    "amostardaram": "amostardar",
    "amostardaras": "amostardar",
    "amostardarde": "amostardar",
    "amostardardes": "amostardar",
    "amostardare": "amostardar",
    "amostardarei": "amostardar",
    "amostardareis": "amostardar",
    "amostardarem": "amostardar",
    "amostardaremos": "amostardar",
    "amostardares": "amostardar",
    "amostardaria": "amostardar",
    "amostardariam": "amostardar",
    "amostardarias": "amostardar",
    "amostardarmo": "amostardar",
    "amostardarmos": "amostardar",
    "amostardará": "amostardar",
    "amostardarás": "amostardar",
    "amostardarão": "amostardar",
    "amostardaríamos": "amostardar",
    "amostardaríeis": "amostardar",
    "amostardas": "amostardar",
    "amostardasse": "amostardar",
    "amostardassem": "amostardar",
    "amostardasses": "amostardar",
    "amostardaste": "amostardar",
    "amostardastes": "amostardar",
    "amostardava": "amostardar",
    "amostardavam": "amostardar",
    "amostardavas": "amostardar",
    "amostarde": "amostardar",
    "amostardei": "amostardar",
    "amostardeis": "amostardar",
    "amostardem": "amostardar",
    "amostardemo": "amostardar",
    "amostardemos": "amostardar",
    "amostardes": "amostardar",
    "amostardo": "amostardar",
    "amostardou": "amostardar",
    "amostardá": "amostardar",
    "amostardámo": "amostardar",
    "amostardámos": "amostardar",
    "amostardáramo": "amostardar",
    "amostardáramos": "amostardar",
    "amostardárei": "amostardar",
    "amostardáreis": "amostardar",
    "amostardásseis": "amostardar",
    "amostardássemos": "amostardar",
    "amostardávamo": "amostardar",
    "amostardávamos": "amostardar",
    "amostardávei": "amostardar",
    "amostardáveis": "amostardar",
    "amostra": "amostrar",
    "amostrada": "amostrar",
    "amostradas": "amostrar",
    "amostradiça": "amostradiço",
    "amostradiças": "amostradiço",
    "amostradiços": "amostradiço",
    "amostrado": "amostrar",
    "amostrados": "amostrar",
    "amostragens": "amostragem",
    "amostrai": "amostrar",
    "amostrais": "amostrar",
    "amostram": "amostrar",
    "amostramo": "amostrar",
    "amostramos": "amostrar",
    "amostrando": "amostrar",
    "amostrara": "amostrar",
    "amostraram": "amostrar",
    "amostraras": "amostrar",
    "amostrarde": "amostrar",
    "amostrardes": "amostrar",
    "amostrare": "amostrar",
    "amostrarei": "amostrar",
    "amostrareis": "amostrar",
    "amostrarem": "amostrar",
    "amostraremos": "amostrar",
    "amostrares": "amostrar",
    "amostraria": "amostrar",
    "amostrariam": "amostrar",
    "amostrarias": "amostrar",
    "amostrarmo": "amostrar",
    "amostrarmos": "amostrar",
    "amostrará": "amostrar",
    "amostrarás": "amostrar",
    "amostrarão": "amostrar",
    "amostraríamos": "amostrar",
    "amostraríeis": "amostrar",
    "amostras": "amostrar",
    "amostrasse": "amostrar",
    "amostrassem": "amostrar",
    "amostrasses": "amostrar",
    "amostraste": "amostrar",
    "amostrastes": "amostrar",
    "amostrava": "amostrar",
    "amostravam": "amostrar",
    "amostravas": "amostrar",
    "amostre": "amostrar",
    "amostrei": "amostrar",
    "amostreis": "amostrar",
    "amostrem": "amostrar",
    "amostremo": "amostrar",
    "amostremos": "amostrar",
    "amostres": "amostrar",
    "amostrinha": "amostra",
    "amostrinhas": "amostra",
    "amostrita": "amostra",
    "amostritas": "amostra",
    "amostro": "amostrar",
    "amostrou": "amostrar",
    "amostrá": "amostrar",
    "amostrámo": "amostrar",
    "amostrámos": "amostrar",
    "amostráramo": "amostrar",
    "amostráramos": "amostrar",
    "amostrárei": "amostrar",
    "amostráreis": "amostrar",
    "amostrásseis": "amostrar",
    "amostrássemos": "amostrar",
    "amostrávamo": "amostrar",
    "amostrávamos": "amostrar",
    "amostrávei": "amostrar",
    "amostráveis": "amostrar",
    "amota": "amotar",
    "amotada": "amotar",
    "amotadas": "amotar",
    "amotado": "amotar",
    "amotados": "amotar",
    "amotai": "amotar",
    "amotais": "amotar",
    "amotam": "amotar",
    "amotamo": "amotar",
    "amotamos": "amotar",
    "amotando": "amotar",
    "amotara": "amotar",
    "amotaram": "amotar",
    "amotaras": "amotar",
    "amotarde": "amotar",
    "amotardes": "amotar",
    "amotare": "amotar",
    "amotarei": "amotar",
    "amotareis": "amotar",
    "amotarem": "amotar",
    "amotaremos": "amotar",
    "amotares": "amotar",
    "amotaria": "amotar",
    "amotariam": "amotar",
    "amotarias": "amotar",
    "amotarmo": "amotar",
    "amotarmos": "amotar",
    "amotará": "amotar",
    "amotarás": "amotar",
    "amotarão": "amotar",
    "amotaríamos": "amotar",
    "amotaríeis": "amotar",
    "amotas": "amotar",
    "amotasse": "amotar",
    "amotassem": "amotar",
    "amotasses": "amotar",
    "amotaste": "amotar",
    "amotastes": "amotar",
    "amotava": "amotar",
    "amotavam": "amotar",
    "amotavas": "amotar",
    "amote": "amotar",
    "amotei": "amotar",
    "amoteis": "amotar",
    "amotem": "amotar",
    "amotemo": "amotar",
    "amotemos": "amotar",
    "amotes": "amotar",
    "amotina": "amotinar",
    "amotinada": "amotinar",
    "amotinadas": "amotinar",
    "amotinado": "amotinar",
    "amotinadora": "amotinador",
    "amotinadoras": "amotinador",
    "amotinadores": "amotinador",
    "amotinados": "amotinar",
    "amotinai": "amotinar",
    "amotinais": "amotinar",
    "amotinam": "amotinar",
    "amotinamo": "amotinar",
    "amotinamos": "amotinar",
    "amotinando": "amotinar",
    "amotinara": "amotinar",
    "amotinaram": "amotinar",
    "amotinaras": "amotinar",
    "amotinarde": "amotinar",
    "amotinardes": "amotinar",
    "amotinare": "amotinar",
    "amotinarei": "amotinar",
    "amotinareis": "amotinar",
    "amotinarem": "amotinar",
    "amotinaremos": "amotinar",
    "amotinares": "amotinar",
    "amotinaria": "amotinar",
    "amotinariam": "amotinar",
    "amotinarias": "amotinar",
    "amotinarmo": "amotinar",
    "amotinarmos": "amotinar",
    "amotinará": "amotinar",
    "amotinarás": "amotinar",
    "amotinarão": "amotinar",
    "amotinaríamos": "amotinar",
    "amotinaríeis": "amotinar",
    "amotinas": "amotinar",
    "amotinasse": "amotinar",
    "amotinassem": "amotinar",
    "amotinasses": "amotinar",
    "amotinaste": "amotinar",
    "amotinastes": "amotinar",
    "amotinava": "amotinar",
    "amotinavam": "amotinar",
    "amotinavas": "amotinar",
    "amotinações": "amotinação",
    "amotine": "amotinar",
    "amotinei": "amotinar",
    "amotineis": "amotinar",
    "amotinem": "amotinar",
    "amotinemo": "amotinar",
    "amotinemos": "amotinar",
    "amotines": "amotinar",
    "amotino": "amotinar",
    "amotinou": "amotinar",
    "amotiná": "amotinar",
    "amotinámo": "amotinar",
    "amotinámos": "amotinar",
    "amotináramo": "amotinar",
    "amotináramos": "amotinar",
    "amotinárei": "amotinar",
    "amotináreis": "amotinar",
    "amotinásseis": "amotinar",
    "amotinássemos": "amotinar",
    "amotinávamo": "amotinar",
    "amotinávamos": "amotinar",
    "amotinávei": "amotinar",
    "amotináveis": "amotinar",
    "amoto": "amotar",
    "amotou": "amotar",
    "amotá": "amotar",
    "amotámo": "amotar",
    "amotámos": "amotar",
    "amotáramo": "amotar",
    "amotáramos": "amotar",
    "amotárei": "amotar",
    "amotáreis": "amotar",
    "amotásseis": "amotar",
    "amotássemos": "amotar",
    "amotávamo": "amotar",
    "amotávamos": "amotar",
    "amotávei": "amotar",
    "amotáveis": "amotar",
    "amou": "amar",
    "amouca": "amoucar",
    "amoucada": "amoucar",
    "amoucadas": "amoucar",
    "amoucado": "amoucar",
    "amoucados": "amoucar",
    "amoucai": "amoucar",
    "amoucais": "amoucar",
    "amoucam": "amoucar",
    "amoucamo": "amoucar",
    "amoucamos": "amoucar",
    "amoucando": "amoucar",
    "amoucara": "amoucar",
    "amoucaram": "amoucar",
    "amoucaras": "amoucar",
    "amoucarde": "amoucar",
    "amoucardes": "amoucar",
    "amoucare": "amoucar",
    "amoucarei": "amoucar",
    "amoucareis": "amoucar",
    "amoucarem": "amoucar",
    "amoucaremos": "amoucar",
    "amoucares": "amoucar",
    "amoucaria": "amoucar",
    "amoucariam": "amoucar",
    "amoucarias": "amoucar",
    "amoucarmo": "amoucar",
    "amoucarmos": "amoucar",
    "amoucará": "amoucar",
    "amoucarás": "amoucar",
    "amoucarão": "amoucar",
    "amoucaríamos": "amoucar",
    "amoucaríeis": "amoucar",
    "amoucas": "amoucar",
    "amoucasse": "amoucar",
    "amoucassem": "amoucar",
    "amoucasses": "amoucar",
    "amoucaste": "amoucar",
    "amoucastes": "amoucar",
    "amoucava": "amoucar",
    "amoucavam": "amoucar",
    "amoucavas": "amoucar",
    "amouco": "amoucar",
    "amoucos": "amouco",
    "amoucou": "amoucar",
    "amoucá": "amoucar",
    "amoucámo": "amoucar",
    "amoucámos": "amoucar",
    "amoucáramo": "amoucar",
    "amoucáramos": "amoucar",
    "amoucárei": "amoucar",
    "amoucáreis": "amoucar",
    "amoucásseis": "amoucar",
    "amoucássemos": "amoucar",
    "amoucávamo": "amoucar",
    "amoucávamos": "amoucar",
    "amoucávei": "amoucar",
    "amoucáveis": "amoucar",
    "amouque": "amoucar",
    "amouquei": "amoucar",
    "amouqueis": "amoucar",
    "amouquem": "amoucar",
    "amouquemo": "amoucar",
    "amouquemos": "amoucar",
    "amouques": "amoucar",
    "amoura": "amourar",
    "amourada": "amourar",
    "amouradas": "amourar",
    "amourado": "amourar",
    "amourados": "amourar",
    "amourai": "amourar",
    "amourais": "amourar",
    "amouram": "amourar",
    "amouramo": "amourar",
    "amouramos": "amourar",
    "amourando": "amourar",
    "amourara": "amourar",
    "amouraram": "amourar",
    "amouraras": "amourar",
    "amourarde": "amourar",
    "amourardes": "amourar",
    "amourare": "amourar",
    "amourarei": "amourar",
    "amourareis": "amourar",
    "amourarem": "amourar",
    "amouraremos": "amourar",
    "amourares": "amourar",
    "amouraria": "amourar",
    "amourariam": "amourar",
    "amourarias": "amourar",
    "amourarmo": "amourar",
    "amourarmos": "amourar",
    "amourará": "amourar",
    "amourarás": "amourar",
    "amourarão": "amourar",
    "amouraríamos": "amourar",
    "amouraríeis": "amourar",
    "amouras": "amourar",
    "amourasse": "amourar",
    "amourassem": "amourar",
    "amourasses": "amourar",
    "amouraste": "amourar",
    "amourastes": "amourar",
    "amourava": "amourar",
    "amouravam": "amourar",
    "amouravas": "amourar",
    "amoure": "amourar",
    "amourei": "amourar",
    "amoureis": "amourar",
    "amourem": "amourar",
    "amouremo": "amourar",
    "amouremos": "amourar",
    "amoures": "amourar",
    "amourisca": "amouriscar",
    "amouriscada": "amouriscar",
    "amouriscadas": "amouriscar",
    "amouriscado": "amouriscar",
    "amouriscados": "amouriscar",
    "amouriscai": "amouriscar",
    "amouriscais": "amouriscar",
    "amouriscam": "amouriscar",
    "amouriscamo": "amouriscar",
    "amouriscamos": "amouriscar",
    "amouriscando": "amouriscar",
    "amouriscara": "amouriscar",
    "amouriscaram": "amouriscar",
    "amouriscaras": "amouriscar",
    "amouriscarde": "amouriscar",
    "amouriscardes": "amouriscar",
    "amouriscare": "amouriscar",
    "amouriscarei": "amouriscar",
    "amouriscareis": "amouriscar",
    "amouriscarem": "amouriscar",
    "amouriscaremos": "amouriscar",
    "amouriscares": "amouriscar",
    "amouriscaria": "amouriscar",
    "amouriscariam": "amouriscar",
    "amouriscarias": "amouriscar",
    "amouriscarmo": "amouriscar",
    "amouriscarmos": "amouriscar",
    "amouriscará": "amouriscar",
    "amouriscarás": "amouriscar",
    "amouriscarão": "amouriscar",
    "amouriscaríamos": "amouriscar",
    "amouriscaríeis": "amouriscar",
    "amouriscas": "amouriscar",
    "amouriscasse": "amouriscar",
    "amouriscassem": "amouriscar",
    "amouriscasses": "amouriscar",
    "amouriscaste": "amouriscar",
    "amouriscastes": "amouriscar",
    "amouriscava": "amouriscar",
    "amouriscavam": "amouriscar",
    "amouriscavas": "amouriscar",
    "amourisco": "amouriscar",
    "amouriscou": "amouriscar",
    "amouriscá": "amouriscar",
    "amouriscámo": "amouriscar",
    "amouriscámos": "amouriscar",
    "amouriscáramo": "amouriscar",
    "amouriscáramos": "amouriscar",
    "amouriscárei": "amouriscar",
    "amouriscáreis": "amouriscar",
    "amouriscásseis": "amouriscar",
    "amouriscássemos": "amouriscar",
    "amouriscávamo": "amouriscar",
    "amouriscávamos": "amouriscar",
    "amouriscávei": "amouriscar",
    "amouriscáveis": "amouriscar",
    "amourisque": "amouriscar",
    "amourisquei": "amouriscar",
    "amourisqueis": "amouriscar",
    "amourisquem": "amouriscar",
    "amourisquemo": "amouriscar",
    "amourisquemos": "amouriscar",
    "amourisques": "amouriscar",
    "amouro": "amourar",
    "amouroa": "amouroar",
    "amouroada": "amouroar",
    "amouroadas": "amouroar",
    "amouroado": "amouroar",
    "amouroados": "amouroar",
    "amouroai": "amouroar",
    "amouroais": "amouroar",
    "amouroam": "amouroar",
    "amouroamo": "amouroar",
    "amouroamos": "amouroar",
    "amouroando": "amouroar",
    "amouroara": "amouroar",
    "amouroaram": "amouroar",
    "amouroaras": "amouroar",
    "amouroarde": "amouroar",
    "amouroardes": "amouroar",
    "amouroare": "amouroar",
    "amouroarei": "amouroar",
    "amouroareis": "amouroar",
    "amouroarem": "amouroar",
    "amouroaremos": "amouroar",
    "amouroares": "amouroar",
    "amouroaria": "amouroar",
    "amouroariam": "amouroar",
    "amouroarias": "amouroar",
    "amouroarmo": "amouroar",
    "amouroarmos": "amouroar",
    "amouroará": "amouroar",
    "amouroarás": "amouroar",
    "amouroarão": "amouroar",
    "amouroaríamos": "amouroar",
    "amouroaríeis": "amouroar",
    "amouroas": "amouroar",
    "amouroasse": "amouroar",
    "amouroassem": "amouroar",
    "amouroasses": "amouroar",
    "amouroaste": "amouroar",
    "amouroastes": "amouroar",
    "amouroava": "amouroar",
    "amouroavam": "amouroar",
    "amouroavas": "amouroar",
    "amouroe": "amouroar",
    "amouroei": "amouroar",
    "amouroeis": "amouroar",
    "amouroem": "amouroar",
    "amouroemo": "amouroar",
    "amouroemos": "amouroar",
    "amouroes": "amouroar",
    "amouroo": "amouroar",
    "amouroou": "amouroar",
    "amourou": "amourar",
    "amouroá": "amouroar",
    "amouroámo": "amouroar",
    "amouroámos": "amouroar",
    "amouroáramo": "amouroar",
    "amouroáramos": "amouroar",
    "amouroárei": "amouroar",
    "amouroáreis": "amouroar",
    "amouroásseis": "amouroar",
    "amouroássemos": "amouroar",
    "amouroávamo": "amouroar",
    "amouroávamos": "amouroar",
    "amouroávei": "amouroar",
    "amouroáveis": "amouroar",
    "amourá": "amourar",
    "amourámo": "amourar",
    "amourámos": "amourar",
    "amouráramo": "amourar",
    "amouráramos": "amourar",
    "amourárei": "amourar",
    "amouráreis": "amourar",
    "amourásseis": "amourar",
    "amourássemos": "amourar",
    "amourávamo": "amourar",
    "amourávamos": "amourar",
    "amourávei": "amourar",
    "amouráveis": "amourar",
    "amouta": "amoutar",
    "amoutada": "amoutar",
    "amoutadas": "amoutar",
    "amoutado": "amoutar",
    "amoutados": "amoutar",
    "amoutai": "amoutar",
    "amoutais": "amoutar",
    "amoutam": "amoutar",
    "amoutamo": "amoutar",
    "amoutamos": "amoutar",
    "amoutando": "amoutar",
    "amoutara": "amoutar",
    "amoutaram": "amoutar",
    "amoutaras": "amoutar",
    "amoutarde": "amoutar",
    "amoutardes": "amoutar",
    "amoutare": "amoutar",
    "amoutarei": "amoutar",
    "amoutareis": "amoutar",
    "amoutarem": "amoutar",
    "amoutaremos": "amoutar",
    "amoutares": "amoutar",
    "amoutaria": "amoutar",
    "amoutariam": "amoutar",
    "amoutarias": "amoutar",
    "amoutarmo": "amoutar",
    "amoutarmos": "amoutar",
    "amoutará": "amoutar",
    "amoutarás": "amoutar",
    "amoutarão": "amoutar",
    "amoutaríamos": "amoutar",
    "amoutaríeis": "amoutar",
    "amoutas": "amoutar",
    "amoutasse": "amoutar",
    "amoutassem": "amoutar",
    "amoutasses": "amoutar",
    "amoutaste": "amoutar",
    "amoutastes": "amoutar",
    "amoutava": "amoutar",
    "amoutavam": "amoutar",
    "amoutavas": "amoutar",
    "amoute": "amoutar",
    "amoutei": "amoutar",
    "amouteis": "amoutar",
    "amoutem": "amoutar",
    "amoutemo": "amoutar",
    "amoutemos": "amoutar",
    "amoutes": "amoutar",
    "amouto": "amoutar",
    "amoutou": "amoutar",
    "amoutá": "amoutar",
    "amoutámo": "amoutar",
    "amoutámos": "amoutar",
    "amoutáramo": "amoutar",
    "amoutáramos": "amoutar",
    "amoutárei": "amoutar",
    "amoutáreis": "amoutar",
    "amoutásseis": "amoutar",
    "amoutássemos": "amoutar",
    "amoutávamo": "amoutar",
    "amoutávamos": "amoutar",
    "amoutávei": "amoutar",
    "amoutáveis": "amoutar",
    "amouxa": "amouxar",
    "amouxada": "amouxar",
    "amouxadas": "amouxar",
    "amouxado": "amouxar",
    "amouxados": "amouxar",
    "amouxai": "amouxar",
    "amouxais": "amouxar",
    "amouxam": "amouxar",
    "amouxamo": "amouxar",
    "amouxamos": "amouxar",
    "amouxando": "amouxar",
    "amouxara": "amouxar",
    "amouxaram": "amouxar",
    "amouxaras": "amouxar",
    "amouxarde": "amouxar",
    "amouxardes": "amouxar",
    "amouxare": "amouxar",
    "amouxarei": "amouxar",
    "amouxareis": "amouxar",
    "amouxarem": "amouxar",
    "amouxaremos": "amouxar",
    "amouxares": "amouxar",
    "amouxaria": "amouxar",
    "amouxariam": "amouxar",
    "amouxarias": "amouxar",
    "amouxarmo": "amouxar",
    "amouxarmos": "amouxar",
    "amouxará": "amouxar",
    "amouxarás": "amouxar",
    "amouxarão": "amouxar",
    "amouxaríamos": "amouxar",
    "amouxaríeis": "amouxar",
    "amouxas": "amouxar",
    "amouxasse": "amouxar",
    "amouxassem": "amouxar",
    "amouxasses": "amouxar",
    "amouxaste": "amouxar",
    "amouxastes": "amouxar",
    "amouxava": "amouxar",
    "amouxavam": "amouxar",
    "amouxavas": "amouxar",
    "amouxe": "amouxar",
    "amouxei": "amouxar",
    "amouxeis": "amouxar",
    "amouxem": "amouxar",
    "amouxemo": "amouxar",
    "amouxemos": "amouxar",
    "amouxes": "amouxar",
    "amouxo": "amouxar",
    "amouxos": "amouxo",
    "amouxou": "amouxar",
    "amouxá": "amouxar",
    "amouxámo": "amouxar",
    "amouxámos": "amouxar",
    "amouxáramo": "amouxar",
    "amouxáramos": "amouxar",
    "amouxárei": "amouxar",
    "amouxáreis": "amouxar",
    "amouxásseis": "amouxar",
    "amouxássemos": "amouxar",
    "amouxávamo": "amouxar",
    "amouxávamos": "amouxar",
    "amouxávei": "amouxar",
    "amouxáveis": "amouxar",
    "amova": "amover",
    "amovais": "amover",
    "amovam": "amover",
    "amovamo": "amover",
    "amovamos": "amover",
    "amovas": "amover",
    "amove": "amover",
    "amovei": "amover",
    "amoveis": "amover",
    "amovem": "amover",
    "amovemo": "amover",
    "amovemos": "amover",
    "amovendo": "amover",
    "amovera": "amover",
    "amoveram": "amover",
    "amoveras": "amover",
    "amoverde": "amover",
    "amoverdes": "amover",
    "amovere": "amover",
    "amoverei": "amover",
    "amovereis": "amover",
    "amoverem": "amover",
    "amoveremos": "amover",
    "amoveres": "amover",
    "amoveria": "amover",
    "amoveriam": "amover",
    "amoverias": "amover",
    "amovermo": "amover",
    "amovermos": "amover",
    "amoverá": "amover",
    "amoverás": "amover",
    "amoverão": "amover",
    "amoveríamos": "amover",
    "amoveríeis": "amover",
    "amoves": "amover",
    "amovesse": "amover",
    "amovessem": "amover",
    "amovesses": "amover",
    "amoveste": "amover",
    "amovestes": "amover",
    "amoveu": "amover",
    "amovi": "amover",
    "amovia": "amover",
    "amoviam": "amover",
    "amovias": "amover",
    "amovibilidades": "amovibilidade",
    "amovida": "amover",
    "amovidas": "amover",
    "amovido": "amover",
    "amovidos": "amover",
    "amovo": "amover",
    "amovê": "amover",
    "amovêramo": "amover",
    "amovêramos": "amover",
    "amovêrei": "amover",
    "amovêreis": "amover",
    "amovêsseis": "amover",
    "amovêssemos": "amover",
    "amovíamo": "amover",
    "amovíamos": "amover",
    "amovíei": "amover",
    "amovíeis": "amover",
    "amovíveis": "amovível",
    "amoxama": "amoxamar",
    "amoxamada": "amoxamar",
    "amoxamadas": "amoxamar",
    "amoxamado": "amoxamar",
    "amoxamados": "amoxamar",
    "amoxamai": "amoxamar",
    "amoxamais": "amoxamar",
    "amoxamam": "amoxamar",
    "amoxamamo": "amoxamar",
    "amoxamamos": "amoxamar",
    "amoxamando": "amoxamar",
    "amoxamara": "amoxamar",
    "amoxamaram": "amoxamar",
    "amoxamaras": "amoxamar",
    "amoxamarde": "amoxamar",
    "amoxamardes": "amoxamar",
    "amoxamare": "amoxamar",
    "amoxamarei": "amoxamar",
    "amoxamareis": "amoxamar",
    "amoxamarem": "amoxamar",
    "amoxamaremos": "amoxamar",
    "amoxamares": "amoxamar",
    "amoxamaria": "amoxamar",
    "amoxamariam": "amoxamar",
    "amoxamarias": "amoxamar",
    "amoxamarmo": "amoxamar",
    "amoxamarmos": "amoxamar",
    "amoxamará": "amoxamar",
    "amoxamarás": "amoxamar",
    "amoxamarão": "amoxamar",
    "amoxamaríamos": "amoxamar",
    "amoxamaríeis": "amoxamar",
    "amoxamas": "amoxamar",
    "amoxamasse": "amoxamar",
    "amoxamassem": "amoxamar",
    "amoxamasses": "amoxamar",
    "amoxamaste": "amoxamar",
    "amoxamastes": "amoxamar",
    "amoxamava": "amoxamar",
    "amoxamavam": "amoxamar",
    "amoxamavas": "amoxamar",
    "amoxame": "amoxamar",
    "amoxamei": "amoxamar",
    "amoxameis": "amoxamar",
    "amoxamem": "amoxamar",
    "amoxamemo": "amoxamar",
    "amoxamemos": "amoxamar",
    "amoxames": "amoxamar",
    "amoxamo": "amoxamar",
    "amoxamou": "amoxamar",
    "amoxamá": "amoxamar",
    "amoxamámo": "amoxamar",
    "amoxamámos": "amoxamar",
    "amoxamáramo": "amoxamar",
    "amoxamáramos": "amoxamar",
    "amoxamárei": "amoxamar",
    "amoxamáreis": "amoxamar",
    "amoxamásseis": "amoxamar",
    "amoxamássemos": "amoxamar",
    "amoxamávamo": "amoxamar",
    "amoxamávamos": "amoxamar",
    "amoxamávei": "amoxamar",
    "amoxamáveis": "amoxamar",
    "ampara": "amparar",
    "amparada": "amparar",
    "amparadas": "amparar",
    "amparado": "amparar",
    "amparadora": "amparador",
    "amparadoras": "amparador",
    "amparadores": "amparador",
    "amparados": "amparar",
    "amparai": "amparar",
    "amparais": "amparar",
    "amparam": "amparar",
    "amparamentos": "amparamento",
    "amparamo": "amparar",
    "amparamos": "amparar",
    "amparando": "amparar",
    "amparara": "amparar",
    "ampararam": "amparar",
    "ampararas": "amparar",
    "ampararde": "amparar",
    "amparardes": "amparar",
    "amparare": "amparar",
    "ampararei": "amparar",
    "amparareis": "amparar",
    "ampararem": "amparar",
    "ampararemos": "amparar",
    "amparares": "amparar",
    "ampararia": "amparar",
    "amparariam": "amparar",
    "ampararias": "amparar",
    "ampararmo": "amparar",
    "ampararmos": "amparar",
    "amparará": "amparar",
    "ampararás": "amparar",
    "ampararão": "amparar",
    "ampararíamos": "amparar",
    "ampararíeis": "amparar",
    "amparas": "amparar",
    "amparasse": "amparar",
    "amparassem": "amparar",
    "amparasses": "amparar",
    "amparaste": "amparar",
    "amparastes": "amparar",
    "amparava": "amparar",
    "amparavam": "amparar",
    "amparavas": "amparar",
    "ampare": "amparar",
    "amparei": "amparar",
    "ampareis": "amparar",
    "amparem": "amparar",
    "amparemo": "amparar",
    "amparemos": "amparar",
    "ampares": "amparar",
    "amparo": "amparar",
    "amparos": "amparo",
    "amparou": "amparar",
    "ampará": "amparar",
    "amparámo": "amparar",
    "amparámos": "amparar",
    "amparáramo": "amparar",
    "amparáramos": "amparar",
    "amparárei": "amparar",
    "amparáreis": "amparar",
    "amparásseis": "amparar",
    "amparássemos": "amparar",
    "amparávamo": "amparar",
    "amparávamos": "amparar",
    "amparávei": "amparar",
    "amparáveis": "amparar",
    "ampelidácea": "ampelidáceo",
    "ampelidáceas": "ampelidáceo",
    "ampelidáceos": "ampelidáceo",
    "ampelites": "ampelite",
    "ampelitos": "ampelito",
    "ampelofagias": "ampelofagia",
    "ampelografias": "ampelografia",
    "ampelologias": "ampelologia",
    "ampelológica": "ampelológico",
    "ampelológicas": "ampelológico",
    "ampelológicos": "ampelológico",
    "ampeloterapias": "ampeloterapia",
    "ampelídea": "ampelídeo",
    "ampelídeas": "ampelídeo",
    "ampelídeos": "ampelídeo",
    "ampelófaga": "ampelófago",
    "ampelófagas": "ampelófago",
    "ampelófagos": "ampelófago",
    "ampelógrafos": "ampelógrafo",
    "ampelóloga": "ampelólogo",
    "ampelólogas": "ampelólogo",
    "ampelólogos": "ampelólogo",
    "amperagens": "amperagem",
    "amperes": "ampere",
    "amperímetros": "amperímetro",
    "ampicilinas": "ampicilina",
    "ampla": "amplo",
    "amplas": "amplo",
    "amplectiva": "amplectivo",
    "amplectivas": "amplectivo",
    "amplectivos": "amplectivo",
    "amplexicaudes": "amplexicaude",
    "amplexiflora": "amplexifloro",
    "amplexifloras": "amplexifloro",
    "amplexifloros": "amplexifloro",
    "amplexifólia": "amplexifólio",
    "amplexifólias": "amplexifólio",
    "amplexifólios": "amplexifólio",
    "amplexiva": "amplexivo",
    "amplexivas": "amplexivo",
    "amplexivos": "amplexivo",
    "amplexos": "amplexo",
    "amplia": "ampliar",
    "ampliada": "ampliar",
    "ampliadas": "ampliar",
    "ampliado": "ampliar",
    "ampliadora": "ampliador",
    "ampliadoras": "ampliador",
    "ampliadores": "ampliador",
    "ampliados": "ampliar",
    "ampliadíssima": "ampliado",
    "ampliadíssimas": "ampliado",
    "ampliadíssimo": "ampliado",
    "ampliadíssimos": "ampliado",
    "ampliai": "ampliar",
    "ampliais": "ampliar",
    "ampliam": "ampliar",
    "ampliamo": "ampliar",
    "ampliamos": "ampliar",
    "ampliando": "ampliar",
    "ampliara": "ampliar",
    "ampliaram": "ampliar",
    "ampliaras": "ampliar",
    "ampliarde": "ampliar",
    "ampliardes": "ampliar",
    "ampliare": "ampliar",
    "ampliarei": "ampliar",
    "ampliareis": "ampliar",
    "ampliarem": "ampliar",
    "ampliaremos": "ampliar",
    "ampliares": "ampliar",
    "ampliaria": "ampliar",
    "ampliariam": "ampliar",
    "ampliarias": "ampliar",
    "ampliarmo": "ampliar",
    "ampliarmos": "ampliar",
    "ampliará": "ampliar",
    "ampliarás": "ampliar",
    "ampliarão": "ampliar",
    "ampliaríamos": "ampliar",
    "ampliaríeis": "ampliar",
    "amplias": "ampliar",
    "ampliasse": "ampliar",
    "ampliassem": "ampliar",
    "ampliasses": "ampliar",
    "ampliaste": "ampliar",
    "ampliastes": "ampliar",
    "ampliativa": "ampliativo",
    "ampliativas": "ampliativo",
    "ampliativos": "ampliativo",
    "ampliatória": "ampliatório",
    "ampliatórias": "ampliatório",
    "ampliatórios": "ampliatório",
    "ampliava": "ampliar",
    "ampliavam": "ampliar",
    "ampliavas": "ampliar",
    "ampliações": "ampliação",
    "amplidões": "amplidão",
    "amplie": "ampliar",
    "ampliei": "ampliar",
    "amplieis": "ampliar",
    "ampliem": "ampliar",
    "ampliemo": "ampliar",
    "ampliemos": "ampliar",
    "amplies": "ampliar",
    "amplifica": "amplificar",
    "amplificada": "amplificar",
    "amplificadas": "amplificar",
    "amplificado": "amplificar",
    "amplificadora": "amplificador",
    "amplificadoras": "amplificador",
    "amplificadores": "amplificador",
    "amplificados": "amplificar",
    "amplificai": "amplificar",
    "amplificais": "amplificar",
    "amplificam": "amplificar",
    "amplificamo": "amplificar",
    "amplificamos": "amplificar",
    "amplificando": "amplificar",
    "amplificara": "amplificar",
    "amplificaram": "amplificar",
    "amplificaras": "amplificar",
    "amplificarde": "amplificar",
    "amplificardes": "amplificar",
    "amplificare": "amplificar",
    "amplificarei": "amplificar",
    "amplificareis": "amplificar",
    "amplificarem": "amplificar",
    "amplificaremos": "amplificar",
    "amplificares": "amplificar",
    "amplificaria": "amplificar",
    "amplificariam": "amplificar",
    "amplificarias": "amplificar",
    "amplificarmo": "amplificar",
    "amplificarmos": "amplificar",
    "amplificará": "amplificar",
    "amplificarás": "amplificar",
    "amplificarão": "amplificar",
    "amplificaríamos": "amplificar",
    "amplificaríeis": "amplificar",
    "amplificas": "amplificar",
    "amplificasse": "amplificar",
    "amplificassem": "amplificar",
    "amplificasses": "amplificar",
    "amplificaste": "amplificar",
    "amplificastes": "amplificar",
    "amplificativa": "amplificativo",
    "amplificativas": "amplificativo",
    "amplificativos": "amplificativo",
    "amplificava": "amplificar",
    "amplificavam": "amplificar",
    "amplificavas": "amplificar",
    "amplificações": "amplificação",
    "amplifico": "amplificar",
    "amplificou": "amplificar",
    "amplificá": "amplificar",
    "amplificámo": "amplificar",
    "amplificámos": "amplificar",
    "amplificáramo": "amplificar",
    "amplificáramos": "amplificar",
    "amplificárei": "amplificar",
    "amplificáreis": "amplificar",
    "amplificásseis": "amplificar",
    "amplificássemos": "amplificar",
    "amplificávamo": "amplificar",
    "amplificávamos": "amplificar",
    "amplificávei": "amplificar",
    "amplificáveis": "amplificável",
    "amplifique": "amplificar",
    "amplifiquei": "amplificar",
    "amplifiqueis": "amplificar",
    "amplifiquem": "amplificar",
    "amplifiquemo": "amplificar",
    "amplifiquemos": "amplificar",
    "amplifiques": "amplificar",
    "amplimamosa": "amplimamoso",
    "amplimamosas": "amplimamoso",
    "amplimamosos": "amplimamoso",
    "amplio": "ampliar",
    "ampliou": "ampliar",
    "amplitudes": "amplitude",
    "ampliá": "ampliar",
    "ampliámo": "ampliar",
    "ampliámos": "ampliar",
    "ampliáramo": "ampliar",
    "ampliáramos": "ampliar",
    "ampliárei": "ampliar",
    "ampliáreis": "ampliar",
    "ampliásseis": "ampliar",
    "ampliássemos": "ampliar",
    "ampliávamo": "ampliar",
    "ampliávamos": "ampliar",
    "ampliávei": "ampliar",
    "ampliáveis": "ampliável",
    "amplos": "amplo",
    "amplíssima": "amplo",
    "amplíssimas": "amplo",
    "amplíssimo": "amplo",
    "amplíssimos": "amplo",
    "ampolas": "ampola",
    "ampolha": "ampolhar",
    "ampolhada": "ampolhar",
    "ampolhadas": "ampolhar",
    "ampolhado": "ampolhar",
    "ampolhados": "ampolhar",
    "ampolhai": "ampolhar",
    "ampolhais": "ampolhar",
    "ampolham": "ampolhar",
    "ampolhamo": "ampolhar",
    "ampolhamos": "ampolhar",
    "ampolhando": "ampolhar",
    "ampolhara": "ampolhar",
    "ampolharam": "ampolhar",
    "ampolharas": "ampolhar",
    "ampolharde": "ampolhar",
    "ampolhardes": "ampolhar",
    "ampolhare": "ampolhar",
    "ampolharei": "ampolhar",
    "ampolhareis": "ampolhar",
    "ampolharem": "ampolhar",
    "ampolharemos": "ampolhar",
    "ampolhares": "ampolhar",
    "ampolharia": "ampolhar",
    "ampolhariam": "ampolhar",
    "ampolharias": "ampolhar",
    "ampolharmo": "ampolhar",
    "ampolharmos": "ampolhar",
    "ampolhará": "ampolhar",
    "ampolharás": "ampolhar",
    "ampolharão": "ampolhar",
    "ampolharíamos": "ampolhar",
    "ampolharíeis": "ampolhar",
    "ampolhas": "ampolhar",
    "ampolhasse": "ampolhar",
    "ampolhassem": "ampolhar",
    "ampolhasses": "ampolhar",
    "ampolhaste": "ampolhar",
    "ampolhastes": "ampolhar",
    "ampolhava": "ampolhar",
    "ampolhavam": "ampolhar",
    "ampolhavas": "ampolhar",
    "ampolhe": "ampolhar",
    "ampolhei": "ampolhar",
    "ampolheis": "ampolhar",
    "ampolhem": "ampolhar",
    "ampolhemo": "ampolhar",
    "ampolhemos": "ampolhar",
    "ampolhes": "ampolhar",
    "ampolho": "ampolhar",
    "ampolhou": "ampolhar",
    "ampolhá": "ampolhar",
    "ampolhámo": "ampolhar",
    "ampolhámos": "ampolhar",
    "ampolháramo": "ampolhar",
    "ampolháramos": "ampolhar",
    "ampolhárei": "ampolhar",
    "ampolháreis": "ampolhar",
    "ampolhásseis": "ampolhar",
    "ampolhássemos": "ampolhar",
    "ampolhávamo": "ampolhar",
    "ampolhávamos": "ampolhar",
    "ampolhávei": "ampolhar",
    "ampolháveis": "ampolhar",
    "ampulhetas": "ampulheta",
    "amputa": "amputar",
    "amputada": "amputar",
    "amputadas": "amputar",
    "amputado": "amputar",
    "amputados": "amputar",
    "amputai": "amputar",
    "amputais": "amputar",
    "amputam": "amputar",
    "amputamo": "amputar",
    "amputamos": "amputar",
    "amputando": "amputar",
    "amputara": "amputar",
    "amputaram": "amputar",
    "amputaras": "amputar",
    "amputarde": "amputar",
    "amputardes": "amputar",
    "amputare": "amputar",
    "amputarei": "amputar",
    "amputareis": "amputar",
    "amputarem": "amputar",
    "amputaremos": "amputar",
    "amputares": "amputar",
    "amputaria": "amputar",
    "amputariam": "amputar",
    "amputarias": "amputar",
    "amputarmo": "amputar",
    "amputarmos": "amputar",
    "amputará": "amputar",
    "amputarás": "amputar",
    "amputarão": "amputar",
    "amputaríamos": "amputar",
    "amputaríeis": "amputar",
    "amputas": "amputar",
    "amputasse": "amputar",
    "amputassem": "amputar",
    "amputasses": "amputar",
    "amputaste": "amputar",
    "amputastes": "amputar",
    "amputava": "amputar",
    "amputavam": "amputar",
    "amputavas": "amputar",
    "amputações": "amputação",
    "ampute": "amputar",
    "amputei": "amputar",
    "amputeis": "amputar",
    "amputem": "amputar",
    "amputemo": "amputar",
    "amputemos": "amputar",
    "amputes": "amputar",
    "amputo": "amputar",
    "amputou": "amputar",
    "amputá": "amputar",
    "amputámo": "amputar",
    "amputámos": "amputar",
    "amputáramo": "amputar",
    "amputáramos": "amputar",
    "amputárei": "amputar",
    "amputáreis": "amputar",
    "amputásseis": "amputar",
    "amputássemos": "amputar",
    "amputávamo": "amputar",
    "amputávamos": "amputar",
    "amputávei": "amputar",
    "amputáveis": "amputar",
    "ampères": "ampère",
    "ampélidas": "ampélida",
    "amua": "amuar",
    "amuada": "amuar",
    "amuadas": "amuar",
    "amuado": "amuar",
    "amuados": "amuar",
    "amuadíssima": "amuado",
    "amuadíssimas": "amuado",
    "amuadíssimo": "amuado",
    "amuadíssimos": "amuado",
    "amuai": "amuar",
    "amuais": "amuar",
    "amuam": "amuar",
    "amuamentos": "amuamento",
    "amuamo": "amuar",
    "amuamos": "amuar",
    "amuando": "amuar",
    "amuara": "amuar",
    "amuaram": "amuar",
    "amuaras": "amuar",
    "amuardes": "amuar",
    "amuarei": "amuar",
    "amuareis": "amuar",
    "amuarem": "amuar",
    "amuaremos": "amuar",
    "amuares": "amuar",
    "amuaria": "amuar",
    "amuariam": "amuar",
    "amuarias": "amuar",
    "amuarmo": "amuar",
    "amuarmos": "amuar",
    "amuará": "amuar",
    "amuarás": "amuar",
    "amuarão": "amuar",
    "amuaríamos": "amuar",
    "amuaríeis": "amuar",
    "amuas": "amuar",
    "amuasse": "amuar",
    "amuassem": "amuar",
    "amuasses": "amuar",
    "amuaste": "amuar",
    "amuastes": "amuar",
    "amuava": "amuar",
    "amuavam": "amuar",
    "amuavas": "amuar",
    "amue": "amuar",
    "amuei": "amuar",
    "amueis": "amuar",
    "amuem": "amuar",
    "amuemo": "amuar",
    "amuemos": "amuar",
    "amues": "amuar",
    "amuganha": "amuganhar",
    "amuganhada": "amuganhar",
    "amuganhadas": "amuganhar",
    "amuganhado": "amuganhar",
    "amuganhados": "amuganhar",
    "amuganhai": "amuganhar",
    "amuganhais": "amuganhar",
    "amuganham": "amuganhar",
    "amuganhamo": "amuganhar",
    "amuganhamos": "amuganhar",
    "amuganhando": "amuganhar",
    "amuganhara": "amuganhar",
    "amuganharam": "amuganhar",
    "amuganharas": "amuganhar",
    "amuganharde": "amuganhar",
    "amuganhardes": "amuganhar",
    "amuganhare": "amuganhar",
    "amuganharei": "amuganhar",
    "amuganhareis": "amuganhar",
    "amuganharem": "amuganhar",
    "amuganharemos": "amuganhar",
    "amuganhares": "amuganhar",
    "amuganharia": "amuganhar",
    "amuganhariam": "amuganhar",
    "amuganharias": "amuganhar",
    "amuganharmo": "amuganhar",
    "amuganharmos": "amuganhar",
    "amuganhará": "amuganhar",
    "amuganharás": "amuganhar",
    "amuganharão": "amuganhar",
    "amuganharíamos": "amuganhar",
    "amuganharíeis": "amuganhar",
    "amuganhas": "amuganhar",
    "amuganhasse": "amuganhar",
    "amuganhassem": "amuganhar",
    "amuganhasses": "amuganhar",
    "amuganhaste": "amuganhar",
    "amuganhastes": "amuganhar",
    "amuganhava": "amuganhar",
    "amuganhavam": "amuganhar",
    "amuganhavas": "amuganhar",
    "amuganhe": "amuganhar",
    "amuganhei": "amuganhar",
    "amuganheis": "amuganhar",
    "amuganhem": "amuganhar",
    "amuganhemo": "amuganhar",
    "amuganhemos": "amuganhar",
    "amuganhes": "amuganhar",
    "amuganho": "amuganhar",
    "amuganhou": "amuganhar",
    "amuganhá": "amuganhar",
    "amuganhámo": "amuganhar",
    "amuganhámos": "amuganhar",
    "amuganháramo": "amuganhar",
    "amuganháramos": "amuganhar",
    "amuganhárei": "amuganhar",
    "amuganháreis": "amuganhar",
    "amuganhásseis": "amuganhar",
    "amuganhássemos": "amuganhar",
    "amuganhávamo": "amuganhar",
    "amuganhávamos": "amuganhar",
    "amuganhávei": "amuganhar",
    "amuganháveis": "amuganhar",
    "amulata": "amulatar",
    "amulatada": "amulatar",
    "amulatadas": "amulatar",
    "amulatado": "amulatar",
    "amulatados": "amulatar",
    "amulatai": "amulatar",
    "amulatais": "amulatar",
    "amulatam": "amulatar",
    "amulatamo": "amulatar",
    "amulatamos": "amulatar",
    "amulatando": "amulatar",
    "amulatara": "amulatar",
    "amulataram": "amulatar",
    "amulataras": "amulatar",
    "amulatarde": "amulatar",
    "amulatardes": "amulatar",
    "amulatare": "amulatar",
    "amulatarei": "amulatar",
    "amulatareis": "amulatar",
    "amulatarem": "amulatar",
    "amulataremos": "amulatar",
    "amulatares": "amulatar",
    "amulataria": "amulatar",
    "amulatariam": "amulatar",
    "amulatarias": "amulatar",
    "amulatarmo": "amulatar",
    "amulatarmos": "amulatar",
    "amulatará": "amulatar",
    "amulatarás": "amulatar",
    "amulatarão": "amulatar",
    "amulataríamos": "amulatar",
    "amulataríeis": "amulatar",
    "amulatas": "amulatar",
    "amulatasse": "amulatar",
    "amulatassem": "amulatar",
    "amulatasses": "amulatar",
    "amulataste": "amulatar",
    "amulatastes": "amulatar",
    "amulatava": "amulatar",
    "amulatavam": "amulatar",
    "amulatavas": "amulatar",
    "amulate": "amulatar",
    "amulatei": "amulatar",
    "amulateis": "amulatar",
    "amulatem": "amulatar",
    "amulatemo": "amulatar",
    "amulatemos": "amulatar",
    "amulates": "amulatar",
    "amulato": "amulatar",
    "amulatou": "amulatar",
    "amulatá": "amulatar",
    "amulatámo": "amulatar",
    "amulatámos": "amulatar",
    "amulatáramo": "amulatar",
    "amulatáramos": "amulatar",
    "amulatárei": "amulatar",
    "amulatáreis": "amulatar",
    "amulatásseis": "amulatar",
    "amulatássemos": "amulatar",
    "amulatávamo": "amulatar",
    "amulatávamos": "amulatar",
    "amulatávei": "amulatar",
    "amulatáveis": "amulatar",
    "amuletos": "amuleto",
    "amulhera": "amulherar",
    "amulherada": "amulherar",
    "amulheradas": "amulherar",
    "amulherado": "amulherar",
    "amulherados": "amulherar",
    "amulherai": "amulherar",
    "amulherais": "amulherar",
    "amulheram": "amulherar",
    "amulheramo": "amulherar",
    "amulheramos": "amulherar",
    "amulherando": "amulherar",
    "amulherara": "amulherar",
    "amulheraram": "amulherar",
    "amulheraras": "amulherar",
    "amulherarde": "amulherar",
    "amulherardes": "amulherar",
    "amulherare": "amulherar",
    "amulherarei": "amulherar",
    "amulherareis": "amulherar",
    "amulherarem": "amulherar",
    "amulheraremos": "amulherar",
    "amulherares": "amulherar",
    "amulheraria": "amulherar",
    "amulherariam": "amulherar",
    "amulherarias": "amulherar",
    "amulherarmo": "amulherar",
    "amulherarmos": "amulherar",
    "amulherará": "amulherar",
    "amulherarás": "amulherar",
    "amulherarão": "amulherar",
    "amulheraríamos": "amulherar",
    "amulheraríeis": "amulherar",
    "amulheras": "amulherar",
    "amulherasse": "amulherar",
    "amulherassem": "amulherar",
    "amulherasses": "amulherar",
    "amulheraste": "amulherar",
    "amulherastes": "amulherar",
    "amulherava": "amulherar",
    "amulheravam": "amulherar",
    "amulheravas": "amulherar",
    "amulhere": "amulherar",
    "amulherei": "amulherar",
    "amulhereis": "amulherar",
    "amulherem": "amulherar",
    "amulheremo": "amulherar",
    "amulheremos": "amulherar",
    "amulherenga": "amulherengar",
    "amulherengada": "amulherengar",
    "amulherengadas": "amulherengar",
    "amulherengado": "amulherengar",
    "amulherengados": "amulherengar",
    "amulherengai": "amulherengar",
    "amulherengais": "amulherengar",
    "amulherengam": "amulherengar",
    "amulherengamo": "amulherengar",
    "amulherengamos": "amulherengar",
    "amulherengando": "amulherengar",
    "amulherengara": "amulherengar",
    "amulherengaram": "amulherengar",
    "amulherengaras": "amulherengar",
    "amulherengarde": "amulherengar",
    "amulherengardes": "amulherengar",
    "amulherengare": "amulherengar",
    "amulherengarei": "amulherengar",
    "amulherengareis": "amulherengar",
    "amulherengarem": "amulherengar",
    "amulherengaremos": "amulherengar",
    "amulherengares": "amulherengar",
    "amulherengaria": "amulherengar",
    "amulherengariam": "amulherengar",
    "amulherengarias": "amulherengar",
    "amulherengarmo": "amulherengar",
    "amulherengarmos": "amulherengar",
    "amulherengará": "amulherengar",
    "amulherengarás": "amulherengar",
    "amulherengarão": "amulherengar",
    "amulherengaríamos": "amulherengar",
    "amulherengaríeis": "amulherengar",
    "amulherengas": "amulherengar",
    "amulherengasse": "amulherengar",
    "amulherengassem": "amulherengar",
    "amulherengasses": "amulherengar",
    "amulherengaste": "amulherengar",
    "amulherengastes": "amulherengar",
    "amulherengava": "amulherengar",
    "amulherengavam": "amulherengar",
    "amulherengavas": "amulherengar",
    "amulherengo": "amulherengar",
    "amulherengou": "amulherengar",
    "amulherengue": "amulherengar",
    "amulherenguei": "amulherengar",
    "amulherengueis": "amulherengar",
    "amulherenguem": "amulherengar",
    "amulherenguemo": "amulherengar",
    "amulherenguemos": "amulherengar",
    "amulherengues": "amulherengar",
    "amulherengá": "amulherengar",
    "amulherengámo": "amulherengar",
    "amulherengámos": "amulherengar",
    "amulherengáramo": "amulherengar",
    "amulherengáramos": "amulherengar",
    "amulherengárei": "amulherengar",
    "amulherengáreis": "amulherengar",
    "amulherengásseis": "amulherengar",
    "amulherengássemos": "amulherengar",
    "amulherengávamo": "amulherengar",
    "amulherengávamos": "amulherengar",
    "amulherengávei": "amulherengar",
    "amulherengáveis": "amulherengar",
    "amulheres": "amulherar",
    "amulhero": "amulherar",
    "amulherou": "amulherar",
    "amulherá": "amulherar",
    "amulherámo": "amulherar",
    "amulherámos": "amulherar",
    "amulheráramo": "amulherar",
    "amulheráramos": "amulherar",
    "amulherárei": "amulherar",
    "amulheráreis": "amulherar",
    "amulherásseis": "amulherar",
    "amulherássemos": "amulherar",
    "amulherávamo": "amulherar",
    "amulherávamos": "amulherar",
    "amulherávei": "amulherar",
    "amulheráveis": "amulherar",
    "amulética": "amulético",
    "amuléticas": "amulético",
    "amuléticos": "amulético",
    "amumia": "amumiar",
    "amumiada": "amumiar",
    "amumiadas": "amumiar",
    "amumiado": "amumiar",
    "amumiados": "amumiar",
    "amumiai": "amumiar",
    "amumiais": "amumiar",
    "amumiam": "amumiar",
    "amumiamo": "amumiar",
    "amumiamos": "amumiar",
    "amumiando": "amumiar",
    "amumiara": "amumiar",
    "amumiaram": "amumiar",
    "amumiaras": "amumiar",
    "amumiarde": "amumiar",
    "amumiardes": "amumiar",
    "amumiare": "amumiar",
    "amumiarei": "amumiar",
    "amumiareis": "amumiar",
    "amumiarem": "amumiar",
    "amumiaremos": "amumiar",
    "amumiares": "amumiar",
    "amumiaria": "amumiar",
    "amumiariam": "amumiar",
    "amumiarias": "amumiar",
    "amumiarmo": "amumiar",
    "amumiarmos": "amumiar",
    "amumiará": "amumiar",
    "amumiarás": "amumiar",
    "amumiarão": "amumiar",
    "amumiaríamos": "amumiar",
    "amumiaríeis": "amumiar",
    "amumias": "amumiar",
    "amumiasse": "amumiar",
    "amumiassem": "amumiar",
    "amumiasses": "amumiar",
    "amumiaste": "amumiar",
    "amumiastes": "amumiar",
    "amumiava": "amumiar",
    "amumiavam": "amumiar",
    "amumiavas": "amumiar",
    "amumie": "amumiar",
    "amumiei": "amumiar",
    "amumieis": "amumiar",
    "amumiem": "amumiar",
    "amumiemo": "amumiar",
    "amumiemos": "amumiar",
    "amumies": "amumiar",
    "amumio": "amumiar",
    "amumiou": "amumiar",
    "amumiá": "amumiar",
    "amumiámo": "amumiar",
    "amumiámos": "amumiar",
    "amumiáramo": "amumiar",
    "amumiáramos": "amumiar",
    "amumiárei": "amumiar",
    "amumiáreis": "amumiar",
    "amumiásseis": "amumiar",
    "amumiássemos": "amumiar",
    "amumiávamo": "amumiar",
    "amumiávamos": "amumiar",
    "amumiávei": "amumiar",
    "amumiáveis": "amumiar",
    "amunicia": "amuniciar",
    "amuniciada": "amuniciar",
    "amuniciadas": "amuniciar",
    "amuniciado": "amuniciar",
    "amuniciados": "amuniciar",
    "amuniciai": "amuniciar",
    "amuniciais": "amuniciar",
    "amuniciam": "amuniciar",
    "amuniciamentos": "amuniciamento",
    "amuniciamo": "amuniciar",
    "amuniciamos": "amuniciar",
    "amuniciando": "amuniciar",
    "amuniciara": "amuniciar",
    "amuniciaram": "amuniciar",
    "amuniciaras": "amuniciar",
    "amuniciarde": "amuniciar",
    "amuniciardes": "amuniciar",
    "amuniciare": "amuniciar",
    "amuniciarei": "amuniciar",
    "amuniciareis": "amuniciar",
    "amuniciarem": "amuniciar",
    "amuniciaremos": "amuniciar",
    "amuniciares": "amuniciar",
    "amuniciaria": "amuniciar",
    "amuniciariam": "amuniciar",
    "amuniciarias": "amuniciar",
    "amuniciarmo": "amuniciar",
    "amuniciarmos": "amuniciar",
    "amuniciará": "amuniciar",
    "amuniciarás": "amuniciar",
    "amuniciarão": "amuniciar",
    "amuniciaríamos": "amuniciar",
    "amuniciaríeis": "amuniciar",
    "amunicias": "amuniciar",
    "amuniciasse": "amuniciar",
    "amuniciassem": "amuniciar",
    "amuniciasses": "amuniciar",
    "amuniciaste": "amuniciar",
    "amuniciastes": "amuniciar",
    "amuniciava": "amuniciar",
    "amuniciavam": "amuniciar",
    "amuniciavas": "amuniciar",
    "amunicie": "amuniciar",
    "amuniciei": "amuniciar",
    "amunicieis": "amuniciar",
    "amuniciem": "amuniciar",
    "amuniciemo": "amuniciar",
    "amuniciemos": "amuniciar",
    "amunicies": "amuniciar",
    "amunicio": "amuniciar",
    "amuniciou": "amuniciar",
    "amuniciá": "amuniciar",
    "amuniciámo": "amuniciar",
    "amuniciámos": "amuniciar",
    "amuniciáramo": "amuniciar",
    "amuniciáramos": "amuniciar",
    "amuniciárei": "amuniciar",
    "amuniciáreis": "amuniciar",
    "amuniciásseis": "amuniciar",
    "amuniciássemos": "amuniciar",
    "amuniciávamo": "amuniciar",
    "amuniciávamos": "amuniciar",
    "amuniciávei": "amuniciar",
    "amuniciáveis": "amuniciar",
    "amunigas": "amuniga",
    "amuo": "amuar",
    "amuos": "amuo",
    "amuou": "amuar",
    "amura": "amurar",
    "amurada": "amurar",
    "amuradas": "amurar",
    "amurado": "amurar",
    "amurados": "amurar",
    "amurai": "amurar",
    "amurais": "amurar",
    "amuralha": "amuralhar",
    "amuralhada": "amuralhar",
    "amuralhadas": "amuralhar",
    "amuralhado": "amuralhar",
    "amuralhados": "amuralhar",
    "amuralhai": "amuralhar",
    "amuralhais": "amuralhar",
    "amuralham": "amuralhar",
    "amuralhamo": "amuralhar",
    "amuralhamos": "amuralhar",
    "amuralhando": "amuralhar",
    "amuralhara": "amuralhar",
    "amuralharam": "amuralhar",
    "amuralharas": "amuralhar",
    "amuralharde": "amuralhar",
    "amuralhardes": "amuralhar",
    "amuralhare": "amuralhar",
    "amuralharei": "amuralhar",
    "amuralhareis": "amuralhar",
    "amuralharem": "amuralhar",
    "amuralharemos": "amuralhar",
    "amuralhares": "amuralhar",
    "amuralharia": "amuralhar",
    "amuralhariam": "amuralhar",
    "amuralharias": "amuralhar",
    "amuralharmo": "amuralhar",
    "amuralharmos": "amuralhar",
    "amuralhará": "amuralhar",
    "amuralharás": "amuralhar",
    "amuralharão": "amuralhar",
    "amuralharíamos": "amuralhar",
    "amuralharíeis": "amuralhar",
    "amuralhas": "amuralhar",
    "amuralhasse": "amuralhar",
    "amuralhassem": "amuralhar",
    "amuralhasses": "amuralhar",
    "amuralhaste": "amuralhar",
    "amuralhastes": "amuralhar",
    "amuralhava": "amuralhar",
    "amuralhavam": "amuralhar",
    "amuralhavas": "amuralhar",
    "amuralhe": "amuralhar",
    "amuralhei": "amuralhar",
    "amuralheis": "amuralhar",
    "amuralhem": "amuralhar",
    "amuralhemo": "amuralhar",
    "amuralhemos": "amuralhar",
    "amuralhes": "amuralhar",
    "amuralho": "amuralhar",
    "amuralhou": "amuralhar",
    "amuralhá": "amuralhar",
    "amuralhámo": "amuralhar",
    "amuralhámos": "amuralhar",
    "amuralháramo": "amuralhar",
    "amuralháramos": "amuralhar",
    "amuralhárei": "amuralhar",
    "amuralháreis": "amuralhar",
    "amuralhásseis": "amuralhar",
    "amuralhássemos": "amuralhar",
    "amuralhávamo": "amuralhar",
    "amuralhávamos": "amuralhar",
    "amuralhávei": "amuralhar",
    "amuralháveis": "amuralhar",
    "amuram": "amurar",
    "amuramo": "amurar",
    "amuramos": "amurar",
    "amurando": "amurar",
    "amurara": "amurar",
    "amuraram": "amurar",
    "amuraras": "amurar",
    "amurarde": "amurar",
    "amurardes": "amurar",
    "amurare": "amurar",
    "amurarei": "amurar",
    "amurareis": "amurar",
    "amurarem": "amurar",
    "amuraremos": "amurar",
    "amurares": "amurar",
    "amuraria": "amurar",
    "amurariam": "amurar",
    "amurarias": "amurar",
    "amurarmo": "amurar",
    "amurarmos": "amurar",
    "amurará": "amurar",
    "amurarás": "amurar",
    "amurarão": "amurar",
    "amuraríamos": "amurar",
    "amuraríeis": "amurar",
    "amuras": "amurar",
    "amurasse": "amurar",
    "amurassem": "amurar",
    "amurasses": "amurar",
    "amuraste": "amurar",
    "amurastes": "amurar",
    "amurava": "amurar",
    "amuravam": "amurar",
    "amuravas": "amurar",
    "amurcas": "amurca",
    "amure": "amurar",
    "amurei": "amurar",
    "amureis": "amurar",
    "amurem": "amurar",
    "amuremo": "amurar",
    "amuremos": "amurar",
    "amures": "amurar",
    "amuro": "amurar",
    "amurou": "amurar",
    "amurá": "amurar",
    "amurámo": "amurar",
    "amurámos": "amurar",
    "amuráramo": "amurar",
    "amuráramos": "amurar",
    "amurárei": "amurar",
    "amuráreis": "amurar",
    "amurásseis": "amurar",
    "amurássemos": "amurar",
    "amurávamo": "amurar",
    "amurávamos": "amurar",
    "amurávei": "amurar",
    "amuráveis": "amurar",
    "amusias": "amusia",
    "amuámo": "amuar",
    "amuámos": "amuar",
    "amuáramo": "amuar",
    "amuáramos": "amuar",
    "amuáreis": "amuar",
    "amuásseis": "amuar",
    "amuássemos": "amuar",
    "amuávamo": "amuar",
    "amuávamos": "amuar",
    "amuáveis": "amuar",
    "amá": "amar",
    "amábeis": "amábil",
    "amálgamas": "amálgama",
    "amámo": "amar",
    "amámos": "amar",
    "amáramo": "amar",
    "amáramos": "amar",
    "amárei": "amar",
    "amáreis": "amar",
    "amásia": "amásio",
    "amásias": "amásio",
    "amásios": "amásio",
    "amásseis": "amar",
    "amássemos": "amar",
    "amávamo": "amar",
    "amávamos": "amar",
    "amávei": "amar",
    "amáveis": "amável",
    "amânoas": "amânoa",
    "amãs": "amã",
    "améns": "amén",
    "amétrica": "amétrico",
    "amétricas": "amétrico",
    "amétricos": "amétrico",
    "amêijoas": "amêijoa",
    "amências": "amência",
    "amêndoas": "amêndoa",
    "amículos": "amículo",
    "amídalas": "amídala",
    "amígdalas": "amígdala",
    "amílases": "amílase",
    "amília": "amílio",
    "amílias": "amílio",
    "amílica": "amílico",
    "amílicas": "amílico",
    "amílicos": "amílico",
    "amílios": "amílio",
    "amíntica": "amíntico",
    "amínticas": "amíntico",
    "amínticos": "amíntico",
    "amóditas": "amódita",
    "amónias": "amónia",
    "amónios": "amónio",
    "amórfica": "amórfico",
    "amórficas": "amórfico",
    "amórficos": "amórfico",
    "anabaptismos": "anabaptismo",
    "anabaptistas": "anabaptista",
    "anabasias": "anabasia",
    "anabatismos": "anabatismo",
    "anabatistas": "anabatista",
    "anabenodáctila": "anabenodáctilo",
    "anabenodáctilas": "anabenodáctilo",
    "anabenodáctilos": "anabenodáctilo",
    "anabolisantes": "anabolisante",
    "anabolismos": "anabolismo",
    "anabolizantes": "anabolizante",
    "anabática": "anabático",
    "anabáticas": "anabático",
    "anabáticos": "anabático",
    "anabólica": "anabólico",
    "anabólicas": "anabólico",
    "anabólicos": "anabólico",
    "anaca": "anaco",
    "anacara": "anacarar",
    "anacarada": "anacarar",
    "anacaradas": "anacarar",
    "anacarado": "anacarar",
    "anacarados": "anacarar",
    "anacarai": "anacarar",
    "anacarais": "anacarar",
    "anacaram": "anacarar",
    "anacaramo": "anacarar",
    "anacaramos": "anacarar",
    "anacarando": "anacarar",
    "anacarara": "anacarar",
    "anacararam": "anacarar",
    "anacararas": "anacarar",
    "anacararde": "anacarar",
    "anacarardes": "anacarar",
    "anacarare": "anacarar",
    "anacararei": "anacarar",
    "anacarareis": "anacarar",
    "anacararem": "anacarar",
    "anacararemos": "anacarar",
    "anacarares": "anacarar",
    "anacararia": "anacarar",
    "anacarariam": "anacarar",
    "anacararias": "anacarar",
    "anacararmo": "anacarar",
    "anacararmos": "anacarar",
    "anacarará": "anacarar",
    "anacararás": "anacarar",
    "anacararão": "anacarar",
    "anacararíamos": "anacarar",
    "anacararíeis": "anacarar",
    "anacaras": "anacarar",
    "anacarasse": "anacarar",
    "anacarassem": "anacarar",
    "anacarasses": "anacarar",
    "anacaraste": "anacarar",
    "anacarastes": "anacarar",
    "anacarava": "anacarar",
    "anacaravam": "anacarar",
    "anacaravas": "anacarar",
    "anacardeiros": "anacardeiro",
    "anacardinas": "anacardina",
    "anacardiácea": "anacardiáceo",
    "anacardiáceas": "anacardiáceo",
    "anacardiáceos": "anacardiáceo",
    "anacardos": "anacardo",
    "anacare": "anacarar",
    "anacarei": "anacarar",
    "anacareis": "anacarar",
    "anacarem": "anacarar",
    "anacaremo": "anacarar",
    "anacaremos": "anacarar",
    "anacares": "anacarar",
    "anacaro": "anacarar",
    "anacarou": "anacarar",
    "anacará": "anacarar",
    "anacarámo": "anacarar",
    "anacarámos": "anacarar",
    "anacaráramo": "anacarar",
    "anacaráramos": "anacarar",
    "anacarárei": "anacarar",
    "anacaráreis": "anacarar",
    "anacarásseis": "anacarar",
    "anacarássemos": "anacarar",
    "anacarávamo": "anacarar",
    "anacarávamos": "anacarar",
    "anacarávei": "anacarar",
    "anacaráveis": "anacarar",
    "anacas": "anaco",
    "anacatarses": "anacatarse",
    "anacatarsias": "anacatarsia",
    "anacatártica": "anacatártico",
    "anacatárticas": "anacatártico",
    "anacatárticos": "anacatártico",
    "anacaínas": "anacaína",
    "anace": "anaçar",
    "anacefaleoses": "anacefaleose",
    "anacei": "anaçar",
    "anaceis": "anaçar",
    "anacem": "anaçar",
    "anacemo": "anaçar",
    "anacemos": "anaçar",
    "anaces": "anaçar",
    "anacineses": "anacinese",
    "anacinesias": "anacinesia",
    "anacolutias": "anacolutia",
    "anacolutos": "anacoluto",
    "anacolútica": "anacolútico",
    "anacolúticas": "anacolútico",
    "anacolúticos": "anacolútico",
    "anacondas": "anaconda",
    "anaconquilismos": "anaconquilismo",
    "anacoretas": "anacoreta",
    "anacoretismos": "anacoretismo",
    "anacorética": "anacorético",
    "anacoréticas": "anacorético",
    "anacoréticos": "anacorético",
    "anacos": "anaco",
    "anacreontismos": "anacreontismo",
    "anacreontiza": "anacreontizar",
    "anacreontizada": "anacreontizar",
    "anacreontizadas": "anacreontizar",
    "anacreontizado": "anacreontizar",
    "anacreontizados": "anacreontizar",
    "anacreontizai": "anacreontizar",
    "anacreontizais": "anacreontizar",
    "anacreontizam": "anacreontizar",
    "anacreontizamo": "anacreontizar",
    "anacreontizamos": "anacreontizar",
    "anacreontizando": "anacreontizar",
    "anacreontizara": "anacreontizar",
    "anacreontizaram": "anacreontizar",
    "anacreontizaras": "anacreontizar",
    "anacreontizarde": "anacreontizar",
    "anacreontizardes": "anacreontizar",
    "anacreontizare": "anacreontizar",
    "anacreontizarei": "anacreontizar",
    "anacreontizareis": "anacreontizar",
    "anacreontizarem": "anacreontizar",
    "anacreontizaremos": "anacreontizar",
    "anacreontizares": "anacreontizar",
    "anacreontizaria": "anacreontizar",
    "anacreontizariam": "anacreontizar",
    "anacreontizarias": "anacreontizar",
    "anacreontizarmo": "anacreontizar",
    "anacreontizarmos": "anacreontizar",
    "anacreontizará": "anacreontizar",
    "anacreontizarás": "anacreontizar",
    "anacreontizarão": "anacreontizar",
    "anacreontizaríamos": "anacreontizar",
    "anacreontizaríeis": "anacreontizar",
    "anacreontizas": "anacreontizar",
    "anacreontizasse": "anacreontizar",
    "anacreontizassem": "anacreontizar",
    "anacreontizasses": "anacreontizar",
    "anacreontizaste": "anacreontizar",
    "anacreontizastes": "anacreontizar",
    "anacreontizava": "anacreontizar",
    "anacreontizavam": "anacreontizar",
    "anacreontizavas": "anacreontizar",
    "anacreontize": "anacreontizar",
    "anacreontizei": "anacreontizar",
    "anacreontizeis": "anacreontizar",
    "anacreontizem": "anacreontizar",
    "anacreontizemo": "anacreontizar",
    "anacreontizemos": "anacreontizar",
    "anacreontizes": "anacreontizar",
    "anacreontizo": "anacreontizar",
    "anacreontizou": "anacreontizar",
    "anacreontizá": "anacreontizar",
    "anacreontizámo": "anacreontizar",
    "anacreontizámos": "anacreontizar",
    "anacreontizáramo": "anacreontizar",
    "anacreontizáramos": "anacreontizar",
    "anacreontizárei": "anacreontizar",
    "anacreontizáreis": "anacreontizar",
    "anacreontizásseis": "anacreontizar",
    "anacreontizássemos": "anacreontizar",
    "anacreontizávamo": "anacreontizar",
    "anacreontizávamos": "anacreontizar",
    "anacreontizávei": "anacreontizar",
    "anacreontizáveis": "anacreontizar",
    "anacreôntica": "anacreôntico",
    "anacreônticas": "anacreôntico",
    "anacreônticos": "anacreôntico",
    "anacroasias": "anacroasia",
    "anacronismos": "anacronismo",
    "anacroniza": "anacronizar",
    "anacronizada": "anacronizar",
    "anacronizadas": "anacronizar",
    "anacronizado": "anacronizar",
    "anacronizados": "anacronizar",
    "anacronizai": "anacronizar",
    "anacronizais": "anacronizar",
    "anacronizam": "anacronizar",
    "anacronizamo": "anacronizar",
    "anacronizamos": "anacronizar",
    "anacronizando": "anacronizar",
    "anacronizara": "anacronizar",
    "anacronizaram": "anacronizar",
    "anacronizaras": "anacronizar",
    "anacronizarde": "anacronizar",
    "anacronizardes": "anacronizar",
    "anacronizare": "anacronizar",
    "anacronizarei": "anacronizar",
    "anacronizareis": "anacronizar",
    "anacronizarem": "anacronizar",
    "anacronizaremos": "anacronizar",
    "anacronizares": "anacronizar",
    "anacronizaria": "anacronizar",
    "anacronizariam": "anacronizar",
    "anacronizarias": "anacronizar",
    "anacronizarmo": "anacronizar",
    "anacronizarmos": "anacronizar",
    "anacronizará": "anacronizar",
    "anacronizarás": "anacronizar",
    "anacronizarão": "anacronizar",
    "anacronizaríamos": "anacronizar",
    "anacronizaríeis": "anacronizar",
    "anacronizas": "anacronizar",
    "anacronizasse": "anacronizar",
    "anacronizassem": "anacronizar",
    "anacronizasses": "anacronizar",
    "anacronizaste": "anacronizar",
    "anacronizastes": "anacronizar",
    "anacronizava": "anacronizar",
    "anacronizavam": "anacronizar",
    "anacronizavas": "anacronizar",
    "anacronize": "anacronizar",
    "anacronizei": "anacronizar",
    "anacronizeis": "anacronizar",
    "anacronizem": "anacronizar",
    "anacronizemo": "anacronizar",
    "anacronizemos": "anacronizar",
    "anacronizes": "anacronizar",
    "anacronizo": "anacronizar",
    "anacronizou": "anacronizar",
    "anacronizá": "anacronizar",
    "anacronizámo": "anacronizar",
    "anacronizámos": "anacronizar",
    "anacronizáramo": "anacronizar",
    "anacronizáramos": "anacronizar",
    "anacronizárei": "anacronizar",
    "anacronizáreis": "anacronizar",
    "anacronizásseis": "anacronizar",
    "anacronizássemos": "anacronizar",
    "anacronizávamo": "anacronizar",
    "anacronizávamos": "anacronizar",
    "anacronizávei": "anacronizar",
    "anacronizáveis": "anacronizar",
    "anacrusas": "anacrusa",
    "anacruses": "anacruse",
    "anacrónica": "anacrónico",
    "anacrónicas": "anacrónico",
    "anacrónicos": "anacrónico",
    "anactesias": "anactesia",
    "anactésica": "anactésico",
    "anactésicas": "anactésico",
    "anactésicos": "anactésico",
    "anactética": "anactético",
    "anactéticas": "anactético",
    "anactéticos": "anactético",
    "anacárdica": "anacárdico",
    "anacárdicas": "anacárdico",
    "anacárdicos": "anacárdico",
    "anacárdios": "anacárdio",
    "anacâmptica": "anacâmptico",
    "anacâmpticas": "anacâmptico",
    "anacâmpticos": "anacâmptico",
    "anacíclica": "anacíclico",
    "anacíclicas": "anacíclico",
    "anacíclicos": "anacíclico",
    "anadarias": "anadaria",
    "anadelarias": "anadelaria",
    "anadiploses": "anadiplose",
    "anaduvas": "anaduva",
    "anadéis": "anadel",
    "anaerobioses": "anaerobiose",
    "anaeróbia": "anaeróbio",
    "anaeróbias": "anaeróbio",
    "anaeróbica": "anaeróbico",
    "anaeróbicas": "anaeróbico",
    "anaeróbicos": "anaeróbico",
    "anaeróbios": "anaeróbio",
    "anafa": "anafar",
    "anafada": "anafar",
    "anafadas": "anafar",
    "anafado": "anafar",
    "anafados": "anafar",
    "anafai": "anafar",
    "anafaias": "anafaia",
    "anafais": "anafar",
    "anafalantíases": "anafalantíase",
    "anafam": "anafar",
    "anafamo": "anafar",
    "anafamos": "anafar",
    "anafando": "anafar",
    "anafara": "anafar",
    "anafaram": "anafar",
    "anafaras": "anafar",
    "anafarde": "anafar",
    "anafardes": "anafar",
    "anafare": "anafar",
    "anafarei": "anafar",
    "anafareis": "anafar",
    "anafarem": "anafar",
    "anafaremos": "anafar",
    "anafares": "anafar",
    "anafaria": "anafar",
    "anafariam": "anafar",
    "anafarias": "anafar",
    "anafarmo": "anafar",
    "anafarmos": "anafar",
    "anafará": "anafar",
    "anafarás": "anafar",
    "anafarão": "anafar",
    "anafaríamos": "anafar",
    "anafaríeis": "anafar",
    "anafas": "anafar",
    "anafasse": "anafar",
    "anafassem": "anafar",
    "anafasses": "anafar",
    "anafaste": "anafar",
    "anafastes": "anafar",
    "anafava": "anafar",
    "anafavam": "anafar",
    "anafavas": "anafar",
    "anafe": "anafar",
    "anafei": "anafar",
    "anafeis": "anafar",
    "anafem": "anafar",
    "anafemo": "anafar",
    "anafemos": "anafar",
    "anafes": "anafe",
    "anafias": "anafia",
    "anafiis": "anafil",
    "anafilaxias": "anafilaxia",
    "anafileiros": "anafileiro",
    "anafiláctica": "anafiláctico",
    "anafilácticas": "anafiláctico",
    "anafilácticos": "anafiláctico",
    "anafo": "anafar",
    "anaforeses": "anaforese",
    "anaforismos": "anaforismo",
    "anafou": "anafar",
    "anafrodisias": "anafrodisia",
    "anafrodisíaca": "anafrodisíaco",
    "anafrodisíacas": "anafrodisíaco",
    "anafrodisíacos": "anafrodisíaco",
    "anafroditas": "anafrodita",
    "anafrodites": "anafrodite",
    "anafrodítica": "anafrodítico",
    "anafrodíticas": "anafrodítico",
    "anafrodíticos": "anafrodítico",
    "anafá": "anafar",
    "anafámo": "anafar",
    "anafámos": "anafar",
    "anafáramo": "anafar",
    "anafáramos": "anafar",
    "anafárei": "anafar",
    "anafáreis": "anafar",
    "anafásseis": "anafar",
    "anafássemos": "anafar",
    "anafávamo": "anafar",
    "anafávamos": "anafar",
    "anafávei": "anafar",
    "anafáveis": "anafar",
    "anafórica": "anafórico",
    "anafóricas": "anafórico",
    "anafóricos": "anafórico",
    "anagalha": "anagalhar",
    "anagalhada": "anagalhar",
    "anagalhadas": "anagalhar",
    "anagalhado": "anagalhar",
    "anagalhados": "anagalhar",
    "anagalhai": "anagalhar",
    "anagalhais": "anagalhar",
    "anagalham": "anagalhar",
    "anagalhamo": "anagalhar",
    "anagalhamos": "anagalhar",
    "anagalhando": "anagalhar",
    "anagalhara": "anagalhar",
    "anagalharam": "anagalhar",
    "anagalharas": "anagalhar",
    "anagalharde": "anagalhar",
    "anagalhardes": "anagalhar",
    "anagalhare": "anagalhar",
    "anagalharei": "anagalhar",
    "anagalhareis": "anagalhar",
    "anagalharem": "anagalhar",
    "anagalharemos": "anagalhar",
    "anagalhares": "anagalhar",
    "anagalharia": "anagalhar",
    "anagalhariam": "anagalhar",
    "anagalharias": "anagalhar",
    "anagalharmo": "anagalhar",
    "anagalharmos": "anagalhar",
    "anagalhará": "anagalhar",
    "anagalharás": "anagalhar",
    "anagalharão": "anagalhar",
    "anagalharíamos": "anagalhar",
    "anagalharíeis": "anagalhar",
    "anagalhas": "anagalhar",
    "anagalhasse": "anagalhar",
    "anagalhassem": "anagalhar",
    "anagalhasses": "anagalhar",
    "anagalhaste": "anagalhar",
    "anagalhastes": "anagalhar",
    "anagalhava": "anagalhar",
    "anagalhavam": "anagalhar",
    "anagalhavas": "anagalhar",
    "anagalhe": "anagalhar",
    "anagalhei": "anagalhar",
    "anagalheis": "anagalhar",
    "anagalhem": "anagalhar",
    "anagalhemo": "anagalhar",
    "anagalhemos": "anagalhar",
    "anagalhes": "anagalhar",
    "anagalho": "anagalhar",
    "anagalhou": "anagalhar",
    "anagalhá": "anagalhar",
    "anagalhámo": "anagalhar",
    "anagalhámos": "anagalhar",
    "anagalháramo": "anagalhar",
    "anagalháramos": "anagalhar",
    "anagalhárei": "anagalhar",
    "anagalháreis": "anagalhar",
    "anagalhásseis": "anagalhar",
    "anagalhássemos": "anagalhar",
    "anagalhávamo": "anagalhar",
    "anagalhávamos": "anagalhar",
    "anagalhávei": "anagalhar",
    "anagalháveis": "anagalhar",
    "anagalidínea": "anagalidíneo",
    "anagalidíneas": "anagalidíneo",
    "anagalidíneos": "anagalidíneo",
    "anagalídea": "anagalídeo",
    "anagalídeas": "anagalídeo",
    "anagalídeos": "anagalídeo",
    "anagenésica": "anagenésico",
    "anagenésicas": "anagenésico",
    "anagenésicos": "anagenésico",
    "anagenética": "anagenético",
    "anagenéticas": "anagenético",
    "anagenéticos": "anagenético",
    "anagliptografias": "anagliptografia",
    "anagliptográfica": "anagliptográfico",
    "anagliptográficas": "anagliptográfico",
    "anagliptográficos": "anagliptográfico",
    "anaglífica": "anaglífico",
    "anaglíficas": "anaglífico",
    "anaglíficos": "anaglífico",
    "anagnoses": "anagnose",
    "anagnosigrafias": "anagnosigrafia",
    "anagnostas": "anagnosta",
    "anagnóstica": "anagnóstico",
    "anagnósticas": "anagnóstico",
    "anagnósticos": "anagnóstico",
    "anagogias": "anagogia",
    "anagogismos": "anagogismo",
    "anagogistas": "anagogista",
    "anagramas": "anagrama",
    "anagramatistas": "anagramatista",
    "anagramatiza": "anagramatizar",
    "anagramatizada": "anagramatizar",
    "anagramatizadas": "anagramatizar",
    "anagramatizado": "anagramatizar",
    "anagramatizados": "anagramatizar",
    "anagramatizai": "anagramatizar",
    "anagramatizais": "anagramatizar",
    "anagramatizam": "anagramatizar",
    "anagramatizamo": "anagramatizar",
    "anagramatizamos": "anagramatizar",
    "anagramatizando": "anagramatizar",
    "anagramatizara": "anagramatizar",
    "anagramatizaram": "anagramatizar",
    "anagramatizaras": "anagramatizar",
    "anagramatizardes": "anagramatizar",
    "anagramatizarei": "anagramatizar",
    "anagramatizareis": "anagramatizar",
    "anagramatizarem": "anagramatizar",
    "anagramatizaremos": "anagramatizar",
    "anagramatizares": "anagramatizar",
    "anagramatizaria": "anagramatizar",
    "anagramatizariam": "anagramatizar",
    "anagramatizarias": "anagramatizar",
    "anagramatizarmo": "anagramatizar",
    "anagramatizarmos": "anagramatizar",
    "anagramatizará": "anagramatizar",
    "anagramatizarás": "anagramatizar",
    "anagramatizarão": "anagramatizar",
    "anagramatizaríamos": "anagramatizar",
    "anagramatizaríeis": "anagramatizar",
    "anagramatizas": "anagramatizar",
    "anagramatizasse": "anagramatizar",
    "anagramatizassem": "anagramatizar",
    "anagramatizasses": "anagramatizar",
    "anagramatizaste": "anagramatizar",
    "anagramatizastes": "anagramatizar",
    "anagramatizava": "anagramatizar",
    "anagramatizavam": "anagramatizar",
    "anagramatizavas": "anagramatizar",
    "anagramatize": "anagramatizar",
    "anagramatizei": "anagramatizar",
    "anagramatizeis": "anagramatizar",
    "anagramatizem": "anagramatizar",
    "anagramatizemo": "anagramatizar",
    "anagramatizemos": "anagramatizar",
    "anagramatizes": "anagramatizar",
    "anagramatizo": "anagramatizar",
    "anagramatizou": "anagramatizar",
    "anagramatizámo": "anagramatizar",
    "anagramatizámos": "anagramatizar",
    "anagramatizáramo": "anagramatizar",
    "anagramatizáramos": "anagramatizar",
    "anagramatizáreis": "anagramatizar",
    "anagramatizásseis": "anagramatizar",
    "anagramatizássemos": "anagramatizar",
    "anagramatizávamo": "anagramatizar",
    "anagramatizávamos": "anagramatizar",
    "anagramatizáveis": "anagramatizar",
    "anagramática": "anagramático",
    "anagramáticas": "anagramático",
    "anagramáticos": "anagramático",
    "anaguéis": "anaguel",
    "anagálides": "anagálide",
    "anagéneses": "anagénese",
    "anagógica": "anagógico",
    "anagógicas": "anagógico",
    "anagógicos": "anagógico",
    "anaias": "anaia",
    "anainhos": "anainho",
    "anais": "anal",
    "analabos": "analabo",
    "analcites": "analcite",
    "analectas": "analecta",
    "analectora": "analector",
    "analectoras": "analector",
    "analectores": "analector",
    "analectos": "analecto",
    "analemas": "analema",
    "analemática": "analemático",
    "analemáticas": "analemático",
    "analemáticos": "analemático",
    "analepses": "analepse",
    "analepsias": "analepsia",
    "analfabeta": "analfabeto",
    "analfabetas": "analfabeto",
    "analfabetismos": "analfabetismo",
    "analfabetos": "analfabeto",
    "analfabética": "analfabético",
    "analfabéticas": "analfabético",
    "analfabéticos": "analfabético",
    "analgesias": "analgesia",
    "analgias": "analgia",
    "analginas": "analgina",
    "analgiza": "analgizar",
    "analgizada": "analgizar",
    "analgizadas": "analgizar",
    "analgizado": "analgizar",
    "analgizados": "analgizar",
    "analgizai": "analgizar",
    "analgizais": "analgizar",
    "analgizam": "analgizar",
    "analgizamo": "analgizar",
    "analgizamos": "analgizar",
    "analgizando": "analgizar",
    "analgizara": "analgizar",
    "analgizaram": "analgizar",
    "analgizaras": "analgizar",
    "analgizarde": "analgizar",
    "analgizardes": "analgizar",
    "analgizare": "analgizar",
    "analgizarei": "analgizar",
    "analgizareis": "analgizar",
    "analgizarem": "analgizar",
    "analgizaremos": "analgizar",
    "analgizares": "analgizar",
    "analgizaria": "analgizar",
    "analgizariam": "analgizar",
    "analgizarias": "analgizar",
    "analgizarmo": "analgizar",
    "analgizarmos": "analgizar",
    "analgizará": "analgizar",
    "analgizarás": "analgizar",
    "analgizarão": "analgizar",
    "analgizaríamos": "analgizar",
    "analgizaríeis": "analgizar",
    "analgizas": "analgizar",
    "analgizasse": "analgizar",
    "analgizassem": "analgizar",
    "analgizasses": "analgizar",
    "analgizaste": "analgizar",
    "analgizastes": "analgizar",
    "analgizava": "analgizar",
    "analgizavam": "analgizar",
    "analgizavas": "analgizar",
    "analgize": "analgizar",
    "analgizei": "analgizar",
    "analgizeis": "analgizar",
    "analgizem": "analgizar",
    "analgizemo": "analgizar",
    "analgizemos": "analgizar",
    "analgizes": "analgizar",
    "analgizo": "analgizar",
    "analgizou": "analgizar",
    "analgizá": "analgizar",
    "analgizámo": "analgizar",
    "analgizámos": "analgizar",
    "analgizáramo": "analgizar",
    "analgizáramos": "analgizar",
    "analgizárei": "analgizar",
    "analgizáreis": "analgizar",
    "analgizásseis": "analgizar",
    "analgizássemos": "analgizar",
    "analgizávamo": "analgizar",
    "analgizávamos": "analgizar",
    "analgizávei": "analgizar",
    "analgizáveis": "analgizar",
    "analgognosias": "analgognosia",
    "analgésica": "analgésico",
    "analgésicas": "analgésico",
    "analgésicos": "analgésico",
    "analinas": "analina",
    "analisa": "analisar",
    "analisada": "analisar",
    "analisadas": "analisar",
    "analisado": "analisar",
    "analisadora": "analisador",
    "analisadoras": "analisador",
    "analisadores": "analisador",
    "analisados": "analisar",
    "analisai": "analisar",
    "analisais": "analisar",
    "analisam": "analisar",
    "analisamo": "analisar",
    "analisamos": "analisar",
    "analisando": "analisar",
    "analisara": "analisar",
    "analisaram": "analisar",
    "analisaras": "analisar",
    "analisarde": "analisar",
    "analisardes": "analisar",
    "analisare": "analisar",
    "analisarei": "analisar",
    "analisareis": "analisar",
    "analisarem": "analisar",
    "analisaremos": "analisar",
    "analisares": "analisar",
    "analisaria": "analisar",
    "analisariam": "analisar",
    "analisarias": "analisar",
    "analisarmo": "analisar",
    "analisarmos": "analisar",
    "analisará": "analisar",
    "analisarás": "analisar",
    "analisarão": "analisar",
    "analisaríamos": "analisar",
    "analisaríeis": "analisar",
    "analisas": "analisar",
    "analisasse": "analisar",
    "analisassem": "analisar",
    "analisasses": "analisar",
    "analisaste": "analisar",
    "analisastes": "analisar",
    "analisava": "analisar",
    "analisavam": "analisar",
    "analisavas": "analisar",
    "analise": "analisar",
    "analisei": "analisar",
    "analiseis": "analisar",
    "analisem": "analisar",
    "analisemo": "analisar",
    "analisemos": "analisar",
    "analises": "analisar",
    "analiso": "analisar",
    "analisou": "analisar",
    "analistas": "analista",
    "analisá": "analisar",
    "analisámo": "analisar",
    "analisámos": "analisar",
    "analisáramo": "analisar",
    "analisáramos": "analisar",
    "analisárei": "analisar",
    "analisáreis": "analisar",
    "analisásseis": "analisar",
    "analisássemos": "analisar",
    "analisávamo": "analisar",
    "analisávamos": "analisar",
    "analisávei": "analisar",
    "analisáveis": "analisável",
    "analiticidades": "analiticidade",
    "analogias": "analogia",
    "analogismos": "analogismo",
    "analogistas": "analogista",
    "analogísticos": "analogístico",
    "analoses": "analose",
    "analéptica": "analéptico",
    "analépticas": "analéptico",
    "analépticos": "analéptico",
    "analítica": "analítico",
    "analíticas": "analítico",
    "analíticos": "analítico",
    "analógica": "analógico",
    "analógicas": "analógico",
    "analógicos": "analógico",
    "anambés": "anambé",
    "anames": "aname",
    "anamitas": "anamita",
    "anamneses": "anamnese",
    "anamnesias": "anamnesia",
    "anamniada": "anamniado",
    "anamniadas": "anamniado",
    "anamniados": "anamniado",
    "anamniotas": "anamniota",
    "anamnésias": "anamnésia",
    "anamnésica": "anamnésico",
    "anamnésicas": "anamnésico",
    "anamnésicos": "anamnésico",
    "anamnéstica": "anamnéstico",
    "anamnésticas": "anamnéstico",
    "anamnésticos": "anamnéstico",
    "anamorfismos": "anamorfismo",
    "anamorfoses": "anamorfose",
    "anamêsa": "anamês",
    "anamêsas": "anamês",
    "anamêses": "anamês",
    "anamítica": "anamítico",
    "anamíticas": "anamítico",
    "anamíticos": "anamítico",
    "anamórfica": "anamórfico",
    "anamórficas": "anamórfico",
    "anamórficos": "anamórfico",
    "ananaseiros": "ananaseiro",
    "ananases": "ananás",
    "anandra": "anandro",
    "anandras": "anandro",
    "anandrias": "anandria",
    "anandrina": "anandrino",
    "anandrinas": "anandrino",
    "anandrinos": "anandrino",
    "anandros": "anandro",
    "ananica": "ananicar",
    "ananicada": "ananicar",
    "ananicadas": "ananicar",
    "ananicado": "ananicar",
    "ananicados": "ananicar",
    "ananicai": "ananicar",
    "ananicais": "ananicar",
    "ananicam": "ananicar",
    "ananicamo": "ananicar",
    "ananicamos": "ananicar",
    "ananicando": "ananicar",
    "ananicara": "ananicar",
    "ananicaram": "ananicar",
    "ananicaras": "ananicar",
    "ananicarde": "ananicar",
    "ananicardes": "ananicar",
    "ananicare": "ananicar",
    "ananicarei": "ananicar",
    "ananicareis": "ananicar",
    "ananicarem": "ananicar",
    "ananicaremos": "ananicar",
    "ananicares": "ananicar",
    "ananicaria": "ananicar",
    "ananicariam": "ananicar",
    "ananicarias": "ananicar",
    "ananicarmo": "ananicar",
    "ananicarmos": "ananicar",
    "ananicará": "ananicar",
    "ananicarás": "ananicar",
    "ananicarão": "ananicar",
    "ananicaríamos": "ananicar",
    "ananicaríeis": "ananicar",
    "ananicas": "ananicar",
    "ananicasse": "ananicar",
    "ananicassem": "ananicar",
    "ananicasses": "ananicar",
    "ananicaste": "ananicar",
    "ananicastes": "ananicar",
    "ananicava": "ananicar",
    "ananicavam": "ananicar",
    "ananicavas": "ananicar",
    "ananico": "ananicar",
    "ananicos": "ananico",
    "ananicou": "ananicar",
    "ananicá": "ananicar",
    "ananicámo": "ananicar",
    "ananicámos": "ananicar",
    "ananicáramo": "ananicar",
    "ananicáramos": "ananicar",
    "ananicárei": "ananicar",
    "ananicáreis": "ananicar",
    "ananicásseis": "ananicar",
    "ananicássemos": "ananicar",
    "ananicávamo": "ananicar",
    "ananicávamos": "ananicar",
    "ananicávei": "ananicar",
    "ananicáveis": "ananicar",
    "ananique": "ananicar",
    "ananiquei": "ananicar",
    "ananiqueis": "ananicar",
    "ananiquem": "ananicar",
    "ananiquemo": "ananicar",
    "ananiquemos": "ananicar",
    "ananiques": "ananicar",
    "ananismos": "ananismo",
    "ananta": "ananto",
    "anantas": "ananto",
    "anantera": "anantero",
    "ananteras": "anantero",
    "ananteros": "anantero",
    "anantos": "ananto",
    "anantérica": "anantérico",
    "anantéricas": "anantérico",
    "anantéricos": "anantérico",
    "anapestos": "anapesto",
    "anaplasias": "anaplasia",
    "anaplasmoses": "anaplasmose",
    "anaplastias": "anaplastia",
    "anaplástica": "anaplástico",
    "anaplásticas": "anaplástico",
    "anaplásticos": "anaplástico",
    "anapnografias": "anapnografia",
    "anapnográfica": "anapnográfico",
    "anapnográficas": "anapnográfico",
    "anapnográficos": "anapnográfico",
    "anapnógrafos": "anapnógrafo",
    "anaptixes": "anaptixe",
    "anaptíctica": "anaptíctico",
    "anaptícticas": "anaptíctico",
    "anaptícticos": "anaptíctico",
    "anapéstica": "anapéstico",
    "anapésticas": "anapéstico",
    "anapésticos": "anapéstico",
    "anarmónica": "anarmónico",
    "anarmónicas": "anarmónico",
    "anarmónicos": "anarmónico",
    "anarquias": "anarquia",
    "anarquismos": "anarquismo",
    "anarquistas": "anarquista",
    "anarquiza": "anarquizar",
    "anarquizada": "anarquizar",
    "anarquizadas": "anarquizar",
    "anarquizado": "anarquizar",
    "anarquizados": "anarquizar",
    "anarquizai": "anarquizar",
    "anarquizais": "anarquizar",
    "anarquizam": "anarquizar",
    "anarquizamo": "anarquizar",
    "anarquizamos": "anarquizar",
    "anarquizando": "anarquizar",
    "anarquizantes": "anarquizante",
    "anarquizara": "anarquizar",
    "anarquizaram": "anarquizar",
    "anarquizaras": "anarquizar",
    "anarquizarde": "anarquizar",
    "anarquizardes": "anarquizar",
    "anarquizare": "anarquizar",
    "anarquizarei": "anarquizar",
    "anarquizareis": "anarquizar",
    "anarquizarem": "anarquizar",
    "anarquizaremos": "anarquizar",
    "anarquizares": "anarquizar",
    "anarquizaria": "anarquizar",
    "anarquizariam": "anarquizar",
    "anarquizarias": "anarquizar",
    "anarquizarmo": "anarquizar",
    "anarquizarmos": "anarquizar",
    "anarquizará": "anarquizar",
    "anarquizarás": "anarquizar",
    "anarquizarão": "anarquizar",
    "anarquizaríamos": "anarquizar",
    "anarquizaríeis": "anarquizar",
    "anarquizas": "anarquizar",
    "anarquizasse": "anarquizar",
    "anarquizassem": "anarquizar",
    "anarquizasses": "anarquizar",
    "anarquizaste": "anarquizar",
    "anarquizastes": "anarquizar",
    "anarquizava": "anarquizar",
    "anarquizavam": "anarquizar",
    "anarquizavas": "anarquizar",
    "anarquizações": "anarquização",
    "anarquize": "anarquizar",
    "anarquizei": "anarquizar",
    "anarquizeis": "anarquizar",
    "anarquizem": "anarquizar",
    "anarquizemo": "anarquizar",
    "anarquizemos": "anarquizar",
    "anarquizes": "anarquizar",
    "anarquizo": "anarquizar",
    "anarquizou": "anarquizar",
    "anarquizá": "anarquizar",
    "anarquizámo": "anarquizar",
    "anarquizámos": "anarquizar",
    "anarquizáramo": "anarquizar",
    "anarquizáramos": "anarquizar",
    "anarquizárei": "anarquizar",
    "anarquizáreis": "anarquizar",
    "anarquizásseis": "anarquizar",
    "anarquizássemos": "anarquizar",
    "anarquizávamo": "anarquizar",
    "anarquizávamos": "anarquizar",
    "anarquizávei": "anarquizar",
    "anarquizáveis": "anarquizar",
    "anartra": "anartro",
    "anartras": "anartro",
    "anartrias": "anartria",
    "anartros": "anartro",
    "anasarca": "anasarco",
    "anasarcas": "anasarco",
    "anasarcos": "anasarco",
    "anastalses": "anastalse",
    "anastigmatismos": "anastigmatismo",
    "anastigmática": "anastigmático",
    "anastigmáticas": "anastigmático",
    "anastigmáticos": "anastigmático",
    "anastomosa": "anastomosar",
    "anastomosada": "anastomosar",
    "anastomosadas": "anastomosar",
    "anastomosado": "anastomosar",
    "anastomosados": "anastomosar",
    "anastomosai": "anastomosar",
    "anastomosais": "anastomosar",
    "anastomosam": "anastomosar",
    "anastomosamo": "anastomosar",
    "anastomosamos": "anastomosar",
    "anastomosando": "anastomosar",
    "anastomosara": "anastomosar",
    "anastomosaram": "anastomosar",
    "anastomosaras": "anastomosar",
    "anastomosarde": "anastomosar",
    "anastomosardes": "anastomosar",
    "anastomosare": "anastomosar",
    "anastomosarei": "anastomosar",
    "anastomosareis": "anastomosar",
    "anastomosarem": "anastomosar",
    "anastomosaremos": "anastomosar",
    "anastomosares": "anastomosar",
    "anastomosaria": "anastomosar",
    "anastomosariam": "anastomosar",
    "anastomosarias": "anastomosar",
    "anastomosarmo": "anastomosar",
    "anastomosarmos": "anastomosar",
    "anastomosará": "anastomosar",
    "anastomosarás": "anastomosar",
    "anastomosarão": "anastomosar",
    "anastomosaríamos": "anastomosar",
    "anastomosaríeis": "anastomosar",
    "anastomosas": "anastomosar",
    "anastomosasse": "anastomosar",
    "anastomosassem": "anastomosar",
    "anastomosasses": "anastomosar",
    "anastomosaste": "anastomosar",
    "anastomosastes": "anastomosar",
    "anastomosava": "anastomosar",
    "anastomosavam": "anastomosar",
    "anastomosavas": "anastomosar",
    "anastomose": "anastomosar",
    "anastomosei": "anastomosar",
    "anastomoseis": "anastomosar",
    "anastomosem": "anastomosar",
    "anastomosemo": "anastomosar",
    "anastomosemos": "anastomosar",
    "anastomoses": "anastomose",
    "anastomoso": "anastomosar",
    "anastomosou": "anastomosar",
    "anastomosá": "anastomosar",
    "anastomosámo": "anastomosar",
    "anastomosámos": "anastomosar",
    "anastomosáramo": "anastomosar",
    "anastomosáramos": "anastomosar",
    "anastomosárei": "anastomosar",
    "anastomosáreis": "anastomosar",
    "anastomosásseis": "anastomosar",
    "anastomosássemos": "anastomosar",
    "anastomosávamo": "anastomosar",
    "anastomosávamos": "anastomosar",
    "anastomosávei": "anastomosar",
    "anastomosáveis": "anastomosar",
    "anastomótica": "anastomótico",
    "anastomóticas": "anastomótico",
    "anastomóticos": "anastomótico",
    "anastrofias": "anastrofia",
    "anastrófica": "anastrófico",
    "anastróficas": "anastrófico",
    "anastróficos": "anastrófico",
    "anastácios": "anastácio",
    "anastática": "anastático",
    "anastáticas": "anastático",
    "anastáticos": "anastático",
    "anasártica": "anasártico",
    "anasárticas": "anasártico",
    "anasárticos": "anasártico",
    "anata": "anatar",
    "anatada": "anatar",
    "anatadas": "anatar",
    "anatado": "anatar",
    "anatados": "anatar",
    "anatai": "anatar",
    "anatais": "anatar",
    "anatam": "anatar",
    "anatamo": "anatar",
    "anatamos": "anatar",
    "anatando": "anatar",
    "anatara": "anatar",
    "anataram": "anatar",
    "anataras": "anatar",
    "anatarde": "anatar",
    "anatardes": "anatar",
    "anatare": "anatar",
    "anatarei": "anatar",
    "anatareis": "anatar",
    "anatarem": "anatar",
    "anataremos": "anatar",
    "anatares": "anatar",
    "anataria": "anatar",
    "anatariam": "anatar",
    "anatarias": "anatar",
    "anatarmo": "anatar",
    "anatarmos": "anatar",
    "anatará": "anatar",
    "anatarás": "anatar",
    "anatarão": "anatar",
    "anataríamos": "anatar",
    "anataríeis": "anatar",
    "anatas": "anatar",
    "anatasse": "anatar",
    "anatassem": "anatar",
    "anatasses": "anatar",
    "anataste": "anatar",
    "anatastes": "anatar",
    "anatava": "anatar",
    "anatavam": "anatar",
    "anatavas": "anatar",
    "anate": "anatar",
    "anatei": "anatar",
    "anateira": "anateirar",
    "anateirada": "anateirar",
    "anateiradas": "anateirar",
    "anateirado": "anateirar",
    "anateirados": "anateirar",
    "anateirai": "anateirar",
    "anateirais": "anateirar",
    "anateiram": "anateirar",
    "anateiramo": "anateirar",
    "anateiramos": "anateirar",
    "anateirando": "anateirar",
    "anateirara": "anateirar",
    "anateiraram": "anateirar",
    "anateiraras": "anateirar",
    "anateirarde": "anateirar",
    "anateirardes": "anateirar",
    "anateirare": "anateirar",
    "anateirarei": "anateirar",
    "anateirareis": "anateirar",
    "anateirarem": "anateirar",
    "anateiraremos": "anateirar",
    "anateirares": "anateirar",
    "anateiraria": "anateirar",
    "anateirariam": "anateirar",
    "anateirarias": "anateirar",
    "anateirarmo": "anateirar",
    "anateirarmos": "anateirar",
    "anateirará": "anateirar",
    "anateirarás": "anateirar",
    "anateirarão": "anateirar",
    "anateiraríamos": "anateirar",
    "anateiraríeis": "anateirar",
    "anateiras": "anateirar",
    "anateirasse": "anateirar",
    "anateirassem": "anateirar",
    "anateirasses": "anateirar",
    "anateiraste": "anateirar",
    "anateirastes": "anateirar",
    "anateirava": "anateirar",
    "anateiravam": "anateirar",
    "anateiravas": "anateirar",
    "anateire": "anateirar",
    "anateirei": "anateirar",
    "anateireis": "anateirar",
    "anateirem": "anateirar",
    "anateiremo": "anateirar",
    "anateiremos": "anateirar",
    "anateires": "anateirar",
    "anateiro": "anateirar",
    "anateirou": "anateirar",
    "anateirá": "anateirar",
    "anateirámo": "anateirar",
    "anateirámos": "anateirar",
    "anateiráramo": "anateirar",
    "anateiráramos": "anateirar",
    "anateirárei": "anateirar",
    "anateiráreis": "anateirar",
    "anateirásseis": "anateirar",
    "anateirássemos": "anateirar",
    "anateirávamo": "anateirar",
    "anateirávamos": "anateirar",
    "anateirávei": "anateirar",
    "anateiráveis": "anateirar",
    "anateis": "anatar",
    "anatem": "anatar",
    "anatematismos": "anatematismo",
    "anatematiza": "anatematizar",
    "anatematizada": "anatematizar",
    "anatematizadas": "anatematizar",
    "anatematizado": "anatematizar",
    "anatematizadora": "anatematizador",
    "anatematizadoras": "anatematizador",
    "anatematizadores": "anatematizador",
    "anatematizados": "anatematizar",
    "anatematizai": "anatematizar",
    "anatematizais": "anatematizar",
    "anatematizam": "anatematizar",
    "anatematizamo": "anatematizar",
    "anatematizamos": "anatematizar",
    "anatematizando": "anatematizar",
    "anatematizara": "anatematizar",
    "anatematizaram": "anatematizar",
    "anatematizaras": "anatematizar",
    "anatematizarde": "anatematizar",
    "anatematizardes": "anatematizar",
    "anatematizare": "anatematizar",
    "anatematizarei": "anatematizar",
    "anatematizareis": "anatematizar",
    "anatematizarem": "anatematizar",
    "anatematizaremos": "anatematizar",
    "anatematizares": "anatematizar",
    "anatematizaria": "anatematizar",
    "anatematizariam": "anatematizar",
    "anatematizarias": "anatematizar",
    "anatematizarmo": "anatematizar",
    "anatematizarmos": "anatematizar",
    "anatematizará": "anatematizar",
    "anatematizarás": "anatematizar",
    "anatematizarão": "anatematizar",
    "anatematizaríamos": "anatematizar",
    "anatematizaríeis": "anatematizar",
    "anatematizas": "anatematizar",
    "anatematizasse": "anatematizar",
    "anatematizassem": "anatematizar",
    "anatematizasses": "anatematizar",
    "anatematizaste": "anatematizar",
    "anatematizastes": "anatematizar",
    "anatematizava": "anatematizar",
    "anatematizavam": "anatematizar",
    "anatematizavas": "anatematizar",
    "anatematizações": "anatematização",
    "anatematize": "anatematizar",
    "anatematizei": "anatematizar",
    "anatematizeis": "anatematizar",
    "anatematizem": "anatematizar",
    "anatematizemo": "anatematizar",
    "anatematizemos": "anatematizar",
    "anatematizes": "anatematizar",
    "anatematizo": "anatematizar",
    "anatematizou": "anatematizar",
    "anatematizá": "anatematizar",
    "anatematizámo": "anatematizar",
    "anatematizámos": "anatematizar",
    "anatematizáramo": "anatematizar",
    "anatematizáramos": "anatematizar",
    "anatematizárei": "anatematizar",
    "anatematizáreis": "anatematizar",
    "anatematizásseis": "anatematizar",
    "anatematizássemos": "anatematizar",
    "anatematizávamo": "anatematizar",
    "anatematizávamos": "anatematizar",
    "anatematizávei": "anatematizar",
    "anatematizáveis": "anatematizar",
    "anatemo": "anatar",
    "anatemos": "anatar",
    "anatemática": "anatemático",
    "anatemáticas": "anatemático",
    "anatemáticos": "anatemático",
    "anates": "anatar",
    "anatexias": "anatexia",
    "anatistas": "anatista",
    "anato": "anatar",
    "anatocismos": "anatocismo",
    "anatomias": "anatomia",
    "anatomistas": "anatomista",
    "anatomiza": "anatomizar",
    "anatomizada": "anatomizar",
    "anatomizadas": "anatomizar",
    "anatomizado": "anatomizar",
    "anatomizados": "anatomizar",
    "anatomizai": "anatomizar",
    "anatomizais": "anatomizar",
    "anatomizam": "anatomizar",
    "anatomizamo": "anatomizar",
    "anatomizamos": "anatomizar",
    "anatomizando": "anatomizar",
    "anatomizara": "anatomizar",
    "anatomizaram": "anatomizar",
    "anatomizaras": "anatomizar",
    "anatomizarde": "anatomizar",
    "anatomizardes": "anatomizar",
    "anatomizare": "anatomizar",
    "anatomizarei": "anatomizar",
    "anatomizareis": "anatomizar",
    "anatomizarem": "anatomizar",
    "anatomizaremos": "anatomizar",
    "anatomizares": "anatomizar",
    "anatomizaria": "anatomizar",
    "anatomizariam": "anatomizar",
    "anatomizarias": "anatomizar",
    "anatomizarmo": "anatomizar",
    "anatomizarmos": "anatomizar",
    "anatomizará": "anatomizar",
    "anatomizarás": "anatomizar",
    "anatomizarão": "anatomizar",
    "anatomizaríamos": "anatomizar",
    "anatomizaríeis": "anatomizar",
    "anatomizas": "anatomizar",
    "anatomizasse": "anatomizar",
    "anatomizassem": "anatomizar",
    "anatomizasses": "anatomizar",
    "anatomizaste": "anatomizar",
    "anatomizastes": "anatomizar",
    "anatomizava": "anatomizar",
    "anatomizavam": "anatomizar",
    "anatomizavas": "anatomizar",
    "anatomizações": "anatomização",
    "anatomize": "anatomizar",
    "anatomizei": "anatomizar",
    "anatomizeis": "anatomizar",
    "anatomizem": "anatomizar",
    "anatomizemo": "anatomizar",
    "anatomizemos": "anatomizar",
    "anatomizes": "anatomizar",
    "anatomizo": "anatomizar",
    "anatomizou": "anatomizar",
    "anatomizá": "anatomizar",
    "anatomizámo": "anatomizar",
    "anatomizámos": "anatomizar",
    "anatomizáramo": "anatomizar",
    "anatomizáramos": "anatomizar",
    "anatomizárei": "anatomizar",
    "anatomizáreis": "anatomizar",
    "anatomizásseis": "anatomizar",
    "anatomizássemos": "anatomizar",
    "anatomizávamo": "anatomizar",
    "anatomizávamos": "anatomizar",
    "anatomizávei": "anatomizar",
    "anatomizáveis": "anatomizar",
    "anatou": "anatar",
    "anatríptica": "anatríptico",
    "anatrípticas": "anatríptico",
    "anatrípticos": "anatríptico",
    "anatrópica": "anatrópico",
    "anatrópicas": "anatrópico",
    "anatrópicos": "anatrópico",
    "anatá": "anatar",
    "anatámo": "anatar",
    "anatámos": "anatar",
    "anatáramo": "anatar",
    "anatáramos": "anatar",
    "anatárei": "anatar",
    "anatáreis": "anatar",
    "anatásia": "anatásio",
    "anatásias": "anatásio",
    "anatásios": "anatásio",
    "anatásseis": "anatar",
    "anatássemos": "anatar",
    "anatávamo": "anatar",
    "anatávamos": "anatar",
    "anatávei": "anatar",
    "anatáveis": "anatar",
    "anatéxica": "anatéxico",
    "anatéxicas": "anatéxico",
    "anatéxicos": "anatéxico",
    "anatídea": "anatídeo",
    "anatídeas": "anatídeo",
    "anatídeos": "anatídeo",
    "anatómica": "anatómico",
    "anatómicas": "anatómico",
    "anatómicos": "anatómico",
    "anaudias": "anaudia",
    "anavalha": "anavalhar",
    "anavalhada": "anavalhar",
    "anavalhadas": "anavalhar",
    "anavalhado": "anavalhar",
    "anavalhados": "anavalhar",
    "anavalhai": "anavalhar",
    "anavalhais": "anavalhar",
    "anavalham": "anavalhar",
    "anavalhamo": "anavalhar",
    "anavalhamos": "anavalhar",
    "anavalhando": "anavalhar",
    "anavalhara": "anavalhar",
    "anavalharam": "anavalhar",
    "anavalharas": "anavalhar",
    "anavalharde": "anavalhar",
    "anavalhardes": "anavalhar",
    "anavalhare": "anavalhar",
    "anavalharei": "anavalhar",
    "anavalhareis": "anavalhar",
    "anavalharem": "anavalhar",
    "anavalharemos": "anavalhar",
    "anavalhares": "anavalhar",
    "anavalharia": "anavalhar",
    "anavalhariam": "anavalhar",
    "anavalharias": "anavalhar",
    "anavalharmo": "anavalhar",
    "anavalharmos": "anavalhar",
    "anavalhará": "anavalhar",
    "anavalharás": "anavalhar",
    "anavalharão": "anavalhar",
    "anavalharíamos": "anavalhar",
    "anavalharíeis": "anavalhar",
    "anavalhas": "anavalhar",
    "anavalhasse": "anavalhar",
    "anavalhassem": "anavalhar",
    "anavalhasses": "anavalhar",
    "anavalhaste": "anavalhar",
    "anavalhastes": "anavalhar",
    "anavalhava": "anavalhar",
    "anavalhavam": "anavalhar",
    "anavalhavas": "anavalhar",
    "anavalhe": "anavalhar",
    "anavalhei": "anavalhar",
    "anavalheis": "anavalhar",
    "anavalhem": "anavalhar",
    "anavalhemo": "anavalhar",
    "anavalhemos": "anavalhar",
    "anavalhes": "anavalhar",
    "anavalho": "anavalhar",
    "anavalhou": "anavalhar",
    "anavalhá": "anavalhar",
    "anavalhámo": "anavalhar",
    "anavalhámos": "anavalhar",
    "anavalháramo": "anavalhar",
    "anavalháramos": "anavalhar",
    "anavalhárei": "anavalhar",
    "anavalháreis": "anavalhar",
    "anavalhásseis": "anavalhar",
    "anavalhássemos": "anavalhar",
    "anavalhávamo": "anavalhar",
    "anavalhávamos": "anavalhar",
    "anavalhávei": "anavalhar",
    "anavalháveis": "anavalhar",
    "anazotúrias": "anazotúria",
    "anazotúrica": "anazotúrico",
    "anazotúricas": "anazotúrico",
    "anazotúricos": "anazotúrico",
    "anazótica": "anazótico",
    "anazóticas": "anazótico",
    "anazóticos": "anazótico",
    "anaça": "anaçar",
    "anaçada": "anaçar",
    "anaçadas": "anaçar",
    "anaçado": "anaçar",
    "anaçados": "anaçar",
    "anaçai": "anaçar",
    "anaçais": "anaçar",
    "anaçam": "anaçar",
    "anaçamo": "anaçar",
    "anaçamos": "anaçar",
    "anaçando": "anaçar",
    "anaçara": "anaçar",
    "anaçaram": "anaçar",
    "anaçaras": "anaçar",
    "anaçarde": "anaçar",
    "anaçardes": "anaçar",
    "anaçare": "anaçar",
    "anaçarei": "anaçar",
    "anaçareis": "anaçar",
    "anaçarem": "anaçar",
    "anaçaremos": "anaçar",
    "anaçares": "anaçar",
    "anaçaria": "anaçar",
    "anaçariam": "anaçar",
    "anaçarias": "anaçar",
    "anaçarmo": "anaçar",
    "anaçarmos": "anaçar",
    "anaçará": "anaçar",
    "anaçarás": "anaçar",
    "anaçarão": "anaçar",
    "anaçaríamos": "anaçar",
    "anaçaríeis": "anaçar",
    "anaças": "anaçar",
    "anaçasse": "anaçar",
    "anaçassem": "anaçar",
    "anaçasses": "anaçar",
    "anaçaste": "anaçar",
    "anaçastes": "anaçar",
    "anaçava": "anaçar",
    "anaçavam": "anaçar",
    "anaçavas": "anaçar",
    "anaço": "anaçar",
    "anaçou": "anaçar",
    "anaçá": "anaçar",
    "anaçámo": "anaçar",
    "anaçámos": "anaçar",
    "anaçáramo": "anaçar",
    "anaçáramos": "anaçar",
    "anaçárei": "anaçar",
    "anaçáreis": "anaçar",
    "anaçásseis": "anaçar",
    "anaçássemos": "anaçar",
    "anaçávamo": "anaçar",
    "anaçávamos": "anaçar",
    "anaçávei": "anaçar",
    "anaçáveis": "anaçar",
    "ancas": "anca",
    "ancestrais": "ancestral",
    "ancestralidades": "ancestralidade",
    "anchovas": "anchova",
    "ancianias": "anciania",
    "ancianidades": "ancianidade",
    "anciis": "ancil",
    "ancilares": "ancilar",
    "ancilas": "ancila",
    "anciloglossias": "anciloglossia",
    "ancilosada": "ancilosado",
    "ancilosadas": "ancilosado",
    "ancilosados": "ancilosado",
    "anciloses": "ancilose",
    "ancilostomoses": "ancilostomose",
    "ancilostomíases": "ancilostomíase",
    "ancilóides": "ancilóide",
    "ancilóstomos": "ancilóstomo",
    "ancinha": "ancinhar",
    "ancinhada": "ancinhar",
    "ancinhadas": "ancinhar",
    "ancinhado": "ancinhar",
    "ancinhados": "ancinhar",
    "ancinhai": "ancinhar",
    "ancinhais": "ancinhar",
    "ancinham": "ancinhar",
    "ancinhamo": "ancinhar",
    "ancinhamos": "ancinhar",
    "ancinhando": "ancinhar",
    "ancinhara": "ancinhar",
    "ancinharam": "ancinhar",
    "ancinharas": "ancinhar",
    "ancinharde": "ancinhar",
    "ancinhardes": "ancinhar",
    "ancinhare": "ancinhar",
    "ancinharei": "ancinhar",
    "ancinhareis": "ancinhar",
    "ancinharem": "ancinhar",
    "ancinharemos": "ancinhar",
    "ancinhares": "ancinhar",
    "ancinharia": "ancinhar",
    "ancinhariam": "ancinhar",
    "ancinharias": "ancinhar",
    "ancinharmo": "ancinhar",
    "ancinharmos": "ancinhar",
    "ancinhará": "ancinhar",
    "ancinharás": "ancinhar",
    "ancinharão": "ancinhar",
    "ancinharíamos": "ancinhar",
    "ancinharíeis": "ancinhar",
    "ancinhas": "ancinhar",
    "ancinhasse": "ancinhar",
    "ancinhassem": "ancinhar",
    "ancinhasses": "ancinhar",
    "ancinhaste": "ancinhar",
    "ancinhastes": "ancinhar",
    "ancinhava": "ancinhar",
    "ancinhavam": "ancinhar",
    "ancinhavas": "ancinhar",
    "ancinhe": "ancinhar",
    "ancinhei": "ancinhar",
    "ancinheis": "ancinhar",
    "ancinhem": "ancinhar",
    "ancinhemo": "ancinhar",
    "ancinhemos": "ancinhar",
    "ancinhes": "ancinhar",
    "ancinho": "ancinhar",
    "ancinhos": "ancinho",
    "ancinhou": "ancinhar",
    "ancinhá": "ancinhar",
    "ancinhámo": "ancinhar",
    "ancinhámos": "ancinhar",
    "ancinháramo": "ancinhar",
    "ancinháramos": "ancinhar",
    "ancinhárei": "ancinhar",
    "ancinháreis": "ancinhar",
    "ancinhásseis": "ancinhar",
    "ancinhássemos": "ancinhar",
    "ancinhávamo": "ancinhar",
    "ancinhávamos": "ancinhar",
    "ancinhávei": "ancinhar",
    "ancinháveis": "ancinhar",
    "ancipitada": "ancipitado",
    "ancipitadas": "ancipitado",
    "ancipitados": "ancipitado",
    "ancipitais": "ancipital",
    "anciróides": "anciróide",
    "anciã": "ancião",
    "anciães": "ancião",
    "anciãos": "ancião",
    "anciãs": "ancião",
    "anciões": "ancião",
    "ancora": "ancorar",
    "ancorada": "ancorar",
    "ancoradas": "ancorar",
    "ancorado": "ancorar",
    "ancoradoiros": "ancoradoiro",
    "ancorados": "ancorar",
    "ancoradouros": "ancoradouro",
    "ancoragens": "ancoragem",
    "ancorai": "ancorar",
    "ancorais": "ancorar",
    "ancoram": "ancorar",
    "ancoramentos": "ancoramento",
    "ancoramo": "ancorar",
    "ancoramos": "ancorar",
    "ancorando": "ancorar",
    "ancorara": "ancorar",
    "ancoraram": "ancorar",
    "ancoraras": "ancorar",
    "ancorardes": "ancorar",
    "ancorarei": "ancorar",
    "ancorareis": "ancorar",
    "ancorarem": "ancorar",
    "ancoraremos": "ancorar",
    "ancorares": "ancorar",
    "ancoraria": "ancorar",
    "ancorariam": "ancorar",
    "ancorarias": "ancorar",
    "ancorarmo": "ancorar",
    "ancorarmos": "ancorar",
    "ancorará": "ancorar",
    "ancorarás": "ancorar",
    "ancorarão": "ancorar",
    "ancoraríamos": "ancorar",
    "ancoraríeis": "ancorar",
    "ancoras": "ancorar",
    "ancorasse": "ancorar",
    "ancorassem": "ancorar",
    "ancorasses": "ancorar",
    "ancoraste": "ancorar",
    "ancorastes": "ancorar",
    "ancorava": "ancorar",
    "ancoravam": "ancorar",
    "ancoravas": "ancorar",
    "ancorações": "ancoração",
    "ancore": "ancorar",
    "ancorei": "ancorar",
    "ancoreis": "ancorar",
    "ancorem": "ancorar",
    "ancoremo": "ancorar",
    "ancoremos": "ancorar",
    "ancores": "ancorar",
    "ancoretas": "ancoreta",
    "ancoro": "ancorar",
    "ancorotes": "ancorote",
    "ancorou": "ancorar",
    "ancorámo": "ancorar",
    "ancorámos": "ancorar",
    "ancoráramo": "ancorar",
    "ancoráramos": "ancorar",
    "ancoráreis": "ancorar",
    "ancorásseis": "ancorar",
    "ancorássemos": "ancorar",
    "ancorávamo": "ancorar",
    "ancorávamos": "ancorar",
    "ancoráveis": "ancorar",
    "ancos": "anco",
    "ancuda": "ancudo",
    "ancudas": "ancudo",
    "ancudos": "ancudo",
    "ancudíssima": "ancudo",
    "ancudíssimas": "ancudo",
    "ancudíssimo": "ancudo",
    "ancudíssimos": "ancudo",
    "ancípites": "ancípite",
    "ancólias": "ancólia",
    "ancónea": "ancóneo",
    "ancóneas": "ancóneo",
    "ancóneos": "ancóneo",
    "anda": "andar",
    "andacas": "andaca",
    "andada": "andar",
    "andadas": "andar",
    "andadeira": "andadeiro",
    "andadeiras": "andadeiro",
    "andadeiros": "andadeiro",
    "andado": "andar",
    "andadora": "andador",
    "andadoras": "andador",
    "andadores": "andador",
    "andadorias": "andadoria",
    "andados": "andar",
    "andaduras": "andadura",
    "andai": "andar",
    "andaias": "andaia",
    "andaima": "andaimar",
    "andaimada": "andaimar",
    "andaimadas": "andaimar",
    "andaimado": "andaimar",
    "andaimados": "andaimar",
    "andaimai": "andaimar",
    "andaimais": "andaimar",
    "andaimam": "andaimar",
    "andaimamo": "andaimar",
    "andaimamos": "andaimar",
    "andaimando": "andaimar",
    "andaimara": "andaimar",
    "andaimaram": "andaimar",
    "andaimaras": "andaimar",
    "andaimarde": "andaimar",
    "andaimardes": "andaimar",
    "andaimare": "andaimar",
    "andaimarei": "andaimar",
    "andaimareis": "andaimar",
    "andaimarem": "andaimar",
    "andaimaremos": "andaimar",
    "andaimares": "andaimar",
    "andaimaria": "andaimar",
    "andaimariam": "andaimar",
    "andaimarias": "andaimaria",
    "andaimarmo": "andaimar",
    "andaimarmos": "andaimar",
    "andaimará": "andaimar",
    "andaimarás": "andaimar",
    "andaimarão": "andaimar",
    "andaimaríamos": "andaimar",
    "andaimaríeis": "andaimar",
    "andaimas": "andaimar",
    "andaimasse": "andaimar",
    "andaimassem": "andaimar",
    "andaimasses": "andaimar",
    "andaimaste": "andaimar",
    "andaimastes": "andaimar",
    "andaimava": "andaimar",
    "andaimavam": "andaimar",
    "andaimavas": "andaimar",
    "andaime": "andaimar",
    "andaimei": "andaimar",
    "andaimeis": "andaimar",
    "andaimem": "andaimar",
    "andaimemo": "andaimar",
    "andaimemos": "andaimar",
    "andaimes": "andaime",
    "andaimo": "andaimar",
    "andaimos": "andaimo",
    "andaimou": "andaimar",
    "andaimá": "andaimar",
    "andaimámo": "andaimar",
    "andaimámos": "andaimar",
    "andaimáramo": "andaimar",
    "andaimáramos": "andaimar",
    "andaimárei": "andaimar",
    "andaimáreis": "andaimar",
    "andaimásseis": "andaimar",
    "andaimássemos": "andaimar",
    "andaimávamo": "andaimar",
    "andaimávamos": "andaimar",
    "andaimávei": "andaimar",
    "andaimáveis": "andaimar",
    "andainas": "andaina",
    "andais": "andar",
    "andalas": "andala",
    "andaluza": "andaluz",
    "andaluzas": "andaluz",
    "andaluzes": "andaluz",
    "andaluzites": "andaluzite",
    "andam": "andar",
    "andamentos": "andamento",
    "andamo": "andar",
    "andamos": "andar",
    "andanas": "andana",
    "andando": "andar",
    "andanhos": "andanho",
    "andantes": "andante",
    "andantesca": "andantesco",
    "andantescas": "andantesco",
    "andantescos": "andantesco",
    "andantina": "andantino",
    "andantinas": "andantino",
    "andantinos": "andantino",
    "andanças": "andança",
    "andapés": "andapé",
    "andara": "andar",
    "andaram": "andar",
    "andaras": "andar",
    "andarde": "andar",
    "andardes": "andar",
    "andare": "andar",
    "andarecos": "andareco",
    "andarei": "andar",
    "andareis": "andar",
    "andareja": "andarejo",
    "andarejas": "andarejo",
    "andarejos": "andarejo",
    "andarem": "andar",
    "andaremos": "andar",
    "andarenga": "andarengo",
    "andarengas": "andarengo",
    "andarengos": "andarengo",
    "andares": "andar",
    "andaria": "andar",
    "andariam": "andar",
    "andarias": "andar",
    "andarilha": "andarilhar",
    "andarilhada": "andarilhar",
    "andarilhadas": "andarilhar",
    "andarilhado": "andarilhar",
    "andarilhados": "andarilhar",
    "andarilhai": "andarilhar",
    "andarilhais": "andarilhar",
    "andarilham": "andarilhar",
    "andarilhamo": "andarilhar",
    "andarilhamos": "andarilhar",
    "andarilhando": "andarilhar",
    "andarilhara": "andarilhar",
    "andarilharam": "andarilhar",
    "andarilharas": "andarilhar",
    "andarilhardes": "andarilhar",
    "andarilharei": "andarilhar",
    "andarilhareis": "andarilhar",
    "andarilharem": "andarilhar",
    "andarilharemos": "andarilhar",
    "andarilhares": "andarilhar",
    "andarilharia": "andarilhar",
    "andarilhariam": "andarilhar",
    "andarilharias": "andarilhar",
    "andarilharmo": "andarilhar",
    "andarilharmos": "andarilhar",
    "andarilhará": "andarilhar",
    "andarilharás": "andarilhar",
    "andarilharão": "andarilhar",
    "andarilharíamos": "andarilhar",
    "andarilharíeis": "andarilhar",
    "andarilhas": "andarilhar",
    "andarilhasse": "andarilhar",
    "andarilhassem": "andarilhar",
    "andarilhasses": "andarilhar",
    "andarilhaste": "andarilhar",
    "andarilhastes": "andarilhar",
    "andarilhava": "andarilhar",
    "andarilhavam": "andarilhar",
    "andarilhavas": "andarilhar",
    "andarilhe": "andarilhar",
    "andarilhei": "andarilhar",
    "andarilheis": "andarilhar",
    "andarilhem": "andarilhar",
    "andarilhemo": "andarilhar",
    "andarilhemos": "andarilhar",
    "andarilhes": "andarilhar",
    "andarilho": "andarilhar",
    "andarilhos": "andarilho",
    "andarilhou": "andarilhar",
    "andarilhámo": "andarilhar",
    "andarilhámos": "andarilhar",
    "andarilháramo": "andarilhar",
    "andarilháramos": "andarilhar",
    "andarilháreis": "andarilhar",
    "andarilhásseis": "andarilhar",
    "andarilhássemos": "andarilhar",
    "andarilhávamo": "andarilhar",
    "andarilhávamos": "andarilhar",
    "andarilháveis": "andarilhar",
    "andarivelos": "andarivelo",
    "andarmo": "andar",
    "andarmos": "andar",
    "andará": "andar",
    "andarás": "andar",
    "andarão": "andar",
    "andaríamos": "andar",
    "andaríeis": "andar",
    "andas": "andar",
    "andasse": "andar",
    "andassem": "andar",
    "andasses": "andar",
    "andaste": "andar",
    "andastes": "andar",
    "andava": "andar",
    "andavam": "andar",
    "andavas": "andar",
    "andaços": "andaço",
    "ande": "andar",
    "andebolistas": "andebolista",
    "andei": "andar",
    "andeiros": "andeiro",
    "andeis": "andar",
    "andeja": "andejar",
    "andejada": "andejar",
    "andejadas": "andejar",
    "andejado": "andejar",
    "andejados": "andejar",
    "andejai": "andejar",
    "andejais": "andejar",
    "andejam": "andejar",
    "andejamo": "andejar",
    "andejamos": "andejar",
    "andejando": "andejar",
    "andejara": "andejar",
    "andejaram": "andejar",
    "andejaras": "andejar",
    "andejardes": "andejar",
    "andejarei": "andejar",
    "andejareis": "andejar",
    "andejarem": "andejar",
    "andejaremos": "andejar",
    "andejares": "andejar",
    "andejaria": "andejar",
    "andejariam": "andejar",
    "andejarias": "andejar",
    "andejarmo": "andejar",
    "andejarmos": "andejar",
    "andejará": "andejar",
    "andejarás": "andejar",
    "andejarão": "andejar",
    "andejaríamos": "andejar",
    "andejaríeis": "andejar",
    "andejas": "andejar",
    "andejasse": "andejar",
    "andejassem": "andejar",
    "andejasses": "andejar",
    "andejaste": "andejar",
    "andejastes": "andejar",
    "andejava": "andejar",
    "andejavam": "andejar",
    "andejavas": "andejar",
    "andeje": "andejar",
    "andejei": "andejar",
    "andejeis": "andejar",
    "andejem": "andejar",
    "andejemo": "andejar",
    "andejemos": "andejar",
    "andejes": "andejar",
    "andejo": "andejar",
    "andejos": "andejo",
    "andejou": "andejar",
    "andejámo": "andejar",
    "andejámos": "andejar",
    "andejáramo": "andejar",
    "andejáramos": "andejar",
    "andejáreis": "andejar",
    "andejásseis": "andejar",
    "andejássemos": "andejar",
    "andejávamo": "andejar",
    "andejávamos": "andejar",
    "andejáveis": "andejar",
    "andem": "andar",
    "andemo": "andar",
    "andemos": "andar",
    "anderesas": "anderesa",
    "andes": "andar",
    "andesinas": "andesina",
    "andesita": "andesito",
    "andesitas": "andesito",
    "andesites": "andesite",
    "andesitos": "andesito",
    "andilhas": "andilha",
    "andilheiros": "andilheiro",
    "andina": "andino",
    "andinas": "andino",
    "andinhas": "andinha",
    "andinos": "andino",
    "andirobeiras": "andirobeira",
    "ando": "andar",
    "andoa": "andoar",
    "andoada": "andoar",
    "andoadas": "andoar",
    "andoado": "andoar",
    "andoados": "andoar",
    "andoai": "andoar",
    "andoais": "andoar",
    "andoam": "andoar",
    "andoamo": "andoar",
    "andoamos": "andoar",
    "andoando": "andoar",
    "andoara": "andoar",
    "andoaram": "andoar",
    "andoaras": "andoar",
    "andoarde": "andoar",
    "andoardes": "andoar",
    "andoare": "andoar",
    "andoarei": "andoar",
    "andoareis": "andoar",
    "andoarem": "andoar",
    "andoaremos": "andoar",
    "andoares": "andoar",
    "andoaria": "andoar",
    "andoariam": "andoar",
    "andoarias": "andoar",
    "andoarmo": "andoar",
    "andoarmos": "andoar",
    "andoará": "andoar",
    "andoarás": "andoar",
    "andoarão": "andoar",
    "andoaríamos": "andoar",
    "andoaríeis": "andoar",
    "andoas": "andoar",
    "andoasse": "andoar",
    "andoassem": "andoar",
    "andoasses": "andoar",
    "andoaste": "andoar",
    "andoastes": "andoar",
    "andoava": "andoar",
    "andoavam": "andoar",
    "andoavas": "andoar",
    "andoe": "andoar",
    "andoei": "andoar",
    "andoeis": "andoar",
    "andoem": "andoar",
    "andoemo": "andoar",
    "andoemos": "andoar",
    "andoes": "andoar",
    "andoo": "andoar",
    "andoou": "andoar",
    "andores": "andor",
    "andorina": "andorino",
    "andorinas": "andorino",
    "andorinhas": "andorinha",
    "andorinhos": "andorinho",
    "andorinhões": "andorinhão",
    "andorinos": "andorino",
    "andoriscos": "andorisco",
    "andorrana": "andorrano",
    "andorranas": "andorrano",
    "andorranos": "andorrano",
    "andorriana": "andorriano",
    "andorrianas": "andorriano",
    "andorrianos": "andorriano",
    "andou": "andar",
    "andoá": "andoar",
    "andoámo": "andoar",
    "andoámos": "andoar",
    "andoáramo": "andoar",
    "andoáramos": "andoar",
    "andoárei": "andoar",
    "andoáreis": "andoar",
    "andoásseis": "andoar",
    "andoássemos": "andoar",
    "andoávamo": "andoar",
    "andoávamos": "andoar",
    "andoávei": "andoar",
    "andoáveis": "andoar",
    "andrajos": "andrajo",
    "andrajosa": "andrajoso",
    "andrajosas": "andrajoso",
    "andrajosidades": "andrajosidade",
    "andrajosos": "andrajoso",
    "andrajosíssima": "andrajoso",
    "andrajosíssimas": "andrajoso",
    "andrajosíssimo": "andrajoso",
    "andrajosíssimos": "andrajoso",
    "andratites": "andratite",
    "andrios": "andrio",
    "androceus": "androceu",
    "androdínamos": "androdínamo",
    "androfagias": "androfagia",
    "androfilias": "androfilia",
    "androfobias": "androfobia",
    "androgenesias": "androgenesia",
    "androgenésica": "androgenésico",
    "androgenésicas": "androgenésico",
    "androgenésicos": "androgenésico",
    "androginias": "androginia",
    "androginismos": "androginismo",
    "androginóides": "androginóide",
    "androgénios": "androgénio",
    "androgínica": "androgínico",
    "androgínicas": "androgínico",
    "androgínicos": "androgínico",
    "androlatrias": "androlatria",
    "andrologias": "andrologia",
    "andromanias": "andromania",
    "andromaníaca": "andromaníaco",
    "andromaníacas": "andromaníaco",
    "andromaníacos": "andromaníaco",
    "andromas": "androma",
    "andromorfa": "andromorfo",
    "andromorfas": "andromorfo",
    "andromorfos": "andromorfo",
    "andropausas": "andropausa",
    "androrropias": "androrropia",
    "androsemos": "androsemo",
    "andrófaga": "andrófago",
    "andrófagas": "andrófago",
    "andrófagos": "andrófago",
    "andrófila": "andrófilo",
    "andrófilas": "andrófilo",
    "andrófilos": "andrófilo",
    "andrófoba": "andrófobo",
    "andrófobas": "andrófobo",
    "andrófobos": "andrófobo",
    "andróforos": "andróforo",
    "andrógina": "andrógino",
    "andróginas": "andrógino",
    "andróginos": "andrógino",
    "andróides": "andróide",
    "andrólatras": "andrólatra",
    "andrómedas": "andrómeda",
    "andurriais": "andurrial",
    "andus": "andu",
    "andá": "andar",
    "andábatas": "andábata",
    "andámo": "andar",
    "andámos": "andar",
    "andáramo": "andar",
    "andáramos": "andar",
    "andárei": "andar",
    "andáreis": "andar",
    "andásseis": "andar",
    "andássemos": "andar",
    "andávamo": "andar",
    "andávamos": "andar",
    "andávei": "andar",
    "andáveis": "andável",
    "andícolas": "andícola",
    "andóbias": "andóbia",
    "anecóica": "anecóico",
    "anecóicas": "anecóico",
    "anecóicos": "anecóico",
    "anedia": "anediar",
    "anediada": "anediar",
    "anediadas": "anediar",
    "anediado": "anediar",
    "anediados": "anediar",
    "anediai": "anediar",
    "anediais": "anediar",
    "anediam": "anediar",
    "anediamo": "anediar",
    "anediamos": "anediar",
    "anediando": "anediar",
    "anediara": "anediar",
    "anediaram": "anediar",
    "anediaras": "anediar",
    "anediarde": "anediar",
    "anediardes": "anediar",
    "anediare": "anediar",
    "anediarei": "anediar",
    "anediareis": "anediar",
    "anediarem": "anediar",
    "anediaremos": "anediar",
    "anediares": "anediar",
    "anediaria": "anediar",
    "anediariam": "anediar",
    "anediarias": "anediar",
    "anediarmo": "anediar",
    "anediarmos": "anediar",
    "anediará": "anediar",
    "anediarás": "anediar",
    "anediarão": "anediar",
    "anediaríamos": "anediar",
    "anediaríeis": "anediar",
    "anedias": "anediar",
    "anediasse": "anediar",
    "anediassem": "anediar",
    "anediasses": "anediar",
    "anediaste": "anediar",
    "anediastes": "anediar",
    "anediava": "anediar",
    "anediavam": "anediar",
    "anediavas": "anediar",
    "anedie": "anediar",
    "anediei": "anediar",
    "anedieis": "anediar",
    "anediem": "anediar",
    "anediemo": "anediar",
    "anediemos": "anediar",
    "anedies": "anediar",
    "anedio": "anediar",
    "anediou": "anediar",
    "anediá": "anediar",
    "anediámo": "anediar",
    "anediámos": "anediar",
    "anediáramo": "anediar",
    "anediáramos": "anediar",
    "anediárei": "anediar",
    "anediáreis": "anediar",
    "anediásseis": "anediar",
    "anediássemos": "anediar",
    "anediávamo": "anediar",
    "anediávamos": "anediar",
    "anediávei": "anediar",
    "anediáveis": "anediar",
    "anedotas": "anedota",
    "anedotistas": "anedotista",
    "anedotiza": "anedotizar",
    "anedotizada": "anedotizar",
    "anedotizadas": "anedotizar",
    "anedotizado": "anedotizar",
    "anedotizados": "anedotizar",
    "anedotizai": "anedotizar",
    "anedotizais": "anedotizar",
    "anedotizam": "anedotizar",
    "anedotizamo": "anedotizar",
    "anedotizamos": "anedotizar",
    "anedotizando": "anedotizar",
    "anedotizara": "anedotizar",
    "anedotizaram": "anedotizar",
    "anedotizaras": "anedotizar",
    "anedotizarde": "anedotizar",
    "anedotizardes": "anedotizar",
    "anedotizare": "anedotizar",
    "anedotizarei": "anedotizar",
    "anedotizareis": "anedotizar",
    "anedotizarem": "anedotizar",
    "anedotizaremos": "anedotizar",
    "anedotizares": "anedotizar",
    "anedotizaria": "anedotizar",
    "anedotizariam": "anedotizar",
    "anedotizarias": "anedotizar",
    "anedotizarmo": "anedotizar",
    "anedotizarmos": "anedotizar",
    "anedotizará": "anedotizar",
    "anedotizarás": "anedotizar",
    "anedotizarão": "anedotizar",
    "anedotizaríamos": "anedotizar",
    "anedotizaríeis": "anedotizar",
    "anedotizas": "anedotizar",
    "anedotizasse": "anedotizar",
    "anedotizassem": "anedotizar",
    "anedotizasses": "anedotizar",
    "anedotizaste": "anedotizar",
    "anedotizastes": "anedotizar",
    "anedotizava": "anedotizar",
    "anedotizavam": "anedotizar",
    "anedotizavas": "anedotizar",
    "anedotize": "anedotizar",
    "anedotizei": "anedotizar",
    "anedotizeis": "anedotizar",
    "anedotizem": "anedotizar",
    "anedotizemo": "anedotizar",
    "anedotizemos": "anedotizar",
    "anedotizes": "anedotizar",
    "anedotizo": "anedotizar",
    "anedotizou": "anedotizar",
    "anedotizá": "anedotizar",
    "anedotizámo": "anedotizar",
    "anedotizámos": "anedotizar",
    "anedotizáramo": "anedotizar",
    "anedotizáramos": "anedotizar",
    "anedotizárei": "anedotizar",
    "anedotizáreis": "anedotizar",
    "anedotizásseis": "anedotizar",
    "anedotizássemos": "anedotizar",
    "anedotizávamo": "anedotizar",
    "anedotizávamos": "anedotizar",
    "anedotizávei": "anedotizar",
    "anedotizáveis": "anedotizar",
    "anedotomanias": "anedotomania",
    "anedotomaníaca": "anedotomaníaco",
    "anedotomaníacas": "anedotomaníaco",
    "anedotomaníacos": "anedotomaníaco",
    "anedotários": "anedotário",
    "anedótica": "anedótico",
    "anedóticas": "anedótico",
    "anedóticos": "anedótico",
    "anega": "anegar",
    "anegada": "anegar",
    "anegadas": "anegar",
    "anegado": "anegar",
    "anegados": "anegar",
    "anegai": "anegar",
    "anegais": "anegar",
    "anegam": "anegar",
    "anegamo": "anegar",
    "anegamos": "anegar",
    "anegando": "anegar",
    "anegara": "anegar",
    "anegaram": "anegar",
    "anegaras": "anegar",
    "anegarde": "anegar",
    "anegardes": "anegar",
    "anegare": "anegar",
    "anegarei": "anegar",
    "anegareis": "anegar",
    "anegarem": "anegar",
    "anegaremos": "anegar",
    "anegares": "anegar",
    "anegaria": "anegar",
    "anegariam": "anegar",
    "anegarias": "anegar",
    "anegarmo": "anegar",
    "anegarmos": "anegar",
    "anegará": "anegar",
    "anegarás": "anegar",
    "anegarão": "anegar",
    "anegaríamos": "anegar",
    "anegaríeis": "anegar",
    "anegas": "anegar",
    "anegasse": "anegar",
    "anegassem": "anegar",
    "anegasses": "anegar",
    "anegaste": "anegar",
    "anegastes": "anegar",
    "anegava": "anegar",
    "anegavam": "anegar",
    "anegavas": "anegar",
    "anego": "anegar",
    "anegou": "anegar",
    "anegra": "anegrar",
    "anegrada": "anegrar",
    "anegradas": "anegrar",
    "anegrado": "anegrar",
    "anegrados": "anegrar",
    "anegrai": "anegrar",
    "anegrais": "anegrar",
    "anegralhada": "anegralhado",
    "anegralhadas": "anegralhado",
    "anegralhados": "anegralhado",
    "anegram": "anegrar",
    "anegramo": "anegrar",
    "anegramos": "anegrar",
    "anegrando": "anegrar",
    "anegrara": "anegrar",
    "anegraram": "anegrar",
    "anegraras": "anegrar",
    "anegrarde": "anegrar",
    "anegrardes": "anegrar",
    "anegrare": "anegrar",
    "anegrarei": "anegrar",
    "anegrareis": "anegrar",
    "anegrarem": "anegrar",
    "anegraremos": "anegrar",
    "anegrares": "anegrar",
    "anegraria": "anegrar",
    "anegrariam": "anegrar",
    "anegrarias": "anegrar",
    "anegrarmo": "anegrar",
    "anegrarmos": "anegrar",
    "anegrará": "anegrar",
    "anegrarás": "anegrar",
    "anegrarão": "anegrar",
    "anegraríamos": "anegrar",
    "anegraríeis": "anegrar",
    "anegras": "anegrar",
    "anegrasse": "anegrar",
    "anegrassem": "anegrar",
    "anegrasses": "anegrar",
    "anegraste": "anegrar",
    "anegrastes": "anegrar",
    "anegrava": "anegrar",
    "anegravam": "anegrar",
    "anegravas": "anegrar",
    "anegre": "anegrar",
    "anegrei": "anegrar",
    "anegreis": "anegrar",
    "anegreja": "anegrejar",
    "anegrejada": "anegrejar",
    "anegrejadas": "anegrejar",
    "anegrejado": "anegrejar",
    "anegrejados": "anegrejar",
    "anegrejai": "anegrejar",
    "anegrejais": "anegrejar",
    "anegrejam": "anegrejar",
    "anegrejamo": "anegrejar",
    "anegrejamos": "anegrejar",
    "anegrejando": "anegrejar",
    "anegrejara": "anegrejar",
    "anegrejaram": "anegrejar",
    "anegrejaras": "anegrejar",
    "anegrejarde": "anegrejar",
    "anegrejardes": "anegrejar",
    "anegrejare": "anegrejar",
    "anegrejarei": "anegrejar",
    "anegrejareis": "anegrejar",
    "anegrejarem": "anegrejar",
    "anegrejaremos": "anegrejar",
    "anegrejares": "anegrejar",
    "anegrejaria": "anegrejar",
    "anegrejariam": "anegrejar",
    "anegrejarias": "anegrejar",
    "anegrejarmo": "anegrejar",
    "anegrejarmos": "anegrejar",
    "anegrejará": "anegrejar",
    "anegrejarás": "anegrejar",
    "anegrejarão": "anegrejar",
    "anegrejaríamos": "anegrejar",
    "anegrejaríeis": "anegrejar",
    "anegrejas": "anegrejar",
    "anegrejasse": "anegrejar",
    "anegrejassem": "anegrejar",
    "anegrejasses": "anegrejar",
    "anegrejaste": "anegrejar",
    "anegrejastes": "anegrejar",
    "anegrejava": "anegrejar",
    "anegrejavam": "anegrejar",
    "anegrejavas": "anegrejar",
    "anegreje": "anegrejar",
    "anegrejei": "anegrejar",
    "anegrejeis": "anegrejar",
    "anegrejem": "anegrejar",
    "anegrejemo": "anegrejar",
    "anegrejemos": "anegrejar",
    "anegrejes": "anegrejar",
    "anegrejo": "anegrejar",
    "anegrejou": "anegrejar",
    "anegrejá": "anegrejar",
    "anegrejámo": "anegrejar",
    "anegrejámos": "anegrejar",
    "anegrejáramo": "anegrejar",
    "anegrejáramos": "anegrejar",
    "anegrejárei": "anegrejar",
    "anegrejáreis": "anegrejar",
    "anegrejásseis": "anegrejar",
    "anegrejássemos": "anegrejar",
    "anegrejávamo": "anegrejar",
    "anegrejávamos": "anegrejar",
    "anegrejávei": "anegrejar",
    "anegrejáveis": "anegrejar",
    "anegrem": "anegrar",
    "anegremo": "anegrar",
    "anegremos": "anegrar",
    "anegres": "anegrar",
    "anegriscada": "anegriscado",
    "anegriscadas": "anegriscado",
    "anegriscados": "anegriscado",
    "anegro": "anegrar",
    "anegrou": "anegrar",
    "anegrá": "anegrar",
    "anegrámo": "anegrar",
    "anegrámos": "anegrar",
    "anegráramo": "anegrar",
    "anegráramos": "anegrar",
    "anegrárei": "anegrar",
    "anegráreis": "anegrar",
    "anegrásseis": "anegrar",
    "anegrássemos": "anegrar",
    "anegrávamo": "anegrar",
    "anegrávamos": "anegrar",
    "anegrávei": "anegrar",
    "anegráveis": "anegrar",
    "anegue": "anegar",
    "aneguei": "anegar",
    "anegueis": "anegar",
    "aneguem": "anegar",
    "aneguemo": "anegar",
    "aneguemos": "anegar",
    "anegues": "anegar",
    "anegá": "anegar",
    "anegámo": "anegar",
    "anegámos": "anegar",
    "anegáramo": "anegar",
    "anegáramos": "anegar",
    "anegárei": "anegar",
    "anegáreis": "anegar",
    "anegásseis": "anegar",
    "anegássemos": "anegar",
    "anegávamo": "anegar",
    "anegávamos": "anegar",
    "anegávei": "anegar",
    "anegáveis": "anegar",
    "aneira": "aneiro",
    "aneiras": "aneiro",
    "aneiros": "aneiro",
    "aneixas": "aneixa",
    "aneizinhos": "anel",
    "aneizitos": "anel",
    "aneja": "anejo",
    "anejas": "anejo",
    "anejos": "anejo",
    "anela": "anelar",
    "anelada": "anelar",
    "aneladas": "anelar",
    "anelado": "anelar",
    "anelados": "anelar",
    "aneladuras": "aneladura",
    "anelai": "anelar",
    "anelais": "anelar",
    "anelam": "anelar",
    "anelamo": "anelar",
    "anelamos": "anelar",
    "anelando": "anelar",
    "anelantes": "anelante",
    "anelara": "anelar",
    "anelaram": "anelar",
    "anelaras": "anelar",
    "anelarde": "anelar",
    "anelardes": "anelar",
    "anelare": "anelar",
    "anelarei": "anelar",
    "anelareis": "anelar",
    "anelarem": "anelar",
    "anelaremos": "anelar",
    "anelares": "anelar",
    "anelaria": "anelar",
    "anelariam": "anelar",
    "anelarias": "anelar",
    "anelarmo": "anelar",
    "anelarmos": "anelar",
    "anelará": "anelar",
    "anelarás": "anelar",
    "anelarão": "anelar",
    "anelaríamos": "anelar",
    "anelaríeis": "anelar",
    "anelas": "anelar",
    "anelasse": "anelar",
    "anelassem": "anelar",
    "anelasses": "anelar",
    "anelaste": "anelar",
    "anelastes": "anelar",
    "anelava": "anelar",
    "anelavam": "anelar",
    "anelavas": "anelar",
    "anelações": "anelação",
    "anele": "anelar",
    "anelei": "anelar",
    "aneleiras": "aneleira",
    "aneleis": "anelar",
    "anelem": "anelar",
    "anelemo": "anelar",
    "anelemos": "anelar",
    "aneles": "anelar",
    "anelhos": "anelho",
    "aneliformes": "aneliforme",
    "anelinho": "anel",
    "anelinhos": "anel",
    "anelito": "anel",
    "anelitos": "anel",
    "anelo": "anelar",
    "anelos": "anelo",
    "anelou": "anelar",
    "anelzinho": "anel",
    "anelzito": "anel",
    "anelá": "anelar",
    "anelámo": "anelar",
    "anelámos": "anelar",
    "aneláramo": "anelar",
    "aneláramos": "anelar",
    "anelárei": "anelar",
    "aneláreis": "anelar",
    "anelásseis": "anelar",
    "anelássemos": "anelar",
    "anelávamo": "anelar",
    "anelávamos": "anelar",
    "anelávei": "anelar",
    "aneláveis": "anelar",
    "aneléctrica": "aneléctrico",
    "aneléctricas": "aneléctrico",
    "aneléctricos": "aneléctrico",
    "anelídea": "anelídeo",
    "anelídeas": "anelídeo",
    "anelídeos": "anelídeo",
    "anelões": "anelão",
    "anemiada": "anemiado",
    "anemiadas": "anemiado",
    "anemiados": "anemiado",
    "anemiantes": "anemiante",
    "anemias": "anemia",
    "anemiza": "anemizar",
    "anemizada": "anemizar",
    "anemizadas": "anemizar",
    "anemizado": "anemizar",
    "anemizados": "anemizar",
    "anemizai": "anemizar",
    "anemizais": "anemizar",
    "anemizam": "anemizar",
    "anemizamo": "anemizar",
    "anemizamos": "anemizar",
    "anemizando": "anemizar",
    "anemizantes": "anemizante",
    "anemizara": "anemizar",
    "anemizaram": "anemizar",
    "anemizaras": "anemizar",
    "anemizarde": "anemizar",
    "anemizardes": "anemizar",
    "anemizare": "anemizar",
    "anemizarei": "anemizar",
    "anemizareis": "anemizar",
    "anemizarem": "anemizar",
    "anemizaremos": "anemizar",
    "anemizares": "anemizar",
    "anemizaria": "anemizar",
    "anemizariam": "anemizar",
    "anemizarias": "anemizar",
    "anemizarmo": "anemizar",
    "anemizarmos": "anemizar",
    "anemizará": "anemizar",
    "anemizarás": "anemizar",
    "anemizarão": "anemizar",
    "anemizaríamos": "anemizar",
    "anemizaríeis": "anemizar",
    "anemizas": "anemizar",
    "anemizasse": "anemizar",
    "anemizassem": "anemizar",
    "anemizasses": "anemizar",
    "anemizaste": "anemizar",
    "anemizastes": "anemizar",
    "anemizava": "anemizar",
    "anemizavam": "anemizar",
    "anemizavas": "anemizar",
    "anemize": "anemizar",
    "anemizei": "anemizar",
    "anemizeis": "anemizar",
    "anemizem": "anemizar",
    "anemizemo": "anemizar",
    "anemizemos": "anemizar",
    "anemizes": "anemizar",
    "anemizo": "anemizar",
    "anemizou": "anemizar",
    "anemizá": "anemizar",
    "anemizámo": "anemizar",
    "anemizámos": "anemizar",
    "anemizáramo": "anemizar",
    "anemizáramos": "anemizar",
    "anemizárei": "anemizar",
    "anemizáreis": "anemizar",
    "anemizásseis": "anemizar",
    "anemizássemos": "anemizar",
    "anemizávamo": "anemizar",
    "anemizávamos": "anemizar",
    "anemizávei": "anemizar",
    "anemizáveis": "anemizar",
    "anemofilias": "anemofilia",
    "anemofobias": "anemofobia",
    "anemogamias": "anemogamia",
    "anemografias": "anemografia",
    "anemogramas": "anemograma",
    "anemográfica": "anemográfico",
    "anemográficas": "anemográfico",
    "anemográficos": "anemográfico",
    "anemologias": "anemologia",
    "anemológica": "anemológico",
    "anemológicas": "anemológico",
    "anemológicos": "anemológico",
    "anemometrias": "anemometria",
    "anemometrógrafos": "anemometrógrafo",
    "anemométrica": "anemométrico",
    "anemométricas": "anemométrico",
    "anemométricos": "anemométrico",
    "anemopluviográfica": "anemopluviográfico",
    "anemopluviográficas": "anemopluviográfico",
    "anemopluviográficos": "anemopluviográfico",
    "anemopluviógrafos": "anemopluviógrafo",
    "anemoscopias": "anemoscopia",
    "anemoscópica": "anemoscópico",
    "anemoscópicas": "anemoscópico",
    "anemoscópicos": "anemoscópico",
    "anemoscópios": "anemoscópio",
    "anemoterapeutas": "anemoterapeuta",
    "anemoterapias": "anemoterapia",
    "anemoterapêutica": "anemoterapêutico",
    "anemoterapêuticas": "anemoterapêutico",
    "anemoterapêuticos": "anemoterapêutico",
    "anemoterápica": "anemoterápico",
    "anemoterápicas": "anemoterápico",
    "anemoterápicos": "anemoterápico",
    "anemotropismos": "anemotropismo",
    "anemática": "anemático",
    "anemáticas": "anemático",
    "anemáticos": "anemático",
    "anemófila": "anemófilo",
    "anemófilas": "anemófilo",
    "anemófilos": "anemófilo",
    "anemófoba": "anemófobo",
    "anemófobas": "anemófobo",
    "anemófobos": "anemófobo",
    "anemógama": "anemógamo",
    "anemógamas": "anemógamo",
    "anemógamos": "anemógamo",
    "anemógrafos": "anemógrafo",
    "anemómetros": "anemómetro",
    "anemótropa": "anemótropo",
    "anemótropas": "anemótropo",
    "anemótropos": "anemótropo",
    "anencefalias": "anencefalia",
    "anencefálica": "anencefálico",
    "anencefálicas": "anencefálico",
    "anencefálicos": "anencefálico",
    "anencéfala": "anencéfalo",
    "anencéfalas": "anencéfalo",
    "anencéfalos": "anencéfalo",
    "anepatias": "anepatia",
    "anepigrafias": "anepigrafia",
    "anepígrafa": "anepígrafo",
    "anepígrafas": "anepígrafo",
    "anepígrafos": "anepígrafo",
    "anequins": "anequim",
    "anervias": "anervia",
    "anervismos": "anervismo",
    "aneróides": "aneróide",
    "anesias": "anesia",
    "anestesia": "anestesiar",
    "anestesiada": "anestesiar",
    "anestesiadas": "anestesiar",
    "anestesiado": "anestesiar",
    "anestesiados": "anestesiar",
    "anestesiai": "anestesiar",
    "anestesiais": "anestesiar",
    "anestesiam": "anestesiar",
    "anestesiamo": "anestesiar",
    "anestesiamos": "anestesiar",
    "anestesiando": "anestesiar",
    "anestesiantes": "anestesiante",
    "anestesiara": "anestesiar",
    "anestesiaram": "anestesiar",
    "anestesiaras": "anestesiar",
    "anestesiarde": "anestesiar",
    "anestesiardes": "anestesiar",
    "anestesiare": "anestesiar",
    "anestesiarei": "anestesiar",
    "anestesiareis": "anestesiar",
    "anestesiarem": "anestesiar",
    "anestesiaremos": "anestesiar",
    "anestesiares": "anestesiar",
    "anestesiaria": "anestesiar",
    "anestesiariam": "anestesiar",
    "anestesiarias": "anestesiar",
    "anestesiarmo": "anestesiar",
    "anestesiarmos": "anestesiar",
    "anestesiará": "anestesiar",
    "anestesiarás": "anestesiar",
    "anestesiarão": "anestesiar",
    "anestesiaríamos": "anestesiar",
    "anestesiaríeis": "anestesiar",
    "anestesias": "anestesiar",
    "anestesiasse": "anestesiar",
    "anestesiassem": "anestesiar",
    "anestesiasses": "anestesiar",
    "anestesiaste": "anestesiar",
    "anestesiastes": "anestesiar",
    "anestesiava": "anestesiar",
    "anestesiavam": "anestesiar",
    "anestesiavas": "anestesiar",
    "anestesie": "anestesiar",
    "anestesiei": "anestesiar",
    "anestesieis": "anestesiar",
    "anestesiem": "anestesiar",
    "anestesiemo": "anestesiar",
    "anestesiemos": "anestesiar",
    "anestesies": "anestesiar",
    "anestesio": "anestesiar",
    "anestesiou": "anestesiar",
    "anestesistas": "anestesista",
    "anestesiá": "anestesiar",
    "anestesiámo": "anestesiar",
    "anestesiámos": "anestesiar",
    "anestesiáramo": "anestesiar",
    "anestesiáramos": "anestesiar",
    "anestesiárei": "anestesiar",
    "anestesiáreis": "anestesiar",
    "anestesiásseis": "anestesiar",
    "anestesiássemos": "anestesiar",
    "anestesiávamo": "anestesiar",
    "anestesiávamos": "anestesiar",
    "anestesiávei": "anestesiar",
    "anestesiáveis": "anestesiável",
    "anestésica": "anestésico",
    "anestésicas": "anestésico",
    "anestésicos": "anestésico",
    "anestética": "anestético",
    "anestéticas": "anestético",
    "anestéticos": "anestético",
    "anetes": "anete",
    "anetos": "aneto",
    "anetuns": "anetum",
    "aneurias": "aneuria",
    "aneurismais": "aneurismal",
    "aneurismas": "aneurisma",
    "aneurismática": "aneurismático",
    "aneurismáticas": "aneurismático",
    "aneurismáticos": "aneurismático",
    "aneuritmias": "aneuritmia",
    "aneuroses": "aneurose",
    "aneurostenias": "aneurostenia",
    "aneurítmica": "aneurítmico",
    "aneurítmicas": "aneurítmico",
    "aneurítmicos": "aneurítmico",
    "anexa": "anexo",
    "anexada": "anexar",
    "anexadas": "anexar",
    "anexado": "anexar",
    "anexados": "anexar",
    "anexai": "anexar",
    "anexais": "anexar",
    "anexam": "anexar",
    "anexamo": "anexar",
    "anexamos": "anexar",
    "anexando": "anexar",
    "anexara": "anexar",
    "anexaram": "anexar",
    "anexaras": "anexar",
    "anexarde": "anexar",
    "anexardes": "anexar",
    "anexare": "anexar",
    "anexarei": "anexar",
    "anexareis": "anexar",
    "anexarem": "anexar",
    "anexaremos": "anexar",
    "anexares": "anexar",
    "anexaria": "anexar",
    "anexariam": "anexar",
    "anexarias": "anexar",
    "anexarmo": "anexar",
    "anexarmos": "anexar",
    "anexará": "anexar",
    "anexarás": "anexar",
    "anexarão": "anexar",
    "anexaríamos": "anexar",
    "anexaríeis": "anexar",
    "anexas": "anexo",
    "anexasse": "anexar",
    "anexassem": "anexar",
    "anexasses": "anexar",
    "anexaste": "anexar",
    "anexastes": "anexar",
    "anexava": "anexar",
    "anexavam": "anexar",
    "anexavas": "anexar",
    "anexações": "anexação",
    "anexe": "anexar",
    "anexei": "anexar",
    "anexeis": "anexar",
    "anexem": "anexar",
    "anexemo": "anexar",
    "anexemos": "anexar",
    "anexes": "anexar",
    "anexins": "anexim",
    "anexionismos": "anexionismo",
    "anexionistas": "anexionista",
    "anexiristas": "anexirista",
    "anexo": "anexar",
    "anexos": "anexo",
    "anexou": "anexar",
    "anexá": "anexar",
    "anexámo": "anexar",
    "anexámos": "anexar",
    "anexáramo": "anexar",
    "anexáramos": "anexar",
    "anexárei": "anexar",
    "anexáreis": "anexar",
    "anexásseis": "anexar",
    "anexássemos": "anexar",
    "anexávamo": "anexar",
    "anexávamos": "anexar",
    "anexávei": "anexar",
    "anexáveis": "anexável",
    "anfetaminas": "anfetamina",
    "anfiartroses": "anfiartrose",
    "anfibiografias": "anfibiografia",
    "anfibiográfica": "anfibiográfico",
    "anfibiográficas": "anfibiográfico",
    "anfibiográficos": "anfibiográfico",
    "anfibiologias": "anfibiologia",
    "anfibiológica": "anfibiológico",
    "anfibiológicas": "anfibiológico",
    "anfibiológicos": "anfibiológico",
    "anfibióloga": "anfibiólogo",
    "anfibiólogas": "anfibiólogo",
    "anfibiólogos": "anfibiólogo",
    "anfibolias": "anfibolia",
    "anfibolitos": "anfibolito",
    "anfibologias": "anfibologia",
    "anfibologistas": "anfibologista",
    "anfiboloxistos": "anfiboloxisto",
    "anfibológica": "anfibológico",
    "anfibológicas": "anfibológico",
    "anfibológicos": "anfibológico",
    "anfibólica": "anfibólico",
    "anfibólicas": "anfibólico",
    "anfibólicos": "anfibólico",
    "anfibólios": "anfibólio",
    "anfictionias": "anfictionia",
    "anfictiónia": "anfictiónio",
    "anfictiónias": "anfictiónio",
    "anfictiónica": "anfictiónico",
    "anfictiónicas": "anfictiónico",
    "anfictiónicos": "anfictiónico",
    "anfictiónios": "anfictiónio",
    "anfictiões": "anfictião",
    "anficéfala": "anficéfalo",
    "anficéfalas": "anficéfalo",
    "anficéfalos": "anficéfalo",
    "anfida": "anfido",
    "anfidartroses": "anfidartrose",
    "anfidas": "anfido",
    "anfidermes": "anfiderme",
    "anfidos": "anfido",
    "anfifagias": "anfifagia",
    "anfigamias": "anfigamia",
    "anfigena": "anfigeno",
    "anfigenas": "anfigeno",
    "anfigenos": "anfigeno",
    "anfiguris": "anfiguri",
    "anfigurítica": "anfigurítico",
    "anfiguríticas": "anfigurítico",
    "anfiguríticos": "anfigurítico",
    "anfigénios": "anfigénio",
    "anfigúrica": "anfigúrico",
    "anfigúricas": "anfigúrico",
    "anfigúricos": "anfigúrico",
    "anfineuros": "anfineuro",
    "anfioxos": "anfioxo",
    "anfiprostilos": "anfiprostilo",
    "anfisarcas": "anfisarca",
    "anfisbenas": "anfisbena",
    "anfiteatrais": "anfiteatral",
    "anfiteatros": "anfiteatro",
    "anfiteátrica": "anfiteátrico",
    "anfiteátricas": "anfiteátrico",
    "anfiteátricos": "anfiteátrico",
    "anfitrites": "anfitrite",
    "anfitriã": "anfitrião",
    "anfitriãs": "anfitrião",
    "anfitriões": "anfitrião",
    "anfitropias": "anfitropia",
    "anfitrópica": "anfitrópico",
    "anfitrópicas": "anfitrópico",
    "anfitrópicos": "anfitrópico",
    "anfitálamos": "anfitálamo",
    "anforais": "anforal",
    "anforicidades": "anforicidade",
    "anfotérica": "anfotérico",
    "anfotéricas": "anfotérico",
    "anfotéricos": "anfotérico",
    "anfracta": "anfracto",
    "anfractas": "anfracto",
    "anfractos": "anfracto",
    "anfractua": "anfractuo",
    "anfractuas": "anfractuo",
    "anfractuos": "anfractuo",
    "anfractuosidades": "anfractuosidade",
    "anfíbia": "anfíbio",
    "anfíbias": "anfíbio",
    "anfíbios": "anfíbio",
    "anfíbola": "anfíbolo",
    "anfíbolas": "anfíbolo",
    "anfíbolos": "anfíbolo",
    "anfíbraca": "anfíbraco",
    "anfíbracas": "anfíbraco",
    "anfíbracos": "anfíbraco",
    "anfífaga": "anfífago",
    "anfífagas": "anfífago",
    "anfífagos": "anfífago",
    "anfígama": "anfígamo",
    "anfígamas": "anfígamo",
    "anfígamos": "anfígamo",
    "anfímacra": "anfímacro",
    "anfímacras": "anfímacro",
    "anfímacros": "anfímacro",
    "anfípodes": "anfípode",
    "anfíptera": "anfíptero",
    "anfípteras": "anfíptero",
    "anfípteros": "anfíptero",
    "anfíscios": "anfíscio",
    "anfítropa": "anfítropo",
    "anfítropas": "anfítropo",
    "anfítropos": "anfítropo",
    "anfólita": "anfólito",
    "anfólitas": "anfólito",
    "anfólitos": "anfólito",
    "anfórica": "anfórico",
    "anfóricas": "anfórico",
    "anfóricos": "anfórico",
    "anfótera": "anfótero",
    "anfóteras": "anfótero",
    "anfóteros": "anfótero",
    "anganas": "angana",
    "angarelas": "angarela",
    "angaria": "angariar",
    "angariada": "angariar",
    "angariadas": "angariar",
    "angariado": "angariar",
    "angariadora": "angariador",
    "angariadoras": "angariador",
    "angariadores": "angariador",
    "angariados": "angariar",
    "angariai": "angariar",
    "angariais": "angariar",
    "angariam": "angariar",
    "angariamo": "angariar",
    "angariamos": "angariar",
    "angariando": "angariar",
    "angariara": "angariar",
    "angariaram": "angariar",
    "angariaras": "angariar",
    "angariarde": "angariar",
    "angariardes": "angariar",
    "angariare": "angariar",
    "angariarei": "angariar",
    "angariareis": "angariar",
    "angariarem": "angariar",
    "angariaremos": "angariar",
    "angariares": "angariar",
    "angariaria": "angariar",
    "angariariam": "angariar",
    "angariarias": "angariar",
    "angariarmo": "angariar",
    "angariarmos": "angariar",
    "angariará": "angariar",
    "angariarás": "angariar",
    "angariarão": "angariar",
    "angariaríamos": "angariar",
    "angariaríeis": "angariar",
    "angarias": "angariar",
    "angariasse": "angariar",
    "angariassem": "angariar",
    "angariasses": "angariar",
    "angariaste": "angariar",
    "angariastes": "angariar",
    "angariava": "angariar",
    "angariavam": "angariar",
    "angariavas": "angariar",
    "angariações": "angariação",
    "angarie": "angariar",
    "angariei": "angariar",
    "angarieis": "angariar",
    "angariem": "angariar",
    "angariemo": "angariar",
    "angariemos": "angariar",
    "angaries": "angariar",
    "angarilhas": "angarilha",
    "angario": "angariar",
    "angariou": "angariar",
    "angariá": "angariar",
    "angariámo": "angariar",
    "angariámos": "angariar",
    "angariáramo": "angariar",
    "angariáramos": "angariar",
    "angariárei": "angariar",
    "angariáreis": "angariar",
    "angariásseis": "angariar",
    "angariássemos": "angariar",
    "angariávamo": "angariar",
    "angariávamos": "angariar",
    "angariávei": "angariar",
    "angariáveis": "angariável",
    "angelicais": "angelical",
    "angelina": "angelino",
    "angelinas": "angelino",
    "angelinos": "angelino",
    "angelins": "angelim",
    "angelismos": "angelismo",
    "angelitas": "angelita",
    "angelitudes": "angelitude",
    "angeliza": "angelizar",
    "angelizada": "angelizar",
    "angelizadas": "angelizar",
    "angelizado": "angelizar",
    "angelizados": "angelizar",
    "angelizai": "angelizar",
    "angelizais": "angelizar",
    "angelizam": "angelizar",
    "angelizamo": "angelizar",
    "angelizamos": "angelizar",
    "angelizando": "angelizar",
    "angelizara": "angelizar",
    "angelizaram": "angelizar",
    "angelizaras": "angelizar",
    "angelizarde": "angelizar",
    "angelizardes": "angelizar",
    "angelizare": "angelizar",
    "angelizarei": "angelizar",
    "angelizareis": "angelizar",
    "angelizarem": "angelizar",
    "angelizaremos": "angelizar",
    "angelizares": "angelizar",
    "angelizaria": "angelizar",
    "angelizariam": "angelizar",
    "angelizarias": "angelizar",
    "angelizarmo": "angelizar",
    "angelizarmos": "angelizar",
    "angelizará": "angelizar",
    "angelizarás": "angelizar",
    "angelizarão": "angelizar",
    "angelizaríamos": "angelizar",
    "angelizaríeis": "angelizar",
    "angelizas": "angelizar",
    "angelizasse": "angelizar",
    "angelizassem": "angelizar",
    "angelizasses": "angelizar",
    "angelizaste": "angelizar",
    "angelizastes": "angelizar",
    "angelizava": "angelizar",
    "angelizavam": "angelizar",
    "angelizavas": "angelizar",
    "angelizações": "angelização",
    "angelize": "angelizar",
    "angelizei": "angelizar",
    "angelizeis": "angelizar",
    "angelizem": "angelizar",
    "angelizemo": "angelizar",
    "angelizemos": "angelizar",
    "angelizes": "angelizar",
    "angelizo": "angelizar",
    "angelizou": "angelizar",
    "angelizá": "angelizar",
    "angelizámo": "angelizar",
    "angelizámos": "angelizar",
    "angelizáramo": "angelizar",
    "angelizáramos": "angelizar",
    "angelizárei": "angelizar",
    "angelizáreis": "angelizar",
    "angelizásseis": "angelizar",
    "angelizássemos": "angelizar",
    "angelizávamo": "angelizar",
    "angelizávamos": "angelizar",
    "angelizávei": "angelizar",
    "angelizáveis": "angelizar",
    "angelografias": "angelografia",
    "angelográfica": "angelográfico",
    "angelográficas": "angelográfico",
    "angelográficos": "angelográfico",
    "angelolatrias": "angelolatria",
    "angelologias": "angelologia",
    "angelólatras": "angelólatra",
    "anginas": "angina",
    "anginosa": "anginoso",
    "anginosas": "anginoso",
    "anginosos": "anginoso",
    "anginosíssima": "anginoso",
    "anginosíssimas": "anginoso",
    "anginosíssimo": "anginoso",
    "anginosíssimos": "anginoso",
    "angiocolites": "angiocolite",
    "angiografias": "angiografia",
    "angiográfica": "angiográfico",
    "angiográficas": "angiográfico",
    "angiográficos": "angiográfico",
    "angiologias": "angiologia",
    "angiológica": "angiológico",
    "angiológicas": "angiológico",
    "angiológicos": "angiológico",
    "angiomas": "angioma",
    "angiorragias": "angiorragia",
    "angioscopias": "angioscopia",
    "angioscópica": "angioscópico",
    "angioscópicas": "angioscópico",
    "angioscópicos": "angioscópico",
    "angioscópios": "angioscópio",
    "angioses": "angiose",
    "angiospermais": "angiospermal",
    "angiospérmica": "angiospérmico",
    "angiospérmicas": "angiospérmico",
    "angiospérmicos": "angiospérmico",
    "angiotomias": "angiotomia",
    "angites": "angite",
    "angla": "anglo",
    "anglas": "anglo",
    "angledôzeres": "angledôzer",
    "anglesites": "anglesite",
    "anglicana": "anglicano",
    "anglicanas": "anglicano",
    "anglicanismos": "anglicanismo",
    "anglicanos": "anglicano",
    "anglicismos": "anglicismo",
    "angliciza": "anglicizar",
    "anglicizada": "anglicizar",
    "anglicizadas": "anglicizar",
    "anglicizado": "anglicizar",
    "anglicizados": "anglicizar",
    "anglicizai": "anglicizar",
    "anglicizais": "anglicizar",
    "anglicizam": "anglicizar",
    "anglicizamo": "anglicizar",
    "anglicizamos": "anglicizar",
    "anglicizando": "anglicizar",
    "anglicizara": "anglicizar",
    "anglicizaram": "anglicizar",
    "anglicizaras": "anglicizar",
    "anglicizarde": "anglicizar",
    "anglicizardes": "anglicizar",
    "anglicizare": "anglicizar",
    "anglicizarei": "anglicizar",
    "anglicizareis": "anglicizar",
    "anglicizarem": "anglicizar",
    "anglicizaremos": "anglicizar",
    "anglicizares": "anglicizar",
    "anglicizaria": "anglicizar",
    "anglicizariam": "anglicizar",
    "anglicizarias": "anglicizar",
    "anglicizarmo": "anglicizar",
    "anglicizarmos": "anglicizar",
    "anglicizará": "anglicizar",
    "anglicizarás": "anglicizar",
    "anglicizarão": "anglicizar",
    "anglicizaríamos": "anglicizar",
    "anglicizaríeis": "anglicizar",
    "anglicizas": "anglicizar",
    "anglicizasse": "anglicizar",
    "anglicizassem": "anglicizar",
    "anglicizasses": "anglicizar",
    "anglicizaste": "anglicizar",
    "anglicizastes": "anglicizar",
    "anglicizava": "anglicizar",
    "anglicizavam": "anglicizar",
    "anglicizavas": "anglicizar",
    "anglicize": "anglicizar",
    "anglicizei": "anglicizar",
    "anglicizeis": "anglicizar",
    "anglicizem": "anglicizar",
    "anglicizemo": "anglicizar",
    "anglicizemos": "anglicizar",
    "anglicizes": "anglicizar",
    "anglicizo": "anglicizar",
    "anglicizou": "anglicizar",
    "anglicizá": "anglicizar",
    "anglicizámo": "anglicizar",
    "anglicizámos": "anglicizar",
    "anglicizáramo": "anglicizar",
    "anglicizáramos": "anglicizar",
    "anglicizárei": "anglicizar",
    "anglicizáreis": "anglicizar",
    "anglicizásseis": "anglicizar",
    "anglicizássemos": "anglicizar",
    "anglicizávamo": "anglicizar",
    "anglicizávamos": "anglicizar",
    "anglicizávei": "anglicizar",
    "anglicizáveis": "anglicizar",
    "anglofilias": "anglofilia",
    "anglofobias": "anglofobia",
    "anglomanias": "anglomania",
    "anglomaniza": "anglomanizar",
    "anglomanizada": "anglomanizar",
    "anglomanizadas": "anglomanizar",
    "anglomanizado": "anglomanizar",
    "anglomanizados": "anglomanizar",
    "anglomanizai": "anglomanizar",
    "anglomanizais": "anglomanizar",
    "anglomanizam": "anglomanizar",
    "anglomanizamo": "anglomanizar",
    "anglomanizamos": "anglomanizar",
    "anglomanizando": "anglomanizar",
    "anglomanizara": "anglomanizar",
    "anglomanizaram": "anglomanizar",
    "anglomanizaras": "anglomanizar",
    "anglomanizarde": "anglomanizar",
    "anglomanizardes": "anglomanizar",
    "anglomanizare": "anglomanizar",
    "anglomanizarei": "anglomanizar",
    "anglomanizareis": "anglomanizar",
    "anglomanizarem": "anglomanizar",
    "anglomanizaremos": "anglomanizar",
    "anglomanizares": "anglomanizar",
    "anglomanizaria": "anglomanizar",
    "anglomanizariam": "anglomanizar",
    "anglomanizarias": "anglomanizar",
    "anglomanizarmo": "anglomanizar",
    "anglomanizarmos": "anglomanizar",
    "anglomanizará": "anglomanizar",
    "anglomanizarás": "anglomanizar",
    "anglomanizarão": "anglomanizar",
    "anglomanizaríamos": "anglomanizar",
    "anglomanizaríeis": "anglomanizar",
    "anglomanizas": "anglomanizar",
    "anglomanizasse": "anglomanizar",
    "anglomanizassem": "anglomanizar",
    "anglomanizasses": "anglomanizar",
    "anglomanizaste": "anglomanizar",
    "anglomanizastes": "anglomanizar",
    "anglomanizava": "anglomanizar",
    "anglomanizavam": "anglomanizar",
    "anglomanizavas": "anglomanizar",
    "anglomanize": "anglomanizar",
    "anglomanizei": "anglomanizar",
    "anglomanizeis": "anglomanizar",
    "anglomanizem": "anglomanizar",
    "anglomanizemo": "anglomanizar",
    "anglomanizemos": "anglomanizar",
    "anglomanizes": "anglomanizar",
    "anglomanizo": "anglomanizar",
    "anglomanizou": "anglomanizar",
    "anglomanizá": "anglomanizar",
    "anglomanizámo": "anglomanizar",
    "anglomanizámos": "anglomanizar",
    "anglomanizáramo": "anglomanizar",
    "anglomanizáramos": "anglomanizar",
    "anglomanizárei": "anglomanizar",
    "anglomanizáreis": "anglomanizar",
    "anglomanizásseis": "anglomanizar",
    "anglomanizássemos": "anglomanizar",
    "anglomanizávamo": "anglomanizar",
    "anglomanizávamos": "anglomanizar",
    "anglomanizávei": "anglomanizar",
    "anglomanizáveis": "anglomanizar",
    "anglomaníaca": "anglomaníaco",
    "anglomaníacas": "anglomaníaco",
    "anglomaníacos": "anglomaníaco",
    "anglos": "anglo",
    "anglófila": "anglófilo",
    "anglófilas": "anglófilo",
    "anglófilos": "anglófilo",
    "anglófoba": "anglófobo",
    "anglófobas": "anglófobo",
    "anglófobos": "anglófobo",
    "anglófona": "anglófono",
    "anglófonas": "anglófono",
    "anglófonos": "anglófono",
    "anglómana": "anglómano",
    "anglómanas": "anglómano",
    "anglómanos": "anglómano",
    "angolana": "angolano",
    "angolanas": "angolano",
    "angolanidades": "angolanidade",
    "angolanos": "angolano",
    "angolares": "angolar",
    "angolas": "angola",
    "angolenses": "angolense",
    "angolinhas": "angolinha",
    "angoras": "angora",
    "angoretas": "angoreta",
    "angorás": "angorá",
    "angras": "angra",
    "angrenses": "angrense",
    "angstrons": "angstrom",
    "anguicidas": "anguicida",
    "anguiformes": "anguiforme",
    "anguiliformes": "anguiliforme",
    "anguiluloses": "anguilulose",
    "anguilulídea": "anguilulídeo",
    "anguilulídeas": "anguilulídeo",
    "anguilulídeos": "anguilulídeo",
    "anguilídea": "anguilídeo",
    "anguilídeas": "anguilídeo",
    "anguilídeos": "anguilídeo",
    "anguilóides": "anguilóide",
    "anguilúlida": "anguilúlido",
    "anguilúlidas": "anguilúlido",
    "anguilúlidos": "anguilúlido",
    "anguina": "anguino",
    "anguinas": "anguino",
    "anguinos": "anguino",
    "angulada": "angulado",
    "anguladas": "angulado",
    "angulados": "angulado",
    "angulares": "angular",
    "angularidades": "angularidade",
    "angulas": "angula",
    "angulaturas": "angulatura",
    "angulações": "angulação",
    "anguletes": "angulete",
    "angulirrostra": "angulirrostro",
    "angulirrostras": "angulirrostro",
    "angulirrostros": "angulirrostro",
    "angulometrias": "angulometria",
    "angulométrica": "angulométrico",
    "angulométricas": "angulométrico",
    "angulométricos": "angulométrico",
    "angulosa": "anguloso",
    "angulosas": "anguloso",
    "angulosos": "anguloso",
    "angulária": "angulário",
    "angulárias": "angulário",
    "angulários": "angulário",
    "angulóides": "angulóide",
    "angulómetros": "angulómetro",
    "angustia": "angustiar",
    "angustiada": "angustiar",
    "angustiadas": "angustiar",
    "angustiado": "angustiar",
    "angustiadora": "angustiador",
    "angustiadoras": "angustiador",
    "angustiadores": "angustiador",
    "angustiados": "angustiar",
    "angustiadíssima": "angustiado",
    "angustiadíssimas": "angustiado",
    "angustiadíssimo": "angustiado",
    "angustiadíssimos": "angustiado",
    "angustiai": "angustiar",
    "angustiais": "angustiar",
    "angustiam": "angustiar",
    "angustiamo": "angustiar",
    "angustiamos": "angustiar",
    "angustiando": "angustiar",
    "angustiantes": "angustiante",
    "angustiara": "angustiar",
    "angustiaram": "angustiar",
    "angustiaras": "angustiar",
    "angustiarde": "angustiar",
    "angustiardes": "angustiar",
    "angustiare": "angustiar",
    "angustiarei": "angustiar",
    "angustiareis": "angustiar",
    "angustiarem": "angustiar",
    "angustiaremos": "angustiar",
    "angustiares": "angustiar",
    "angustiaria": "angustiar",
    "angustiariam": "angustiar",
    "angustiarias": "angustiar",
    "angustiarmo": "angustiar",
    "angustiarmos": "angustiar",
    "angustiará": "angustiar",
    "angustiarás": "angustiar",
    "angustiarão": "angustiar",
    "angustiaríamos": "angustiar",
    "angustiaríeis": "angustiar",
    "angustias": "angustiar",
    "angustiasse": "angustiar",
    "angustiassem": "angustiar",
    "angustiasses": "angustiar",
    "angustiaste": "angustiar",
    "angustiastes": "angustiar",
    "angustiava": "angustiar",
    "angustiavam": "angustiar",
    "angustiavas": "angustiar",
    "angusticlavos": "angusticlavo",
    "angusticlávios": "angusticlávio",
    "angustie": "angustiar",
    "angustiei": "angustiar",
    "angustieis": "angustiar",
    "angustiem": "angustiar",
    "angustiemo": "angustiar",
    "angustiemos": "angustiar",
    "angusties": "angustiar",
    "angustifoliada": "angustifoliado",
    "angustifoliadas": "angustifoliado",
    "angustifoliados": "angustifoliado",
    "angustifólia": "angustifólio",
    "angustifólias": "angustifólio",
    "angustifólios": "angustifólio",
    "angustio": "angustiar",
    "angustiosa": "angustioso",
    "angustiosas": "angustioso",
    "angustiosos": "angustioso",
    "angustiou": "angustiar",
    "angustirrostra": "angustirrostro",
    "angustirrostras": "angustirrostro",
    "angustirrostros": "angustirrostro",
    "angustiá": "angustiar",
    "angustiámo": "angustiar",
    "angustiámos": "angustiar",
    "angustiáramo": "angustiar",
    "angustiáramos": "angustiar",
    "angustiárei": "angustiar",
    "angustiáreis": "angustiar",
    "angustiásseis": "angustiar",
    "angustiássemos": "angustiar",
    "angustiávamo": "angustiar",
    "angustiávamos": "angustiar",
    "angustiávei": "angustiar",
    "angustiáveis": "angustiar",
    "angusturas": "angustura",
    "angustímana": "angustímano",
    "angustímanas": "angustímano",
    "angustímanos": "angustímano",
    "anguzadas": "anguzada",
    "anguícoma": "anguícomo",
    "anguícomas": "anguícomo",
    "anguícomos": "anguícomo",
    "anguífera": "anguífero",
    "anguíferas": "anguífero",
    "anguíferos": "anguífero",
    "anguílida": "anguílido",
    "anguílidas": "anguílido",
    "anguílidos": "anguílido",
    "anguílula": "anguílulo",
    "anguílulas": "anguílulo",
    "anguílulos": "anguílulo",
    "anguípedes": "anguípede",
    "angélias": "angélia",
    "angélica": "angélico",
    "angélicas": "angélico",
    "angélicos": "angélico",
    "angústias": "angústia",
    "anhangueras": "anhanguera",
    "anhos": "anho",
    "anhotos": "anhoto",
    "aniagens": "aniagem",
    "anicha": "anichar",
    "anichada": "anichar",
    "anichadas": "anichar",
    "anichado": "anichar",
    "anichados": "anichar",
    "anichai": "anichar",
    "anichais": "anichar",
    "anicham": "anichar",
    "anichamo": "anichar",
    "anichamos": "anichar",
    "anichando": "anichar",
    "anichara": "anichar",
    "anicharam": "anichar",
    "anicharas": "anichar",
    "anicharde": "anichar",
    "anichardes": "anichar",
    "anichare": "anichar",
    "anicharei": "anichar",
    "anichareis": "anichar",
    "anicharem": "anichar",
    "anicharemos": "anichar",
    "anichares": "anichar",
    "anicharia": "anichar",
    "anichariam": "anichar",
    "anicharias": "anichar",
    "anicharmo": "anichar",
    "anicharmos": "anichar",
    "anichará": "anichar",
    "anicharás": "anichar",
    "anicharão": "anichar",
    "anicharíamos": "anichar",
    "anicharíeis": "anichar",
    "anichas": "anichar",
    "anichasse": "anichar",
    "anichassem": "anichar",
    "anichasses": "anichar",
    "anichaste": "anichar",
    "anichastes": "anichar",
    "anichava": "anichar",
    "anichavam": "anichar",
    "anichavas": "anichar",
    "aniche": "anichar",
    "anichei": "anichar",
    "anicheis": "anichar",
    "anichem": "anichar",
    "anichemo": "anichar",
    "anichemos": "anichar",
    "aniches": "anichar",
    "anicho": "anichar",
    "anichou": "anichar",
    "anichá": "anichar",
    "anichámo": "anichar",
    "anichámos": "anichar",
    "anicháramo": "anichar",
    "anicháramos": "anichar",
    "anichárei": "anichar",
    "anicháreis": "anichar",
    "anichásseis": "anichar",
    "anichássemos": "anichar",
    "anichávamo": "anichar",
    "anichávamos": "anichar",
    "anichávei": "anichar",
    "anicháveis": "anichar",
    "anidra": "anidro",
    "anidras": "anidro",
    "anidridos": "anidrido",
    "anidrites": "anidrite",
    "anidros": "anidro",
    "anidroses": "anidrose",
    "aniela": "anielar",
    "anielada": "anielar",
    "anieladas": "anielar",
    "anielado": "anielar",
    "anielados": "anielar",
    "anielagens": "anielagem",
    "anielai": "anielar",
    "anielais": "anielar",
    "anielam": "anielar",
    "anielamo": "anielar",
    "anielamos": "anielar",
    "anielando": "anielar",
    "anielara": "anielar",
    "anielaram": "anielar",
    "anielaras": "anielar",
    "anielarde": "anielar",
    "anielardes": "anielar",
    "anielare": "anielar",
    "anielarei": "anielar",
    "anielareis": "anielar",
    "anielarem": "anielar",
    "anielaremos": "anielar",
    "anielares": "anielar",
    "anielaria": "anielar",
    "anielariam": "anielar",
    "anielarias": "anielar",
    "anielarmo": "anielar",
    "anielarmos": "anielar",
    "anielará": "anielar",
    "anielarás": "anielar",
    "anielarão": "anielar",
    "anielaríamos": "anielar",
    "anielaríeis": "anielar",
    "anielas": "anielar",
    "anielasse": "anielar",
    "anielassem": "anielar",
    "anielasses": "anielar",
    "anielaste": "anielar",
    "anielastes": "anielar",
    "anielava": "anielar",
    "anielavam": "anielar",
    "anielavas": "anielar",
    "aniele": "anielar",
    "anielei": "anielar",
    "anieleis": "anielar",
    "anielem": "anielar",
    "anielemo": "anielar",
    "anielemos": "anielar",
    "anieles": "anielar",
    "anielo": "anielar",
    "anielou": "anielar",
    "anielá": "anielar",
    "anielámo": "anielar",
    "anielámos": "anielar",
    "anieláramo": "anielar",
    "anieláramos": "anielar",
    "anielárei": "anielar",
    "anieláreis": "anielar",
    "anielásseis": "anielar",
    "anielássemos": "anielar",
    "anielávamo": "anielar",
    "anielávamos": "anielar",
    "anielávei": "anielar",
    "anieláveis": "anielar",
    "aniila": "aniilar",
    "aniilada": "aniilar",
    "aniiladas": "aniilar",
    "aniilado": "aniilar",
    "aniilados": "aniilar",
    "aniilai": "aniilar",
    "aniilais": "aniilar",
    "aniilam": "aniilar",
    "aniilamo": "aniilar",
    "aniilamos": "aniilar",
    "aniilando": "aniilar",
    "aniilara": "aniilar",
    "aniilaram": "aniilar",
    "aniilaras": "aniilar",
    "aniilarde": "aniilar",
    "aniilardes": "aniilar",
    "aniilare": "aniilar",
    "aniilarei": "aniilar",
    "aniilareis": "aniilar",
    "aniilarem": "aniilar",
    "aniilaremos": "aniilar",
    "aniilares": "aniilar",
    "aniilaria": "aniilar",
    "aniilariam": "aniilar",
    "aniilarias": "aniilar",
    "aniilarmo": "aniilar",
    "aniilarmos": "aniilar",
    "aniilará": "aniilar",
    "aniilarás": "aniilar",
    "aniilarão": "aniilar",
    "aniilaríamos": "aniilar",
    "aniilaríeis": "aniilar",
    "aniilas": "aniilar",
    "aniilasse": "aniilar",
    "aniilassem": "aniilar",
    "aniilasses": "aniilar",
    "aniilaste": "aniilar",
    "aniilastes": "aniilar",
    "aniilava": "aniilar",
    "aniilavam": "aniilar",
    "aniilavas": "aniilar",
    "aniile": "aniilar",
    "aniilei": "aniilar",
    "aniileis": "aniilar",
    "aniilem": "aniilar",
    "aniilemo": "aniilar",
    "aniilemos": "aniilar",
    "aniiles": "aniilar",
    "aniilo": "aniilar",
    "aniilou": "aniilar",
    "aniilá": "aniilar",
    "aniilámo": "aniilar",
    "aniilámos": "aniilar",
    "aniiláramo": "aniilar",
    "aniiláramos": "aniilar",
    "aniilárei": "aniilar",
    "aniiláreis": "aniilar",
    "aniilásseis": "aniilar",
    "aniilássemos": "aniilar",
    "aniilávamo": "aniilar",
    "aniilávamos": "aniilar",
    "aniilávei": "aniilar",
    "aniiláveis": "aniilar",
    "aniis": "anil",
    "anila": "anilar",
    "anilada": "anilar",
    "aniladas": "anilar",
    "anilado": "anilar",
    "anilados": "anilar",
    "anilai": "anilar",
    "anilais": "anilar",
    "anilam": "anilar",
    "anilamo": "anilar",
    "anilamos": "anilar",
    "anilando": "anilar",
    "anilara": "anilar",
    "anilaram": "anilar",
    "anilaras": "anilar",
    "anilarde": "anilar",
    "anilardes": "anilar",
    "anilare": "anilar",
    "anilarei": "anilar",
    "anilareis": "anilar",
    "anilarem": "anilar",
    "anilaremos": "anilar",
    "anilares": "anilar",
    "anilaria": "anilar",
    "anilariam": "anilar",
    "anilarias": "anilar",
    "anilarmo": "anilar",
    "anilarmos": "anilar",
    "anilará": "anilar",
    "anilarás": "anilar",
    "anilarão": "anilar",
    "anilaríamos": "anilar",
    "anilaríeis": "anilar",
    "anilas": "anilar",
    "anilasse": "anilar",
    "anilassem": "anilar",
    "anilasses": "anilar",
    "anilaste": "anilar",
    "anilastes": "anilar",
    "anilava": "anilar",
    "anilavam": "anilar",
    "anilavas": "anilar",
    "anile": "anilar",
    "anilei": "anilar",
    "anileiras": "anileira",
    "anileiros": "anileiro",
    "anileis": "anilar",
    "anilem": "anilar",
    "anilemo": "anilar",
    "anilemos": "anilar",
    "aniles": "anilar",
    "anilha": "anilhar",
    "anilhace": "anilhaçar",
    "anilhacei": "anilhaçar",
    "anilhaceis": "anilhaçar",
    "anilhacem": "anilhaçar",
    "anilhacemo": "anilhaçar",
    "anilhacemos": "anilhaçar",
    "anilhaces": "anilhaçar",
    "anilhada": "anilhar",
    "anilhadas": "anilhar",
    "anilhado": "anilhar",
    "anilhados": "anilhar",
    "anilhai": "anilhar",
    "anilhais": "anilhar",
    "anilham": "anilhar",
    "anilhamo": "anilhar",
    "anilhamos": "anilhar",
    "anilhando": "anilhar",
    "anilhara": "anilhar",
    "anilharam": "anilhar",
    "anilharas": "anilhar",
    "anilharde": "anilhar",
    "anilhardes": "anilhar",
    "anilhare": "anilhar",
    "anilharei": "anilhar",
    "anilhareis": "anilhar",
    "anilharem": "anilhar",
    "anilharemos": "anilhar",
    "anilhares": "anilhar",
    "anilharia": "anilhar",
    "anilhariam": "anilhar",
    "anilharias": "anilhar",
    "anilharmo": "anilhar",
    "anilharmos": "anilhar",
    "anilhará": "anilhar",
    "anilharás": "anilhar",
    "anilharão": "anilhar",
    "anilharíamos": "anilhar",
    "anilharíeis": "anilhar",
    "anilhas": "anilhar",
    "anilhasse": "anilhar",
    "anilhassem": "anilhar",
    "anilhasses": "anilhar",
    "anilhaste": "anilhar",
    "anilhastes": "anilhar",
    "anilhava": "anilhar",
    "anilhavam": "anilhar",
    "anilhavas": "anilhar",
    "anilhaça": "anilhaçar",
    "anilhaçada": "anilhaçar",
    "anilhaçadas": "anilhaçar",
    "anilhaçado": "anilhaçar",
    "anilhaçados": "anilhaçar",
    "anilhaçai": "anilhaçar",
    "anilhaçais": "anilhaçar",
    "anilhaçam": "anilhaçar",
    "anilhaçamo": "anilhaçar",
    "anilhaçamos": "anilhaçar",
    "anilhaçando": "anilhaçar",
    "anilhaçara": "anilhaçar",
    "anilhaçaram": "anilhaçar",
    "anilhaçaras": "anilhaçar",
    "anilhaçarde": "anilhaçar",
    "anilhaçardes": "anilhaçar",
    "anilhaçare": "anilhaçar",
    "anilhaçarei": "anilhaçar",
    "anilhaçareis": "anilhaçar",
    "anilhaçarem": "anilhaçar",
    "anilhaçaremos": "anilhaçar",
    "anilhaçares": "anilhaçar",
    "anilhaçaria": "anilhaçar",
    "anilhaçariam": "anilhaçar",
    "anilhaçarias": "anilhaçar",
    "anilhaçarmo": "anilhaçar",
    "anilhaçarmos": "anilhaçar",
    "anilhaçará": "anilhaçar",
    "anilhaçarás": "anilhaçar",
    "anilhaçarão": "anilhaçar",
    "anilhaçaríamos": "anilhaçar",
    "anilhaçaríeis": "anilhaçar",
    "anilhaças": "anilhaçar",
    "anilhaçasse": "anilhaçar",
    "anilhaçassem": "anilhaçar",
    "anilhaçasses": "anilhaçar",
    "anilhaçaste": "anilhaçar",
    "anilhaçastes": "anilhaçar",
    "anilhaçava": "anilhaçar",
    "anilhaçavam": "anilhaçar",
    "anilhaçavas": "anilhaçar",
    "anilhaço": "anilhaçar",
    "anilhaçou": "anilhaçar",
    "anilhaçá": "anilhaçar",
    "anilhaçámo": "anilhaçar",
    "anilhaçámos": "anilhaçar",
    "anilhaçáramo": "anilhaçar",
    "anilhaçáramos": "anilhaçar",
    "anilhaçárei": "anilhaçar",
    "anilhaçáreis": "anilhaçar",
    "anilhaçásseis": "anilhaçar",
    "anilhaçássemos": "anilhaçar",
    "anilhaçávamo": "anilhaçar",
    "anilhaçávamos": "anilhaçar",
    "anilhaçávei": "anilhaçar",
    "anilhaçáveis": "anilhaçar",
    "anilhe": "anilhar",
    "anilhei": "anilhar",
    "anilheis": "anilhar",
    "anilhem": "anilhar",
    "anilhemo": "anilhar",
    "anilhemos": "anilhar",
    "anilhes": "anilhar",
    "anilho": "anilhar",
    "anilhos": "anilho",
    "anilhou": "anilhar",
    "anilhá": "anilhar",
    "anilhámo": "anilhar",
    "anilhámos": "anilhar",
    "anilháramo": "anilhar",
    "anilháramos": "anilhar",
    "anilhárei": "anilhar",
    "anilháreis": "anilhar",
    "anilhásseis": "anilhar",
    "anilhássemos": "anilhar",
    "anilhávamo": "anilhar",
    "anilhávamos": "anilhar",
    "anilhávei": "anilhar",
    "anilháveis": "anilhar",
    "anilina": "anilinar",
    "anilinada": "anilinar",
    "anilinadas": "anilinar",
    "anilinado": "anilinar",
    "anilinados": "anilinar",
    "anilinai": "anilinar",
    "anilinais": "anilinar",
    "anilinam": "anilinar",
    "anilinamo": "anilinar",
    "anilinamos": "anilinar",
    "anilinando": "anilinar",
    "anilinara": "anilinar",
    "anilinaram": "anilinar",
    "anilinaras": "anilinar",
    "anilinarde": "anilinar",
    "anilinardes": "anilinar",
    "anilinare": "anilinar",
    "anilinarei": "anilinar",
    "anilinareis": "anilinar",
    "anilinarem": "anilinar",
    "anilinaremos": "anilinar",
    "anilinares": "anilinar",
    "anilinaria": "anilinar",
    "anilinariam": "anilinar",
    "anilinarias": "anilinar",
    "anilinarmo": "anilinar",
    "anilinarmos": "anilinar",
    "anilinará": "anilinar",
    "anilinarás": "anilinar",
    "anilinarão": "anilinar",
    "anilinaríamos": "anilinar",
    "anilinaríeis": "anilinar",
    "anilinas": "anilinar",
    "anilinasse": "anilinar",
    "anilinassem": "anilinar",
    "anilinasses": "anilinar",
    "anilinaste": "anilinar",
    "anilinastes": "anilinar",
    "anilinava": "anilinar",
    "anilinavam": "anilinar",
    "anilinavas": "anilinar",
    "aniline": "anilinar",
    "anilinei": "anilinar",
    "anilineis": "anilinar",
    "anilinem": "anilinar",
    "anilinemo": "anilinar",
    "anilinemos": "anilinar",
    "anilines": "anilinar",
    "anilino": "anilinar",
    "anilinou": "anilinar",
    "aniliná": "anilinar",
    "anilinámo": "anilinar",
    "anilinámos": "anilinar",
    "anilináramo": "anilinar",
    "anilináramos": "anilinar",
    "anilinárei": "anilinar",
    "anilináreis": "anilinar",
    "anilinásseis": "anilinar",
    "anilinássemos": "anilinar",
    "anilinávamo": "anilinar",
    "anilinávamos": "anilinar",
    "anilinávei": "anilinar",
    "anilináveis": "anilinar",
    "anilismos": "anilismo",
    "anilites": "anilite",
    "anilo": "anilar",
    "anilou": "anilar",
    "anilá": "anilar",
    "anilámo": "anilar",
    "anilámos": "anilar",
    "aniláramo": "anilar",
    "aniláramos": "anilar",
    "anilárei": "anilar",
    "aniláreis": "anilar",
    "anilásseis": "anilar",
    "anilássemos": "anilar",
    "anilávamo": "anilar",
    "anilávamos": "anilar",
    "anilávei": "anilar",
    "aniláveis": "anilar",
    "anima": "animar",
    "animada": "animar",
    "animadas": "animar",
    "animado": "animar",
    "animadora": "animador",
    "animadoras": "animador",
    "animadores": "animador",
    "animados": "animar",
    "animadversões": "animadversão",
    "animadverte": "animadvertir",
    "animadvertem": "animadvertir",
    "animadvertes": "animadvertir",
    "animadverti": "animadvertir",
    "animadvertia": "animadvertir",
    "animadvertiam": "animadvertir",
    "animadvertias": "animadvertir",
    "animadvertida": "animadvertir",
    "animadvertidas": "animadvertir",
    "animadvertido": "animadvertir",
    "animadvertidos": "animadvertir",
    "animadvertimo": "animadvertir",
    "animadvertimos": "animadvertir",
    "animadvertindo": "animadvertir",
    "animadvertira": "animadvertir",
    "animadvertiram": "animadvertir",
    "animadvertiras": "animadvertir",
    "animadvertirde": "animadvertir",
    "animadvertirdes": "animadvertir",
    "animadvertire": "animadvertir",
    "animadvertirei": "animadvertir",
    "animadvertireis": "animadvertir",
    "animadvertirem": "animadvertir",
    "animadvertiremos": "animadvertir",
    "animadvertires": "animadvertir",
    "animadvertiria": "animadvertir",
    "animadvertiriam": "animadvertir",
    "animadvertirias": "animadvertir",
    "animadvertirmo": "animadvertir",
    "animadvertirmos": "animadvertir",
    "animadvertirá": "animadvertir",
    "animadvertirás": "animadvertir",
    "animadvertirão": "animadvertir",
    "animadvertiríamos": "animadvertir",
    "animadvertiríeis": "animadvertir",
    "animadvertis": "animadvertir",
    "animadvertisse": "animadvertir",
    "animadvertissem": "animadvertir",
    "animadvertisses": "animadvertir",
    "animadvertiste": "animadvertir",
    "animadvertistes": "animadvertir",
    "animadvertiu": "animadvertir",
    "animadvertíamo": "animadvertir",
    "animadvertíamos": "animadvertir",
    "animadvertíei": "animadvertir",
    "animadvertíeis": "animadvertir",
    "animadvertíramo": "animadvertir",
    "animadvertíramos": "animadvertir",
    "animadvertírei": "animadvertir",
    "animadvertíreis": "animadvertir",
    "animadvertísseis": "animadvertir",
    "animadvertíssemos": "animadvertir",
    "animadvirta": "animadvertir",
    "animadvirtais": "animadvertir",
    "animadvirtam": "animadvertir",
    "animadvirtamo": "animadvertir",
    "animadvirtamos": "animadvertir",
    "animadvirtas": "animadvertir",
    "animadvirto": "animadvertir",
    "animadíssima": "animado",
    "animadíssimas": "animado",
    "animadíssimo": "animado",
    "animadíssimos": "animado",
    "animai": "animar",
    "animais": "animar",
    "animaizinhas": "animal",
    "animaizinhos": "animal",
    "animaizitos": "animal",
    "animaladas": "animalada",
    "animalaços": "animalaço",
    "animalculares": "animalcular",
    "animalejos": "animalejo",
    "animalesca": "animalesco",
    "animalescas": "animalesco",
    "animalescos": "animalesco",
    "animalicidas": "animalicida",
    "animalicídios": "animalicídio",
    "animalidades": "animalidade",
    "animalinha": "animal",
    "animalinhas": "animal",
    "animalinho": "animal",
    "animalinhos": "animal",
    "animalismos": "animalismo",
    "animalistas": "animalista",
    "animalita": "animal",
    "animalitas": "animal",
    "animalito": "animal",
    "animalitos": "animal",
    "animaliza": "animalizar",
    "animalizada": "animalizar",
    "animalizadas": "animalizar",
    "animalizado": "animalizar",
    "animalizados": "animalizar",
    "animalizai": "animalizar",
    "animalizais": "animalizar",
    "animalizam": "animalizar",
    "animalizamo": "animalizar",
    "animalizamos": "animalizar",
    "animalizando": "animalizar",
    "animalizara": "animalizar",
    "animalizaram": "animalizar",
    "animalizaras": "animalizar",
    "animalizarde": "animalizar",
    "animalizardes": "animalizar",
    "animalizare": "animalizar",
    "animalizarei": "animalizar",
    "animalizareis": "animalizar",
    "animalizarem": "animalizar",
    "animalizaremos": "animalizar",
    "animalizares": "animalizar",
    "animalizaria": "animalizar",
    "animalizariam": "animalizar",
    "animalizarias": "animalizar",
    "animalizarmo": "animalizar",
    "animalizarmos": "animalizar",
    "animalizará": "animalizar",
    "animalizarás": "animalizar",
    "animalizarão": "animalizar",
    "animalizaríamos": "animalizar",
    "animalizaríeis": "animalizar",
    "animalizas": "animalizar",
    "animalizasse": "animalizar",
    "animalizassem": "animalizar",
    "animalizasses": "animalizar",
    "animalizaste": "animalizar",
    "animalizastes": "animalizar",
    "animalizava": "animalizar",
    "animalizavam": "animalizar",
    "animalizavas": "animalizar",
    "animalizações": "animalização",
    "animalize": "animalizar",
    "animalizei": "animalizar",
    "animalizeis": "animalizar",
    "animalizem": "animalizar",
    "animalizemo": "animalizar",
    "animalizemos": "animalizar",
    "animalizes": "animalizar",
    "animalizo": "animalizar",
    "animalizou": "animalizar",
    "animalizá": "animalizar",
    "animalizámo": "animalizar",
    "animalizámos": "animalizar",
    "animalizáramo": "animalizar",
    "animalizáramos": "animalizar",
    "animalizárei": "animalizar",
    "animalizáreis": "animalizar",
    "animalizásseis": "animalizar",
    "animalizássemos": "animalizar",
    "animalizávamo": "animalizar",
    "animalizávamos": "animalizar",
    "animalizávei": "animalizar",
    "animalizáveis": "animalizar",
    "animalogias": "animalogia",
    "animalona": "animalão",
    "animalonas": "animalão",
    "animalzinha": "animal",
    "animalzinho": "animal",
    "animalzito": "animal",
    "animalões": "animalão",
    "animam": "animar",
    "animamo": "animar",
    "animamos": "animar",
    "animando": "animar",
    "animantes": "animante",
    "animara": "animar",
    "animaram": "animar",
    "animaras": "animar",
    "animarde": "animar",
    "animardes": "animar",
    "animare": "animar",
    "animarei": "animar",
    "animareis": "animar",
    "animarem": "animar",
    "animaremos": "animar",
    "animares": "animar",
    "animaria": "animar",
    "animariam": "animar",
    "animarias": "animar",
    "animarmo": "animar",
    "animarmos": "animar",
    "animará": "animar",
    "animarás": "animar",
    "animarão": "animar",
    "animaríamos": "animar",
    "animaríeis": "animar",
    "animas": "animar",
    "animasse": "animar",
    "animassem": "animar",
    "animasses": "animar",
    "animaste": "animar",
    "animastes": "animar",
    "animatográfica": "animatográfico",
    "animatográficas": "animatográfico",
    "animatográficos": "animatográfico",
    "animatos": "animato",
    "animatógrafos": "animatógrafo",
    "animava": "animar",
    "animavam": "animar",
    "animavas": "animar",
    "animações": "animação",
    "anime": "animar",
    "animei": "animar",
    "animeis": "animar",
    "animem": "animar",
    "animemo": "animar",
    "animemos": "animar",
    "animes": "anime",
    "animicidas": "animicida",
    "animismos": "animismo",
    "animistas": "animista",
    "animizitas": "animal",
    "animizitos": "animal",
    "animlzita": "animal",
    "animlzito": "animal",
    "animo": "animar",
    "animosa": "animoso",
    "animosas": "animoso",
    "animosidades": "animosidade",
    "animosos": "animoso",
    "animosíssima": "animoso",
    "animosíssimas": "animoso",
    "animosíssimo": "animoso",
    "animosíssimos": "animoso",
    "animou": "animar",
    "animá": "animar",
    "animálculos": "animálculo",
    "animálias": "animália",
    "animámo": "animar",
    "animámos": "animar",
    "animáramo": "animar",
    "animáramos": "animar",
    "animárei": "animar",
    "animáreis": "animar",
    "animásseis": "animar",
    "animássemos": "animar",
    "animávamo": "animar",
    "animávamos": "animar",
    "animávei": "animar",
    "animáveis": "animável",
    "aninas": "anina",
    "aninha": "aninhar",
    "aninhada": "aninhar",
    "aninhadas": "aninhar",
    "aninhado": "aninhar",
    "aninhadora": "aninhador",
    "aninhadoras": "aninhador",
    "aninhadores": "aninhador",
    "aninhados": "aninhar",
    "aninhai": "aninhar",
    "aninhais": "aninhar",
    "aninham": "aninhar",
    "aninhamo": "aninhar",
    "aninhamos": "aninhar",
    "aninhando": "aninhar",
    "aninhara": "aninhar",
    "aninharam": "aninhar",
    "aninharas": "aninhar",
    "aninharde": "aninhar",
    "aninhardes": "aninhar",
    "aninhare": "aninhar",
    "aninharei": "aninhar",
    "aninhareis": "aninhar",
    "aninharem": "aninhar",
    "aninharemos": "aninhar",
    "aninhares": "aninhar",
    "aninharia": "aninhar",
    "aninhariam": "aninhar",
    "aninharias": "aninhar",
    "aninharmo": "aninhar",
    "aninharmos": "aninhar",
    "aninhará": "aninhar",
    "aninharás": "aninhar",
    "aninharão": "aninhar",
    "aninharíamos": "aninhar",
    "aninharíeis": "aninhar",
    "aninhas": "aninhar",
    "aninhasse": "aninhar",
    "aninhassem": "aninhar",
    "aninhasses": "aninhar",
    "aninhaste": "aninhar",
    "aninhastes": "aninhar",
    "aninhava": "aninhar",
    "aninhavam": "aninhar",
    "aninhavas": "aninhar",
    "aninhe": "aninhar",
    "aninhei": "aninhar",
    "aninheis": "aninhar",
    "aninhem": "aninhar",
    "aninhemo": "aninhar",
    "aninhemos": "aninhar",
    "aninhes": "aninhar",
    "aninho": "ano",
    "aninhos": "ano",
    "aninhou": "aninhar",
    "aninhá": "aninhar",
    "aninhámo": "aninhar",
    "aninhámos": "aninhar",
    "aninháramo": "aninhar",
    "aninháramos": "aninhar",
    "aninhárei": "aninhar",
    "aninháreis": "aninhar",
    "aninhásseis": "aninhar",
    "aninhássemos": "aninhar",
    "aninhávamo": "aninhar",
    "aninhávamos": "aninhar",
    "aninhávei": "aninhar",
    "aninháveis": "aninhar",
    "aniquila": "aniquilar",
    "aniquilada": "aniquilar",
    "aniquiladas": "aniquilar",
    "aniquilado": "aniquilar",
    "aniquiladora": "aniquilador",
    "aniquiladoras": "aniquilador",
    "aniquiladores": "aniquilador",
    "aniquilados": "aniquilar",
    "aniquilai": "aniquilar",
    "aniquilais": "aniquilar",
    "aniquilam": "aniquilar",
    "aniquilamentos": "aniquilamento",
    "aniquilamo": "aniquilar",
    "aniquilamos": "aniquilar",
    "aniquilando": "aniquilar",
    "aniquilara": "aniquilar",
    "aniquilaram": "aniquilar",
    "aniquilaras": "aniquilar",
    "aniquilarde": "aniquilar",
    "aniquilardes": "aniquilar",
    "aniquilare": "aniquilar",
    "aniquilarei": "aniquilar",
    "aniquilareis": "aniquilar",
    "aniquilarem": "aniquilar",
    "aniquilaremos": "aniquilar",
    "aniquilares": "aniquilar",
    "aniquilaria": "aniquilar",
    "aniquilariam": "aniquilar",
    "aniquilarias": "aniquilar",
    "aniquilarmo": "aniquilar",
    "aniquilarmos": "aniquilar",
    "aniquilará": "aniquilar",
    "aniquilarás": "aniquilar",
    "aniquilarão": "aniquilar",
    "aniquilaríamos": "aniquilar",
    "aniquilaríeis": "aniquilar",
    "aniquilas": "aniquilar",
    "aniquilasse": "aniquilar",
    "aniquilassem": "aniquilar",
    "aniquilasses": "aniquilar",
    "aniquilaste": "aniquilar",
    "aniquilastes": "aniquilar",
    "aniquilava": "aniquilar",
    "aniquilavam": "aniquilar",
    "aniquilavas": "aniquilar",
    "aniquilações": "aniquilação",
    "aniquile": "aniquilar",
    "aniquilei": "aniquilar",
    "aniquileis": "aniquilar",
    "aniquilem": "aniquilar",
    "aniquilemo": "aniquilar",
    "aniquilemos": "aniquilar",
    "aniquiles": "aniquilar",
    "aniquilo": "aniquilar",
    "aniquilou": "aniquilar",
    "aniquilá": "aniquilar",
    "aniquilámo": "aniquilar",
    "aniquilámos": "aniquilar",
    "aniquiláramo": "aniquilar",
    "aniquiláramos": "aniquilar",
    "aniquilárei": "aniquilar",
    "aniquiláreis": "aniquilar",
    "aniquilásseis": "aniquilar",
    "aniquilássemos": "aniquilar",
    "aniquilávamo": "aniquilar",
    "aniquilávamos": "aniquilar",
    "aniquilávei": "aniquilar",
    "aniquiláveis": "aniquilável",
    "anisa": "anisar",
    "anisada": "anisar",
    "anisadas": "anisar",
    "anisado": "anisar",
    "anisadores": "anisador",
    "anisados": "anisar",
    "anisai": "anisar",
    "anisais": "anisar",
    "anisam": "anisar",
    "anisamo": "anisar",
    "anisamos": "anisar",
    "anisando": "anisar",
    "anisanta": "anisanto",
    "anisantas": "anisanto",
    "anisantes": "anisante",
    "anisantos": "anisanto",
    "anisara": "anisar",
    "anisaram": "anisar",
    "anisaras": "anisar",
    "anisarde": "anisar",
    "anisardes": "anisar",
    "anisare": "anisar",
    "anisarei": "anisar",
    "anisareis": "anisar",
    "anisarem": "anisar",
    "anisaremos": "anisar",
    "anisares": "anisar",
    "anisaria": "anisar",
    "anisariam": "anisar",
    "anisarias": "anisar",
    "anisarmo": "anisar",
    "anisarmos": "anisar",
    "anisará": "anisar",
    "anisarás": "anisar",
    "anisarão": "anisar",
    "anisaríamos": "anisar",
    "anisaríeis": "anisar",
    "anisas": "anisar",
    "anisasse": "anisar",
    "anisassem": "anisar",
    "anisasses": "anisar",
    "anisaste": "anisar",
    "anisastes": "anisar",
    "anisava": "anisar",
    "anisavam": "anisar",
    "anisavas": "anisar",
    "anise": "anisar",
    "anisei": "anisar",
    "aniseiras": "aniseira",
    "aniseis": "anisar",
    "anisem": "anisar",
    "anisemo": "anisar",
    "anisemos": "anisar",
    "anises": "anisar",
    "anisetas": "aniseta",
    "anisetes": "anisete",
    "anisinas": "anisina",
    "aniso": "anisar",
    "anisocorias": "anisocoria",
    "anisocromias": "anisocromia",
    "anisocromática": "anisocromático",
    "anisocromáticas": "anisocromático",
    "anisocromáticos": "anisocromático",
    "anisocrómios": "anisocrómio",
    "anisocórica": "anisocórico",
    "anisocóricas": "anisocórico",
    "anisocóricos": "anisocórico",
    "anisodactilias": "anisodactilia",
    "anisodontes": "anisodonte",
    "anisodontias": "anisodontia",
    "anisodáctila": "anisodáctilo",
    "anisodáctilas": "anisodáctilo",
    "anisodáctilos": "anisodáctilo",
    "anisofilias": "anisofilia",
    "anisogamias": "anisogamia",
    "anisomerias": "anisomeria",
    "anisometrias": "anisometria",
    "anisometropes": "anisometrope",
    "anisometropias": "anisometropia",
    "anisométrica": "anisométrico",
    "anisométricas": "anisométrico",
    "anisométricos": "anisométrico",
    "anisopetalias": "anisopetalia",
    "anisopodias": "anisopodia",
    "anisopterias": "anisopteria",
    "anisopétala": "anisopétalo",
    "anisopétalas": "anisopétalo",
    "anisopétalos": "anisopétalo",
    "anisostemonias": "anisostemonia",
    "anisostémones": "anisostémone",
    "anisotropias": "anisotropia",
    "anisotrópica": "anisotrópico",
    "anisotrópicas": "anisotrópico",
    "anisotrópicos": "anisotrópico",
    "anisou": "anisar",
    "anista": "anisto",
    "anistas": "anisto",
    "anistos": "anisto",
    "anisá": "anisar",
    "anisámo": "anisar",
    "anisámos": "anisar",
    "anisáramo": "anisar",
    "anisáramos": "anisar",
    "anisárei": "anisar",
    "anisáreis": "anisar",
    "anisásseis": "anisar",
    "anisássemos": "anisar",
    "anisávamo": "anisar",
    "anisávamos": "anisar",
    "anisávei": "anisar",
    "anisáveis": "anisar",
    "anisófila": "anisófilo",
    "anisófilas": "anisófilo",
    "anisófilos": "anisófilo",
    "anisógama": "anisógamo",
    "anisógamas": "anisógamo",
    "anisógamos": "anisógamo",
    "anisómera": "anisómero",
    "anisómeras": "anisómero",
    "anisómeros": "anisómero",
    "anisómetros": "anisómetro",
    "anisópodes": "anisópode",
    "anisóptera": "anisóptero",
    "anisópteras": "anisóptero",
    "anisópteros": "anisóptero",
    "anisótropa": "anisótropo",
    "anisótropas": "anisótropo",
    "anisótropos": "anisótropo",
    "anites": "anite",
    "anito": "ano",
    "anitos": "ano",
    "anivela": "anivelar",
    "anivelada": "anivelar",
    "aniveladas": "anivelar",
    "anivelado": "anivelar",
    "anivelados": "anivelar",
    "anivelai": "anivelar",
    "anivelais": "anivelar",
    "anivelam": "anivelar",
    "anivelamo": "anivelar",
    "anivelamos": "anivelar",
    "anivelando": "anivelar",
    "anivelara": "anivelar",
    "anivelaram": "anivelar",
    "anivelaras": "anivelar",
    "anivelarde": "anivelar",
    "anivelardes": "anivelar",
    "anivelare": "anivelar",
    "anivelarei": "anivelar",
    "anivelareis": "anivelar",
    "anivelarem": "anivelar",
    "anivelaremos": "anivelar",
    "anivelares": "anivelar",
    "anivelaria": "anivelar",
    "anivelariam": "anivelar",
    "anivelarias": "anivelar",
    "anivelarmo": "anivelar",
    "anivelarmos": "anivelar",
    "anivelará": "anivelar",
    "anivelarás": "anivelar",
    "anivelarão": "anivelar",
    "anivelaríamos": "anivelar",
    "anivelaríeis": "anivelar",
    "anivelas": "anivelar",
    "anivelasse": "anivelar",
    "anivelassem": "anivelar",
    "anivelasses": "anivelar",
    "anivelaste": "anivelar",
    "anivelastes": "anivelar",
    "anivelava": "anivelar",
    "anivelavam": "anivelar",
    "anivelavas": "anivelar",
    "anivele": "anivelar",
    "anivelei": "anivelar",
    "aniveleis": "anivelar",
    "anivelem": "anivelar",
    "anivelemo": "anivelar",
    "anivelemos": "anivelar",
    "aniveles": "anivelar",
    "anivelo": "anivelar",
    "anivelou": "anivelar",
    "anivelá": "anivelar",
    "anivelámo": "anivelar",
    "anivelámos": "anivelar",
    "aniveláramo": "anivelar",
    "aniveláramos": "anivelar",
    "anivelárei": "anivelar",
    "aniveláreis": "anivelar",
    "anivelásseis": "anivelar",
    "anivelássemos": "anivelar",
    "anivelávamo": "anivelar",
    "anivelávamos": "anivelar",
    "anivelávei": "anivelar",
    "aniveláveis": "anivelar",
    "aniversaria": "aniversariar",
    "aniversariada": "aniversariar",
    "aniversariadas": "aniversariar",
    "aniversariado": "aniversariar",
    "aniversariados": "aniversariar",
    "aniversariai": "aniversariar",
    "aniversariais": "aniversariar",
    "aniversariam": "aniversariar",
    "aniversariamo": "aniversariar",
    "aniversariamos": "aniversariar",
    "aniversariando": "aniversariar",
    "aniversariantes": "aniversariante",
    "aniversariara": "aniversariar",
    "aniversariaram": "aniversariar",
    "aniversariaras": "aniversariar",
    "aniversariardes": "aniversariar",
    "aniversariarei": "aniversariar",
    "aniversariareis": "aniversariar",
    "aniversariarem": "aniversariar",
    "aniversariaremos": "aniversariar",
    "aniversariares": "aniversariar",
    "aniversariaria": "aniversariar",
    "aniversariariam": "aniversariar",
    "aniversariarias": "aniversariar",
    "aniversariarmo": "aniversariar",
    "aniversariarmos": "aniversariar",
    "aniversariará": "aniversariar",
    "aniversariarás": "aniversariar",
    "aniversariarão": "aniversariar",
    "aniversariaríamos": "aniversariar",
    "aniversariaríeis": "aniversariar",
    "aniversarias": "aniversariar",
    "aniversariasse": "aniversariar",
    "aniversariassem": "aniversariar",
    "aniversariasses": "aniversariar",
    "aniversariaste": "aniversariar",
    "aniversariastes": "aniversariar",
    "aniversariava": "aniversariar",
    "aniversariavam": "aniversariar",
    "aniversariavas": "aniversariar",
    "aniversarie": "aniversariar",
    "aniversariei": "aniversariar",
    "aniversarieis": "aniversariar",
    "aniversariem": "aniversariar",
    "aniversariemo": "aniversariar",
    "aniversariemos": "aniversariar",
    "aniversaries": "aniversariar",
    "aniversario": "aniversariar",
    "aniversariou": "aniversariar",
    "aniversariámo": "aniversariar",
    "aniversariámos": "aniversariar",
    "aniversariáramo": "aniversariar",
    "aniversariáramos": "aniversariar",
    "aniversariáreis": "aniversariar",
    "aniversariásseis": "aniversariar",
    "aniversariássemos": "aniversariar",
    "aniversariávamo": "aniversariar",
    "aniversariávamos": "aniversariar",
    "aniversariáveis": "aniversariar",
    "aniversários": "aniversário",
    "aniões": "anião",
    "anjinho": "anjo",
    "anjinhos": "anjo",
    "anjito": "anjo",
    "anjitos": "anjo",
    "anjos": "anjo",
    "anjouniis": "anjounil",
    "anoas": "anoa",
    "anodias": "anodia",
    "anodinias": "anodinia",
    "anodizada": "anodizado",
    "anodizadas": "anodizado",
    "anodizados": "anodizado",
    "anodizações": "anodização",
    "anodoncias": "anodoncia",
    "anodontias": "anodontia",
    "anoftalmias": "anoftalmia",
    "anoftálmica": "anoftálmico",
    "anoftálmicas": "anoftálmico",
    "anoftálmicos": "anoftálmico",
    "anognoses": "anognose",
    "anoitece": "anoitecer",
    "anoitecei": "anoitecer",
    "anoiteceis": "anoitecer",
    "anoitecem": "anoitecer",
    "anoitecemo": "anoitecer",
    "anoitecemos": "anoitecer",
    "anoitecendo": "anoitecer",
    "anoitecera": "anoitecer",
    "anoiteceram": "anoitecer",
    "anoiteceras": "anoitecer",
    "anoitecerdes": "anoitecer",
    "anoitecerei": "anoitecer",
    "anoitecereis": "anoitecer",
    "anoitecerem": "anoitecer",
    "anoiteceremos": "anoitecer",
    "anoiteceres": "anoitecer",
    "anoiteceria": "anoitecer",
    "anoiteceriam": "anoitecer",
    "anoitecerias": "anoitecer",
    "anoitecermo": "anoitecer",
    "anoitecermos": "anoitecer",
    "anoitecerá": "anoitecer",
    "anoitecerás": "anoitecer",
    "anoitecerão": "anoitecer",
    "anoiteceríamos": "anoitecer",
    "anoiteceríeis": "anoitecer",
    "anoiteces": "anoitecer",
    "anoitecesse": "anoitecer",
    "anoitecessem": "anoitecer",
    "anoitecesses": "anoitecer",
    "anoiteceste": "anoitecer",
    "anoitecestes": "anoitecer",
    "anoiteceu": "anoitecer",
    "anoiteci": "anoitecer",
    "anoitecia": "anoitecer",
    "anoiteciam": "anoitecer",
    "anoitecias": "anoitecer",
    "anoitecida": "anoitecer",
    "anoitecidas": "anoitecer",
    "anoitecido": "anoitecer",
    "anoitecidos": "anoitecer",
    "anoitecêramo": "anoitecer",
    "anoitecêramos": "anoitecer",
    "anoitecêreis": "anoitecer",
    "anoitecêsseis": "anoitecer",
    "anoitecêssemos": "anoitecer",
    "anoitecíamo": "anoitecer",
    "anoitecíamos": "anoitecer",
    "anoitecíeis": "anoitecer",
    "anoiteça": "anoitecer",
    "anoiteçais": "anoitecer",
    "anoiteçam": "anoitecer",
    "anoiteçamo": "anoitecer",
    "anoiteçamos": "anoitecer",
    "anoiteças": "anoitecer",
    "anoiteço": "anoitecer",
    "anoja": "anojar",
    "anojada": "anojar",
    "anojadas": "anojar",
    "anojadiça": "anojadiço",
    "anojadiças": "anojadiço",
    "anojadiços": "anojadiço",
    "anojado": "anojar",
    "anojadora": "anojador",
    "anojadoras": "anojador",
    "anojadores": "anojador",
    "anojados": "anojar",
    "anojai": "anojar",
    "anojais": "anojar",
    "anojam": "anojar",
    "anojamentos": "anojamento",
    "anojamo": "anojar",
    "anojamos": "anojar",
    "anojando": "anojar",
    "anojara": "anojar",
    "anojaram": "anojar",
    "anojaras": "anojar",
    "anojarde": "anojar",
    "anojardes": "anojar",
    "anojare": "anojar",
    "anojarei": "anojar",
    "anojareis": "anojar",
    "anojarem": "anojar",
    "anojaremos": "anojar",
    "anojares": "anojar",
    "anojaria": "anojar",
    "anojariam": "anojar",
    "anojarias": "anojar",
    "anojarmo": "anojar",
    "anojarmos": "anojar",
    "anojará": "anojar",
    "anojarás": "anojar",
    "anojarão": "anojar",
    "anojaríamos": "anojar",
    "anojaríeis": "anojar",
    "anojas": "anojar",
    "anojasse": "anojar",
    "anojassem": "anojar",
    "anojasses": "anojar",
    "anojaste": "anojar",
    "anojastes": "anojar",
    "anojava": "anojar",
    "anojavam": "anojar",
    "anojavas": "anojar",
    "anoje": "anojar",
    "anojei": "anojar",
    "anojeis": "anojar",
    "anojem": "anojar",
    "anojemo": "anojar",
    "anojemos": "anojar",
    "anojes": "anojar",
    "anojo": "anojar",
    "anojos": "anojo",
    "anojosa": "anojoso",
    "anojosas": "anojoso",
    "anojosos": "anojoso",
    "anojou": "anojar",
    "anojá": "anojar",
    "anojámo": "anojar",
    "anojámos": "anojar",
    "anojáramo": "anojar",
    "anojáramos": "anojar",
    "anojárei": "anojar",
    "anojáreis": "anojar",
    "anojásseis": "anojar",
    "anojássemos": "anojar",
    "anojávamo": "anojar",
    "anojávamos": "anojar",
    "anojávei": "anojar",
    "anojáveis": "anojar",
    "anomalias": "anomalia",
    "anomaloscópica": "anomaloscópico",
    "anomaloscópicas": "anomaloscópico",
    "anomaloscópicos": "anomaloscópico",
    "anomaloscópios": "anomaloscópio",
    "anomalística": "anomalístico",
    "anomalísticas": "anomalístico",
    "anomalísticos": "anomalístico",
    "anomeia": "anomeu",
    "anomeias": "anomeu",
    "anomeus": "anomeu",
    "anomeísmos": "anomeísmo",
    "anomias": "anomia",
    "anominações": "anominação",
    "anomocefalias": "anomocefalia",
    "anomocefálica": "anomocefálico",
    "anomocefálicas": "anomocefálico",
    "anomocefálicos": "anomocefálico",
    "anomocéfala": "anomocéfalo",
    "anomocéfalas": "anomocéfalo",
    "anomocéfalos": "anomocéfalo",
    "anomólogos": "anomólogo",
    "anonas": "anona",
    "anoneiras": "anoneira",
    "anonima": "anonimar",
    "anonimada": "anonimar",
    "anonimadas": "anonimar",
    "anonimado": "anonimar",
    "anonimados": "anonimar",
    "anonimai": "anonimar",
    "anonimais": "anonimar",
    "anonimam": "anonimar",
    "anonimamo": "anonimar",
    "anonimamos": "anonimar",
    "anonimando": "anonimar",
    "anonimara": "anonimar",
    "anonimaram": "anonimar",
    "anonimaras": "anonimar",
    "anonimarde": "anonimar",
    "anonimardes": "anonimar",
    "anonimare": "anonimar",
    "anonimarei": "anonimar",
    "anonimareis": "anonimar",
    "anonimarem": "anonimar",
    "anonimaremos": "anonimar",
    "anonimares": "anonimar",
    "anonimaria": "anonimar",
    "anonimariam": "anonimar",
    "anonimarias": "anonimar",
    "anonimarmo": "anonimar",
    "anonimarmos": "anonimar",
    "anonimará": "anonimar",
    "anonimarás": "anonimar",
    "anonimarão": "anonimar",
    "anonimaríamos": "anonimar",
    "anonimaríeis": "anonimar",
    "anonimas": "anonimar",
    "anonimasse": "anonimar",
    "anonimassem": "anonimar",
    "anonimasses": "anonimar",
    "anonimaste": "anonimar",
    "anonimastes": "anonimar",
    "anonimatos": "anonimato",
    "anonimava": "anonimar",
    "anonimavam": "anonimar",
    "anonimavas": "anonimar",
    "anonime": "anonimar",
    "anonimei": "anonimar",
    "anonimeis": "anonimar",
    "anonimem": "anonimar",
    "anonimemo": "anonimar",
    "anonimemos": "anonimar",
    "anonimes": "anonimar",
    "anonimidades": "anonimidade",
    "anonimo": "anonimar",
    "anonimou": "anonimar",
    "anonimá": "anonimar",
    "anonimámo": "anonimar",
    "anonimámos": "anonimar",
    "anonimáramo": "anonimar",
    "anonimáramos": "anonimar",
    "anonimárei": "anonimar",
    "anonimáreis": "anonimar",
    "anonimásseis": "anonimar",
    "anonimássemos": "anonimar",
    "anonimávamo": "anonimar",
    "anonimávamos": "anonimar",
    "anonimávei": "anonimar",
    "anonimáveis": "anonimar",
    "anoniquias": "anoniquia",
    "anonácea": "anonáceo",
    "anonáceas": "anonáceo",
    "anonáceos": "anonáceo",
    "anonária": "anonário",
    "anonárias": "anonário",
    "anonários": "anonário",
    "anonímias": "anonímia",
    "anopluros": "anopluro",
    "anopsias": "anopsia",
    "anopétala": "anopétalo",
    "anopétalas": "anopétalo",
    "anopétalos": "anopétalo",
    "anoques": "anoque",
    "anoraques": "anoraque",
    "anordesteada": "anordestear",
    "anordesteadas": "anordestear",
    "anordesteado": "anordestear",
    "anordesteados": "anordestear",
    "anordesteai": "anordestear",
    "anordesteais": "anordestear",
    "anordesteamo": "anordestear",
    "anordesteamos": "anordestear",
    "anordesteando": "anordestear",
    "anordesteara": "anordestear",
    "anordestearam": "anordestear",
    "anordestearas": "anordestear",
    "anordestearde": "anordestear",
    "anordesteardes": "anordestear",
    "anordesteare": "anordestear",
    "anordestearei": "anordestear",
    "anordesteareis": "anordestear",
    "anordestearem": "anordestear",
    "anordestearemos": "anordestear",
    "anordesteares": "anordestear",
    "anordestearia": "anordestear",
    "anordesteariam": "anordestear",
    "anordestearias": "anordestear",
    "anordestearmo": "anordestear",
    "anordestearmos": "anordestear",
    "anordesteará": "anordestear",
    "anordestearás": "anordestear",
    "anordestearão": "anordestear",
    "anordestearíamos": "anordestear",
    "anordestearíeis": "anordestear",
    "anordesteasse": "anordestear",
    "anordesteassem": "anordestear",
    "anordesteasses": "anordestear",
    "anordesteaste": "anordestear",
    "anordesteastes": "anordestear",
    "anordesteava": "anordestear",
    "anordesteavam": "anordestear",
    "anordesteavas": "anordestear",
    "anordesteei": "anordestear",
    "anordesteeis": "anordestear",
    "anordesteemo": "anordestear",
    "anordesteemos": "anordestear",
    "anordesteia": "anordestear",
    "anordesteiam": "anordestear",
    "anordesteias": "anordestear",
    "anordesteie": "anordestear",
    "anordesteiem": "anordestear",
    "anordesteies": "anordestear",
    "anordesteio": "anordestear",
    "anordesteou": "anordestear",
    "anordesteá": "anordestear",
    "anordesteámo": "anordestear",
    "anordesteámos": "anordestear",
    "anordesteáramo": "anordestear",
    "anordesteáramos": "anordestear",
    "anordesteárei": "anordestear",
    "anordesteáreis": "anordestear",
    "anordesteásseis": "anordestear",
    "anordesteássemos": "anordestear",
    "anordesteávamo": "anordestear",
    "anordesteávamos": "anordestear",
    "anordesteávei": "anordestear",
    "anordesteáveis": "anordestear",
    "anorexias": "anorexia",
    "anormais": "anormal",
    "anormalidades": "anormalidade",
    "anorteada": "anortear",
    "anorteadas": "anortear",
    "anorteado": "anortear",
    "anorteados": "anortear",
    "anorteai": "anortear",
    "anorteais": "anortear",
    "anorteamentos": "anorteamento",
    "anorteamo": "anortear",
    "anorteamos": "anortear",
    "anorteando": "anortear",
    "anorteara": "anortear",
    "anortearam": "anortear",
    "anortearas": "anortear",
    "anortearde": "anortear",
    "anorteardes": "anortear",
    "anorteare": "anortear",
    "anortearei": "anortear",
    "anorteareis": "anortear",
    "anortearem": "anortear",
    "anortearemos": "anortear",
    "anorteares": "anortear",
    "anortearia": "anortear",
    "anorteariam": "anortear",
    "anortearias": "anortear",
    "anortearmo": "anortear",
    "anortearmos": "anortear",
    "anorteará": "anortear",
    "anortearás": "anortear",
    "anortearão": "anortear",
    "anortearíamos": "anortear",
    "anortearíeis": "anortear",
    "anorteasse": "anortear",
    "anorteassem": "anortear",
    "anorteasses": "anortear",
    "anorteaste": "anortear",
    "anorteastes": "anortear",
    "anorteava": "anortear",
    "anorteavam": "anortear",
    "anorteavas": "anortear",
    "anorteei": "anortear",
    "anorteeis": "anortear",
    "anorteemo": "anortear",
    "anorteemos": "anortear",
    "anorteia": "anortear",
    "anorteiam": "anortear",
    "anorteias": "anortear",
    "anorteie": "anortear",
    "anorteiem": "anortear",
    "anorteies": "anortear",
    "anorteio": "anortear",
    "anorteou": "anortear",
    "anorteá": "anortear",
    "anorteámo": "anortear",
    "anorteámos": "anortear",
    "anorteáramo": "anortear",
    "anorteáramos": "anortear",
    "anorteárei": "anortear",
    "anorteáreis": "anortear",
    "anorteásseis": "anortear",
    "anorteássemos": "anortear",
    "anorteávamo": "anortear",
    "anorteávamos": "anortear",
    "anorteávei": "anortear",
    "anorteáveis": "anortear",
    "anortites": "anortite",
    "anortografias": "anortografia",
    "anortográfica": "anortográfico",
    "anortográficas": "anortográfico",
    "anortográficos": "anortográfico",
    "anortositos": "anortosito",
    "anortóclases": "anortóclase",
    "anoréctica": "anoréctico",
    "anorécticas": "anoréctico",
    "anorécticos": "anoréctico",
    "anoréxica": "anoréxico",
    "anoréxicas": "anoréxico",
    "anoréxicos": "anoréxico",
    "anos": "ano",
    "anosa": "anoso",
    "anosas": "anoso",
    "anosfresias": "anosfresia",
    "anosias": "anosia",
    "anosidades": "anosidade",
    "anosmias": "anosmia",
    "anosognosias": "anosognosia",
    "anosos": "anoso",
    "anosteoses": "anosteose",
    "anosteozoária": "anosteozoário",
    "anosteozoárias": "anosteozoário",
    "anosteozoários": "anosteozoário",
    "anostoses": "anostose",
    "anosíssima": "anoso",
    "anosíssimas": "anoso",
    "anosíssimo": "anoso",
    "anosíssimos": "anoso",
    "anota": "anoto",
    "anotada": "anotar",
    "anotadas": "anotar",
    "anotado": "anotar",
    "anotadora": "anotador",
    "anotadoras": "anotador",
    "anotadores": "anotador",
    "anotados": "anotar",
    "anotadíssima": "anotado",
    "anotadíssimas": "anotado",
    "anotadíssimo": "anotado",
    "anotadíssimos": "anotado",
    "anotai": "anotar",
    "anotais": "anotar",
    "anotam": "anotar",
    "anotamo": "anotar",
    "anotamos": "anotar",
    "anotando": "anotar",
    "anotara": "anotar",
    "anotaram": "anotar",
    "anotaras": "anotar",
    "anotarde": "anotar",
    "anotardes": "anotar",
    "anotare": "anotar",
    "anotarei": "anotar",
    "anotareis": "anotar",
    "anotarem": "anotar",
    "anotaremos": "anotar",
    "anotares": "anotar",
    "anotaria": "anotar",
    "anotariam": "anotar",
    "anotarias": "anotar",
    "anotarmo": "anotar",
    "anotarmos": "anotar",
    "anotará": "anotar",
    "anotarás": "anotar",
    "anotarão": "anotar",
    "anotaríamos": "anotar",
    "anotaríeis": "anotar",
    "anotas": "anoto",
    "anotasse": "anotar",
    "anotassem": "anotar",
    "anotasses": "anotar",
    "anotaste": "anotar",
    "anotastes": "anotar",
    "anotava": "anotar",
    "anotavam": "anotar",
    "anotavas": "anotar",
    "anotações": "anotação",
    "anote": "anotar",
    "anotei": "anotar",
    "anoteis": "anotar",
    "anotem": "anotar",
    "anotemo": "anotar",
    "anotemos": "anotar",
    "anotes": "anotar",
    "anotias": "anotia",
    "anoto": "anotar",
    "anotos": "anoto",
    "anotou": "anotar",
    "anotá": "anotar",
    "anotámo": "anotar",
    "anotámos": "anotar",
    "anotáramo": "anotar",
    "anotáramos": "anotar",
    "anotárei": "anotar",
    "anotáreis": "anotar",
    "anotásseis": "anotar",
    "anotássemos": "anotar",
    "anotávamo": "anotar",
    "anotávamos": "anotar",
    "anotávei": "anotar",
    "anotáveis": "anotável",
    "anoutece": "anoutecer",
    "anoutecei": "anoutecer",
    "anouteceis": "anoutecer",
    "anoutecem": "anoutecer",
    "anoutecemo": "anoutecer",
    "anoutecemos": "anoutecer",
    "anoutecendo": "anoutecer",
    "anoutecera": "anoutecer",
    "anouteceram": "anoutecer",
    "anouteceras": "anoutecer",
    "anoutecerdes": "anoutecer",
    "anoutecerei": "anoutecer",
    "anoutecereis": "anoutecer",
    "anoutecerem": "anoutecer",
    "anouteceremos": "anoutecer",
    "anouteceres": "anoutecer",
    "anouteceria": "anoutecer",
    "anouteceriam": "anoutecer",
    "anoutecerias": "anoutecer",
    "anoutecermo": "anoutecer",
    "anoutecermos": "anoutecer",
    "anoutecerá": "anoutecer",
    "anoutecerás": "anoutecer",
    "anoutecerão": "anoutecer",
    "anouteceríamos": "anoutecer",
    "anouteceríeis": "anoutecer",
    "anouteces": "anoutecer",
    "anoutecesse": "anoutecer",
    "anoutecessem": "anoutecer",
    "anoutecesses": "anoutecer",
    "anouteceste": "anoutecer",
    "anoutecestes": "anoutecer",
    "anouteceu": "anoutecer",
    "anouteci": "anoutecer",
    "anoutecia": "anoutecer",
    "anouteciam": "anoutecer",
    "anoutecias": "anoutecer",
    "anoutecida": "anoutecer",
    "anoutecidas": "anoutecer",
    "anoutecido": "anoutecer",
    "anoutecidos": "anoutecer",
    "anoutecêramo": "anoutecer",
    "anoutecêramos": "anoutecer",
    "anoutecêreis": "anoutecer",
    "anoutecêsseis": "anoutecer",
    "anoutecêssemos": "anoutecer",
    "anoutecíamo": "anoutecer",
    "anoutecíamos": "anoutecer",
    "anoutecíeis": "anoutecer",
    "anouteça": "anoutecer",
    "anouteçais": "anoutecer",
    "anouteçam": "anoutecer",
    "anouteçamo": "anoutecer",
    "anouteçamos": "anoutecer",
    "anouteças": "anoutecer",
    "anouteço": "anoutecer",
    "anovamentos": "anovamento",
    "anoveada": "anovear",
    "anoveadas": "anovear",
    "anoveado": "anovear",
    "anoveados": "anovear",
    "anoveai": "anovear",
    "anoveais": "anovear",
    "anoveamo": "anovear",
    "anoveamos": "anovear",
    "anoveando": "anovear",
    "anoveara": "anovear",
    "anovearam": "anovear",
    "anovearas": "anovear",
    "anovearde": "anovear",
    "anoveardes": "anovear",
    "anoveare": "anovear",
    "anovearei": "anovear",
    "anoveareis": "anovear",
    "anovearem": "anovear",
    "anovearemos": "anovear",
    "anoveares": "anovear",
    "anovearia": "anovear",
    "anoveariam": "anovear",
    "anovearias": "anovear",
    "anovearmo": "anovear",
    "anovearmos": "anovear",
    "anoveará": "anovear",
    "anovearás": "anovear",
    "anovearão": "anovear",
    "anovearíamos": "anovear",
    "anovearíeis": "anovear",
    "anoveasse": "anovear",
    "anoveassem": "anovear",
    "anoveasses": "anovear",
    "anoveaste": "anovear",
    "anoveastes": "anovear",
    "anoveava": "anovear",
    "anoveavam": "anovear",
    "anoveavas": "anovear",
    "anoveei": "anovear",
    "anoveeis": "anovear",
    "anoveemo": "anovear",
    "anoveemos": "anovear",
    "anoveia": "anovear",
    "anoveiam": "anovear",
    "anoveias": "anovear",
    "anoveie": "anovear",
    "anoveiem": "anovear",
    "anoveies": "anovear",
    "anoveio": "anovear",
    "anovela": "anovelar",
    "anovelada": "anovelar",
    "anoveladas": "anovelar",
    "anovelado": "anovelar",
    "anovelados": "anovelar",
    "anovelai": "anovelar",
    "anovelais": "anovelar",
    "anovelam": "anovelar",
    "anovelamo": "anovelar",
    "anovelamos": "anovelar",
    "anovelando": "anovelar",
    "anovelara": "anovelar",
    "anovelaram": "anovelar",
    "anovelaras": "anovelar",
    "anovelarde": "anovelar",
    "anovelardes": "anovelar",
    "anovelare": "anovelar",
    "anovelarei": "anovelar",
    "anovelareis": "anovelar",
    "anovelarem": "anovelar",
    "anovelaremos": "anovelar",
    "anovelares": "anovelar",
    "anovelaria": "anovelar",
    "anovelariam": "anovelar",
    "anovelarias": "anovelar",
    "anovelarmo": "anovelar",
    "anovelarmos": "anovelar",
    "anovelará": "anovelar",
    "anovelarás": "anovelar",
    "anovelarão": "anovelar",
    "anovelaríamos": "anovelar",
    "anovelaríeis": "anovelar",
    "anovelas": "anovelar",
    "anovelasse": "anovelar",
    "anovelassem": "anovelar",
    "anovelasses": "anovelar",
    "anovelaste": "anovelar",
    "anovelastes": "anovelar",
    "anovelava": "anovelar",
    "anovelavam": "anovelar",
    "anovelavas": "anovelar",
    "anovele": "anovelar",
    "anovelei": "anovelar",
    "anoveleis": "anovelar",
    "anovelem": "anovelar",
    "anovelemo": "anovelar",
    "anovelemos": "anovelar",
    "anoveles": "anovelar",
    "anovelo": "anovelar",
    "anovelou": "anovelar",
    "anovelá": "anovelar",
    "anovelámo": "anovelar",
    "anovelámos": "anovelar",
    "anoveláramo": "anovelar",
    "anoveláramos": "anovelar",
    "anovelárei": "anovelar",
    "anoveláreis": "anovelar",
    "anovelásseis": "anovelar",
    "anovelássemos": "anovelar",
    "anovelávamo": "anovelar",
    "anovelávamos": "anovelar",
    "anovelávei": "anovelar",
    "anoveláveis": "anovelar",
    "anoveou": "anovear",
    "anoveá": "anovear",
    "anoveámo": "anovear",
    "anoveámos": "anovear",
    "anoveáramo": "anovear",
    "anoveáramos": "anovear",
    "anoveárei": "anovear",
    "anoveáreis": "anovear",
    "anoveásseis": "anovear",
    "anoveássemos": "anovear",
    "anoveávamo": "anovear",
    "anoveávamos": "anovear",
    "anoveávei": "anovear",
    "anoveáveis": "anovear",
    "anoxemias": "anoxemia",
    "anoxiemias": "anoxiemia",
    "anquilosada": "anquilosado",
    "anquilosadas": "anquilosado",
    "anquilosados": "anquilosado",
    "anquiloses": "anquilose",
    "anquinha": "anca",
    "anquinhas": "anca",
    "anquita": "anca",
    "anquitas": "anca",
    "ansas": "ansa",
    "anseia": "ansiar",
    "anseiam": "ansiar",
    "anseias": "ansiar",
    "anseie": "ansiar",
    "anseiem": "ansiar",
    "anseies": "ansiar",
    "anseio": "ansiar",
    "anseios": "anseio",
    "anseriformes": "anseriforme",
    "anserina": "anserino",
    "anserinas": "anserino",
    "anserinos": "anserino",
    "ansiada": "ansiar",
    "ansiadas": "ansiar",
    "ansiado": "ansiar",
    "ansiados": "ansiar",
    "ansiai": "ansiar",
    "ansiais": "ansiar",
    "ansiamentos": "ansiamento",
    "ansiamo": "ansiar",
    "ansiamos": "ansiar",
    "ansiando": "ansiar",
    "ansiara": "ansiar",
    "ansiaram": "ansiar",
    "ansiaras": "ansiar",
    "ansiarde": "ansiar",
    "ansiardes": "ansiar",
    "ansiare": "ansiar",
    "ansiarei": "ansiar",
    "ansiareis": "ansiar",
    "ansiarem": "ansiar",
    "ansiaremos": "ansiar",
    "ansiares": "ansiar",
    "ansiaria": "ansiar",
    "ansiariam": "ansiar",
    "ansiarias": "ansiar",
    "ansiarmo": "ansiar",
    "ansiarmos": "ansiar",
    "ansiará": "ansiar",
    "ansiarás": "ansiar",
    "ansiarão": "ansiar",
    "ansiaríamos": "ansiar",
    "ansiaríeis": "ansiar",
    "ansiasse": "ansiar",
    "ansiassem": "ansiar",
    "ansiasses": "ansiar",
    "ansiaste": "ansiar",
    "ansiastes": "ansiar",
    "ansiava": "ansiar",
    "ansiavam": "ansiar",
    "ansiavas": "ansiar",
    "ansiedades": "ansiedade",
    "ansiei": "ansiar",
    "ansieis": "ansiar",
    "ansiemo": "ansiar",
    "ansiemos": "ansiar",
    "ansiformes": "ansiforme",
    "ansiolíticos": "ansiolítico",
    "ansiosa": "ansioso",
    "ansiosas": "ansioso",
    "ansiosos": "ansioso",
    "ansiosíssima": "ansioso",
    "ansiosíssimas": "ansioso",
    "ansiosíssimo": "ansioso",
    "ansiosíssimos": "ansioso",
    "ansiou": "ansiar",
    "ansiá": "ansiar",
    "ansiámo": "ansiar",
    "ansiámos": "ansiar",
    "ansiáramo": "ansiar",
    "ansiáramos": "ansiar",
    "ansiárei": "ansiar",
    "ansiáreis": "ansiar",
    "ansiásseis": "ansiar",
    "ansiássemos": "ansiar",
    "ansiávamo": "ansiar",
    "ansiávamos": "ansiar",
    "ansiávei": "ansiar",
    "ansiáveis": "ansiar",
    "anspeçadas": "anspeçada",
    "anta": "antar",
    "antada": "antar",
    "antadas": "antar",
    "antado": "antar",
    "antados": "antar",
    "antagonismos": "antagonismo",
    "antagonistas": "antagonista",
    "antagoniza": "antagonizar",
    "antagonizada": "antagonizar",
    "antagonizadas": "antagonizar",
    "antagonizado": "antagonizar",
    "antagonizados": "antagonizar",
    "antagonizai": "antagonizar",
    "antagonizais": "antagonizar",
    "antagonizam": "antagonizar",
    "antagonizamo": "antagonizar",
    "antagonizamos": "antagonizar",
    "antagonizando": "antagonizar",
    "antagonizara": "antagonizar",
    "antagonizaram": "antagonizar",
    "antagonizaras": "antagonizar",
    "antagonizarde": "antagonizar",
    "antagonizardes": "antagonizar",
    "antagonizare": "antagonizar",
    "antagonizarei": "antagonizar",
    "antagonizareis": "antagonizar",
    "antagonizarem": "antagonizar",
    "antagonizaremos": "antagonizar",
    "antagonizares": "antagonizar",
    "antagonizaria": "antagonizar",
    "antagonizariam": "antagonizar",
    "antagonizarias": "antagonizar",
    "antagonizarmo": "antagonizar",
    "antagonizarmos": "antagonizar",
    "antagonizará": "antagonizar",
    "antagonizarás": "antagonizar",
    "antagonizarão": "antagonizar",
    "antagonizaríamos": "antagonizar",
    "antagonizaríeis": "antagonizar",
    "antagonizas": "antagonizar",
    "antagonizasse": "antagonizar",
    "antagonizassem": "antagonizar",
    "antagonizasses": "antagonizar",
    "antagonizaste": "antagonizar",
    "antagonizastes": "antagonizar",
    "antagonizava": "antagonizar",
    "antagonizavam": "antagonizar",
    "antagonizavas": "antagonizar",
    "antagonize": "antagonizar",
    "antagonizei": "antagonizar",
    "antagonizeis": "antagonizar",
    "antagonizem": "antagonizar",
    "antagonizemo": "antagonizar",
    "antagonizemos": "antagonizar",
    "antagonizes": "antagonizar",
    "antagonizo": "antagonizar",
    "antagonizou": "antagonizar",
    "antagonizá": "antagonizar",
    "antagonizámo": "antagonizar",
    "antagonizámos": "antagonizar",
    "antagonizáramo": "antagonizar",
    "antagonizáramos": "antagonizar",
    "antagonizárei": "antagonizar",
    "antagonizáreis": "antagonizar",
    "antagonizásseis": "antagonizar",
    "antagonizássemos": "antagonizar",
    "antagonizávamo": "antagonizar",
    "antagonizávamos": "antagonizar",
    "antagonizávei": "antagonizar",
    "antagonizáveis": "antagonizar",
    "antagónica": "antagónico",
    "antagónicas": "antagónico",
    "antagónicos": "antagónico",
    "antai": "antar",
    "antais": "antar",
    "antalgias": "antalgia",
    "antam": "antar",
    "antamo": "antar",
    "antamos": "antar",
    "antanagoges": "antanagoge",
    "antanagógica": "antanagógico",
    "antanagógicas": "antanagógico",
    "antanagógicos": "antanagógico",
    "antando": "antar",
    "antanáclases": "antanáclase",
    "antapódoses": "antapódose",
    "antara": "antar",
    "antaram": "antar",
    "antaras": "antar",
    "antarde": "antar",
    "antardes": "antar",
    "antare": "antar",
    "antarei": "antar",
    "antareis": "antar",
    "antarem": "antar",
    "antaremos": "antar",
    "antares": "antar",
    "antaria": "antar",
    "antariam": "antar",
    "antarias": "antar",
    "antarmo": "antar",
    "antarmos": "antar",
    "antará": "antar",
    "antarás": "antar",
    "antarão": "antar",
    "antaríamos": "antar",
    "antaríeis": "antar",
    "antas": "antar",
    "antasse": "antar",
    "antassem": "antar",
    "antasses": "antar",
    "antaste": "antar",
    "antastes": "antar",
    "antava": "antar",
    "antavam": "antar",
    "antavas": "antar",
    "ante": "antar",
    "anteactos": "anteacto",
    "anteauroras": "anteaurora",
    "antebocas": "anteboca",
    "antebraquiais": "antebraquial",
    "antebraços": "antebraço",
    "antebéns": "antebém",
    "antecaniculares": "antecanicular",
    "antecantos": "antecanto",
    "anteceda": "anteceder",
    "antecedais": "anteceder",
    "antecedam": "anteceder",
    "antecedamo": "anteceder",
    "antecedamos": "anteceder",
    "antecedas": "anteceder",
    "antecede": "anteceder",
    "antecedei": "anteceder",
    "antecedeis": "anteceder",
    "antecedem": "anteceder",
    "antecedemo": "anteceder",
    "antecedemos": "anteceder",
    "antecedendo": "anteceder",
    "antecedentes": "antecedente",
    "antecedera": "anteceder",
    "antecederam": "anteceder",
    "antecederas": "anteceder",
    "antecederde": "anteceder",
    "antecederdes": "anteceder",
    "antecedere": "anteceder",
    "antecederei": "anteceder",
    "antecedereis": "anteceder",
    "antecederem": "anteceder",
    "antecederemos": "anteceder",
    "antecederes": "anteceder",
    "antecederia": "anteceder",
    "antecederiam": "anteceder",
    "antecederias": "anteceder",
    "antecedermo": "anteceder",
    "antecedermos": "anteceder",
    "antecederá": "anteceder",
    "antecederás": "anteceder",
    "antecederão": "anteceder",
    "antecederíamos": "anteceder",
    "antecederíeis": "anteceder",
    "antecedes": "anteceder",
    "antecedesse": "anteceder",
    "antecedessem": "anteceder",
    "antecedesses": "anteceder",
    "antecedeste": "anteceder",
    "antecedestes": "anteceder",
    "antecedeu": "anteceder",
    "antecedi": "anteceder",
    "antecedia": "anteceder",
    "antecediam": "anteceder",
    "antecedias": "anteceder",
    "antecedida": "antecedido",
    "antecedidas": "antecedido",
    "antecedido": "anteceder",
    "antecedidos": "antecedido",
    "antecedo": "anteceder",
    "antecedê": "anteceder",
    "antecedências": "antecedência",
    "antecedêramo": "anteceder",
    "antecedêramos": "anteceder",
    "antecedêrei": "anteceder",
    "antecedêreis": "anteceder",
    "antecedêsseis": "anteceder",
    "antecedêssemos": "anteceder",
    "antecedíamo": "anteceder",
    "antecedíamos": "anteceder",
    "antecedíei": "anteceder",
    "antecedíeis": "anteceder",
    "antecenas": "antecena",
    "antecendências": "antecendência",
    "antecessora": "antecessor",
    "antecessoras": "antecessor",
    "antecessores": "antecessor",
    "antecipa": "antecipar",
    "antecipada": "antecipar",
    "antecipadas": "antecipar",
    "antecipado": "antecipar",
    "antecipados": "antecipar",
    "antecipai": "antecipar",
    "antecipais": "antecipar",
    "antecipam": "antecipar",
    "antecipamo": "antecipar",
    "antecipamos": "antecipar",
    "antecipando": "antecipar",
    "antecipara": "antecipar",
    "anteciparam": "antecipar",
    "anteciparas": "antecipar",
    "anteciparde": "antecipar",
    "antecipardes": "antecipar",
    "antecipare": "antecipar",
    "anteciparei": "antecipar",
    "antecipareis": "antecipar",
    "anteciparem": "antecipar",
    "anteciparemos": "antecipar",
    "antecipares": "antecipar",
    "anteciparia": "antecipar",
    "antecipariam": "antecipar",
    "anteciparias": "antecipar",
    "anteciparmo": "antecipar",
    "anteciparmos": "antecipar",
    "antecipará": "antecipar",
    "anteciparás": "antecipar",
    "anteciparão": "antecipar",
    "anteciparíamos": "antecipar",
    "anteciparíeis": "antecipar",
    "antecipas": "antecipar",
    "antecipasse": "antecipar",
    "antecipassem": "antecipar",
    "antecipasses": "antecipar",
    "antecipaste": "antecipar",
    "antecipastes": "antecipar",
    "antecipava": "antecipar",
    "antecipavam": "antecipar",
    "antecipavas": "antecipar",
    "antecipações": "antecipação",
    "antecipe": "antecipar",
    "antecipei": "antecipar",
    "antecipeis": "antecipar",
    "antecipem": "antecipar",
    "antecipemo": "antecipar",
    "antecipemos": "antecipar",
    "antecipes": "antecipar",
    "antecipo": "antecipar",
    "antecipou": "antecipar",
    "antecipá": "antecipar",
    "antecipámo": "antecipar",
    "antecipámos": "antecipar",
    "antecipáramo": "antecipar",
    "antecipáramos": "antecipar",
    "antecipárei": "antecipar",
    "antecipáreis": "antecipar",
    "antecipásseis": "antecipar",
    "antecipássemos": "antecipar",
    "antecipávamo": "antecipar",
    "antecipávamos": "antecipar",
    "antecipávei": "antecipar",
    "antecipáveis": "antecipável",
    "antecolunas": "antecoluna",
    "antecomeços": "antecomeço",
    "anteconhecimentos": "anteconhecimento",
    "anteconjugais": "anteconjugal",
    "antecontratos": "antecontrato",
    "antecoros": "antecoro",
    "antecâmaras": "antecâmara",
    "antecâmbrica": "antecâmbrico",
    "antecâmbricas": "antecâmbrico",
    "antecâmbricos": "antecâmbrico",
    "antecéus": "antecéu",
    "antedada": "antedar",
    "antedadas": "antedar",
    "antedado": "antedar",
    "antedados": "antedar",
    "antedai": "antedar",
    "antedais": "antedar",
    "antedamo": "antedar",
    "antedamos": "antedar",
    "antedando": "antedar",
    "antedarde": "antedar",
    "antedardes": "antedar",
    "antedare": "antedar",
    "antedarei": "antedar",
    "antedareis": "antedar",
    "antedarem": "antedar",
    "antedaremos": "antedar",
    "antedares": "antedar",
    "antedaria": "antedar",
    "antedariam": "antedar",
    "antedarias": "antedar",
    "antedarmo": "antedar",
    "antedarmos": "antedar",
    "antedará": "antedar",
    "antedarás": "antedar",
    "antedarão": "antedar",
    "antedaríamos": "antedar",
    "antedaríeis": "antedar",
    "antedata": "antedatar",
    "antedatada": "antedatar",
    "antedatadas": "antedatar",
    "antedatado": "antedatar",
    "antedatados": "antedatar",
    "antedatai": "antedatar",
    "antedatais": "antedatar",
    "antedatam": "antedatar",
    "antedatamo": "antedatar",
    "antedatamos": "antedatar",
    "antedatando": "antedatar",
    "antedatara": "antedatar",
    "antedataram": "antedatar",
    "antedataras": "antedatar",
    "antedatarde": "antedatar",
    "antedatardes": "antedatar",
    "antedatare": "antedatar",
    "antedatarei": "antedatar",
    "antedatareis": "antedatar",
    "antedatarem": "antedatar",
    "antedataremos": "antedatar",
    "antedatares": "antedatar",
    "antedataria": "antedatar",
    "antedatariam": "antedatar",
    "antedatarias": "antedatar",
    "antedatarmo": "antedatar",
    "antedatarmos": "antedatar",
    "antedatará": "antedatar",
    "antedatarás": "antedatar",
    "antedatarão": "antedatar",
    "antedataríamos": "antedatar",
    "antedataríeis": "antedatar",
    "antedatas": "antedatar",
    "antedatasse": "antedatar",
    "antedatassem": "antedatar",
    "antedatasses": "antedatar",
    "antedataste": "antedatar",
    "antedatastes": "antedatar",
    "antedatava": "antedatar",
    "antedatavam": "antedatar",
    "antedatavas": "antedatar",
    "antedate": "antedatar",
    "antedatei": "antedatar",
    "antedateis": "antedatar",
    "antedatem": "antedatar",
    "antedatemo": "antedatar",
    "antedatemos": "antedatar",
    "antedates": "antedatar",
    "antedato": "antedatar",
    "antedatou": "antedatar",
    "antedatá": "antedatar",
    "antedatámo": "antedatar",
    "antedatámos": "antedatar",
    "antedatáramo": "antedatar",
    "antedatáramos": "antedatar",
    "antedatárei": "antedatar",
    "antedatáreis": "antedatar",
    "antedatásseis": "antedatar",
    "antedatássemos": "antedatar",
    "antedatávamo": "antedatar",
    "antedatávamos": "antedatar",
    "antedatávei": "antedatar",
    "antedatáveis": "antedatar",
    "antedava": "antedar",
    "antedavam": "antedar",
    "antedavas": "antedar",
    "antedei": "antedar",
    "antedeis": "antedar",
    "antedemo": "antedar",
    "antedemos": "antedar",
    "antedera": "antedar",
    "antederam": "antedar",
    "antederas": "antedar",
    "antedesse": "antedar",
    "antedessem": "antedar",
    "antedesses": "antedar",
    "antedeste": "antedar",
    "antedestes": "antedar",
    "antedeu": "antedar",
    "antediga": "antedizer",
    "antedigais": "antedizer",
    "antedigam": "antedizer",
    "antedigamo": "antedizer",
    "antedigamos": "antedizer",
    "antedigas": "antedizer",
    "antedigo": "antedizer",
    "antediluvianos": "antediluviano",
    "antedirei": "antedizer",
    "antedireis": "antedizer",
    "antediremos": "antedizer",
    "antediria": "antedizer",
    "antediriam": "antedizer",
    "antedirias": "antedizer",
    "antedirá": "antedizer",
    "antedirás": "antedizer",
    "antedirão": "antedizer",
    "antediríamos": "antedizer",
    "antediríeis": "antedizer",
    "antedisse": "antedizer",
    "antedissemo": "antedizer",
    "antedissemos": "antedizer",
    "antedisser": "antedizer",
    "antedissera": "antedizer",
    "antedisseram": "antedizer",
    "antedisseras": "antedizer",
    "antedisserdes": "antedizer",
    "antedisserem": "antedizer",
    "antedisseres": "antedizer",
    "antedissermos": "antedizer",
    "antedissesse": "antedizer",
    "antedissessem": "antedizer",
    "antedissesses": "antedizer",
    "antedisseste": "antedizer",
    "antedissestes": "antedizer",
    "antedisséramo": "antedizer",
    "antedisséramos": "antedizer",
    "antedissérei": "antedizer",
    "antedisséreis": "antedizer",
    "antedissésseis": "antedizer",
    "antedisséssemos": "antedizer",
    "antedita": "antedizer",
    "anteditas": "antedizer",
    "antedito": "antedizer",
    "anteditos": "antedizer",
    "antediz": "antedizer",
    "antedize": "antedizer",
    "antedizei": "antedizer",
    "antedizeis": "antedizer",
    "antedizem": "antedizer",
    "antedizemo": "antedizer",
    "antedizemos": "antedizer",
    "antedizendo": "antedizer",
    "antedizerde": "antedizer",
    "antedizerdes": "antedizer",
    "antedizere": "antedizer",
    "antedizerem": "antedizer",
    "antedizeres": "antedizer",
    "antedizermo": "antedizer",
    "antedizermos": "antedizer",
    "antedizes": "antedizer",
    "antedizia": "antedizer",
    "antediziam": "antedizer",
    "antedizias": "antedizer",
    "antedizê": "antedizer",
    "antedizíamo": "antedizer",
    "antedizíamos": "antedizer",
    "antedizíei": "antedizer",
    "antedizíeis": "antedizer",
    "antedou": "antedar",
    "antedá": "antedar",
    "antedás": "antedar",
    "antedávamo": "antedar",
    "antedávamos": "antedar",
    "antedávei": "antedar",
    "antedáveis": "antedar",
    "antedão": "antedar",
    "antedéramo": "antedar",
    "antedéramos": "antedar",
    "antedérei": "antedar",
    "antedéreis": "antedar",
    "antedésseis": "antedar",
    "antedéssemos": "antedar",
    "antedê": "antedar",
    "antedêem": "antedar",
    "antedêmo": "antedar",
    "antedêmos": "antedar",
    "antedês": "antedar",
    "antefaces": "anteface",
    "antefebriis": "antefebril",
    "antefere": "anteferir",
    "anteferem": "anteferir",
    "anteferes": "anteferir",
    "anteferi": "anteferir",
    "anteferia": "anteferir",
    "anteferiam": "anteferir",
    "anteferias": "anteferir",
    "anteferida": "anteferir",
    "anteferidas": "anteferir",
    "anteferido": "anteferir",
    "anteferidos": "anteferir",
    "anteferimo": "anteferir",
    "anteferimos": "anteferir",
    "anteferindo": "anteferir",
    "anteferira": "anteferir",
    "anteferiram": "anteferir",
    "anteferiras": "anteferir",
    "anteferirde": "anteferir",
    "anteferirdes": "anteferir",
    "anteferire": "anteferir",
    "anteferirei": "anteferir",
    "anteferireis": "anteferir",
    "anteferirem": "anteferir",
    "anteferiremos": "anteferir",
    "anteferires": "anteferir",
    "anteferiria": "anteferir",
    "antefeririam": "anteferir",
    "anteferirias": "anteferir",
    "anteferirmo": "anteferir",
    "anteferirmos": "anteferir",
    "anteferirá": "anteferir",
    "anteferirás": "anteferir",
    "anteferirão": "anteferir",
    "anteferiríamos": "anteferir",
    "anteferiríeis": "anteferir",
    "anteferis": "anteferir",
    "anteferisse": "anteferir",
    "anteferissem": "anteferir",
    "anteferisses": "anteferir",
    "anteferiste": "anteferir",
    "anteferistes": "anteferir",
    "anteferiu": "anteferir",
    "anteferíamo": "anteferir",
    "anteferíamos": "anteferir",
    "anteferíei": "anteferir",
    "anteferíeis": "anteferir",
    "anteferíramo": "anteferir",
    "anteferíramos": "anteferir",
    "anteferírei": "anteferir",
    "anteferíreis": "anteferir",
    "anteferísseis": "anteferir",
    "anteferíssemos": "anteferir",
    "antefira": "anteferir",
    "antefirais": "anteferir",
    "antefiram": "anteferir",
    "antefiramo": "anteferir",
    "antefiramos": "anteferir",
    "antefiras": "anteferir",
    "antefirmas": "antefirma",
    "antefiro": "anteferir",
    "antefixa": "antefixo",
    "antefixas": "antefixo",
    "antefixos": "antefixo",
    "antefossos": "antefosso",
    "antefrua": "antefruir",
    "antefruais": "antefruir",
    "antefruam": "antefruir",
    "antefruamo": "antefruir",
    "antefruamos": "antefruir",
    "antefruas": "antefruir",
    "antefruem": "antefruir",
    "antefrui": "antefruir",
    "antefruindo": "antefruir",
    "antefruirde": "antefruir",
    "antefruirdes": "antefruir",
    "antefruirei": "antefruir",
    "antefruireis": "antefruir",
    "antefruiremos": "antefruir",
    "antefruiria": "antefruir",
    "antefruiriam": "antefruir",
    "antefruirias": "antefruir",
    "antefruirmo": "antefruir",
    "antefruirmos": "antefruir",
    "antefruirá": "antefruir",
    "antefruirás": "antefruir",
    "antefruirão": "antefruir",
    "antefruiríamos": "antefruir",
    "antefruiríeis": "antefruir",
    "antefruis": "antefruir",
    "antefruiu": "antefruir",
    "antefruo": "antefruir",
    "antefruí": "antefruir",
    "antefruía": "antefruir",
    "antefruíam": "antefruir",
    "antefruíamo": "antefruir",
    "antefruíamos": "antefruir",
    "antefruías": "antefruir",
    "antefruída": "antefruir",
    "antefruídas": "antefruir",
    "antefruído": "antefruir",
    "antefruídos": "antefruir",
    "antefruíei": "antefruir",
    "antefruíeis": "antefruir",
    "antefruímo": "antefruir",
    "antefruímos": "antefruir",
    "antefruíra": "antefruir",
    "antefruíram": "antefruir",
    "antefruíramo": "antefruir",
    "antefruíramos": "antefruir",
    "antefruíras": "antefruir",
    "antefruíre": "antefruir",
    "antefruírei": "antefruir",
    "antefruíreis": "antefruir",
    "antefruírem": "antefruir",
    "antefruíres": "antefruir",
    "antefruís": "antefruir",
    "antefruísse": "antefruir",
    "antefruísseis": "antefruir",
    "antefruíssem": "antefruir",
    "antefruíssemos": "antefruir",
    "antefruísses": "antefruir",
    "antefruíste": "antefruir",
    "antefruístes": "antefruir",
    "antegabinetes": "antegabinete",
    "antegalhas": "antegalha",
    "antegares": "antegare",
    "antegosta": "antegostar",
    "antegostada": "antegostar",
    "antegostadas": "antegostar",
    "antegostado": "antegostar",
    "antegostados": "antegostar",
    "antegostai": "antegostar",
    "antegostais": "antegostar",
    "antegostam": "antegostar",
    "antegostamo": "antegostar",
    "antegostamos": "antegostar",
    "antegostando": "antegostar",
    "antegostara": "antegostar",
    "antegostaram": "antegostar",
    "antegostaras": "antegostar",
    "antegostarde": "antegostar",
    "antegostardes": "antegostar",
    "antegostare": "antegostar",
    "antegostarei": "antegostar",
    "antegostareis": "antegostar",
    "antegostarem": "antegostar",
    "antegostaremos": "antegostar",
    "antegostares": "antegostar",
    "antegostaria": "antegostar",
    "antegostariam": "antegostar",
    "antegostarias": "antegostar",
    "antegostarmo": "antegostar",
    "antegostarmos": "antegostar",
    "antegostará": "antegostar",
    "antegostarás": "antegostar",
    "antegostarão": "antegostar",
    "antegostaríamos": "antegostar",
    "antegostaríeis": "antegostar",
    "antegostas": "antegostar",
    "antegostasse": "antegostar",
    "antegostassem": "antegostar",
    "antegostasses": "antegostar",
    "antegostaste": "antegostar",
    "antegostastes": "antegostar",
    "antegostava": "antegostar",
    "antegostavam": "antegostar",
    "antegostavas": "antegostar",
    "antegoste": "antegostar",
    "antegostei": "antegostar",
    "antegosteis": "antegostar",
    "antegostem": "antegostar",
    "antegostemo": "antegostar",
    "antegostemos": "antegostar",
    "antegostes": "antegostar",
    "antegosto": "antegostar",
    "antegostos": "antegosto",
    "antegostou": "antegostar",
    "antegostá": "antegostar",
    "antegostámo": "antegostar",
    "antegostámos": "antegostar",
    "antegostáramo": "antegostar",
    "antegostáramos": "antegostar",
    "antegostárei": "antegostar",
    "antegostáreis": "antegostar",
    "antegostásseis": "antegostar",
    "antegostássemos": "antegostar",
    "antegostávamo": "antegostar",
    "antegostávamos": "antegostar",
    "antegostávei": "antegostar",
    "antegostáveis": "antegostar",
    "antegoza": "antegozar",
    "antegozada": "antegozar",
    "antegozadas": "antegozar",
    "antegozado": "antegozar",
    "antegozados": "antegozar",
    "antegozai": "antegozar",
    "antegozais": "antegozar",
    "antegozam": "antegozar",
    "antegozamo": "antegozar",
    "antegozamos": "antegozar",
    "antegozando": "antegozar",
    "antegozara": "antegozar",
    "antegozaram": "antegozar",
    "antegozaras": "antegozar",
    "antegozarde": "antegozar",
    "antegozardes": "antegozar",
    "antegozare": "antegozar",
    "antegozarei": "antegozar",
    "antegozareis": "antegozar",
    "antegozarem": "antegozar",
    "antegozaremos": "antegozar",
    "antegozares": "antegozar",
    "antegozaria": "antegozar",
    "antegozariam": "antegozar",
    "antegozarias": "antegozar",
    "antegozarmo": "antegozar",
    "antegozarmos": "antegozar",
    "antegozará": "antegozar",
    "antegozarás": "antegozar",
    "antegozarão": "antegozar",
    "antegozaríamos": "antegozar",
    "antegozaríeis": "antegozar",
    "antegozas": "antegozar",
    "antegozasse": "antegozar",
    "antegozassem": "antegozar",
    "antegozasses": "antegozar",
    "antegozaste": "antegozar",
    "antegozastes": "antegozar",
    "antegozava": "antegozar",
    "antegozavam": "antegozar",
    "antegozavas": "antegozar",
    "antegoze": "antegozar",
    "antegozei": "antegozar",
    "antegozeis": "antegozar",
    "antegozem": "antegozar",
    "antegozemo": "antegozar",
    "antegozemos": "antegozar",
    "antegozes": "antegozar",
    "antegozo": "antegozar",
    "antegozos": "antegozo",
    "antegozou": "antegozar",
    "antegozá": "antegozar",
    "antegozámo": "antegozar",
    "antegozámos": "antegozar",
    "antegozáramo": "antegozar",
    "antegozáramos": "antegozar",
    "antegozárei": "antegozar",
    "antegozáreis": "antegozar",
    "antegozásseis": "antegozar",
    "antegozássemos": "antegozar",
    "antegozávamo": "antegozar",
    "antegozávamos": "antegozar",
    "antegozávei": "antegozar",
    "antegozáveis": "antegozar",
    "antegramaticais": "antegramatical",
    "anteguardas": "anteguarda",
    "antei": "antar",
    "anteis": "antar",
    "antelas": "antela",
    "antelações": "antelação",
    "antelmíntica": "antelmíntico",
    "antelmínticas": "antelmíntico",
    "antelmínticos": "antelmíntico",
    "antelucanos": "antelucano",
    "antelóquios": "antelóquio",
    "antem": "antar",
    "antemanhãs": "antemanhã",
    "antemeridiana": "antemeridiano",
    "antemeridianas": "antemeridiano",
    "antemeridianos": "antemeridiano",
    "antemesas": "antemesa",
    "antemo": "antar",
    "antemolares": "antemolar",
    "antemos": "antar",
    "antemostra": "antemostrar",
    "antemostrada": "antemostrar",
    "antemostradas": "antemostrar",
    "antemostrado": "antemostrar",
    "antemostrados": "antemostrar",
    "antemostrai": "antemostrar",
    "antemostrais": "antemostrar",
    "antemostram": "antemostrar",
    "antemostramo": "antemostrar",
    "antemostramos": "antemostrar",
    "antemostrando": "antemostrar",
    "antemostrara": "antemostrar",
    "antemostraram": "antemostrar",
    "antemostraras": "antemostrar",
    "antemostrarde": "antemostrar",
    "antemostrardes": "antemostrar",
    "antemostrare": "antemostrar",
    "antemostrarei": "antemostrar",
    "antemostrareis": "antemostrar",
    "antemostrarem": "antemostrar",
    "antemostraremos": "antemostrar",
    "antemostrares": "antemostrar",
    "antemostraria": "antemostrar",
    "antemostrariam": "antemostrar",
    "antemostrarias": "antemostrar",
    "antemostrarmo": "antemostrar",
    "antemostrarmos": "antemostrar",
    "antemostrará": "antemostrar",
    "antemostrarás": "antemostrar",
    "antemostrarão": "antemostrar",
    "antemostraríamos": "antemostrar",
    "antemostraríeis": "antemostrar",
    "antemostras": "antemostrar",
    "antemostrasse": "antemostrar",
    "antemostrassem": "antemostrar",
    "antemostrasses": "antemostrar",
    "antemostraste": "antemostrar",
    "antemostrastes": "antemostrar",
    "antemostrava": "antemostrar",
    "antemostravam": "antemostrar",
    "antemostravas": "antemostrar",
    "antemostre": "antemostrar",
    "antemostrei": "antemostrar",
    "antemostreis": "antemostrar",
    "antemostrem": "antemostrar",
    "antemostremo": "antemostrar",
    "antemostremos": "antemostrar",
    "antemostres": "antemostrar",
    "antemostro": "antemostrar",
    "antemostrou": "antemostrar",
    "antemostrá": "antemostrar",
    "antemostrámo": "antemostrar",
    "antemostrámos": "antemostrar",
    "antemostráramo": "antemostrar",
    "antemostráramos": "antemostrar",
    "antemostrárei": "antemostrar",
    "antemostráreis": "antemostrar",
    "antemostrásseis": "antemostrar",
    "antemostrássemos": "antemostrar",
    "antemostrávamo": "antemostrar",
    "antemostrávamos": "antemostrar",
    "antemostrávei": "antemostrar",
    "antemostráveis": "antemostrar",
    "antemova": "antemover",
    "antemovais": "antemover",
    "antemovam": "antemover",
    "antemovamo": "antemover",
    "antemovamos": "antemover",
    "antemovas": "antemover",
    "antemove": "antemover",
    "antemovei": "antemover",
    "antemoveis": "antemover",
    "antemovem": "antemover",
    "antemovemo": "antemover",
    "antemovemos": "antemover",
    "antemovendo": "antemover",
    "antemovera": "antemover",
    "antemoveram": "antemover",
    "antemoveras": "antemover",
    "antemoverde": "antemover",
    "antemoverdes": "antemover",
    "antemovere": "antemover",
    "antemoverei": "antemover",
    "antemovereis": "antemover",
    "antemoverem": "antemover",
    "antemoveremos": "antemover",
    "antemoveres": "antemover",
    "antemoveria": "antemover",
    "antemoveriam": "antemover",
    "antemoverias": "antemover",
    "antemovermo": "antemover",
    "antemovermos": "antemover",
    "antemoverá": "antemover",
    "antemoverás": "antemover",
    "antemoverão": "antemover",
    "antemoveríamos": "antemover",
    "antemoveríeis": "antemover",
    "antemoves": "antemover",
    "antemovesse": "antemover",
    "antemovessem": "antemover",
    "antemovesses": "antemover",
    "antemoveste": "antemover",
    "antemovestes": "antemover",
    "antemoveu": "antemover",
    "antemovi": "antemover",
    "antemovia": "antemover",
    "antemoviam": "antemover",
    "antemovias": "antemover",
    "antemovida": "antemover",
    "antemovidas": "antemover",
    "antemovido": "antemover",
    "antemovidos": "antemover",
    "antemovo": "antemover",
    "antemovê": "antemover",
    "antemovêramo": "antemover",
    "antemovêramos": "antemover",
    "antemovêrei": "antemover",
    "antemovêreis": "antemover",
    "antemovêsseis": "antemover",
    "antemovêssemos": "antemover",
    "antemovíamo": "antemover",
    "antemovíamos": "antemover",
    "antemovíei": "antemover",
    "antemovíeis": "antemover",
    "antemura": "antemurar",
    "antemurada": "antemurar",
    "antemuradas": "antemurar",
    "antemurado": "antemurar",
    "antemurados": "antemurar",
    "antemurai": "antemurar",
    "antemurais": "antemurar",
    "antemuram": "antemurar",
    "antemuramo": "antemurar",
    "antemuramos": "antemurar",
    "antemurando": "antemurar",
    "antemurara": "antemurar",
    "antemuraram": "antemurar",
    "antemuraras": "antemurar",
    "antemurarde": "antemurar",
    "antemurardes": "antemurar",
    "antemurare": "antemurar",
    "antemurarei": "antemurar",
    "antemurareis": "antemurar",
    "antemurarem": "antemurar",
    "antemuraremos": "antemurar",
    "antemurares": "antemurar",
    "antemuraria": "antemurar",
    "antemurariam": "antemurar",
    "antemurarias": "antemurar",
    "antemurarmo": "antemurar",
    "antemurarmos": "antemurar",
    "antemurará": "antemurar",
    "antemurarás": "antemurar",
    "antemurarão": "antemurar",
    "antemuraríamos": "antemurar",
    "antemuraríeis": "antemurar",
    "antemuras": "antemurar",
    "antemurasse": "antemurar",
    "antemurassem": "antemurar",
    "antemurasses": "antemurar",
    "antemuraste": "antemurar",
    "antemurastes": "antemurar",
    "antemurava": "antemurar",
    "antemuravam": "antemurar",
    "antemuravas": "antemurar",
    "antemure": "antemurar",
    "antemurei": "antemurar",
    "antemureis": "antemurar",
    "antemurem": "antemurar",
    "antemuremo": "antemurar",
    "antemuremos": "antemurar",
    "antemures": "antemurar",
    "antemuro": "antemurar",
    "antemuros": "antemuro",
    "antemurou": "antemurar",
    "antemurá": "antemurar",
    "antemurámo": "antemurar",
    "antemurámos": "antemurar",
    "antemuráramo": "antemurar",
    "antemuráramos": "antemurar",
    "antemurárei": "antemurar",
    "antemuráreis": "antemurar",
    "antemurásseis": "antemurar",
    "antemurássemos": "antemurar",
    "antemurávamo": "antemurar",
    "antemurávamos": "antemurar",
    "antemurávei": "antemurar",
    "antemuráveis": "antemurar",
    "antenada": "antenado",
    "antenadas": "antenado",
    "antenados": "antenado",
    "antenas": "antena",
    "anteniformes": "anteniforme",
    "antenomes": "antenome",
    "antenulares": "antenular",
    "antenupciais": "antenupcial",
    "antenífera": "antenífero",
    "anteníferas": "antenífero",
    "anteníferos": "antenífero",
    "anteoculares": "anteocular",
    "anteocupa": "anteocupar",
    "anteocupada": "anteocupar",
    "anteocupadas": "anteocupar",
    "anteocupado": "anteocupar",
    "anteocupados": "anteocupar",
    "anteocupai": "anteocupar",
    "anteocupais": "anteocupar",
    "anteocupam": "anteocupar",
    "anteocupamo": "anteocupar",
    "anteocupamos": "anteocupar",
    "anteocupando": "anteocupar",
    "anteocupantes": "anteocupante",
    "anteocupara": "anteocupar",
    "anteocuparam": "anteocupar",
    "anteocuparas": "anteocupar",
    "anteocuparde": "anteocupar",
    "anteocupardes": "anteocupar",
    "anteocupare": "anteocupar",
    "anteocuparei": "anteocupar",
    "anteocupareis": "anteocupar",
    "anteocuparem": "anteocupar",
    "anteocuparemos": "anteocupar",
    "anteocupares": "anteocupar",
    "anteocuparia": "anteocupar",
    "anteocupariam": "anteocupar",
    "anteocuparias": "anteocupar",
    "anteocuparmo": "anteocupar",
    "anteocuparmos": "anteocupar",
    "anteocupará": "anteocupar",
    "anteocuparás": "anteocupar",
    "anteocuparão": "anteocupar",
    "anteocuparíamos": "anteocupar",
    "anteocuparíeis": "anteocupar",
    "anteocupas": "anteocupar",
    "anteocupasse": "anteocupar",
    "anteocupassem": "anteocupar",
    "anteocupasses": "anteocupar",
    "anteocupaste": "anteocupar",
    "anteocupastes": "anteocupar",
    "anteocupava": "anteocupar",
    "anteocupavam": "anteocupar",
    "anteocupavas": "anteocupar",
    "anteocupações": "anteocupação",
    "anteocupe": "anteocupar",
    "anteocupei": "anteocupar",
    "anteocupeis": "anteocupar",
    "anteocupem": "anteocupar",
    "anteocupemo": "anteocupar",
    "anteocupemos": "anteocupar",
    "anteocupes": "anteocupar",
    "anteocupo": "anteocupar",
    "anteocupou": "anteocupar",
    "anteocupá": "anteocupar",
    "anteocupámo": "anteocupar",
    "anteocupámos": "anteocupar",
    "anteocupáramo": "anteocupar",
    "anteocupáramos": "anteocupar",
    "anteocupárei": "anteocupar",
    "anteocupáreis": "anteocupar",
    "anteocupásseis": "anteocupar",
    "anteocupássemos": "anteocupar",
    "anteocupávamo": "anteocupar",
    "anteocupávamos": "anteocupar",
    "anteocupávei": "anteocupar",
    "anteocupáveis": "anteocupar",
    "antepaga": "antepagar",
    "antepagada": "antepagar",
    "antepagadas": "antepagar",
    "antepagado": "antepagar",
    "antepagados": "antepagar",
    "antepagai": "antepagar",
    "antepagais": "antepagar",
    "antepagam": "antepagar",
    "antepagamo": "antepagar",
    "antepagamos": "antepagar",
    "antepagando": "antepagar",
    "antepagara": "antepagar",
    "antepagaram": "antepagar",
    "antepagaras": "antepagar",
    "antepagarde": "antepagar",
    "antepagardes": "antepagar",
    "antepagare": "antepagar",
    "antepagarei": "antepagar",
    "antepagareis": "antepagar",
    "antepagarem": "antepagar",
    "antepagaremos": "antepagar",
    "antepagares": "antepagar",
    "antepagaria": "antepagar",
    "antepagariam": "antepagar",
    "antepagarias": "antepagar",
    "antepagarmo": "antepagar",
    "antepagarmos": "antepagar",
    "antepagará": "antepagar",
    "antepagarás": "antepagar",
    "antepagarão": "antepagar",
    "antepagaríamos": "antepagar",
    "antepagaríeis": "antepagar",
    "antepagas": "antepagar",
    "antepagasse": "antepagar",
    "antepagassem": "antepagar",
    "antepagasses": "antepagar",
    "antepagaste": "antepagar",
    "antepagastes": "antepagar",
    "antepagava": "antepagar",
    "antepagavam": "antepagar",
    "antepagavas": "antepagar",
    "antepago": "antepagar",
    "antepagou": "antepagar",
    "antepague": "antepagar",
    "antepaguei": "antepagar",
    "antepagueis": "antepagar",
    "antepaguem": "antepagar",
    "antepaguemo": "antepagar",
    "antepaguemos": "antepagar",
    "antepagues": "antepagar",
    "antepagá": "antepagar",
    "antepagámo": "antepagar",
    "antepagámos": "antepagar",
    "antepagáramo": "antepagar",
    "antepagáramos": "antepagar",
    "antepagárei": "antepagar",
    "antepagáreis": "antepagar",
    "antepagásseis": "antepagar",
    "antepagássemos": "antepagar",
    "antepagávamo": "antepagar",
    "antepagávamos": "antepagar",
    "antepagávei": "antepagar",
    "antepagáveis": "antepagar",
    "antepara": "anteparar",
    "anteparada": "anteparar",
    "anteparadas": "anteparar",
    "anteparado": "anteparar",
    "anteparados": "anteparar",
    "anteparai": "anteparar",
    "anteparais": "anteparar",
    "anteparam": "anteparar",
    "anteparamo": "anteparar",
    "anteparamos": "anteparar",
    "anteparando": "anteparar",
    "anteparara": "anteparar",
    "antepararam": "anteparar",
    "antepararas": "anteparar",
    "antepararde": "anteparar",
    "anteparardes": "anteparar",
    "anteparare": "anteparar",
    "antepararei": "anteparar",
    "anteparareis": "anteparar",
    "antepararem": "anteparar",
    "antepararemos": "anteparar",
    "anteparares": "anteparar",
    "antepararia": "anteparar",
    "anteparariam": "anteparar",
    "antepararias": "anteparar",
    "antepararmo": "anteparar",
    "antepararmos": "anteparar",
    "anteparará": "anteparar",
    "antepararás": "anteparar",
    "antepararão": "anteparar",
    "antepararíamos": "anteparar",
    "antepararíeis": "anteparar",
    "anteparas": "anteparar",
    "anteparasse": "anteparar",
    "anteparassem": "anteparar",
    "anteparasses": "anteparar",
    "anteparaste": "anteparar",
    "anteparastes": "anteparar",
    "anteparava": "anteparar",
    "anteparavam": "anteparar",
    "anteparavas": "anteparar",
    "antepare": "anteparar",
    "anteparei": "anteparar",
    "antepareis": "anteparar",
    "anteparem": "anteparar",
    "anteparemo": "anteparar",
    "anteparemos": "anteparar",
    "antepares": "anteparar",
    "anteparo": "anteparar",
    "anteparos": "anteparo",
    "anteparou": "anteparar",
    "antepartos": "anteparto",
    "antepará": "anteparar",
    "anteparámo": "anteparar",
    "anteparámos": "anteparar",
    "anteparáramo": "anteparar",
    "anteparáramos": "anteparar",
    "anteparárei": "anteparar",
    "anteparáreis": "anteparar",
    "anteparásseis": "anteparar",
    "anteparássemos": "anteparar",
    "anteparávamo": "anteparar",
    "anteparávamos": "anteparar",
    "anteparávei": "anteparar",
    "anteparáveis": "anteparar",
    "antepassa": "antepassar",
    "antepassada": "antepassar",
    "antepassadas": "antepassar",
    "antepassado": "antepassar",
    "antepassados": "antepassar",
    "antepassai": "antepassar",
    "antepassais": "antepassar",
    "antepassam": "antepassar",
    "antepassamo": "antepassar",
    "antepassamos": "antepassar",
    "antepassando": "antepassar",
    "antepassara": "antepassar",
    "antepassaram": "antepassar",
    "antepassaras": "antepassar",
    "antepassarde": "antepassar",
    "antepassardes": "antepassar",
    "antepassare": "antepassar",
    "antepassarei": "antepassar",
    "antepassareis": "antepassar",
    "antepassarem": "antepassar",
    "antepassaremos": "antepassar",
    "antepassares": "antepassar",
    "antepassaria": "antepassar",
    "antepassariam": "antepassar",
    "antepassarias": "antepassar",
    "antepassarmo": "antepassar",
    "antepassarmos": "antepassar",
    "antepassará": "antepassar",
    "antepassarás": "antepassar",
    "antepassarão": "antepassar",
    "antepassaríamos": "antepassar",
    "antepassaríeis": "antepassar",
    "antepassas": "antepassar",
    "antepassasse": "antepassar",
    "antepassassem": "antepassar",
    "antepassasses": "antepassar",
    "antepassaste": "antepassar",
    "antepassastes": "antepassar",
    "antepassava": "antepassar",
    "antepassavam": "antepassar",
    "antepassavas": "antepassar",
    "antepasse": "antepassar",
    "antepassei": "antepassar",
    "antepasseis": "antepassar",
    "antepassem": "antepassar",
    "antepassemo": "antepassar",
    "antepassemos": "antepassar",
    "antepasses": "antepassar",
    "antepasso": "antepassar",
    "antepassou": "antepassar",
    "antepassá": "antepassar",
    "antepassámo": "antepassar",
    "antepassámos": "antepassar",
    "antepassáramo": "antepassar",
    "antepassáramos": "antepassar",
    "antepassárei": "antepassar",
    "antepassáreis": "antepassar",
    "antepassásseis": "antepassar",
    "antepassássemos": "antepassar",
    "antepassávamo": "antepassar",
    "antepassávamos": "antepassar",
    "antepassávei": "antepassar",
    "antepassáveis": "antepassar",
    "antepastos": "antepasto",
    "antepectorais": "antepectoral",
    "antepenúltima": "antepenúltimo",
    "antepenúltimas": "antepenúltimo",
    "antepenúltimos": "antepenúltimo",
    "antepirremas": "antepirrema",
    "antepomo": "antepor",
    "antepomos": "antepor",
    "anteponde": "antepor",
    "antepondes": "antepor",
    "antepondo": "antepor",
    "anteponha": "antepor",
    "anteponhais": "antepor",
    "anteponham": "antepor",
    "anteponhamo": "antepor",
    "anteponhamos": "antepor",
    "anteponhas": "antepor",
    "anteponho": "antepor",
    "antepopas": "antepopa",
    "anteporde": "antepor",
    "antepordes": "antepor",
    "antepore": "antepor",
    "anteporei": "antepor",
    "anteporeis": "antepor",
    "anteporem": "antepor",
    "anteporemos": "antepor",
    "antepores": "antepor",
    "anteporia": "antepor",
    "anteporiam": "antepor",
    "anteporias": "antepor",
    "antepormo": "antepor",
    "antepormos": "antepor",
    "anteportadas": "anteportada",
    "anteportais": "anteportal",
    "anteportarias": "anteportaria",
    "anteportas": "anteporta",
    "anteportos": "anteporto",
    "anteporá": "antepor",
    "anteporás": "antepor",
    "anteporão": "antepor",
    "anteporíamos": "antepor",
    "anteporíeis": "antepor",
    "anteposições": "anteposição",
    "anteposta": "anteposto",
    "antepostas": "anteposto",
    "anteposto": "antepor",
    "antepostos": "anteposto",
    "antepotentes": "antepotente",
    "anteprimeira": "anteprimeiro",
    "anteprimeiras": "anteprimeiro",
    "anteprimeiros": "anteprimeiro",
    "anteprogramas": "anteprograma",
    "anteprojectos": "anteprojecto",
    "antepropostas": "anteproposta",
    "antepunha": "antepor",
    "antepunham": "antepor",
    "antepunhas": "antepor",
    "antepus": "antepor",
    "antepusemo": "antepor",
    "antepusemos": "antepor",
    "antepuser": "antepor",
    "antepusera": "antepor",
    "antepuseram": "antepor",
    "antepuseras": "antepor",
    "antepuserdes": "antepor",
    "antepuserem": "antepor",
    "antepuseres": "antepor",
    "antepusermos": "antepor",
    "antepusesse": "antepor",
    "antepusessem": "antepor",
    "antepusesses": "antepor",
    "antepuseste": "antepor",
    "antepusestes": "antepor",
    "antepuséramo": "antepor",
    "antepuséramos": "antepor",
    "antepusérei": "antepor",
    "antepuséreis": "antepor",
    "antepusésseis": "antepor",
    "antepuséssemos": "antepor",
    "antepô": "antepor",
    "antepôs": "antepor",
    "antepõe": "antepor",
    "antepõem": "antepor",
    "antepões": "antepor",
    "antepúnhamo": "antepor",
    "antepúnhamos": "antepor",
    "antepúnhei": "antepor",
    "antepúnheis": "antepor",
    "anteras": "antera",
    "anteriana": "anteriano",
    "anterianas": "anteriano",
    "anterianos": "anteriano",
    "anteriformes": "anteriforme",
    "anterina": "anterino",
    "anterinas": "anterino",
    "anterinos": "anterino",
    "anteriores": "anterior",
    "anterioridades": "anterioridade",
    "anterioriza": "anteriorizar",
    "anteriorizada": "anteriorizar",
    "anteriorizadas": "anteriorizar",
    "anteriorizado": "anteriorizar",
    "anteriorizados": "anteriorizar",
    "anteriorizai": "anteriorizar",
    "anteriorizais": "anteriorizar",
    "anteriorizam": "anteriorizar",
    "anteriorizamo": "anteriorizar",
    "anteriorizamos": "anteriorizar",
    "anteriorizando": "anteriorizar",
    "anteriorizara": "anteriorizar",
    "anteriorizaram": "anteriorizar",
    "anteriorizaras": "anteriorizar",
    "anteriorizarde": "anteriorizar",
    "anteriorizardes": "anteriorizar",
    "anteriorizare": "anteriorizar",
    "anteriorizarei": "anteriorizar",
    "anteriorizareis": "anteriorizar",
    "anteriorizarem": "anteriorizar",
    "anteriorizaremos": "anteriorizar",
    "anteriorizares": "anteriorizar",
    "anteriorizaria": "anteriorizar",
    "anteriorizariam": "anteriorizar",
    "anteriorizarias": "anteriorizar",
    "anteriorizarmo": "anteriorizar",
    "anteriorizarmos": "anteriorizar",
    "anteriorizará": "anteriorizar",
    "anteriorizarás": "anteriorizar",
    "anteriorizarão": "anteriorizar",
    "anteriorizaríamos": "anteriorizar",
    "anteriorizaríeis": "anteriorizar",
    "anteriorizas": "anteriorizar",
    "anteriorizasse": "anteriorizar",
    "anteriorizassem": "anteriorizar",
    "anteriorizasses": "anteriorizar",
    "anteriorizaste": "anteriorizar",
    "anteriorizastes": "anteriorizar",
    "anteriorizava": "anteriorizar",
    "anteriorizavam": "anteriorizar",
    "anteriorizavas": "anteriorizar",
    "anteriorize": "anteriorizar",
    "anteriorizei": "anteriorizar",
    "anteriorizeis": "anteriorizar",
    "anteriorizem": "anteriorizar",
    "anteriorizemo": "anteriorizar",
    "anteriorizemos": "anteriorizar",
    "anteriorizes": "anteriorizar",
    "anteriorizo": "anteriorizar",
    "anteriorizou": "anteriorizar",
    "anteriorizá": "anteriorizar",
    "anteriorizámo": "anteriorizar",
    "anteriorizámos": "anteriorizar",
    "anteriorizáramo": "anteriorizar",
    "anteriorizáramos": "anteriorizar",
    "anteriorizárei": "anteriorizar",
    "anteriorizáreis": "anteriorizar",
    "anteriorizásseis": "anteriorizar",
    "anteriorizássemos": "anteriorizar",
    "anteriorizávamo": "anteriorizar",
    "anteriorizávamos": "anteriorizar",
    "anteriorizávei": "anteriorizar",
    "anteriorizáveis": "anteriorizar",
    "anterozóides": "anterozóide",
    "anterrostos": "anterrosto",
    "anterídia": "anterídio",
    "anterídias": "anterídio",
    "anterídios": "anterídio",
    "anterífera": "anterífero",
    "anteríferas": "anterífero",
    "anteríferos": "anterífero",
    "antes": "antar",
    "anteses": "antese",
    "antessacristias": "antessacristia",
    "antessalas": "antessala",
    "antessalões": "antessalão",
    "antessazões": "antessazão",
    "antessente": "antessentir",
    "antessentem": "antessentir",
    "antessentes": "antessentir",
    "antessenti": "antessentir",
    "antessentia": "antessentir",
    "antessentiam": "antessentir",
    "antessentias": "antessentir",
    "antessentida": "antessentir",
    "antessentidas": "antessentir",
    "antessentido": "antessentir",
    "antessentidos": "antessentir",
    "antessentimo": "antessentir",
    "antessentimos": "antessentir",
    "antessentindo": "antessentir",
    "antessentira": "antessentir",
    "antessentiram": "antessentir",
    "antessentiras": "antessentir",
    "antessentirde": "antessentir",
    "antessentirdes": "antessentir",
    "antessentire": "antessentir",
    "antessentirei": "antessentir",
    "antessentireis": "antessentir",
    "antessentirem": "antessentir",
    "antessentiremos": "antessentir",
    "antessentires": "antessentir",
    "antessentiria": "antessentir",
    "antessentiriam": "antessentir",
    "antessentirias": "antessentir",
    "antessentirmo": "antessentir",
    "antessentirmos": "antessentir",
    "antessentirá": "antessentir",
    "antessentirás": "antessentir",
    "antessentirão": "antessentir",
    "antessentiríamos": "antessentir",
    "antessentiríeis": "antessentir",
    "antessentis": "antessentir",
    "antessentisse": "antessentir",
    "antessentissem": "antessentir",
    "antessentisses": "antessentir",
    "antessentiste": "antessentir",
    "antessentistes": "antessentir",
    "antessentiu": "antessentir",
    "antessentíamo": "antessentir",
    "antessentíamos": "antessentir",
    "antessentíei": "antessentir",
    "antessentíeis": "antessentir",
    "antessentíramo": "antessentir",
    "antessentíramos": "antessentir",
    "antessentírei": "antessentir",
    "antessentíreis": "antessentir",
    "antessentísseis": "antessentir",
    "antessentíssemos": "antessentir",
    "antessinta": "antessentir",
    "antessintais": "antessentir",
    "antessintam": "antessentir",
    "antessintamo": "antessentir",
    "antessintamos": "antessentir",
    "antessintas": "antessentir",
    "antessinto": "antessentir",
    "antestaturas": "antestatura",
    "antestreias": "antestreia",
    "anteterminais": "anteterminal",
    "antetítulos": "antetítulo",
    "antevede": "antever",
    "antevedes": "antever",
    "anteveja": "antever",
    "antevejais": "antever",
    "antevejam": "antever",
    "antevejamo": "antever",
    "antevejamos": "antever",
    "antevejas": "antever",
    "antevejo": "antever",
    "antevemo": "antever",
    "antevemos": "antever",
    "antevendo": "antever",
    "anteverde": "antever",
    "anteverdes": "antever",
    "antevere": "antever",
    "anteverei": "antever",
    "antevereis": "antever",
    "anteverem": "antever",
    "anteveremos": "antever",
    "anteveres": "antever",
    "anteveria": "antever",
    "anteveriam": "antever",
    "anteverias": "antever",
    "antevermo": "antever",
    "antevermos": "antever",
    "anteversões": "anteversão",
    "anteverta": "anteverter",
    "antevertais": "anteverter",
    "antevertam": "anteverter",
    "antevertamo": "anteverter",
    "antevertamos": "anteverter",
    "antevertas": "anteverter",
    "anteverte": "anteverter",
    "antevertei": "anteverter",
    "anteverteis": "anteverter",
    "antevertem": "anteverter",
    "antevertemo": "anteverter",
    "antevertemos": "anteverter",
    "antevertendo": "anteverter",
    "antevertera": "anteverter",
    "anteverteram": "anteverter",
    "anteverteras": "anteverter",
    "anteverterde": "anteverter",
    "anteverterdes": "anteverter",
    "antevertere": "anteverter",
    "anteverterei": "anteverter",
    "antevertereis": "anteverter",
    "anteverterem": "anteverter",
    "anteverteremos": "anteverter",
    "anteverteres": "anteverter",
    "anteverteria": "anteverter",
    "anteverteriam": "anteverter",
    "anteverterias": "anteverter",
    "antevertermo": "anteverter",
    "antevertermos": "anteverter",
    "anteverterá": "anteverter",
    "anteverterás": "anteverter",
    "anteverterão": "anteverter",
    "anteverteríamos": "anteverter",
    "anteverteríeis": "anteverter",
    "antevertes": "anteverter",
    "antevertesse": "anteverter",
    "antevertessem": "anteverter",
    "antevertesses": "anteverter",
    "anteverteste": "anteverter",
    "antevertestes": "anteverter",
    "anteverteu": "anteverter",
    "anteverti": "anteverter",
    "antevertia": "anteverter",
    "antevertiam": "anteverter",
    "antevertias": "anteverter",
    "antevertida": "anteverter",
    "antevertidas": "anteverter",
    "antevertido": "anteverter",
    "antevertidos": "anteverter",
    "anteverto": "anteverter",
    "antevertê": "anteverter",
    "antevertêramo": "anteverter",
    "antevertêramos": "anteverter",
    "antevertêrei": "anteverter",
    "antevertêreis": "anteverter",
    "antevertêsseis": "anteverter",
    "antevertêssemos": "anteverter",
    "antevertíamo": "anteverter",
    "antevertíamos": "anteverter",
    "antevertíei": "anteverter",
    "antevertíeis": "anteverter",
    "anteverá": "antever",
    "anteverás": "antever",
    "anteverão": "antever",
    "anteveríamos": "antever",
    "anteveríeis": "antever",
    "antevi": "antever",
    "antevia": "antever",
    "anteviam": "antever",
    "antevias": "antever",
    "antevidentes": "antevidente",
    "antevidências": "antevidência",
    "antevigílias": "antevigília",
    "antevimo": "antever",
    "antevimos": "antever",
    "antevir": "antever",
    "antevira": "antever",
    "anteviram": "antever",
    "anteviras": "antever",
    "antevirdes": "antever",
    "antevirem": "antever",
    "antevires": "antever",
    "antevirmos": "antever",
    "antevisse": "antever",
    "antevissem": "antever",
    "antevisses": "antever",
    "antevista": "antevisto",
    "antevistas": "antevisto",
    "anteviste": "antever",
    "antevistes": "antever",
    "antevisto": "antever",
    "antevistos": "antevisto",
    "antevisões": "antevisão",
    "anteviu": "antever",
    "antevocálica": "antevocálico",
    "antevocálicas": "antevocálico",
    "antevocálicos": "antevocálico",
    "antevésperas": "antevéspera",
    "antevê": "antever",
    "antevêem": "antever",
    "antevês": "antever",
    "antevíamo": "antever",
    "antevíamos": "antever",
    "antevíei": "antever",
    "antevíeis": "antever",
    "antevíramo": "antever",
    "antevíramos": "antever",
    "antevírei": "antever",
    "antevíreis": "antever",
    "antevísseis": "antever",
    "antevíssemos": "antever",
    "anteâmbulos": "anteâmbulo",
    "antiabolucionistas": "antiabolucionista",
    "antiabortiva": "antiabortivo",
    "antiabortivas": "antiabortivo",
    "antiabortivos": "antiabortivo",
    "antiacadémica": "antiacadémico",
    "antiacadémicas": "antiacadémico",
    "antiacadémicos": "antiacadémico",
    "antiacidezes": "antiacidez",
    "antiafrodisíaca": "antiafrodisíaco",
    "antiafrodisíacas": "antiafrodisíaco",
    "antiafrodisíacos": "antiafrodisíaco",
    "antiaglutinantes": "antiaglutinante",
    "antiagrícolas": "antiagrícola",
    "antialcalina": "antialcalino",
    "antialcalinas": "antialcalino",
    "antialcalinos": "antialcalino",
    "antialcoolismos": "antialcoolismo",
    "antialcoólica": "antialcoólico",
    "antialcoólicas": "antialcoólico",
    "antialcoólicos": "antialcoólico",
    "antialgésica": "antialgésico",
    "antialgésicas": "antialgésico",
    "antialgésicos": "antialgésico",
    "antialienígena": "antialienígeno",
    "antialienígenas": "antialienígeno",
    "antialienígenos": "antialienígeno",
    "antiamericana": "antiamericano",
    "antiamericanas": "antiamericano",
    "antiamericanos": "antiamericano",
    "antiapopléctica": "antiapopléctico",
    "antiapoplécticas": "antiapopléctico",
    "antiapoplécticos": "antiapopléctico",
    "antiarinas": "antiarina",
    "antiaristocratas": "antiaristocrata",
    "antiaristocrática": "antiaristocrático",
    "antiaristocráticas": "antiaristocrático",
    "antiaristocráticos": "antiaristocrático",
    "antiartrítica": "antiartrítico",
    "antiartríticas": "antiartrítico",
    "antiartríticos": "antiartrítico",
    "antiartística": "antiartístico",
    "antiartísticas": "antiartístico",
    "antiartísticos": "antiartístico",
    "antiasmática": "antiasmático",
    "antiasmáticas": "antiasmático",
    "antiasmáticos": "antiasmático",
    "antiaérea": "antiaéreo",
    "antiaéreas": "antiaéreo",
    "antiaéreos": "antiaéreo",
    "antibalística": "antibalístico",
    "antibalísticas": "antibalístico",
    "antibalísticos": "antibalístico",
    "antibelicistas": "antibelicista",
    "antibiliosa": "antibilioso",
    "antibiliosas": "antibilioso",
    "antibiliosos": "antibilioso",
    "antibioses": "antibiose",
    "antibioterapeutas": "antibioterapeuta",
    "antibioterapias": "antibioterapia",
    "antibioterapêutica": "antibioterapêutico",
    "antibioterapêuticas": "antibioterapêutico",
    "antibioterapêuticos": "antibioterapêutico",
    "antibiótica": "antibiótico",
    "antibióticas": "antibiótico",
    "antibióticos": "antibiótico",
    "antiblenorrágica": "antiblenorrágico",
    "antiblenorrágicas": "antiblenorrágico",
    "antiblenorrágicos": "antiblenorrágico",
    "antibloqueios": "antibloqueio",
    "antibritânica": "antibritânico",
    "antibritânicas": "antibritânico",
    "antibritânicos": "antibritânico",
    "antibrómica": "antibrómico",
    "antibrómicas": "antibrómico",
    "antibrómicos": "antibrómico",
    "antibulas": "antibula",
    "antibáquia": "antibáquio",
    "antibáquias": "antibáquio",
    "antibáquios": "antibáquio",
    "anticancerosa": "anticanceroso",
    "anticancerosas": "anticanceroso",
    "anticancerosos": "anticanceroso",
    "anticanónica": "anticanónico",
    "anticanónicas": "anticanónico",
    "anticanónicos": "anticanónico",
    "anticardeais": "anticardeal",
    "anticarros": "anticarro",
    "anticatolicismos": "anticatolicismo",
    "anticatódios": "anticatódio",
    "anticatólica": "anticatólico",
    "anticatólicas": "anticatólico",
    "anticatólicos": "anticatólico",
    "anticefalálgica": "anticefalálgico",
    "anticefalálgicas": "anticefalálgico",
    "anticefalálgicos": "anticefalálgico",
    "anticentralismos": "anticentralismo",
    "anticiclones": "anticiclone",
    "anticientífica": "anticientífico",
    "anticientíficas": "anticientífico",
    "anticientíficos": "anticientífico",
    "anticivilizadora": "anticivilizador",
    "anticivilizadoras": "anticivilizador",
    "anticivilizadores": "anticivilizador",
    "anticivismos": "anticivismo",
    "anticlericais": "anticlerical",
    "anticlericalismos": "anticlericalismo",
    "anticlinais": "anticlinal",
    "anticlinórios": "anticlinório",
    "anticlássica": "anticlássico",
    "anticlássicas": "anticlássico",
    "anticlássicos": "anticlássico",
    "anticoagulantes": "anticoagulante",
    "anticolérica": "anticolérico",
    "anticoléricas": "anticolérico",
    "anticoléricos": "anticolérico",
    "anticomanias": "anticomania",
    "anticomaníaca": "anticomaníaco",
    "anticomaníacas": "anticomaníaco",
    "anticomaníacos": "anticomaníaco",
    "anticombustíveis": "anticombustível",
    "anticomerciais": "anticomercial",
    "anticomunismos": "anticomunismo",
    "anticomunistas": "anticomunista",
    "anticoncepcionais": "anticoncepcional",
    "anticonceptivos": "anticonceptivo",
    "anticoncepções": "anticoncepção",
    "anticoncílios": "anticoncílio",
    "anticonjugais": "anticonjugal",
    "anticonstitucionais": "anticonstitucional",
    "anticoposcópios": "anticoposcópio",
    "anticorporativa": "anticorporativo",
    "anticorporativas": "anticorporativo",
    "anticorporativismos": "anticorporativismo",
    "anticorporativos": "anticorporativo",
    "anticorpos": "anticorpo",
    "anticorrosiva": "anticorrosivo",
    "anticorrosivas": "anticorrosivo",
    "anticorrosivos": "anticorrosivo",
    "anticosmética": "anticosmético",
    "anticosméticas": "anticosmético",
    "anticosméticos": "anticosmético",
    "anticrepusculares": "anticrepuscular",
    "anticrepúsculos": "anticrepúsculo",
    "anticrises": "anticrise",
    "anticristianismos": "anticristianismo",
    "anticristos": "anticristo",
    "anticristã": "anticristão",
    "anticristãos": "anticristão",
    "anticristãs": "anticristão",
    "anticrítica": "anticrítico",
    "anticríticas": "anticrítico",
    "anticríticos": "anticrítico",
    "anticárdia": "anticárdio",
    "anticárdias": "anticárdio",
    "anticárdios": "anticárdio",
    "anticátodos": "anticátodo",
    "anticéptica": "anticéptico",
    "anticépticas": "anticéptico",
    "anticépticos": "anticéptico",
    "anticívica": "anticívico",
    "anticívicas": "anticívico",
    "anticívicos": "anticívico",
    "anticómana": "anticómano",
    "anticómanas": "anticómano",
    "anticómanos": "anticómano",
    "antidemocracias": "antidemocracia",
    "antidemocratas": "antidemocrata",
    "antidemocratismos": "antidemocratismo",
    "antidemocrática": "antidemocrático",
    "antidemocráticas": "antidemocrático",
    "antidemocráticos": "antidemocrático",
    "antidemoníaca": "antidemoníaco",
    "antidemoníacas": "antidemoníaco",
    "antidemoníacos": "antidemoníaco",
    "antidepressiva": "antidepressivo",
    "antidepressivas": "antidepressivo",
    "antidepressivos": "antidepressivo",
    "antiderrapantes": "antiderrapante",
    "antidesmáceas": "antidesmácea",
    "antidesportistas": "antidesportista",
    "antidesportiva": "antidesportivo",
    "antidesportivas": "antidesportivo",
    "antidesportivos": "antidesportivo",
    "antidiabética": "antidiabético",
    "antidiabéticas": "antidiabético",
    "antidiabéticos": "antidiabético",
    "antidiaforética": "antidiaforético",
    "antidiaforéticas": "antidiaforético",
    "antidiaforéticos": "antidiaforético",
    "antidiarréica": "antidiarréico",
    "antidiarréicas": "antidiarréico",
    "antidiarréicos": "antidiarréico",
    "antidiftérica": "antidiftérico",
    "antidiftéricas": "antidiftérico",
    "antidiftéricos": "antidiftérico",
    "antidigestiva": "antidigestivo",
    "antidigestivas": "antidigestivo",
    "antidigestivos": "antidigestivo",
    "antidinástica": "antidinástico",
    "antidinásticas": "antidinástico",
    "antidinásticos": "antidinástico",
    "antidisentérica": "antidisentérico",
    "antidisentéricas": "antidisentérico",
    "antidisentéricos": "antidisentérico",
    "antidispneica": "antidispneico",
    "antidispneicas": "antidispneico",
    "antidispneicos": "antidispneico",
    "antidispéptica": "antidispéptico",
    "antidispépticas": "antidispéptico",
    "antidispépticos": "antidispéptico",
    "antidiurética": "antidiurético",
    "antidiuréticas": "antidiurético",
    "antidiuréticos": "antidiurético",
    "antidogmatismos": "antidogmatismo",
    "antidogmática": "antidogmático",
    "antidogmáticas": "antidogmático",
    "antidogmáticos": "antidogmático",
    "antidramática": "antidramático",
    "antidramáticas": "antidramático",
    "antidramáticos": "antidramático",
    "antidáctila": "antidáctilo",
    "antidáctilas": "antidáctilo",
    "antidáctilos": "antidáctilo",
    "antidínica": "antidínico",
    "antidínicas": "antidínico",
    "antidínicos": "antidínico",
    "antieconómica": "antieconómico",
    "antieconómicas": "antieconómico",
    "antieconómicos": "antieconómico",
    "antiemética": "antiemético",
    "antieméticas": "antiemético",
    "antieméticos": "antiemético",
    "antiepidémica": "antiepidémico",
    "antiepidémicas": "antiepidémico",
    "antiepidémicos": "antiepidémico",
    "antiescarlatinosa": "antiescarlatinoso",
    "antiescarlatinosas": "antiescarlatinoso",
    "antiescarlatinosos": "antiescarlatinoso",
    "antiescorbútica": "antiescorbútico",
    "antiescorbúticas": "antiescorbútico",
    "antiescorbúticos": "antiescorbútico",
    "antiescravistas": "antiescravista",
    "antiescrofulosa": "antiescrofuloso",
    "antiescrofulosas": "antiescrofuloso",
    "antiescrofulosos": "antiescrofuloso",
    "antiespasmódica": "antiespasmódico",
    "antiespasmódicas": "antiespasmódico",
    "antiespasmódicos": "antiespasmódico",
    "antiespiritualisma": "antiespiritualismo",
    "antiespiritualismas": "antiespiritualismo",
    "antiespiritualismos": "antiespiritualismo",
    "antiestafilocócica": "antiestafilocócico",
    "antiestafilocócicas": "antiestafilocócico",
    "antiestafilocócicos": "antiestafilocócico",
    "antiestética": "antiestético",
    "antiestéticas": "antiestético",
    "antiestéticos": "antiestético",
    "antietimológica": "antietimológico",
    "antietimológicas": "antietimológico",
    "antietimológicos": "antietimológico",
    "antieuropeia": "antieuropeu",
    "antieuropeias": "antieuropeu",
    "antieuropeus": "antieuropeu",
    "antieuropeísmos": "antieuropeísmo",
    "antievangélica": "antievangélico",
    "antievangélicas": "antievangélico",
    "antievangélicos": "antievangélico",
    "antifascismos": "antifascismo",
    "antifascistas": "antifascista",
    "antifebriis": "antifebril",
    "antifederalismos": "antifederalismo",
    "antifederalistas": "antifederalista",
    "antiferroeléctrica": "antiferroeléctrico",
    "antiferroeléctricas": "antiferroeléctrico",
    "antiferroeléctricos": "antiferroeléctrico",
    "antiferromagnetismos": "antiferromagnetismo",
    "antiferruginosa": "antiferruginoso",
    "antiferruginosas": "antiferruginoso",
    "antiferruginosos": "antiferruginoso",
    "antifilosófica": "antifilosófico",
    "antifilosóficas": "antifilosófico",
    "antifilosóficos": "antifilosófico",
    "antifisiológica": "antifisiológico",
    "antifisiológicas": "antifisiológico",
    "antifisiológicos": "antifisiológico",
    "antiflatulenta": "antiflatulento",
    "antiflatulentas": "antiflatulento",
    "antiflatulentos": "antiflatulento",
    "antiflogística": "antiflogístico",
    "antiflogísticas": "antiflogístico",
    "antiflogísticos": "antiflogístico",
    "antifoneiros": "antifoneiro",
    "antifonias": "antifonia",
    "antifonários": "antifonário",
    "antiga": "antigo",
    "antigalhas": "antigalha",
    "antigalhos": "antigalho",
    "antigalicanismos": "antigalicanismo",
    "antigangrenosa": "antigangrenoso",
    "antigangrenosas": "antigangrenoso",
    "antigangrenosos": "antigangrenoso",
    "antigas": "antigo",
    "antigeométrica": "antigeométrico",
    "antigeométricas": "antigeométrico",
    "antigeométricos": "antigeométrico",
    "antigermânica": "antigermânico",
    "antigermânicas": "antigermânico",
    "antigermânicos": "antigermânico",
    "antigorites": "antigorite",
    "antigos": "antigo",
    "antigotosa": "antigotoso",
    "antigotosas": "antigotoso",
    "antigotosos": "antigotoso",
    "antigovernamentais": "antigovernamental",
    "antigramaticais": "antigramatical",
    "antigravidades": "antigravidade",
    "antigrevistas": "antigrevista",
    "antigripais": "antigripal",
    "antigualhas": "antigualha",
    "antiguidades": "antiguidade",
    "antiguinha": "antigo",
    "antiguinhas": "antigo",
    "antiguinho": "antigo",
    "antiguinhos": "antigo",
    "antiguita": "antigo",
    "antiguitas": "antigo",
    "antiguito": "antigo",
    "antiguitos": "antigo",
    "antigáses": "antigás",
    "antigásica": "antigásico",
    "antigásicas": "antigásico",
    "antigásicos": "antigásico",
    "antigénica": "antigénico",
    "antigénicas": "antigénico",
    "antigénicos": "antigénico",
    "antigénios": "antigénio",
    "antigórios": "antigório",
    "antiinflamatórios": "antiinflamatório",
    "antijurídica": "antijurídico",
    "antijurídicas": "antijurídico",
    "antijurídicos": "antijurídico",
    "antilambdas": "antilambda",
    "antiletárgica": "antiletárgico",
    "antiletárgicas": "antiletárgico",
    "antiletárgicos": "antiletárgico",
    "antiliberais": "antiliberal",
    "antiligantes": "antiligante",
    "antilogaritmos": "antilogaritmo",
    "antilogias": "antilogia",
    "antilogismos": "antilogismo",
    "antiluética": "antiluético",
    "antiluéticas": "antiluético",
    "antiluéticos": "antiluético",
    "antilítica": "antilítico",
    "antilíticas": "antilítico",
    "antilíticos": "antilítico",
    "antilógica": "antilógico",
    "antilógicas": "antilógico",
    "antilógicos": "antilógico",
    "antimaculadores": "antimaculador",
    "antimagnética": "antimagnético",
    "antimagnéticas": "antimagnético",
    "antimagnéticos": "antimagnético",
    "antimarxistas": "antimarxista",
    "antimatérias": "antimatéria",
    "antimaçónica": "antimaçónico",
    "antimaçónicas": "antimaçónico",
    "antimaçónicos": "antimaçónico",
    "antimefítica": "antimefítico",
    "antimefíticas": "antimefítico",
    "antimefíticos": "antimefítico",
    "antimelancólica": "antimelancólico",
    "antimelancólicas": "antimelancólico",
    "antimelancólicos": "antimelancólico",
    "antimelódica": "antimelódico",
    "antimelódicas": "antimelódico",
    "antimelódicos": "antimelódico",
    "antimetalepses": "antimetalepse",
    "antimetáboles": "antimetábole",
    "antimetáteses": "antimetátese",
    "antimicrobianos": "antimicrobiano",
    "antimilitares": "antimilitar",
    "antimilitarismos": "antimilitarismo",
    "antimilitaristas": "antimilitarista",
    "antiministriais": "antiministrial",
    "antimnésias": "antimnésia",
    "antimnésica": "antimnésico",
    "antimnésicas": "antimnésico",
    "antimnésicos": "antimnésico",
    "antimodas": "antimoda",
    "antimodesnistas": "antimodesnista",
    "antimonacais": "antimonacal",
    "antimoniais": "antimonial",
    "antimoniatos": "antimoniato",
    "antimonites": "antimonite",
    "antimonárquica": "antimonárquico",
    "antimonárquicas": "antimonárquico",
    "antimonárquicos": "antimonárquico",
    "antimonástica": "antimonástico",
    "antimonásticas": "antimonástico",
    "antimonásticos": "antimonástico",
    "antimonóxidos": "antimonóxido",
    "antimorais": "antimoral",
    "antimísseis": "antimíssil",
    "antimónios": "antimónio",
    "antinacionais": "antinacional",
    "antinarcótica": "antinarcótico",
    "antinarcóticas": "antinarcótico",
    "antinarcóticos": "antinarcótico",
    "antinaturais": "antinatural",
    "antinazis": "antinazi",
    "antinefrítica": "antinefrítico",
    "antinefríticas": "antinefrítico",
    "antinefríticos": "antinefrítico",
    "antineutrinos": "antineutrino",
    "antineutrões": "antineutrão",
    "antinevrálgica": "antinevrálgico",
    "antinevrálgicas": "antinevrálgico",
    "antinevrálgicos": "antinevrálgico",
    "antinevrótica": "antinevrótico",
    "antinevróticas": "antinevrótico",
    "antinevróticos": "antinevrótico",
    "antinhas": "antinha",
    "antinodais": "antinodal",
    "antinodos": "antinodo",
    "antinomiana": "antinomiano",
    "antinomianas": "antinomiano",
    "antinomianos": "antinomiano",
    "antinomias": "antinomia",
    "antinomismos": "antinomismo",
    "antinucleares": "antinuclear",
    "antinupciais": "antinupcial",
    "antinómica": "antinómico",
    "antinómicas": "antinómico",
    "antinómicos": "antinómico",
    "antiocidentais": "antiocidental",
    "antiofídica": "antiofídico",
    "antiofídicas": "antiofídico",
    "antiofídicos": "antiofídico",
    "antioquenos": "antioqueno",
    "antioquenses": "antioquense",
    "antioquiana": "antioquiano",
    "antioquianas": "antioquiano",
    "antioquianos": "antioquiano",
    "antioxidantes": "antioxidante",
    "antioódica": "antioódico",
    "antioódicas": "antioódico",
    "antioódicos": "antioódico",
    "antipapados": "antipapado",
    "antipapas": "antipapa",
    "antipapismos": "antipapismo",
    "antipapistas": "antipapista",
    "antiparalelismos": "antiparalelismo",
    "antiparasitas": "antiparasita",
    "antiparlamentares": "antiparlamentar",
    "antiparlamentarismos": "antiparlamentarismo",
    "antipartidária": "antipartidário",
    "antipartidárias": "antipartidário",
    "antipartidários": "antipartidário",
    "antipartículas": "antipartícula",
    "antiparástases": "antiparástase",
    "antipatias": "antipatia",
    "antipatiza": "antipatizar",
    "antipatizada": "antipatizar",
    "antipatizadas": "antipatizar",
    "antipatizado": "antipatizar",
    "antipatizados": "antipatizar",
    "antipatizai": "antipatizar",
    "antipatizais": "antipatizar",
    "antipatizam": "antipatizar",
    "antipatizamo": "antipatizar",
    "antipatizamos": "antipatizar",
    "antipatizando": "antipatizar",
    "antipatizara": "antipatizar",
    "antipatizaram": "antipatizar",
    "antipatizaras": "antipatizar",
    "antipatizardes": "antipatizar",
    "antipatizarei": "antipatizar",
    "antipatizareis": "antipatizar",
    "antipatizarem": "antipatizar",
    "antipatizaremos": "antipatizar",
    "antipatizares": "antipatizar",
    "antipatizaria": "antipatizar",
    "antipatizariam": "antipatizar",
    "antipatizarias": "antipatizar",
    "antipatizarmo": "antipatizar",
    "antipatizarmos": "antipatizar",
    "antipatizará": "antipatizar",
    "antipatizarás": "antipatizar",
    "antipatizarão": "antipatizar",
    "antipatizaríamos": "antipatizar",
    "antipatizaríeis": "antipatizar",
    "antipatizas": "antipatizar",
    "antipatizasse": "antipatizar",
    "antipatizassem": "antipatizar",
    "antipatizasses": "antipatizar",
    "antipatizaste": "antipatizar",
    "antipatizastes": "antipatizar",
    "antipatizava": "antipatizar",
    "antipatizavam": "antipatizar",
    "antipatizavas": "antipatizar",
    "antipatize": "antipatizar",
    "antipatizei": "antipatizar",
    "antipatizeis": "antipatizar",
    "antipatizem": "antipatizar",
    "antipatizemo": "antipatizar",
    "antipatizemos": "antipatizar",
    "antipatizes": "antipatizar",
    "antipatizo": "antipatizar",
    "antipatizou": "antipatizar",
    "antipatizámo": "antipatizar",
    "antipatizámos": "antipatizar",
    "antipatizáramo": "antipatizar",
    "antipatizáramos": "antipatizar",
    "antipatizáreis": "antipatizar",
    "antipatizásseis": "antipatizar",
    "antipatizássemos": "antipatizar",
    "antipatizávamo": "antipatizar",
    "antipatizávamos": "antipatizar",
    "antipatizáveis": "antipatizar",
    "antipatriotas": "antipatriota",
    "antipatriotismos": "antipatriotismo",
    "antipatriótica": "antipatriótico",
    "antipatrióticas": "antipatriótico",
    "antipatrióticos": "antipatriótico",
    "antipedagógica": "antipedagógico",
    "antipedagógicas": "antipedagógico",
    "antipedagógicos": "antipedagógico",
    "antiperistaltismos": "antiperistaltismo",
    "antiperistáltica": "antiperistáltico",
    "antiperistálticas": "antiperistáltico",
    "antiperistálticos": "antiperistáltico",
    "antiperiódica": "antiperiódico",
    "antiperiódicas": "antiperiódico",
    "antiperiódicos": "antiperiódico",
    "antiperístases": "antiperístase",
    "antipessoais": "antipessoal",
    "antipestilenciais": "antipestilencial",
    "antipirinas": "antipirina",
    "antipirinismos": "antipirinismo",
    "antipirética": "antipirético",
    "antipiréticas": "antipirético",
    "antipiréticos": "antipirético",
    "antipirótica": "antipirótico",
    "antipiróticas": "antipirótico",
    "antipiróticos": "antipirótico",
    "antipleurítica": "antipleurítico",
    "antipleuríticas": "antipleurítico",
    "antipleuríticos": "antipleurítico",
    "antiplástica": "antiplástico",
    "antiplásticas": "antiplástico",
    "antiplásticos": "antiplástico",
    "antipneumocócitos": "antipneumocócito",
    "antipneumónica": "antipneumónico",
    "antipneumónicas": "antipneumónico",
    "antipneumónicos": "antipneumónico",
    "antipodais": "antipodal",
    "antipodágrica": "antipodágrico",
    "antipodágricas": "antipodágrico",
    "antipodágricos": "antipodágrico",
    "antipoliorcética": "antipoliorcético",
    "antipoliorcéticas": "antipoliorcético",
    "antipoliorcéticos": "antipoliorcético",
    "antipoluentes": "antipoluente",
    "antipolítica": "antipolítico",
    "antipolíticas": "antipolítico",
    "antipolíticos": "antipolítico",
    "antipopulares": "antipopular",
    "antipoética": "antipoético",
    "antipoéticas": "antipoético",
    "antipoéticos": "antipoético",
    "antipraxistas": "antipraxista",
    "antiprogressitas": "antiprogressita",
    "antiprotões": "antiprotão",
    "antipsórica": "antipsórico",
    "antipsóricas": "antipsórico",
    "antipsóricos": "antipsórico",
    "antiptoses": "antiptose",
    "antipática": "antipático",
    "antipáticas": "antipático",
    "antipáticos": "antipático",
    "antipêndios": "antipêndio",
    "antipútrida": "antipútrido",
    "antipútridas": "antipútrido",
    "antipútridos": "antipútrido",
    "antiqua": "antiquar",
    "antiquada": "antiquar",
    "antiquadas": "antiquar",
    "antiquado": "antiquar",
    "antiquados": "antiquar",
    "antiquadíssima": "antiquado",
    "antiquadíssimas": "antiquado",
    "antiquadíssimo": "antiquado",
    "antiquadíssimos": "antiquado",
    "antiquai": "antiquar",
    "antiquais": "antiquar",
    "antiqualhas": "antiqualha",
    "antiquam": "antiquar",
    "antiquamo": "antiquar",
    "antiquamos": "antiquar",
    "antiquando": "antiquar",
    "antiquara": "antiquar",
    "antiquaram": "antiquar",
    "antiquaras": "antiquar",
    "antiquarde": "antiquar",
    "antiquardes": "antiquar",
    "antiquare": "antiquar",
    "antiquarei": "antiquar",
    "antiquareis": "antiquar",
    "antiquarem": "antiquar",
    "antiquaremos": "antiquar",
    "antiquares": "antiquar",
    "antiquaria": "antiquar",
    "antiquariam": "antiquar",
    "antiquarias": "antiquar",
    "antiquarmo": "antiquar",
    "antiquarmos": "antiquar",
    "antiquará": "antiquar",
    "antiquarás": "antiquar",
    "antiquarão": "antiquar",
    "antiquaríamos": "antiquar",
    "antiquaríeis": "antiquar",
    "antiquas": "antiquar",
    "antiquasse": "antiquar",
    "antiquassem": "antiquar",
    "antiquasses": "antiquar",
    "antiquaste": "antiquar",
    "antiquastes": "antiquar",
    "antiquava": "antiquar",
    "antiquavam": "antiquar",
    "antiquavas": "antiquar",
    "antiquei": "antiquar",
    "antiqueis": "antiquar",
    "antiquemo": "antiquar",
    "antiquemos": "antiquar",
    "antiques": "antiquar",
    "antiquo": "antiquar",
    "antiquou": "antiquar",
    "antiquá": "antiquar",
    "antiquámo": "antiquar",
    "antiquámos": "antiquar",
    "antiquáramo": "antiquar",
    "antiquáramos": "antiquar",
    "antiquárei": "antiquar",
    "antiquáreis": "antiquar",
    "antiquários": "antiquário",
    "antiquásseis": "antiquar",
    "antiquássemos": "antiquar",
    "antiquávamo": "antiquar",
    "antiquávamos": "antiquar",
    "antiquávei": "antiquar",
    "antiquáveis": "antiquar",
    "antiquíssima": "antigo",
    "antiquíssimas": "antigo",
    "antiquíssimo": "antigo",
    "antiquíssimos": "antigo",
    "antiqúe": "antiquar",
    "antiqúem": "antiquar",
    "antiqúes": "antiquar",
    "antirracrinas": "antirracrina",
    "antirrinas": "antirrina",
    "antirrética": "antirrético",
    "antirréticas": "antirrético",
    "antirréticos": "antirrético",
    "antirríneas": "antirrínea",
    "antispasmódica": "antispasmódico",
    "antispasmódicas": "antispasmódico",
    "antispasmódicos": "antispasmódico",
    "antispastos": "antispasto",
    "antispástica": "antispástico",
    "antispásticas": "antispástico",
    "antispásticos": "antispástico",
    "antitabágica": "antitabágico",
    "antitabágicas": "antitabágico",
    "antitabágicos": "antitabágico",
    "antitanques": "antitanque",
    "antiteatros": "antiteatro",
    "antiterrorismos": "antiterrorismo",
    "antiterroristas": "antiterrorista",
    "antitetânica": "antitetânico",
    "antitetânicas": "antitetânico",
    "antitetânicos": "antitetânico",
    "antiteísmos": "antiteísmo",
    "antiteístas": "antiteísta",
    "antitoxinas": "antitoxina",
    "antitrinitária": "antitrinitário",
    "antitrinitárias": "antitrinitário",
    "antitrinitários": "antitrinitário",
    "antituberculosa": "antituberculoso",
    "antituberculosas": "antituberculoso",
    "antituberculosos": "antituberculoso",
    "antitérmica": "antitérmico",
    "antitérmicas": "antitérmico",
    "antitérmicos": "antitérmico",
    "antitóxica": "antitóxico",
    "antitóxicas": "antitóxico",
    "antitóxicos": "antitóxico",
    "antitússica": "antitússico",
    "antitússicas": "antitússico",
    "antitússicos": "antitússico",
    "antivariólica": "antivariólico",
    "antivariólicas": "antivariólico",
    "antivariólicos": "antivariólico",
    "antivenosa": "antivenoso",
    "antivenosas": "antivenoso",
    "antivenosos": "antivenoso",
    "antivenérea": "antivenéreo",
    "antivenéreas": "antivenéreo",
    "antivenéreos": "antivenéreo",
    "antivirais": "antiviral",
    "antiviriis": "antiviril",
    "antivirulenta": "antivirulento",
    "antivirulentas": "antivirulento",
    "antivirulentos": "antivirulento",
    "antizímica": "antizímico",
    "antizímicas": "antizímico",
    "antizímicos": "antizímico",
    "antiácidos": "antiácido",
    "antiálgica": "antiálgico",
    "antiálgicas": "antiálgico",
    "antiálgicos": "antiálgico",
    "anto": "antar",
    "antofilites": "antofilite",
    "antofilos": "antofilo",
    "antogonistais": "antogonistal",
    "antografias": "antografia",
    "antoja": "antojar",
    "antojada": "antojar",
    "antojadas": "antojar",
    "antojadiça": "antojadiço",
    "antojadiças": "antojadiço",
    "antojadiços": "antojadiço",
    "antojado": "antojar",
    "antojados": "antojar",
    "antojai": "antojar",
    "antojais": "antojar",
    "antojam": "antojar",
    "antojamo": "antojar",
    "antojamos": "antojar",
    "antojando": "antojar",
    "antojara": "antojar",
    "antojaram": "antojar",
    "antojaras": "antojar",
    "antojarde": "antojar",
    "antojardes": "antojar",
    "antojare": "antojar",
    "antojarei": "antojar",
    "antojareis": "antojar",
    "antojarem": "antojar",
    "antojaremos": "antojar",
    "antojares": "antojar",
    "antojaria": "antojar",
    "antojariam": "antojar",
    "antojarias": "antojar",
    "antojarmo": "antojar",
    "antojarmos": "antojar",
    "antojará": "antojar",
    "antojarás": "antojar",
    "antojarão": "antojar",
    "antojaríamos": "antojar",
    "antojaríeis": "antojar",
    "antojas": "antojar",
    "antojasse": "antojar",
    "antojassem": "antojar",
    "antojasses": "antojar",
    "antojaste": "antojar",
    "antojastes": "antojar",
    "antojava": "antojar",
    "antojavam": "antojar",
    "antojavas": "antojar",
    "antoje": "antojar",
    "antojei": "antojar",
    "antojeis": "antojar",
    "antojem": "antojar",
    "antojemo": "antojar",
    "antojemos": "antojar",
    "antojes": "antojar",
    "antojo": "antojar",
    "antojos": "antojo",
    "antojou": "antojar",
    "antojá": "antojar",
    "antojámo": "antojar",
    "antojámos": "antojar",
    "antojáramo": "antojar",
    "antojáramos": "antojar",
    "antojárei": "antojar",
    "antojáreis": "antojar",
    "antojásseis": "antojar",
    "antojássemos": "antojar",
    "antojávamo": "antojar",
    "antojávamos": "antojar",
    "antojávei": "antojar",
    "antojáveis": "antojar",
    "antolha": "antolhar",
    "antolhada": "antolhar",
    "antolhadas": "antolhar",
    "antolhado": "antolhar",
    "antolhados": "antolhar",
    "antolhai": "antolhar",
    "antolhais": "antolhar",
    "antolham": "antolhar",
    "antolhamo": "antolhar",
    "antolhamos": "antolhar",
    "antolhando": "antolhar",
    "antolhara": "antolhar",
    "antolharam": "antolhar",
    "antolharas": "antolhar",
    "antolharde": "antolhar",
    "antolhardes": "antolhar",
    "antolhare": "antolhar",
    "antolharei": "antolhar",
    "antolhareis": "antolhar",
    "antolharem": "antolhar",
    "antolharemos": "antolhar",
    "antolhares": "antolhar",
    "antolharia": "antolhar",
    "antolhariam": "antolhar",
    "antolharias": "antolhar",
    "antolharmo": "antolhar",
    "antolharmos": "antolhar",
    "antolhará": "antolhar",
    "antolharás": "antolhar",
    "antolharão": "antolhar",
    "antolharíamos": "antolhar",
    "antolharíeis": "antolhar",
    "antolhas": "antolhar",
    "antolhasse": "antolhar",
    "antolhassem": "antolhar",
    "antolhasses": "antolhar",
    "antolhaste": "antolhar",
    "antolhastes": "antolhar",
    "antolhava": "antolhar",
    "antolhavam": "antolhar",
    "antolhavas": "antolhar",
    "antolhe": "antolhar",
    "antolhei": "antolhar",
    "antolheis": "antolhar",
    "antolhem": "antolhar",
    "antolhemo": "antolhar",
    "antolhemos": "antolhar",
    "antolhes": "antolhar",
    "antolho": "antolhar",
    "antolhos": "antolho",
    "antolhou": "antolhar",
    "antolhá": "antolhar",
    "antolhámo": "antolhar",
    "antolhámos": "antolhar",
    "antolháramo": "antolhar",
    "antolháramos": "antolhar",
    "antolhárei": "antolhar",
    "antolháreis": "antolhar",
    "antolhásseis": "antolhar",
    "antolhássemos": "antolhar",
    "antolhávamo": "antolhar",
    "antolhávamos": "antolhar",
    "antolhávei": "antolhar",
    "antolháveis": "antolhar",
    "antologias": "antologia",
    "antologistas": "antologista",
    "antológica": "antológico",
    "antológicas": "antológico",
    "antológicos": "antológico",
    "antomanias": "antomania",
    "antoniana": "antoniano",
    "antonianas": "antoniano",
    "antonianos": "antoniano",
    "antonina": "antonino",
    "antoninas": "antonino",
    "antoninos": "antonino",
    "antonomásias": "antonomásia",
    "antonomástica": "antonomástico",
    "antonomásticas": "antonomástico",
    "antonomásticos": "antonomástico",
    "antonímias": "antonímia",
    "antorismos": "antorismo",
    "antotropismos": "antotropismo",
    "antou": "antar",
    "antoxantinas": "antoxantina",
    "antozoária": "antozoário",
    "antozoárias": "antozoário",
    "antozoários": "antozoário",
    "antracenos": "antraceno",
    "antraciformes": "antraciforme",
    "antracites": "antracite",
    "antracitos": "antracito",
    "antracitosa": "antracitoso",
    "antracitosas": "antracitoso",
    "antracitosos": "antracitoso",
    "antracnoses": "antracnose",
    "antracolítica": "antracolítico",
    "antracolíticas": "antracolítico",
    "antracolíticos": "antracolítico",
    "antracomantes": "antracomante",
    "antracomâncias": "antracomância",
    "antracoses": "antracose",
    "antracénica": "antracénico",
    "antracénicas": "antracénico",
    "antracénicos": "antracénico",
    "antracífera": "antracífero",
    "antracíferas": "antracífero",
    "antracíferos": "antracífero",
    "antrazes": "antraz",
    "antrenos": "antreno",
    "antropagogias": "antropagogia",
    "antropiatrias": "antropiatria",
    "antropobiologias": "antropobiologia",
    "antropocentrismos": "antropocentrismo",
    "antropocêntrica": "antropocêntrico",
    "antropocêntricas": "antropocêntrico",
    "antropocêntricos": "antropocêntrico",
    "antropofagias": "antropofagia",
    "antropofilias": "antropofilia",
    "antropofobias": "antropofobia",
    "antropogenesias": "antropogenesia",
    "antropogenias": "antropogenia",
    "antropogeografias": "antropogeografia",
    "antropoglossos": "antropoglosso",
    "antropognosias": "antropognosia",
    "antropografias": "antropografia",
    "antropogéneses": "antropogénese",
    "antropolatrias": "antropolatria",
    "antropologias": "antropologia",
    "antropologistas": "antropologista",
    "antropológica": "antropológico",
    "antropológicas": "antropológico",
    "antropológicos": "antropológico",
    "antropomancias": "antropomancia",
    "antropomantes": "antropomante",
    "antropometrias": "antropometria",
    "antropomorfa": "antropomorfo",
    "antropomorfas": "antropomorfo",
    "antropomorfias": "antropomorfia",
    "antropomorfismos": "antropomorfismo",
    "antropomorfos": "antropomorfo",
    "antropomorfoses": "antropomorfose",
    "antropométrica": "antropométrico",
    "antropométricas": "antropométrico",
    "antropométricos": "antropométrico",
    "antropomórfica": "antropomórfico",
    "antropomórficas": "antropomórfico",
    "antropomórficos": "antropomórfico",
    "antroponomias": "antroponomia",
    "antroponímias": "antroponímia",
    "antroponímica": "antroponímico",
    "antroponímicas": "antroponímico",
    "antroponímicos": "antroponímico",
    "antropopatias": "antropopatia",
    "antropopitecos": "antropopiteco",
    "antropossofias": "antropossofia",
    "antroposófica": "antroposófico",
    "antroposóficas": "antroposófico",
    "antroposóficos": "antroposófico",
    "antropotaxias": "antropotaxia",
    "antropotecnias": "antropotecnia",
    "antropoterapias": "antropoterapia",
    "antropoterápica": "antropoterápico",
    "antropoterápicas": "antropoterápico",
    "antropoterápicos": "antropoterápico",
    "antropoteísmos": "antropoteísmo",
    "antropoteístas": "antropoteísta",
    "antropotomias": "antropotomia",
    "antropotáxica": "antropotáxico",
    "antropotáxicas": "antropotáxico",
    "antropotáxicos": "antropotáxico",
    "antropozóica": "antropozóico",
    "antropozóicas": "antropozóico",
    "antropozóicos": "antropozóico",
    "antropófaga": "antropófago",
    "antropófagas": "antropófago",
    "antropófagos": "antropófago",
    "antropófila": "antropófilo",
    "antropófilas": "antropófilo",
    "antropófilos": "antropófilo",
    "antropófoba": "antropófobo",
    "antropófobas": "antropófobo",
    "antropófobos": "antropófobo",
    "antropóides": "antropóide",
    "antropólatras": "antropólatra",
    "antropólita": "antropólito",
    "antropólitas": "antropólito",
    "antropólitos": "antropólito",
    "antropóloga": "antropólogo",
    "antropólogas": "antropólogo",
    "antropólogos": "antropólogo",
    "antropónimos": "antropónimo",
    "antros": "antro",
    "antroscopias": "antroscopia",
    "antroscópica": "antroscópico",
    "antroscópicas": "antroscópico",
    "antroscópicos": "antroscópico",
    "antrácias": "antrácia",
    "antrácica": "antrácico",
    "antrácicas": "antrácico",
    "antrácicos": "antrácico",
    "antrófora": "antróforo",
    "antróforas": "antróforo",
    "antróforos": "antróforo",
    "antá": "antar",
    "antálgica": "antálgico",
    "antálgicas": "antálgico",
    "antálgicos": "antálgico",
    "antámo": "antar",
    "antámos": "antar",
    "antáramo": "antar",
    "antáramos": "antar",
    "antárctica": "antárctico",
    "antárcticas": "antárctico",
    "antárcticos": "antárctico",
    "antárei": "antar",
    "antáreis": "antar",
    "antásseis": "antar",
    "antássemos": "antar",
    "antávamo": "antar",
    "antávamos": "antar",
    "antávei": "antar",
    "antáveis": "antar",
    "antélices": "antélice",
    "antélios": "antélio",
    "anténulas": "anténula",
    "antícopes": "antícope",
    "antídotos": "antídoto",
    "antídromos": "antídromo",
    "antífonas": "antífona",
    "antífrases": "antífrase",
    "antígenos": "antígeno",
    "antígrafa": "antígrafo",
    "antígrafas": "antígrafo",
    "antígrafos": "antígrafo",
    "antílopes": "antílope",
    "antímeros": "antímero",
    "antíspases": "antíspase",
    "antístites": "antístite",
    "antístrofes": "antístrofe",
    "antíteses": "antítese",
    "antítipa": "antítipo",
    "antítipas": "antítipo",
    "antítipos": "antítipo",
    "antítraga": "antítrago",
    "antítragas": "antítrago",
    "antítragos": "antítrago",
    "antítropos": "antítropo",
    "antófaga": "antófago",
    "antófagas": "antófago",
    "antófagos": "antófago",
    "antófila": "antófilo",
    "antófilas": "antófilo",
    "antófilos": "antófilo",
    "antófora": "antóforo",
    "antóforas": "antóforo",
    "antóforos": "antóforo",
    "antógrafa": "antógrafo",
    "antógrafas": "antógrafo",
    "antógrafos": "antógrafo",
    "antólitos": "antólito",
    "antóloga": "antólogo",
    "antólogas": "antólogo",
    "antólogos": "antólogo",
    "antónima": "antónimo",
    "antónimas": "antónimo",
    "antónimos": "antónimo",
    "antúrios": "antúrio",
    "anua": "anuir",
    "anuais": "anuir",
    "anualidades": "anualidade",
    "anualizada": "anualizado",
    "anualizadas": "anualizado",
    "anualizados": "anualizado",
    "anuam": "anuir",
    "anuamo": "anuir",
    "anuamos": "anuir",
    "anuas": "anuir",
    "anuem": "anuir",
    "anuentes": "anuente",
    "anui": "anuir",
    "anuidades": "anuidade",
    "anuindo": "anuir",
    "anuirde": "anuir",
    "anuirdes": "anuir",
    "anuirei": "anuir",
    "anuireis": "anuir",
    "anuiremos": "anuir",
    "anuiria": "anuir",
    "anuiriam": "anuir",
    "anuirias": "anuir",
    "anuirmo": "anuir",
    "anuirmos": "anuir",
    "anuirá": "anuir",
    "anuirás": "anuir",
    "anuirão": "anuir",
    "anuiríamos": "anuir",
    "anuiríeis": "anuir",
    "anuis": "anuir",
    "anuitários": "anuitário",
    "anuiu": "anuir",
    "anula": "anular",
    "anulabilidades": "anulabilidade",
    "anulada": "anular",
    "anuladas": "anular",
    "anulado": "anular",
    "anuladora": "anulador",
    "anuladoras": "anulador",
    "anuladores": "anulador",
    "anulados": "anular",
    "anulai": "anular",
    "anulais": "anular",
    "anulam": "anular",
    "anulamentos": "anulamento",
    "anulamo": "anular",
    "anulamos": "anular",
    "anulando": "anular",
    "anulantes": "anulante",
    "anulara": "anular",
    "anularam": "anular",
    "anularas": "anular",
    "anularde": "anular",
    "anulardes": "anular",
    "anulare": "anular",
    "anularei": "anular",
    "anulareis": "anular",
    "anularem": "anular",
    "anularemos": "anular",
    "anulares": "anular",
    "anularia": "anular",
    "anulariam": "anular",
    "anularias": "anular",
    "anularmo": "anular",
    "anularmos": "anular",
    "anulará": "anular",
    "anularás": "anular",
    "anularão": "anular",
    "anularíamos": "anular",
    "anularíeis": "anular",
    "anulas": "anular",
    "anulasse": "anular",
    "anulassem": "anular",
    "anulasses": "anular",
    "anulaste": "anular",
    "anulastes": "anular",
    "anulativa": "anulativo",
    "anulativas": "anulativo",
    "anulativos": "anulativo",
    "anulatória": "anulatório",
    "anulatórias": "anulatório",
    "anulatórios": "anulatório",
    "anulava": "anular",
    "anulavam": "anular",
    "anulavas": "anular",
    "anulações": "anulação",
    "anule": "anular",
    "anulei": "anular",
    "anuleis": "anular",
    "anulem": "anular",
    "anulemo": "anular",
    "anulemos": "anular",
    "anules": "anular",
    "anulicórnea": "anulicórneo",
    "anulicórneas": "anulicórneo",
    "anulicórneos": "anulicórneo",
    "anulifera": "anulifero",
    "anuliferas": "anulifero",
    "anuliferos": "anulifero",
    "anulo": "anular",
    "anulou": "anular",
    "anulá": "anular",
    "anulámo": "anular",
    "anulámos": "anular",
    "anuláramo": "anular",
    "anuláramos": "anular",
    "anulárei": "anular",
    "anuláreis": "anular",
    "anulásseis": "anular",
    "anulássemos": "anular",
    "anulávamo": "anular",
    "anulávamos": "anular",
    "anulávei": "anular",
    "anuláveis": "anulável",
    "anuncia": "anunciar",
    "anunciada": "anunciar",
    "anunciadas": "anunciar",
    "anunciado": "anunciar",
    "anunciadora": "anunciador",
    "anunciadoras": "anunciador",
    "anunciadores": "anunciador",
    "anunciados": "anunciar",
    "anunciai": "anunciar",
    "anunciais": "anunciar",
    "anunciam": "anunciar",
    "anunciamo": "anunciar",
    "anunciamos": "anunciar",
    "anunciando": "anunciar",
    "anunciantes": "anunciante",
    "anunciara": "anunciar",
    "anunciaram": "anunciar",
    "anunciaras": "anunciar",
    "anunciarde": "anunciar",
    "anunciardes": "anunciar",
    "anunciare": "anunciar",
    "anunciarei": "anunciar",
    "anunciareis": "anunciar",
    "anunciarem": "anunciar",
    "anunciaremos": "anunciar",
    "anunciares": "anunciar",
    "anunciaria": "anunciar",
    "anunciariam": "anunciar",
    "anunciarias": "anunciar",
    "anunciarmo": "anunciar",
    "anunciarmos": "anunciar",
    "anunciará": "anunciar",
    "anunciarás": "anunciar",
    "anunciarão": "anunciar",
    "anunciaríamos": "anunciar",
    "anunciaríeis": "anunciar",
    "anuncias": "anunciar",
    "anunciasse": "anunciar",
    "anunciassem": "anunciar",
    "anunciasses": "anunciar",
    "anunciaste": "anunciar",
    "anunciastes": "anunciar",
    "anunciativa": "anunciativo",
    "anunciativas": "anunciativo",
    "anunciativos": "anunciativo",
    "anunciava": "anunciar",
    "anunciavam": "anunciar",
    "anunciavas": "anunciar",
    "anunciações": "anunciação",
    "anuncie": "anunciar",
    "anunciei": "anunciar",
    "anuncieis": "anunciar",
    "anunciem": "anunciar",
    "anunciemo": "anunciar",
    "anunciemos": "anunciar",
    "anuncies": "anunciar",
    "anuncio": "anunciar",
    "anunciou": "anunciar",
    "anuncistas": "anuncista",
    "anunciá": "anunciar",
    "anunciámo": "anunciar",
    "anunciámos": "anunciar",
    "anunciáramo": "anunciar",
    "anunciáramos": "anunciar",
    "anunciárei": "anunciar",
    "anunciáreis": "anunciar",
    "anunciásseis": "anunciar",
    "anunciássemos": "anunciar",
    "anunciávamo": "anunciar",
    "anunciávamos": "anunciar",
    "anunciávei": "anunciar",
    "anunciáveis": "anunciável",
    "anuo": "anuir",
    "anureses": "anurese",
    "anuros": "anuro",
    "anuvia": "anuviar",
    "anuviada": "anuviar",
    "anuviadas": "anuviar",
    "anuviado": "anuviar",
    "anuviadora": "anuviador",
    "anuviadoras": "anuviador",
    "anuviadores": "anuviador",
    "anuviados": "anuviar",
    "anuviai": "anuviar",
    "anuviais": "anuviar",
    "anuviam": "anuviar",
    "anuviamo": "anuviar",
    "anuviamos": "anuviar",
    "anuviando": "anuviar",
    "anuviara": "anuviar",
    "anuviaram": "anuviar",
    "anuviaras": "anuviar",
    "anuviarde": "anuviar",
    "anuviardes": "anuviar",
    "anuviare": "anuviar",
    "anuviarei": "anuviar",
    "anuviareis": "anuviar",
    "anuviarem": "anuviar",
    "anuviaremos": "anuviar",
    "anuviares": "anuviar",
    "anuviaria": "anuviar",
    "anuviariam": "anuviar",
    "anuviarias": "anuviar",
    "anuviarmo": "anuviar",
    "anuviarmos": "anuviar",
    "anuviará": "anuviar",
    "anuviarás": "anuviar",
    "anuviarão": "anuviar",
    "anuviaríamos": "anuviar",
    "anuviaríeis": "anuviar",
    "anuvias": "anuviar",
    "anuviasse": "anuviar",
    "anuviassem": "anuviar",
    "anuviasses": "anuviar",
    "anuviaste": "anuviar",
    "anuviastes": "anuviar",
    "anuviava": "anuviar",
    "anuviavam": "anuviar",
    "anuviavas": "anuviar",
    "anuvie": "anuviar",
    "anuviei": "anuviar",
    "anuvieis": "anuviar",
    "anuviem": "anuviar",
    "anuviemo": "anuviar",
    "anuviemos": "anuviar",
    "anuvies": "anuviar",
    "anuvio": "anuviar",
    "anuviou": "anuviar",
    "anuviá": "anuviar",
    "anuviámo": "anuviar",
    "anuviámos": "anuviar",
    "anuviáramo": "anuviar",
    "anuviáramos": "anuviar",
    "anuviárei": "anuviar",
    "anuviáreis": "anuviar",
    "anuviásseis": "anuviar",
    "anuviássemos": "anuviar",
    "anuviávamo": "anuviar",
    "anuviávamos": "anuviar",
    "anuviávei": "anuviar",
    "anuviáveis": "anuviar",
    "anuários": "anuário",
    "anuências": "anuência",
    "anuí": "anuir",
    "anuía": "anuir",
    "anuíam": "anuir",
    "anuíamo": "anuir",
    "anuíamos": "anuir",
    "anuías": "anuir",
    "anuída": "anuir",
    "anuídas": "anuir",
    "anuído": "anuir",
    "anuídos": "anuir",
    "anuíei": "anuir",
    "anuíeis": "anuir",
    "anuímo": "anuir",
    "anuímos": "anuir",
    "anuíra": "anuir",
    "anuíram": "anuir",
    "anuíramo": "anuir",
    "anuíramos": "anuir",
    "anuíras": "anuir",
    "anuíre": "anuir",
    "anuírei": "anuir",
    "anuíreis": "anuir",
    "anuírem": "anuir",
    "anuíres": "anuir",
    "anuís": "anuir",
    "anuísse": "anuir",
    "anuísseis": "anuir",
    "anuíssem": "anuir",
    "anuíssemos": "anuir",
    "anuísses": "anuir",
    "anuíste": "anuir",
    "anuístes": "anuir",
    "anversos": "anverso",
    "anzolada": "anzolado",
    "anzoladas": "anzolado",
    "anzolados": "anzolado",
    "anzoladíssima": "anzolado",
    "anzoladíssimas": "anzolado",
    "anzoladíssimo": "anzolado",
    "anzoladíssimos": "anzolado",
    "anzoleiros": "anzoleiro",
    "anzolos": "anzolo",
    "anzóis": "anzol",
    "anábatas": "anábata",
    "anáclases": "anáclase",
    "anáfases": "anáfase",
    "anáfegas": "anáfega",
    "anáfises": "anáfise",
    "anáforas": "anáfora",
    "anáglifa": "anáglifo",
    "anáglifas": "anáglifo",
    "anáglifos": "anáglifo",
    "anáguas": "anágua",
    "análcimes": "análcime",
    "análcimos": "análcimo",
    "análgica": "análgico",
    "análgicas": "análgico",
    "análgicos": "análgico",
    "análises": "análise",
    "análoga": "análogo",
    "análogas": "análogo",
    "análogos": "análogo",
    "anáptica": "anáptico",
    "anápticas": "anáptico",
    "anápticos": "anáptico",
    "anárquica": "anárquico",
    "anárquicas": "anárquico",
    "anárquicos": "anárquico",
    "anártrica": "anártrico",
    "anártricas": "anártrico",
    "anártricos": "anártrico",
    "anás": "aná",
    "anástrofes": "anástrofe",
    "anátases": "anátase",
    "anátemas": "anátema",
    "anátidas": "anátida",
    "anátropa": "anátropo",
    "anátropas": "anátropo",
    "anátropos": "anátropo",
    "anândria": "anândrio",
    "anândrias": "anândrio",
    "anândrios": "anândrio",
    "anânica": "anânico",
    "anânicas": "anânico",
    "anânicos": "anânico",
    "anã": "anão",
    "anãozinho": "anão",
    "anãozito": "anão",
    "anãs": "anão",
    "anãza": "anãzar",
    "anãzada": "anãzar",
    "anãzadas": "anãzar",
    "anãzado": "anãzar",
    "anãzados": "anãzar",
    "anãzai": "anãzar",
    "anãzais": "anãzar",
    "anãzam": "anãzar",
    "anãzamo": "anãzar",
    "anãzamos": "anãzar",
    "anãzando": "anãzar",
    "anãzara": "anãzar",
    "anãzaram": "anãzar",
    "anãzaras": "anãzar",
    "anãzarde": "anãzar",
    "anãzardes": "anãzar",
    "anãzare": "anãzar",
    "anãzarei": "anãzar",
    "anãzareis": "anãzar",
    "anãzarem": "anãzar",
    "anãzaremos": "anãzar",
    "anãzares": "anãzar",
    "anãzaria": "anãzar",
    "anãzariam": "anãzar",
    "anãzarias": "anãzar",
    "anãzarmo": "anãzar",
    "anãzarmos": "anãzar",
    "anãzará": "anãzar",
    "anãzarás": "anãzar",
    "anãzarão": "anãzar",
    "anãzaríamos": "anãzar",
    "anãzaríeis": "anãzar",
    "anãzas": "anãzar",
    "anãzasse": "anãzar",
    "anãzassem": "anãzar",
    "anãzasses": "anãzar",
    "anãzaste": "anãzar",
    "anãzastes": "anãzar",
    "anãzava": "anãzar",
    "anãzavam": "anãzar",
    "anãzavas": "anãzar",
    "anãze": "anãzar",
    "anãzei": "anãzar",
    "anãzeis": "anãzar",
    "anãzem": "anãzar",
    "anãzemo": "anãzar",
    "anãzemos": "anãzar",
    "anãzes": "anãzar",
    "anãzinha": "anão",
    "anãzinhas": "anão",
    "anãzita": "anão",
    "anãzitas": "anão",
    "anãzo": "anãzar",
    "anãzou": "anãzar",
    "anãzá": "anãzar",
    "anãzámo": "anãzar",
    "anãzámos": "anãzar",
    "anãzáramo": "anãzar",
    "anãzáramos": "anãzar",
    "anãzárei": "anãzar",
    "anãzáreis": "anãzar",
    "anãzásseis": "anãzar",
    "anãzássemos": "anãzar",
    "anãzávamo": "anãzar",
    "anãzávamos": "anãzar",
    "anãzávei": "anãzar",
    "anãzáveis": "anãzar",
    "anéis": "anel",
    "anélidos": "anélido",
    "anélitos": "anélito",
    "anélitros": "anélitro",
    "anémica": "anémico",
    "anémicas": "anémico",
    "anémicos": "anémico",
    "anémonas": "anémona",
    "anérvea": "anérveo",
    "anérveas": "anérveo",
    "anérveos": "anérveo",
    "anídrica": "anídrico",
    "anídricas": "anídrico",
    "anídricos": "anídrico",
    "anídridos": "anídrido",
    "anímica": "anímico",
    "anímicas": "anímico",
    "anímicos": "anímico",
    "anísica": "anísico",
    "anísicas": "anísico",
    "anísicos": "anísico",
    "anódica": "anódico",
    "anódicas": "anódico",
    "anódicos": "anódico",
    "anódina": "anódino",
    "anódinas": "anódino",
    "anódinos": "anódino",
    "anódios": "anódio",
    "anófeles": "anófele",
    "anómala": "anómalo",
    "anómalas": "anómalo",
    "anómalos": "anómalo",
    "anónima": "anónimo",
    "anónimas": "anónimo",
    "anónimos": "anónimo",
    "anóveas": "anóvea",
    "anões": "anão",
    "anõezinhos": "anão",
    "anõezitos": "anão",
    "anúduvas": "anúduva",
    "anúncios": "anúncio",
    "anúrias": "anúria",
    "anúrica": "anúrico",
    "anúricas": "anúrico",
    "anúricos": "anúrico",
    "aoristos": "aoristo",
    "aortalgias": "aortalgia",
    "aortalgésica": "aortalgésico",
    "aortalgésicas": "aortalgésico",
    "aortalgésicos": "aortalgésico",
    "aortas": "aorta",
    "aortectasias": "aortectasia",
    "aorteurismas": "aorteurisma",
    "aortites": "aortite",
    "aortoclasias": "aortoclasia",
    "aortoclastias": "aortoclastia",
    "aortografias": "aortografia",
    "aortográfica": "aortográfico",
    "aortográficas": "aortográfico",
    "aortográficos": "aortográfico",
    "aortostenias": "aortostenia",
    "aortosténica": "aortosténico",
    "aortosténicas": "aortosténico",
    "aortosténicos": "aortosténico",
    "aorística": "aorístico",
    "aorísticas": "aorístico",
    "aorísticos": "aorístico",
    "apaches": "apache",
    "apachorra": "apachorrar",
    "apachorrada": "apachorrar",
    "apachorradas": "apachorrar",
    "apachorrado": "apachorrar",
    "apachorrados": "apachorrar",
    "apachorrai": "apachorrar",
    "apachorrais": "apachorrar",
    "apachorram": "apachorrar",
    "apachorramo": "apachorrar",
    "apachorramos": "apachorrar",
    "apachorrando": "apachorrar",
    "apachorrara": "apachorrar",
    "apachorraram": "apachorrar",
    "apachorraras": "apachorrar",
    "apachorrarde": "apachorrar",
    "apachorrardes": "apachorrar",
    "apachorrare": "apachorrar",
    "apachorrarei": "apachorrar",
    "apachorrareis": "apachorrar",
    "apachorrarem": "apachorrar",
    "apachorraremos": "apachorrar",
    "apachorrares": "apachorrar",
    "apachorraria": "apachorrar",
    "apachorrariam": "apachorrar",
    "apachorrarias": "apachorrar",
    "apachorrarmo": "apachorrar",
    "apachorrarmos": "apachorrar",
    "apachorrará": "apachorrar",
    "apachorrarás": "apachorrar",
    "apachorrarão": "apachorrar",
    "apachorraríamos": "apachorrar",
    "apachorraríeis": "apachorrar",
    "apachorras": "apachorrar",
    "apachorrasse": "apachorrar",
    "apachorrassem": "apachorrar",
    "apachorrasses": "apachorrar",
    "apachorraste": "apachorrar",
    "apachorrastes": "apachorrar",
    "apachorrava": "apachorrar",
    "apachorravam": "apachorrar",
    "apachorravas": "apachorrar",
    "apachorre": "apachorrar",
    "apachorrei": "apachorrar",
    "apachorreis": "apachorrar",
    "apachorrem": "apachorrar",
    "apachorremo": "apachorrar",
    "apachorremos": "apachorrar",
    "apachorres": "apachorrar",
    "apachorro": "apachorrar",
    "apachorrou": "apachorrar",
    "apachorrá": "apachorrar",
    "apachorrámo": "apachorrar",
    "apachorrámos": "apachorrar",
    "apachorráramo": "apachorrar",
    "apachorráramos": "apachorrar",
    "apachorrárei": "apachorrar",
    "apachorráreis": "apachorrar",
    "apachorrásseis": "apachorrar",
    "apachorrássemos": "apachorrar",
    "apachorrávamo": "apachorrar",
    "apachorrávamos": "apachorrar",
    "apachorrávei": "apachorrar",
    "apachorráveis": "apachorrar",
    "apadrinha": "apadrinhar",
    "apadrinhada": "apadrinhar",
    "apadrinhadas": "apadrinhar",
    "apadrinhado": "apadrinhar",
    "apadrinhadora": "apadrinhador",
    "apadrinhadoras": "apadrinhador",
    "apadrinhadores": "apadrinhador",
    "apadrinhados": "apadrinhar",
    "apadrinhadíssima": "apadrinhado",
    "apadrinhadíssimas": "apadrinhado",
    "apadrinhadíssimo": "apadrinhado",
    "apadrinhadíssimos": "apadrinhado",
    "apadrinhai": "apadrinhar",
    "apadrinhais": "apadrinhar",
    "apadrinham": "apadrinhar",
    "apadrinhamentos": "apadrinhamento",
    "apadrinhamo": "apadrinhar",
    "apadrinhamos": "apadrinhar",
    "apadrinhando": "apadrinhar",
    "apadrinhara": "apadrinhar",
    "apadrinharam": "apadrinhar",
    "apadrinharas": "apadrinhar",
    "apadrinharde": "apadrinhar",
    "apadrinhardes": "apadrinhar",
    "apadrinhare": "apadrinhar",
    "apadrinharei": "apadrinhar",
    "apadrinhareis": "apadrinhar",
    "apadrinharem": "apadrinhar",
    "apadrinharemos": "apadrinhar",
    "apadrinhares": "apadrinhar",
    "apadrinharia": "apadrinhar",
    "apadrinhariam": "apadrinhar",
    "apadrinharias": "apadrinhar",
    "apadrinharmo": "apadrinhar",
    "apadrinharmos": "apadrinhar",
    "apadrinhará": "apadrinhar",
    "apadrinharás": "apadrinhar",
    "apadrinharão": "apadrinhar",
    "apadrinharíamos": "apadrinhar",
    "apadrinharíeis": "apadrinhar",
    "apadrinhas": "apadrinhar",
    "apadrinhasse": "apadrinhar",
    "apadrinhassem": "apadrinhar",
    "apadrinhasses": "apadrinhar",
    "apadrinhaste": "apadrinhar",
    "apadrinhastes": "apadrinhar",
    "apadrinhava": "apadrinhar",
    "apadrinhavam": "apadrinhar",
    "apadrinhavas": "apadrinhar",
    "apadrinhe": "apadrinhar",
    "apadrinhei": "apadrinhar",
    "apadrinheis": "apadrinhar",
    "apadrinhem": "apadrinhar",
    "apadrinhemo": "apadrinhar",
    "apadrinhemos": "apadrinhar",
    "apadrinhes": "apadrinhar",
    "apadrinho": "apadrinhar",
    "apadrinhou": "apadrinhar",
    "apadrinhá": "apadrinhar",
    "apadrinhámo": "apadrinhar",
    "apadrinhámos": "apadrinhar",
    "apadrinháramo": "apadrinhar",
    "apadrinháramos": "apadrinhar",
    "apadrinhárei": "apadrinhar",
    "apadrinháreis": "apadrinhar",
    "apadrinhásseis": "apadrinhar",
    "apadrinhássemos": "apadrinhar",
    "apadrinhávamo": "apadrinhar",
    "apadrinhávamos": "apadrinhar",
    "apadrinhávei": "apadrinhar",
    "apadrinháveis": "apadrinhar",
    "apadroa": "apadroar",
    "apadroada": "apadroar",
    "apadroadas": "apadroar",
    "apadroado": "apadroar",
    "apadroados": "apadroar",
    "apadroai": "apadroar",
    "apadroais": "apadroar",
    "apadroam": "apadroar",
    "apadroamo": "apadroar",
    "apadroamos": "apadroar",
    "apadroando": "apadroar",
    "apadroara": "apadroar",
    "apadroaram": "apadroar",
    "apadroaras": "apadroar",
    "apadroarde": "apadroar",
    "apadroardes": "apadroar",
    "apadroare": "apadroar",
    "apadroarei": "apadroar",
    "apadroareis": "apadroar",
    "apadroarem": "apadroar",
    "apadroaremos": "apadroar",
    "apadroares": "apadroar",
    "apadroaria": "apadroar",
    "apadroariam": "apadroar",
    "apadroarias": "apadroar",
    "apadroarmo": "apadroar",
    "apadroarmos": "apadroar",
    "apadroará": "apadroar",
    "apadroarás": "apadroar",
    "apadroarão": "apadroar",
    "apadroaríamos": "apadroar",
    "apadroaríeis": "apadroar",
    "apadroas": "apadroar",
    "apadroasse": "apadroar",
    "apadroassem": "apadroar",
    "apadroasses": "apadroar",
    "apadroaste": "apadroar",
    "apadroastes": "apadroar",
    "apadroava": "apadroar",
    "apadroavam": "apadroar",
    "apadroavas": "apadroar",
    "apadroe": "apadroar",
    "apadroei": "apadroar",
    "apadroeis": "apadroar",
    "apadroem": "apadroar",
    "apadroemo": "apadroar",
    "apadroemos": "apadroar",
    "apadroes": "apadroar",
    "apadroo": "apadroar",
    "apadroou": "apadroar",
    "apadroá": "apadroar",
    "apadroámo": "apadroar",
    "apadroámos": "apadroar",
    "apadroáramo": "apadroar",
    "apadroáramos": "apadroar",
    "apadroárei": "apadroar",
    "apadroáreis": "apadroar",
    "apadroásseis": "apadroar",
    "apadroássemos": "apadroar",
    "apadroávamo": "apadroar",
    "apadroávamos": "apadroar",
    "apadroávei": "apadroar",
    "apadroáveis": "apadroar",
    "apaga": "apagar",
    "apagada": "apagar",
    "apagadas": "apagar",
    "apagadinha": "apagado",
    "apagadinhas": "apagado",
    "apagadinho": "apagado",
    "apagadinhos": "apagado",
    "apagadita": "apagado",
    "apagaditas": "apagado",
    "apagadito": "apagado",
    "apagaditos": "apagado",
    "apagado": "apagar",
    "apagadores": "apagador",
    "apagados": "apagar",
    "apagadíssima": "apagado",
    "apagadíssimas": "apagado",
    "apagadíssimo": "apagado",
    "apagadíssimos": "apagado",
    "apagai": "apagar",
    "apagais": "apagar",
    "apagam": "apagar",
    "apagamentos": "apagamento",
    "apagamo": "apagar",
    "apagamos": "apagar",
    "apagando": "apagar",
    "apagara": "apagar",
    "apagaram": "apagar",
    "apagaras": "apagar",
    "apagarde": "apagar",
    "apagardes": "apagar",
    "apagare": "apagar",
    "apagarei": "apagar",
    "apagareis": "apagar",
    "apagarem": "apagar",
    "apagaremos": "apagar",
    "apagares": "apagar",
    "apagaria": "apagar",
    "apagariam": "apagar",
    "apagarias": "apagar",
    "apagarmo": "apagar",
    "apagarmos": "apagar",
    "apagará": "apagar",
    "apagarás": "apagar",
    "apagarão": "apagar",
    "apagaríamos": "apagar",
    "apagaríeis": "apagar",
    "apagas": "apagar",
    "apagasse": "apagar",
    "apagassem": "apagar",
    "apagasses": "apagar",
    "apagaste": "apagar",
    "apagastes": "apagar",
    "apagava": "apagar",
    "apagavam": "apagar",
    "apagavas": "apagar",
    "apago": "apagar",
    "apagogias": "apagogia",
    "apagou": "apagar",
    "apague": "apagar",
    "apaguei": "apagar",
    "apagueis": "apagar",
    "apaguem": "apagar",
    "apaguemo": "apagar",
    "apaguemos": "apagar",
    "apagues": "apagar",
    "apagá": "apagar",
    "apagámo": "apagar",
    "apagámos": "apagar",
    "apagáramo": "apagar",
    "apagáramos": "apagar",
    "apagárei": "apagar",
    "apagáreis": "apagar",
    "apagásseis": "apagar",
    "apagássemos": "apagar",
    "apagávamo": "apagar",
    "apagávamos": "apagar",
    "apagávei": "apagar",
    "apagáveis": "apagar",
    "apagões": "apagão",
    "apaija": "apaijar",
    "apaijada": "apaijar",
    "apaijadas": "apaijar",
    "apaijado": "apaijar",
    "apaijados": "apaijar",
    "apaijai": "apaijar",
    "apaijais": "apaijar",
    "apaijam": "apaijar",
    "apaijamo": "apaijar",
    "apaijamos": "apaijar",
    "apaijando": "apaijar",
    "apaijara": "apaijar",
    "apaijaram": "apaijar",
    "apaijaras": "apaijar",
    "apaijarde": "apaijar",
    "apaijardes": "apaijar",
    "apaijare": "apaijar",
    "apaijarei": "apaijar",
    "apaijareis": "apaijar",
    "apaijarem": "apaijar",
    "apaijaremos": "apaijar",
    "apaijares": "apaijar",
    "apaijaria": "apaijar",
    "apaijariam": "apaijar",
    "apaijarias": "apaijar",
    "apaijarmo": "apaijar",
    "apaijarmos": "apaijar",
    "apaijará": "apaijar",
    "apaijarás": "apaijar",
    "apaijarão": "apaijar",
    "apaijaríamos": "apaijar",
    "apaijaríeis": "apaijar",
    "apaijas": "apaijar",
    "apaijasse": "apaijar",
    "apaijassem": "apaijar",
    "apaijasses": "apaijar",
    "apaijaste": "apaijar",
    "apaijastes": "apaijar",
    "apaijava": "apaijar",
    "apaijavam": "apaijar",
    "apaijavas": "apaijar",
    "apaije": "apaijar",
    "apaijei": "apaijar",
    "apaijeis": "apaijar",
    "apaijem": "apaijar",
    "apaijemo": "apaijar",
    "apaijemos": "apaijar",
    "apaijes": "apaijar",
    "apaijo": "apaijar",
    "apaijou": "apaijar",
    "apaijá": "apaijar",
    "apaijámo": "apaijar",
    "apaijámos": "apaijar",
    "apaijáramo": "apaijar",
    "apaijáramos": "apaijar",
    "apaijárei": "apaijar",
    "apaijáreis": "apaijar",
    "apaijásseis": "apaijar",
    "apaijássemos": "apaijar",
    "apaijávamo": "apaijar",
    "apaijávamos": "apaijar",
    "apaijávei": "apaijar",
    "apaijáveis": "apaijar",
    "apainela": "apainelar",
    "apainelada": "apainelar",
    "apaineladas": "apainelar",
    "apainelado": "apainelar",
    "apainelados": "apainelar",
    "apainelai": "apainelar",
    "apainelais": "apainelar",
    "apainelam": "apainelar",
    "apainelamentos": "apainelamento",
    "apainelamo": "apainelar",
    "apainelamos": "apainelar",
    "apainelando": "apainelar",
    "apainelara": "apainelar",
    "apainelaram": "apainelar",
    "apainelaras": "apainelar",
    "apainelarde": "apainelar",
    "apainelardes": "apainelar",
    "apainelare": "apainelar",
    "apainelarei": "apainelar",
    "apainelareis": "apainelar",
    "apainelarem": "apainelar",
    "apainelaremos": "apainelar",
    "apainelares": "apainelar",
    "apainelaria": "apainelar",
    "apainelariam": "apainelar",
    "apainelarias": "apainelar",
    "apainelarmo": "apainelar",
    "apainelarmos": "apainelar",
    "apainelará": "apainelar",
    "apainelarás": "apainelar",
    "apainelarão": "apainelar",
    "apainelaríamos": "apainelar",
    "apainelaríeis": "apainelar",
    "apainelas": "apainelar",
    "apainelasse": "apainelar",
    "apainelassem": "apainelar",
    "apainelasses": "apainelar",
    "apainelaste": "apainelar",
    "apainelastes": "apainelar",
    "apainelava": "apainelar",
    "apainelavam": "apainelar",
    "apainelavas": "apainelar",
    "apainele": "apainelar",
    "apainelei": "apainelar",
    "apaineleis": "apainelar",
    "apainelem": "apainelar",
    "apainelemo": "apainelar",
    "apainelemos": "apainelar",
    "apaineles": "apainelar",
    "apainelo": "apainelar",
    "apainelou": "apainelar",
    "apainelá": "apainelar",
    "apainelámo": "apainelar",
    "apainelámos": "apainelar",
    "apaineláramo": "apainelar",
    "apaineláramos": "apainelar",
    "apainelárei": "apainelar",
    "apaineláreis": "apainelar",
    "apainelásseis": "apainelar",
    "apainelássemos": "apainelar",
    "apainelávamo": "apainelar",
    "apainelávamos": "apainelar",
    "apainelávei": "apainelar",
    "apaineláveis": "apainelar",
    "apaiola": "apaiolar",
    "apaiolada": "apaiolar",
    "apaioladas": "apaiolar",
    "apaiolado": "apaiolar",
    "apaiolados": "apaiolar",
    "apaiolai": "apaiolar",
    "apaiolais": "apaiolar",
    "apaiolam": "apaiolar",
    "apaiolamo": "apaiolar",
    "apaiolamos": "apaiolar",
    "apaiolando": "apaiolar",
    "apaiolara": "apaiolar",
    "apaiolaram": "apaiolar",
    "apaiolaras": "apaiolar",
    "apaiolarde": "apaiolar",
    "apaiolardes": "apaiolar",
    "apaiolare": "apaiolar",
    "apaiolarei": "apaiolar",
    "apaiolareis": "apaiolar",
    "apaiolarem": "apaiolar",
    "apaiolaremos": "apaiolar",
    "apaiolares": "apaiolar",
    "apaiolaria": "apaiolar",
    "apaiolariam": "apaiolar",
    "apaiolarias": "apaiolar",
    "apaiolarmo": "apaiolar",
    "apaiolarmos": "apaiolar",
    "apaiolará": "apaiolar",
    "apaiolarás": "apaiolar",
    "apaiolarão": "apaiolar",
    "apaiolaríamos": "apaiolar",
    "apaiolaríeis": "apaiolar",
    "apaiolas": "apaiolar",
    "apaiolasse": "apaiolar",
    "apaiolassem": "apaiolar",
    "apaiolasses": "apaiolar",
    "apaiolaste": "apaiolar",
    "apaiolastes": "apaiolar",
    "apaiolava": "apaiolar",
    "apaiolavam": "apaiolar",
    "apaiolavas": "apaiolar",
    "apaiole": "apaiolar",
    "apaiolei": "apaiolar",
    "apaioleis": "apaiolar",
    "apaiolem": "apaiolar",
    "apaiolemo": "apaiolar",
    "apaiolemos": "apaiolar",
    "apaioles": "apaiolar",
    "apaiolo": "apaiolar",
    "apaiolou": "apaiolar",
    "apaiolá": "apaiolar",
    "apaiolámo": "apaiolar",
    "apaiolámos": "apaiolar",
    "apaioláramo": "apaiolar",
    "apaioláramos": "apaiolar",
    "apaiolárei": "apaiolar",
    "apaioláreis": "apaiolar",
    "apaiolásseis": "apaiolar",
    "apaiolássemos": "apaiolar",
    "apaiolávamo": "apaiolar",
    "apaiolávamos": "apaiolar",
    "apaiolávei": "apaiolar",
    "apaioláveis": "apaiolar",
    "apaisa": "apaisar",
    "apaisada": "apaisar",
    "apaisadas": "apaisar",
    "apaisado": "apaisar",
    "apaisados": "apaisar",
    "apaisai": "apaisar",
    "apaisais": "apaisar",
    "apaisam": "apaisar",
    "apaisamo": "apaisar",
    "apaisamos": "apaisar",
    "apaisana": "apaisanar",
    "apaisanada": "apaisanar",
    "apaisanadas": "apaisanar",
    "apaisanado": "apaisanar",
    "apaisanados": "apaisanar",
    "apaisanai": "apaisanar",
    "apaisanais": "apaisanar",
    "apaisanam": "apaisanar",
    "apaisanamo": "apaisanar",
    "apaisanamos": "apaisanar",
    "apaisanando": "apaisanar",
    "apaisanara": "apaisanar",
    "apaisanaram": "apaisanar",
    "apaisanaras": "apaisanar",
    "apaisanarde": "apaisanar",
    "apaisanardes": "apaisanar",
    "apaisanare": "apaisanar",
    "apaisanarei": "apaisanar",
    "apaisanareis": "apaisanar",
    "apaisanarem": "apaisanar",
    "apaisanaremos": "apaisanar",
    "apaisanares": "apaisanar",
    "apaisanaria": "apaisanar",
    "apaisanariam": "apaisanar",
    "apaisanarias": "apaisanar",
    "apaisanarmo": "apaisanar",
    "apaisanarmos": "apaisanar",
    "apaisanará": "apaisanar",
    "apaisanarás": "apaisanar",
    "apaisanarão": "apaisanar",
    "apaisanaríamos": "apaisanar",
    "apaisanaríeis": "apaisanar",
    "apaisanas": "apaisanar",
    "apaisanasse": "apaisanar",
    "apaisanassem": "apaisanar",
    "apaisanasses": "apaisanar",
    "apaisanaste": "apaisanar",
    "apaisanastes": "apaisanar",
    "apaisanava": "apaisanar",
    "apaisanavam": "apaisanar",
    "apaisanavas": "apaisanar",
    "apaisando": "apaisar",
    "apaisane": "apaisanar",
    "apaisanei": "apaisanar",
    "apaisaneis": "apaisanar",
    "apaisanem": "apaisanar",
    "apaisanemo": "apaisanar",
    "apaisanemos": "apaisanar",
    "apaisanes": "apaisanar",
    "apaisano": "apaisanar",
    "apaisanou": "apaisanar",
    "apaisaná": "apaisanar",
    "apaisanámo": "apaisanar",
    "apaisanámos": "apaisanar",
    "apaisanáramo": "apaisanar",
    "apaisanáramos": "apaisanar",
    "apaisanárei": "apaisanar",
    "apaisanáreis": "apaisanar",
    "apaisanásseis": "apaisanar",
    "apaisanássemos": "apaisanar",
    "apaisanávamo": "apaisanar",
    "apaisanávamos": "apaisanar",
    "apaisanávei": "apaisanar",
    "apaisanáveis": "apaisanar",
    "apaisara": "apaisar",
    "apaisaram": "apaisar",
    "apaisaras": "apaisar",
    "apaisarde": "apaisar",
    "apaisardes": "apaisar",
    "apaisare": "apaisar",
    "apaisarei": "apaisar",
    "apaisareis": "apaisar",
    "apaisarem": "apaisar",
    "apaisaremos": "apaisar",
    "apaisares": "apaisar",
    "apaisaria": "apaisar",
    "apaisariam": "apaisar",
    "apaisarias": "apaisar",
    "apaisarmo": "apaisar",
    "apaisarmos": "apaisar",
    "apaisará": "apaisar",
    "apaisarás": "apaisar",
    "apaisarão": "apaisar",
    "apaisaríamos": "apaisar",
    "apaisaríeis": "apaisar",
    "apaisas": "apaisar",
    "apaisasse": "apaisar",
    "apaisassem": "apaisar",
    "apaisasses": "apaisar",
    "apaisaste": "apaisar",
    "apaisastes": "apaisar",
    "apaisava": "apaisar",
    "apaisavam": "apaisar",
    "apaisavas": "apaisar",
    "apaise": "apaisar",
    "apaisei": "apaisar",
    "apaiseis": "apaisar",
    "apaisem": "apaisar",
    "apaisemo": "apaisar",
    "apaisemos": "apaisar",
    "apaises": "apaisar",
    "apaiso": "apaisar",
    "apaisou": "apaisar",
    "apaisá": "apaisar",
    "apaisámo": "apaisar",
    "apaisámos": "apaisar",
    "apaisáramo": "apaisar",
    "apaisáramos": "apaisar",
    "apaisárei": "apaisar",
    "apaisáreis": "apaisar",
    "apaisásseis": "apaisar",
    "apaisássemos": "apaisar",
    "apaisávamo": "apaisar",
    "apaisávamos": "apaisar",
    "apaisávei": "apaisar",
    "apaisáveis": "apaisar",
    "apaixona": "apaixonar",
    "apaixonada": "apaixonar",
    "apaixonadas": "apaixonar",
    "apaixonadinha": "apaixonado",
    "apaixonadinhas": "apaixonado",
    "apaixonadinho": "apaixonado",
    "apaixonadinhos": "apaixonado",
    "apaixonadita": "apaixonado",
    "apaixonaditas": "apaixonado",
    "apaixonadito": "apaixonado",
    "apaixonaditos": "apaixonado",
    "apaixonadiça": "apaixonadiço",
    "apaixonadiças": "apaixonadiço",
    "apaixonadiços": "apaixonadiço",
    "apaixonado": "apaixonar",
    "apaixonados": "apaixonar",
    "apaixonadíssima": "apaixonado",
    "apaixonadíssimas": "apaixonado",
    "apaixonadíssimo": "apaixonado",
    "apaixonadíssimos": "apaixonado",
    "apaixonai": "apaixonar",
    "apaixonais": "apaixonar",
    "apaixonam": "apaixonar",
    "apaixonamo": "apaixonar",
    "apaixonamos": "apaixonar",
    "apaixonando": "apaixonar",
    "apaixonantes": "apaixonante",
    "apaixonara": "apaixonar",
    "apaixonaram": "apaixonar",
    "apaixonaras": "apaixonar",
    "apaixonarde": "apaixonar",
    "apaixonardes": "apaixonar",
    "apaixonare": "apaixonar",
    "apaixonarei": "apaixonar",
    "apaixonareis": "apaixonar",
    "apaixonarem": "apaixonar",
    "apaixonaremos": "apaixonar",
    "apaixonares": "apaixonar",
    "apaixonaria": "apaixonar",
    "apaixonariam": "apaixonar",
    "apaixonarias": "apaixonar",
    "apaixonarmo": "apaixonar",
    "apaixonarmos": "apaixonar",
    "apaixonará": "apaixonar",
    "apaixonarás": "apaixonar",
    "apaixonarão": "apaixonar",
    "apaixonaríamos": "apaixonar",
    "apaixonaríeis": "apaixonar",
    "apaixonas": "apaixonar",
    "apaixonasse": "apaixonar",
    "apaixonassem": "apaixonar",
    "apaixonasses": "apaixonar",
    "apaixonaste": "apaixonar",
    "apaixonastes": "apaixonar",
    "apaixonava": "apaixonar",
    "apaixonavam": "apaixonar",
    "apaixonavas": "apaixonar",
    "apaixone": "apaixonar",
    "apaixonei": "apaixonar",
    "apaixoneis": "apaixonar",
    "apaixonem": "apaixonar",
    "apaixonemo": "apaixonar",
    "apaixonemos": "apaixonar",
    "apaixones": "apaixonar",
    "apaixono": "apaixonar",
    "apaixonou": "apaixonar",
    "apaixoná": "apaixonar",
    "apaixonámo": "apaixonar",
    "apaixonámos": "apaixonar",
    "apaixonáramo": "apaixonar",
    "apaixonáramos": "apaixonar",
    "apaixonárei": "apaixonar",
    "apaixonáreis": "apaixonar",
    "apaixonásseis": "apaixonar",
    "apaixonássemos": "apaixonar",
    "apaixonávamo": "apaixonar",
    "apaixonávamos": "apaixonar",
    "apaixonávei": "apaixonar",
    "apaixonáveis": "apaixonar",
    "apaja": "apajar",
    "apajada": "apajar",
    "apajadas": "apajar",
    "apajado": "apajar",
    "apajados": "apajar",
    "apajai": "apajar",
    "apajais": "apajar",
    "apajam": "apajar",
    "apajamo": "apajar",
    "apajamos": "apajar",
    "apajando": "apajar",
    "apajara": "apajar",
    "apajaram": "apajar",
    "apajaras": "apajar",
    "apajarde": "apajar",
    "apajardes": "apajar",
    "apajare": "apajar",
    "apajarei": "apajar",
    "apajareis": "apajar",
    "apajarem": "apajar",
    "apajaremos": "apajar",
    "apajares": "apajar",
    "apajaria": "apajar",
    "apajariam": "apajar",
    "apajarias": "apajar",
    "apajarmo": "apajar",
    "apajarmos": "apajar",
    "apajará": "apajar",
    "apajarás": "apajar",
    "apajarão": "apajar",
    "apajaríamos": "apajar",
    "apajaríeis": "apajar",
    "apajas": "apajar",
    "apajasse": "apajar",
    "apajassem": "apajar",
    "apajasses": "apajar",
    "apajaste": "apajar",
    "apajastes": "apajar",
    "apajava": "apajar",
    "apajavam": "apajar",
    "apajavas": "apajar",
    "apaje": "apajar",
    "apajeada": "apajear",
    "apajeadas": "apajear",
    "apajeado": "apajear",
    "apajeados": "apajear",
    "apajeai": "apajear",
    "apajeais": "apajear",
    "apajeamo": "apajear",
    "apajeamos": "apajear",
    "apajeando": "apajear",
    "apajeara": "apajear",
    "apajearam": "apajear",
    "apajearas": "apajear",
    "apajearde": "apajear",
    "apajeardes": "apajear",
    "apajeare": "apajear",
    "apajearei": "apajear",
    "apajeareis": "apajear",
    "apajearem": "apajear",
    "apajearemos": "apajear",
    "apajeares": "apajear",
    "apajearia": "apajear",
    "apajeariam": "apajear",
    "apajearias": "apajear",
    "apajearmo": "apajear",
    "apajearmos": "apajear",
    "apajeará": "apajear",
    "apajearás": "apajear",
    "apajearão": "apajear",
    "apajearíamos": "apajear",
    "apajearíeis": "apajear",
    "apajeasse": "apajear",
    "apajeassem": "apajear",
    "apajeasses": "apajear",
    "apajeaste": "apajear",
    "apajeastes": "apajear",
    "apajeava": "apajear",
    "apajeavam": "apajear",
    "apajeavas": "apajear",
    "apajeei": "apajear",
    "apajeeis": "apajear",
    "apajeemo": "apajear",
    "apajeemos": "apajear",
    "apajei": "apajar",
    "apajeia": "apajear",
    "apajeiam": "apajear",
    "apajeias": "apajear",
    "apajeie": "apajear",
    "apajeiem": "apajear",
    "apajeies": "apajear",
    "apajeio": "apajear",
    "apajeis": "apajar",
    "apajem": "apajar",
    "apajemo": "apajar",
    "apajemos": "apajar",
    "apajeou": "apajear",
    "apajes": "apajar",
    "apajeá": "apajear",
    "apajeámo": "apajear",
    "apajeámos": "apajear",
    "apajeáramo": "apajear",
    "apajeáramos": "apajear",
    "apajeárei": "apajear",
    "apajeáreis": "apajear",
    "apajeásseis": "apajear",
    "apajeássemos": "apajear",
    "apajeávamo": "apajear",
    "apajeávamos": "apajear",
    "apajeávei": "apajear",
    "apajeáveis": "apajear",
    "apajo": "apajar",
    "apajou": "apajar",
    "apajá": "apajar",
    "apajámo": "apajar",
    "apajámos": "apajar",
    "apajáramo": "apajar",
    "apajáramos": "apajar",
    "apajárei": "apajar",
    "apajáreis": "apajar",
    "apajásseis": "apajar",
    "apajássemos": "apajar",
    "apajávamo": "apajar",
    "apajávamos": "apajar",
    "apajávei": "apajar",
    "apajáveis": "apajar",
    "apalace": "apalaçar",
    "apalacei": "apalaçar",
    "apalaceis": "apalaçar",
    "apalacem": "apalaçar",
    "apalacemo": "apalaçar",
    "apalacemos": "apalaçar",
    "apalaces": "apalaçar",
    "apalaciana": "apalacianar",
    "apalacianada": "apalacianar",
    "apalacianadas": "apalacianar",
    "apalacianado": "apalacianar",
    "apalacianados": "apalacianar",
    "apalacianai": "apalacianar",
    "apalacianais": "apalacianar",
    "apalacianam": "apalacianar",
    "apalacianamo": "apalacianar",
    "apalacianamos": "apalacianar",
    "apalacianando": "apalacianar",
    "apalacianara": "apalacianar",
    "apalacianaram": "apalacianar",
    "apalacianaras": "apalacianar",
    "apalacianarde": "apalacianar",
    "apalacianardes": "apalacianar",
    "apalacianare": "apalacianar",
    "apalacianarei": "apalacianar",
    "apalacianareis": "apalacianar",
    "apalacianarem": "apalacianar",
    "apalacianaremos": "apalacianar",
    "apalacianares": "apalacianar",
    "apalacianaria": "apalacianar",
    "apalacianariam": "apalacianar",
    "apalacianarias": "apalacianar",
    "apalacianarmo": "apalacianar",
    "apalacianarmos": "apalacianar",
    "apalacianará": "apalacianar",
    "apalacianarás": "apalacianar",
    "apalacianarão": "apalacianar",
    "apalacianaríamos": "apalacianar",
    "apalacianaríeis": "apalacianar",
    "apalacianas": "apalacianar",
    "apalacianasse": "apalacianar",
    "apalacianassem": "apalacianar",
    "apalacianasses": "apalacianar",
    "apalacianaste": "apalacianar",
    "apalacianastes": "apalacianar",
    "apalacianava": "apalacianar",
    "apalacianavam": "apalacianar",
    "apalacianavas": "apalacianar",
    "apalaciane": "apalacianar",
    "apalacianei": "apalacianar",
    "apalacianeis": "apalacianar",
    "apalacianem": "apalacianar",
    "apalacianemo": "apalacianar",
    "apalacianemos": "apalacianar",
    "apalacianes": "apalacianar",
    "apalaciano": "apalacianar",
    "apalacianou": "apalacianar",
    "apalacianá": "apalacianar",
    "apalacianámo": "apalacianar",
    "apalacianámos": "apalacianar",
    "apalacianáramo": "apalacianar",
    "apalacianáramos": "apalacianar",
    "apalacianárei": "apalacianar",
    "apalacianáreis": "apalacianar",
    "apalacianásseis": "apalacianar",
    "apalacianássemos": "apalacianar",
    "apalacianávamo": "apalacianar",
    "apalacianávamos": "apalacianar",
    "apalacianávei": "apalacianar",
    "apalacianáveis": "apalacianar",
    "apalada": "apaladar",
    "apaladada": "apaladar",
    "apaladadas": "apaladar",
    "apaladado": "apaladar",
    "apaladados": "apaladar",
    "apaladai": "apaladar",
    "apaladais": "apaladar",
    "apaladam": "apaladar",
    "apaladamo": "apaladar",
    "apaladamos": "apaladar",
    "apaladando": "apaladar",
    "apaladara": "apaladar",
    "apaladaram": "apaladar",
    "apaladaras": "apaladar",
    "apaladarde": "apaladar",
    "apaladardes": "apaladar",
    "apaladare": "apaladar",
    "apaladarei": "apaladar",
    "apaladareis": "apaladar",
    "apaladarem": "apaladar",
    "apaladaremos": "apaladar",
    "apaladares": "apaladar",
    "apaladaria": "apaladar",
    "apaladariam": "apaladar",
    "apaladarias": "apaladar",
    "apaladarmo": "apaladar",
    "apaladarmos": "apaladar",
    "apaladará": "apaladar",
    "apaladarás": "apaladar",
    "apaladarão": "apaladar",
    "apaladaríamos": "apaladar",
    "apaladaríeis": "apaladar",
    "apaladas": "apaladar",
    "apaladasse": "apaladar",
    "apaladassem": "apaladar",
    "apaladasses": "apaladar",
    "apaladaste": "apaladar",
    "apaladastes": "apaladar",
    "apaladava": "apaladar",
    "apaladavam": "apaladar",
    "apaladavas": "apaladar",
    "apalade": "apaladar",
    "apaladei": "apaladar",
    "apaladeis": "apaladar",
    "apaladem": "apaladar",
    "apalademo": "apaladar",
    "apalademos": "apaladar",
    "apalades": "apaladar",
    "apalado": "apaladar",
    "apaladou": "apaladar",
    "apaladá": "apaladar",
    "apaladámo": "apaladar",
    "apaladámos": "apaladar",
    "apaladáramo": "apaladar",
    "apaladáramos": "apaladar",
    "apaladárei": "apaladar",
    "apaladáreis": "apaladar",
    "apaladásseis": "apaladar",
    "apaladássemos": "apaladar",
    "apaladávamo": "apaladar",
    "apaladávamos": "apaladar",
    "apaladávei": "apaladar",
    "apaladáveis": "apaladar",
    "apalanca": "apalancar",
    "apalancada": "apalancar",
    "apalancadas": "apalancar",
    "apalancado": "apalancar",
    "apalancados": "apalancar",
    "apalancai": "apalancar",
    "apalancais": "apalancar",
    "apalancam": "apalancar",
    "apalancamo": "apalancar",
    "apalancamos": "apalancar",
    "apalancando": "apalancar",
    "apalancara": "apalancar",
    "apalancaram": "apalancar",
    "apalancaras": "apalancar",
    "apalancarde": "apalancar",
    "apalancardes": "apalancar",
    "apalancare": "apalancar",
    "apalancarei": "apalancar",
    "apalancareis": "apalancar",
    "apalancarem": "apalancar",
    "apalancaremos": "apalancar",
    "apalancares": "apalancar",
    "apalancaria": "apalancar",
    "apalancariam": "apalancar",
    "apalancarias": "apalancar",
    "apalancarmo": "apalancar",
    "apalancarmos": "apalancar",
    "apalancará": "apalancar",
    "apalancarás": "apalancar",
    "apalancarão": "apalancar",
    "apalancaríamos": "apalancar",
    "apalancaríeis": "apalancar",
    "apalancas": "apalancar",
    "apalancasse": "apalancar",
    "apalancassem": "apalancar",
    "apalancasses": "apalancar",
    "apalancaste": "apalancar",
    "apalancastes": "apalancar",
    "apalancava": "apalancar",
    "apalancavam": "apalancar",
    "apalancavas": "apalancar",
    "apalanco": "apalancar",
    "apalancou": "apalancar",
    "apalancá": "apalancar",
    "apalancámo": "apalancar",
    "apalancámos": "apalancar",
    "apalancáramo": "apalancar",
    "apalancáramos": "apalancar",
    "apalancárei": "apalancar",
    "apalancáreis": "apalancar",
    "apalancásseis": "apalancar",
    "apalancássemos": "apalancar",
    "apalancávamo": "apalancar",
    "apalancávamos": "apalancar",
    "apalancávei": "apalancar",
    "apalancáveis": "apalancar",
    "apalanque": "apalancar",
    "apalanquei": "apalancar",
    "apalanqueis": "apalancar",
    "apalanquem": "apalancar",
    "apalanquemo": "apalancar",
    "apalanquemos": "apalancar",
    "apalanques": "apalancar",
    "apalavra": "apalavrar",
    "apalavrada": "apalavrar",
    "apalavradas": "apalavrar",
    "apalavrado": "apalavrar",
    "apalavrados": "apalavrar",
    "apalavrai": "apalavrar",
    "apalavrais": "apalavrar",
    "apalavram": "apalavrar",
    "apalavramo": "apalavrar",
    "apalavramos": "apalavrar",
    "apalavrando": "apalavrar",
    "apalavrara": "apalavrar",
    "apalavraram": "apalavrar",
    "apalavraras": "apalavrar",
    "apalavrarde": "apalavrar",
    "apalavrardes": "apalavrar",
    "apalavrare": "apalavrar",
    "apalavrarei": "apalavrar",
    "apalavrareis": "apalavrar",
    "apalavrarem": "apalavrar",
    "apalavraremos": "apalavrar",
    "apalavrares": "apalavrar",
    "apalavraria": "apalavrar",
    "apalavrariam": "apalavrar",
    "apalavrarias": "apalavrar",
    "apalavrarmo": "apalavrar",
    "apalavrarmos": "apalavrar",
    "apalavrará": "apalavrar",
    "apalavrarás": "apalavrar",
    "apalavrarão": "apalavrar",
    "apalavraríamos": "apalavrar",
    "apalavraríeis": "apalavrar",
    "apalavras": "apalavrar",
    "apalavrasse": "apalavrar",
    "apalavrassem": "apalavrar",
    "apalavrasses": "apalavrar",
    "apalavraste": "apalavrar",
    "apalavrastes": "apalavrar",
    "apalavrava": "apalavrar",
    "apalavravam": "apalavrar",
    "apalavravas": "apalavrar",
    "apalavre": "apalavrar",
    "apalavrei": "apalavrar",
    "apalavreis": "apalavrar",
    "apalavrem": "apalavrar",
    "apalavremo": "apalavrar",
    "apalavremos": "apalavrar",
    "apalavres": "apalavrar",
    "apalavro": "apalavrar",
    "apalavrou": "apalavrar",
    "apalavrá": "apalavrar",
    "apalavrámo": "apalavrar",
    "apalavrámos": "apalavrar",
    "apalavráramo": "apalavrar",
    "apalavráramos": "apalavrar",
    "apalavrárei": "apalavrar",
    "apalavráreis": "apalavrar",
    "apalavrásseis": "apalavrar",
    "apalavrássemos": "apalavrar",
    "apalavrávamo": "apalavrar",
    "apalavrávamos": "apalavrar",
    "apalavrávei": "apalavrar",
    "apalavráveis": "apalavrar",
    "apalaça": "apalaçar",
    "apalaçada": "apalaçar",
    "apalaçadas": "apalaçar",
    "apalaçado": "apalaçar",
    "apalaçados": "apalaçar",
    "apalaçai": "apalaçar",
    "apalaçais": "apalaçar",
    "apalaçam": "apalaçar",
    "apalaçamo": "apalaçar",
    "apalaçamos": "apalaçar",
    "apalaçando": "apalaçar",
    "apalaçara": "apalaçar",
    "apalaçaram": "apalaçar",
    "apalaçaras": "apalaçar",
    "apalaçarde": "apalaçar",
    "apalaçardes": "apalaçar",
    "apalaçare": "apalaçar",
    "apalaçarei": "apalaçar",
    "apalaçareis": "apalaçar",
    "apalaçarem": "apalaçar",
    "apalaçaremos": "apalaçar",
    "apalaçares": "apalaçar",
    "apalaçaria": "apalaçar",
    "apalaçariam": "apalaçar",
    "apalaçarias": "apalaçar",
    "apalaçarmo": "apalaçar",
    "apalaçarmos": "apalaçar",
    "apalaçará": "apalaçar",
    "apalaçarás": "apalaçar",
    "apalaçarão": "apalaçar",
    "apalaçaríamos": "apalaçar",
    "apalaçaríeis": "apalaçar",
    "apalaças": "apalaçar",
    "apalaçasse": "apalaçar",
    "apalaçassem": "apalaçar",
    "apalaçasses": "apalaçar",
    "apalaçaste": "apalaçar",
    "apalaçastes": "apalaçar",
    "apalaçava": "apalaçar",
    "apalaçavam": "apalaçar",
    "apalaçavas": "apalaçar",
    "apalaço": "apalaçar",
    "apalaçou": "apalaçar",
    "apalaçá": "apalaçar",
    "apalaçámo": "apalaçar",
    "apalaçámos": "apalaçar",
    "apalaçáramo": "apalaçar",
    "apalaçáramos": "apalaçar",
    "apalaçárei": "apalaçar",
    "apalaçáreis": "apalaçar",
    "apalaçásseis": "apalaçar",
    "apalaçássemos": "apalaçar",
    "apalaçávamo": "apalaçar",
    "apalaçávamos": "apalaçar",
    "apalaçávei": "apalaçar",
    "apalaçáveis": "apalaçar",
    "apaleada": "apalear",
    "apaleadas": "apalear",
    "apaleado": "apalear",
    "apaleados": "apalear",
    "apaleai": "apalear",
    "apaleais": "apalear",
    "apaleamentos": "apaleamento",
    "apaleamo": "apalear",
    "apaleamos": "apalear",
    "apaleando": "apalear",
    "apaleara": "apalear",
    "apalearam": "apalear",
    "apalearas": "apalear",
    "apalearde": "apalear",
    "apaleardes": "apalear",
    "apaleare": "apalear",
    "apalearei": "apalear",
    "apaleareis": "apalear",
    "apalearem": "apalear",
    "apalearemos": "apalear",
    "apaleares": "apalear",
    "apalearia": "apalear",
    "apaleariam": "apalear",
    "apalearias": "apalear",
    "apalearmo": "apalear",
    "apalearmos": "apalear",
    "apaleará": "apalear",
    "apalearás": "apalear",
    "apalearão": "apalear",
    "apalearíamos": "apalear",
    "apalearíeis": "apalear",
    "apaleasse": "apalear",
    "apaleassem": "apalear",
    "apaleasses": "apalear",
    "apaleaste": "apalear",
    "apaleastes": "apalear",
    "apaleava": "apalear",
    "apaleavam": "apalear",
    "apaleavas": "apalear",
    "apaleações": "apaleação",
    "apaleei": "apalear",
    "apaleeis": "apalear",
    "apaleemo": "apalear",
    "apaleemos": "apalear",
    "apaleia": "apalear",
    "apaleiam": "apalear",
    "apaleias": "apalear",
    "apaleie": "apalear",
    "apaleiem": "apalear",
    "apaleies": "apalear",
    "apaleio": "apalear",
    "apaleou": "apalear",
    "apalerma": "apalermar",
    "apalermada": "apalermar",
    "apalermadas": "apalermar",
    "apalermado": "apalermar",
    "apalermados": "apalermar",
    "apalermai": "apalermar",
    "apalermais": "apalermar",
    "apalermam": "apalermar",
    "apalermamo": "apalermar",
    "apalermamos": "apalermar",
    "apalermando": "apalermar",
    "apalermara": "apalermar",
    "apalermaram": "apalermar",
    "apalermaras": "apalermar",
    "apalermarde": "apalermar",
    "apalermardes": "apalermar",
    "apalermare": "apalermar",
    "apalermarei": "apalermar",
    "apalermareis": "apalermar",
    "apalermarem": "apalermar",
    "apalermaremos": "apalermar",
    "apalermares": "apalermar",
    "apalermaria": "apalermar",
    "apalermariam": "apalermar",
    "apalermarias": "apalermar",
    "apalermarmo": "apalermar",
    "apalermarmos": "apalermar",
    "apalermará": "apalermar",
    "apalermarás": "apalermar",
    "apalermarão": "apalermar",
    "apalermaríamos": "apalermar",
    "apalermaríeis": "apalermar",
    "apalermas": "apalermar",
    "apalermasse": "apalermar",
    "apalermassem": "apalermar",
    "apalermasses": "apalermar",
    "apalermaste": "apalermar",
    "apalermastes": "apalermar",
    "apalermava": "apalermar",
    "apalermavam": "apalermar",
    "apalermavas": "apalermar",
    "apalerme": "apalermar",
    "apalermei": "apalermar",
    "apalermeis": "apalermar",
    "apalermem": "apalermar",
    "apalermemo": "apalermar",
    "apalermemos": "apalermar",
    "apalermes": "apalermar",
    "apalermo": "apalermar",
    "apalermou": "apalermar",
    "apalermá": "apalermar",
    "apalermámo": "apalermar",
    "apalermámos": "apalermar",
    "apalermáramo": "apalermar",
    "apalermáramos": "apalermar",
    "apalermárei": "apalermar",
    "apalermáreis": "apalermar",
    "apalermásseis": "apalermar",
    "apalermássemos": "apalermar",
    "apalermávamo": "apalermar",
    "apalermávamos": "apalermar",
    "apalermávei": "apalermar",
    "apalermáveis": "apalermar",
    "apalestra": "apalestrar",
    "apalestrada": "apalestrar",
    "apalestradas": "apalestrar",
    "apalestrado": "apalestrar",
    "apalestrados": "apalestrar",
    "apalestrai": "apalestrar",
    "apalestrais": "apalestrar",
    "apalestram": "apalestrar",
    "apalestramo": "apalestrar",
    "apalestramos": "apalestrar",
    "apalestrando": "apalestrar",
    "apalestrara": "apalestrar",
    "apalestraram": "apalestrar",
    "apalestraras": "apalestrar",
    "apalestrarde": "apalestrar",
    "apalestrardes": "apalestrar",
    "apalestrare": "apalestrar",
    "apalestrarei": "apalestrar",
    "apalestrareis": "apalestrar",
    "apalestrarem": "apalestrar",
    "apalestraremos": "apalestrar",
    "apalestrares": "apalestrar",
    "apalestraria": "apalestrar",
    "apalestrariam": "apalestrar",
    "apalestrarias": "apalestrar",
    "apalestrarmo": "apalestrar",
    "apalestrarmos": "apalestrar",
    "apalestrará": "apalestrar",
    "apalestrarás": "apalestrar",
    "apalestrarão": "apalestrar",
    "apalestraríamos": "apalestrar",
    "apalestraríeis": "apalestrar",
    "apalestras": "apalestrar",
    "apalestrasse": "apalestrar",
    "apalestrassem": "apalestrar",
    "apalestrasses": "apalestrar",
    "apalestraste": "apalestrar",
    "apalestrastes": "apalestrar",
    "apalestrava": "apalestrar",
    "apalestravam": "apalestrar",
    "apalestravas": "apalestrar",
    "apalestre": "apalestrar",
    "apalestrei": "apalestrar",
    "apalestreis": "apalestrar",
    "apalestrem": "apalestrar",
    "apalestremo": "apalestrar",
    "apalestremos": "apalestrar",
    "apalestres": "apalestrar",
    "apalestro": "apalestrar",
    "apalestrou": "apalestrar",
    "apalestrá": "apalestrar",
    "apalestrámo": "apalestrar",
    "apalestrámos": "apalestrar",
    "apalestráramo": "apalestrar",
    "apalestráramos": "apalestrar",
    "apalestrárei": "apalestrar",
    "apalestráreis": "apalestrar",
    "apalestrásseis": "apalestrar",
    "apalestrássemos": "apalestrar",
    "apalestrávamo": "apalestrar",
    "apalestrávamos": "apalestrar",
    "apalestrávei": "apalestrar",
    "apalestráveis": "apalestrar",
    "apaleá": "apalear",
    "apaleámo": "apalear",
    "apaleámos": "apalear",
    "apaleáramo": "apalear",
    "apaleáramos": "apalear",
    "apaleárei": "apalear",
    "apaleáreis": "apalear",
    "apaleásseis": "apalear",
    "apaleássemos": "apalear",
    "apaleávamo": "apalear",
    "apaleávamos": "apalear",
    "apaleávei": "apalear",
    "apaleáveis": "apalear",
    "apalhace": "apalhaçar",
    "apalhacei": "apalhaçar",
    "apalhaceis": "apalhaçar",
    "apalhacem": "apalhaçar",
    "apalhacemo": "apalhaçar",
    "apalhacemos": "apalhaçar",
    "apalhaces": "apalhaçar",
    "apalhaça": "apalhaçar",
    "apalhaçada": "apalhaçar",
    "apalhaçadas": "apalhaçar",
    "apalhaçado": "apalhaçar",
    "apalhaçados": "apalhaçar",
    "apalhaçai": "apalhaçar",
    "apalhaçais": "apalhaçar",
    "apalhaçam": "apalhaçar",
    "apalhaçamo": "apalhaçar",
    "apalhaçamos": "apalhaçar",
    "apalhaçando": "apalhaçar",
    "apalhaçara": "apalhaçar",
    "apalhaçaram": "apalhaçar",
    "apalhaçaras": "apalhaçar",
    "apalhaçarde": "apalhaçar",
    "apalhaçardes": "apalhaçar",
    "apalhaçare": "apalhaçar",
    "apalhaçarei": "apalhaçar",
    "apalhaçareis": "apalhaçar",
    "apalhaçarem": "apalhaçar",
    "apalhaçaremos": "apalhaçar",
    "apalhaçares": "apalhaçar",
    "apalhaçaria": "apalhaçar",
    "apalhaçariam": "apalhaçar",
    "apalhaçarias": "apalhaçar",
    "apalhaçarmo": "apalhaçar",
    "apalhaçarmos": "apalhaçar",
    "apalhaçará": "apalhaçar",
    "apalhaçarás": "apalhaçar",
    "apalhaçarão": "apalhaçar",
    "apalhaçaríamos": "apalhaçar",
    "apalhaçaríeis": "apalhaçar",
    "apalhaças": "apalhaçar",
    "apalhaçasse": "apalhaçar",
    "apalhaçassem": "apalhaçar",
    "apalhaçasses": "apalhaçar",
    "apalhaçaste": "apalhaçar",
    "apalhaçastes": "apalhaçar",
    "apalhaçava": "apalhaçar",
    "apalhaçavam": "apalhaçar",
    "apalhaçavas": "apalhaçar",
    "apalhaço": "apalhaçar",
    "apalhaçou": "apalhaçar",
    "apalhaçá": "apalhaçar",
    "apalhaçámo": "apalhaçar",
    "apalhaçámos": "apalhaçar",
    "apalhaçáramo": "apalhaçar",
    "apalhaçáramos": "apalhaçar",
    "apalhaçárei": "apalhaçar",
    "apalhaçáreis": "apalhaçar",
    "apalhaçásseis": "apalhaçar",
    "apalhaçássemos": "apalhaçar",
    "apalhaçávamo": "apalhaçar",
    "apalhaçávamos": "apalhaçar",
    "apalhaçávei": "apalhaçar",
    "apalhaçáveis": "apalhaçar",
    "apalma": "apalmar",
    "apalmada": "apalmar",
    "apalmadas": "apalmar",
    "apalmado": "apalmar",
    "apalmados": "apalmar",
    "apalmai": "apalmar",
    "apalmais": "apalmar",
    "apalmam": "apalmar",
    "apalmamo": "apalmar",
    "apalmamos": "apalmar",
    "apalmando": "apalmar",
    "apalmara": "apalmar",
    "apalmaram": "apalmar",
    "apalmaras": "apalmar",
    "apalmarde": "apalmar",
    "apalmardes": "apalmar",
    "apalmare": "apalmar",
    "apalmarei": "apalmar",
    "apalmareis": "apalmar",
    "apalmarem": "apalmar",
    "apalmaremos": "apalmar",
    "apalmares": "apalmar",
    "apalmaria": "apalmar",
    "apalmariam": "apalmar",
    "apalmarias": "apalmar",
    "apalmarmo": "apalmar",
    "apalmarmos": "apalmar",
    "apalmará": "apalmar",
    "apalmarás": "apalmar",
    "apalmarão": "apalmar",
    "apalmaríamos": "apalmar",
    "apalmaríeis": "apalmar",
    "apalmas": "apalmar",
    "apalmasse": "apalmar",
    "apalmassem": "apalmar",
    "apalmasses": "apalmar",
    "apalmaste": "apalmar",
    "apalmastes": "apalmar",
    "apalmava": "apalmar",
    "apalmavam": "apalmar",
    "apalmavas": "apalmar",
    "apalme": "apalmar",
    "apalmei": "apalmar",
    "apalmeis": "apalmar",
    "apalmem": "apalmar",
    "apalmemo": "apalmar",
    "apalmemos": "apalmar",
    "apalmes": "apalmar",
    "apalmo": "apalmar",
    "apalmou": "apalmar",
    "apalmá": "apalmar",
    "apalmámo": "apalmar",
    "apalmámos": "apalmar",
    "apalmáramo": "apalmar",
    "apalmáramos": "apalmar",
    "apalmárei": "apalmar",
    "apalmáreis": "apalmar",
    "apalmásseis": "apalmar",
    "apalmássemos": "apalmar",
    "apalmávamo": "apalmar",
    "apalmávamos": "apalmar",
    "apalmávei": "apalmar",
    "apalmáveis": "apalmar",
    "apalpa": "apalpar",
    "apalpada": "apalpar",
    "apalpadas": "apalpar",
    "apalpadeiras": "apalpadeira",
    "apalpadelas": "apalpadela",
    "apalpado": "apalpar",
    "apalpados": "apalpar",
    "apalpai": "apalpar",
    "apalpais": "apalpar",
    "apalpam": "apalpar",
    "apalpamentos": "apalpamento",
    "apalpamo": "apalpar",
    "apalpamos": "apalpar",
    "apalpando": "apalpar",
    "apalpanços": "apalpanço",
    "apalpara": "apalpar",
    "apalparam": "apalpar",
    "apalparas": "apalpar",
    "apalparde": "apalpar",
    "apalpardes": "apalpar",
    "apalpare": "apalpar",
    "apalparei": "apalpar",
    "apalpareis": "apalpar",
    "apalparem": "apalpar",
    "apalparemos": "apalpar",
    "apalpares": "apalpar",
    "apalparia": "apalpar",
    "apalpariam": "apalpar",
    "apalparias": "apalpar",
    "apalparmo": "apalpar",
    "apalparmos": "apalpar",
    "apalpará": "apalpar",
    "apalparás": "apalpar",
    "apalparão": "apalpar",
    "apalparíamos": "apalpar",
    "apalparíeis": "apalpar",
    "apalpas": "apalpar",
    "apalpasse": "apalpar",
    "apalpassem": "apalpar",
    "apalpasses": "apalpar",
    "apalpaste": "apalpar",
    "apalpastes": "apalpar",
    "apalpava": "apalpar",
    "apalpavam": "apalpar",
    "apalpavas": "apalpar",
    "apalpações": "apalpação",
    "apalpe": "apalpar",
    "apalpei": "apalpar",
    "apalpeis": "apalpar",
    "apalpem": "apalpar",
    "apalpemo": "apalpar",
    "apalpemos": "apalpar",
    "apalpes": "apalpar",
    "apalpo": "apalpar",
    "apalpos": "apalpo",
    "apalpou": "apalpar",
    "apalpá": "apalpar",
    "apalpámo": "apalpar",
    "apalpámos": "apalpar",
    "apalpáramo": "apalpar",
    "apalpáramos": "apalpar",
    "apalpárei": "apalpar",
    "apalpáreis": "apalpar",
    "apalpásseis": "apalpar",
    "apalpássemos": "apalpar",
    "apalpávamo": "apalpar",
    "apalpávamos": "apalpar",
    "apalpávei": "apalpar",
    "apalpáveis": "apalpável",
    "apalpões": "apalpão",
    "apanagistas": "apanagista",
    "apanca": "apancar",
    "apancada": "apancar",
    "apancadada": "apancadado",
    "apancadadas": "apancadado",
    "apancadados": "apancadado",
    "apancadas": "apancar",
    "apancado": "apancar",
    "apancados": "apancar",
    "apancai": "apancar",
    "apancais": "apancar",
    "apancam": "apancar",
    "apancamentos": "apancamento",
    "apancamo": "apancar",
    "apancamos": "apancar",
    "apancando": "apancar",
    "apancara": "apancar",
    "apancaram": "apancar",
    "apancaras": "apancar",
    "apancarde": "apancar",
    "apancardes": "apancar",
    "apancare": "apancar",
    "apancarei": "apancar",
    "apancareis": "apancar",
    "apancarem": "apancar",
    "apancaremos": "apancar",
    "apancares": "apancar",
    "apancaria": "apancar",
    "apancariam": "apancar",
    "apancarias": "apancar",
    "apancarmo": "apancar",
    "apancarmos": "apancar",
    "apancará": "apancar",
    "apancarás": "apancar",
    "apancarão": "apancar",
    "apancaríamos": "apancar",
    "apancaríeis": "apancar",
    "apancas": "apancar",
    "apancasse": "apancar",
    "apancassem": "apancar",
    "apancasses": "apancar",
    "apancaste": "apancar",
    "apancastes": "apancar",
    "apancava": "apancar",
    "apancavam": "apancar",
    "apancavas": "apancar",
    "apanco": "apancar",
    "apancou": "apancar",
    "apancá": "apancar",
    "apancámo": "apancar",
    "apancámos": "apancar",
    "apancáramo": "apancar",
    "apancáramos": "apancar",
    "apancárei": "apancar",
    "apancáreis": "apancar",
    "apancásseis": "apancar",
    "apancássemos": "apancar",
    "apancávamo": "apancar",
    "apancávamos": "apancar",
    "apancávei": "apancar",
    "apancáveis": "apancar",
    "apanda": "apandar",
    "apandada": "apandar",
    "apandadas": "apandar",
    "apandado": "apandar",
    "apandados": "apandar",
    "apandai": "apandar",
    "apandais": "apandar",
    "apandam": "apandar",
    "apandamo": "apandar",
    "apandamos": "apandar",
    "apandando": "apandar",
    "apandara": "apandar",
    "apandaram": "apandar",
    "apandaras": "apandar",
    "apandarde": "apandar",
    "apandardes": "apandar",
    "apandare": "apandar",
    "apandarei": "apandar",
    "apandareis": "apandar",
    "apandarem": "apandar",
    "apandaremos": "apandar",
    "apandares": "apandar",
    "apandaria": "apandar",
    "apandariam": "apandar",
    "apandarias": "apandar",
    "apandarmo": "apandar",
    "apandarmos": "apandar",
    "apandará": "apandar",
    "apandarás": "apandar",
    "apandarão": "apandar",
    "apandaríamos": "apandar",
    "apandaríeis": "apandar",
    "apandas": "apandar",
    "apandasse": "apandar",
    "apandassem": "apandar",
    "apandasses": "apandar",
    "apandaste": "apandar",
    "apandastes": "apandar",
    "apandava": "apandar",
    "apandavam": "apandar",
    "apandavas": "apandar",
    "apande": "apandar",
    "apandei": "apandar",
    "apandeis": "apandar",
    "apandem": "apandar",
    "apandemo": "apandar",
    "apandemos": "apandar",
    "apandes": "apandar",
    "apandilha": "apandilhar",
    "apandilhada": "apandilhar",
    "apandilhadas": "apandilhar",
    "apandilhado": "apandilhar",
    "apandilhados": "apandilhar",
    "apandilhai": "apandilhar",
    "apandilhais": "apandilhar",
    "apandilham": "apandilhar",
    "apandilhamo": "apandilhar",
    "apandilhamos": "apandilhar",
    "apandilhando": "apandilhar",
    "apandilhara": "apandilhar",
    "apandilharam": "apandilhar",
    "apandilharas": "apandilhar",
    "apandilharde": "apandilhar",
    "apandilhardes": "apandilhar",
    "apandilhare": "apandilhar",
    "apandilharei": "apandilhar",
    "apandilhareis": "apandilhar",
    "apandilharem": "apandilhar",
    "apandilharemos": "apandilhar",
    "apandilhares": "apandilhar",
    "apandilharia": "apandilhar",
    "apandilhariam": "apandilhar",
    "apandilharias": "apandilhar",
    "apandilharmo": "apandilhar",
    "apandilharmos": "apandilhar",
    "apandilhará": "apandilhar",
    "apandilharás": "apandilhar",
    "apandilharão": "apandilhar",
    "apandilharíamos": "apandilhar",
    "apandilharíeis": "apandilhar",
    "apandilhas": "apandilhar",
    "apandilhasse": "apandilhar",
    "apandilhassem": "apandilhar",
    "apandilhasses": "apandilhar",
    "apandilhaste": "apandilhar",
    "apandilhastes": "apandilhar",
    "apandilhava": "apandilhar",
    "apandilhavam": "apandilhar",
    "apandilhavas": "apandilhar",
    "apandilhe": "apandilhar",
    "apandilhei": "apandilhar",
    "apandilheis": "apandilhar",
    "apandilhem": "apandilhar",
    "apandilhemo": "apandilhar",
    "apandilhemos": "apandilhar",
    "apandilhes": "apandilhar",
    "apandilho": "apandilhar",
    "apandilhou": "apandilhar",
    "apandilhá": "apandilhar",
    "apandilhámo": "apandilhar",
    "apandilhámos": "apandilhar",
    "apandilháramo": "apandilhar",
    "apandilháramos": "apandilhar",
    "apandilhárei": "apandilhar",
    "apandilháreis": "apandilhar",
    "apandilhásseis": "apandilhar",
    "apandilhássemos": "apandilhar",
    "apandilhávamo": "apandilhar",
    "apandilhávamos": "apandilhar",
    "apandilhávei": "apandilhar",
    "apandilháveis": "apandilhar",
    "apando": "apandar",
    "apandou": "apandar",
    "apandrias": "apandria",
    "apandá": "apandar",
    "apandámo": "apandar",
    "apandámos": "apandar",
    "apandáramo": "apandar",
    "apandáramos": "apandar",
    "apandárei": "apandar",
    "apandáreis": "apandar",
    "apandásseis": "apandar",
    "apandássemos": "apandar",
    "apandávamo": "apandar",
    "apandávamos": "apandar",
    "apandávei": "apandar",
    "apandáveis": "apandar",
    "apanha": "apanhar",
    "apanhada": "apanhar",
    "apanhadas": "apanhar",
    "apanhadeira": "apanhador",
    "apanhadeiras": "apanhador",
    "apanhado": "apanhar",
    "apanhadores": "apanhador",
    "apanhados": "apanhar",
    "apanhaduras": "apanhadura",
    "apanhadíssima": "apanhado",
    "apanhadíssimas": "apanhado",
    "apanhadíssimo": "apanhado",
    "apanhadíssimos": "apanhado",
    "apanhai": "apanhar",
    "apanhais": "apanhar",
    "apanham": "apanhar",
    "apanhamentos": "apanhamento",
    "apanhamo": "apanhar",
    "apanhamos": "apanhar",
    "apanhando": "apanhar",
    "apanhara": "apanhar",
    "apanharam": "apanhar",
    "apanharas": "apanhar",
    "apanharde": "apanhar",
    "apanhardes": "apanhar",
    "apanhare": "apanhar",
    "apanharei": "apanhar",
    "apanhareis": "apanhar",
    "apanharem": "apanhar",
    "apanharemos": "apanhar",
    "apanhares": "apanhar",
    "apanharia": "apanhar",
    "apanhariam": "apanhar",
    "apanharias": "apanhar",
    "apanharmo": "apanhar",
    "apanharmos": "apanhar",
    "apanhará": "apanhar",
    "apanharás": "apanhar",
    "apanharão": "apanhar",
    "apanharíamos": "apanhar",
    "apanharíeis": "apanhar",
    "apanhas": "apanhar",
    "apanhasse": "apanhar",
    "apanhassem": "apanhar",
    "apanhasses": "apanhar",
    "apanhaste": "apanhar",
    "apanhastes": "apanhar",
    "apanhava": "apanhar",
    "apanhavam": "apanhar",
    "apanhavas": "apanhar",
    "apanhe": "apanhar",
    "apanhei": "apanhar",
    "apanheis": "apanhar",
    "apanhem": "apanhar",
    "apanhemo": "apanhar",
    "apanhemos": "apanhar",
    "apanhes": "apanhar",
    "apanhias": "apanhia",
    "apanho": "apanhar",
    "apanhos": "apanho",
    "apanhou": "apanhar",
    "apanhá": "apanhar",
    "apanhámo": "apanhar",
    "apanhámos": "apanhar",
    "apanháramo": "apanhar",
    "apanháramos": "apanhar",
    "apanhárei": "apanhar",
    "apanháreis": "apanhar",
    "apanhásseis": "apanhar",
    "apanhássemos": "apanhar",
    "apanhávamo": "apanhar",
    "apanhávamos": "apanhar",
    "apanhávei": "apanhar",
    "apanháveis": "apanhável",
    "apanica": "apanicar",
    "apanicada": "apanicar",
    "apanicadas": "apanicar",
    "apanicado": "apanicar",
    "apanicados": "apanicar",
    "apanicai": "apanicar",
    "apanicais": "apanicar",
    "apanicam": "apanicar",
    "apanicamo": "apanicar",
    "apanicamos": "apanicar",
    "apanicando": "apanicar",
    "apanicara": "apanicar",
    "apanicaram": "apanicar",
    "apanicaras": "apanicar",
    "apanicarde": "apanicar",
    "apanicardes": "apanicar",
    "apanicare": "apanicar",
    "apanicarei": "apanicar",
    "apanicareis": "apanicar",
    "apanicarem": "apanicar",
    "apanicaremos": "apanicar",
    "apanicares": "apanicar",
    "apanicaria": "apanicar",
    "apanicariam": "apanicar",
    "apanicarias": "apanicar",
    "apanicarmo": "apanicar",
    "apanicarmos": "apanicar",
    "apanicará": "apanicar",
    "apanicarás": "apanicar",
    "apanicarão": "apanicar",
    "apanicaríamos": "apanicar",
    "apanicaríeis": "apanicar",
    "apanicas": "apanicar",
    "apanicasse": "apanicar",
    "apanicassem": "apanicar",
    "apanicasses": "apanicar",
    "apanicaste": "apanicar",
    "apanicastes": "apanicar",
    "apanicava": "apanicar",
    "apanicavam": "apanicar",
    "apanicavas": "apanicar",
    "apanico": "apanicar",
    "apanicou": "apanicar",
    "apanicá": "apanicar",
    "apanicámo": "apanicar",
    "apanicámos": "apanicar",
    "apanicáramo": "apanicar",
    "apanicáramos": "apanicar",
    "apanicárei": "apanicar",
    "apanicáreis": "apanicar",
    "apanicásseis": "apanicar",
    "apanicássemos": "apanicar",
    "apanicávamo": "apanicar",
    "apanicávamos": "apanicar",
    "apanicávei": "apanicar",
    "apanicáveis": "apanicar",
    "apanigua": "apaniguar",
    "apaniguada": "apaniguar",
    "apaniguadas": "apaniguar",
    "apaniguado": "apaniguar",
    "apaniguados": "apaniguar",
    "apaniguai": "apaniguar",
    "apaniguais": "apaniguar",
    "apaniguam": "apaniguar",
    "apaniguamo": "apaniguar",
    "apaniguamos": "apaniguar",
    "apaniguando": "apaniguar",
    "apaniguara": "apaniguar",
    "apaniguaram": "apaniguar",
    "apaniguaras": "apaniguar",
    "apaniguarde": "apaniguar",
    "apaniguardes": "apaniguar",
    "apaniguare": "apaniguar",
    "apaniguarei": "apaniguar",
    "apaniguareis": "apaniguar",
    "apaniguarem": "apaniguar",
    "apaniguaremos": "apaniguar",
    "apaniguares": "apaniguar",
    "apaniguaria": "apaniguar",
    "apaniguariam": "apaniguar",
    "apaniguarias": "apaniguar",
    "apaniguarmo": "apaniguar",
    "apaniguarmos": "apaniguar",
    "apaniguará": "apaniguar",
    "apaniguarás": "apaniguar",
    "apaniguarão": "apaniguar",
    "apaniguaríamos": "apaniguar",
    "apaniguaríeis": "apaniguar",
    "apaniguas": "apaniguar",
    "apaniguasse": "apaniguar",
    "apaniguassem": "apaniguar",
    "apaniguasses": "apaniguar",
    "apaniguaste": "apaniguar",
    "apaniguastes": "apaniguar",
    "apaniguava": "apaniguar",
    "apaniguavam": "apaniguar",
    "apaniguavas": "apaniguar",
    "apaniguei": "apaniguar",
    "apanigueis": "apaniguar",
    "apaniguemo": "apaniguar",
    "apaniguemos": "apaniguar",
    "apanigues": "apaniguar",
    "apaniguo": "apaniguar",
    "apaniguou": "apaniguar",
    "apaniguá": "apaniguar",
    "apaniguámo": "apaniguar",
    "apaniguámos": "apaniguar",
    "apaniguáramo": "apaniguar",
    "apaniguáramos": "apaniguar",
    "apaniguárei": "apaniguar",
    "apaniguáreis": "apaniguar",
    "apaniguásseis": "apaniguar",
    "apaniguássemos": "apaniguar",
    "apaniguávamo": "apaniguar",
    "apaniguávamos": "apaniguar",
    "apaniguávei": "apaniguar",
    "apaniguáveis": "apaniguar",
    "apanigúe": "apaniguar",
    "apanigúem": "apaniguar",
    "apanigúes": "apaniguar",
    "apanique": "apanicar",
    "apaniquei": "apanicar",
    "apaniqueis": "apanicar",
    "apaniquem": "apanicar",
    "apaniquemo": "apanicar",
    "apaniquemos": "apanicar",
    "apaniques": "apanicar",
    "apanque": "apancar",
    "apanquei": "apancar",
    "apanqueis": "apancar",
    "apanquem": "apancar",
    "apanquemo": "apancar",
    "apanquemos": "apancar",
    "apanques": "apancar",
    "apantomancias": "apantomancia",
    "apantomantes": "apantomante",
    "apantomântica": "apantomântico",
    "apantomânticas": "apantomântico",
    "apantomânticos": "apantomântico",
    "apantropias": "apantropia",
    "apantufa": "apantufar",
    "apantufada": "apantufar",
    "apantufadas": "apantufar",
    "apantufado": "apantufar",
    "apantufados": "apantufar",
    "apantufai": "apantufar",
    "apantufais": "apantufar",
    "apantufam": "apantufar",
    "apantufamo": "apantufar",
    "apantufamos": "apantufar",
    "apantufando": "apantufar",
    "apantufara": "apantufar",
    "apantufaram": "apantufar",
    "apantufaras": "apantufar",
    "apantufarde": "apantufar",
    "apantufardes": "apantufar",
    "apantufare": "apantufar",
    "apantufarei": "apantufar",
    "apantufareis": "apantufar",
    "apantufarem": "apantufar",
    "apantufaremos": "apantufar",
    "apantufares": "apantufar",
    "apantufaria": "apantufar",
    "apantufariam": "apantufar",
    "apantufarias": "apantufar",
    "apantufarmo": "apantufar",
    "apantufarmos": "apantufar",
    "apantufará": "apantufar",
    "apantufarás": "apantufar",
    "apantufarão": "apantufar",
    "apantufaríamos": "apantufar",
    "apantufaríeis": "apantufar",
    "apantufas": "apantufar",
    "apantufasse": "apantufar",
    "apantufassem": "apantufar",
    "apantufasses": "apantufar",
    "apantufaste": "apantufar",
    "apantufastes": "apantufar",
    "apantufava": "apantufar",
    "apantufavam": "apantufar",
    "apantufavas": "apantufar",
    "apantufe": "apantufar",
    "apantufei": "apantufar",
    "apantufeis": "apantufar",
    "apantufem": "apantufar",
    "apantufemo": "apantufar",
    "apantufemos": "apantufar",
    "apantufes": "apantufar",
    "apantufo": "apantufar",
    "apantufou": "apantufar",
    "apantufá": "apantufar",
    "apantufámo": "apantufar",
    "apantufámos": "apantufar",
    "apantufáramo": "apantufar",
    "apantufáramos": "apantufar",
    "apantufárei": "apantufar",
    "apantufáreis": "apantufar",
    "apantufásseis": "apantufar",
    "apantufássemos": "apantufar",
    "apantufávamo": "apantufar",
    "apantufávamos": "apantufar",
    "apantufávei": "apantufar",
    "apantufáveis": "apantufar",
    "apanágios": "apanágio",
    "apaparica": "apaparicar",
    "apaparicada": "apaparicar",
    "apaparicadas": "apaparicar",
    "apaparicado": "apaparicar",
    "apaparicados": "apaparicar",
    "apaparicai": "apaparicar",
    "apaparicais": "apaparicar",
    "apaparicam": "apaparicar",
    "apaparicamentos": "apaparicamento",
    "apaparicamo": "apaparicar",
    "apaparicamos": "apaparicar",
    "apaparicando": "apaparicar",
    "apaparicara": "apaparicar",
    "apaparicaram": "apaparicar",
    "apaparicaras": "apaparicar",
    "apaparicarde": "apaparicar",
    "apaparicardes": "apaparicar",
    "apaparicare": "apaparicar",
    "apaparicarei": "apaparicar",
    "apaparicareis": "apaparicar",
    "apaparicarem": "apaparicar",
    "apaparicaremos": "apaparicar",
    "apaparicares": "apaparicar",
    "apaparicaria": "apaparicar",
    "apaparicariam": "apaparicar",
    "apaparicarias": "apaparicar",
    "apaparicarmo": "apaparicar",
    "apaparicarmos": "apaparicar",
    "apaparicará": "apaparicar",
    "apaparicarás": "apaparicar",
    "apaparicarão": "apaparicar",
    "apaparicaríamos": "apaparicar",
    "apaparicaríeis": "apaparicar",
    "apaparicas": "apaparicar",
    "apaparicasse": "apaparicar",
    "apaparicassem": "apaparicar",
    "apaparicasses": "apaparicar",
    "apaparicaste": "apaparicar",
    "apaparicastes": "apaparicar",
    "apaparicava": "apaparicar",
    "apaparicavam": "apaparicar",
    "apaparicavas": "apaparicar",
    "apaparico": "apaparicar",
    "apaparicos": "apaparico",
    "apaparicou": "apaparicar",
    "apaparicá": "apaparicar",
    "apaparicámo": "apaparicar",
    "apaparicámos": "apaparicar",
    "apaparicáramo": "apaparicar",
    "apaparicáramos": "apaparicar",
    "apaparicárei": "apaparicar",
    "apaparicáreis": "apaparicar",
    "apaparicásseis": "apaparicar",
    "apaparicássemos": "apaparicar",
    "apaparicávamo": "apaparicar",
    "apaparicávamos": "apaparicar",
    "apaparicávei": "apaparicar",
    "apaparicáveis": "apaparicar",
    "apaparique": "apaparicar",
    "apapariquei": "apaparicar",
    "apapariqueis": "apaparicar",
    "apapariquem": "apaparicar",
    "apapariquemo": "apaparicar",
    "apapariquemos": "apaparicar",
    "apapariques": "apaparicar",
    "apapoilada": "apapoilado",
    "apapoiladas": "apapoilado",
    "apapoilados": "apapoilado",
    "apara": "aparar",
    "aparada": "aparar",
    "aparadas": "aparar",
    "aparadeiras": "aparadeira",
    "aparadelas": "aparadela",
    "aparado": "aparar",
    "aparadora": "aparador",
    "aparadoras": "aparador",
    "aparadores": "aparador",
    "aparados": "aparar",
    "aparafusa": "aparafusar",
    "aparafusada": "aparafusar",
    "aparafusadas": "aparafusar",
    "aparafusado": "aparafusar",
    "aparafusados": "aparafusar",
    "aparafusai": "aparafusar",
    "aparafusais": "aparafusar",
    "aparafusam": "aparafusar",
    "aparafusamentos": "aparafusamento",
    "aparafusamo": "aparafusar",
    "aparafusamos": "aparafusar",
    "aparafusando": "aparafusar",
    "aparafusara": "aparafusar",
    "aparafusaram": "aparafusar",
    "aparafusaras": "aparafusar",
    "aparafusarde": "aparafusar",
    "aparafusardes": "aparafusar",
    "aparafusare": "aparafusar",
    "aparafusarei": "aparafusar",
    "aparafusareis": "aparafusar",
    "aparafusarem": "aparafusar",
    "aparafusaremos": "aparafusar",
    "aparafusares": "aparafusar",
    "aparafusaria": "aparafusar",
    "aparafusariam": "aparafusar",
    "aparafusarias": "aparafusar",
    "aparafusarmo": "aparafusar",
    "aparafusarmos": "aparafusar",
    "aparafusará": "aparafusar",
    "aparafusarás": "aparafusar",
    "aparafusarão": "aparafusar",
    "aparafusaríamos": "aparafusar",
    "aparafusaríeis": "aparafusar",
    "aparafusas": "aparafusar",
    "aparafusasse": "aparafusar",
    "aparafusassem": "aparafusar",
    "aparafusasses": "aparafusar",
    "aparafusaste": "aparafusar",
    "aparafusastes": "aparafusar",
    "aparafusava": "aparafusar",
    "aparafusavam": "aparafusar",
    "aparafusavas": "aparafusar",
    "aparafuse": "aparafusar",
    "aparafusei": "aparafusar",
    "aparafuseis": "aparafusar",
    "aparafusem": "aparafusar",
    "aparafusemo": "aparafusar",
    "aparafusemos": "aparafusar",
    "aparafuses": "aparafusar",
    "aparafuso": "aparafusar",
    "aparafusou": "aparafusar",
    "aparafusá": "aparafusar",
    "aparafusámo": "aparafusar",
    "aparafusámos": "aparafusar",
    "aparafusáramo": "aparafusar",
    "aparafusáramos": "aparafusar",
    "aparafusárei": "aparafusar",
    "aparafusáreis": "aparafusar",
    "aparafusásseis": "aparafusar",
    "aparafusássemos": "aparafusar",
    "aparafusávamo": "aparafusar",
    "aparafusávamos": "aparafusar",
    "aparafusávei": "aparafusar",
    "aparafusáveis": "aparafusar",
    "aparagens": "aparagem",
    "aparai": "aparar",
    "aparais": "aparar",
    "aparalta": "aparaltar",
    "aparaltada": "aparaltar",
    "aparaltadas": "aparaltar",
    "aparaltado": "aparaltar",
    "aparaltados": "aparaltar",
    "aparaltai": "aparaltar",
    "aparaltais": "aparaltar",
    "aparaltam": "aparaltar",
    "aparaltamo": "aparaltar",
    "aparaltamos": "aparaltar",
    "aparaltando": "aparaltar",
    "aparaltara": "aparaltar",
    "aparaltaram": "aparaltar",
    "aparaltaras": "aparaltar",
    "aparaltarde": "aparaltar",
    "aparaltardes": "aparaltar",
    "aparaltare": "aparaltar",
    "aparaltarei": "aparaltar",
    "aparaltareis": "aparaltar",
    "aparaltarem": "aparaltar",
    "aparaltaremos": "aparaltar",
    "aparaltares": "aparaltar",
    "aparaltaria": "aparaltar",
    "aparaltariam": "aparaltar",
    "aparaltarias": "aparaltar",
    "aparaltarmo": "aparaltar",
    "aparaltarmos": "aparaltar",
    "aparaltará": "aparaltar",
    "aparaltarás": "aparaltar",
    "aparaltarão": "aparaltar",
    "aparaltaríamos": "aparaltar",
    "aparaltaríeis": "aparaltar",
    "aparaltas": "aparaltar",
    "aparaltasse": "aparaltar",
    "aparaltassem": "aparaltar",
    "aparaltasses": "aparaltar",
    "aparaltaste": "aparaltar",
    "aparaltastes": "aparaltar",
    "aparaltava": "aparaltar",
    "aparaltavam": "aparaltar",
    "aparaltavas": "aparaltar",
    "aparalte": "aparaltar",
    "aparaltei": "aparaltar",
    "aparalteis": "aparaltar",
    "aparaltem": "aparaltar",
    "aparaltemo": "aparaltar",
    "aparaltemos": "aparaltar",
    "aparaltes": "aparaltar",
    "aparalto": "aparaltar",
    "aparaltou": "aparaltar",
    "aparaltá": "aparaltar",
    "aparaltámo": "aparaltar",
    "aparaltámos": "aparaltar",
    "aparaltáramo": "aparaltar",
    "aparaltáramos": "aparaltar",
    "aparaltárei": "aparaltar",
    "aparaltáreis": "aparaltar",
    "aparaltásseis": "aparaltar",
    "aparaltássemos": "aparaltar",
    "aparaltávamo": "aparaltar",
    "aparaltávamos": "aparaltar",
    "aparaltávei": "aparaltar",
    "aparaltáveis": "aparaltar",
    "aparam": "aparar",
    "aparamenta": "aparamentar",
    "aparamentada": "aparamentar",
    "aparamentadas": "aparamentar",
    "aparamentado": "aparamentar",
    "aparamentados": "aparamentar",
    "aparamentai": "aparamentar",
    "aparamentais": "aparamentar",
    "aparamentam": "aparamentar",
    "aparamentamo": "aparamentar",
    "aparamentamos": "aparamentar",
    "aparamentando": "aparamentar",
    "aparamentara": "aparamentar",
    "aparamentaram": "aparamentar",
    "aparamentaras": "aparamentar",
    "aparamentarde": "aparamentar",
    "aparamentardes": "aparamentar",
    "aparamentare": "aparamentar",
    "aparamentarei": "aparamentar",
    "aparamentareis": "aparamentar",
    "aparamentarem": "aparamentar",
    "aparamentaremos": "aparamentar",
    "aparamentares": "aparamentar",
    "aparamentaria": "aparamentar",
    "aparamentariam": "aparamentar",
    "aparamentarias": "aparamentar",
    "aparamentarmo": "aparamentar",
    "aparamentarmos": "aparamentar",
    "aparamentará": "aparamentar",
    "aparamentarás": "aparamentar",
    "aparamentarão": "aparamentar",
    "aparamentaríamos": "aparamentar",
    "aparamentaríeis": "aparamentar",
    "aparamentas": "aparamentar",
    "aparamentasse": "aparamentar",
    "aparamentassem": "aparamentar",
    "aparamentasses": "aparamentar",
    "aparamentaste": "aparamentar",
    "aparamentastes": "aparamentar",
    "aparamentava": "aparamentar",
    "aparamentavam": "aparamentar",
    "aparamentavas": "aparamentar",
    "aparamente": "aparamentar",
    "aparamentei": "aparamentar",
    "aparamenteis": "aparamentar",
    "aparamentem": "aparamentar",
    "aparamentemo": "aparamentar",
    "aparamentemos": "aparamentar",
    "aparamentes": "aparamentar",
    "aparamento": "aparamentar",
    "aparamentosa": "aparamentoso",
    "aparamentosas": "aparamentoso",
    "aparamentosos": "aparamentoso",
    "aparamentou": "aparamentar",
    "aparamentá": "aparamentar",
    "aparamentámo": "aparamentar",
    "aparamentámos": "aparamentar",
    "aparamentáramo": "aparamentar",
    "aparamentáramos": "aparamentar",
    "aparamentárei": "aparamentar",
    "aparamentáreis": "aparamentar",
    "aparamentásseis": "aparamentar",
    "aparamentássemos": "aparamentar",
    "aparamentávamo": "aparamentar",
    "aparamentávamos": "aparamentar",
    "aparamentávei": "aparamentar",
    "aparamentáveis": "aparamentar",
    "aparamo": "aparar",
    "aparamos": "aparar",
    "aparando": "aparar",
    "aparara": "aparar",
    "apararam": "aparar",
    "apararas": "aparar",
    "apararde": "aparar",
    "aparardes": "aparar",
    "aparare": "aparar",
    "apararei": "aparar",
    "aparareis": "aparar",
    "apararem": "aparar",
    "apararemos": "aparar",
    "aparares": "aparar",
    "apararia": "aparar",
    "aparariam": "aparar",
    "apararias": "aparar",
    "apararmo": "aparar",
    "apararmos": "aparar",
    "aparará": "aparar",
    "apararás": "aparar",
    "apararão": "aparar",
    "apararíamos": "aparar",
    "apararíeis": "aparar",
    "aparas": "aparar",
    "aparasse": "aparar",
    "aparassem": "aparar",
    "aparasses": "aparar",
    "aparaste": "aparar",
    "aparastes": "aparar",
    "aparatos": "aparato",
    "aparatosa": "aparatoso",
    "aparatosas": "aparatoso",
    "aparatosos": "aparatoso",
    "aparatosíssima": "aparatoso",
    "aparatosíssimas": "aparatoso",
    "aparatosíssimo": "aparatoso",
    "aparatosíssimos": "aparatoso",
    "aparava": "aparar",
    "aparavam": "aparar",
    "aparavas": "aparar",
    "aparca": "aparcar",
    "aparcada": "aparcar",
    "aparcadas": "aparcar",
    "aparcado": "aparcar",
    "aparcados": "aparcar",
    "aparcai": "aparcar",
    "aparcais": "aparcar",
    "aparcam": "aparcar",
    "aparcamentos": "aparcamento",
    "aparcamo": "aparcar",
    "aparcamos": "aparcar",
    "aparcando": "aparcar",
    "aparcara": "aparcar",
    "aparcaram": "aparcar",
    "aparcaras": "aparcar",
    "aparcarde": "aparcar",
    "aparcardes": "aparcar",
    "aparcare": "aparcar",
    "aparcarei": "aparcar",
    "aparcareis": "aparcar",
    "aparcarem": "aparcar",
    "aparcaremos": "aparcar",
    "aparcares": "aparcar",
    "aparcaria": "aparcar",
    "aparcariam": "aparcar",
    "aparcarias": "aparcar",
    "aparcarmo": "aparcar",
    "aparcarmos": "aparcar",
    "aparcará": "aparcar",
    "aparcarás": "aparcar",
    "aparcarão": "aparcar",
    "aparcaríamos": "aparcar",
    "aparcaríeis": "aparcar",
    "aparcas": "aparcar",
    "aparcasse": "aparcar",
    "aparcassem": "aparcar",
    "aparcasses": "aparcar",
    "aparcaste": "aparcar",
    "aparcastes": "aparcar",
    "aparcava": "aparcar",
    "aparcavam": "aparcar",
    "aparcavas": "aparcar",
    "aparceira": "aparceirar",
    "aparceirada": "aparceirar",
    "aparceiradas": "aparceirar",
    "aparceirado": "aparceirar",
    "aparceirados": "aparceirar",
    "aparceirai": "aparceirar",
    "aparceirais": "aparceirar",
    "aparceiram": "aparceirar",
    "aparceiramo": "aparceirar",
    "aparceiramos": "aparceirar",
    "aparceirando": "aparceirar",
    "aparceirara": "aparceirar",
    "aparceiraram": "aparceirar",
    "aparceiraras": "aparceirar",
    "aparceirarde": "aparceirar",
    "aparceirardes": "aparceirar",
    "aparceirare": "aparceirar",
    "aparceirarei": "aparceirar",
    "aparceirareis": "aparceirar",
    "aparceirarem": "aparceirar",
    "aparceiraremos": "aparceirar",
    "aparceirares": "aparceirar",
    "aparceiraria": "aparceirar",
    "aparceirariam": "aparceirar",
    "aparceirarias": "aparceirar",
    "aparceirarmo": "aparceirar",
    "aparceirarmos": "aparceirar",
    "aparceirará": "aparceirar",
    "aparceirarás": "aparceirar",
    "aparceirarão": "aparceirar",
    "aparceiraríamos": "aparceirar",
    "aparceiraríeis": "aparceirar",
    "aparceiras": "aparceirar",
    "aparceirasse": "aparceirar",
    "aparceirassem": "aparceirar",
    "aparceirasses": "aparceirar",
    "aparceiraste": "aparceirar",
    "aparceirastes": "aparceirar",
    "aparceirava": "aparceirar",
    "aparceiravam": "aparceirar",
    "aparceiravas": "aparceirar",
    "aparceire": "aparceirar",
    "aparceirei": "aparceirar",
    "aparceireis": "aparceirar",
    "aparceirem": "aparceirar",
    "aparceiremo": "aparceirar",
    "aparceiremos": "aparceirar",
    "aparceires": "aparceirar",
    "aparceiro": "aparceirar",
    "aparceirou": "aparceirar",
    "aparceirá": "aparceirar",
    "aparceirámo": "aparceirar",
    "aparceirámos": "aparceirar",
    "aparceiráramo": "aparceirar",
    "aparceiráramos": "aparceirar",
    "aparceirárei": "aparceirar",
    "aparceiráreis": "aparceirar",
    "aparceirásseis": "aparceirar",
    "aparceirássemos": "aparceirar",
    "aparceirávamo": "aparceirar",
    "aparceirávamos": "aparceirar",
    "aparceirávei": "aparceirar",
    "aparceiráveis": "aparceirar",
    "aparcela": "aparcelar",
    "aparcelada": "aparcelar",
    "aparceladas": "aparcelar",
    "aparcelado": "aparcelar",
    "aparcelados": "aparcelar",
    "aparcelai": "aparcelar",
    "aparcelais": "aparcelar",
    "aparcelam": "aparcelar",
    "aparcelamentos": "aparcelamento",
    "aparcelamo": "aparcelar",
    "aparcelamos": "aparcelar",
    "aparcelando": "aparcelar",
    "aparcelara": "aparcelar",
    "aparcelaram": "aparcelar",
    "aparcelaras": "aparcelar",
    "aparcelarde": "aparcelar",
    "aparcelardes": "aparcelar",
    "aparcelare": "aparcelar",
    "aparcelarei": "aparcelar",
    "aparcelareis": "aparcelar",
    "aparcelarem": "aparcelar",
    "aparcelaremos": "aparcelar",
    "aparcelares": "aparcelar",
    "aparcelaria": "aparcelar",
    "aparcelariam": "aparcelar",
    "aparcelarias": "aparcelar",
    "aparcelarmo": "aparcelar",
    "aparcelarmos": "aparcelar",
    "aparcelará": "aparcelar",
    "aparcelarás": "aparcelar",
    "aparcelarão": "aparcelar",
    "aparcelaríamos": "aparcelar",
    "aparcelaríeis": "aparcelar",
    "aparcelas": "aparcelar",
    "aparcelasse": "aparcelar",
    "aparcelassem": "aparcelar",
    "aparcelasses": "aparcelar",
    "aparcelaste": "aparcelar",
    "aparcelastes": "aparcelar",
    "aparcelava": "aparcelar",
    "aparcelavam": "aparcelar",
    "aparcelavas": "aparcelar",
    "aparcele": "aparcelar",
    "aparcelei": "aparcelar",
    "aparceleis": "aparcelar",
    "aparcelem": "aparcelar",
    "aparcelemo": "aparcelar",
    "aparcelemos": "aparcelar",
    "aparceles": "aparcelar",
    "aparcelo": "aparcelar",
    "aparcelou": "aparcelar",
    "aparcelá": "aparcelar",
    "aparcelámo": "aparcelar",
    "aparcelámos": "aparcelar",
    "aparceláramo": "aparcelar",
    "aparceláramos": "aparcelar",
    "aparcelárei": "aparcelar",
    "aparceláreis": "aparcelar",
    "aparcelásseis": "aparcelar",
    "aparcelássemos": "aparcelar",
    "aparcelávamo": "aparcelar",
    "aparcelávamos": "aparcelar",
    "aparcelávei": "aparcelar",
    "aparceláveis": "aparcelar",
    "aparco": "aparcar",
    "aparcou": "aparcar",
    "aparcá": "aparcar",
    "aparcámo": "aparcar",
    "aparcámos": "aparcar",
    "aparcáramo": "aparcar",
    "aparcáramos": "aparcar",
    "aparcárei": "aparcar",
    "aparcáreis": "aparcar",
    "aparcásseis": "aparcar",
    "aparcássemos": "aparcar",
    "aparcávamo": "aparcar",
    "aparcávamos": "aparcar",
    "aparcávei": "aparcar",
    "aparcáveis": "aparcar",
    "apardace": "apardaçar",
    "apardacei": "apardaçar",
    "apardaceis": "apardaçar",
    "apardacem": "apardaçar",
    "apardacemo": "apardaçar",
    "apardacemos": "apardaçar",
    "apardaces": "apardaçar",
    "apardaça": "apardaçar",
    "apardaçada": "apardaçar",
    "apardaçadas": "apardaçar",
    "apardaçado": "apardaçar",
    "apardaçados": "apardaçar",
    "apardaçai": "apardaçar",
    "apardaçais": "apardaçar",
    "apardaçam": "apardaçar",
    "apardaçamo": "apardaçar",
    "apardaçamos": "apardaçar",
    "apardaçando": "apardaçar",
    "apardaçara": "apardaçar",
    "apardaçaram": "apardaçar",
    "apardaçaras": "apardaçar",
    "apardaçarde": "apardaçar",
    "apardaçardes": "apardaçar",
    "apardaçare": "apardaçar",
    "apardaçarei": "apardaçar",
    "apardaçareis": "apardaçar",
    "apardaçarem": "apardaçar",
    "apardaçaremos": "apardaçar",
    "apardaçares": "apardaçar",
    "apardaçaria": "apardaçar",
    "apardaçariam": "apardaçar",
    "apardaçarias": "apardaçar",
    "apardaçarmo": "apardaçar",
    "apardaçarmos": "apardaçar",
    "apardaçará": "apardaçar",
    "apardaçarás": "apardaçar",
    "apardaçarão": "apardaçar",
    "apardaçaríamos": "apardaçar",
    "apardaçaríeis": "apardaçar",
    "apardaças": "apardaçar",
    "apardaçasse": "apardaçar",
    "apardaçassem": "apardaçar",
    "apardaçasses": "apardaçar",
    "apardaçaste": "apardaçar",
    "apardaçastes": "apardaçar",
    "apardaçava": "apardaçar",
    "apardaçavam": "apardaçar",
    "apardaçavas": "apardaçar",
    "apardaço": "apardaçar",
    "apardaçou": "apardaçar",
    "apardaçá": "apardaçar",
    "apardaçámo": "apardaçar",
    "apardaçámos": "apardaçar",
    "apardaçáramo": "apardaçar",
    "apardaçáramos": "apardaçar",
    "apardaçárei": "apardaçar",
    "apardaçáreis": "apardaçar",
    "apardaçásseis": "apardaçar",
    "apardaçássemos": "apardaçar",
    "apardaçávamo": "apardaçar",
    "apardaçávamos": "apardaçar",
    "apardaçávei": "apardaçar",
    "apardaçáveis": "apardaçar",
    "apare": "aparar",
    "aparece": "aparecer",
    "aparecei": "aparecer",
    "apareceis": "aparecer",
    "aparecem": "aparecer",
    "aparecemo": "aparecer",
    "aparecemos": "aparecer",
    "aparecendo": "aparecer",
    "aparecera": "aparecer",
    "apareceram": "aparecer",
    "apareceras": "aparecer",
    "aparecerdes": "aparecer",
    "aparecerei": "aparecer",
    "aparecereis": "aparecer",
    "aparecerem": "aparecer",
    "apareceremos": "aparecer",
    "apareceres": "aparecer",
    "apareceria": "aparecer",
    "apareceriam": "aparecer",
    "aparecerias": "aparecer",
    "aparecermo": "aparecer",
    "aparecermos": "aparecer",
    "aparecerá": "aparecer",
    "aparecerás": "aparecer",
    "aparecerão": "aparecer",
    "apareceríamos": "aparecer",
    "apareceríeis": "aparecer",
    "apareces": "aparecer",
    "aparecesse": "aparecer",
    "aparecessem": "aparecer",
    "aparecesses": "aparecer",
    "apareceste": "aparecer",
    "aparecestes": "aparecer",
    "apareceu": "aparecer",
    "apareci": "aparecer",
    "aparecia": "aparecer",
    "apareciam": "aparecer",
    "aparecias": "aparecer",
    "aparecida": "aparecido",
    "aparecidas": "aparecido",
    "aparecido": "aparecer",
    "aparecidos": "aparecido",
    "aparecimentos": "aparecimento",
    "aparecêramo": "aparecer",
    "aparecêramos": "aparecer",
    "aparecêreis": "aparecer",
    "aparecêsseis": "aparecer",
    "aparecêssemos": "aparecer",
    "aparecíamo": "aparecer",
    "aparecíamos": "aparecer",
    "aparecíeis": "aparecer",
    "aparei": "aparar",
    "apareis": "aparar",
    "aparelha": "aparelhar",
    "aparelhada": "aparelhar",
    "aparelhadas": "aparelhar",
    "aparelhado": "aparelhar",
    "aparelhadora": "aparelhador",
    "aparelhadoras": "aparelhador",
    "aparelhadores": "aparelhador",
    "aparelhados": "aparelhar",
    "aparelhagens": "aparelhagem",
    "aparelhai": "aparelhar",
    "aparelhais": "aparelhar",
    "aparelham": "aparelhar",
    "aparelhamentos": "aparelhamento",
    "aparelhamo": "aparelhar",
    "aparelhamos": "aparelhar",
    "aparelhando": "aparelhar",
    "aparelhara": "aparelhar",
    "aparelharam": "aparelhar",
    "aparelharas": "aparelhar",
    "aparelharde": "aparelhar",
    "aparelhardes": "aparelhar",
    "aparelhare": "aparelhar",
    "aparelharei": "aparelhar",
    "aparelhareis": "aparelhar",
    "aparelharem": "aparelhar",
    "aparelharemos": "aparelhar",
    "aparelhares": "aparelhar",
    "aparelharia": "aparelhar",
    "aparelhariam": "aparelhar",
    "aparelharias": "aparelhar",
    "aparelharmo": "aparelhar",
    "aparelharmos": "aparelhar",
    "aparelhará": "aparelhar",
    "aparelharás": "aparelhar",
    "aparelharão": "aparelhar",
    "aparelharíamos": "aparelhar",
    "aparelharíeis": "aparelhar",
    "aparelhas": "aparelhar",
    "aparelhasse": "aparelhar",
    "aparelhassem": "aparelhar",
    "aparelhasses": "aparelhar",
    "aparelhaste": "aparelhar",
    "aparelhastes": "aparelhar",
    "aparelhava": "aparelhar",
    "aparelhavam": "aparelhar",
    "aparelhavas": "aparelhar",
    "aparelhe": "aparelhar",
    "aparelhei": "aparelhar",
    "aparelheis": "aparelhar",
    "aparelhem": "aparelhar",
    "aparelhemo": "aparelhar",
    "aparelhemos": "aparelhar",
    "aparelhes": "aparelhar",
    "aparelhinho": "aparelho",
    "aparelhinhos": "aparelho",
    "aparelhito": "aparelho",
    "aparelhitos": "aparelho",
    "aparelho": "aparelhar",
    "aparelhos": "aparelho",
    "aparelhou": "aparelhar",
    "aparelhozinho": "aparelho",
    "aparelhozinhos": "aparelho",
    "aparelhozito": "aparelho",
    "aparelhozitos": "aparelho",
    "aparelhá": "aparelhar",
    "aparelhámo": "aparelhar",
    "aparelhámos": "aparelhar",
    "aparelháramo": "aparelhar",
    "aparelháramos": "aparelhar",
    "aparelhárei": "aparelhar",
    "aparelháreis": "aparelhar",
    "aparelhásseis": "aparelhar",
    "aparelhássemos": "aparelhar",
    "aparelhávamo": "aparelhar",
    "aparelhávamos": "aparelhar",
    "aparelhávei": "aparelhar",
    "aparelháveis": "aparelhável",
    "aparelhómetros": "aparelhómetro",
    "aparem": "aparar",
    "aparemo": "aparar",
    "aparemos": "aparar",
    "aparenta": "aparentar",
    "aparentada": "aparentar",
    "aparentadas": "aparentar",
    "aparentado": "aparentar",
    "aparentados": "aparentar",
    "aparentai": "aparentar",
    "aparentais": "aparentar",
    "aparentam": "aparentar",
    "aparentamo": "aparentar",
    "aparentamos": "aparentar",
    "aparentando": "aparentar",
    "aparentara": "aparentar",
    "aparentaram": "aparentar",
    "aparentaras": "aparentar",
    "aparentarde": "aparentar",
    "aparentardes": "aparentar",
    "aparentare": "aparentar",
    "aparentarei": "aparentar",
    "aparentareis": "aparentar",
    "aparentarem": "aparentar",
    "aparentaremos": "aparentar",
    "aparentares": "aparentar",
    "aparentaria": "aparentar",
    "aparentariam": "aparentar",
    "aparentarias": "aparentar",
    "aparentarmo": "aparentar",
    "aparentarmos": "aparentar",
    "aparentará": "aparentar",
    "aparentarás": "aparentar",
    "aparentarão": "aparentar",
    "aparentaríamos": "aparentar",
    "aparentaríeis": "aparentar",
    "aparentas": "aparentar",
    "aparentasse": "aparentar",
    "aparentassem": "aparentar",
    "aparentasses": "aparentar",
    "aparentaste": "aparentar",
    "aparentastes": "aparentar",
    "aparentava": "aparentar",
    "aparentavam": "aparentar",
    "aparentavas": "aparentar",
    "aparente": "aparentar",
    "aparentei": "aparentar",
    "aparenteis": "aparentar",
    "aparentela": "aparentelar",
    "aparentelada": "aparentelar",
    "aparenteladas": "aparentelar",
    "aparentelado": "aparentelar",
    "aparentelados": "aparentelar",
    "aparentelai": "aparentelar",
    "aparentelais": "aparentelar",
    "aparentelam": "aparentelar",
    "aparentelamo": "aparentelar",
    "aparentelamos": "aparentelar",
    "aparentelando": "aparentelar",
    "aparentelara": "aparentelar",
    "aparentelaram": "aparentelar",
    "aparentelaras": "aparentelar",
    "aparentelarde": "aparentelar",
    "aparentelardes": "aparentelar",
    "aparentelare": "aparentelar",
    "aparentelarei": "aparentelar",
    "aparentelareis": "aparentelar",
    "aparentelarem": "aparentelar",
    "aparentelaremos": "aparentelar",
    "aparentelares": "aparentelar",
    "aparentelaria": "aparentelar",
    "aparentelariam": "aparentelar",
    "aparentelarias": "aparentelar",
    "aparentelarmo": "aparentelar",
    "aparentelarmos": "aparentelar",
    "aparentelará": "aparentelar",
    "aparentelarás": "aparentelar",
    "aparentelarão": "aparentelar",
    "aparentelaríamos": "aparentelar",
    "aparentelaríeis": "aparentelar",
    "aparentelas": "aparentelar",
    "aparentelasse": "aparentelar",
    "aparentelassem": "aparentelar",
    "aparentelasses": "aparentelar",
    "aparentelaste": "aparentelar",
    "aparentelastes": "aparentelar",
    "aparentelava": "aparentelar",
    "aparentelavam": "aparentelar",
    "aparentelavas": "aparentelar",
    "aparentele": "aparentelar",
    "aparentelei": "aparentelar",
    "aparenteleis": "aparentelar",
    "aparentelem": "aparentelar",
    "aparentelemo": "aparentelar",
    "aparentelemos": "aparentelar",
    "aparenteles": "aparentelar",
    "aparentelo": "aparentelar",
    "aparentelou": "aparentelar",
    "aparentelá": "aparentelar",
    "aparentelámo": "aparentelar",
    "aparentelámos": "aparentelar",
    "aparenteláramo": "aparentelar",
    "aparenteláramos": "aparentelar",
    "aparentelárei": "aparentelar",
    "aparenteláreis": "aparentelar",
    "aparentelásseis": "aparentelar",
    "aparentelássemos": "aparentelar",
    "aparentelávamo": "aparentelar",
    "aparentelávamos": "aparentelar",
    "aparentelávei": "aparentelar",
    "aparenteláveis": "aparentelar",
    "aparentem": "aparentar",
    "aparentemo": "aparentar",
    "aparentemos": "aparentar",
    "aparentes": "aparente",
    "aparento": "aparentar",
    "aparentou": "aparentar",
    "aparentá": "aparentar",
    "aparentámo": "aparentar",
    "aparentámos": "aparentar",
    "aparentáramo": "aparentar",
    "aparentáramos": "aparentar",
    "aparentárei": "aparentar",
    "aparentáreis": "aparentar",
    "aparentásseis": "aparentar",
    "aparentássemos": "aparentar",
    "aparentávamo": "aparentar",
    "aparentávamos": "aparentar",
    "aparentávei": "aparentar",
    "aparentáveis": "aparentar",
    "apares": "aparar",
    "apareça": "aparecer",
    "apareçais": "aparecer",
    "apareçam": "aparecer",
    "apareçamo": "aparecer",
    "apareçamos": "aparecer",
    "apareças": "aparecer",
    "apareço": "aparecer",
    "aparições": "aparição",
    "aparo": "aparar",
    "aparolada": "aparolado",
    "aparoladas": "aparolado",
    "aparolados": "aparolado",
    "aparoquia": "aparoquiar",
    "aparoquiada": "aparoquiar",
    "aparoquiadas": "aparoquiar",
    "aparoquiado": "aparoquiar",
    "aparoquiados": "aparoquiar",
    "aparoquiai": "aparoquiar",
    "aparoquiais": "aparoquiar",
    "aparoquiam": "aparoquiar",
    "aparoquiamo": "aparoquiar",
    "aparoquiamos": "aparoquiar",
    "aparoquiana": "aparoquianar",
    "aparoquianada": "aparoquianar",
    "aparoquianadas": "aparoquianar",
    "aparoquianado": "aparoquianar",
    "aparoquianados": "aparoquianar",
    "aparoquianai": "aparoquianar",
    "aparoquianais": "aparoquianar",
    "aparoquianam": "aparoquianar",
    "aparoquianamo": "aparoquianar",
    "aparoquianamos": "aparoquianar",
    "aparoquianando": "aparoquianar",
    "aparoquianara": "aparoquianar",
    "aparoquianaram": "aparoquianar",
    "aparoquianaras": "aparoquianar",
    "aparoquianarde": "aparoquianar",
    "aparoquianardes": "aparoquianar",
    "aparoquianare": "aparoquianar",
    "aparoquianarei": "aparoquianar",
    "aparoquianareis": "aparoquianar",
    "aparoquianarem": "aparoquianar",
    "aparoquianaremos": "aparoquianar",
    "aparoquianares": "aparoquianar",
    "aparoquianaria": "aparoquianar",
    "aparoquianariam": "aparoquianar",
    "aparoquianarias": "aparoquianar",
    "aparoquianarmo": "aparoquianar",
    "aparoquianarmos": "aparoquianar",
    "aparoquianará": "aparoquianar",
    "aparoquianarás": "aparoquianar",
    "aparoquianarão": "aparoquianar",
    "aparoquianaríamos": "aparoquianar",
    "aparoquianaríeis": "aparoquianar",
    "aparoquianas": "aparoquianar",
    "aparoquianasse": "aparoquianar",
    "aparoquianassem": "aparoquianar",
    "aparoquianasses": "aparoquianar",
    "aparoquianaste": "aparoquianar",
    "aparoquianastes": "aparoquianar",
    "aparoquianava": "aparoquianar",
    "aparoquianavam": "aparoquianar",
    "aparoquianavas": "aparoquianar",
    "aparoquiando": "aparoquiar",
    "aparoquiane": "aparoquianar",
    "aparoquianei": "aparoquianar",
    "aparoquianeis": "aparoquianar",
    "aparoquianem": "aparoquianar",
    "aparoquianemo": "aparoquianar",
    "aparoquianemos": "aparoquianar",
    "aparoquianes": "aparoquianar",
    "aparoquiano": "aparoquianar",
    "aparoquianou": "aparoquianar",
    "aparoquianá": "aparoquianar",
    "aparoquianámo": "aparoquianar",
    "aparoquianámos": "aparoquianar",
    "aparoquianáramo": "aparoquianar",
    "aparoquianáramos": "aparoquianar",
    "aparoquianárei": "aparoquianar",
    "aparoquianáreis": "aparoquianar",
    "aparoquianásseis": "aparoquianar",
    "aparoquianássemos": "aparoquianar",
    "aparoquianávamo": "aparoquianar",
    "aparoquianávamos": "aparoquianar",
    "aparoquianávei": "aparoquianar",
    "aparoquianáveis": "aparoquianar",
    "aparoquiara": "aparoquiar",
    "aparoquiaram": "aparoquiar",
    "aparoquiaras": "aparoquiar",
    "aparoquiarde": "aparoquiar",
    "aparoquiardes": "aparoquiar",
    "aparoquiare": "aparoquiar",
    "aparoquiarei": "aparoquiar",
    "aparoquiareis": "aparoquiar",
    "aparoquiarem": "aparoquiar",
    "aparoquiaremos": "aparoquiar",
    "aparoquiares": "aparoquiar",
    "aparoquiaria": "aparoquiar",
    "aparoquiariam": "aparoquiar",
    "aparoquiarias": "aparoquiar",
    "aparoquiarmo": "aparoquiar",
    "aparoquiarmos": "aparoquiar",
    "aparoquiará": "aparoquiar",
    "aparoquiarás": "aparoquiar",
    "aparoquiarão": "aparoquiar",
    "aparoquiaríamos": "aparoquiar",
    "aparoquiaríeis": "aparoquiar",
    "aparoquias": "aparoquiar",
    "aparoquiasse": "aparoquiar",
    "aparoquiassem": "aparoquiar",
    "aparoquiasses": "aparoquiar",
    "aparoquiaste": "aparoquiar",
    "aparoquiastes": "aparoquiar",
    "aparoquiava": "aparoquiar",
    "aparoquiavam": "aparoquiar",
    "aparoquiavas": "aparoquiar",
    "aparoquie": "aparoquiar",
    "aparoquiei": "aparoquiar",
    "aparoquieis": "aparoquiar",
    "aparoquiem": "aparoquiar",
    "aparoquiemo": "aparoquiar",
    "aparoquiemos": "aparoquiar",
    "aparoquies": "aparoquiar",
    "aparoquio": "aparoquiar",
    "aparoquiou": "aparoquiar",
    "aparoquiá": "aparoquiar",
    "aparoquiámo": "aparoquiar",
    "aparoquiámos": "aparoquiar",
    "aparoquiáramo": "aparoquiar",
    "aparoquiáramos": "aparoquiar",
    "aparoquiárei": "aparoquiar",
    "aparoquiáreis": "aparoquiar",
    "aparoquiásseis": "aparoquiar",
    "aparoquiássemos": "aparoquiar",
    "aparoquiávamo": "aparoquiar",
    "aparoquiávamos": "aparoquiar",
    "aparoquiávei": "aparoquiar",
    "aparoquiáveis": "aparoquiar",
    "aparos": "aparo",
    "aparou": "aparar",
    "aparque": "aparcar",
    "aparquei": "aparcar",
    "aparqueis": "aparcar",
    "aparquem": "aparcar",
    "aparquemo": "aparcar",
    "aparquemos": "aparcar",
    "aparques": "aparcar",
    "aparra": "aparrar",
    "aparrada": "aparrar",
    "aparradas": "aparrar",
    "aparrado": "aparrar",
    "aparrados": "aparrar",
    "aparrai": "aparrar",
    "aparrais": "aparrar",
    "aparram": "aparrar",
    "aparramo": "aparrar",
    "aparramos": "aparrar",
    "aparrando": "aparrar",
    "aparrara": "aparrar",
    "aparraram": "aparrar",
    "aparraras": "aparrar",
    "aparrardes": "aparrar",
    "aparrarei": "aparrar",
    "aparrareis": "aparrar",
    "aparrarem": "aparrar",
    "aparraremos": "aparrar",
    "aparrares": "aparrar",
    "aparraria": "aparrar",
    "aparrariam": "aparrar",
    "aparrarias": "aparrar",
    "aparrarmo": "aparrar",
    "aparrarmos": "aparrar",
    "aparrará": "aparrar",
    "aparrarás": "aparrar",
    "aparrarão": "aparrar",
    "aparraríamos": "aparrar",
    "aparraríeis": "aparrar",
    "aparras": "aparrar",
    "aparrasse": "aparrar",
    "aparrassem": "aparrar",
    "aparrasses": "aparrar",
    "aparraste": "aparrar",
    "aparrastes": "aparrar",
    "aparrava": "aparrar",
    "aparravam": "aparrar",
    "aparravas": "aparrar",
    "aparrações": "aparração",
    "aparre": "aparrar",
    "aparrei": "aparrar",
    "aparreira": "aparreirar",
    "aparreirada": "aparreirar",
    "aparreiradas": "aparreirar",
    "aparreirado": "aparreirar",
    "aparreirados": "aparreirar",
    "aparreirai": "aparreirar",
    "aparreirais": "aparreirar",
    "aparreiram": "aparreirar",
    "aparreiramo": "aparreirar",
    "aparreiramos": "aparreirar",
    "aparreirando": "aparreirar",
    "aparreirara": "aparreirar",
    "aparreiraram": "aparreirar",
    "aparreiraras": "aparreirar",
    "aparreirarde": "aparreirar",
    "aparreirardes": "aparreirar",
    "aparreirare": "aparreirar",
    "aparreirarei": "aparreirar",
    "aparreirareis": "aparreirar",
    "aparreirarem": "aparreirar",
    "aparreiraremos": "aparreirar",
    "aparreirares": "aparreirar",
    "aparreiraria": "aparreirar",
    "aparreirariam": "aparreirar",
    "aparreirarias": "aparreirar",
    "aparreirarmo": "aparreirar",
    "aparreirarmos": "aparreirar",
    "aparreirará": "aparreirar",
    "aparreirarás": "aparreirar",
    "aparreirarão": "aparreirar",
    "aparreiraríamos": "aparreirar",
    "aparreiraríeis": "aparreirar",
    "aparreiras": "aparreirar",
    "aparreirasse": "aparreirar",
    "aparreirassem": "aparreirar",
    "aparreirasses": "aparreirar",
    "aparreiraste": "aparreirar",
    "aparreirastes": "aparreirar",
    "aparreirava": "aparreirar",
    "aparreiravam": "aparreirar",
    "aparreiravas": "aparreirar",
    "aparreire": "aparreirar",
    "aparreirei": "aparreirar",
    "aparreireis": "aparreirar",
    "aparreirem": "aparreirar",
    "aparreiremo": "aparreirar",
    "aparreiremos": "aparreirar",
    "aparreires": "aparreirar",
    "aparreiro": "aparreirar",
    "aparreirou": "aparreirar",
    "aparreirá": "aparreirar",
    "aparreirámo": "aparreirar",
    "aparreirámos": "aparreirar",
    "aparreiráramo": "aparreirar",
    "aparreiráramos": "aparreirar",
    "aparreirárei": "aparreirar",
    "aparreiráreis": "aparreirar",
    "aparreirásseis": "aparreirar",
    "aparreirássemos": "aparreirar",
    "aparreirávamo": "aparreirar",
    "aparreirávamos": "aparreirar",
    "aparreirávei": "aparreirar",
    "aparreiráveis": "aparreirar",
    "aparreis": "aparrar",
    "aparrem": "aparrar",
    "aparremo": "aparrar",
    "aparremos": "aparrar",
    "aparres": "aparrar",
    "aparro": "aparrar",
    "aparrou": "aparrar",
    "aparrámo": "aparrar",
    "aparrámos": "aparrar",
    "aparráramo": "aparrar",
    "aparráramos": "aparrar",
    "aparráreis": "aparrar",
    "aparrásseis": "aparrar",
    "aparrássemos": "aparrar",
    "aparrávamo": "aparrar",
    "aparrávamos": "aparrar",
    "aparráveis": "aparrar",
    "aparta": "apartar",
    "apartada": "apartar",
    "apartadas": "apartar",
    "apartadiça": "apartadiço",
    "apartadiças": "apartadiço",
    "apartadiços": "apartadiço",
    "apartado": "apartar",
    "apartadora": "apartador",
    "apartadoras": "apartador",
    "apartadores": "apartador",
    "apartados": "apartar",
    "apartai": "apartar",
    "apartais": "apartar",
    "apartam": "apartar",
    "apartamentos": "apartamento",
    "apartamentozinho": "apartamento",
    "apartamentozinhos": "apartamento",
    "apartamentozito": "apartamento",
    "apartamentozitos": "apartamento",
    "apartamo": "apartar",
    "apartamos": "apartar",
    "apartando": "apartar",
    "apartara": "apartar",
    "apartaram": "apartar",
    "apartaras": "apartar",
    "apartarde": "apartar",
    "apartardes": "apartar",
    "apartare": "apartar",
    "apartarei": "apartar",
    "apartareis": "apartar",
    "apartarem": "apartar",
    "apartaremos": "apartar",
    "apartares": "apartar",
    "apartaria": "apartar",
    "apartariam": "apartar",
    "apartarias": "apartar",
    "apartarmo": "apartar",
    "apartarmos": "apartar",
    "apartará": "apartar",
    "apartarás": "apartar",
    "apartarão": "apartar",
    "apartaríamos": "apartar",
    "apartaríeis": "apartar",
    "apartas": "apartar",
    "apartasse": "apartar",
    "apartassem": "apartar",
    "apartasses": "apartar",
    "apartaste": "apartar",
    "apartastes": "apartar",
    "apartava": "apartar",
    "apartavam": "apartar",
    "apartavas": "apartar",
    "apartações": "apartação",
    "aparte": "apartar",
    "apartei": "apartar",
    "aparteis": "apartar",
    "apartem": "apartar",
    "apartemo": "apartar",
    "apartemos": "apartar",
    "apartes": "aparte",
    "aparthotéis": "aparthotel",
    "apartidária": "apartidário",
    "apartidárias": "apartidário",
    "apartidários": "apartidário",
    "aparto": "apartar",
    "apartou": "apartar",
    "apartá": "apartar",
    "apartámo": "apartar",
    "apartámos": "apartar",
    "apartáramo": "apartar",
    "apartáramos": "apartar",
    "apartárei": "apartar",
    "apartáreis": "apartar",
    "apartásseis": "apartar",
    "apartássemos": "apartar",
    "apartávamo": "apartar",
    "apartávamos": "apartar",
    "apartávei": "apartar",
    "apartáveis": "apartar",
    "aparvalha": "aparvalhar",
    "aparvalhada": "aparvalhar",
    "aparvalhadas": "aparvalhar",
    "aparvalhado": "aparvalhar",
    "aparvalhados": "aparvalhar",
    "aparvalhai": "aparvalhar",
    "aparvalhais": "aparvalhar",
    "aparvalham": "aparvalhar",
    "aparvalhamo": "aparvalhar",
    "aparvalhamos": "aparvalhar",
    "aparvalhando": "aparvalhar",
    "aparvalhara": "aparvalhar",
    "aparvalharam": "aparvalhar",
    "aparvalharas": "aparvalhar",
    "aparvalharde": "aparvalhar",
    "aparvalhardes": "aparvalhar",
    "aparvalhare": "aparvalhar",
    "aparvalharei": "aparvalhar",
    "aparvalhareis": "aparvalhar",
    "aparvalharem": "aparvalhar",
    "aparvalharemos": "aparvalhar",
    "aparvalhares": "aparvalhar",
    "aparvalharia": "aparvalhar",
    "aparvalhariam": "aparvalhar",
    "aparvalharias": "aparvalhar",
    "aparvalharmo": "aparvalhar",
    "aparvalharmos": "aparvalhar",
    "aparvalhará": "aparvalhar",
    "aparvalharás": "aparvalhar",
    "aparvalharão": "aparvalhar",
    "aparvalharíamos": "aparvalhar",
    "aparvalharíeis": "aparvalhar",
    "aparvalhas": "aparvalhar",
    "aparvalhasse": "aparvalhar",
    "aparvalhassem": "aparvalhar",
    "aparvalhasses": "aparvalhar",
    "aparvalhaste": "aparvalhar",
    "aparvalhastes": "aparvalhar",
    "aparvalhava": "aparvalhar",
    "aparvalhavam": "aparvalhar",
    "aparvalhavas": "aparvalhar",
    "aparvalhe": "aparvalhar",
    "aparvalhei": "aparvalhar",
    "aparvalheis": "aparvalhar",
    "aparvalhem": "aparvalhar",
    "aparvalhemo": "aparvalhar",
    "aparvalhemos": "aparvalhar",
    "aparvalhes": "aparvalhar",
    "aparvalho": "aparvalhar",
    "aparvalhou": "aparvalhar",
    "aparvalhá": "aparvalhar",
    "aparvalhámo": "aparvalhar",
    "aparvalhámos": "aparvalhar",
    "aparvalháramo": "aparvalhar",
    "aparvalháramos": "aparvalhar",
    "aparvalhárei": "aparvalhar",
    "aparvalháreis": "aparvalhar",
    "aparvalhásseis": "aparvalhar",
    "aparvalhássemos": "aparvalhar",
    "aparvalhávamo": "aparvalhar",
    "aparvalhávamos": "aparvalhar",
    "aparvalhávei": "aparvalhar",
    "aparvalháveis": "aparvalhar",
    "aparvoamentos": "aparvoamento",
    "apará": "aparar",
    "aparámo": "aparar",
    "aparámos": "aparar",
    "aparáramo": "aparar",
    "aparáramos": "aparar",
    "aparárei": "aparar",
    "aparáreis": "aparar",
    "aparásseis": "aparar",
    "aparássemos": "aparar",
    "aparávamo": "aparar",
    "aparávamos": "aparar",
    "aparávei": "aparar",
    "aparáveis": "aparar",
    "aparências": "aparência",
    "apascenta": "apascentar",
    "apascentada": "apascentar",
    "apascentadas": "apascentar",
    "apascentado": "apascentar",
    "apascentadora": "apascentador",
    "apascentadoras": "apascentador",
    "apascentadores": "apascentador",
    "apascentados": "apascentar",
    "apascentai": "apascentar",
    "apascentais": "apascentar",
    "apascentam": "apascentar",
    "apascentamentos": "apascentamento",
    "apascentamo": "apascentar",
    "apascentamos": "apascentar",
    "apascentando": "apascentar",
    "apascentara": "apascentar",
    "apascentaram": "apascentar",
    "apascentaras": "apascentar",
    "apascentarde": "apascentar",
    "apascentardes": "apascentar",
    "apascentare": "apascentar",
    "apascentarei": "apascentar",
    "apascentareis": "apascentar",
    "apascentarem": "apascentar",
    "apascentaremos": "apascentar",
    "apascentares": "apascentar",
    "apascentaria": "apascentar",
    "apascentariam": "apascentar",
    "apascentarias": "apascentar",
    "apascentarmo": "apascentar",
    "apascentarmos": "apascentar",
    "apascentará": "apascentar",
    "apascentarás": "apascentar",
    "apascentarão": "apascentar",
    "apascentaríamos": "apascentar",
    "apascentaríeis": "apascentar",
    "apascentas": "apascentar",
    "apascentasse": "apascentar",
    "apascentassem": "apascentar",
    "apascentasses": "apascentar",
    "apascentaste": "apascentar",
    "apascentastes": "apascentar",
    "apascentava": "apascentar",
    "apascentavam": "apascentar",
    "apascentavas": "apascentar",
    "apascente": "apascentar",
    "apascentei": "apascentar",
    "apascenteis": "apascentar",
    "apascentem": "apascentar",
    "apascentemo": "apascentar",
    "apascentemos": "apascentar",
    "apascentes": "apascentar",
    "apascento": "apascentar",
    "apascentou": "apascentar",
    "apascentá": "apascentar",
    "apascentámo": "apascentar",
    "apascentámos": "apascentar",
    "apascentáramo": "apascentar",
    "apascentáramos": "apascentar",
    "apascentárei": "apascentar",
    "apascentáreis": "apascentar",
    "apascentásseis": "apascentar",
    "apascentássemos": "apascentar",
    "apascentávamo": "apascentar",
    "apascentávamos": "apascentar",
    "apascentávei": "apascentar",
    "apascentáveis": "apascentar",
    "apasquinada": "apasquinado",
    "apasquinadas": "apasquinado",
    "apasquinados": "apasquinado",
    "apassiva": "apassivar",
    "apassivada": "apassivar",
    "apassivadas": "apassivar",
    "apassivado": "apassivar",
    "apassivadora": "apassivador",
    "apassivadoras": "apassivador",
    "apassivadores": "apassivador",
    "apassivados": "apassivar",
    "apassivai": "apassivar",
    "apassivais": "apassivar",
    "apassivam": "apassivar",
    "apassivamo": "apassivar",
    "apassivamos": "apassivar",
    "apassivando": "apassivar",
    "apassivantes": "apassivante",
    "apassivara": "apassivar",
    "apassivaram": "apassivar",
    "apassivaras": "apassivar",
    "apassivarde": "apassivar",
    "apassivardes": "apassivar",
    "apassivare": "apassivar",
    "apassivarei": "apassivar",
    "apassivareis": "apassivar",
    "apassivarem": "apassivar",
    "apassivaremos": "apassivar",
    "apassivares": "apassivar",
    "apassivaria": "apassivar",
    "apassivariam": "apassivar",
    "apassivarias": "apassivar",
    "apassivarmo": "apassivar",
    "apassivarmos": "apassivar",
    "apassivará": "apassivar",
    "apassivarás": "apassivar",
    "apassivarão": "apassivar",
    "apassivaríamos": "apassivar",
    "apassivaríeis": "apassivar",
    "apassivas": "apassivar",
    "apassivasse": "apassivar",
    "apassivassem": "apassivar",
    "apassivasses": "apassivar",
    "apassivaste": "apassivar",
    "apassivastes": "apassivar",
    "apassivativa": "apassivativo",
    "apassivativas": "apassivativo",
    "apassivativos": "apassivativo",
    "apassivava": "apassivar",
    "apassivavam": "apassivar",
    "apassivavas": "apassivar",
    "apassivações": "apassivação",
    "apassive": "apassivar",
    "apassivei": "apassivar",
    "apassiveis": "apassivar",
    "apassivem": "apassivar",
    "apassivemo": "apassivar",
    "apassivemos": "apassivar",
    "apassives": "apassivar",
    "apassivo": "apassivar",
    "apassivou": "apassivar",
    "apassivá": "apassivar",
    "apassivámo": "apassivar",
    "apassivámos": "apassivar",
    "apassiváramo": "apassivar",
    "apassiváramos": "apassivar",
    "apassivárei": "apassivar",
    "apassiváreis": "apassivar",
    "apassivásseis": "apassivar",
    "apassivássemos": "apassivar",
    "apassivávamo": "apassivar",
    "apassivávamos": "apassivar",
    "apassivávei": "apassivar",
    "apassiváveis": "apassivável",
    "apatacada": "apatacado",
    "apatacadas": "apatacado",
    "apatacados": "apatacado",
    "apateta": "apatetar",
    "apatetada": "apatetar",
    "apatetadas": "apatetar",
    "apatetadinha": "apatetado",
    "apatetadinhas": "apatetado",
    "apatetadinho": "apatetado",
    "apatetadinhos": "apatetado",
    "apatetadita": "apatetado",
    "apatetaditas": "apatetado",
    "apatetadito": "apatetado",
    "apatetaditos": "apatetado",
    "apatetado": "apatetar",
    "apatetados": "apatetar",
    "apatetai": "apatetar",
    "apatetais": "apatetar",
    "apatetam": "apatetar",
    "apatetamo": "apatetar",
    "apatetamos": "apatetar",
    "apatetando": "apatetar",
    "apatetara": "apatetar",
    "apatetaram": "apatetar",
    "apatetaras": "apatetar",
    "apatetarde": "apatetar",
    "apatetardes": "apatetar",
    "apatetare": "apatetar",
    "apatetarei": "apatetar",
    "apatetareis": "apatetar",
    "apatetarem": "apatetar",
    "apatetaremos": "apatetar",
    "apatetares": "apatetar",
    "apatetaria": "apatetar",
    "apatetariam": "apatetar",
    "apatetarias": "apatetar",
    "apatetarmo": "apatetar",
    "apatetarmos": "apatetar",
    "apatetará": "apatetar",
    "apatetarás": "apatetar",
    "apatetarão": "apatetar",
    "apatetaríamos": "apatetar",
    "apatetaríeis": "apatetar",
    "apatetas": "apatetar",
    "apatetasse": "apatetar",
    "apatetassem": "apatetar",
    "apatetasses": "apatetar",
    "apatetaste": "apatetar",
    "apatetastes": "apatetar",
    "apatetava": "apatetar",
    "apatetavam": "apatetar",
    "apatetavas": "apatetar",
    "apatete": "apatetar",
    "apatetei": "apatetar",
    "apateteis": "apatetar",
    "apatetem": "apatetar",
    "apatetemo": "apatetar",
    "apatetemos": "apatetar",
    "apatetes": "apatetar",
    "apateto": "apatetar",
    "apatetou": "apatetar",
    "apatetá": "apatetar",
    "apatetámo": "apatetar",
    "apatetámos": "apatetar",
    "apatetáramo": "apatetar",
    "apatetáramos": "apatetar",
    "apatetárei": "apatetar",
    "apatetáreis": "apatetar",
    "apatetásseis": "apatetar",
    "apatetássemos": "apatetar",
    "apatetávamo": "apatetar",
    "apatetávamos": "apatetar",
    "apatetávei": "apatetar",
    "apatetáveis": "apatetar",
    "apatias": "apatia",
    "apatitas": "apatita",
    "apatites": "apatite",
    "apatriotas": "apatriota",
    "apavora": "apavorar",
    "apavorada": "apavorar",
    "apavoradas": "apavorar",
    "apavorado": "apavorar",
    "apavoradora": "apavorador",
    "apavoradoras": "apavorador",
    "apavoradores": "apavorador",
    "apavorados": "apavorar",
    "apavoradíssima": "apavorado",
    "apavoradíssimas": "apavorado",
    "apavoradíssimo": "apavorado",
    "apavoradíssimos": "apavorado",
    "apavorai": "apavorar",
    "apavorais": "apavorar",
    "apavoram": "apavorar",
    "apavoramentos": "apavoramento",
    "apavoramo": "apavorar",
    "apavoramos": "apavorar",
    "apavorando": "apavorar",
    "apavorantes": "apavorante",
    "apavorara": "apavorar",
    "apavoraram": "apavorar",
    "apavoraras": "apavorar",
    "apavorarde": "apavorar",
    "apavorardes": "apavorar",
    "apavorare": "apavorar",
    "apavorarei": "apavorar",
    "apavorareis": "apavorar",
    "apavorarem": "apavorar",
    "apavoraremos": "apavorar",
    "apavorares": "apavorar",
    "apavoraria": "apavorar",
    "apavorariam": "apavorar",
    "apavorarias": "apavorar",
    "apavorarmo": "apavorar",
    "apavorarmos": "apavorar",
    "apavorará": "apavorar",
    "apavorarás": "apavorar",
    "apavorarão": "apavorar",
    "apavoraríamos": "apavorar",
    "apavoraríeis": "apavorar",
    "apavoras": "apavorar",
    "apavorasse": "apavorar",
    "apavorassem": "apavorar",
    "apavorasses": "apavorar",
    "apavoraste": "apavorar",
    "apavorastes": "apavorar",
    "apavorava": "apavorar",
    "apavoravam": "apavorar",
    "apavoravas": "apavorar",
    "apavore": "apavorar",
    "apavorei": "apavorar",
    "apavoreis": "apavorar",
    "apavorem": "apavorar",
    "apavoremo": "apavorar",
    "apavoremos": "apavorar",
    "apavores": "apavorar",
    "apavoro": "apavorar",
    "apavorou": "apavorar",
    "apavorá": "apavorar",
    "apavorámo": "apavorar",
    "apavorámos": "apavorar",
    "apavoráramo": "apavorar",
    "apavoráramos": "apavorar",
    "apavorárei": "apavorar",
    "apavoráreis": "apavorar",
    "apavorásseis": "apavorar",
    "apavorássemos": "apavorar",
    "apavorávamo": "apavorar",
    "apavorávamos": "apavorar",
    "apavorávei": "apavorar",
    "apavoráveis": "apavorar",
    "apazigua": "apaziguar",
    "apaziguada": "apaziguar",
    "apaziguadas": "apaziguar",
    "apaziguado": "apaziguar",
    "apaziguadora": "apaziguador",
    "apaziguadoras": "apaziguador",
    "apaziguadores": "apaziguador",
    "apaziguados": "apaziguar",
    "apaziguai": "apaziguar",
    "apaziguais": "apaziguar",
    "apaziguam": "apaziguar",
    "apaziguamentos": "apaziguamento",
    "apaziguamo": "apaziguar",
    "apaziguamos": "apaziguar",
    "apaziguando": "apaziguar",
    "apaziguantes": "apaziguante",
    "apaziguara": "apaziguar",
    "apaziguaram": "apaziguar",
    "apaziguaras": "apaziguar",
    "apaziguarde": "apaziguar",
    "apaziguardes": "apaziguar",
    "apaziguare": "apaziguar",
    "apaziguarei": "apaziguar",
    "apaziguareis": "apaziguar",
    "apaziguarem": "apaziguar",
    "apaziguaremos": "apaziguar",
    "apaziguares": "apaziguar",
    "apaziguaria": "apaziguar",
    "apaziguariam": "apaziguar",
    "apaziguarias": "apaziguar",
    "apaziguarmo": "apaziguar",
    "apaziguarmos": "apaziguar",
    "apaziguará": "apaziguar",
    "apaziguarás": "apaziguar",
    "apaziguarão": "apaziguar",
    "apaziguaríamos": "apaziguar",
    "apaziguaríeis": "apaziguar",
    "apaziguas": "apaziguar",
    "apaziguasse": "apaziguar",
    "apaziguassem": "apaziguar",
    "apaziguasses": "apaziguar",
    "apaziguaste": "apaziguar",
    "apaziguastes": "apaziguar",
    "apaziguava": "apaziguar",
    "apaziguavam": "apaziguar",
    "apaziguavas": "apaziguar",
    "apaziguei": "apaziguar",
    "apazigueis": "apaziguar",
    "apaziguemo": "apaziguar",
    "apaziguemos": "apaziguar",
    "apazigues": "apaziguar",
    "apaziguo": "apaziguar",
    "apaziguou": "apaziguar",
    "apaziguá": "apaziguar",
    "apaziguámo": "apaziguar",
    "apaziguámos": "apaziguar",
    "apaziguáramo": "apaziguar",
    "apaziguáramos": "apaziguar",
    "apaziguárei": "apaziguar",
    "apaziguáreis": "apaziguar",
    "apaziguásseis": "apaziguar",
    "apaziguássemos": "apaziguar",
    "apaziguávamo": "apaziguar",
    "apaziguávamos": "apaziguar",
    "apaziguávei": "apaziguar",
    "apaziguáveis": "apaziguável",
    "apazigúe": "apaziguar",
    "apazigúem": "apaziguar",
    "apazigúes": "apaziguar",
    "apaúlos": "apaúlo",
    "apeada": "apear",
    "apeadas": "apear",
    "apeadeiras": "apeadeira",
    "apeadeiros": "apeadeiro",
    "apeado": "apear",
    "apeados": "apear",
    "apeadíssima": "apeado",
    "apeadíssimas": "apeado",
    "apeadíssimo": "apeado",
    "apeadíssimos": "apeado",
    "apeai": "apear",
    "apeais": "apear",
    "apeamentos": "apeamento",
    "apeamo": "apear",
    "apeamos": "apear",
    "apeando": "apear",
    "apeanhas": "apeanha",
    "apeara": "apear",
    "apearam": "apear",
    "apearas": "apear",
    "apearde": "apear",
    "apeardes": "apear",
    "apeare": "apear",
    "apearei": "apear",
    "apeareis": "apear",
    "apearem": "apear",
    "apearemos": "apear",
    "apeares": "apear",
    "apearia": "apear",
    "apeariam": "apear",
    "apearias": "apear",
    "apearmo": "apear",
    "apearmos": "apear",
    "apeará": "apear",
    "apearás": "apear",
    "apearão": "apear",
    "apearíamos": "apear",
    "apearíeis": "apear",
    "apeasse": "apear",
    "apeassem": "apear",
    "apeasses": "apear",
    "apeaste": "apear",
    "apeastes": "apear",
    "apeava": "apear",
    "apeavam": "apear",
    "apeavas": "apear",
    "apeaças": "apeaça",
    "apedada": "apedado",
    "apedadas": "apedado",
    "apedados": "apedado",
    "apedantada": "apedantado",
    "apedantadas": "apedantado",
    "apedantados": "apedantado",
    "apedeuta": "apedeuto",
    "apedeutas": "apedeuto",
    "apedeutismos": "apedeutismo",
    "apedeutos": "apedeuto",
    "apedicelada": "apedicelado",
    "apediceladas": "apedicelado",
    "apedicelados": "apedicelado",
    "apedramentos": "apedramento",
    "apedreja": "apedrejar",
    "apedrejada": "apedrejar",
    "apedrejadas": "apedrejar",
    "apedrejado": "apedrejar",
    "apedrejadora": "apedrejador",
    "apedrejadoras": "apedrejador",
    "apedrejadores": "apedrejador",
    "apedrejados": "apedrejar",
    "apedrejai": "apedrejar",
    "apedrejais": "apedrejar",
    "apedrejam": "apedrejar",
    "apedrejamentos": "apedrejamento",
    "apedrejamo": "apedrejar",
    "apedrejamos": "apedrejar",
    "apedrejando": "apedrejar",
    "apedrejara": "apedrejar",
    "apedrejaram": "apedrejar",
    "apedrejaras": "apedrejar",
    "apedrejarde": "apedrejar",
    "apedrejardes": "apedrejar",
    "apedrejare": "apedrejar",
    "apedrejarei": "apedrejar",
    "apedrejareis": "apedrejar",
    "apedrejarem": "apedrejar",
    "apedrejaremos": "apedrejar",
    "apedrejares": "apedrejar",
    "apedrejaria": "apedrejar",
    "apedrejariam": "apedrejar",
    "apedrejarias": "apedrejar",
    "apedrejarmo": "apedrejar",
    "apedrejarmos": "apedrejar",
    "apedrejará": "apedrejar",
    "apedrejarás": "apedrejar",
    "apedrejarão": "apedrejar",
    "apedrejaríamos": "apedrejar",
    "apedrejaríeis": "apedrejar",
    "apedrejas": "apedrejar",
    "apedrejasse": "apedrejar",
    "apedrejassem": "apedrejar",
    "apedrejasses": "apedrejar",
    "apedrejaste": "apedrejar",
    "apedrejastes": "apedrejar",
    "apedrejava": "apedrejar",
    "apedrejavam": "apedrejar",
    "apedrejavas": "apedrejar",
    "apedreje": "apedrejar",
    "apedrejei": "apedrejar",
    "apedrejeis": "apedrejar",
    "apedrejem": "apedrejar",
    "apedrejemo": "apedrejar",
    "apedrejemos": "apedrejar",
    "apedrejes": "apedrejar",
    "apedrejo": "apedrejar",
    "apedrejou": "apedrejar",
    "apedrejá": "apedrejar",
    "apedrejámo": "apedrejar",
    "apedrejámos": "apedrejar",
    "apedrejáramo": "apedrejar",
    "apedrejáramos": "apedrejar",
    "apedrejárei": "apedrejar",
    "apedrejáreis": "apedrejar",
    "apedrejásseis": "apedrejar",
    "apedrejássemos": "apedrejar",
    "apedrejávamo": "apedrejar",
    "apedrejávamos": "apedrejar",
    "apedrejávei": "apedrejar",
    "apedrejáveis": "apedrejar",
    "apeei": "apear",
    "apeeis": "apear",
    "apeemo": "apear",
    "apeemos": "apear",
    "apega": "apegar",
    "apegada": "apegar",
    "apegadas": "apegar",
    "apegadiça": "apegadiço",
    "apegadiças": "apegadiço",
    "apegadiços": "apegadiço",
    "apegado": "apegar",
    "apegadora": "apegador",
    "apegadoras": "apegador",
    "apegadores": "apegador",
    "apegados": "apegar",
    "apegai": "apegar",
    "apegais": "apegar",
    "apegam": "apegar",
    "apegamentos": "apegamento",
    "apegamo": "apegar",
    "apegamos": "apegar",
    "apegando": "apegar",
    "apegara": "apegar",
    "apegaram": "apegar",
    "apegaras": "apegar",
    "apegarde": "apegar",
    "apegardes": "apegar",
    "apegare": "apegar",
    "apegarei": "apegar",
    "apegareis": "apegar",
    "apegarem": "apegar",
    "apegaremos": "apegar",
    "apegares": "apegar",
    "apegaria": "apegar",
    "apegariam": "apegar",
    "apegarias": "apegar",
    "apegarmo": "apegar",
    "apegarmos": "apegar",
    "apegará": "apegar",
    "apegarás": "apegar",
    "apegarão": "apegar",
    "apegaríamos": "apegar",
    "apegaríeis": "apegar",
    "apegas": "apegar",
    "apegasse": "apegar",
    "apegassem": "apegar",
    "apegasses": "apegar",
    "apegaste": "apegar",
    "apegastes": "apegar",
    "apegava": "apegar",
    "apegavam": "apegar",
    "apegavas": "apegar",
    "apegações": "apegação",
    "apego": "apegar",
    "apegos": "apego",
    "apegou": "apegar",
    "apegue": "apegar",
    "apeguei": "apegar",
    "apegueis": "apegar",
    "apeguem": "apegar",
    "apeguemo": "apegar",
    "apeguemos": "apegar",
    "apegues": "apegar",
    "apeguilhos": "apeguilho",
    "apegá": "apegar",
    "apegámo": "apegar",
    "apegámos": "apegar",
    "apegáramo": "apegar",
    "apegáramos": "apegar",
    "apegárei": "apegar",
    "apegáreis": "apegar",
    "apegásseis": "apegar",
    "apegássemos": "apegar",
    "apegávamo": "apegar",
    "apegávamos": "apegar",
    "apegávei": "apegar",
    "apegáveis": "apegar",
    "apeia": "apear",
    "apeiam": "apear",
    "apeias": "apear",
    "apeie": "apear",
    "apeiem": "apear",
    "apeies": "apear",
    "apeio": "apear",
    "apeiradora": "apeirador",
    "apeiradoras": "apeirador",
    "apeiradores": "apeirador",
    "apeiragens": "apeiragem",
    "apeirias": "apeiria",
    "apeiros": "apeiro",
    "apeja": "apejar",
    "apejada": "apejar",
    "apejadas": "apejar",
    "apejado": "apejar",
    "apejados": "apejar",
    "apejai": "apejar",
    "apejais": "apejar",
    "apejam": "apejar",
    "apejamo": "apejar",
    "apejamos": "apejar",
    "apejando": "apejar",
    "apejara": "apejar",
    "apejaram": "apejar",
    "apejaras": "apejar",
    "apejarde": "apejar",
    "apejardes": "apejar",
    "apejare": "apejar",
    "apejarei": "apejar",
    "apejareis": "apejar",
    "apejarem": "apejar",
    "apejaremos": "apejar",
    "apejares": "apejar",
    "apejaria": "apejar",
    "apejariam": "apejar",
    "apejarias": "apejar",
    "apejarmo": "apejar",
    "apejarmos": "apejar",
    "apejará": "apejar",
    "apejarás": "apejar",
    "apejarão": "apejar",
    "apejaríamos": "apejar",
    "apejaríeis": "apejar",
    "apejas": "apejar",
    "apejasse": "apejar",
    "apejassem": "apejar",
    "apejasses": "apejar",
    "apejaste": "apejar",
    "apejastes": "apejar",
    "apejava": "apejar",
    "apejavam": "apejar",
    "apejavas": "apejar",
    "apeje": "apejar",
    "apejei": "apejar",
    "apejeis": "apejar",
    "apejem": "apejar",
    "apejemo": "apejar",
    "apejemos": "apejar",
    "apejes": "apejar",
    "apejo": "apejar",
    "apejou": "apejar",
    "apejá": "apejar",
    "apejámo": "apejar",
    "apejámos": "apejar",
    "apejáramo": "apejar",
    "apejáramos": "apejar",
    "apejárei": "apejar",
    "apejáreis": "apejar",
    "apejásseis": "apejar",
    "apejássemos": "apejar",
    "apejávamo": "apejar",
    "apejávamos": "apejar",
    "apejávei": "apejar",
    "apejáveis": "apejar",
    "apela": "apelar",
    "apelabilidades": "apelabilidade",
    "apelada": "apelar",
    "apeladas": "apelar",
    "apelado": "apelar",
    "apeladora": "apelador",
    "apeladoras": "apelador",
    "apeladores": "apelador",
    "apelados": "apelar",
    "apelai": "apelar",
    "apelais": "apelar",
    "apelam": "apelar",
    "apelamentos": "apelamento",
    "apelamo": "apelar",
    "apelamos": "apelar",
    "apelando": "apelar",
    "apelantes": "apelante",
    "apelara": "apelar",
    "apelaram": "apelar",
    "apelaras": "apelar",
    "apelarde": "apelar",
    "apelardes": "apelar",
    "apelare": "apelar",
    "apelarei": "apelar",
    "apelareis": "apelar",
    "apelarem": "apelar",
    "apelaremos": "apelar",
    "apelares": "apelar",
    "apelaria": "apelar",
    "apelariam": "apelar",
    "apelarias": "apelar",
    "apelarmo": "apelar",
    "apelarmos": "apelar",
    "apelará": "apelar",
    "apelarás": "apelar",
    "apelarão": "apelar",
    "apelaríamos": "apelar",
    "apelaríeis": "apelar",
    "apelas": "apelar",
    "apelasse": "apelar",
    "apelassem": "apelar",
    "apelasses": "apelar",
    "apelaste": "apelar",
    "apelastes": "apelar",
    "apelativa": "apelativo",
    "apelativas": "apelativo",
    "apelativos": "apelativo",
    "apelatória": "apelatório",
    "apelatórias": "apelatório",
    "apelatórios": "apelatório",
    "apelava": "apelar",
    "apelavam": "apelar",
    "apelavas": "apelar",
    "apelações": "apelação",
    "apele": "apelar",
    "apelei": "apelar",
    "apeleis": "apelar",
    "apelem": "apelar",
    "apelemo": "apelar",
    "apelemos": "apelar",
    "apeles": "apelar",
    "apelida": "apelidar",
    "apelidada": "apelidar",
    "apelidadas": "apelidar",
    "apelidado": "apelidar",
    "apelidados": "apelidar",
    "apelidai": "apelidar",
    "apelidais": "apelidar",
    "apelidam": "apelidar",
    "apelidamo": "apelidar",
    "apelidamos": "apelidar",
    "apelidando": "apelidar",
    "apelidara": "apelidar",
    "apelidaram": "apelidar",
    "apelidaras": "apelidar",
    "apelidarde": "apelidar",
    "apelidardes": "apelidar",
    "apelidare": "apelidar",
    "apelidarei": "apelidar",
    "apelidareis": "apelidar",
    "apelidarem": "apelidar",
    "apelidaremos": "apelidar",
    "apelidares": "apelidar",
    "apelidaria": "apelidar",
    "apelidariam": "apelidar",
    "apelidarias": "apelidar",
    "apelidarmo": "apelidar",
    "apelidarmos": "apelidar",
    "apelidará": "apelidar",
    "apelidarás": "apelidar",
    "apelidarão": "apelidar",
    "apelidaríamos": "apelidar",
    "apelidaríeis": "apelidar",
    "apelidas": "apelidar",
    "apelidasse": "apelidar",
    "apelidassem": "apelidar",
    "apelidasses": "apelidar",
    "apelidaste": "apelidar",
    "apelidastes": "apelidar",
    "apelidava": "apelidar",
    "apelidavam": "apelidar",
    "apelidavas": "apelidar",
    "apelidações": "apelidação",
    "apelide": "apelidar",
    "apelidei": "apelidar",
    "apelideis": "apelidar",
    "apelidem": "apelidar",
    "apelidemo": "apelidar",
    "apelidemos": "apelidar",
    "apelides": "apelidar",
    "apelido": "apelidar",
    "apelidos": "apelido",
    "apelidou": "apelidar",
    "apelidá": "apelidar",
    "apelidámo": "apelidar",
    "apelidámos": "apelidar",
    "apelidáramo": "apelidar",
    "apelidáramos": "apelidar",
    "apelidárei": "apelidar",
    "apelidáreis": "apelidar",
    "apelidásseis": "apelidar",
    "apelidássemos": "apelidar",
    "apelidávamo": "apelidar",
    "apelidávamos": "apelidar",
    "apelidávei": "apelidar",
    "apelidáveis": "apelidar",
    "apelintra": "apelintrar",
    "apelintrada": "apelintrar",
    "apelintradas": "apelintrar",
    "apelintrado": "apelintrar",
    "apelintrados": "apelintrar",
    "apelintrai": "apelintrar",
    "apelintrais": "apelintrar",
    "apelintram": "apelintrar",
    "apelintramo": "apelintrar",
    "apelintramos": "apelintrar",
    "apelintrando": "apelintrar",
    "apelintrara": "apelintrar",
    "apelintraram": "apelintrar",
    "apelintraras": "apelintrar",
    "apelintrarde": "apelintrar",
    "apelintrardes": "apelintrar",
    "apelintrare": "apelintrar",
    "apelintrarei": "apelintrar",
    "apelintrareis": "apelintrar",
    "apelintrarem": "apelintrar",
    "apelintraremos": "apelintrar",
    "apelintrares": "apelintrar",
    "apelintraria": "apelintrar",
    "apelintrariam": "apelintrar",
    "apelintrarias": "apelintrar",
    "apelintrarmo": "apelintrar",
    "apelintrarmos": "apelintrar",
    "apelintrará": "apelintrar",
    "apelintrarás": "apelintrar",
    "apelintrarão": "apelintrar",
    "apelintraríamos": "apelintrar",
    "apelintraríeis": "apelintrar",
    "apelintras": "apelintrar",
    "apelintrasse": "apelintrar",
    "apelintrassem": "apelintrar",
    "apelintrasses": "apelintrar",
    "apelintraste": "apelintrar",
    "apelintrastes": "apelintrar",
    "apelintrava": "apelintrar",
    "apelintravam": "apelintrar",
    "apelintravas": "apelintrar",
    "apelintre": "apelintrar",
    "apelintrei": "apelintrar",
    "apelintreis": "apelintrar",
    "apelintrem": "apelintrar",
    "apelintremo": "apelintrar",
    "apelintremos": "apelintrar",
    "apelintres": "apelintrar",
    "apelintro": "apelintrar",
    "apelintrou": "apelintrar",
    "apelintrá": "apelintrar",
    "apelintrámo": "apelintrar",
    "apelintrámos": "apelintrar",
    "apelintráramo": "apelintrar",
    "apelintráramos": "apelintrar",
    "apelintrárei": "apelintrar",
    "apelintráreis": "apelintrar",
    "apelintrásseis": "apelintrar",
    "apelintrássemos": "apelintrar",
    "apelintrávamo": "apelintrar",
    "apelintrávamos": "apelintrar",
    "apelintrávei": "apelintrar",
    "apelintráveis": "apelintrar",
    "apelo": "apelar",
    "apelos": "apelo",
    "apelou": "apelar",
    "apelá": "apelar",
    "apelámo": "apelar",
    "apelámos": "apelar",
    "apeláramo": "apelar",
    "apeláramos": "apelar",
    "apelárei": "apelar",
    "apeláreis": "apelar",
    "apelásseis": "apelar",
    "apelássemos": "apelar",
    "apelávamo": "apelar",
    "apelávamos": "apelar",
    "apelávei": "apelar",
    "apeláveis": "apelável",
    "apenda": "apender",
    "apendais": "apender",
    "apendam": "apender",
    "apendamo": "apender",
    "apendamos": "apender",
    "apendas": "apender",
    "apende": "apender",
    "apendei": "apender",
    "apendeis": "apender",
    "apendem": "apender",
    "apendemo": "apender",
    "apendemos": "apender",
    "apendendo": "apender",
    "apendera": "apender",
    "apenderam": "apender",
    "apenderas": "apender",
    "apenderde": "apender",
    "apenderdes": "apender",
    "apendere": "apender",
    "apenderei": "apender",
    "apendereis": "apender",
    "apenderem": "apender",
    "apenderemos": "apender",
    "apenderes": "apender",
    "apenderia": "apender",
    "apenderiam": "apender",
    "apenderias": "apender",
    "apendermo": "apender",
    "apendermos": "apender",
    "apenderá": "apender",
    "apenderás": "apender",
    "apenderão": "apender",
    "apenderíamos": "apender",
    "apenderíeis": "apender",
    "apendes": "apender",
    "apendesse": "apender",
    "apendessem": "apender",
    "apendesses": "apender",
    "apendeste": "apender",
    "apendestes": "apender",
    "apendeu": "apender",
    "apendi": "apender",
    "apendia": "apender",
    "apendiam": "apender",
    "apendias": "apender",
    "apendicalgias": "apendicalgia",
    "apendicectomias": "apendicectomia",
    "apendiciada": "apendiciado",
    "apendiciadas": "apendiciado",
    "apendiciados": "apendiciado",
    "apendiciformes": "apendiciforme",
    "apendicites": "apendicite",
    "apendicografias": "apendicografia",
    "apendiculada": "apendiculado",
    "apendiculadas": "apendiculado",
    "apendiculados": "apendiculado",
    "apendiculares": "apendicular",
    "apendiculária": "apendiculário",
    "apendiculárias": "apendiculário",
    "apendiculários": "apendiculário",
    "apendida": "apender",
    "apendidas": "apender",
    "apendido": "apender",
    "apendidos": "apender",
    "apendo": "apender",
    "apendoamentos": "apendoamento",
    "apendê": "apender",
    "apendências": "apendência",
    "apendêramo": "apender",
    "apendêramos": "apender",
    "apendêrei": "apender",
    "apendêreis": "apender",
    "apendêsseis": "apender",
    "apendêssemos": "apender",
    "apendíamo": "apender",
    "apendíamos": "apender",
    "apendículos": "apendículo",
    "apendíei": "apender",
    "apendíeis": "apender",
    "apenhamentos": "apenhamento",
    "apenhascada": "apenhascado",
    "apenhascadas": "apenhascado",
    "apenhascados": "apenhascado",
    "apeninsulada": "apeninsulado",
    "apeninsuladas": "apeninsulado",
    "apeninsulados": "apeninsulado",
    "apensa": "apenso",
    "apensamentos": "apensamento",
    "apensas": "apenso",
    "apensações": "apensação",
    "apensos": "apenso",
    "apenumbra": "apenumbrar",
    "apenumbrada": "apenumbrar",
    "apenumbradas": "apenumbrar",
    "apenumbrado": "apenumbrar",
    "apenumbrados": "apenumbrar",
    "apenumbrai": "apenumbrar",
    "apenumbrais": "apenumbrar",
    "apenumbram": "apenumbrar",
    "apenumbramo": "apenumbrar",
    "apenumbramos": "apenumbrar",
    "apenumbrando": "apenumbrar",
    "apenumbrara": "apenumbrar",
    "apenumbraram": "apenumbrar",
    "apenumbraras": "apenumbrar",
    "apenumbrarde": "apenumbrar",
    "apenumbrardes": "apenumbrar",
    "apenumbrare": "apenumbrar",
    "apenumbrarei": "apenumbrar",
    "apenumbrareis": "apenumbrar",
    "apenumbrarem": "apenumbrar",
    "apenumbraremos": "apenumbrar",
    "apenumbrares": "apenumbrar",
    "apenumbraria": "apenumbrar",
    "apenumbrariam": "apenumbrar",
    "apenumbrarias": "apenumbrar",
    "apenumbrarmo": "apenumbrar",
    "apenumbrarmos": "apenumbrar",
    "apenumbrará": "apenumbrar",
    "apenumbrarás": "apenumbrar",
    "apenumbrarão": "apenumbrar",
    "apenumbraríamos": "apenumbrar",
    "apenumbraríeis": "apenumbrar",
    "apenumbras": "apenumbrar",
    "apenumbrasse": "apenumbrar",
    "apenumbrassem": "apenumbrar",
    "apenumbrasses": "apenumbrar",
    "apenumbraste": "apenumbrar",
    "apenumbrastes": "apenumbrar",
    "apenumbrava": "apenumbrar",
    "apenumbravam": "apenumbrar",
    "apenumbravas": "apenumbrar",
    "apenumbre": "apenumbrar",
    "apenumbrei": "apenumbrar",
    "apenumbreis": "apenumbrar",
    "apenumbrem": "apenumbrar",
    "apenumbremo": "apenumbrar",
    "apenumbremos": "apenumbrar",
    "apenumbres": "apenumbrar",
    "apenumbro": "apenumbrar",
    "apenumbrou": "apenumbrar",
    "apenumbrá": "apenumbrar",
    "apenumbrámo": "apenumbrar",
    "apenumbrámos": "apenumbrar",
    "apenumbráramo": "apenumbrar",
    "apenumbráramos": "apenumbrar",
    "apenumbrárei": "apenumbrar",
    "apenumbráreis": "apenumbrar",
    "apenumbrásseis": "apenumbrar",
    "apenumbrássemos": "apenumbrar",
    "apenumbrávamo": "apenumbrar",
    "apenumbrávamos": "apenumbrar",
    "apenumbrávei": "apenumbrar",
    "apenumbráveis": "apenumbrar",
    "apeou": "apear",
    "apepinada": "apepinado",
    "apepinadas": "apepinado",
    "apepinados": "apepinado",
    "apepinações": "apepinação",
    "apepsias": "apepsia",
    "apequena": "apequenar",
    "apequenada": "apequenar",
    "apequenadas": "apequenar",
    "apequenado": "apequenar",
    "apequenados": "apequenar",
    "apequenai": "apequenar",
    "apequenais": "apequenar",
    "apequenam": "apequenar",
    "apequenamo": "apequenar",
    "apequenamos": "apequenar",
    "apequenando": "apequenar",
    "apequenara": "apequenar",
    "apequenaram": "apequenar",
    "apequenaras": "apequenar",
    "apequenarde": "apequenar",
    "apequenardes": "apequenar",
    "apequenare": "apequenar",
    "apequenarei": "apequenar",
    "apequenareis": "apequenar",
    "apequenarem": "apequenar",
    "apequenaremos": "apequenar",
    "apequenares": "apequenar",
    "apequenaria": "apequenar",
    "apequenariam": "apequenar",
    "apequenarias": "apequenar",
    "apequenarmo": "apequenar",
    "apequenarmos": "apequenar",
    "apequenará": "apequenar",
    "apequenarás": "apequenar",
    "apequenarão": "apequenar",
    "apequenaríamos": "apequenar",
    "apequenaríeis": "apequenar",
    "apequenas": "apequenar",
    "apequenasse": "apequenar",
    "apequenassem": "apequenar",
    "apequenasses": "apequenar",
    "apequenaste": "apequenar",
    "apequenastes": "apequenar",
    "apequenava": "apequenar",
    "apequenavam": "apequenar",
    "apequenavas": "apequenar",
    "apequene": "apequenar",
    "apequenei": "apequenar",
    "apequeneis": "apequenar",
    "apequenem": "apequenar",
    "apequenemo": "apequenar",
    "apequenemos": "apequenar",
    "apequenes": "apequenar",
    "apequeno": "apequenar",
    "apequenou": "apequenar",
    "apequená": "apequenar",
    "apequenámo": "apequenar",
    "apequenámos": "apequenar",
    "apequenáramo": "apequenar",
    "apequenáramos": "apequenar",
    "apequenárei": "apequenar",
    "apequenáreis": "apequenar",
    "apequenásseis": "apequenar",
    "apequenássemos": "apequenar",
    "apequenávamo": "apequenar",
    "apequenávamos": "apequenar",
    "apequenávei": "apequenar",
    "apequenáveis": "apequenar",
    "aperalta": "aperaltar",
    "aperaltada": "aperaltar",
    "aperaltadas": "aperaltar",
    "aperaltado": "aperaltar",
    "aperaltados": "aperaltar",
    "aperaltai": "aperaltar",
    "aperaltais": "aperaltar",
    "aperaltam": "aperaltar",
    "aperaltamo": "aperaltar",
    "aperaltamos": "aperaltar",
    "aperaltando": "aperaltar",
    "aperaltara": "aperaltar",
    "aperaltaram": "aperaltar",
    "aperaltaras": "aperaltar",
    "aperaltarde": "aperaltar",
    "aperaltardes": "aperaltar",
    "aperaltare": "aperaltar",
    "aperaltarei": "aperaltar",
    "aperaltareis": "aperaltar",
    "aperaltarem": "aperaltar",
    "aperaltaremos": "aperaltar",
    "aperaltares": "aperaltar",
    "aperaltaria": "aperaltar",
    "aperaltariam": "aperaltar",
    "aperaltarias": "aperaltar",
    "aperaltarmo": "aperaltar",
    "aperaltarmos": "aperaltar",
    "aperaltará": "aperaltar",
    "aperaltarás": "aperaltar",
    "aperaltarão": "aperaltar",
    "aperaltaríamos": "aperaltar",
    "aperaltaríeis": "aperaltar",
    "aperaltas": "aperaltar",
    "aperaltasse": "aperaltar",
    "aperaltassem": "aperaltar",
    "aperaltasses": "aperaltar",
    "aperaltaste": "aperaltar",
    "aperaltastes": "aperaltar",
    "aperaltava": "aperaltar",
    "aperaltavam": "aperaltar",
    "aperaltavas": "aperaltar",
    "aperalte": "aperaltar",
    "aperaltei": "aperaltar",
    "aperalteis": "aperaltar",
    "aperaltem": "aperaltar",
    "aperaltemo": "aperaltar",
    "aperaltemos": "aperaltar",
    "aperaltes": "aperaltar",
    "aperalto": "aperaltar",
    "aperaltou": "aperaltar",
    "aperaltá": "aperaltar",
    "aperaltámo": "aperaltar",
    "aperaltámos": "aperaltar",
    "aperaltáramo": "aperaltar",
    "aperaltáramos": "aperaltar",
    "aperaltárei": "aperaltar",
    "aperaltáreis": "aperaltar",
    "aperaltásseis": "aperaltar",
    "aperaltássemos": "aperaltar",
    "aperaltávamo": "aperaltar",
    "aperaltávamos": "aperaltar",
    "aperaltávei": "aperaltar",
    "aperaltáveis": "aperaltar",
    "aperceba": "aperceber",
    "apercebais": "aperceber",
    "apercebam": "aperceber",
    "apercebamo": "aperceber",
    "apercebamos": "aperceber",
    "apercebas": "aperceber",
    "apercebe": "aperceber",
    "apercebei": "aperceber",
    "apercebeis": "aperceber",
    "apercebem": "aperceber",
    "apercebemo": "aperceber",
    "apercebemos": "aperceber",
    "apercebendo": "aperceber",
    "apercebera": "aperceber",
    "aperceberam": "aperceber",
    "aperceberas": "aperceber",
    "aperceberdes": "aperceber",
    "aperceberei": "aperceber",
    "apercebereis": "aperceber",
    "aperceberem": "aperceber",
    "aperceberemos": "aperceber",
    "aperceberes": "aperceber",
    "aperceberia": "aperceber",
    "aperceberiam": "aperceber",
    "aperceberias": "aperceber",
    "apercebermo": "aperceber",
    "apercebermos": "aperceber",
    "aperceberá": "aperceber",
    "aperceberás": "aperceber",
    "aperceberão": "aperceber",
    "aperceberíamos": "aperceber",
    "aperceberíeis": "aperceber",
    "apercebes": "aperceber",
    "apercebesse": "aperceber",
    "apercebessem": "aperceber",
    "apercebesses": "aperceber",
    "apercebeste": "aperceber",
    "apercebestes": "aperceber",
    "apercebeu": "aperceber",
    "apercebi": "aperceber",
    "apercebia": "aperceber",
    "apercebiam": "aperceber",
    "apercebias": "aperceber",
    "apercebida": "apercebido",
    "apercebidas": "apercebido",
    "apercebido": "aperceber",
    "apercebidos": "apercebido",
    "apercebimentos": "apercebimento",
    "apercebo": "aperceber",
    "apercebêramo": "aperceber",
    "apercebêramos": "aperceber",
    "apercebêreis": "aperceber",
    "apercebêsseis": "aperceber",
    "apercebêssemos": "aperceber",
    "apercebíamo": "aperceber",
    "apercebíamos": "aperceber",
    "apercebíeis": "aperceber",
    "aperceptabilidades": "aperceptabilidade",
    "aperceptiva": "aperceptivo",
    "aperceptivas": "aperceptivo",
    "aperceptivos": "aperceptivo",
    "aperceptíveis": "aperceptível",
    "apercepções": "apercepção",
    "aperfeiçoa": "aperfeiçoar",
    "aperfeiçoada": "aperfeiçoar",
    "aperfeiçoadas": "aperfeiçoar",
    "aperfeiçoado": "aperfeiçoar",
    "aperfeiçoadora": "aperfeiçoador",
    "aperfeiçoadoras": "aperfeiçoador",
    "aperfeiçoadores": "aperfeiçoador",
    "aperfeiçoados": "aperfeiçoar",
    "aperfeiçoai": "aperfeiçoar",
    "aperfeiçoais": "aperfeiçoar",
    "aperfeiçoam": "aperfeiçoar",
    "aperfeiçoamentos": "aperfeiçoamento",
    "aperfeiçoamo": "aperfeiçoar",
    "aperfeiçoamos": "aperfeiçoar",
    "aperfeiçoando": "aperfeiçoar",
    "aperfeiçoara": "aperfeiçoar",
    "aperfeiçoaram": "aperfeiçoar",
    "aperfeiçoaras": "aperfeiçoar",
    "aperfeiçoarde": "aperfeiçoar",
    "aperfeiçoardes": "aperfeiçoar",
    "aperfeiçoare": "aperfeiçoar",
    "aperfeiçoarei": "aperfeiçoar",
    "aperfeiçoareis": "aperfeiçoar",
    "aperfeiçoarem": "aperfeiçoar",
    "aperfeiçoaremos": "aperfeiçoar",
    "aperfeiçoares": "aperfeiçoar",
    "aperfeiçoaria": "aperfeiçoar",
    "aperfeiçoariam": "aperfeiçoar",
    "aperfeiçoarias": "aperfeiçoar",
    "aperfeiçoarmo": "aperfeiçoar",
    "aperfeiçoarmos": "aperfeiçoar",
    "aperfeiçoará": "aperfeiçoar",
    "aperfeiçoarás": "aperfeiçoar",
    "aperfeiçoarão": "aperfeiçoar",
    "aperfeiçoaríamos": "aperfeiçoar",
    "aperfeiçoaríeis": "aperfeiçoar",
    "aperfeiçoas": "aperfeiçoar",
    "aperfeiçoasse": "aperfeiçoar",
    "aperfeiçoassem": "aperfeiçoar",
    "aperfeiçoasses": "aperfeiçoar",
    "aperfeiçoaste": "aperfeiçoar",
    "aperfeiçoastes": "aperfeiçoar",
    "aperfeiçoava": "aperfeiçoar",
    "aperfeiçoavam": "aperfeiçoar",
    "aperfeiçoavas": "aperfeiçoar",
    "aperfeiçoe": "aperfeiçoar",
    "aperfeiçoei": "aperfeiçoar",
    "aperfeiçoeis": "aperfeiçoar",
    "aperfeiçoem": "aperfeiçoar",
    "aperfeiçoemo": "aperfeiçoar",
    "aperfeiçoemos": "aperfeiçoar",
    "aperfeiçoes": "aperfeiçoar",
    "aperfeiçoo": "aperfeiçoar",
    "aperfeiçoou": "aperfeiçoar",
    "aperfeiçoá": "aperfeiçoar",
    "aperfeiçoámo": "aperfeiçoar",
    "aperfeiçoámos": "aperfeiçoar",
    "aperfeiçoáramo": "aperfeiçoar",
    "aperfeiçoáramos": "aperfeiçoar",
    "aperfeiçoárei": "aperfeiçoar",
    "aperfeiçoáreis": "aperfeiçoar",
    "aperfeiçoásseis": "aperfeiçoar",
    "aperfeiçoássemos": "aperfeiçoar",
    "aperfeiçoávamo": "aperfeiçoar",
    "aperfeiçoávamos": "aperfeiçoar",
    "aperfeiçoávei": "aperfeiçoar",
    "aperfeiçoáveis": "aperfeiçoável",
    "aperfilha": "aperfilhar",
    "aperfilhada": "aperfilhar",
    "aperfilhadas": "aperfilhar",
    "aperfilhado": "aperfilhar",
    "aperfilhados": "aperfilhar",
    "aperfilhai": "aperfilhar",
    "aperfilhais": "aperfilhar",
    "aperfilham": "aperfilhar",
    "aperfilhamo": "aperfilhar",
    "aperfilhamos": "aperfilhar",
    "aperfilhando": "aperfilhar",
    "aperfilhara": "aperfilhar",
    "aperfilharam": "aperfilhar",
    "aperfilharas": "aperfilhar",
    "aperfilharde": "aperfilhar",
    "aperfilhardes": "aperfilhar",
    "aperfilhare": "aperfilhar",
    "aperfilharei": "aperfilhar",
    "aperfilhareis": "aperfilhar",
    "aperfilharem": "aperfilhar",
    "aperfilharemos": "aperfilhar",
    "aperfilhares": "aperfilhar",
    "aperfilharia": "aperfilhar",
    "aperfilhariam": "aperfilhar",
    "aperfilharias": "aperfilhar",
    "aperfilharmo": "aperfilhar",
    "aperfilharmos": "aperfilhar",
    "aperfilhará": "aperfilhar",
    "aperfilharás": "aperfilhar",
    "aperfilharão": "aperfilhar",
    "aperfilharíamos": "aperfilhar",
    "aperfilharíeis": "aperfilhar",
    "aperfilhas": "aperfilhar",
    "aperfilhasse": "aperfilhar",
    "aperfilhassem": "aperfilhar",
    "aperfilhasses": "aperfilhar",
    "aperfilhaste": "aperfilhar",
    "aperfilhastes": "aperfilhar",
    "aperfilhava": "aperfilhar",
    "aperfilhavam": "aperfilhar",
    "aperfilhavas": "aperfilhar",
    "aperfilhe": "aperfilhar",
    "aperfilhei": "aperfilhar",
    "aperfilheis": "aperfilhar",
    "aperfilhem": "aperfilhar",
    "aperfilhemo": "aperfilhar",
    "aperfilhemos": "aperfilhar",
    "aperfilhes": "aperfilhar",
    "aperfilho": "aperfilhar",
    "aperfilhou": "aperfilhar",
    "aperfilhá": "aperfilhar",
    "aperfilhámo": "aperfilhar",
    "aperfilhámos": "aperfilhar",
    "aperfilháramo": "aperfilhar",
    "aperfilháramos": "aperfilhar",
    "aperfilhárei": "aperfilhar",
    "aperfilháreis": "aperfilhar",
    "aperfilhásseis": "aperfilhar",
    "aperfilhássemos": "aperfilhar",
    "aperfilhávamo": "aperfilhar",
    "aperfilhávamos": "aperfilhar",
    "aperfilhávei": "aperfilhar",
    "aperfilháveis": "aperfilhar",
    "apergaminhada": "apergaminhado",
    "apergaminhadas": "apergaminhado",
    "apergaminhados": "apergaminhado",
    "aperiantados": "aperiantado",
    "aperiantácea": "aperiantáceo",
    "aperiantáceas": "aperiantáceo",
    "aperiantáceos": "aperiantáceo",
    "aperientes": "aperiente",
    "aperitiva": "aperitivo",
    "aperitivas": "aperitivo",
    "aperitivos": "aperitivo",
    "aperitivozinho": "aperitivo",
    "aperitivozinhos": "aperitivo",
    "aperitivozito": "aperitivo",
    "aperitivozitos": "aperitivo",
    "aperitórios": "aperitório",
    "aperiódica": "aperiódico",
    "aperiódicas": "aperiódico",
    "aperiódicos": "aperiódico",
    "apernadeiras": "apernadeira",
    "aperrada": "aperrado",
    "aperradas": "aperrado",
    "aperrados": "aperrado",
    "aperreada": "aperreado",
    "aperreadas": "aperreado",
    "aperreadora": "aperreador",
    "aperreadoras": "aperreador",
    "aperreadores": "aperreador",
    "aperreados": "aperreado",
    "aperreações": "aperreação",
    "aperta": "apertar",
    "apertada": "apertar",
    "apertadas": "apertar",
    "apertadeiras": "apertadeira",
    "apertadelas": "apertadela",
    "apertadinha": "apertado",
    "apertadinhas": "apertado",
    "apertadinho": "apertado",
    "apertadinhos": "apertado",
    "apertadita": "apertado",
    "apertaditas": "apertado",
    "apertadito": "apertado",
    "apertaditos": "apertado",
    "apertado": "apertar",
    "apertadoiros": "apertadoiro",
    "apertadora": "apertador",
    "apertadoras": "apertador",
    "apertadores": "apertador",
    "apertados": "apertar",
    "apertadouros": "apertadouro",
    "apertadíssima": "apertado",
    "apertadíssimas": "apertado",
    "apertadíssimo": "apertado",
    "apertadíssimos": "apertado",
    "apertai": "apertar",
    "apertais": "apertar",
    "apertam": "apertar",
    "apertamentos": "apertamento",
    "apertamo": "apertar",
    "apertamos": "apertar",
    "apertando": "apertar",
    "apertara": "apertar",
    "apertaram": "apertar",
    "apertaras": "apertar",
    "apertarde": "apertar",
    "apertardes": "apertar",
    "apertare": "apertar",
    "apertarei": "apertar",
    "apertareis": "apertar",
    "apertarem": "apertar",
    "apertaremos": "apertar",
    "apertares": "apertar",
    "apertaria": "apertar",
    "apertariam": "apertar",
    "apertarias": "apertar",
    "apertarmo": "apertar",
    "apertarmos": "apertar",
    "apertará": "apertar",
    "apertarás": "apertar",
    "apertarão": "apertar",
    "apertaríamos": "apertar",
    "apertaríeis": "apertar",
    "apertas": "apertar",
    "apertasse": "apertar",
    "apertassem": "apertar",
    "apertasses": "apertar",
    "apertaste": "apertar",
    "apertastes": "apertar",
    "apertava": "apertar",
    "apertavam": "apertar",
    "apertavas": "apertar",
    "aperte": "apertar",
    "apertei": "apertar",
    "aperteis": "apertar",
    "apertem": "apertar",
    "apertemo": "apertar",
    "apertemos": "apertar",
    "apertes": "apertar",
    "aperto": "apertar",
    "apertos": "aperto",
    "apertou": "apertar",
    "aperturas": "apertura",
    "apertá": "apertar",
    "apertámo": "apertar",
    "apertámos": "apertar",
    "apertáramo": "apertar",
    "apertáramos": "apertar",
    "apertárei": "apertar",
    "apertáreis": "apertar",
    "apertásseis": "apertar",
    "apertássemos": "apertar",
    "apertávamo": "apertar",
    "apertávamos": "apertar",
    "apertávei": "apertar",
    "apertáveis": "apertável",
    "apertómetros": "apertómetro",
    "apertões": "apertão",
    "aperuada": "aperuado",
    "aperuadas": "aperuado",
    "aperuados": "aperuado",
    "apes": "ape",
    "apessoada": "apessoado",
    "apessoadas": "apessoado",
    "apessoados": "apessoado",
    "apestanada": "apestanado",
    "apestanadas": "apestanado",
    "apestanados": "apestanado",
    "apetaliflora": "apetalifloro",
    "apetalifloras": "apetalifloro",
    "apetalifloros": "apetalifloro",
    "apetalífera": "apetalífero",
    "apetalíferas": "apetalífero",
    "apetalíferos": "apetalífero",
    "apetece": "apetecer",
    "apetecei": "apetecer",
    "apeteceis": "apetecer",
    "apetecem": "apetecer",
    "apetecemo": "apetecer",
    "apetecemos": "apetecer",
    "apetecendo": "apetecer",
    "apetecera": "apetecer",
    "apeteceram": "apetecer",
    "apeteceras": "apetecer",
    "apetecerde": "apetecer",
    "apetecerdes": "apetecer",
    "apetecere": "apetecer",
    "apetecerei": "apetecer",
    "apetecereis": "apetecer",
    "apetecerem": "apetecer",
    "apeteceremos": "apetecer",
    "apeteceres": "apetecer",
    "apeteceria": "apetecer",
    "apeteceriam": "apetecer",
    "apetecerias": "apetecer",
    "apetecermo": "apetecer",
    "apetecermos": "apetecer",
    "apetecerá": "apetecer",
    "apetecerás": "apetecer",
    "apetecerão": "apetecer",
    "apeteceríamos": "apetecer",
    "apeteceríeis": "apetecer",
    "apeteces": "apetecer",
    "apetecesse": "apetecer",
    "apetecessem": "apetecer",
    "apetecesses": "apetecer",
    "apeteceste": "apetecer",
    "apetecestes": "apetecer",
    "apeteceu": "apetecer",
    "apeteci": "apetecer",
    "apetecia": "apetecer",
    "apeteciam": "apetecer",
    "apetecias": "apetecer",
    "apetecida": "apetecido",
    "apetecidas": "apetecido",
    "apetecido": "apetecer",
    "apetecidos": "apetecido",
    "apetecê": "apetecer",
    "apetecêramo": "apetecer",
    "apetecêramos": "apetecer",
    "apetecêrei": "apetecer",
    "apetecêreis": "apetecer",
    "apetecêsseis": "apetecer",
    "apetecêssemos": "apetecer",
    "apetecíamo": "apetecer",
    "apetecíamos": "apetecer",
    "apetecíei": "apetecer",
    "apetecíeis": "apetecer",
    "apetecíveis": "apetecível",
    "apetentes": "apetente",
    "apeteça": "apetecer",
    "apeteçais": "apetecer",
    "apeteçam": "apetecer",
    "apeteçamo": "apetecer",
    "apeteçamos": "apetecer",
    "apeteças": "apetecer",
    "apeteço": "apetecer",
    "apetibilidades": "apetibilidade",
    "apetita": "apetitar",
    "apetitada": "apetitar",
    "apetitadas": "apetitar",
    "apetitado": "apetitar",
    "apetitados": "apetitar",
    "apetitai": "apetitar",
    "apetitais": "apetitar",
    "apetitam": "apetitar",
    "apetitamo": "apetitar",
    "apetitamos": "apetitar",
    "apetitando": "apetitar",
    "apetitara": "apetitar",
    "apetitaram": "apetitar",
    "apetitaras": "apetitar",
    "apetitarde": "apetitar",
    "apetitardes": "apetitar",
    "apetitare": "apetitar",
    "apetitarei": "apetitar",
    "apetitareis": "apetitar",
    "apetitarem": "apetitar",
    "apetitaremos": "apetitar",
    "apetitares": "apetitar",
    "apetitaria": "apetitar",
    "apetitariam": "apetitar",
    "apetitarias": "apetitar",
    "apetitarmo": "apetitar",
    "apetitarmos": "apetitar",
    "apetitará": "apetitar",
    "apetitarás": "apetitar",
    "apetitarão": "apetitar",
    "apetitaríamos": "apetitar",
    "apetitaríeis": "apetitar",
    "apetitas": "apetitar",
    "apetitasse": "apetitar",
    "apetitassem": "apetitar",
    "apetitasses": "apetitar",
    "apetitaste": "apetitar",
    "apetitastes": "apetitar",
    "apetitava": "apetitar",
    "apetitavam": "apetitar",
    "apetitavas": "apetitar",
    "apetite": "apetitar",
    "apetitei": "apetitar",
    "apetiteis": "apetitar",
    "apetitem": "apetitar",
    "apetitemo": "apetitar",
    "apetitemos": "apetitar",
    "apetites": "apetite",
    "apetitiva": "apetitivo",
    "apetitivas": "apetitivo",
    "apetitivos": "apetitivo",
    "apetito": "apetitar",
    "apetitosa": "apetitoso",
    "apetitosas": "apetitoso",
    "apetitosos": "apetitoso",
    "apetitosíssima": "apetitoso",
    "apetitosíssimas": "apetitoso",
    "apetitosíssimo": "apetitoso",
    "apetitosíssimos": "apetitoso",
    "apetitou": "apetitar",
    "apetitá": "apetitar",
    "apetitámo": "apetitar",
    "apetitámos": "apetitar",
    "apetitáramo": "apetitar",
    "apetitáramos": "apetitar",
    "apetitárei": "apetitar",
    "apetitáreis": "apetitar",
    "apetitásseis": "apetitar",
    "apetitássemos": "apetitar",
    "apetitávamo": "apetitar",
    "apetitávamos": "apetitar",
    "apetitávei": "apetitar",
    "apetitáveis": "apetitar",
    "apetições": "apetição",
    "apetrecha": "apetrechar",
    "apetrechada": "apetrechar",
    "apetrechadas": "apetrechar",
    "apetrechado": "apetrechar",
    "apetrechados": "apetrechar",
    "apetrechai": "apetrechar",
    "apetrechais": "apetrechar",
    "apetrecham": "apetrechar",
    "apetrechamentos": "apetrechamento",
    "apetrechamo": "apetrechar",
    "apetrechamos": "apetrechar",
    "apetrechando": "apetrechar",
    "apetrechara": "apetrechar",
    "apetrecharam": "apetrechar",
    "apetrecharas": "apetrechar",
    "apetrecharde": "apetrechar",
    "apetrechardes": "apetrechar",
    "apetrechare": "apetrechar",
    "apetrecharei": "apetrechar",
    "apetrechareis": "apetrechar",
    "apetrecharem": "apetrechar",
    "apetrecharemos": "apetrechar",
    "apetrechares": "apetrechar",
    "apetrecharia": "apetrechar",
    "apetrechariam": "apetrechar",
    "apetrecharias": "apetrechar",
    "apetrecharmo": "apetrechar",
    "apetrecharmos": "apetrechar",
    "apetrechará": "apetrechar",
    "apetrecharás": "apetrechar",
    "apetrecharão": "apetrechar",
    "apetrecharíamos": "apetrechar",
    "apetrecharíeis": "apetrechar",
    "apetrechas": "apetrechar",
    "apetrechasse": "apetrechar",
    "apetrechassem": "apetrechar",
    "apetrechasses": "apetrechar",
    "apetrechaste": "apetrechar",
    "apetrechastes": "apetrechar",
    "apetrechava": "apetrechar",
    "apetrechavam": "apetrechar",
    "apetrechavas": "apetrechar",
    "apetreche": "apetrechar",
    "apetrechei": "apetrechar",
    "apetrecheis": "apetrechar",
    "apetrechem": "apetrechar",
    "apetrechemo": "apetrechar",
    "apetrechemos": "apetrechar",
    "apetreches": "apetrechar",
    "apetrecho": "apetrechar",
    "apetrechos": "apetrecho",
    "apetrechou": "apetrechar",
    "apetrechá": "apetrechar",
    "apetrechámo": "apetrechar",
    "apetrechámos": "apetrechar",
    "apetrecháramo": "apetrechar",
    "apetrecháramos": "apetrechar",
    "apetrechárei": "apetrechar",
    "apetrecháreis": "apetrechar",
    "apetrechásseis": "apetrechar",
    "apetrechássemos": "apetrechar",
    "apetrechávamo": "apetrechar",
    "apetrechávamos": "apetrechar",
    "apetrechávei": "apetrechar",
    "apetrecháveis": "apetrechar",
    "apetências": "apetência",
    "apeá": "apear",
    "apeámo": "apear",
    "apeámos": "apear",
    "apeáramo": "apear",
    "apeáramos": "apear",
    "apeárei": "apear",
    "apeáreis": "apear",
    "apeásseis": "apear",
    "apeássemos": "apear",
    "apeávamo": "apear",
    "apeávamos": "apear",
    "apeávei": "apear",
    "apeáveis": "apear",
    "apiacás": "apiacá",
    "apicada": "apicado",
    "apicadas": "apicado",
    "apicados": "apicado",
    "apicais": "apical",
    "apiciaduras": "apiciadura",
    "apicidas": "apicida",
    "apicidiflora": "apicidifloro",
    "apicidifloras": "apicidifloro",
    "apicidifloros": "apicidifloro",
    "apiciformes": "apiciforme",
    "apicodentais": "apicodental",
    "apiculada": "apiculado",
    "apiculadas": "apiculado",
    "apiculados": "apiculado",
    "apicultora": "apicultor",
    "apicultoras": "apicultor",
    "apicultores": "apicultor",
    "apiculturais": "apicultural",
    "apiculturas": "apicultura",
    "apicuns": "apicum",
    "apidas": "apida",
    "apieda": "apiedar",
    "apiedada": "apiedar",
    "apiedadas": "apiedar",
    "apiedado": "apiedar",
    "apiedados": "apiedar",
    "apiedai": "apiedar",
    "apiedais": "apiedar",
    "apiedam": "apiedar",
    "apiedamo": "apiedar",
    "apiedamos": "apiedar",
    "apiedando": "apiedar",
    "apiedara": "apiedar",
    "apiedaram": "apiedar",
    "apiedaras": "apiedar",
    "apiedarde": "apiedar",
    "apiedardes": "apiedar",
    "apiedare": "apiedar",
    "apiedarei": "apiedar",
    "apiedareis": "apiedar",
    "apiedarem": "apiedar",
    "apiedaremos": "apiedar",
    "apiedares": "apiedar",
    "apiedaria": "apiedar",
    "apiedariam": "apiedar",
    "apiedarias": "apiedar",
    "apiedarmo": "apiedar",
    "apiedarmos": "apiedar",
    "apiedará": "apiedar",
    "apiedarás": "apiedar",
    "apiedarão": "apiedar",
    "apiedaríamos": "apiedar",
    "apiedaríeis": "apiedar",
    "apiedas": "apiedar",
    "apiedasse": "apiedar",
    "apiedassem": "apiedar",
    "apiedasses": "apiedar",
    "apiedaste": "apiedar",
    "apiedastes": "apiedar",
    "apiedava": "apiedar",
    "apiedavam": "apiedar",
    "apiedavas": "apiedar",
    "apiede": "apiedar",
    "apiedei": "apiedar",
    "apiedeis": "apiedar",
    "apiedem": "apiedar",
    "apiedemo": "apiedar",
    "apiedemos": "apiedar",
    "apiedes": "apiedar",
    "apiedo": "apiedar",
    "apiedou": "apiedar",
    "apiedá": "apiedar",
    "apiedámo": "apiedar",
    "apiedámos": "apiedar",
    "apiedáramo": "apiedar",
    "apiedáramos": "apiedar",
    "apiedárei": "apiedar",
    "apiedáreis": "apiedar",
    "apiedásseis": "apiedar",
    "apiedássemos": "apiedar",
    "apiedávamo": "apiedar",
    "apiedávamos": "apiedar",
    "apiedávei": "apiedar",
    "apiedáveis": "apiedar",
    "apifobias": "apifobia",
    "apiformes": "apiforme",
    "apifóbica": "apifóbico",
    "apifóbicas": "apifóbico",
    "apifóbicos": "apifóbico",
    "apimenta": "apimentar",
    "apimentada": "apimentar",
    "apimentadas": "apimentar",
    "apimentado": "apimentar",
    "apimentados": "apimentar",
    "apimentai": "apimentar",
    "apimentais": "apimentar",
    "apimentam": "apimentar",
    "apimentamo": "apimentar",
    "apimentamos": "apimentar",
    "apimentando": "apimentar",
    "apimentara": "apimentar",
    "apimentaram": "apimentar",
    "apimentaras": "apimentar",
    "apimentarde": "apimentar",
    "apimentardes": "apimentar",
    "apimentare": "apimentar",
    "apimentarei": "apimentar",
    "apimentareis": "apimentar",
    "apimentarem": "apimentar",
    "apimentaremos": "apimentar",
    "apimentares": "apimentar",
    "apimentaria": "apimentar",
    "apimentariam": "apimentar",
    "apimentarias": "apimentar",
    "apimentarmo": "apimentar",
    "apimentarmos": "apimentar",
    "apimentará": "apimentar",
    "apimentarás": "apimentar",
    "apimentarão": "apimentar",
    "apimentaríamos": "apimentar",
    "apimentaríeis": "apimentar",
    "apimentas": "apimentar",
    "apimentasse": "apimentar",
    "apimentassem": "apimentar",
    "apimentasses": "apimentar",
    "apimentaste": "apimentar",
    "apimentastes": "apimentar",
    "apimentava": "apimentar",
    "apimentavam": "apimentar",
    "apimentavas": "apimentar",
    "apimente": "apimentar",
    "apimentei": "apimentar",
    "apimenteis": "apimentar",
    "apimentem": "apimentar",
    "apimentemo": "apimentar",
    "apimentemos": "apimentar",
    "apimentes": "apimentar",
    "apimento": "apimentar",
    "apimentou": "apimentar",
    "apimentá": "apimentar",
    "apimentámo": "apimentar",
    "apimentámos": "apimentar",
    "apimentáramo": "apimentar",
    "apimentáramos": "apimentar",
    "apimentárei": "apimentar",
    "apimentáreis": "apimentar",
    "apimentásseis": "apimentar",
    "apimentássemos": "apimentar",
    "apimentávamo": "apimentar",
    "apimentávamos": "apimentar",
    "apimentávei": "apimentar",
    "apimentáveis": "apimentar",
    "apinha": "apinhar",
    "apinhada": "apinhar",
    "apinhadas": "apinhar",
    "apinhado": "apinhar",
    "apinhados": "apinhar",
    "apinhai": "apinhar",
    "apinhais": "apinhar",
    "apinham": "apinhar",
    "apinhamo": "apinhar",
    "apinhamos": "apinhar",
    "apinhando": "apinhar",
    "apinhara": "apinhar",
    "apinharam": "apinhar",
    "apinharas": "apinhar",
    "apinharde": "apinhar",
    "apinhardes": "apinhar",
    "apinhare": "apinhar",
    "apinharei": "apinhar",
    "apinhareis": "apinhar",
    "apinharem": "apinhar",
    "apinharemos": "apinhar",
    "apinhares": "apinhar",
    "apinharia": "apinhar",
    "apinhariam": "apinhar",
    "apinharias": "apinhar",
    "apinharmo": "apinhar",
    "apinharmos": "apinhar",
    "apinhará": "apinhar",
    "apinharás": "apinhar",
    "apinharão": "apinhar",
    "apinharíamos": "apinhar",
    "apinharíeis": "apinhar",
    "apinhas": "apinhar",
    "apinhasse": "apinhar",
    "apinhassem": "apinhar",
    "apinhasses": "apinhar",
    "apinhaste": "apinhar",
    "apinhastes": "apinhar",
    "apinhava": "apinhar",
    "apinhavam": "apinhar",
    "apinhavas": "apinhar",
    "apinhe": "apinhar",
    "apinhei": "apinhar",
    "apinheis": "apinhar",
    "apinhem": "apinhar",
    "apinhemo": "apinhar",
    "apinhemos": "apinhar",
    "apinhes": "apinhar",
    "apinho": "apinhar",
    "apinhou": "apinhar",
    "apinhá": "apinhar",
    "apinhámo": "apinhar",
    "apinhámos": "apinhar",
    "apinháramo": "apinhar",
    "apinháramos": "apinhar",
    "apinhárei": "apinhar",
    "apinháreis": "apinhar",
    "apinhásseis": "apinhar",
    "apinhássemos": "apinhar",
    "apinhávamo": "apinhar",
    "apinhávamos": "apinhar",
    "apinhávei": "apinhar",
    "apinháveis": "apinhar",
    "apinocada": "apinocado",
    "apinocadas": "apinocado",
    "apinocados": "apinocado",
    "apinocadíssima": "apinocado",
    "apinocadíssimas": "apinocado",
    "apinocadíssimo": "apinocado",
    "apinocadíssimos": "apinocado",
    "apinários": "apinário",
    "apirexias": "apirexia",
    "apirinas": "apirina",
    "apirética": "apirético",
    "apiréticas": "apirético",
    "apiréticos": "apirético",
    "apisinas": "apisina",
    "apisinações": "apisinação",
    "apisteiros": "apisteiro",
    "apistos": "apisto",
    "apita": "apitar",
    "apitada": "apitar",
    "apitadas": "apitar",
    "apitadelas": "apitadela",
    "apitado": "apitar",
    "apitados": "apitar",
    "apitai": "apitar",
    "apitais": "apitar",
    "apitam": "apitar",
    "apitamo": "apitar",
    "apitamos": "apitar",
    "apitando": "apitar",
    "apitara": "apitar",
    "apitaram": "apitar",
    "apitaras": "apitar",
    "apitardes": "apitar",
    "apitarei": "apitar",
    "apitareis": "apitar",
    "apitarem": "apitar",
    "apitaremos": "apitar",
    "apitares": "apitar",
    "apitaria": "apitar",
    "apitariam": "apitar",
    "apitarias": "apitar",
    "apitarmo": "apitar",
    "apitarmos": "apitar",
    "apitará": "apitar",
    "apitarás": "apitar",
    "apitarão": "apitar",
    "apitaríamos": "apitar",
    "apitaríeis": "apitar",
    "apitas": "apitar",
    "apitasse": "apitar",
    "apitassem": "apitar",
    "apitasses": "apitar",
    "apitaste": "apitar",
    "apitastes": "apitar",
    "apitava": "apitar",
    "apitavam": "apitar",
    "apitavas": "apitar",
    "apite": "apitar",
    "apitei": "apitar",
    "apiteis": "apitar",
    "apitem": "apitar",
    "apitemo": "apitar",
    "apitemos": "apitar",
    "apites": "apitar",
    "apito": "apitar",
    "apitos": "apito",
    "apitou": "apitar",
    "apitámo": "apitar",
    "apitámos": "apitar",
    "apitáramo": "apitar",
    "apitáramos": "apitar",
    "apitáreis": "apitar",
    "apitásseis": "apitar",
    "apitássemos": "apitar",
    "apitávamo": "apitar",
    "apitávamos": "apitar",
    "apitáveis": "apitar",
    "apiácea": "apiáceo",
    "apiáceas": "apiáceo",
    "apiáceos": "apiáceo",
    "apiários": "apiário",
    "apióis": "apiol",
    "aplaca": "aplacar",
    "aplacada": "aplacar",
    "aplacadas": "aplacar",
    "aplacado": "aplacar",
    "aplacados": "aplacar",
    "aplacai": "aplacar",
    "aplacais": "aplacar",
    "aplacam": "aplacar",
    "aplacamo": "aplacar",
    "aplacamos": "aplacar",
    "aplacando": "aplacar",
    "aplacara": "aplacar",
    "aplacaram": "aplacar",
    "aplacaras": "aplacar",
    "aplacarde": "aplacar",
    "aplacardes": "aplacar",
    "aplacare": "aplacar",
    "aplacarei": "aplacar",
    "aplacareis": "aplacar",
    "aplacarem": "aplacar",
    "aplacaremos": "aplacar",
    "aplacares": "aplacar",
    "aplacaria": "aplacar",
    "aplacariam": "aplacar",
    "aplacarias": "aplacar",
    "aplacarmo": "aplacar",
    "aplacarmos": "aplacar",
    "aplacará": "aplacar",
    "aplacarás": "aplacar",
    "aplacarão": "aplacar",
    "aplacaríamos": "aplacar",
    "aplacaríeis": "aplacar",
    "aplacas": "aplacar",
    "aplacasse": "aplacar",
    "aplacassem": "aplacar",
    "aplacasses": "aplacar",
    "aplacaste": "aplacar",
    "aplacastes": "aplacar",
    "aplacava": "aplacar",
    "aplacavam": "aplacar",
    "aplacavas": "aplacar",
    "aplacações": "aplacação",
    "aplacentária": "aplacentário",
    "aplacentárias": "aplacentário",
    "aplacentários": "aplacentário",
    "aplaco": "aplacar",
    "aplacou": "aplacar",
    "aplacá": "aplacar",
    "aplacámo": "aplacar",
    "aplacámos": "aplacar",
    "aplacáramo": "aplacar",
    "aplacáramos": "aplacar",
    "aplacárei": "aplacar",
    "aplacáreis": "aplacar",
    "aplacásseis": "aplacar",
    "aplacássemos": "aplacar",
    "aplacávamo": "aplacar",
    "aplacávamos": "aplacar",
    "aplacávei": "aplacar",
    "aplacáveis": "aplacável",
    "aplaina": "aplainar",
    "aplainada": "aplainar",
    "aplainadas": "aplainar",
    "aplainado": "aplainar",
    "aplainadora": "aplainador",
    "aplainadoras": "aplainador",
    "aplainadores": "aplainador",
    "aplainados": "aplainar",
    "aplainai": "aplainar",
    "aplainais": "aplainar",
    "aplainam": "aplainar",
    "aplainamentos": "aplainamento",
    "aplainamo": "aplainar",
    "aplainamos": "aplainar",
    "aplainando": "aplainar",
    "aplainara": "aplainar",
    "aplainaram": "aplainar",
    "aplainaras": "aplainar",
    "aplainarde": "aplainar",
    "aplainardes": "aplainar",
    "aplainare": "aplainar",
    "aplainarei": "aplainar",
    "aplainareis": "aplainar",
    "aplainarem": "aplainar",
    "aplainaremos": "aplainar",
    "aplainares": "aplainar",
    "aplainaria": "aplainar",
    "aplainariam": "aplainar",
    "aplainarias": "aplainar",
    "aplainarmo": "aplainar",
    "aplainarmos": "aplainar",
    "aplainará": "aplainar",
    "aplainarás": "aplainar",
    "aplainarão": "aplainar",
    "aplainaríamos": "aplainar",
    "aplainaríeis": "aplainar",
    "aplainas": "aplainar",
    "aplainasse": "aplainar",
    "aplainassem": "aplainar",
    "aplainasses": "aplainar",
    "aplainaste": "aplainar",
    "aplainastes": "aplainar",
    "aplainava": "aplainar",
    "aplainavam": "aplainar",
    "aplainavas": "aplainar",
    "aplainações": "aplainação",
    "aplaine": "aplainar",
    "aplainei": "aplainar",
    "aplaineis": "aplainar",
    "aplainem": "aplainar",
    "aplainemo": "aplainar",
    "aplainemos": "aplainar",
    "aplaines": "aplainar",
    "aplaino": "aplainar",
    "aplainou": "aplainar",
    "aplainá": "aplainar",
    "aplainámo": "aplainar",
    "aplainámos": "aplainar",
    "aplaináramo": "aplainar",
    "aplaináramos": "aplainar",
    "aplainárei": "aplainar",
    "aplaináreis": "aplainar",
    "aplainásseis": "aplainar",
    "aplainássemos": "aplainar",
    "aplainávamo": "aplainar",
    "aplainávamos": "aplainar",
    "aplainávei": "aplainar",
    "aplaináveis": "aplainável",
    "aplana": "aplanar",
    "aplanada": "aplanar",
    "aplanadas": "aplanar",
    "aplanado": "aplanar",
    "aplanadora": "aplanador",
    "aplanadoras": "aplanador",
    "aplanadores": "aplanador",
    "aplanados": "aplanar",
    "aplanai": "aplanar",
    "aplanais": "aplanar",
    "aplanam": "aplanar",
    "aplanamo": "aplanar",
    "aplanamos": "aplanar",
    "aplanando": "aplanar",
    "aplanara": "aplanar",
    "aplanaram": "aplanar",
    "aplanaras": "aplanar",
    "aplanarde": "aplanar",
    "aplanardes": "aplanar",
    "aplanare": "aplanar",
    "aplanarei": "aplanar",
    "aplanareis": "aplanar",
    "aplanarem": "aplanar",
    "aplanaremos": "aplanar",
    "aplanares": "aplanar",
    "aplanaria": "aplanar",
    "aplanariam": "aplanar",
    "aplanarias": "aplanar",
    "aplanarmo": "aplanar",
    "aplanarmos": "aplanar",
    "aplanará": "aplanar",
    "aplanarás": "aplanar",
    "aplanarão": "aplanar",
    "aplanaríamos": "aplanar",
    "aplanaríeis": "aplanar",
    "aplanas": "aplanar",
    "aplanasse": "aplanar",
    "aplanassem": "aplanar",
    "aplanasses": "aplanar",
    "aplanaste": "aplanar",
    "aplanastes": "aplanar",
    "aplanava": "aplanar",
    "aplanavam": "aplanar",
    "aplanavas": "aplanar",
    "aplanações": "aplanação",
    "aplane": "aplanar",
    "aplanei": "aplanar",
    "aplaneis": "aplanar",
    "aplanem": "aplanar",
    "aplanemo": "aplanar",
    "aplanemos": "aplanar",
    "aplanes": "aplanar",
    "aplanetismos": "aplanetismo",
    "aplano": "aplanar",
    "aplanogâmetas": "aplanogâmeta",
    "aplanou": "aplanar",
    "aplaná": "aplanar",
    "aplanámo": "aplanar",
    "aplanámos": "aplanar",
    "aplanáramo": "aplanar",
    "aplanáramos": "aplanar",
    "aplanárei": "aplanar",
    "aplanáreis": "aplanar",
    "aplanásseis": "aplanar",
    "aplanássemos": "aplanar",
    "aplanávamo": "aplanar",
    "aplanávamos": "aplanar",
    "aplanávei": "aplanar",
    "aplanáveis": "aplanável",
    "aplanética": "aplanético",
    "aplanéticas": "aplanético",
    "aplanéticos": "aplanético",
    "aplaque": "aplacar",
    "aplaquei": "aplacar",
    "aplaqueis": "aplacar",
    "aplaquem": "aplacar",
    "aplaquemo": "aplacar",
    "aplaquemos": "aplacar",
    "aplaques": "aplacar",
    "aplasias": "aplasia",
    "aplasta": "aplastar",
    "aplastada": "aplastar",
    "aplastadas": "aplastar",
    "aplastado": "aplastar",
    "aplastados": "aplastar",
    "aplastai": "aplastar",
    "aplastais": "aplastar",
    "aplastam": "aplastar",
    "aplastamo": "aplastar",
    "aplastamos": "aplastar",
    "aplastando": "aplastar",
    "aplastara": "aplastar",
    "aplastaram": "aplastar",
    "aplastaras": "aplastar",
    "aplastarde": "aplastar",
    "aplastardes": "aplastar",
    "aplastare": "aplastar",
    "aplastarei": "aplastar",
    "aplastareis": "aplastar",
    "aplastarem": "aplastar",
    "aplastaremos": "aplastar",
    "aplastares": "aplastar",
    "aplastaria": "aplastar",
    "aplastariam": "aplastar",
    "aplastarias": "aplastar",
    "aplastarmo": "aplastar",
    "aplastarmos": "aplastar",
    "aplastará": "aplastar",
    "aplastarás": "aplastar",
    "aplastarão": "aplastar",
    "aplastaríamos": "aplastar",
    "aplastaríeis": "aplastar",
    "aplastas": "aplastar",
    "aplastasse": "aplastar",
    "aplastassem": "aplastar",
    "aplastasses": "aplastar",
    "aplastaste": "aplastar",
    "aplastastes": "aplastar",
    "aplastava": "aplastar",
    "aplastavam": "aplastar",
    "aplastavas": "aplastar",
    "aplaste": "aplastar",
    "aplastei": "aplastar",
    "aplasteis": "aplastar",
    "aplastem": "aplastar",
    "aplastemo": "aplastar",
    "aplastemos": "aplastar",
    "aplastes": "aplastar",
    "aplasto": "aplastar",
    "aplastou": "aplastar",
    "aplastá": "aplastar",
    "aplastámo": "aplastar",
    "aplastámos": "aplastar",
    "aplastáramo": "aplastar",
    "aplastáramos": "aplastar",
    "aplastárei": "aplastar",
    "aplastáreis": "aplastar",
    "aplastásseis": "aplastar",
    "aplastássemos": "aplastar",
    "aplastávamo": "aplastar",
    "aplastávamos": "aplastar",
    "aplastávei": "aplastar",
    "aplastáveis": "aplastar",
    "aplauda": "aplaudir",
    "aplaudais": "aplaudir",
    "aplaudam": "aplaudir",
    "aplaudamo": "aplaudir",
    "aplaudamos": "aplaudir",
    "aplaudas": "aplaudir",
    "aplaude": "aplaudir",
    "aplaudem": "aplaudir",
    "aplaudentes": "aplaudente",
    "aplaudes": "aplaudir",
    "aplaudi": "aplaudir",
    "aplaudia": "aplaudir",
    "aplaudiam": "aplaudir",
    "aplaudias": "aplaudir",
    "aplaudida": "aplaudir",
    "aplaudidas": "aplaudir",
    "aplaudido": "aplaudir",
    "aplaudidos": "aplaudir",
    "aplaudidíssima": "aplaudido",
    "aplaudidíssimas": "aplaudido",
    "aplaudidíssimo": "aplaudido",
    "aplaudidíssimos": "aplaudido",
    "aplaudimo": "aplaudir",
    "aplaudimos": "aplaudir",
    "aplaudindo": "aplaudir",
    "aplaudira": "aplaudir",
    "aplaudiram": "aplaudir",
    "aplaudiras": "aplaudir",
    "aplaudirde": "aplaudir",
    "aplaudirdes": "aplaudir",
    "aplaudire": "aplaudir",
    "aplaudirei": "aplaudir",
    "aplaudireis": "aplaudir",
    "aplaudirem": "aplaudir",
    "aplaudiremos": "aplaudir",
    "aplaudires": "aplaudir",
    "aplaudiria": "aplaudir",
    "aplaudiriam": "aplaudir",
    "aplaudirias": "aplaudir",
    "aplaudirmo": "aplaudir",
    "aplaudirmos": "aplaudir",
    "aplaudirá": "aplaudir",
    "aplaudirás": "aplaudir",
    "aplaudirão": "aplaudir",
    "aplaudiríamos": "aplaudir",
    "aplaudiríeis": "aplaudir",
    "aplaudis": "aplaudir",
    "aplaudisse": "aplaudir",
    "aplaudissem": "aplaudir",
    "aplaudisses": "aplaudir",
    "aplaudiste": "aplaudir",
    "aplaudistes": "aplaudir",
    "aplaudiu": "aplaudir",
    "aplaudo": "aplaudir",
    "aplaudíamo": "aplaudir",
    "aplaudíamos": "aplaudir",
    "aplaudíei": "aplaudir",
    "aplaudíeis": "aplaudir",
    "aplaudíramo": "aplaudir",
    "aplaudíramos": "aplaudir",
    "aplaudírei": "aplaudir",
    "aplaudíreis": "aplaudir",
    "aplaudísseis": "aplaudir",
    "aplaudíssemos": "aplaudir",
    "aplaudíveis": "aplaudível",
    "aplausos": "aplauso",
    "aplausíveis": "aplausível",
    "aplestias": "aplestia",
    "aplica": "aplicar",
    "aplicabilidades": "aplicabilidade",
    "aplicada": "aplicar",
    "aplicadas": "aplicar",
    "aplicado": "aplicar",
    "aplicadors": "aplicador",
    "aplicados": "aplicar",
    "aplicadíssima": "aplicado",
    "aplicadíssimas": "aplicado",
    "aplicadíssimo": "aplicado",
    "aplicadíssimos": "aplicado",
    "aplicai": "aplicar",
    "aplicais": "aplicar",
    "aplicam": "aplicar",
    "aplicamo": "aplicar",
    "aplicamos": "aplicar",
    "aplicando": "aplicar",
    "aplicantes": "aplicante",
    "aplicara": "aplicar",
    "aplicaram": "aplicar",
    "aplicaras": "aplicar",
    "aplicarde": "aplicar",
    "aplicardes": "aplicar",
    "aplicare": "aplicar",
    "aplicarei": "aplicar",
    "aplicareis": "aplicar",
    "aplicarem": "aplicar",
    "aplicaremos": "aplicar",
    "aplicares": "aplicar",
    "aplicaria": "aplicar",
    "aplicariam": "aplicar",
    "aplicarias": "aplicar",
    "aplicarmo": "aplicar",
    "aplicarmos": "aplicar",
    "aplicará": "aplicar",
    "aplicarás": "aplicar",
    "aplicarão": "aplicar",
    "aplicaríamos": "aplicar",
    "aplicaríeis": "aplicar",
    "aplicas": "aplicar",
    "aplicasse": "aplicar",
    "aplicassem": "aplicar",
    "aplicasses": "aplicar",
    "aplicaste": "aplicar",
    "aplicastes": "aplicar",
    "aplicativa": "aplicativo",
    "aplicativas": "aplicativo",
    "aplicativos": "aplicativo",
    "aplicava": "aplicar",
    "aplicavam": "aplicar",
    "aplicavas": "aplicar",
    "aplicações": "aplicação",
    "aplico": "aplicar",
    "aplicou": "aplicar",
    "aplicá": "aplicar",
    "aplicámo": "aplicar",
    "aplicámos": "aplicar",
    "aplicáramo": "aplicar",
    "aplicáramos": "aplicar",
    "aplicárei": "aplicar",
    "aplicáreis": "aplicar",
    "aplicásseis": "aplicar",
    "aplicássemos": "aplicar",
    "aplicávamo": "aplicar",
    "aplicávamos": "aplicar",
    "aplicávei": "aplicar",
    "aplicáveis": "aplicável",
    "aplique": "aplicar",
    "apliquei": "aplicar",
    "apliqueis": "aplicar",
    "apliquem": "aplicar",
    "apliquemo": "aplicar",
    "apliquemos": "aplicar",
    "apliques": "aplique",
    "aplitos": "aplito",
    "aplomada": "aplomado",
    "aplomadas": "aplomado",
    "aplomados": "aplomado",
    "aplástica": "aplástico",
    "aplásticas": "aplástico",
    "aplásticos": "aplástico",
    "aplísias": "aplísia",
    "apneias": "apneia",
    "apneosfixias": "apneosfixia",
    "apneumias": "apneumia",
    "apnêumones": "apnêumone",
    "apoatropinas": "apoatropina",
    "apocalbases": "apocalbase",
    "apocalipses": "apocalipse",
    "apocalíptica": "apocalíptico",
    "apocalípticas": "apocalíptico",
    "apocalípticos": "apocalíptico",
    "apocarpada": "apocarpado",
    "apocarpadas": "apocarpado",
    "apocarpados": "apocarpado",
    "apocarpos": "apocarpo",
    "apocatastática": "apocatastático",
    "apocatastáticas": "apocatastático",
    "apocatastáticos": "apocatastático",
    "apocatásteses": "apocatástese",
    "apocininas": "apocinina",
    "apocinácea": "apocináceo",
    "apocináceas": "apocináceo",
    "apocináceos": "apocináceo",
    "apoclítica": "apoclítico",
    "apoclíticas": "apoclítico",
    "apoclíticos": "apoclítico",
    "apocrifias": "apocrifia",
    "apocriniários": "apocriniário",
    "apocrisias": "apocrisia",
    "apocromatismos": "apocromatismo",
    "apocromática": "apocromático",
    "apocromáticas": "apocromático",
    "apocromáticos": "apocromático",
    "apocárpica": "apocárpico",
    "apocárpicas": "apocárpico",
    "apocárpicos": "apocárpico",
    "apocíneas": "apocínea",
    "apocínia": "apocínio",
    "apocínias": "apocínio",
    "apocínios": "apocínio",
    "apocópica": "apocópico",
    "apocópicas": "apocópico",
    "apocópicos": "apocópico",
    "apoda": "apodar",
    "apodacrítica": "apodacrítico",
    "apodacríticas": "apodacrítico",
    "apodacríticos": "apodacrítico",
    "apodada": "apodar",
    "apodadas": "apodar",
    "apodado": "apodar",
    "apodadora": "apodador",
    "apodadoras": "apodador",
    "apodadores": "apodador",
    "apodados": "apodar",
    "apodai": "apodar",
    "apodais": "apodar",
    "apodam": "apodar",
    "apodamo": "apodar",
    "apodamos": "apodar",
    "apodando": "apodar",
    "apodara": "apodar",
    "apodaram": "apodar",
    "apodaras": "apodar",
    "apodarde": "apodar",
    "apodardes": "apodar",
    "apodare": "apodar",
    "apodarei": "apodar",
    "apodareis": "apodar",
    "apodarem": "apodar",
    "apodaremos": "apodar",
    "apodares": "apodar",
    "apodaria": "apodar",
    "apodariam": "apodar",
    "apodarias": "apodar",
    "apodarmo": "apodar",
    "apodarmos": "apodar",
    "apodará": "apodar",
    "apodarás": "apodar",
    "apodarão": "apodar",
    "apodaríamos": "apodar",
    "apodaríeis": "apodar",
    "apodas": "apodar",
    "apodasse": "apodar",
    "apodassem": "apodar",
    "apodasses": "apodar",
    "apodaste": "apodar",
    "apodastes": "apodar",
    "apodava": "apodar",
    "apodavam": "apodar",
    "apodavas": "apodar",
    "apode": "apodar",
    "apodectas": "apodecta",
    "apodei": "apodar",
    "apodeis": "apodar",
    "apodem": "apodar",
    "apodemialgias": "apodemialgia",
    "apodemo": "apodar",
    "apodemos": "apodar",
    "apodengada": "apodengado",
    "apodengadas": "apodengado",
    "apodengados": "apodengado",
    "apodera": "apoderar",
    "apoderada": "apoderar",
    "apoderadas": "apoderar",
    "apoderado": "apoderar",
    "apoderados": "apoderar",
    "apoderai": "apoderar",
    "apoderais": "apoderar",
    "apoderam": "apoderar",
    "apoderamentos": "apoderamento",
    "apoderamo": "apoderar",
    "apoderamos": "apoderar",
    "apoderando": "apoderar",
    "apoderara": "apoderar",
    "apoderaram": "apoderar",
    "apoderaras": "apoderar",
    "apoderarde": "apoderar",
    "apoderardes": "apoderar",
    "apoderare": "apoderar",
    "apoderarei": "apoderar",
    "apoderareis": "apoderar",
    "apoderarem": "apoderar",
    "apoderaremos": "apoderar",
    "apoderares": "apoderar",
    "apoderaria": "apoderar",
    "apoderariam": "apoderar",
    "apoderarias": "apoderar",
    "apoderarmo": "apoderar",
    "apoderarmos": "apoderar",
    "apoderará": "apoderar",
    "apoderarás": "apoderar",
    "apoderarão": "apoderar",
    "apoderaríamos": "apoderar",
    "apoderaríeis": "apoderar",
    "apoderas": "apoderar",
    "apoderasse": "apoderar",
    "apoderassem": "apoderar",
    "apoderasses": "apoderar",
    "apoderaste": "apoderar",
    "apoderastes": "apoderar",
    "apoderava": "apoderar",
    "apoderavam": "apoderar",
    "apoderavas": "apoderar",
    "apodere": "apoderar",
    "apoderei": "apoderar",
    "apodereis": "apoderar",
    "apoderem": "apoderar",
    "apoderemo": "apoderar",
    "apoderemos": "apoderar",
    "apoderes": "apoderar",
    "apodero": "apoderar",
    "apoderou": "apoderar",
    "apoderá": "apoderar",
    "apoderámo": "apoderar",
    "apoderámos": "apoderar",
    "apoderáramo": "apoderar",
    "apoderáramos": "apoderar",
    "apoderárei": "apoderar",
    "apoderáreis": "apoderar",
    "apoderásseis": "apoderar",
    "apoderássemos": "apoderar",
    "apoderávamo": "apoderar",
    "apoderávamos": "apoderar",
    "apoderávei": "apoderar",
    "apoderáveis": "apoderar",
    "apodes": "apodar",
    "apodias": "apodia",
    "apodioxes": "apodioxe",
    "apoditérios": "apoditério",
    "apodixes": "apodixe",
    "apodo": "apodar",
    "apodos": "apodo",
    "apodou": "apodar",
    "apodrece": "apodrecer",
    "apodrecei": "apodrecer",
    "apodreceis": "apodrecer",
    "apodrecem": "apodrecer",
    "apodrecemo": "apodrecer",
    "apodrecemos": "apodrecer",
    "apodrecendo": "apodrecer",
    "apodrecera": "apodrecer",
    "apodreceram": "apodrecer",
    "apodreceras": "apodrecer",
    "apodrecerdes": "apodrecer",
    "apodrecerei": "apodrecer",
    "apodrecereis": "apodrecer",
    "apodrecerem": "apodrecer",
    "apodreceremos": "apodrecer",
    "apodreceres": "apodrecer",
    "apodreceria": "apodrecer",
    "apodreceriam": "apodrecer",
    "apodrecerias": "apodrecer",
    "apodrecermo": "apodrecer",
    "apodrecermos": "apodrecer",
    "apodrecerá": "apodrecer",
    "apodrecerás": "apodrecer",
    "apodrecerão": "apodrecer",
    "apodreceríamos": "apodrecer",
    "apodreceríeis": "apodrecer",
    "apodreces": "apodrecer",
    "apodrecesse": "apodrecer",
    "apodrecessem": "apodrecer",
    "apodrecesses": "apodrecer",
    "apodreceste": "apodrecer",
    "apodrecestes": "apodrecer",
    "apodreceu": "apodrecer",
    "apodreci": "apodrecer",
    "apodrecia": "apodrecer",
    "apodreciam": "apodrecer",
    "apodrecias": "apodrecer",
    "apodrecida": "apodrecido",
    "apodrecidas": "apodrecido",
    "apodrecido": "apodrecer",
    "apodrecidos": "apodrecido",
    "apodrecimentos": "apodrecimento",
    "apodrecêramo": "apodrecer",
    "apodrecêramos": "apodrecer",
    "apodrecêreis": "apodrecer",
    "apodrecêsseis": "apodrecer",
    "apodrecêssemos": "apodrecer",
    "apodrecíamo": "apodrecer",
    "apodrecíamos": "apodrecer",
    "apodrecíeis": "apodrecer",
    "apodreça": "apodrecer",
    "apodreçais": "apodrecer",
    "apodreçam": "apodrecer",
    "apodreçamo": "apodrecer",
    "apodreçamos": "apodrecer",
    "apodreças": "apodrecer",
    "apodreço": "apodrecer",
    "apodrida": "apodrido",
    "apodridas": "apodrido",
    "apodridos": "apodrido",
    "apodá": "apodar",
    "apodámo": "apodar",
    "apodámos": "apodar",
    "apodáramo": "apodar",
    "apodáramos": "apodar",
    "apodárei": "apodar",
    "apodáreis": "apodar",
    "apodásseis": "apodar",
    "apodássemos": "apodar",
    "apodávamo": "apodar",
    "apodávamos": "apodar",
    "apodávei": "apodar",
    "apodáveis": "apodar",
    "apodíctica": "apodíctico",
    "apodícticas": "apodíctico",
    "apodícticos": "apodíctico",
    "apofilites": "apofilite",
    "apoflegmatismos": "apoflegmatismo",
    "apoflegmática": "apoflegmático",
    "apoflegmáticas": "apoflegmático",
    "apoflegmáticos": "apoflegmático",
    "apofonias": "apofonia",
    "apofântica": "apofântico",
    "apofânticas": "apofântico",
    "apofânticos": "apofântico",
    "apogamias": "apogamia",
    "apogeus": "apogeu",
    "apoginias": "apoginia",
    "apografias": "apografia",
    "apogística": "apogístico",
    "apogísticas": "apogístico",
    "apogísticos": "apogístico",
    "apoia": "apoiar",
    "apoiada": "apoiar",
    "apoiadas": "apoiar",
    "apoiadinha": "apoiado",
    "apoiadinhas": "apoiado",
    "apoiadinho": "apoiado",
    "apoiadinhos": "apoiado",
    "apoiadita": "apoiado",
    "apoiaditas": "apoiado",
    "apoiadito": "apoiado",
    "apoiaditos": "apoiado",
    "apoiado": "apoiar",
    "apoiados": "apoiar",
    "apoiadíssima": "apoiado",
    "apoiadíssimas": "apoiado",
    "apoiadíssimo": "apoiado",
    "apoiadíssimos": "apoiado",
    "apoiai": "apoiar",
    "apoiais": "apoiar",
    "apoiam": "apoiar",
    "apoiamo": "apoiar",
    "apoiamos": "apoiar",
    "apoiando": "apoiar",
    "apoiantes": "apoiante",
    "apoiara": "apoiar",
    "apoiaram": "apoiar",
    "apoiaras": "apoiar",
    "apoiarde": "apoiar",
    "apoiardes": "apoiar",
    "apoiare": "apoiar",
    "apoiarei": "apoiar",
    "apoiareis": "apoiar",
    "apoiarem": "apoiar",
    "apoiaremos": "apoiar",
    "apoiares": "apoiar",
    "apoiaria": "apoiar",
    "apoiariam": "apoiar",
    "apoiarias": "apoiar",
    "apoiarmo": "apoiar",
    "apoiarmos": "apoiar",
    "apoiará": "apoiar",
    "apoiarás": "apoiar",
    "apoiarão": "apoiar",
    "apoiaríamos": "apoiar",
    "apoiaríeis": "apoiar",
    "apoias": "apoiar",
    "apoiasse": "apoiar",
    "apoiassem": "apoiar",
    "apoiasses": "apoiar",
    "apoiaste": "apoiar",
    "apoiastes": "apoiar",
    "apoiava": "apoiar",
    "apoiavam": "apoiar",
    "apoiavas": "apoiar",
    "apoie": "apoiar",
    "apoiei": "apoiar",
    "apoieis": "apoiar",
    "apoiem": "apoiar",
    "apoiemo": "apoiar",
    "apoiemos": "apoiar",
    "apoies": "apoiar",
    "apoio": "apoiar",
    "apoios": "apoio",
    "apoiou": "apoiar",
    "apoiá": "apoiar",
    "apoiámo": "apoiar",
    "apoiámos": "apoiar",
    "apoiáramo": "apoiar",
    "apoiáramos": "apoiar",
    "apoiárei": "apoiar",
    "apoiáreis": "apoiar",
    "apoiásseis": "apoiar",
    "apoiássemos": "apoiar",
    "apoiávamo": "apoiar",
    "apoiávamos": "apoiar",
    "apoiávei": "apoiar",
    "apoiáveis": "apoiável",
    "apojaduras": "apojadura",
    "apojos": "apojo",
    "apolainada": "apolainado",
    "apolainadas": "apolainado",
    "apolainados": "apolainado",
    "apoldrada": "apoldrado",
    "apoldradas": "apoldrado",
    "apoldrados": "apoldrado",
    "apoleações": "apoleação",
    "apolegaduras": "apolegadura",
    "apolinarismos": "apolinarismo",
    "apolinaristas": "apolinarista",
    "apologais": "apologal",
    "apologias": "apologia",
    "apologismos": "apologismo",
    "apologistas": "apologista",
    "apologiza": "apologizar",
    "apologizada": "apologizar",
    "apologizadas": "apologizar",
    "apologizado": "apologizar",
    "apologizados": "apologizar",
    "apologizai": "apologizar",
    "apologizais": "apologizar",
    "apologizam": "apologizar",
    "apologizamo": "apologizar",
    "apologizamos": "apologizar",
    "apologizando": "apologizar",
    "apologizara": "apologizar",
    "apologizaram": "apologizar",
    "apologizaras": "apologizar",
    "apologizarde": "apologizar",
    "apologizardes": "apologizar",
    "apologizare": "apologizar",
    "apologizarei": "apologizar",
    "apologizareis": "apologizar",
    "apologizarem": "apologizar",
    "apologizaremos": "apologizar",
    "apologizares": "apologizar",
    "apologizaria": "apologizar",
    "apologizariam": "apologizar",
    "apologizarias": "apologizar",
    "apologizarmo": "apologizar",
    "apologizarmos": "apologizar",
    "apologizará": "apologizar",
    "apologizarás": "apologizar",
    "apologizarão": "apologizar",
    "apologizaríamos": "apologizar",
    "apologizaríeis": "apologizar",
    "apologizas": "apologizar",
    "apologizasse": "apologizar",
    "apologizassem": "apologizar",
    "apologizasses": "apologizar",
    "apologizaste": "apologizar",
    "apologizastes": "apologizar",
    "apologizava": "apologizar",
    "apologizavam": "apologizar",
    "apologizavas": "apologizar",
    "apologize": "apologizar",
    "apologizei": "apologizar",
    "apologizeis": "apologizar",
    "apologizem": "apologizar",
    "apologizemo": "apologizar",
    "apologizemos": "apologizar",
    "apologizes": "apologizar",
    "apologizo": "apologizar",
    "apologizou": "apologizar",
    "apologizá": "apologizar",
    "apologizámo": "apologizar",
    "apologizámos": "apologizar",
    "apologizáramo": "apologizar",
    "apologizáramos": "apologizar",
    "apologizárei": "apologizar",
    "apologizáreis": "apologizar",
    "apologizásseis": "apologizar",
    "apologizássemos": "apologizar",
    "apologizávamo": "apologizar",
    "apologizávamos": "apologizar",
    "apologizávei": "apologizar",
    "apologizáveis": "apologizar",
    "apologética": "apologético",
    "apologéticas": "apologético",
    "apologéticos": "apologético",
    "apolos": "apolo",
    "apoltrona": "apoltronar",
    "apoltronada": "apoltronar",
    "apoltronadas": "apoltronar",
    "apoltronado": "apoltronar",
    "apoltronados": "apoltronar",
    "apoltronai": "apoltronar",
    "apoltronais": "apoltronar",
    "apoltronam": "apoltronar",
    "apoltronamo": "apoltronar",
    "apoltronamos": "apoltronar",
    "apoltronando": "apoltronar",
    "apoltronara": "apoltronar",
    "apoltronaram": "apoltronar",
    "apoltronaras": "apoltronar",
    "apoltronarde": "apoltronar",
    "apoltronardes": "apoltronar",
    "apoltronare": "apoltronar",
    "apoltronarei": "apoltronar",
    "apoltronareis": "apoltronar",
    "apoltronarem": "apoltronar",
    "apoltronaremos": "apoltronar",
    "apoltronares": "apoltronar",
    "apoltronaria": "apoltronar",
    "apoltronariam": "apoltronar",
    "apoltronarias": "apoltronar",
    "apoltronarmo": "apoltronar",
    "apoltronarmos": "apoltronar",
    "apoltronará": "apoltronar",
    "apoltronarás": "apoltronar",
    "apoltronarão": "apoltronar",
    "apoltronaríamos": "apoltronar",
    "apoltronaríeis": "apoltronar",
    "apoltronas": "apoltronar",
    "apoltronasse": "apoltronar",
    "apoltronassem": "apoltronar",
    "apoltronasses": "apoltronar",
    "apoltronaste": "apoltronar",
    "apoltronastes": "apoltronar",
    "apoltronava": "apoltronar",
    "apoltronavam": "apoltronar",
    "apoltronavas": "apoltronar",
    "apoltrone": "apoltronar",
    "apoltronei": "apoltronar",
    "apoltroneis": "apoltronar",
    "apoltronem": "apoltronar",
    "apoltronemo": "apoltronar",
    "apoltronemos": "apoltronar",
    "apoltrones": "apoltronar",
    "apoltrono": "apoltronar",
    "apoltronou": "apoltronar",
    "apoltroná": "apoltronar",
    "apoltronámo": "apoltronar",
    "apoltronámos": "apoltronar",
    "apoltronáramo": "apoltronar",
    "apoltronáramos": "apoltronar",
    "apoltronárei": "apoltronar",
    "apoltronáreis": "apoltronar",
    "apoltronásseis": "apoltronar",
    "apoltronássemos": "apoltronar",
    "apoltronávamo": "apoltronar",
    "apoltronávamos": "apoltronar",
    "apoltronávei": "apoltronar",
    "apoltronáveis": "apoltronar",
    "apolínea": "apolíneo",
    "apolíneas": "apolíneo",
    "apolíneos": "apolíneo",
    "apolítica": "apolítico",
    "apolíticas": "apolítico",
    "apolíticos": "apolítico",
    "apológica": "apológico",
    "apológicas": "apológico",
    "apológicos": "apológico",
    "apomecometrias": "apomecometria",
    "apomecómetros": "apomecómetro",
    "apomixias": "apomixia",
    "apomo": "apor",
    "apomorfinas": "apomorfina",
    "apomos": "apor",
    "aponde": "apor",
    "apondes": "apor",
    "apondo": "apor",
    "aponeurologias": "aponeurologia",
    "aponeuroses": "aponeurose",
    "aponeurótica": "aponeurótico",
    "aponeuróticas": "aponeurótico",
    "aponeuróticos": "aponeurótico",
    "aponevrologias": "aponevrologia",
    "aponevroses": "aponevrose",
    "aponevrótica": "aponevrótico",
    "aponevróticas": "aponevrótico",
    "aponevróticos": "aponevrótico",
    "aponha": "apor",
    "aponhais": "apor",
    "aponham": "apor",
    "aponhamo": "apor",
    "aponhamos": "apor",
    "aponhas": "apor",
    "aponho": "apor",
    "aponitroses": "aponitrose",
    "aponta": "apontar",
    "apontada": "apontar",
    "apontadas": "apontar",
    "apontado": "apontar",
    "apontadora": "apontador",
    "apontadoras": "apontador",
    "apontadores": "apontador",
    "apontados": "apontar",
    "apontai": "apontar",
    "apontais": "apontar",
    "apontam": "apontar",
    "apontamentos": "apontamento",
    "apontamo": "apontar",
    "apontamos": "apontar",
    "apontando": "apontar",
    "apontara": "apontar",
    "apontaram": "apontar",
    "apontaras": "apontar",
    "apontarde": "apontar",
    "apontardes": "apontar",
    "apontare": "apontar",
    "apontarei": "apontar",
    "apontareis": "apontar",
    "apontarem": "apontar",
    "apontaremos": "apontar",
    "apontares": "apontar",
    "apontaria": "apontar",
    "apontariam": "apontar",
    "apontarias": "apontar",
    "apontarmo": "apontar",
    "apontarmos": "apontar",
    "apontará": "apontar",
    "apontarás": "apontar",
    "apontarão": "apontar",
    "apontaríamos": "apontar",
    "apontaríeis": "apontar",
    "apontas": "apontar",
    "apontasse": "apontar",
    "apontassem": "apontar",
    "apontasses": "apontar",
    "apontaste": "apontar",
    "apontastes": "apontar",
    "apontava": "apontar",
    "apontavam": "apontar",
    "apontavas": "apontar",
    "aponte": "apontar",
    "apontei": "apontar",
    "aponteis": "apontar",
    "apontem": "apontar",
    "apontemo": "apontar",
    "apontemos": "apontar",
    "apontes": "apontar",
    "aponto": "apontar",
    "apontou": "apontar",
    "apontá": "apontar",
    "apontámo": "apontar",
    "apontámos": "apontar",
    "apontáramo": "apontar",
    "apontáramos": "apontar",
    "apontárei": "apontar",
    "apontáreis": "apontar",
    "apontásseis": "apontar",
    "apontássemos": "apontar",
    "apontávamo": "apontar",
    "apontávamos": "apontar",
    "apontávei": "apontar",
    "apontáveis": "apontável",
    "apoplexias": "apoplexia",
    "apoplética": "apoplético",
    "apopléticas": "apoplético",
    "apopléticos": "apoplético",
    "apoquenta": "apoquentar",
    "apoquentada": "apoquentar",
    "apoquentadas": "apoquentar",
    "apoquentado": "apoquentar",
    "apoquentadora": "apoquentador",
    "apoquentadoras": "apoquentador",
    "apoquentadores": "apoquentador",
    "apoquentados": "apoquentar",
    "apoquentadíssima": "apoquentado",
    "apoquentadíssimas": "apoquentado",
    "apoquentadíssimo": "apoquentado",
    "apoquentadíssimos": "apoquentado",
    "apoquentai": "apoquentar",
    "apoquentais": "apoquentar",
    "apoquentam": "apoquentar",
    "apoquentamo": "apoquentar",
    "apoquentamos": "apoquentar",
    "apoquentando": "apoquentar",
    "apoquentara": "apoquentar",
    "apoquentaram": "apoquentar",
    "apoquentaras": "apoquentar",
    "apoquentarde": "apoquentar",
    "apoquentardes": "apoquentar",
    "apoquentare": "apoquentar",
    "apoquentarei": "apoquentar",
    "apoquentareis": "apoquentar",
    "apoquentarem": "apoquentar",
    "apoquentaremos": "apoquentar",
    "apoquentares": "apoquentar",
    "apoquentaria": "apoquentar",
    "apoquentariam": "apoquentar",
    "apoquentarias": "apoquentar",
    "apoquentarmo": "apoquentar",
    "apoquentarmos": "apoquentar",
    "apoquentará": "apoquentar",
    "apoquentarás": "apoquentar",
    "apoquentarão": "apoquentar",
    "apoquentaríamos": "apoquentar",
    "apoquentaríeis": "apoquentar",
    "apoquentas": "apoquentar",
    "apoquentasse": "apoquentar",
    "apoquentassem": "apoquentar",
    "apoquentasses": "apoquentar",
    "apoquentaste": "apoquentar",
    "apoquentastes": "apoquentar",
    "apoquentava": "apoquentar",
    "apoquentavam": "apoquentar",
    "apoquentavas": "apoquentar",
    "apoquentações": "apoquentação",
    "apoquente": "apoquentar",
    "apoquentei": "apoquentar",
    "apoquenteis": "apoquentar",
    "apoquentem": "apoquentar",
    "apoquentemo": "apoquentar",
    "apoquentemos": "apoquentar",
    "apoquentes": "apoquentar",
    "apoquento": "apoquentar",
    "apoquentou": "apoquentar",
    "apoquentá": "apoquentar",
    "apoquentámo": "apoquentar",
    "apoquentámos": "apoquentar",
    "apoquentáramo": "apoquentar",
    "apoquentáramos": "apoquentar",
    "apoquentárei": "apoquentar",
    "apoquentáreis": "apoquentar",
    "apoquentásseis": "apoquentar",
    "apoquentássemos": "apoquentar",
    "apoquentávamo": "apoquentar",
    "apoquentávamos": "apoquentar",
    "apoquentávei": "apoquentar",
    "apoquentáveis": "apoquentar",
    "aporde": "apor",
    "apordes": "apor",
    "apore": "apor",
    "aporei": "apor",
    "aporeis": "apor",
    "aporem": "apor",
    "aporemas": "aporema",
    "aporemos": "apor",
    "apores": "apor",
    "aporia": "apor",
    "aporiam": "apor",
    "aporias": "aporia",
    "aporismas": "aporisma",
    "aporismos": "aporismo",
    "apormo": "apor",
    "apormos": "apor",
    "aporobrânquia": "aporobrânquio",
    "aporobrânquias": "aporobrânquio",
    "aporobrânquios": "aporobrânquio",
    "aporocéfala": "aporocéfalo",
    "aporocéfalas": "aporocéfalo",
    "aporocéfalos": "aporocéfalo",
    "aporrinhações": "aporrinhação",
    "aporrinoses": "aporrinose",
    "aporta": "aportar",
    "aportada": "aportar",
    "aportadas": "aportar",
    "aportado": "aportar",
    "aportados": "aportar",
    "aportai": "aportar",
    "aportais": "aportar",
    "aportam": "aportar",
    "aportamentos": "aportamento",
    "aportamo": "aportar",
    "aportamos": "aportar",
    "aportando": "aportar",
    "aportara": "aportar",
    "aportaram": "aportar",
    "aportaras": "aportar",
    "aportardes": "aportar",
    "aportarei": "aportar",
    "aportareis": "aportar",
    "aportarem": "aportar",
    "aportaremos": "aportar",
    "aportares": "aportar",
    "aportaria": "aportar",
    "aportariam": "aportar",
    "aportarias": "aportar",
    "aportarmo": "aportar",
    "aportarmos": "aportar",
    "aportará": "aportar",
    "aportarás": "aportar",
    "aportarão": "aportar",
    "aportaríamos": "aportar",
    "aportaríeis": "aportar",
    "aportas": "aportar",
    "aportasse": "aportar",
    "aportassem": "aportar",
    "aportasses": "aportar",
    "aportaste": "aportar",
    "aportastes": "aportar",
    "aportava": "aportar",
    "aportavam": "aportar",
    "aportavas": "aportar",
    "aporte": "aportar",
    "aportei": "aportar",
    "aporteis": "aportar",
    "aportelada": "aportelado",
    "aporteladas": "aportelado",
    "aportelados": "aportelado",
    "aportem": "aportar",
    "aportemo": "aportar",
    "aportemos": "aportar",
    "aportes": "aporte",
    "aporto": "aportar",
    "aportou": "aportar",
    "aportuguesa": "aportuguesar",
    "aportuguesada": "aportuguesar",
    "aportuguesadas": "aportuguesar",
    "aportuguesado": "aportuguesar",
    "aportuguesados": "aportuguesar",
    "aportuguesai": "aportuguesar",
    "aportuguesais": "aportuguesar",
    "aportuguesam": "aportuguesar",
    "aportuguesamentos": "aportuguesamento",
    "aportuguesamo": "aportuguesar",
    "aportuguesamos": "aportuguesar",
    "aportuguesando": "aportuguesar",
    "aportuguesara": "aportuguesar",
    "aportuguesaram": "aportuguesar",
    "aportuguesaras": "aportuguesar",
    "aportuguesarde": "aportuguesar",
    "aportuguesardes": "aportuguesar",
    "aportuguesare": "aportuguesar",
    "aportuguesarei": "aportuguesar",
    "aportuguesareis": "aportuguesar",
    "aportuguesarem": "aportuguesar",
    "aportuguesaremos": "aportuguesar",
    "aportuguesares": "aportuguesar",
    "aportuguesaria": "aportuguesar",
    "aportuguesariam": "aportuguesar",
    "aportuguesarias": "aportuguesar",
    "aportuguesarmo": "aportuguesar",
    "aportuguesarmos": "aportuguesar",
    "aportuguesará": "aportuguesar",
    "aportuguesarás": "aportuguesar",
    "aportuguesarão": "aportuguesar",
    "aportuguesaríamos": "aportuguesar",
    "aportuguesaríeis": "aportuguesar",
    "aportuguesas": "aportuguesar",
    "aportuguesasse": "aportuguesar",
    "aportuguesassem": "aportuguesar",
    "aportuguesasses": "aportuguesar",
    "aportuguesaste": "aportuguesar",
    "aportuguesastes": "aportuguesar",
    "aportuguesava": "aportuguesar",
    "aportuguesavam": "aportuguesar",
    "aportuguesavas": "aportuguesar",
    "aportuguese": "aportuguesar",
    "aportuguesei": "aportuguesar",
    "aportugueseis": "aportuguesar",
    "aportuguesem": "aportuguesar",
    "aportuguesemo": "aportuguesar",
    "aportuguesemos": "aportuguesar",
    "aportugueses": "aportuguesar",
    "aportugueso": "aportuguesar",
    "aportuguesou": "aportuguesar",
    "aportuguesá": "aportuguesar",
    "aportuguesámo": "aportuguesar",
    "aportuguesámos": "aportuguesar",
    "aportuguesáramo": "aportuguesar",
    "aportuguesáramos": "aportuguesar",
    "aportuguesárei": "aportuguesar",
    "aportuguesáreis": "aportuguesar",
    "aportuguesásseis": "aportuguesar",
    "aportuguesássemos": "aportuguesar",
    "aportuguesávamo": "aportuguesar",
    "aportuguesávamos": "aportuguesar",
    "aportuguesávei": "aportuguesar",
    "aportuguesáveis": "aportuguesável",
    "aportámo": "aportar",
    "aportámos": "aportar",
    "aportáramo": "aportar",
    "aportáramos": "aportar",
    "aportáreis": "aportar",
    "aportásseis": "aportar",
    "aportássemos": "aportar",
    "aportávamo": "aportar",
    "aportávamos": "aportar",
    "aportáveis": "aportar",
    "aporá": "apor",
    "aporás": "apor",
    "aporão": "apor",
    "aporética": "aporético",
    "aporéticas": "aporético",
    "aporéticos": "aporético",
    "aporíamos": "apor",
    "aporíeis": "apor",
    "apos": "apo",
    "aposenta": "aposentar",
    "aposentada": "aposentar",
    "aposentadas": "aposentar",
    "aposentado": "aposentar",
    "aposentadora": "aposentador",
    "aposentadoras": "aposentador",
    "aposentadores": "aposentador",
    "aposentadorias": "aposentadoria",
    "aposentados": "aposentar",
    "aposentai": "aposentar",
    "aposentais": "aposentar",
    "aposentam": "aposentar",
    "aposentamentos": "aposentamento",
    "aposentamo": "aposentar",
    "aposentamos": "aposentar",
    "aposentando": "aposentar",
    "aposentara": "aposentar",
    "aposentaram": "aposentar",
    "aposentaras": "aposentar",
    "aposentarde": "aposentar",
    "aposentardes": "aposentar",
    "aposentare": "aposentar",
    "aposentarei": "aposentar",
    "aposentareis": "aposentar",
    "aposentarem": "aposentar",
    "aposentaremos": "aposentar",
    "aposentares": "aposentar",
    "aposentaria": "aposentar",
    "aposentariam": "aposentar",
    "aposentarias": "aposentar",
    "aposentarmo": "aposentar",
    "aposentarmos": "aposentar",
    "aposentará": "aposentar",
    "aposentarás": "aposentar",
    "aposentarão": "aposentar",
    "aposentaríamos": "aposentar",
    "aposentaríeis": "aposentar",
    "aposentas": "aposentar",
    "aposentasse": "aposentar",
    "aposentassem": "aposentar",
    "aposentasses": "aposentar",
    "aposentaste": "aposentar",
    "aposentastes": "aposentar",
    "aposentava": "aposentar",
    "aposentavam": "aposentar",
    "aposentavas": "aposentar",
    "aposentações": "aposentação",
    "aposente": "aposentar",
    "aposentei": "aposentar",
    "aposenteis": "aposentar",
    "aposentem": "aposentar",
    "aposentemo": "aposentar",
    "aposentemos": "aposentar",
    "aposentes": "aposentar",
    "aposento": "aposentar",
    "aposentos": "aposento",
    "aposentou": "aposentar",
    "aposentá": "aposentar",
    "aposentámo": "aposentar",
    "aposentámos": "aposentar",
    "aposentáramo": "aposentar",
    "aposentáramos": "aposentar",
    "aposentárei": "aposentar",
    "aposentáreis": "aposentar",
    "aposentásseis": "aposentar",
    "aposentássemos": "aposentar",
    "aposentávamo": "aposentar",
    "aposentávamos": "aposentar",
    "aposentávei": "aposentar",
    "aposentáveis": "aposentar",
    "aposias": "aposia",
    "aposiopeses": "aposiopese",
    "apositias": "apositia",
    "apositiva": "apositivo",
    "apositivas": "apositivo",
    "apositivos": "apositivo",
    "aposições": "aposição",
    "apossa": "apossar",
    "apossada": "apossar",
    "apossadas": "apossar",
    "apossado": "apossar",
    "apossados": "apossar",
    "apossai": "apossar",
    "apossais": "apossar",
    "apossam": "apossar",
    "apossamo": "apossar",
    "apossamos": "apossar",
    "apossando": "apossar",
    "apossara": "apossar",
    "apossaram": "apossar",
    "apossaras": "apossar",
    "apossarde": "apossar",
    "apossardes": "apossar",
    "apossare": "apossar",
    "apossarei": "apossar",
    "apossareis": "apossar",
    "apossarem": "apossar",
    "apossaremos": "apossar",
    "apossares": "apossar",
    "apossaria": "apossar",
    "apossariam": "apossar",
    "apossarias": "apossar",
    "apossarmo": "apossar",
    "apossarmos": "apossar",
    "apossará": "apossar",
    "apossarás": "apossar",
    "apossarão": "apossar",
    "apossaríamos": "apossar",
    "apossaríeis": "apossar",
    "apossas": "apossar",
    "apossasse": "apossar",
    "apossassem": "apossar",
    "apossasses": "apossar",
    "apossaste": "apossar",
    "apossastes": "apossar",
    "apossava": "apossar",
    "apossavam": "apossar",
    "apossavas": "apossar",
    "aposse": "apossar",
    "apossei": "apossar",
    "aposseis": "apossar",
    "apossem": "apossar",
    "apossemo": "apossar",
    "apossemos": "apossar",
    "aposses": "apossar",
    "aposso": "apossar",
    "apossou": "apossar",
    "apossua": "apossuir",
    "apossuais": "apossuir",
    "apossuam": "apossuir",
    "apossuamo": "apossuir",
    "apossuamos": "apossuir",
    "apossuas": "apossuir",
    "apossuem": "apossuir",
    "apossui": "apossuir",
    "apossuindo": "apossuir",
    "apossuirde": "apossuir",
    "apossuirdes": "apossuir",
    "apossuirei": "apossuir",
    "apossuireis": "apossuir",
    "apossuiremos": "apossuir",
    "apossuiria": "apossuir",
    "apossuiriam": "apossuir",
    "apossuirias": "apossuir",
    "apossuirmo": "apossuir",
    "apossuirmos": "apossuir",
    "apossuirá": "apossuir",
    "apossuirás": "apossuir",
    "apossuirão": "apossuir",
    "apossuiríamos": "apossuir",
    "apossuiríeis": "apossuir",
    "apossuis": "apossuir",
    "apossuiu": "apossuir",
    "apossuo": "apossuir",
    "apossuí": "apossuir",
    "apossuía": "apossuir",
    "apossuíam": "apossuir",
    "apossuíamo": "apossuir",
    "apossuíamos": "apossuir",
    "apossuías": "apossuir",
    "apossuída": "apossuir",
    "apossuídas": "apossuir",
    "apossuído": "apossuir",
    "apossuídos": "apossuir",
    "apossuíei": "apossuir",
    "apossuíeis": "apossuir",
    "apossuímo": "apossuir",
    "apossuímos": "apossuir",
    "apossuíra": "apossuir",
    "apossuíram": "apossuir",
    "apossuíramo": "apossuir",
    "apossuíramos": "apossuir",
    "apossuíras": "apossuir",
    "apossuíre": "apossuir",
    "apossuírei": "apossuir",
    "apossuíreis": "apossuir",
    "apossuírem": "apossuir",
    "apossuíres": "apossuir",
    "apossuís": "apossuir",
    "apossuísse": "apossuir",
    "apossuísseis": "apossuir",
    "apossuíssem": "apossuir",
    "apossuíssemos": "apossuir",
    "apossuísses": "apossuir",
    "apossuíste": "apossuir",
    "apossuístes": "apossuir",
    "apossá": "apossar",
    "apossámo": "apossar",
    "apossámos": "apossar",
    "apossáramo": "apossar",
    "apossáramos": "apossar",
    "apossárei": "apossar",
    "apossáreis": "apossar",
    "apossásseis": "apossar",
    "apossássemos": "apossar",
    "apossávamo": "apossar",
    "apossávamos": "apossar",
    "apossávei": "apossar",
    "apossáveis": "apossar",
    "aposta": "aposto",
    "apostada": "apostar",
    "apostadas": "apostar",
    "apostado": "apostar",
    "apostadora": "apostador",
    "apostadoras": "apostador",
    "apostadores": "apostador",
    "apostados": "apostar",
    "apostai": "apostar",
    "apostais": "apostar",
    "apostam": "apostar",
    "apostamo": "apostar",
    "apostamos": "apostar",
    "apostando": "apostar",
    "apostara": "apostar",
    "apostaram": "apostar",
    "apostaras": "apostar",
    "apostarde": "apostar",
    "apostardes": "apostar",
    "apostare": "apostar",
    "apostarei": "apostar",
    "apostareis": "apostar",
    "apostarem": "apostar",
    "apostaremos": "apostar",
    "apostares": "apostar",
    "apostaria": "apostar",
    "apostariam": "apostar",
    "apostarias": "apostar",
    "apostarmo": "apostar",
    "apostarmos": "apostar",
    "apostará": "apostar",
    "apostarás": "apostar",
    "apostarão": "apostar",
    "apostaríamos": "apostar",
    "apostaríeis": "apostar",
    "apostas": "aposto",
    "apostasias": "apostasia",
    "apostasse": "apostar",
    "apostassem": "apostar",
    "apostasses": "apostar",
    "apostaste": "apostar",
    "apostastes": "apostar",
    "apostata": "apostatar",
    "apostatada": "apostatar",
    "apostatadas": "apostatar",
    "apostatado": "apostatar",
    "apostatados": "apostatar",
    "apostatai": "apostatar",
    "apostatais": "apostatar",
    "apostatam": "apostatar",
    "apostatamo": "apostatar",
    "apostatamos": "apostatar",
    "apostatando": "apostatar",
    "apostatara": "apostatar",
    "apostataram": "apostatar",
    "apostataras": "apostatar",
    "apostatarde": "apostatar",
    "apostatardes": "apostatar",
    "apostatare": "apostatar",
    "apostatarei": "apostatar",
    "apostatareis": "apostatar",
    "apostatarem": "apostatar",
    "apostataremos": "apostatar",
    "apostatares": "apostatar",
    "apostataria": "apostatar",
    "apostatariam": "apostatar",
    "apostatarias": "apostatar",
    "apostatarmo": "apostatar",
    "apostatarmos": "apostatar",
    "apostatará": "apostatar",
    "apostatarás": "apostatar",
    "apostatarão": "apostatar",
    "apostataríamos": "apostatar",
    "apostataríeis": "apostatar",
    "apostatas": "apostatar",
    "apostatasse": "apostatar",
    "apostatassem": "apostatar",
    "apostatasses": "apostatar",
    "apostataste": "apostatar",
    "apostatastes": "apostatar",
    "apostatava": "apostatar",
    "apostatavam": "apostatar",
    "apostatavas": "apostatar",
    "apostate": "apostatar",
    "apostatei": "apostatar",
    "apostateis": "apostatar",
    "apostatem": "apostatar",
    "apostatemo": "apostatar",
    "apostatemos": "apostatar",
    "apostates": "apostatar",
    "apostato": "apostatar",
    "apostatou": "apostatar",
    "apostatá": "apostatar",
    "apostatámo": "apostatar",
    "apostatámos": "apostatar",
    "apostatáramo": "apostatar",
    "apostatáramos": "apostatar",
    "apostatárei": "apostatar",
    "apostatáreis": "apostatar",
    "apostatásseis": "apostatar",
    "apostatássemos": "apostatar",
    "apostatávamo": "apostatar",
    "apostatávamos": "apostatar",
    "apostatávei": "apostatar",
    "apostatáveis": "apostatar",
    "apostava": "apostar",
    "apostavam": "apostar",
    "apostavas": "apostar",
    "aposte": "apostar",
    "apostei": "apostar",
    "aposteis": "apostar",
    "apostem": "apostar",
    "apostema": "apostemar",
    "apostemada": "apostemar",
    "apostemadas": "apostemar",
    "apostemado": "apostemar",
    "apostemados": "apostemar",
    "apostemai": "apostemar",
    "apostemais": "apostemar",
    "apostemam": "apostemar",
    "apostemamo": "apostemar",
    "apostemamos": "apostemar",
    "apostemando": "apostemar",
    "apostemara": "apostemar",
    "apostemaram": "apostemar",
    "apostemaras": "apostemar",
    "apostemarde": "apostemar",
    "apostemardes": "apostemar",
    "apostemare": "apostemar",
    "apostemarei": "apostemar",
    "apostemareis": "apostemar",
    "apostemarem": "apostemar",
    "apostemaremos": "apostemar",
    "apostemares": "apostemar",
    "apostemaria": "apostemar",
    "apostemariam": "apostemar",
    "apostemarias": "apostemar",
    "apostemarmo": "apostemar",
    "apostemarmos": "apostemar",
    "apostemará": "apostemar",
    "apostemarás": "apostemar",
    "apostemarão": "apostemar",
    "apostemaríamos": "apostemar",
    "apostemaríeis": "apostemar",
    "apostemas": "apostemar",
    "apostemasse": "apostemar",
    "apostemassem": "apostemar",
    "apostemasses": "apostemar",
    "apostemaste": "apostemar",
    "apostemastes": "apostemar",
    "apostemava": "apostemar",
    "apostemavam": "apostemar",
    "apostemavas": "apostemar",
    "apostemações": "apostemação",
    "aposteme": "apostemar",
    "apostemei": "apostemar",
    "apostemeis": "apostemar",
    "apostemem": "apostemar",
    "apostememo": "apostemar",
    "apostememos": "apostemar",
    "apostemes": "apostemar",
    "apostemo": "apostemar",
    "apostemos": "apostar",
    "apostemosa": "apostemoso",
    "apostemosas": "apostemoso",
    "apostemosos": "apostemoso",
    "apostemou": "apostemar",
    "apostemá": "apostemar",
    "apostemámo": "apostemar",
    "apostemámos": "apostemar",
    "apostemáramo": "apostemar",
    "apostemáramos": "apostemar",
    "apostemárei": "apostemar",
    "apostemáreis": "apostemar",
    "apostemásseis": "apostemar",
    "apostemássemos": "apostemar",
    "apostemática": "apostemático",
    "apostemáticas": "apostemático",
    "apostemáticos": "apostemático",
    "apostemávamo": "apostemar",
    "apostemávamos": "apostemar",
    "apostemávei": "apostemar",
    "apostemáveis": "apostemar",
    "apostes": "apostar",
    "apostias": "apostia",
    "apostiladora": "apostilador",
    "apostiladoras": "apostilador",
    "apostiladores": "apostilador",
    "apostilas": "apostila",
    "aposto": "apostar",
    "apostola": "apostolar",
    "apostolada": "apostolar",
    "apostoladas": "apostolar",
    "apostolado": "apostolar",
    "apostolados": "apostolar",
    "apostolai": "apostolar",
    "apostolais": "apostolar",
    "apostolam": "apostolar",
    "apostolamo": "apostolar",
    "apostolamos": "apostolar",
    "apostolando": "apostolar",
    "apostolara": "apostolar",
    "apostolaram": "apostolar",
    "apostolaras": "apostolar",
    "apostolarde": "apostolar",
    "apostolardes": "apostolar",
    "apostolare": "apostolar",
    "apostolarei": "apostolar",
    "apostolareis": "apostolar",
    "apostolarem": "apostolar",
    "apostolaremos": "apostolar",
    "apostolares": "apostolar",
    "apostolaria": "apostolar",
    "apostolariam": "apostolar",
    "apostolarias": "apostolar",
    "apostolarmo": "apostolar",
    "apostolarmos": "apostolar",
    "apostolará": "apostolar",
    "apostolarás": "apostolar",
    "apostolarão": "apostolar",
    "apostolaríamos": "apostolar",
    "apostolaríeis": "apostolar",
    "apostolas": "apostolar",
    "apostolasse": "apostolar",
    "apostolassem": "apostolar",
    "apostolasses": "apostolar",
    "apostolaste": "apostolar",
    "apostolastes": "apostolar",
    "apostolava": "apostolar",
    "apostolavam": "apostolar",
    "apostolavas": "apostolar",
    "apostole": "apostolar",
    "apostolei": "apostolar",
    "apostoleis": "apostolar",
    "apostolem": "apostolar",
    "apostolemo": "apostolar",
    "apostolemos": "apostolar",
    "apostoles": "apostolar",
    "apostolicidades": "apostolicidade",
    "apostoliza": "apostolizar",
    "apostolizada": "apostolizar",
    "apostolizadas": "apostolizar",
    "apostolizado": "apostolizar",
    "apostolizados": "apostolizar",
    "apostolizai": "apostolizar",
    "apostolizais": "apostolizar",
    "apostolizam": "apostolizar",
    "apostolizamo": "apostolizar",
    "apostolizamos": "apostolizar",
    "apostolizando": "apostolizar",
    "apostolizara": "apostolizar",
    "apostolizaram": "apostolizar",
    "apostolizaras": "apostolizar",
    "apostolizarde": "apostolizar",
    "apostolizardes": "apostolizar",
    "apostolizare": "apostolizar",
    "apostolizarei": "apostolizar",
    "apostolizareis": "apostolizar",
    "apostolizarem": "apostolizar",
    "apostolizaremos": "apostolizar",
    "apostolizares": "apostolizar",
    "apostolizaria": "apostolizar",
    "apostolizariam": "apostolizar",
    "apostolizarias": "apostolizar",
    "apostolizarmo": "apostolizar",
    "apostolizarmos": "apostolizar",
    "apostolizará": "apostolizar",
    "apostolizarás": "apostolizar",
    "apostolizarão": "apostolizar",
    "apostolizaríamos": "apostolizar",
    "apostolizaríeis": "apostolizar",
    "apostolizas": "apostolizar",
    "apostolizasse": "apostolizar",
    "apostolizassem": "apostolizar",
    "apostolizasses": "apostolizar",
    "apostolizaste": "apostolizar",
    "apostolizastes": "apostolizar",
    "apostolizava": "apostolizar",
    "apostolizavam": "apostolizar",
    "apostolizavas": "apostolizar",
    "apostolizações": "apostolização",
    "apostolize": "apostolizar",
    "apostolizei": "apostolizar",
    "apostolizeis": "apostolizar",
    "apostolizem": "apostolizar",
    "apostolizemo": "apostolizar",
    "apostolizemos": "apostolizar",
    "apostolizes": "apostolizar",
    "apostolizo": "apostolizar",
    "apostolizou": "apostolizar",
    "apostolizá": "apostolizar",
    "apostolizámo": "apostolizar",
    "apostolizámos": "apostolizar",
    "apostolizáramo": "apostolizar",
    "apostolizáramos": "apostolizar",
    "apostolizárei": "apostolizar",
    "apostolizáreis": "apostolizar",
    "apostolizásseis": "apostolizar",
    "apostolizássemos": "apostolizar",
    "apostolizávamo": "apostolizar",
    "apostolizávamos": "apostolizar",
    "apostolizávei": "apostolizar",
    "apostolizáveis": "apostolizar",
    "apostolo": "apostolar",
    "apostolou": "apostolar",
    "apostolá": "apostolar",
    "apostolámo": "apostolar",
    "apostolámos": "apostolar",
    "apostoláramo": "apostolar",
    "apostoláramos": "apostolar",
    "apostolárei": "apostolar",
    "apostoláreis": "apostolar",
    "apostolásseis": "apostolar",
    "apostolássemos": "apostolar",
    "apostolávamo": "apostolar",
    "apostolávamos": "apostolar",
    "apostolávei": "apostolar",
    "apostoláveis": "apostolar",
    "apostos": "aposto",
    "apostou": "apostar",
    "aposturas": "apostura",
    "apostá": "apostar",
    "apostámo": "apostar",
    "apostámos": "apostar",
    "apostáramo": "apostar",
    "apostáramos": "apostar",
    "apostárei": "apostar",
    "apostáreis": "apostar",
    "apostásseis": "apostar",
    "apostássemos": "apostar",
    "apostática": "apostático",
    "apostáticas": "apostático",
    "apostáticos": "apostático",
    "apostávamo": "apostar",
    "apostávamos": "apostar",
    "apostávei": "apostar",
    "apostáveis": "apostar",
    "apostólica": "apostólico",
    "apostólicas": "apostólico",
    "apostólicos": "apostólico",
    "aposítica": "aposítico",
    "aposíticas": "aposítico",
    "aposíticos": "aposítico",
    "apotanásias": "apotanásia",
    "apotegmas": "apotegma",
    "apotegmatismos": "apotegmatismo",
    "apotegmática": "apotegmático",
    "apotegmáticas": "apotegmático",
    "apotegmáticos": "apotegmático",
    "apotenta": "apotentar",
    "apotentada": "apotentar",
    "apotentadas": "apotentar",
    "apotentado": "apotentar",
    "apotentados": "apotentar",
    "apotentai": "apotentar",
    "apotentais": "apotentar",
    "apotentam": "apotentar",
    "apotentamo": "apotentar",
    "apotentamos": "apotentar",
    "apotentando": "apotentar",
    "apotentara": "apotentar",
    "apotentaram": "apotentar",
    "apotentaras": "apotentar",
    "apotentarde": "apotentar",
    "apotentardes": "apotentar",
    "apotentare": "apotentar",
    "apotentarei": "apotentar",
    "apotentareis": "apotentar",
    "apotentarem": "apotentar",
    "apotentaremos": "apotentar",
    "apotentares": "apotentar",
    "apotentaria": "apotentar",
    "apotentariam": "apotentar",
    "apotentarias": "apotentar",
    "apotentarmo": "apotentar",
    "apotentarmos": "apotentar",
    "apotentará": "apotentar",
    "apotentarás": "apotentar",
    "apotentarão": "apotentar",
    "apotentaríamos": "apotentar",
    "apotentaríeis": "apotentar",
    "apotentas": "apotentar",
    "apotentasse": "apotentar",
    "apotentassem": "apotentar",
    "apotentasses": "apotentar",
    "apotentaste": "apotentar",
    "apotentastes": "apotentar",
    "apotentava": "apotentar",
    "apotentavam": "apotentar",
    "apotentavas": "apotentar",
    "apotente": "apotentar",
    "apotentei": "apotentar",
    "apotenteis": "apotentar",
    "apotentem": "apotentar",
    "apotentemo": "apotentar",
    "apotentemos": "apotentar",
    "apotentes": "apotentar",
    "apotento": "apotentar",
    "apotentou": "apotentar",
    "apotentá": "apotentar",
    "apotentámo": "apotentar",
    "apotentámos": "apotentar",
    "apotentáramo": "apotentar",
    "apotentáramos": "apotentar",
    "apotentárei": "apotentar",
    "apotentáreis": "apotentar",
    "apotentásseis": "apotentar",
    "apotentássemos": "apotentar",
    "apotentávamo": "apotentar",
    "apotentávamos": "apotentar",
    "apotentávei": "apotentar",
    "apotentáveis": "apotentar",
    "apoteosa": "apoteosar",
    "apoteosada": "apoteosar",
    "apoteosadas": "apoteosar",
    "apoteosado": "apoteosar",
    "apoteosados": "apoteosar",
    "apoteosai": "apoteosar",
    "apoteosais": "apoteosar",
    "apoteosam": "apoteosar",
    "apoteosamo": "apoteosar",
    "apoteosamos": "apoteosar",
    "apoteosando": "apoteosar",
    "apoteosara": "apoteosar",
    "apoteosaram": "apoteosar",
    "apoteosaras": "apoteosar",
    "apoteosarde": "apoteosar",
    "apoteosardes": "apoteosar",
    "apoteosare": "apoteosar",
    "apoteosarei": "apoteosar",
    "apoteosareis": "apoteosar",
    "apoteosarem": "apoteosar",
    "apoteosaremos": "apoteosar",
    "apoteosares": "apoteosar",
    "apoteosaria": "apoteosar",
    "apoteosariam": "apoteosar",
    "apoteosarias": "apoteosar",
    "apoteosarmo": "apoteosar",
    "apoteosarmos": "apoteosar",
    "apoteosará": "apoteosar",
    "apoteosarás": "apoteosar",
    "apoteosarão": "apoteosar",
    "apoteosaríamos": "apoteosar",
    "apoteosaríeis": "apoteosar",
    "apoteosas": "apoteosar",
    "apoteosasse": "apoteosar",
    "apoteosassem": "apoteosar",
    "apoteosasses": "apoteosar",
    "apoteosaste": "apoteosar",
    "apoteosastes": "apoteosar",
    "apoteosava": "apoteosar",
    "apoteosavam": "apoteosar",
    "apoteosavas": "apoteosar",
    "apoteose": "apoteosar",
    "apoteosei": "apoteosar",
    "apoteoseis": "apoteosar",
    "apoteosem": "apoteosar",
    "apoteosemo": "apoteosar",
    "apoteosemos": "apoteosar",
    "apoteoses": "apoteose",
    "apoteoso": "apoteosar",
    "apoteosou": "apoteosar",
    "apoteosá": "apoteosar",
    "apoteosámo": "apoteosar",
    "apoteosámos": "apoteosar",
    "apoteosáramo": "apoteosar",
    "apoteosáramos": "apoteosar",
    "apoteosárei": "apoteosar",
    "apoteosáreis": "apoteosar",
    "apoteosásseis": "apoteosar",
    "apoteosássemos": "apoteosar",
    "apoteosávamo": "apoteosar",
    "apoteosávamos": "apoteosar",
    "apoteosávei": "apoteosar",
    "apoteosáveis": "apoteosar",
    "apoteótica": "apoteótico",
    "apoteóticas": "apoteótico",
    "apoteóticos": "apoteótico",
    "apotécias": "apotécia",
    "apotécios": "apotécio",
    "apoucada": "apoucado",
    "apoucadas": "apoucado",
    "apoucados": "apoucado",
    "apoucamentos": "apoucamento",
    "apraxias": "apraxia",
    "apraz": "aprazer",
    "apraza": "aprazer",
    "aprazada": "aprazar",
    "aprazadas": "aprazar",
    "aprazado": "aprazar",
    "aprazadora": "aprazador",
    "aprazadoras": "aprazador",
    "aprazadores": "aprazador",
    "aprazados": "aprazar",
    "aprazai": "aprazar",
    "aprazais": "aprazar",
    "aprazam": "aprazer",
    "aprazamentos": "aprazamento",
    "aprazamo": "aprazar",
    "aprazamos": "aprazar",
    "aprazando": "aprazar",
    "aprazara": "aprazar",
    "aprazaram": "aprazar",
    "aprazaras": "aprazar",
    "aprazarde": "aprazar",
    "aprazardes": "aprazar",
    "aprazare": "aprazar",
    "aprazarei": "aprazar",
    "aprazareis": "aprazar",
    "aprazarem": "aprazar",
    "aprazaremos": "aprazar",
    "aprazares": "aprazar",
    "aprazaria": "aprazar",
    "aprazariam": "aprazar",
    "aprazarias": "aprazar",
    "aprazarmo": "aprazar",
    "aprazarmos": "aprazar",
    "aprazará": "aprazar",
    "aprazarás": "aprazar",
    "aprazarão": "aprazar",
    "aprazaríamos": "aprazar",
    "aprazaríeis": "aprazar",
    "aprazas": "aprazar",
    "aprazasse": "aprazar",
    "aprazassem": "aprazar",
    "aprazasses": "aprazar",
    "aprazaste": "aprazar",
    "aprazastes": "aprazar",
    "aprazava": "aprazar",
    "aprazavam": "aprazar",
    "aprazavas": "aprazar",
    "apraze": "aprazar",
    "aprazedora": "aprazedor",
    "aprazedoras": "aprazedor",
    "aprazedores": "aprazedor",
    "aprazei": "aprazar",
    "aprazeis": "aprazar",
    "aprazem": "aprazer",
    "aprazemo": "aprazar",
    "aprazemos": "aprazar",
    "aprazendo": "aprazer",
    "aprazerem": "aprazer",
    "aprazeria": "aprazer",
    "aprazeriam": "aprazer",
    "aprazerá": "aprazer",
    "aprazerão": "aprazer",
    "aprazes": "aprazar",
    "aprazia": "aprazer",
    "apraziam": "aprazer",
    "aprazibilidades": "aprazibilidade",
    "aprazida": "aprazer",
    "aprazidas": "aprazer",
    "aprazido": "aprazer",
    "aprazidos": "aprazer",
    "aprazimentos": "aprazimento",
    "aprazo": "aprazar",
    "aprazou": "aprazar",
    "aprazá": "aprazar",
    "aprazámo": "aprazar",
    "aprazámos": "aprazar",
    "aprazáramo": "aprazar",
    "aprazáramos": "aprazar",
    "aprazárei": "aprazar",
    "aprazáreis": "aprazar",
    "aprazásseis": "aprazar",
    "aprazássemos": "aprazar",
    "aprazávamo": "aprazar",
    "aprazávamos": "aprazar",
    "aprazávei": "aprazar",
    "aprazáveis": "aprazar",
    "aprazíveis": "aprazível",
    "aprece": "apreçar",
    "aprecei": "apreçar",
    "apreceis": "apreçar",
    "aprecem": "apreçar",
    "aprecemo": "apreçar",
    "aprecemos": "apreçar",
    "apreces": "apreçar",
    "aprecia": "apreciar",
    "apreciada": "apreciar",
    "apreciadas": "apreciar",
    "apreciado": "apreciar",
    "apreciadora": "apreciador",
    "apreciadoras": "apreciador",
    "apreciadores": "apreciador",
    "apreciados": "apreciar",
    "apreciadíssima": "apreciado",
    "apreciadíssimas": "apreciado",
    "apreciadíssimo": "apreciado",
    "apreciadíssimos": "apreciado",
    "apreciai": "apreciar",
    "apreciais": "apreciar",
    "apreciam": "apreciar",
    "apreciamentos": "apreciamento",
    "apreciamo": "apreciar",
    "apreciamos": "apreciar",
    "apreciando": "apreciar",
    "apreciara": "apreciar",
    "apreciaram": "apreciar",
    "apreciaras": "apreciar",
    "apreciarde": "apreciar",
    "apreciardes": "apreciar",
    "apreciare": "apreciar",
    "apreciarei": "apreciar",
    "apreciareis": "apreciar",
    "apreciarem": "apreciar",
    "apreciaremos": "apreciar",
    "apreciares": "apreciar",
    "apreciaria": "apreciar",
    "apreciariam": "apreciar",
    "apreciarias": "apreciar",
    "apreciarmo": "apreciar",
    "apreciarmos": "apreciar",
    "apreciará": "apreciar",
    "apreciarás": "apreciar",
    "apreciarão": "apreciar",
    "apreciaríamos": "apreciar",
    "apreciaríeis": "apreciar",
    "aprecias": "apreciar",
    "apreciasse": "apreciar",
    "apreciassem": "apreciar",
    "apreciasses": "apreciar",
    "apreciaste": "apreciar",
    "apreciastes": "apreciar",
    "apreciativa": "apreciativo",
    "apreciativas": "apreciativo",
    "apreciativos": "apreciativo",
    "apreciava": "apreciar",
    "apreciavam": "apreciar",
    "apreciavas": "apreciar",
    "apreciações": "apreciação",
    "aprecie": "apreciar",
    "apreciei": "apreciar",
    "aprecieis": "apreciar",
    "apreciem": "apreciar",
    "apreciemo": "apreciar",
    "apreciemos": "apreciar",
    "aprecies": "apreciar",
    "aprecio": "apreciar",
    "apreciou": "apreciar",
    "apreciá": "apreciar",
    "apreciámo": "apreciar",
    "apreciámos": "apreciar",
    "apreciáramo": "apreciar",
    "apreciáramos": "apreciar",
    "apreciárei": "apreciar",
    "apreciáreis": "apreciar",
    "apreciásseis": "apreciar",
    "apreciássemos": "apreciar",
    "apreciávamo": "apreciar",
    "apreciávamos": "apreciar",
    "apreciávei": "apreciar",
    "apreciáveis": "apreciável",
    "apreenda": "apreender",
    "apreendais": "apreender",
    "apreendam": "apreender",
    "apreendamo": "apreender",
    "apreendamos": "apreender",
    "apreendas": "apreender",
    "apreende": "apreender",
    "apreendedora": "apreendedor",
    "apreendedoras": "apreendedor",
    "apreendedores": "apreendedor",
    "apreendei": "apreender",
    "apreendeis": "apreender",
    "apreendem": "apreender",
    "apreendemo": "apreender",
    "apreendemos": "apreender",
    "apreendendo": "apreender",
    "apreendera": "apreender",
    "apreenderam": "apreender",
    "apreenderas": "apreender",
    "apreenderde": "apreender",
    "apreenderdes": "apreender",
    "apreendere": "apreender",
    "apreenderei": "apreender",
    "apreendereis": "apreender",
    "apreenderem": "apreender",
    "apreenderemos": "apreender",
    "apreenderes": "apreender",
    "apreenderia": "apreender",
    "apreenderiam": "apreender",
    "apreenderias": "apreender",
    "apreendermo": "apreender",
    "apreendermos": "apreender",
    "apreenderá": "apreender",
    "apreenderás": "apreender",
    "apreenderão": "apreender",
    "apreenderíamos": "apreender",
    "apreenderíeis": "apreender",
    "apreendes": "apreender",
    "apreendesse": "apreender",
    "apreendessem": "apreender",
    "apreendesses": "apreender",
    "apreendeste": "apreender",
    "apreendestes": "apreender",
    "apreendeu": "apreender",
    "apreendi": "apreender",
    "apreendia": "apreender",
    "apreendiam": "apreender",
    "apreendias": "apreender",
    "apreendida": "apreendido",
    "apreendidas": "apreendido",
    "apreendido": "apreender",
    "apreendidos": "apreendido",
    "apreendo": "apreender",
    "apreendê": "apreender",
    "apreendêramo": "apreender",
    "apreendêramos": "apreender",
    "apreendêrei": "apreender",
    "apreendêreis": "apreender",
    "apreendêsseis": "apreender",
    "apreendêssemos": "apreender",
    "apreendíamo": "apreender",
    "apreendíamos": "apreender",
    "apreendíei": "apreender",
    "apreendíeis": "apreender",
    "apreensibilidades": "apreensibilidade",
    "apreensiva": "apreensivo",
    "apreensivas": "apreensivo",
    "apreensivos": "apreensivo",
    "apreensora": "apreensor",
    "apreensoras": "apreensor",
    "apreensores": "apreensor",
    "apreensíveis": "apreensível",
    "apreensória": "apreensório",
    "apreensórias": "apreensório",
    "apreensórios": "apreensório",
    "apreensões": "apreensão",
    "aprefixa": "aprefixar",
    "aprefixada": "aprefixar",
    "aprefixadas": "aprefixar",
    "aprefixado": "aprefixar",
    "aprefixados": "aprefixar",
    "aprefixai": "aprefixar",
    "aprefixais": "aprefixar",
    "aprefixam": "aprefixar",
    "aprefixamo": "aprefixar",
    "aprefixamos": "aprefixar",
    "aprefixando": "aprefixar",
    "aprefixara": "aprefixar",
    "aprefixaram": "aprefixar",
    "aprefixaras": "aprefixar",
    "aprefixarde": "aprefixar",
    "aprefixardes": "aprefixar",
    "aprefixare": "aprefixar",
    "aprefixarei": "aprefixar",
    "aprefixareis": "aprefixar",
    "aprefixarem": "aprefixar",
    "aprefixaremos": "aprefixar",
    "aprefixares": "aprefixar",
    "aprefixaria": "aprefixar",
    "aprefixariam": "aprefixar",
    "aprefixarias": "aprefixar",
    "aprefixarmo": "aprefixar",
    "aprefixarmos": "aprefixar",
    "aprefixará": "aprefixar",
    "aprefixarás": "aprefixar",
    "aprefixarão": "aprefixar",
    "aprefixaríamos": "aprefixar",
    "aprefixaríeis": "aprefixar",
    "aprefixas": "aprefixar",
    "aprefixasse": "aprefixar",
    "aprefixassem": "aprefixar",
    "aprefixasses": "aprefixar",
    "aprefixaste": "aprefixar",
    "aprefixastes": "aprefixar",
    "aprefixava": "aprefixar",
    "aprefixavam": "aprefixar",
    "aprefixavas": "aprefixar",
    "aprefixe": "aprefixar",
    "aprefixei": "aprefixar",
    "aprefixeis": "aprefixar",
    "aprefixem": "aprefixar",
    "aprefixemo": "aprefixar",
    "aprefixemos": "aprefixar",
    "aprefixes": "aprefixar",
    "aprefixo": "aprefixar",
    "aprefixou": "aprefixar",
    "aprefixá": "aprefixar",
    "aprefixámo": "aprefixar",
    "aprefixámos": "aprefixar",
    "aprefixáramo": "aprefixar",
    "aprefixáramos": "aprefixar",
    "aprefixárei": "aprefixar",
    "aprefixáreis": "aprefixar",
    "aprefixásseis": "aprefixar",
    "aprefixássemos": "aprefixar",
    "aprefixávamo": "aprefixar",
    "aprefixávamos": "aprefixar",
    "aprefixávei": "aprefixar",
    "aprefixáveis": "aprefixar",
    "apregoa": "apregoar",
    "apregoada": "apregoar",
    "apregoadas": "apregoar",
    "apregoado": "apregoar",
    "apregoadora": "apregoador",
    "apregoadoras": "apregoador",
    "apregoadores": "apregoador",
    "apregoados": "apregoar",
    "apregoadíssima": "apregoado",
    "apregoadíssimas": "apregoado",
    "apregoadíssimo": "apregoado",
    "apregoadíssimos": "apregoado",
    "apregoai": "apregoar",
    "apregoais": "apregoar",
    "apregoam": "apregoar",
    "apregoamo": "apregoar",
    "apregoamos": "apregoar",
    "apregoando": "apregoar",
    "apregoara": "apregoar",
    "apregoaram": "apregoar",
    "apregoaras": "apregoar",
    "apregoarde": "apregoar",
    "apregoardes": "apregoar",
    "apregoare": "apregoar",
    "apregoarei": "apregoar",
    "apregoareis": "apregoar",
    "apregoarem": "apregoar",
    "apregoaremos": "apregoar",
    "apregoares": "apregoar",
    "apregoaria": "apregoar",
    "apregoariam": "apregoar",
    "apregoarias": "apregoar",
    "apregoarmo": "apregoar",
    "apregoarmos": "apregoar",
    "apregoará": "apregoar",
    "apregoarás": "apregoar",
    "apregoarão": "apregoar",
    "apregoaríamos": "apregoar",
    "apregoaríeis": "apregoar",
    "apregoas": "apregoar",
    "apregoasse": "apregoar",
    "apregoassem": "apregoar",
    "apregoasses": "apregoar",
    "apregoaste": "apregoar",
    "apregoastes": "apregoar",
    "apregoava": "apregoar",
    "apregoavam": "apregoar",
    "apregoavas": "apregoar",
    "apregoe": "apregoar",
    "apregoei": "apregoar",
    "apregoeis": "apregoar",
    "apregoem": "apregoar",
    "apregoemo": "apregoar",
    "apregoemos": "apregoar",
    "apregoes": "apregoar",
    "apregoo": "apregoar",
    "apregoou": "apregoar",
    "apregoá": "apregoar",
    "apregoámo": "apregoar",
    "apregoámos": "apregoar",
    "apregoáramo": "apregoar",
    "apregoáramos": "apregoar",
    "apregoárei": "apregoar",
    "apregoáreis": "apregoar",
    "apregoásseis": "apregoar",
    "apregoássemos": "apregoar",
    "apregoávamo": "apregoar",
    "apregoávamos": "apregoar",
    "apregoávei": "apregoar",
    "apregoáveis": "apregoável",
    "apremedeiras": "apremedeira",
    "aprenda": "aprender",
    "aprendais": "aprender",
    "aprendam": "aprender",
    "aprendamo": "aprender",
    "aprendamos": "aprender",
    "aprendas": "aprender",
    "aprende": "aprender",
    "aprendei": "aprender",
    "aprendeis": "aprender",
    "aprendem": "aprender",
    "aprendemo": "aprender",
    "aprendemos": "aprender",
    "aprendendo": "aprender",
    "aprendera": "aprender",
    "aprenderam": "aprender",
    "aprenderas": "aprender",
    "aprenderde": "aprender",
    "aprenderdes": "aprender",
    "aprendere": "aprender",
    "aprenderei": "aprender",
    "aprendereis": "aprender",
    "aprenderem": "aprender",
    "aprenderemos": "aprender",
    "aprenderes": "aprender",
    "aprenderia": "aprender",
    "aprenderiam": "aprender",
    "aprenderias": "aprender",
    "aprendermo": "aprender",
    "aprendermos": "aprender",
    "aprenderá": "aprender",
    "aprenderás": "aprender",
    "aprenderão": "aprender",
    "aprenderíamos": "aprender",
    "aprenderíeis": "aprender",
    "aprendes": "aprender",
    "aprendesse": "aprender",
    "aprendessem": "aprender",
    "aprendesses": "aprender",
    "aprendeste": "aprender",
    "aprendestes": "aprender",
    "aprendeu": "aprender",
    "aprendi": "aprender",
    "aprendia": "aprender",
    "aprendiam": "aprender",
    "aprendias": "aprender",
    "aprendida": "aprendido",
    "aprendidas": "aprendido",
    "aprendido": "aprender",
    "aprendidos": "aprendido",
    "aprendiza": "aprendiz",
    "aprendizados": "aprendizado",
    "aprendizagens": "aprendizagem",
    "aprendizas": "aprendiz",
    "aprendizes": "aprendiz",
    "aprendo": "aprender",
    "aprendê": "aprender",
    "aprendêramo": "aprender",
    "aprendêramos": "aprender",
    "aprendêrei": "aprender",
    "aprendêreis": "aprender",
    "aprendêsseis": "aprender",
    "aprendêssemos": "aprender",
    "aprendíamo": "aprender",
    "aprendíamos": "aprender",
    "aprendíei": "aprender",
    "aprendíeis": "aprender",
    "aprendíveis": "aprendível",
    "apresada": "apresado",
    "apresadas": "apresado",
    "apresadora": "apresador",
    "apresadoras": "apresador",
    "apresadores": "apresador",
    "apresados": "apresado",
    "apresamentos": "apresamento",
    "apresenta": "apresentar",
    "apresentada": "apresentar",
    "apresentadas": "apresentar",
    "apresentado": "apresentar",
    "apresentadora": "apresentador",
    "apresentadoras": "apresentador",
    "apresentadores": "apresentador",
    "apresentados": "apresentar",
    "apresentai": "apresentar",
    "apresentais": "apresentar",
    "apresentam": "apresentar",
    "apresentamo": "apresentar",
    "apresentamos": "apresentar",
    "apresentando": "apresentar",
    "apresentantes": "apresentante",
    "apresentara": "apresentar",
    "apresentaram": "apresentar",
    "apresentaras": "apresentar",
    "apresentarde": "apresentar",
    "apresentardes": "apresentar",
    "apresentare": "apresentar",
    "apresentarei": "apresentar",
    "apresentareis": "apresentar",
    "apresentarem": "apresentar",
    "apresentaremos": "apresentar",
    "apresentares": "apresentar",
    "apresentaria": "apresentar",
    "apresentariam": "apresentar",
    "apresentarias": "apresentar",
    "apresentarmo": "apresentar",
    "apresentarmos": "apresentar",
    "apresentará": "apresentar",
    "apresentarás": "apresentar",
    "apresentarão": "apresentar",
    "apresentaríamos": "apresentar",
    "apresentaríeis": "apresentar",
    "apresentas": "apresentar",
    "apresentasse": "apresentar",
    "apresentassem": "apresentar",
    "apresentasses": "apresentar",
    "apresentaste": "apresentar",
    "apresentastes": "apresentar",
    "apresentava": "apresentar",
    "apresentavam": "apresentar",
    "apresentavas": "apresentar",
    "apresentações": "apresentação",
    "apresente": "apresentar",
    "apresentei": "apresentar",
    "apresenteis": "apresentar",
    "apresentem": "apresentar",
    "apresentemo": "apresentar",
    "apresentemos": "apresentar",
    "apresentes": "apresentar",
    "apresento": "apresentar",
    "apresentou": "apresentar",
    "apresentá": "apresentar",
    "apresentámo": "apresentar",
    "apresentámos": "apresentar",
    "apresentáramo": "apresentar",
    "apresentáramos": "apresentar",
    "apresentárei": "apresentar",
    "apresentáreis": "apresentar",
    "apresentásseis": "apresentar",
    "apresentássemos": "apresentar",
    "apresentávamo": "apresentar",
    "apresentávamos": "apresentar",
    "apresentávei": "apresentar",
    "apresentáveis": "apresentável",
    "apresigos": "apresigo",
    "apressa": "apressar",
    "apressada": "apressar",
    "apressadas": "apressar",
    "apressado": "apressar",
    "apressadora": "apressador",
    "apressadoras": "apressador",
    "apressadores": "apressador",
    "apressados": "apressar",
    "apressadíssima": "apressado",
    "apressadíssimas": "apressado",
    "apressadíssimo": "apressado",
    "apressadíssimos": "apressado",
    "apressai": "apressar",
    "apressais": "apressar",
    "apressam": "apressar",
    "apressamo": "apressar",
    "apressamos": "apressar",
    "apressando": "apressar",
    "apressara": "apressar",
    "apressaram": "apressar",
    "apressaras": "apressar",
    "apressarde": "apressar",
    "apressardes": "apressar",
    "apressare": "apressar",
    "apressarei": "apressar",
    "apressareis": "apressar",
    "apressarem": "apressar",
    "apressaremos": "apressar",
    "apressares": "apressar",
    "apressaria": "apressar",
    "apressariam": "apressar",
    "apressarias": "apressar",
    "apressarmo": "apressar",
    "apressarmos": "apressar",
    "apressará": "apressar",
    "apressarás": "apressar",
    "apressarão": "apressar",
    "apressaríamos": "apressar",
    "apressaríeis": "apressar",
    "apressas": "apressar",
    "apressasse": "apressar",
    "apressassem": "apressar",
    "apressasses": "apressar",
    "apressaste": "apressar",
    "apressastes": "apressar",
    "apressava": "apressar",
    "apressavam": "apressar",
    "apressavas": "apressar",
    "apresse": "apressar",
    "apressei": "apressar",
    "apresseis": "apressar",
    "apressem": "apressar",
    "apressemo": "apressar",
    "apressemos": "apressar",
    "apresses": "apressar",
    "apresso": "apressar",
    "apressou": "apressar",
    "apressura": "apressurar",
    "apressurada": "apressurar",
    "apressuradas": "apressurar",
    "apressurado": "apressurar",
    "apressurados": "apressurar",
    "apressurai": "apressurar",
    "apressurais": "apressurar",
    "apressuram": "apressurar",
    "apressuramentos": "apressuramento",
    "apressuramo": "apressurar",
    "apressuramos": "apressurar",
    "apressurando": "apressurar",
    "apressurara": "apressurar",
    "apressuraram": "apressurar",
    "apressuraras": "apressurar",
    "apressurarde": "apressurar",
    "apressurardes": "apressurar",
    "apressurare": "apressurar",
    "apressurarei": "apressurar",
    "apressurareis": "apressurar",
    "apressurarem": "apressurar",
    "apressuraremos": "apressurar",
    "apressurares": "apressurar",
    "apressuraria": "apressurar",
    "apressurariam": "apressurar",
    "apressurarias": "apressurar",
    "apressurarmo": "apressurar",
    "apressurarmos": "apressurar",
    "apressurará": "apressurar",
    "apressurarás": "apressurar",
    "apressurarão": "apressurar",
    "apressuraríamos": "apressurar",
    "apressuraríeis": "apressurar",
    "apressuras": "apressurar",
    "apressurasse": "apressurar",
    "apressurassem": "apressurar",
    "apressurasses": "apressurar",
    "apressuraste": "apressurar",
    "apressurastes": "apressurar",
    "apressurava": "apressurar",
    "apressuravam": "apressurar",
    "apressuravas": "apressurar",
    "apressure": "apressurar",
    "apressurei": "apressurar",
    "apressureis": "apressurar",
    "apressurem": "apressurar",
    "apressuremo": "apressurar",
    "apressuremos": "apressurar",
    "apressures": "apressurar",
    "apressuro": "apressurar",
    "apressurou": "apressurar",
    "apressurá": "apressurar",
    "apressurámo": "apressurar",
    "apressurámos": "apressurar",
    "apressuráramo": "apressurar",
    "apressuráramos": "apressurar",
    "apressurárei": "apressurar",
    "apressuráreis": "apressurar",
    "apressurásseis": "apressurar",
    "apressurássemos": "apressurar",
    "apressurávamo": "apressurar",
    "apressurávamos": "apressurar",
    "apressurávei": "apressurar",
    "apressuráveis": "apressurar",
    "apressá": "apressar",
    "apressámo": "apressar",
    "apressámos": "apressar",
    "apressáramo": "apressar",
    "apressáramos": "apressar",
    "apressárei": "apressar",
    "apressáreis": "apressar",
    "apressásseis": "apressar",
    "apressássemos": "apressar",
    "apressávamo": "apressar",
    "apressávamos": "apressar",
    "apressávei": "apressar",
    "apressáveis": "apressar",
    "apresta": "aprestar",
    "aprestada": "aprestar",
    "aprestadas": "aprestar",
    "aprestado": "aprestar",
    "aprestadora": "aprestador",
    "aprestadoras": "aprestador",
    "aprestadores": "aprestador",
    "aprestados": "aprestar",
    "aprestai": "aprestar",
    "aprestais": "aprestar",
    "aprestam": "aprestar",
    "aprestamentos": "aprestamento",
    "aprestamo": "aprestar",
    "aprestamos": "aprestar",
    "aprestando": "aprestar",
    "aprestara": "aprestar",
    "aprestaram": "aprestar",
    "aprestaras": "aprestar",
    "aprestarde": "aprestar",
    "aprestardes": "aprestar",
    "aprestare": "aprestar",
    "aprestarei": "aprestar",
    "aprestareis": "aprestar",
    "aprestarem": "aprestar",
    "aprestaremos": "aprestar",
    "aprestares": "aprestar",
    "aprestaria": "aprestar",
    "aprestariam": "aprestar",
    "aprestarias": "aprestar",
    "aprestarmo": "aprestar",
    "aprestarmos": "aprestar",
    "aprestará": "aprestar",
    "aprestarás": "aprestar",
    "aprestarão": "aprestar",
    "aprestaríamos": "aprestar",
    "aprestaríeis": "aprestar",
    "aprestas": "aprestar",
    "aprestasse": "aprestar",
    "aprestassem": "aprestar",
    "aprestasses": "aprestar",
    "aprestaste": "aprestar",
    "aprestastes": "aprestar",
    "aprestava": "aprestar",
    "aprestavam": "aprestar",
    "aprestavas": "aprestar",
    "aprestações": "aprestação",
    "apreste": "aprestar",
    "aprestei": "aprestar",
    "apresteis": "aprestar",
    "aprestem": "aprestar",
    "aprestemo": "aprestar",
    "aprestemos": "aprestar",
    "aprestes": "apreste",
    "apresto": "aprestar",
    "aprestos": "apresto",
    "aprestou": "aprestar",
    "aprestá": "aprestar",
    "aprestámo": "aprestar",
    "aprestámos": "aprestar",
    "aprestáramo": "aprestar",
    "aprestáramos": "aprestar",
    "aprestárei": "aprestar",
    "aprestáreis": "aprestar",
    "aprestásseis": "aprestar",
    "aprestássemos": "aprestar",
    "aprestávamo": "aprestar",
    "aprestávamos": "aprestar",
    "aprestávei": "aprestar",
    "aprestáveis": "aprestar",
    "apresuntada": "apresuntado",
    "apresuntadas": "apresuntado",
    "apresuntados": "apresuntado",
    "apreça": "apreçar",
    "apreçada": "apreçar",
    "apreçadas": "apreçar",
    "apreçado": "apreçar",
    "apreçadora": "apreçador",
    "apreçadoras": "apreçador",
    "apreçadores": "apreçador",
    "apreçados": "apreçar",
    "apreçai": "apreçar",
    "apreçais": "apreçar",
    "apreçam": "apreçar",
    "apreçamentos": "apreçamento",
    "apreçamo": "apreçar",
    "apreçamos": "apreçar",
    "apreçando": "apreçar",
    "apreçara": "apreçar",
    "apreçaram": "apreçar",
    "apreçaras": "apreçar",
    "apreçarde": "apreçar",
    "apreçardes": "apreçar",
    "apreçare": "apreçar",
    "apreçarei": "apreçar",
    "apreçareis": "apreçar",
    "apreçarem": "apreçar",
    "apreçaremos": "apreçar",
    "apreçares": "apreçar",
    "apreçaria": "apreçar",
    "apreçariam": "apreçar",
    "apreçarias": "apreçar",
    "apreçarmo": "apreçar",
    "apreçarmos": "apreçar",
    "apreçará": "apreçar",
    "apreçarás": "apreçar",
    "apreçarão": "apreçar",
    "apreçaríamos": "apreçar",
    "apreçaríeis": "apreçar",
    "apreças": "apreçar",
    "apreçasse": "apreçar",
    "apreçassem": "apreçar",
    "apreçasses": "apreçar",
    "apreçaste": "apreçar",
    "apreçastes": "apreçar",
    "apreçava": "apreçar",
    "apreçavam": "apreçar",
    "apreçavas": "apreçar",
    "apreço": "apreçar",
    "apreços": "apreço",
    "apreçou": "apreçar",
    "apreçá": "apreçar",
    "apreçámo": "apreçar",
    "apreçámos": "apreçar",
    "apreçáramo": "apreçar",
    "apreçáramos": "apreçar",
    "apreçárei": "apreçar",
    "apreçáreis": "apreçar",
    "apreçásseis": "apreçar",
    "apreçássemos": "apreçar",
    "apreçávamo": "apreçar",
    "apreçávamos": "apreçar",
    "apreçávei": "apreçar",
    "apreçáveis": "apreçar",
    "aprilina": "aprilino",
    "aprilinas": "aprilino",
    "aprilinos": "aprilino",
    "aprimora": "aprimorar",
    "aprimorada": "aprimorar",
    "aprimoradas": "aprimorar",
    "aprimorado": "aprimorar",
    "aprimorados": "aprimorar",
    "aprimorai": "aprimorar",
    "aprimorais": "aprimorar",
    "aprimoram": "aprimorar",
    "aprimoramentos": "aprimoramento",
    "aprimoramo": "aprimorar",
    "aprimoramos": "aprimorar",
    "aprimorando": "aprimorar",
    "aprimorara": "aprimorar",
    "aprimoraram": "aprimorar",
    "aprimoraras": "aprimorar",
    "aprimorarde": "aprimorar",
    "aprimorardes": "aprimorar",
    "aprimorare": "aprimorar",
    "aprimorarei": "aprimorar",
    "aprimorareis": "aprimorar",
    "aprimorarem": "aprimorar",
    "aprimoraremos": "aprimorar",
    "aprimorares": "aprimorar",
    "aprimoraria": "aprimorar",
    "aprimorariam": "aprimorar",
    "aprimorarias": "aprimorar",
    "aprimorarmo": "aprimorar",
    "aprimorarmos": "aprimorar",
    "aprimorará": "aprimorar",
    "aprimorarás": "aprimorar",
    "aprimorarão": "aprimorar",
    "aprimoraríamos": "aprimorar",
    "aprimoraríeis": "aprimorar",
    "aprimoras": "aprimorar",
    "aprimorasse": "aprimorar",
    "aprimorassem": "aprimorar",
    "aprimorasses": "aprimorar",
    "aprimoraste": "aprimorar",
    "aprimorastes": "aprimorar",
    "aprimorava": "aprimorar",
    "aprimoravam": "aprimorar",
    "aprimoravas": "aprimorar",
    "aprimorações": "aprimoração",
    "aprimore": "aprimorar",
    "aprimorei": "aprimorar",
    "aprimoreis": "aprimorar",
    "aprimorem": "aprimorar",
    "aprimoremo": "aprimorar",
    "aprimoremos": "aprimorar",
    "aprimores": "aprimorar",
    "aprimoro": "aprimorar",
    "aprimorou": "aprimorar",
    "aprimorá": "aprimorar",
    "aprimorámo": "aprimorar",
    "aprimorámos": "aprimorar",
    "aprimoráramo": "aprimorar",
    "aprimoráramos": "aprimorar",
    "aprimorárei": "aprimorar",
    "aprimoráreis": "aprimorar",
    "aprimorásseis": "aprimorar",
    "aprimorássemos": "aprimorar",
    "aprimorávamo": "aprimorar",
    "aprimorávamos": "aprimorar",
    "aprimorávei": "aprimorar",
    "aprimoráveis": "aprimorar",
    "aprincesa": "aprincesar",
    "aprincesada": "aprincesar",
    "aprincesadas": "aprincesar",
    "aprincesado": "aprincesar",
    "aprincesados": "aprincesar",
    "aprincesai": "aprincesar",
    "aprincesais": "aprincesar",
    "aprincesam": "aprincesar",
    "aprincesamo": "aprincesar",
    "aprincesamos": "aprincesar",
    "aprincesando": "aprincesar",
    "aprincesara": "aprincesar",
    "aprincesaram": "aprincesar",
    "aprincesaras": "aprincesar",
    "aprincesarde": "aprincesar",
    "aprincesardes": "aprincesar",
    "aprincesare": "aprincesar",
    "aprincesarei": "aprincesar",
    "aprincesareis": "aprincesar",
    "aprincesarem": "aprincesar",
    "aprincesaremos": "aprincesar",
    "aprincesares": "aprincesar",
    "aprincesaria": "aprincesar",
    "aprincesariam": "aprincesar",
    "aprincesarias": "aprincesar",
    "aprincesarmo": "aprincesar",
    "aprincesarmos": "aprincesar",
    "aprincesará": "aprincesar",
    "aprincesarás": "aprincesar",
    "aprincesarão": "aprincesar",
    "aprincesaríamos": "aprincesar",
    "aprincesaríeis": "aprincesar",
    "aprincesas": "aprincesar",
    "aprincesasse": "aprincesar",
    "aprincesassem": "aprincesar",
    "aprincesasses": "aprincesar",
    "aprincesaste": "aprincesar",
    "aprincesastes": "aprincesar",
    "aprincesava": "aprincesar",
    "aprincesavam": "aprincesar",
    "aprincesavas": "aprincesar",
    "aprincese": "aprincesar",
    "aprincesei": "aprincesar",
    "aprinceseis": "aprincesar",
    "aprincesem": "aprincesar",
    "aprincesemo": "aprincesar",
    "aprincesemos": "aprincesar",
    "aprinceses": "aprincesar",
    "aprinceso": "aprincesar",
    "aprincesou": "aprincesar",
    "aprincesá": "aprincesar",
    "aprincesámo": "aprincesar",
    "aprincesámos": "aprincesar",
    "aprincesáramo": "aprincesar",
    "aprincesáramos": "aprincesar",
    "aprincesárei": "aprincesar",
    "aprincesáreis": "aprincesar",
    "aprincesásseis": "aprincesar",
    "aprincesássemos": "aprincesar",
    "aprincesávamo": "aprincesar",
    "aprincesávamos": "aprincesar",
    "aprincesávei": "aprincesar",
    "aprincesáveis": "aprincesar",
    "aprioridades": "aprioridade",
    "apriorismos": "apriorismo",
    "aprioristas": "apriorista",
    "apriorística": "apriorístico",
    "apriorísticas": "apriorístico",
    "apriorísticos": "apriorístico",
    "apriscos": "aprisco",
    "aprisiona": "aprisionar",
    "aprisionada": "aprisionar",
    "aprisionadas": "aprisionar",
    "aprisionado": "aprisionar",
    "aprisionados": "aprisionar",
    "aprisionai": "aprisionar",
    "aprisionais": "aprisionar",
    "aprisionam": "aprisionar",
    "aprisionamentos": "aprisionamento",
    "aprisionamo": "aprisionar",
    "aprisionamos": "aprisionar",
    "aprisionando": "aprisionar",
    "aprisionara": "aprisionar",
    "aprisionaram": "aprisionar",
    "aprisionaras": "aprisionar",
    "aprisionarde": "aprisionar",
    "aprisionardes": "aprisionar",
    "aprisionare": "aprisionar",
    "aprisionarei": "aprisionar",
    "aprisionareis": "aprisionar",
    "aprisionarem": "aprisionar",
    "aprisionaremos": "aprisionar",
    "aprisionares": "aprisionar",
    "aprisionaria": "aprisionar",
    "aprisionariam": "aprisionar",
    "aprisionarias": "aprisionar",
    "aprisionarmo": "aprisionar",
    "aprisionarmos": "aprisionar",
    "aprisionará": "aprisionar",
    "aprisionarás": "aprisionar",
    "aprisionarão": "aprisionar",
    "aprisionaríamos": "aprisionar",
    "aprisionaríeis": "aprisionar",
    "aprisionas": "aprisionar",
    "aprisionasse": "aprisionar",
    "aprisionassem": "aprisionar",
    "aprisionasses": "aprisionar",
    "aprisionaste": "aprisionar",
    "aprisionastes": "aprisionar",
    "aprisionava": "aprisionar",
    "aprisionavam": "aprisionar",
    "aprisionavas": "aprisionar",
    "aprisione": "aprisionar",
    "aprisionei": "aprisionar",
    "aprisioneis": "aprisionar",
    "aprisionem": "aprisionar",
    "aprisionemo": "aprisionar",
    "aprisionemos": "aprisionar",
    "aprisiones": "aprisionar",
    "aprisiono": "aprisionar",
    "aprisionou": "aprisionar",
    "aprisioná": "aprisionar",
    "aprisionámo": "aprisionar",
    "aprisionámos": "aprisionar",
    "aprisionáramo": "aprisionar",
    "aprisionáramos": "aprisionar",
    "aprisionárei": "aprisionar",
    "aprisionáreis": "aprisionar",
    "aprisionásseis": "aprisionar",
    "aprisionássemos": "aprisionar",
    "aprisionávamo": "aprisionar",
    "aprisionávamos": "aprisionar",
    "aprisionávei": "aprisionar",
    "aprisionáveis": "aprisionar",
    "aproamentos": "aproamento",
    "aprobativa": "aprobativo",
    "aprobativas": "aprobativo",
    "aprobativos": "aprobativo",
    "aprobatória": "aprobatório",
    "aprobatórias": "aprobatório",
    "aprobatórios": "aprobatório",
    "aprocta": "aprocto",
    "aproctas": "aprocto",
    "aproctias": "aproctia",
    "aproctos": "aprocto",
    "aprofunda": "aprofundar",
    "aprofundada": "aprofundar",
    "aprofundadas": "aprofundar",
    "aprofundado": "aprofundar",
    "aprofundados": "aprofundar",
    "aprofundai": "aprofundar",
    "aprofundais": "aprofundar",
    "aprofundam": "aprofundar",
    "aprofundamentos": "aprofundamento",
    "aprofundamo": "aprofundar",
    "aprofundamos": "aprofundar",
    "aprofundando": "aprofundar",
    "aprofundara": "aprofundar",
    "aprofundaram": "aprofundar",
    "aprofundaras": "aprofundar",
    "aprofundarde": "aprofundar",
    "aprofundardes": "aprofundar",
    "aprofundare": "aprofundar",
    "aprofundarei": "aprofundar",
    "aprofundareis": "aprofundar",
    "aprofundarem": "aprofundar",
    "aprofundaremos": "aprofundar",
    "aprofundares": "aprofundar",
    "aprofundaria": "aprofundar",
    "aprofundariam": "aprofundar",
    "aprofundarias": "aprofundar",
    "aprofundarmo": "aprofundar",
    "aprofundarmos": "aprofundar",
    "aprofundará": "aprofundar",
    "aprofundarás": "aprofundar",
    "aprofundarão": "aprofundar",
    "aprofundaríamos": "aprofundar",
    "aprofundaríeis": "aprofundar",
    "aprofundas": "aprofundar",
    "aprofundasse": "aprofundar",
    "aprofundassem": "aprofundar",
    "aprofundasses": "aprofundar",
    "aprofundaste": "aprofundar",
    "aprofundastes": "aprofundar",
    "aprofundava": "aprofundar",
    "aprofundavam": "aprofundar",
    "aprofundavas": "aprofundar",
    "aprofundações": "aprofundação",
    "aprofunde": "aprofundar",
    "aprofundei": "aprofundar",
    "aprofundeis": "aprofundar",
    "aprofundem": "aprofundar",
    "aprofundemo": "aprofundar",
    "aprofundemos": "aprofundar",
    "aprofundes": "aprofundar",
    "aprofundo": "aprofundar",
    "aprofundou": "aprofundar",
    "aprofundá": "aprofundar",
    "aprofundámo": "aprofundar",
    "aprofundámos": "aprofundar",
    "aprofundáramo": "aprofundar",
    "aprofundáramos": "aprofundar",
    "aprofundárei": "aprofundar",
    "aprofundáreis": "aprofundar",
    "aprofundásseis": "aprofundar",
    "aprofundássemos": "aprofundar",
    "aprofundávamo": "aprofundar",
    "aprofundávamos": "aprofundar",
    "aprofundávei": "aprofundar",
    "aprofundáveis": "aprofundável",
    "apronta": "aprontar",
    "aprontada": "aprontar",
    "aprontadas": "aprontar",
    "aprontado": "aprontar",
    "aprontados": "aprontar",
    "aprontai": "aprontar",
    "aprontais": "aprontar",
    "aprontam": "aprontar",
    "aprontamentos": "aprontamento",
    "aprontamo": "aprontar",
    "aprontamos": "aprontar",
    "aprontando": "aprontar",
    "aprontara": "aprontar",
    "aprontaram": "aprontar",
    "aprontaras": "aprontar",
    "aprontarde": "aprontar",
    "aprontardes": "aprontar",
    "aprontare": "aprontar",
    "aprontarei": "aprontar",
    "aprontareis": "aprontar",
    "aprontarem": "aprontar",
    "aprontaremos": "aprontar",
    "aprontares": "aprontar",
    "aprontaria": "aprontar",
    "aprontariam": "aprontar",
    "aprontarias": "aprontar",
    "aprontarmo": "aprontar",
    "aprontarmos": "aprontar",
    "aprontará": "aprontar",
    "aprontarás": "aprontar",
    "aprontarão": "aprontar",
    "aprontaríamos": "aprontar",
    "aprontaríeis": "aprontar",
    "aprontas": "aprontar",
    "aprontasse": "aprontar",
    "aprontassem": "aprontar",
    "aprontasses": "aprontar",
    "aprontaste": "aprontar",
    "aprontastes": "aprontar",
    "aprontava": "aprontar",
    "aprontavam": "aprontar",
    "aprontavas": "aprontar",
    "aprontações": "aprontação",
    "apronte": "aprontar",
    "aprontei": "aprontar",
    "apronteis": "aprontar",
    "aprontem": "aprontar",
    "aprontemo": "aprontar",
    "aprontemos": "aprontar",
    "aprontes": "apronte",
    "apronto": "aprontar",
    "aprontou": "aprontar",
    "aprontá": "aprontar",
    "aprontámo": "aprontar",
    "aprontámos": "aprontar",
    "aprontáramo": "aprontar",
    "aprontáramos": "aprontar",
    "aprontárei": "aprontar",
    "aprontáreis": "aprontar",
    "aprontásseis": "aprontar",
    "aprontássemos": "aprontar",
    "aprontávamo": "aprontar",
    "aprontávamos": "aprontar",
    "aprontávei": "aprontar",
    "aprontáveis": "aprontar",
    "apropinqua": "apropinquar",
    "apropinquada": "apropinquar",
    "apropinquadas": "apropinquar",
    "apropinquado": "apropinquar",
    "apropinquados": "apropinquar",
    "apropinquai": "apropinquar",
    "apropinquais": "apropinquar",
    "apropinquam": "apropinquar",
    "apropinquamo": "apropinquar",
    "apropinquamos": "apropinquar",
    "apropinquando": "apropinquar",
    "apropinquara": "apropinquar",
    "apropinquaram": "apropinquar",
    "apropinquaras": "apropinquar",
    "apropinquarde": "apropinquar",
    "apropinquardes": "apropinquar",
    "apropinquare": "apropinquar",
    "apropinquarei": "apropinquar",
    "apropinquareis": "apropinquar",
    "apropinquarem": "apropinquar",
    "apropinquaremos": "apropinquar",
    "apropinquares": "apropinquar",
    "apropinquaria": "apropinquar",
    "apropinquariam": "apropinquar",
    "apropinquarias": "apropinquar",
    "apropinquarmo": "apropinquar",
    "apropinquarmos": "apropinquar",
    "apropinquará": "apropinquar",
    "apropinquarás": "apropinquar",
    "apropinquarão": "apropinquar",
    "apropinquaríamos": "apropinquar",
    "apropinquaríeis": "apropinquar",
    "apropinquas": "apropinquar",
    "apropinquasse": "apropinquar",
    "apropinquassem": "apropinquar",
    "apropinquasses": "apropinquar",
    "apropinquaste": "apropinquar",
    "apropinquastes": "apropinquar",
    "apropinquava": "apropinquar",
    "apropinquavam": "apropinquar",
    "apropinquavas": "apropinquar",
    "apropinquações": "apropinquação",
    "apropinquei": "apropinquar",
    "apropinqueis": "apropinquar",
    "apropinquemo": "apropinquar",
    "apropinquemos": "apropinquar",
    "apropinques": "apropinquar",
    "apropinquo": "apropinquar",
    "apropinquou": "apropinquar",
    "apropinquá": "apropinquar",
    "apropinquámo": "apropinquar",
    "apropinquámos": "apropinquar",
    "apropinquáramo": "apropinquar",
    "apropinquáramos": "apropinquar",
    "apropinquárei": "apropinquar",
    "apropinquáreis": "apropinquar",
    "apropinquásseis": "apropinquar",
    "apropinquássemos": "apropinquar",
    "apropinquávamo": "apropinquar",
    "apropinquávamos": "apropinquar",
    "apropinquávei": "apropinquar",
    "apropinquáveis": "apropinquar",
    "apropinqúe": "apropinquar",
    "apropinqúem": "apropinquar",
    "apropinqúes": "apropinquar",
    "apropria": "apropriar",
    "apropriada": "apropriar",
    "apropriadas": "apropriar",
    "apropriado": "apropriar",
    "apropriadora": "apropriador",
    "apropriadoras": "apropriador",
    "apropriadores": "apropriador",
    "apropriados": "apropriar",
    "apropriadíssima": "apropriado",
    "apropriadíssimas": "apropriado",
    "apropriadíssimo": "apropriado",
    "apropriadíssimos": "apropriado",
    "apropriagens": "apropriagem",
    "apropriai": "apropriar",
    "apropriais": "apropriar",
    "apropriam": "apropriar",
    "apropriamo": "apropriar",
    "apropriamos": "apropriar",
    "apropriando": "apropriar",
    "apropriara": "apropriar",
    "apropriaram": "apropriar",
    "apropriaras": "apropriar",
    "apropriarde": "apropriar",
    "apropriardes": "apropriar",
    "apropriare": "apropriar",
    "apropriarei": "apropriar",
    "apropriareis": "apropriar",
    "apropriarem": "apropriar",
    "apropriaremos": "apropriar",
    "apropriares": "apropriar",
    "apropriaria": "apropriar",
    "apropriariam": "apropriar",
    "apropriarias": "apropriar",
    "apropriarmo": "apropriar",
    "apropriarmos": "apropriar",
    "apropriará": "apropriar",
    "apropriarás": "apropriar",
    "apropriarão": "apropriar",
    "apropriaríamos": "apropriar",
    "apropriaríeis": "apropriar",
    "aproprias": "apropriar",
    "apropriasse": "apropriar",
    "apropriassem": "apropriar",
    "apropriasses": "apropriar",
    "apropriaste": "apropriar",
    "apropriastes": "apropriar",
    "apropriava": "apropriar",
    "apropriavam": "apropriar",
    "apropriavas": "apropriar",
    "apropriações": "apropriação",
    "aproprie": "apropriar",
    "apropriei": "apropriar",
    "aproprieis": "apropriar",
    "apropriem": "apropriar",
    "apropriemo": "apropriar",
    "apropriemos": "apropriar",
    "apropries": "apropriar",
    "aproprio": "apropriar",
    "apropriou": "apropriar",
    "apropriá": "apropriar",
    "apropriámo": "apropriar",
    "apropriámos": "apropriar",
    "apropriáramo": "apropriar",
    "apropriáramos": "apropriar",
    "apropriárei": "apropriar",
    "apropriáreis": "apropriar",
    "apropriásseis": "apropriar",
    "apropriássemos": "apropriar",
    "apropriávamo": "apropriar",
    "apropriávamos": "apropriar",
    "apropriávei": "apropriar",
    "apropriáveis": "apropriar",
    "aprosada": "aprosado",
    "aprosadas": "aprosado",
    "aprosados": "aprosado",
    "aprosexias": "aprosexia",
    "aprosopa": "aprosopo",
    "aprosopas": "aprosopo",
    "aprosopias": "aprosopia",
    "aprosopos": "aprosopo",
    "aproséxica": "aproséxico",
    "aproséxicas": "aproséxico",
    "aproséxicos": "aproséxico",
    "aprouve": "aprazer",
    "aprouver": "aprazer",
    "aprouvera": "aprazer",
    "aprouveram": "aprazer",
    "aprouverem": "aprazer",
    "aprouvesse": "aprazer",
    "aprouvessem": "aprazer",
    "aprova": "aprovar",
    "aprovada": "aprovar",
    "aprovadas": "aprovar",
    "aprovado": "aprovar",
    "aprovadora": "aprovador",
    "aprovadoras": "aprovador",
    "aprovadores": "aprovador",
    "aprovados": "aprovar",
    "aprovai": "aprovar",
    "aprovais": "aprovar",
    "aprovam": "aprovar",
    "aprovamo": "aprovar",
    "aprovamos": "aprovar",
    "aprovando": "aprovar",
    "aprovara": "aprovar",
    "aprovaram": "aprovar",
    "aprovaras": "aprovar",
    "aprovarde": "aprovar",
    "aprovardes": "aprovar",
    "aprovare": "aprovar",
    "aprovarei": "aprovar",
    "aprovareis": "aprovar",
    "aprovarem": "aprovar",
    "aprovaremos": "aprovar",
    "aprovares": "aprovar",
    "aprovaria": "aprovar",
    "aprovariam": "aprovar",
    "aprovarias": "aprovar",
    "aprovarmo": "aprovar",
    "aprovarmos": "aprovar",
    "aprovará": "aprovar",
    "aprovarás": "aprovar",
    "aprovarão": "aprovar",
    "aprovaríamos": "aprovar",
    "aprovaríeis": "aprovar",
    "aprovas": "aprovar",
    "aprovasse": "aprovar",
    "aprovassem": "aprovar",
    "aprovasses": "aprovar",
    "aprovaste": "aprovar",
    "aprovastes": "aprovar",
    "aprovativa": "aprovativo",
    "aprovativas": "aprovativo",
    "aprovativos": "aprovativo",
    "aprovava": "aprovar",
    "aprovavam": "aprovar",
    "aprovavas": "aprovar",
    "aprovações": "aprovação",
    "aprove": "aprovar",
    "aprovei": "aprovar",
    "aproveis": "aprovar",
    "aproveita": "aproveitar",
    "aproveitabilidades": "aproveitabilidade",
    "aproveitada": "aproveitar",
    "aproveitadas": "aproveitar",
    "aproveitado": "aproveitar",
    "aproveitadora": "aproveitador",
    "aproveitadoras": "aproveitador",
    "aproveitadores": "aproveitador",
    "aproveitados": "aproveitar",
    "aproveitai": "aproveitar",
    "aproveitais": "aproveitar",
    "aproveitam": "aproveitar",
    "aproveitamentos": "aproveitamento",
    "aproveitamo": "aproveitar",
    "aproveitamos": "aproveitar",
    "aproveitando": "aproveitar",
    "aproveitantes": "aproveitante",
    "aproveitara": "aproveitar",
    "aproveitaram": "aproveitar",
    "aproveitaras": "aproveitar",
    "aproveitarde": "aproveitar",
    "aproveitardes": "aproveitar",
    "aproveitare": "aproveitar",
    "aproveitarei": "aproveitar",
    "aproveitareis": "aproveitar",
    "aproveitarem": "aproveitar",
    "aproveitaremos": "aproveitar",
    "aproveitares": "aproveitar",
    "aproveitaria": "aproveitar",
    "aproveitariam": "aproveitar",
    "aproveitarias": "aproveitar",
    "aproveitarmo": "aproveitar",
    "aproveitarmos": "aproveitar",
    "aproveitará": "aproveitar",
    "aproveitarás": "aproveitar",
    "aproveitarão": "aproveitar",
    "aproveitaríamos": "aproveitar",
    "aproveitaríeis": "aproveitar",
    "aproveitas": "aproveitar",
    "aproveitasse": "aproveitar",
    "aproveitassem": "aproveitar",
    "aproveitasses": "aproveitar",
    "aproveitaste": "aproveitar",
    "aproveitastes": "aproveitar",
    "aproveitava": "aproveitar",
    "aproveitavam": "aproveitar",
    "aproveitavas": "aproveitar",
    "aproveitações": "aproveitação",
    "aproveite": "aproveitar",
    "aproveitei": "aproveitar",
    "aproveiteis": "aproveitar",
    "aproveitem": "aproveitar",
    "aproveitemo": "aproveitar",
    "aproveitemos": "aproveitar",
    "aproveites": "aproveitar",
    "aproveito": "aproveitar",
    "aproveitou": "aproveitar",
    "aproveitá": "aproveitar",
    "aproveitámo": "aproveitar",
    "aproveitámos": "aproveitar",
    "aproveitáramo": "aproveitar",
    "aproveitáramos": "aproveitar",
    "aproveitárei": "aproveitar",
    "aproveitáreis": "aproveitar",
    "aproveitásseis": "aproveitar",
    "aproveitássemos": "aproveitar",
    "aproveitávamo": "aproveitar",
    "aproveitávamos": "aproveitar",
    "aproveitávei": "aproveitar",
    "aproveitáveis": "aproveitável",
    "aprovem": "aprovar",
    "aprovemo": "aprovar",
    "aprovemos": "aprovar",
    "aproves": "aprovar",
    "aprovisiona": "aprovisionar",
    "aprovisionada": "aprovisionar",
    "aprovisionadas": "aprovisionar",
    "aprovisionado": "aprovisionar",
    "aprovisionados": "aprovisionar",
    "aprovisionai": "aprovisionar",
    "aprovisionais": "aprovisionar",
    "aprovisionam": "aprovisionar",
    "aprovisionamentos": "aprovisionamento",
    "aprovisionamo": "aprovisionar",
    "aprovisionamos": "aprovisionar",
    "aprovisionando": "aprovisionar",
    "aprovisionara": "aprovisionar",
    "aprovisionaram": "aprovisionar",
    "aprovisionaras": "aprovisionar",
    "aprovisionarde": "aprovisionar",
    "aprovisionardes": "aprovisionar",
    "aprovisionare": "aprovisionar",
    "aprovisionarei": "aprovisionar",
    "aprovisionareis": "aprovisionar",
    "aprovisionarem": "aprovisionar",
    "aprovisionaremos": "aprovisionar",
    "aprovisionares": "aprovisionar",
    "aprovisionaria": "aprovisionar",
    "aprovisionariam": "aprovisionar",
    "aprovisionarias": "aprovisionar",
    "aprovisionarmo": "aprovisionar",
    "aprovisionarmos": "aprovisionar",
    "aprovisionará": "aprovisionar",
    "aprovisionarás": "aprovisionar",
    "aprovisionarão": "aprovisionar",
    "aprovisionaríamos": "aprovisionar",
    "aprovisionaríeis": "aprovisionar",
    "aprovisionas": "aprovisionar",
    "aprovisionasse": "aprovisionar",
    "aprovisionassem": "aprovisionar",
    "aprovisionasses": "aprovisionar",
    "aprovisionaste": "aprovisionar",
    "aprovisionastes": "aprovisionar",
    "aprovisionava": "aprovisionar",
    "aprovisionavam": "aprovisionar",
    "aprovisionavas": "aprovisionar",
    "aprovisione": "aprovisionar",
    "aprovisionei": "aprovisionar",
    "aprovisioneis": "aprovisionar",
    "aprovisionem": "aprovisionar",
    "aprovisionemo": "aprovisionar",
    "aprovisionemos": "aprovisionar",
    "aprovisiones": "aprovisionar",
    "aprovisiono": "aprovisionar",
    "aprovisionou": "aprovisionar",
    "aprovisioná": "aprovisionar",
    "aprovisionámo": "aprovisionar",
    "aprovisionámos": "aprovisionar",
    "aprovisionáramo": "aprovisionar",
    "aprovisionáramos": "aprovisionar",
    "aprovisionárei": "aprovisionar",
    "aprovisionáreis": "aprovisionar",
    "aprovisionásseis": "aprovisionar",
    "aprovisionássemos": "aprovisionar",
    "aprovisionávamo": "aprovisionar",
    "aprovisionávamos": "aprovisionar",
    "aprovisionávei": "aprovisionar",
    "aprovisionáveis": "aprovisionar",
    "aprovo": "aprovar",
    "aprovou": "aprovar",
    "aprová": "aprovar",
    "aprovámo": "aprovar",
    "aprovámos": "aprovar",
    "aprováramo": "aprovar",
    "aprováramos": "aprovar",
    "aprovárei": "aprovar",
    "aprováreis": "aprovar",
    "aprovásseis": "aprovar",
    "aprovássemos": "aprovar",
    "aprovávamo": "aprovar",
    "aprovávamos": "aprovar",
    "aprovávei": "aprovar",
    "aprováveis": "aprovável",
    "aproxima": "aproximar",
    "aproximada": "aproximar",
    "aproximadas": "aproximar",
    "aproximado": "aproximar",
    "aproximados": "aproximar",
    "aproximai": "aproximar",
    "aproximais": "aproximar",
    "aproximam": "aproximar",
    "aproximamo": "aproximar",
    "aproximamos": "aproximar",
    "aproximando": "aproximar",
    "aproximara": "aproximar",
    "aproximaram": "aproximar",
    "aproximaras": "aproximar",
    "aproximarde": "aproximar",
    "aproximardes": "aproximar",
    "aproximare": "aproximar",
    "aproximarei": "aproximar",
    "aproximareis": "aproximar",
    "aproximarem": "aproximar",
    "aproximaremos": "aproximar",
    "aproximares": "aproximar",
    "aproximaria": "aproximar",
    "aproximariam": "aproximar",
    "aproximarias": "aproximar",
    "aproximarmo": "aproximar",
    "aproximarmos": "aproximar",
    "aproximará": "aproximar",
    "aproximarás": "aproximar",
    "aproximarão": "aproximar",
    "aproximaríamos": "aproximar",
    "aproximaríeis": "aproximar",
    "aproximas": "aproximar",
    "aproximasse": "aproximar",
    "aproximassem": "aproximar",
    "aproximasses": "aproximar",
    "aproximaste": "aproximar",
    "aproximastes": "aproximar",
    "aproximativa": "aproximativo",
    "aproximativas": "aproximativo",
    "aproximativos": "aproximativo",
    "aproximava": "aproximar",
    "aproximavam": "aproximar",
    "aproximavas": "aproximar",
    "aproximações": "aproximação",
    "aproxime": "aproximar",
    "aproximei": "aproximar",
    "aproximeis": "aproximar",
    "aproximem": "aproximar",
    "aproximemo": "aproximar",
    "aproximemos": "aproximar",
    "aproximes": "aproximar",
    "aproximo": "aproximar",
    "aproximou": "aproximar",
    "aproximá": "aproximar",
    "aproximámo": "aproximar",
    "aproximámos": "aproximar",
    "aproximáramo": "aproximar",
    "aproximáramos": "aproximar",
    "aproximárei": "aproximar",
    "aproximáreis": "aproximar",
    "aproximásseis": "aproximar",
    "aproximássemos": "aproximar",
    "aproximávamo": "aproximar",
    "aproximávamos": "aproximar",
    "aproximávei": "aproximar",
    "aproximáveis": "aproximável",
    "apruma": "aprumar",
    "aprumada": "aprumar",
    "aprumadas": "aprumar",
    "aprumado": "aprumar",
    "aprumados": "aprumar",
    "aprumadíssima": "aprumado",
    "aprumadíssimas": "aprumado",
    "aprumadíssimo": "aprumado",
    "aprumadíssimos": "aprumado",
    "aprumai": "aprumar",
    "aprumais": "aprumar",
    "aprumam": "aprumar",
    "aprumamo": "aprumar",
    "aprumamos": "aprumar",
    "aprumando": "aprumar",
    "aprumara": "aprumar",
    "aprumaram": "aprumar",
    "aprumaras": "aprumar",
    "aprumarde": "aprumar",
    "aprumardes": "aprumar",
    "aprumare": "aprumar",
    "aprumarei": "aprumar",
    "aprumareis": "aprumar",
    "aprumarem": "aprumar",
    "aprumaremos": "aprumar",
    "aprumares": "aprumar",
    "aprumaria": "aprumar",
    "aprumariam": "aprumar",
    "aprumarias": "aprumar",
    "aprumarmo": "aprumar",
    "aprumarmos": "aprumar",
    "aprumará": "aprumar",
    "aprumarás": "aprumar",
    "aprumarão": "aprumar",
    "aprumaríamos": "aprumar",
    "aprumaríeis": "aprumar",
    "aprumas": "aprumar",
    "aprumasse": "aprumar",
    "aprumassem": "aprumar",
    "aprumasses": "aprumar",
    "aprumaste": "aprumar",
    "aprumastes": "aprumar",
    "aprumava": "aprumar",
    "aprumavam": "aprumar",
    "aprumavas": "aprumar",
    "aprumações": "aprumação",
    "aprume": "aprumar",
    "aprumei": "aprumar",
    "aprumeis": "aprumar",
    "aprumem": "aprumar",
    "aprumemo": "aprumar",
    "aprumemos": "aprumar",
    "aprumes": "aprumar",
    "aprumo": "aprumar",
    "aprumos": "aprumo",
    "aprumou": "aprumar",
    "aprumá": "aprumar",
    "aprumámo": "aprumar",
    "aprumámos": "aprumar",
    "aprumáramo": "aprumar",
    "aprumáramos": "aprumar",
    "aprumárei": "aprumar",
    "aprumáreis": "aprumar",
    "aprumásseis": "aprumar",
    "aprumássemos": "aprumar",
    "aprumávamo": "aprumar",
    "aprumávamos": "aprumar",
    "aprumávei": "aprumar",
    "aprumáveis": "aprumar",
    "apréstamos": "apréstamo",
    "apsarás": "apsará",
    "apsendos": "apsendo",
    "apsides": "apside",
    "apsiquias": "apsiquia",
    "apsiquismos": "apsiquismo",
    "apsitirias": "apsitiria",
    "apta": "apto",
    "aptada": "aptar",
    "aptadas": "aptar",
    "aptado": "aptar",
    "aptados": "aptar",
    "aptai": "aptar",
    "aptais": "aptar",
    "aptam": "aptar",
    "aptamo": "aptar",
    "aptamos": "aptar",
    "aptando": "aptar",
    "aptara": "aptar",
    "aptaram": "aptar",
    "aptaras": "aptar",
    "aptarde": "aptar",
    "aptardes": "aptar",
    "aptare": "aptar",
    "aptarei": "aptar",
    "aptareis": "aptar",
    "aptarem": "aptar",
    "aptaremos": "aptar",
    "aptares": "aptar",
    "aptaria": "aptar",
    "aptariam": "aptar",
    "aptarias": "aptar",
    "aptarmo": "aptar",
    "aptarmos": "aptar",
    "aptará": "aptar",
    "aptarás": "aptar",
    "aptarão": "aptar",
    "aptaríamos": "aptar",
    "aptaríeis": "aptar",
    "aptas": "apto",
    "aptasse": "aptar",
    "aptassem": "aptar",
    "aptasses": "aptar",
    "aptaste": "aptar",
    "aptastes": "aptar",
    "aptava": "aptar",
    "aptavam": "aptar",
    "aptavas": "aptar",
    "apte": "aptar",
    "aptei": "aptar",
    "apteiras": "apteira",
    "apteis": "aptar",
    "aptem": "aptar",
    "aptemo": "aptar",
    "aptemos": "aptar",
    "apterigiana": "apterigiano",
    "apterigianas": "apterigiano",
    "apterigianos": "apterigiano",
    "apterigogénia": "apterigogénio",
    "apterigogénias": "apterigogénio",
    "apterigogénios": "apterigogénio",
    "apterigotas": "apterigota",
    "apterogénia": "apterogénio",
    "apterogénias": "apterogénio",
    "apterogénios": "apterogénio",
    "apterologias": "apterologia",
    "apterígia": "apterígio",
    "apterígias": "apterígio",
    "apterígios": "apterígio",
    "apteróloga": "apterólogo",
    "apterólogas": "apterólogo",
    "apterólogos": "apterólogo",
    "aptes": "aptar",
    "aptialias": "aptialia",
    "aptidões": "aptidão",
    "aptifica": "aptificar",
    "aptificada": "aptificar",
    "aptificadas": "aptificar",
    "aptificado": "aptificar",
    "aptificados": "aptificar",
    "aptificai": "aptificar",
    "aptificais": "aptificar",
    "aptificam": "aptificar",
    "aptificamo": "aptificar",
    "aptificamos": "aptificar",
    "aptificando": "aptificar",
    "aptificara": "aptificar",
    "aptificaram": "aptificar",
    "aptificaras": "aptificar",
    "aptificarde": "aptificar",
    "aptificardes": "aptificar",
    "aptificare": "aptificar",
    "aptificarei": "aptificar",
    "aptificareis": "aptificar",
    "aptificarem": "aptificar",
    "aptificaremos": "aptificar",
    "aptificares": "aptificar",
    "aptificaria": "aptificar",
    "aptificariam": "aptificar",
    "aptificarias": "aptificar",
    "aptificarmo": "aptificar",
    "aptificarmos": "aptificar",
    "aptificará": "aptificar",
    "aptificarás": "aptificar",
    "aptificarão": "aptificar",
    "aptificaríamos": "aptificar",
    "aptificaríeis": "aptificar",
    "aptificas": "aptificar",
    "aptificasse": "aptificar",
    "aptificassem": "aptificar",
    "aptificasses": "aptificar",
    "aptificaste": "aptificar",
    "aptificastes": "aptificar",
    "aptificava": "aptificar",
    "aptificavam": "aptificar",
    "aptificavas": "aptificar",
    "aptifico": "aptificar",
    "aptificou": "aptificar",
    "aptificá": "aptificar",
    "aptificámo": "aptificar",
    "aptificámos": "aptificar",
    "aptificáramo": "aptificar",
    "aptificáramos": "aptificar",
    "aptificárei": "aptificar",
    "aptificáreis": "aptificar",
    "aptificásseis": "aptificar",
    "aptificássemos": "aptificar",
    "aptificávamo": "aptificar",
    "aptificávamos": "aptificar",
    "aptificávei": "aptificar",
    "aptificáveis": "aptificar",
    "aptifique": "aptificar",
    "aptifiquei": "aptificar",
    "aptifiqueis": "aptificar",
    "aptifiquem": "aptificar",
    "aptifiquemo": "aptificar",
    "aptifiquemos": "aptificar",
    "aptifiques": "aptificar",
    "aptitudes": "aptitude",
    "apto": "aptar",
    "aptos": "apto",
    "aptou": "aptar",
    "aptá": "aptar",
    "aptámo": "aptar",
    "aptámos": "aptar",
    "aptáramo": "aptar",
    "aptáramos": "aptar",
    "aptárei": "aptar",
    "aptáreis": "aptar",
    "aptás": "aptá",
    "aptásseis": "aptar",
    "aptássemos": "aptar",
    "aptávamo": "aptar",
    "aptávamos": "aptar",
    "aptávei": "aptar",
    "aptáveis": "aptar",
    "aptérios": "aptério",
    "aptíssima": "apto",
    "aptíssimas": "apto",
    "aptíssimo": "apto",
    "aptíssimos": "apto",
    "apuamentos": "apuamento",
    "apucarada": "apucarado",
    "apucaradas": "apucarado",
    "apucarados": "apucarado",
    "apudorada": "apudorado",
    "apudoradas": "apudorado",
    "apudorados": "apudorado",
    "apuliana": "apuliano",
    "apulianas": "apuliano",
    "apulianos": "apuliano",
    "apulienses": "apuliense",
    "apungas": "apunga",
    "apunha": "apor",
    "apunhala": "apunhalar",
    "apunhalada": "apunhalar",
    "apunhaladas": "apunhalar",
    "apunhalado": "apunhalar",
    "apunhalados": "apunhalar",
    "apunhalai": "apunhalar",
    "apunhalais": "apunhalar",
    "apunhalam": "apunhalar",
    "apunhalamo": "apunhalar",
    "apunhalamos": "apunhalar",
    "apunhalando": "apunhalar",
    "apunhalantes": "apunhalante",
    "apunhalara": "apunhalar",
    "apunhalaram": "apunhalar",
    "apunhalaras": "apunhalar",
    "apunhalarde": "apunhalar",
    "apunhalardes": "apunhalar",
    "apunhalare": "apunhalar",
    "apunhalarei": "apunhalar",
    "apunhalareis": "apunhalar",
    "apunhalarem": "apunhalar",
    "apunhalaremos": "apunhalar",
    "apunhalares": "apunhalar",
    "apunhalaria": "apunhalar",
    "apunhalariam": "apunhalar",
    "apunhalarias": "apunhalar",
    "apunhalarmo": "apunhalar",
    "apunhalarmos": "apunhalar",
    "apunhalará": "apunhalar",
    "apunhalarás": "apunhalar",
    "apunhalarão": "apunhalar",
    "apunhalaríamos": "apunhalar",
    "apunhalaríeis": "apunhalar",
    "apunhalas": "apunhalar",
    "apunhalasse": "apunhalar",
    "apunhalassem": "apunhalar",
    "apunhalasses": "apunhalar",
    "apunhalaste": "apunhalar",
    "apunhalastes": "apunhalar",
    "apunhalava": "apunhalar",
    "apunhalavam": "apunhalar",
    "apunhalavas": "apunhalar",
    "apunhale": "apunhalar",
    "apunhalei": "apunhalar",
    "apunhaleis": "apunhalar",
    "apunhalem": "apunhalar",
    "apunhalemo": "apunhalar",
    "apunhalemos": "apunhalar",
    "apunhales": "apunhalar",
    "apunhalo": "apunhalar",
    "apunhalou": "apunhalar",
    "apunhalá": "apunhalar",
    "apunhalámo": "apunhalar",
    "apunhalámos": "apunhalar",
    "apunhaláramo": "apunhalar",
    "apunhaláramos": "apunhalar",
    "apunhalárei": "apunhalar",
    "apunhaláreis": "apunhalar",
    "apunhalásseis": "apunhalar",
    "apunhalássemos": "apunhalar",
    "apunhalávamo": "apunhalar",
    "apunhalávamos": "apunhalar",
    "apunhalávei": "apunhalar",
    "apunhaláveis": "apunhalar",
    "apunham": "apor",
    "apunhas": "apor",
    "apupa": "apupar",
    "apupada": "apupar",
    "apupadas": "apupar",
    "apupado": "apupar",
    "apupados": "apupar",
    "apupai": "apupar",
    "apupais": "apupar",
    "apupam": "apupar",
    "apupamo": "apupar",
    "apupamos": "apupar",
    "apupando": "apupar",
    "apupara": "apupar",
    "apuparam": "apupar",
    "apuparas": "apupar",
    "apuparde": "apupar",
    "apupardes": "apupar",
    "apupare": "apupar",
    "apuparei": "apupar",
    "apupareis": "apupar",
    "apuparem": "apupar",
    "apuparemos": "apupar",
    "apupares": "apupar",
    "apuparia": "apupar",
    "apupariam": "apupar",
    "apuparias": "apupar",
    "apuparmo": "apupar",
    "apuparmos": "apupar",
    "apupará": "apupar",
    "apuparás": "apupar",
    "apuparão": "apupar",
    "apuparíamos": "apupar",
    "apuparíeis": "apupar",
    "apupas": "apupar",
    "apupasse": "apupar",
    "apupassem": "apupar",
    "apupasses": "apupar",
    "apupaste": "apupar",
    "apupastes": "apupar",
    "apupava": "apupar",
    "apupavam": "apupar",
    "apupavas": "apupar",
    "apupe": "apupar",
    "apupei": "apupar",
    "apupeis": "apupar",
    "apupem": "apupar",
    "apupemo": "apupar",
    "apupemos": "apupar",
    "apupes": "apupar",
    "apupo": "apupar",
    "apupos": "apupo",
    "apupou": "apupar",
    "apupá": "apupar",
    "apupámo": "apupar",
    "apupámos": "apupar",
    "apupáramo": "apupar",
    "apupáramos": "apupar",
    "apupárei": "apupar",
    "apupáreis": "apupar",
    "apupásseis": "apupar",
    "apupássemos": "apupar",
    "apupávamo": "apupar",
    "apupávamos": "apupar",
    "apupávei": "apupar",
    "apupáveis": "apupar",
    "apura": "apurar",
    "apurada": "apurar",
    "apuradas": "apurar",
    "apurado": "apurar",
    "apuradora": "apurador",
    "apuradoras": "apurador",
    "apuradores": "apurador",
    "apurados": "apurar",
    "apuradíssima": "apurado",
    "apuradíssimas": "apurado",
    "apuradíssimo": "apurado",
    "apuradíssimos": "apurado",
    "apurai": "apurar",
    "apurais": "apurar",
    "apuram": "apurar",
    "apuramentos": "apuramento",
    "apuramo": "apurar",
    "apuramos": "apurar",
    "apurando": "apurar",
    "apurara": "apurar",
    "apuraram": "apurar",
    "apuraras": "apurar",
    "apurarde": "apurar",
    "apurardes": "apurar",
    "apurare": "apurar",
    "apurarei": "apurar",
    "apurareis": "apurar",
    "apurarem": "apurar",
    "apuraremos": "apurar",
    "apurares": "apurar",
    "apuraria": "apurar",
    "apurariam": "apurar",
    "apurarias": "apurar",
    "apurarmo": "apurar",
    "apurarmos": "apurar",
    "apurará": "apurar",
    "apurarás": "apurar",
    "apurarão": "apurar",
    "apuraríamos": "apurar",
    "apuraríeis": "apurar",
    "apuras": "apurar",
    "apurasse": "apurar",
    "apurassem": "apurar",
    "apurasses": "apurar",
    "apuraste": "apurar",
    "apurastes": "apurar",
    "apurativa": "apurativo",
    "apurativas": "apurativo",
    "apurativos": "apurativo",
    "apurava": "apurar",
    "apuravam": "apurar",
    "apuravas": "apurar",
    "apurações": "apuração",
    "apure": "apurar",
    "apurei": "apurar",
    "apureis": "apurar",
    "apurem": "apurar",
    "apuremo": "apurar",
    "apuremos": "apurar",
    "apures": "apurar",
    "apuro": "apurar",
    "apuros": "apuro",
    "apurou": "apurar",
    "apurpurada": "apurpurado",
    "apurpuradas": "apurpurado",
    "apurpurados": "apurpurado",
    "apurá": "apurar",
    "apurámo": "apurar",
    "apurámos": "apurar",
    "apuráramo": "apurar",
    "apuráramos": "apurar",
    "apurárei": "apurar",
    "apuráreis": "apurar",
    "apurásseis": "apurar",
    "apurássemos": "apurar",
    "apurávamo": "apurar",
    "apurávamos": "apurar",
    "apurávei": "apurar",
    "apuráveis": "apurável",
    "apus": "apor",
    "apusemo": "apor",
    "apusemos": "apor",
    "apuser": "apor",
    "apusera": "apor",
    "apuseram": "apor",
    "apuseras": "apor",
    "apuserdes": "apor",
    "apuserem": "apor",
    "apuseres": "apor",
    "apusermos": "apor",
    "apusesse": "apor",
    "apusessem": "apor",
    "apusesses": "apor",
    "apuseste": "apor",
    "apusestes": "apor",
    "apuséramo": "apor",
    "apuséramos": "apor",
    "apusérei": "apor",
    "apuséreis": "apor",
    "apusésseis": "apor",
    "apuséssemos": "apor",
    "apática": "apático",
    "apáticas": "apático",
    "apáticos": "apático",
    "apátridas": "apátrida",
    "apéptica": "apéptico",
    "apépticas": "apéptico",
    "apépticos": "apéptico",
    "apés": "apé",
    "apétala": "apétalo",
    "apétalas": "apétalo",
    "apétalos": "apétalo",
    "apêndices": "apêndice",
    "apês": "apê",
    "apícolas": "apícola",
    "apículas": "apícula",
    "apículos": "apículo",
    "apídeos": "apídeo",
    "apífoba": "apífobo",
    "apífobas": "apífobo",
    "apífobos": "apífobo",
    "apívora": "apívoro",
    "apívoras": "apívoro",
    "apívoros": "apívoro",
    "apócitos": "apócito",
    "apóclises": "apóclise",
    "apócopes": "apócope",
    "apócrifa": "apócrifo",
    "apócrifas": "apócrifo",
    "apócrifos": "apócrifo",
    "apódemas": "apódema",
    "apódoses": "apódose",
    "apófases": "apófase",
    "apófiges": "apófige",
    "apófises": "apófise",
    "apógrafa": "apógrafo",
    "apógrafas": "apógrafo",
    "apógrafos": "apógrafo",
    "apólices": "apólice",
    "apólogos": "apólogo",
    "apósita": "apósito",
    "apósitas": "apósito",
    "apósitos": "apósito",
    "apóstases": "apóstase",
    "apóstatas": "apóstata",
    "apóstola": "apóstolo",
    "apóstolas": "apóstolo",
    "apóstolos": "apóstolo",
    "apóstrofes": "apóstrofe",
    "apóstrofos": "apóstrofo",
    "apótemas": "apótema",
    "apóteses": "apótese",
    "apótipos": "apótipo",
    "apótomos": "apótomo",
    "apózemas": "apózema",
    "apô": "apor",
    "apôs": "apor",
    "apõe": "apor",
    "apõem": "apor",
    "apões": "apor",
    "apúlia": "apúlio",
    "apúlias": "apúlio",
    "apúlices": "apúlice",
    "apúlios": "apúlio",
    "apúnhamo": "apor",
    "apúnhamos": "apor",
    "apúnhei": "apor",
    "apúnheis": "apor",
    "aquaculturas": "aquacultura",
    "aquadrilha": "aquadrilhar",
    "aquadrilhada": "aquadrilhar",
    "aquadrilhadas": "aquadrilhar",
    "aquadrilhado": "aquadrilhar",
    "aquadrilhados": "aquadrilhar",
    "aquadrilhai": "aquadrilhar",
    "aquadrilhais": "aquadrilhar",
    "aquadrilham": "aquadrilhar",
    "aquadrilhamentos": "aquadrilhamento",
    "aquadrilhamo": "aquadrilhar",
    "aquadrilhamos": "aquadrilhar",
    "aquadrilhando": "aquadrilhar",
    "aquadrilhara": "aquadrilhar",
    "aquadrilharam": "aquadrilhar",
    "aquadrilharas": "aquadrilhar",
    "aquadrilharde": "aquadrilhar",
    "aquadrilhardes": "aquadrilhar",
    "aquadrilhare": "aquadrilhar",
    "aquadrilharei": "aquadrilhar",
    "aquadrilhareis": "aquadrilhar",
    "aquadrilharem": "aquadrilhar",
    "aquadrilharemos": "aquadrilhar",
    "aquadrilhares": "aquadrilhar",
    "aquadrilharia": "aquadrilhar",
    "aquadrilhariam": "aquadrilhar",
    "aquadrilharias": "aquadrilhar",
    "aquadrilharmo": "aquadrilhar",
    "aquadrilharmos": "aquadrilhar",
    "aquadrilhará": "aquadrilhar",
    "aquadrilharás": "aquadrilhar",
    "aquadrilharão": "aquadrilhar",
    "aquadrilharíamos": "aquadrilhar",
    "aquadrilharíeis": "aquadrilhar",
    "aquadrilhas": "aquadrilhar",
    "aquadrilhasse": "aquadrilhar",
    "aquadrilhassem": "aquadrilhar",
    "aquadrilhasses": "aquadrilhar",
    "aquadrilhaste": "aquadrilhar",
    "aquadrilhastes": "aquadrilhar",
    "aquadrilhava": "aquadrilhar",
    "aquadrilhavam": "aquadrilhar",
    "aquadrilhavas": "aquadrilhar",
    "aquadrilhe": "aquadrilhar",
    "aquadrilhei": "aquadrilhar",
    "aquadrilheis": "aquadrilhar",
    "aquadrilhem": "aquadrilhar",
    "aquadrilhemo": "aquadrilhar",
    "aquadrilhemos": "aquadrilhar",
    "aquadrilhes": "aquadrilhar",
    "aquadrilho": "aquadrilhar",
    "aquadrilhou": "aquadrilhar",
    "aquadrilhá": "aquadrilhar",
    "aquadrilhámo": "aquadrilhar",
    "aquadrilhámos": "aquadrilhar",
    "aquadrilháramo": "aquadrilhar",
    "aquadrilháramos": "aquadrilhar",
    "aquadrilhárei": "aquadrilhar",
    "aquadrilháreis": "aquadrilhar",
    "aquadrilhásseis": "aquadrilhar",
    "aquadrilhássemos": "aquadrilhar",
    "aquadrilhávamo": "aquadrilhar",
    "aquadrilhávamos": "aquadrilhar",
    "aquadrilhávei": "aquadrilhar",
    "aquadrilháveis": "aquadrilhar",
    "aquafortes": "aquaforte",
    "aquafortistas": "aquafortista",
    "aquaparques": "aquaparque",
    "aquaplanagens": "aquaplanagem",
    "aquarelas": "aquarela",
    "aquarelistas": "aquarelista",
    "aquariana": "aquariano",
    "aquarianas": "aquariano",
    "aquarianos": "aquariano",
    "aquartalada": "aquartalado",
    "aquartaladas": "aquartalado",
    "aquartalados": "aquartalado",
    "aquartela": "aquartelar",
    "aquartelada": "aquartelar",
    "aquarteladas": "aquartelar",
    "aquartelado": "aquartelar",
    "aquartelados": "aquartelar",
    "aquartelai": "aquartelar",
    "aquartelais": "aquartelar",
    "aquartelam": "aquartelar",
    "aquartelamentos": "aquartelamento",
    "aquartelamo": "aquartelar",
    "aquartelamos": "aquartelar",
    "aquartelando": "aquartelar",
    "aquartelara": "aquartelar",
    "aquartelaram": "aquartelar",
    "aquartelaras": "aquartelar",
    "aquartelarde": "aquartelar",
    "aquartelardes": "aquartelar",
    "aquartelare": "aquartelar",
    "aquartelarei": "aquartelar",
    "aquartelareis": "aquartelar",
    "aquartelarem": "aquartelar",
    "aquartelaremos": "aquartelar",
    "aquartelares": "aquartelar",
    "aquartelaria": "aquartelar",
    "aquartelariam": "aquartelar",
    "aquartelarias": "aquartelar",
    "aquartelarmo": "aquartelar",
    "aquartelarmos": "aquartelar",
    "aquartelará": "aquartelar",
    "aquartelarás": "aquartelar",
    "aquartelarão": "aquartelar",
    "aquartelaríamos": "aquartelar",
    "aquartelaríeis": "aquartelar",
    "aquartelas": "aquartelar",
    "aquartelasse": "aquartelar",
    "aquartelassem": "aquartelar",
    "aquartelasses": "aquartelar",
    "aquartelaste": "aquartelar",
    "aquartelastes": "aquartelar",
    "aquartelava": "aquartelar",
    "aquartelavam": "aquartelar",
    "aquartelavas": "aquartelar",
    "aquartele": "aquartelar",
    "aquartelei": "aquartelar",
    "aquarteleis": "aquartelar",
    "aquartelem": "aquartelar",
    "aquartelemo": "aquartelar",
    "aquartelemos": "aquartelar",
    "aquarteles": "aquartelar",
    "aquartelo": "aquartelar",
    "aquartelou": "aquartelar",
    "aquartelá": "aquartelar",
    "aquartelámo": "aquartelar",
    "aquartelámos": "aquartelar",
    "aquarteláramo": "aquartelar",
    "aquarteláramos": "aquartelar",
    "aquartelárei": "aquartelar",
    "aquarteláreis": "aquartelar",
    "aquartelásseis": "aquartelar",
    "aquartelássemos": "aquartelar",
    "aquartelávamo": "aquartelar",
    "aquartelávamos": "aquartelar",
    "aquartelávei": "aquartelar",
    "aquarteláveis": "aquartelar",
    "aquatintas": "aquatinta",
    "aquatofanas": "aquatofana",
    "aquece": "aquecer",
    "aquecedelas": "aquecedela",
    "aquecedora": "aquecedor",
    "aquecedoras": "aquecedor",
    "aquecedores": "aquecedor",
    "aquecedouros": "aquecedouro",
    "aquecei": "aquecer",
    "aqueceis": "aquecer",
    "aquecem": "aquecer",
    "aquecemo": "aquecer",
    "aquecemos": "aquecer",
    "aquecendo": "aquecer",
    "aquecera": "aquecer",
    "aqueceram": "aquecer",
    "aqueceras": "aquecer",
    "aquecerde": "aquecer",
    "aquecerdes": "aquecer",
    "aquecere": "aquecer",
    "aquecerei": "aquecer",
    "aquecereis": "aquecer",
    "aquecerem": "aquecer",
    "aqueceremos": "aquecer",
    "aqueceres": "aquecer",
    "aqueceria": "aquecer",
    "aqueceriam": "aquecer",
    "aquecerias": "aquecer",
    "aquecermo": "aquecer",
    "aquecermos": "aquecer",
    "aquecerá": "aquecer",
    "aquecerás": "aquecer",
    "aquecerão": "aquecer",
    "aqueceríamos": "aquecer",
    "aqueceríeis": "aquecer",
    "aqueces": "aquecer",
    "aquecesse": "aquecer",
    "aquecessem": "aquecer",
    "aquecesses": "aquecer",
    "aqueceste": "aquecer",
    "aquecestes": "aquecer",
    "aqueceu": "aquecer",
    "aqueci": "aquecer",
    "aquecia": "aquecer",
    "aqueciam": "aquecer",
    "aquecias": "aquecer",
    "aquecida": "aquecido",
    "aquecidas": "aquecido",
    "aquecido": "aquecer",
    "aquecidos": "aquecido",
    "aquecimentos": "aquecimento",
    "aquecê": "aquecer",
    "aquecêramo": "aquecer",
    "aquecêramos": "aquecer",
    "aquecêrei": "aquecer",
    "aquecêreis": "aquecer",
    "aquecêsseis": "aquecer",
    "aquecêssemos": "aquecer",
    "aquecíamo": "aquecer",
    "aquecíamos": "aquecer",
    "aquecíei": "aquecer",
    "aquecíeis": "aquecer",
    "aquecíveis": "aquecível",
    "aquedutos": "aqueduto",
    "aqueia": "aqueu",
    "aqueias": "aqueu",
    "aquela": "aquele",
    "aquelas": "aquele",
    "aqueles": "aquele",
    "aquentamentos": "aquentamento",
    "aquenódios": "aquenódio",
    "aqueritos": "aquerito",
    "aqueus": "aqueu",
    "aqueça": "aquecer",
    "aqueçais": "aquecer",
    "aqueçam": "aquecer",
    "aqueçamo": "aquecer",
    "aqueçamos": "aquecer",
    "aqueças": "aquecer",
    "aqueço": "aquecer",
    "aquiculas": "aquicula",
    "aquiculturas": "aquicultura",
    "aquiesce": "aquiescer",
    "aquiescei": "aquiescer",
    "aquiesceis": "aquiescer",
    "aquiescem": "aquiescer",
    "aquiescemo": "aquiescer",
    "aquiescemos": "aquiescer",
    "aquiescendo": "aquiescer",
    "aquiescentes": "aquiescente",
    "aquiescera": "aquiescer",
    "aquiesceram": "aquiescer",
    "aquiesceras": "aquiescer",
    "aquiescerdes": "aquiescer",
    "aquiescerei": "aquiescer",
    "aquiescereis": "aquiescer",
    "aquiescerem": "aquiescer",
    "aquiesceremos": "aquiescer",
    "aquiesceres": "aquiescer",
    "aquiesceria": "aquiescer",
    "aquiesceriam": "aquiescer",
    "aquiescerias": "aquiescer",
    "aquiescermo": "aquiescer",
    "aquiescermos": "aquiescer",
    "aquiescerá": "aquiescer",
    "aquiescerás": "aquiescer",
    "aquiescerão": "aquiescer",
    "aquiesceríamos": "aquiescer",
    "aquiesceríeis": "aquiescer",
    "aquiesces": "aquiescer",
    "aquiescesse": "aquiescer",
    "aquiescessem": "aquiescer",
    "aquiescesses": "aquiescer",
    "aquiesceste": "aquiescer",
    "aquiescestes": "aquiescer",
    "aquiesceu": "aquiescer",
    "aquiesci": "aquiescer",
    "aquiescia": "aquiescer",
    "aquiesciam": "aquiescer",
    "aquiescias": "aquiescer",
    "aquiescida": "aquiescer",
    "aquiescidas": "aquiescer",
    "aquiescido": "aquiescer",
    "aquiescidos": "aquiescer",
    "aquiescências": "aquiescência",
    "aquiescêramo": "aquiescer",
    "aquiescêramos": "aquiescer",
    "aquiescêreis": "aquiescer",
    "aquiescêsseis": "aquiescer",
    "aquiescêssemos": "aquiescer",
    "aquiescíamo": "aquiescer",
    "aquiescíamos": "aquiescer",
    "aquiescíeis": "aquiescer",
    "aquiesça": "aquiescer",
    "aquiesçais": "aquiescer",
    "aquiesçam": "aquiescer",
    "aquiesçamo": "aquiescer",
    "aquiesçamos": "aquiescer",
    "aquiesças": "aquiescer",
    "aquiesço": "aquiescer",
    "aquieta": "aquietar",
    "aquietada": "aquietar",
    "aquietadas": "aquietar",
    "aquietado": "aquietar",
    "aquietadora": "aquietador",
    "aquietadoras": "aquietador",
    "aquietadores": "aquietador",
    "aquietados": "aquietar",
    "aquietai": "aquietar",
    "aquietais": "aquietar",
    "aquietam": "aquietar",
    "aquietamo": "aquietar",
    "aquietamos": "aquietar",
    "aquietando": "aquietar",
    "aquietara": "aquietar",
    "aquietaram": "aquietar",
    "aquietaras": "aquietar",
    "aquietarde": "aquietar",
    "aquietardes": "aquietar",
    "aquietare": "aquietar",
    "aquietarei": "aquietar",
    "aquietareis": "aquietar",
    "aquietarem": "aquietar",
    "aquietaremos": "aquietar",
    "aquietares": "aquietar",
    "aquietaria": "aquietar",
    "aquietariam": "aquietar",
    "aquietarias": "aquietar",
    "aquietarmo": "aquietar",
    "aquietarmos": "aquietar",
    "aquietará": "aquietar",
    "aquietarás": "aquietar",
    "aquietarão": "aquietar",
    "aquietaríamos": "aquietar",
    "aquietaríeis": "aquietar",
    "aquietas": "aquietar",
    "aquietasse": "aquietar",
    "aquietassem": "aquietar",
    "aquietasses": "aquietar",
    "aquietaste": "aquietar",
    "aquietastes": "aquietar",
    "aquietava": "aquietar",
    "aquietavam": "aquietar",
    "aquietavas": "aquietar",
    "aquietações": "aquietação",
    "aquiete": "aquietar",
    "aquietei": "aquietar",
    "aquieteis": "aquietar",
    "aquietem": "aquietar",
    "aquietemo": "aquietar",
    "aquietemos": "aquietar",
    "aquietes": "aquietar",
    "aquieto": "aquietar",
    "aquietou": "aquietar",
    "aquietá": "aquietar",
    "aquietámo": "aquietar",
    "aquietámos": "aquietar",
    "aquietáramo": "aquietar",
    "aquietáramos": "aquietar",
    "aquietárei": "aquietar",
    "aquietáreis": "aquietar",
    "aquietásseis": "aquietar",
    "aquietássemos": "aquietar",
    "aquietávamo": "aquietar",
    "aquietávamos": "aquietar",
    "aquietávei": "aquietar",
    "aquietáveis": "aquietar",
    "aquifoleácea": "aquifoleáceo",
    "aquifoleáceas": "aquifoleáceo",
    "aquifoleáceos": "aquifoleáceo",
    "aquifoliáceas": "aquifoliácea",
    "aquilada": "aquilado",
    "aquiladas": "aquilado",
    "aquilados": "aquilado",
    "aquilarínea": "aquilaríneo",
    "aquilaríneas": "aquilaríneo",
    "aquilaríneos": "aquilaríneo",
    "aquilata": "aquilatar",
    "aquilatada": "aquilatar",
    "aquilatadas": "aquilatar",
    "aquilatado": "aquilatar",
    "aquilatadora": "aquilatador",
    "aquilatadoras": "aquilatador",
    "aquilatadores": "aquilatador",
    "aquilatados": "aquilatar",
    "aquilatai": "aquilatar",
    "aquilatais": "aquilatar",
    "aquilatam": "aquilatar",
    "aquilatamo": "aquilatar",
    "aquilatamos": "aquilatar",
    "aquilatando": "aquilatar",
    "aquilatara": "aquilatar",
    "aquilataram": "aquilatar",
    "aquilataras": "aquilatar",
    "aquilatarde": "aquilatar",
    "aquilatardes": "aquilatar",
    "aquilatare": "aquilatar",
    "aquilatarei": "aquilatar",
    "aquilatareis": "aquilatar",
    "aquilatarem": "aquilatar",
    "aquilataremos": "aquilatar",
    "aquilatares": "aquilatar",
    "aquilataria": "aquilatar",
    "aquilatariam": "aquilatar",
    "aquilatarias": "aquilatar",
    "aquilatarmo": "aquilatar",
    "aquilatarmos": "aquilatar",
    "aquilatará": "aquilatar",
    "aquilatarás": "aquilatar",
    "aquilatarão": "aquilatar",
    "aquilataríamos": "aquilatar",
    "aquilataríeis": "aquilatar",
    "aquilatas": "aquilatar",
    "aquilatasse": "aquilatar",
    "aquilatassem": "aquilatar",
    "aquilatasses": "aquilatar",
    "aquilataste": "aquilatar",
    "aquilatastes": "aquilatar",
    "aquilatava": "aquilatar",
    "aquilatavam": "aquilatar",
    "aquilatavas": "aquilatar",
    "aquilatações": "aquilatação",
    "aquilate": "aquilatar",
    "aquilatei": "aquilatar",
    "aquilateis": "aquilatar",
    "aquilatem": "aquilatar",
    "aquilatemo": "aquilatar",
    "aquilatemos": "aquilatar",
    "aquilates": "aquilatar",
    "aquilato": "aquilatar",
    "aquilatou": "aquilatar",
    "aquilatá": "aquilatar",
    "aquilatámo": "aquilatar",
    "aquilatámos": "aquilatar",
    "aquilatáramo": "aquilatar",
    "aquilatáramos": "aquilatar",
    "aquilatárei": "aquilatar",
    "aquilatáreis": "aquilatar",
    "aquilatásseis": "aquilatar",
    "aquilatássemos": "aquilatar",
    "aquilatávamo": "aquilatar",
    "aquilatávamos": "aquilatar",
    "aquilatávei": "aquilatar",
    "aquilatáveis": "aquilatar",
    "aquileia": "aquileu",
    "aquileias": "aquileu",
    "aquileus": "aquileu",
    "aquilias": "aquilia",
    "aquilina": "aquilino",
    "aquilinas": "aquilino",
    "aquilinos": "aquilino",
    "aquilodinias": "aquilodinia",
    "aquilonais": "aquilonal",
    "aquilárias": "aquilária",
    "aquilégias": "aquilégia",
    "aquilégios": "aquilégio",
    "aquilífera": "aquilífero",
    "aquilíferas": "aquilífero",
    "aquilíferos": "aquilífero",
    "aquilónea": "aquilóneo",
    "aquilóneas": "aquilóneo",
    "aquilóneos": "aquilóneo",
    "aquilões": "aquilão",
    "aquinhoadora": "aquinhoador",
    "aquinhoadoras": "aquinhoador",
    "aquinhoadores": "aquinhoador",
    "aquinhoamentos": "aquinhoamento",
    "aquirias": "aquiria",
    "aquisitiva": "aquisitivo",
    "aquisitivas": "aquisitivo",
    "aquisitividades": "aquisitividade",
    "aquisitivos": "aquisitivo",
    "aquisições": "aquisição",
    "aquistas": "aquista",
    "aquosa": "aquoso",
    "aquosas": "aquoso",
    "aquosidades": "aquosidade",
    "aquosos": "aquoso",
    "aquários": "aquário",
    "aquáteis": "aquátil",
    "aquática": "aquático",
    "aquáticas": "aquático",
    "aquáticos": "aquático",
    "aquénia": "aquénio",
    "aquénias": "aquénio",
    "aquénios": "aquénio",
    "aquícolas": "aquícola",
    "aquífera": "aquífero",
    "aquíferas": "aquífero",
    "aquíferos": "aquífero",
    "aquígena": "aquígeno",
    "aquígenas": "aquígeno",
    "aquígenos": "aquígeno",
    "aquílega": "aquílego",
    "aquílegas": "aquílego",
    "aquílegos": "aquílego",
    "ara": "arar",
    "arabescos": "arabesco",
    "arabias": "arabia",
    "arabinoses": "arabinose",
    "arabismos": "arabismo",
    "arabistas": "arabista",
    "arabiza": "arabizar",
    "arabizada": "arabizar",
    "arabizadas": "arabizar",
    "arabizado": "arabizar",
    "arabizados": "arabizar",
    "arabizai": "arabizar",
    "arabizais": "arabizar",
    "arabizam": "arabizar",
    "arabizamo": "arabizar",
    "arabizamos": "arabizar",
    "arabizando": "arabizar",
    "arabizara": "arabizar",
    "arabizaram": "arabizar",
    "arabizaras": "arabizar",
    "arabizarde": "arabizar",
    "arabizardes": "arabizar",
    "arabizare": "arabizar",
    "arabizarei": "arabizar",
    "arabizareis": "arabizar",
    "arabizarem": "arabizar",
    "arabizaremos": "arabizar",
    "arabizares": "arabizar",
    "arabizaria": "arabizar",
    "arabizariam": "arabizar",
    "arabizarias": "arabizar",
    "arabizarmo": "arabizar",
    "arabizarmos": "arabizar",
    "arabizará": "arabizar",
    "arabizarás": "arabizar",
    "arabizarão": "arabizar",
    "arabizaríamos": "arabizar",
    "arabizaríeis": "arabizar",
    "arabizas": "arabizar",
    "arabizasse": "arabizar",
    "arabizassem": "arabizar",
    "arabizasses": "arabizar",
    "arabizaste": "arabizar",
    "arabizastes": "arabizar",
    "arabizava": "arabizar",
    "arabizavam": "arabizar",
    "arabizavas": "arabizar",
    "arabize": "arabizar",
    "arabizei": "arabizar",
    "arabizeis": "arabizar",
    "arabizem": "arabizar",
    "arabizemo": "arabizar",
    "arabizemos": "arabizar",
    "arabizes": "arabizar",
    "arabizo": "arabizar",
    "arabizou": "arabizar",
    "arabizá": "arabizar",
    "arabizámo": "arabizar",
    "arabizámos": "arabizar",
    "arabizáramo": "arabizar",
    "arabizáramos": "arabizar",
    "arabizárei": "arabizar",
    "arabizáreis": "arabizar",
    "arabizásseis": "arabizar",
    "arabizássemos": "arabizar",
    "arabizávamo": "arabizar",
    "arabizávamos": "arabizar",
    "arabizávei": "arabizar",
    "arabizáveis": "arabizável",
    "arabotes": "arabote",
    "aracas": "araca",
    "aracniana": "aracniano",
    "aracnianas": "aracniano",
    "aracnianos": "aracniano",
    "aracnismos": "aracnismo",
    "aracnodérmica": "aracnodérmico",
    "aracnodérmicas": "aracnodérmico",
    "aracnodérmicos": "aracnodérmico",
    "aracnofilias": "aracnofilia",
    "aracnofobias": "aracnofobia",
    "aracnofóbica": "aracnofóbico",
    "aracnofóbicas": "aracnofóbico",
    "aracnofóbicos": "aracnofóbico",
    "aracnoidiana": "aracnoidiano",
    "aracnoidianas": "aracnoidiano",
    "aracnoidianos": "aracnoidiano",
    "aracnoidites": "aracnoidite",
    "aracnopsias": "aracnopsia",
    "aracnídea": "aracnídeo",
    "aracnídeas": "aracnídeo",
    "aracnídeos": "aracnídeo",
    "aracnófila": "aracnófilo",
    "aracnófilas": "aracnófilo",
    "aracnófilos": "aracnófilo",
    "aracnófoba": "aracnófobo",
    "aracnófobas": "aracnófobo",
    "aracnófobos": "aracnófobo",
    "aracnóidea": "aracnóideo",
    "aracnóideas": "aracnóideo",
    "aracnóideos": "aracnóideo",
    "aracnóides": "aracnóide",
    "aracruzenses": "aracruzense",
    "arada": "arar",
    "aradas": "arar",
    "aradeiras": "aradeira",
    "aradeças": "aradeça",
    "arado": "arar",
    "aradora": "arador",
    "aradoras": "arador",
    "aradores": "arador",
    "arados": "arar",
    "aradouros": "aradouro",
    "araduras": "aradura",
    "aragana": "aragano",
    "araganas": "aragano",
    "araganos": "aragano",
    "aragens": "aragem",
    "aragonesa": "aragonês",
    "aragonesas": "aragonês",
    "aragoneses": "aragonês",
    "aragonitas": "aragonita",
    "aragonites": "aragonite",
    "arai": "arar",
    "arais": "arar",
    "aralhas": "aralha",
    "araliácea": "araliáceo",
    "araliáceas": "araliáceo",
    "araliáceos": "araliáceo",
    "aram": "arar",
    "arama": "aramar",
    "aramada": "aramar",
    "aramadas": "aramar",
    "aramado": "aramar",
    "aramados": "aramar",
    "aramagens": "aramagem",
    "aramai": "aramar",
    "aramais": "aramar",
    "aramam": "aramar",
    "aramamo": "aramar",
    "aramamos": "aramar",
    "aramando": "aramar",
    "aramara": "aramar",
    "aramaram": "aramar",
    "aramaras": "aramar",
    "aramarde": "aramar",
    "aramardes": "aramar",
    "aramare": "aramar",
    "aramarei": "aramar",
    "aramareis": "aramar",
    "aramarem": "aramar",
    "aramaremos": "aramar",
    "aramares": "aramar",
    "aramaria": "aramar",
    "aramariam": "aramar",
    "aramarias": "aramar",
    "aramarmo": "aramar",
    "aramarmos": "aramar",
    "aramará": "aramar",
    "aramarás": "aramar",
    "aramarão": "aramar",
    "aramaríamos": "aramar",
    "aramaríeis": "aramar",
    "aramas": "aramar",
    "aramasse": "aramar",
    "aramassem": "aramar",
    "aramasses": "aramar",
    "aramaste": "aramar",
    "aramastes": "aramar",
    "aramava": "aramar",
    "aramavam": "aramar",
    "aramavas": "aramar",
    "arame": "aramar",
    "aramei": "aramar",
    "arameia": "arameu",
    "arameias": "arameu",
    "arameiros": "arameiro",
    "arameis": "aramar",
    "aramem": "aramar",
    "aramemo": "aramar",
    "aramemos": "aramar",
    "aramenhas": "aramenha",
    "arames": "arame",
    "arameus": "arameu",
    "aramistas": "aramista",
    "aramitas": "aramita",
    "aramo": "arar",
    "aramos": "arar",
    "aramou": "aramar",
    "aramá": "aramar",
    "aramámo": "aramar",
    "aramámos": "aramar",
    "aramáramo": "aramar",
    "aramáramos": "aramar",
    "aramárei": "aramar",
    "aramáreis": "aramar",
    "aramásseis": "aramar",
    "aramássemos": "aramar",
    "aramávamo": "aramar",
    "aramávamos": "aramar",
    "aramávei": "aramar",
    "aramáveis": "aramar",
    "arancárias": "arancária",
    "arandelas": "arandela",
    "arando": "arar",
    "arandos": "arando",
    "araneiformes": "araneiforme",
    "araneídea": "araneídeo",
    "araneídeas": "araneídeo",
    "araneídeos": "araneídeo",
    "araneífera": "araneífero",
    "araneíferas": "araneífero",
    "araneíferos": "araneífero",
    "aranhas": "aranha",
    "aranheiras": "aranheira",
    "aranheiros": "aranheiro",
    "aranhenta": "aranhento",
    "aranhentas": "aranhento",
    "aranhentos": "aranhento",
    "aranhiços": "aranhiço",
    "aranholas": "aranhola",
    "aranhosa": "aranhoso",
    "aranhosas": "aranhoso",
    "aranhosos": "aranhoso",
    "aranhuços": "aranhuço",
    "aranhóis": "aranhol",
    "aranhões": "aranhão",
    "aranzeis": "aranzel",
    "araquídica": "araquídico",
    "araquídicas": "araquídico",
    "araquídicos": "araquídico",
    "arara": "arar",
    "araram": "arar",
    "araras": "arara",
    "ararde": "arar",
    "arardes": "arar",
    "arare": "arar",
    "ararei": "arar",
    "arareis": "arar",
    "ararem": "arar",
    "araremos": "arar",
    "arares": "arar",
    "araria": "arar",
    "arariam": "arar",
    "ararias": "arar",
    "araribinas": "araribina",
    "ararmo": "arar",
    "ararmos": "arar",
    "ararutas": "araruta",
    "arará": "arar",
    "ararás": "arar",
    "ararão": "arar",
    "araríamos": "arar",
    "araríeis": "arar",
    "aras": "arar",
    "arasse": "arar",
    "arassem": "arar",
    "arasses": "arar",
    "araste": "arar",
    "arastes": "arar",
    "arasões": "arasão",
    "aratacas": "arataca",
    "aratriformes": "aratriforme",
    "aratória": "aratório",
    "aratórias": "aratório",
    "aratórios": "aratório",
    "araucárias": "araucária",
    "araus": "arau",
    "arautos": "arauto",
    "arava": "arar",
    "aravam": "arar",
    "aravas": "arar",
    "aravelas": "aravela",
    "aravessas": "aravessa",
    "araviadas": "araviada",
    "aravias": "aravia",
    "araçuabas": "araçuaba",
    "arações": "aração",
    "arbaletas": "arbaleta",
    "arbitra": "arbitrar",
    "arbitrada": "arbitrar",
    "arbitradas": "arbitrar",
    "arbitrado": "arbitrar",
    "arbitradora": "arbitrador",
    "arbitradoras": "arbitrador",
    "arbitradores": "arbitrador",
    "arbitrados": "arbitrar",
    "arbitragens": "arbitragem",
    "arbitrai": "arbitrar",
    "arbitrais": "arbitrar",
    "arbitram": "arbitrar",
    "arbitramentos": "arbitramento",
    "arbitramo": "arbitrar",
    "arbitramos": "arbitrar",
    "arbitrando": "arbitrar",
    "arbitrara": "arbitrar",
    "arbitraram": "arbitrar",
    "arbitraras": "arbitrar",
    "arbitrarde": "arbitrar",
    "arbitrardes": "arbitrar",
    "arbitrare": "arbitrar",
    "arbitrarei": "arbitrar",
    "arbitrareis": "arbitrar",
    "arbitrarem": "arbitrar",
    "arbitraremos": "arbitrar",
    "arbitrares": "arbitrar",
    "arbitraria": "arbitrar",
    "arbitrariam": "arbitrar",
    "arbitrarias": "arbitrar",
    "arbitrariedades": "arbitrariedade",
    "arbitrarmo": "arbitrar",
    "arbitrarmos": "arbitrar",
    "arbitrará": "arbitrar",
    "arbitrarás": "arbitrar",
    "arbitrarão": "arbitrar",
    "arbitraríamos": "arbitrar",
    "arbitraríeis": "arbitrar",
    "arbitras": "arbitrar",
    "arbitrasse": "arbitrar",
    "arbitrassem": "arbitrar",
    "arbitrasses": "arbitrar",
    "arbitraste": "arbitrar",
    "arbitrastes": "arbitrar",
    "arbitrativa": "arbitrativo",
    "arbitrativas": "arbitrativo",
    "arbitrativos": "arbitrativo",
    "arbitrava": "arbitrar",
    "arbitravam": "arbitrar",
    "arbitravas": "arbitrar",
    "arbitre": "arbitrar",
    "arbitrei": "arbitrar",
    "arbitreis": "arbitrar",
    "arbitrem": "arbitrar",
    "arbitremo": "arbitrar",
    "arbitremos": "arbitrar",
    "arbitres": "arbitrar",
    "arbitro": "arbitrar",
    "arbitrou": "arbitrar",
    "arbitrá": "arbitrar",
    "arbitrámo": "arbitrar",
    "arbitrámos": "arbitrar",
    "arbitráramo": "arbitrar",
    "arbitráramos": "arbitrar",
    "arbitrárei": "arbitrar",
    "arbitráreis": "arbitrar",
    "arbitrária": "arbitrário",
    "arbitrárias": "arbitrário",
    "arbitrários": "arbitrário",
    "arbitrásseis": "arbitrar",
    "arbitrássemos": "arbitrar",
    "arbitrávamo": "arbitrar",
    "arbitrávamos": "arbitrar",
    "arbitrávei": "arbitrar",
    "arbitráveis": "arbitrar",
    "arboresce": "arborescer",
    "arborescei": "arborescer",
    "arboresceis": "arborescer",
    "arborescem": "arborescer",
    "arborescemo": "arborescer",
    "arborescemos": "arborescer",
    "arborescendo": "arborescer",
    "arborescentes": "arborescente",
    "arborescera": "arborescer",
    "arboresceram": "arborescer",
    "arboresceras": "arborescer",
    "arborescerdes": "arborescer",
    "arborescerei": "arborescer",
    "arborescereis": "arborescer",
    "arborescerem": "arborescer",
    "arboresceremos": "arborescer",
    "arboresceres": "arborescer",
    "arboresceria": "arborescer",
    "arboresceriam": "arborescer",
    "arborescerias": "arborescer",
    "arborescermo": "arborescer",
    "arborescermos": "arborescer",
    "arborescerá": "arborescer",
    "arborescerás": "arborescer",
    "arborescerão": "arborescer",
    "arboresceríamos": "arborescer",
    "arboresceríeis": "arborescer",
    "arboresces": "arborescer",
    "arborescesse": "arborescer",
    "arborescessem": "arborescer",
    "arborescesses": "arborescer",
    "arboresceste": "arborescer",
    "arborescestes": "arborescer",
    "arboresceu": "arborescer",
    "arboresci": "arborescer",
    "arborescia": "arborescer",
    "arboresciam": "arborescer",
    "arborescias": "arborescer",
    "arborescida": "arborescer",
    "arborescidas": "arborescer",
    "arborescido": "arborescer",
    "arborescidos": "arborescer",
    "arborescências": "arborescência",
    "arborescêramo": "arborescer",
    "arborescêramos": "arborescer",
    "arborescêreis": "arborescer",
    "arborescêsseis": "arborescer",
    "arborescêssemos": "arborescer",
    "arborescíamo": "arborescer",
    "arborescíamos": "arborescer",
    "arborescíeis": "arborescer",
    "arboresça": "arborescer",
    "arboresçais": "arborescer",
    "arboresçam": "arborescer",
    "arboresçamo": "arborescer",
    "arboresçamos": "arborescer",
    "arboresças": "arborescer",
    "arboresço": "arborescer",
    "arboricidas": "arboricida",
    "arboricultora": "arboricultor",
    "arboricultoras": "arboricultor",
    "arboricultores": "arboricultor",
    "arboriculturas": "arboricultura",
    "arboriformes": "arboriforme",
    "arboristas": "arborista",
    "arboriza": "arborizar",
    "arborizada": "arborizar",
    "arborizadas": "arborizar",
    "arborizado": "arborizar",
    "arborizados": "arborizar",
    "arborizai": "arborizar",
    "arborizais": "arborizar",
    "arborizam": "arborizar",
    "arborizamo": "arborizar",
    "arborizamos": "arborizar",
    "arborizando": "arborizar",
    "arborizara": "arborizar",
    "arborizaram": "arborizar",
    "arborizaras": "arborizar",
    "arborizarde": "arborizar",
    "arborizardes": "arborizar",
    "arborizare": "arborizar",
    "arborizarei": "arborizar",
    "arborizareis": "arborizar",
    "arborizarem": "arborizar",
    "arborizaremos": "arborizar",
    "arborizares": "arborizar",
    "arborizaria": "arborizar",
    "arborizariam": "arborizar",
    "arborizarias": "arborizar",
    "arborizarmo": "arborizar",
    "arborizarmos": "arborizar",
    "arborizará": "arborizar",
    "arborizarás": "arborizar",
    "arborizarão": "arborizar",
    "arborizaríamos": "arborizar",
    "arborizaríeis": "arborizar",
    "arborizas": "arborizar",
    "arborizasse": "arborizar",
    "arborizassem": "arborizar",
    "arborizasses": "arborizar",
    "arborizaste": "arborizar",
    "arborizastes": "arborizar",
    "arborizava": "arborizar",
    "arborizavam": "arborizar",
    "arborizavas": "arborizar",
    "arborizações": "arborização",
    "arborize": "arborizar",
    "arborizei": "arborizar",
    "arborizeis": "arborizar",
    "arborizem": "arborizar",
    "arborizemo": "arborizar",
    "arborizemos": "arborizar",
    "arborizes": "arborizar",
    "arborizo": "arborizar",
    "arborizou": "arborizar",
    "arborizá": "arborizar",
    "arborizámo": "arborizar",
    "arborizámos": "arborizar",
    "arborizáramo": "arborizar",
    "arborizáramos": "arborizar",
    "arborizárei": "arborizar",
    "arborizáreis": "arborizar",
    "arborizásseis": "arborizar",
    "arborizássemos": "arborizar",
    "arborizávamo": "arborizar",
    "arborizávamos": "arborizar",
    "arborizávei": "arborizar",
    "arborizáveis": "arborizar",
    "arborícolas": "arborícola",
    "arbusculares": "arbuscular",
    "arbustais": "arbustal",
    "arbustiformes": "arbustiforme",
    "arbustiva": "arbustivo",
    "arbustivas": "arbustivo",
    "arbustivos": "arbustivo",
    "arbustos": "arbusto",
    "arbustácea": "arbustáceo",
    "arbustáceas": "arbustáceo",
    "arbustáceos": "arbustáceo",
    "arbutinas": "arbutina",
    "arbutácea": "arbutáceo",
    "arbutáceas": "arbutáceo",
    "arbutáceos": "arbutáceo",
    "arbutóidea": "arbutóideo",
    "arbutóideas": "arbutóideo",
    "arbutóideos": "arbutóideo",
    "arbítrios": "arbítrio",
    "arbórea": "arbóreo",
    "arbóreas": "arbóreo",
    "arbóreos": "arbóreo",
    "arbúsculas": "arbúscula",
    "arbúsculos": "arbúsculo",
    "arbústea": "arbústeo",
    "arbústeas": "arbústeo",
    "arbústeos": "arbústeo",
    "arca": "arcar",
    "arcaboiços": "arcaboiço",
    "arcabouços": "arcabouço",
    "arcabuzadas": "arcabuzada",
    "arcabuzamentos": "arcabuzamento",
    "arcabuzarias": "arcabuzaria",
    "arcabuzeiros": "arcabuzeiro",
    "arcabuzes": "arcabuz",
    "arcabuzetas": "arcabuzeta",
    "arcabéns": "arcabém",
    "arcada": "arcar",
    "arcadas": "arcar",
    "arcadiana": "arcadiano",
    "arcadianas": "arcadiano",
    "arcadianos": "arcadiano",
    "arcadismos": "arcadismo",
    "arcado": "arcar",
    "arcados": "arcar",
    "arcaduras": "arcadura",
    "arcaica": "arcaico",
    "arcaicas": "arcaico",
    "arcaicos": "arcaico",
    "arcainhas": "arcainha",
    "arcais": "arcar",
    "arcaiza": "arcaizar",
    "arcaizada": "arcaizar",
    "arcaizadas": "arcaizar",
    "arcaizado": "arcaizar",
    "arcaizados": "arcaizar",
    "arcaizai": "arcaizar",
    "arcaizais": "arcaizar",
    "arcaizam": "arcaizar",
    "arcaizamentos": "arcaizamento",
    "arcaizamo": "arcaizar",
    "arcaizamos": "arcaizar",
    "arcaizando": "arcaizar",
    "arcaizantes": "arcaizante",
    "arcaizara": "arcaizar",
    "arcaizaram": "arcaizar",
    "arcaizaras": "arcaizar",
    "arcaizarde": "arcaizar",
    "arcaizardes": "arcaizar",
    "arcaizare": "arcaizar",
    "arcaizarei": "arcaizar",
    "arcaizareis": "arcaizar",
    "arcaizarem": "arcaizar",
    "arcaizaremos": "arcaizar",
    "arcaizares": "arcaizar",
    "arcaizaria": "arcaizar",
    "arcaizariam": "arcaizar",
    "arcaizarias": "arcaizar",
    "arcaizarmo": "arcaizar",
    "arcaizarmos": "arcaizar",
    "arcaizará": "arcaizar",
    "arcaizarás": "arcaizar",
    "arcaizarão": "arcaizar",
    "arcaizaríamos": "arcaizar",
    "arcaizaríeis": "arcaizar",
    "arcaizas": "arcaizar",
    "arcaizasse": "arcaizar",
    "arcaizassem": "arcaizar",
    "arcaizasses": "arcaizar",
    "arcaizaste": "arcaizar",
    "arcaizastes": "arcaizar",
    "arcaizava": "arcaizar",
    "arcaizavam": "arcaizar",
    "arcaizavas": "arcaizar",
    "arcaize": "arcaizar",
    "arcaizei": "arcaizar",
    "arcaizeis": "arcaizar",
    "arcaizem": "arcaizar",
    "arcaizemo": "arcaizar",
    "arcaizemos": "arcaizar",
    "arcaizes": "arcaizar",
    "arcaizo": "arcaizar",
    "arcaizou": "arcaizar",
    "arcaizá": "arcaizar",
    "arcaizámo": "arcaizar",
    "arcaizámos": "arcaizar",
    "arcaizáramo": "arcaizar",
    "arcaizáramos": "arcaizar",
    "arcaizárei": "arcaizar",
    "arcaizáreis": "arcaizar",
    "arcaizásseis": "arcaizar",
    "arcaizássemos": "arcaizar",
    "arcaizávamo": "arcaizar",
    "arcaizávamos": "arcaizar",
    "arcaizávei": "arcaizar",
    "arcaizáveis": "arcaizar",
    "arcam": "arcar",
    "arcamo": "arcar",
    "arcamos": "arcar",
    "arcana": "arcano",
    "arcanas": "arcano",
    "arcando": "arcar",
    "arcanes": "arcane",
    "arcangélica": "arcangélico",
    "arcangélicas": "arcangélico",
    "arcangélicos": "arcangélico",
    "arcanjos": "arcanjo",
    "arcanos": "arcano",
    "arcara": "arcar",
    "arcaram": "arcar",
    "arcaras": "arcar",
    "arcardes": "arcar",
    "arcarei": "arcar",
    "arcareis": "arcar",
    "arcarem": "arcar",
    "arcaremos": "arcar",
    "arcares": "arcar",
    "arcaria": "arcar",
    "arcariam": "arcar",
    "arcarias": "arcaria",
    "arcarmo": "arcar",
    "arcarmos": "arcar",
    "arcará": "arcar",
    "arcarás": "arcar",
    "arcarão": "arcar",
    "arcaríamos": "arcar",
    "arcaríeis": "arcar",
    "arcas": "arcar",
    "arcasse": "arcar",
    "arcassem": "arcar",
    "arcasses": "arcar",
    "arcaste": "arcar",
    "arcastes": "arcar",
    "arcaturas": "arcatura",
    "arcava": "arcar",
    "arcavam": "arcar",
    "arcavas": "arcar",
    "arcazes": "arcaz",
    "arcaísmos": "arcaísmo",
    "arcaístas": "arcaísta",
    "arcebispados": "arcebispado",
    "arcebispais": "arcebispal",
    "arcebispos": "arcebispo",
    "arcediagados": "arcediagado",
    "arcediagos": "arcediago",
    "arcelas": "arcela",
    "arcelídea": "arcelídeo",
    "arcelídeas": "arcelídeo",
    "arcelídeos": "arcelídeo",
    "arcelínea": "arcelíneo",
    "arcelíneas": "arcelíneo",
    "arcelíneos": "arcelíneo",
    "arcetes": "arcete",
    "archas": "archa",
    "archeiros": "archeiro",
    "archetes": "archete",
    "archotadas": "archotada",
    "archoteiros": "archoteiro",
    "archotes": "archote",
    "archotistas": "archotista",
    "arcifinais": "arcifinal",
    "arciformes": "arciforme",
    "arcifínia": "arcifínio",
    "arcifínias": "arcifínio",
    "arcifínios": "arcifínio",
    "arcipotentes": "arcipotente",
    "arciprestados": "arciprestado",
    "arciprestais": "arciprestal",
    "arciprestes": "arcipreste",
    "arcitenentes": "arcitenente",
    "arco": "arcar",
    "arcobotantes": "arcobotante",
    "arcontados": "arcontado",
    "arcontarias": "arcontaria",
    "arcontes": "arconte",
    "arcoptoses": "arcoptose",
    "arcorragias": "arcorragia",
    "arcorreias": "arcorreia",
    "arcos": "arco",
    "arcosa": "arcoso",
    "arcosas": "arcoso",
    "arcoses": "arcose",
    "arcosos": "arcoso",
    "arcossólios": "arcossólio",
    "arcou": "arcar",
    "arctações": "arctação",
    "arctocéfala": "arctocéfalo",
    "arctocéfalas": "arctocéfalo",
    "arctocéfalos": "arctocéfalo",
    "arctopitecos": "arctopiteco",
    "arcturos": "arcturo",
    "arcturuss": "arcturus",
    "arctícolas": "arctícola",
    "arcuais": "arcual",
    "arcuenses": "arcuense",
    "arcádia": "arcádio",
    "arcádias": "arcádio",
    "arcádica": "arcádico",
    "arcádicas": "arcádico",
    "arcádicos": "arcádico",
    "arcádios": "arcádio",
    "arcámo": "arcar",
    "arcámos": "arcar",
    "arcáramo": "arcar",
    "arcáramos": "arcar",
    "arcáreis": "arcar",
    "arcários": "arcário",
    "arcásseis": "arcar",
    "arcássemos": "arcar",
    "arcávamo": "arcar",
    "arcávamos": "arcar",
    "arcáveis": "arcar",
    "arcélidas": "arcélida",
    "arcêutides": "arcêutide",
    "arcífera": "arcífero",
    "arcíferas": "arcífero",
    "arcíferos": "arcífero",
    "arcírias": "arcíria",
    "arcões": "arcão",
    "arda": "arder",
    "ardais": "arder",
    "ardam": "arder",
    "ardamo": "arder",
    "ardamos": "arder",
    "ardas": "arder",
    "arde": "arder",
    "ardei": "arder",
    "ardeis": "arder",
    "ardem": "arder",
    "ardemo": "arder",
    "ardemos": "arder",
    "ardendo": "arder",
    "ardentes": "ardente",
    "ardentias": "ardentia",
    "ardentosa": "ardentoso",
    "ardentosas": "ardentoso",
    "ardentosos": "ardentoso",
    "ardera": "arder",
    "arderam": "arder",
    "arderas": "arder",
    "arderdes": "arder",
    "arderei": "arder",
    "ardereis": "arder",
    "arderem": "arder",
    "arderemos": "arder",
    "arderes": "arder",
    "arderia": "arder",
    "arderiam": "arder",
    "arderias": "arder",
    "ardermo": "arder",
    "ardermos": "arder",
    "arderá": "arder",
    "arderás": "arder",
    "arderão": "arder",
    "arderíamos": "arder",
    "arderíeis": "arder",
    "ardes": "arder",
    "ardesse": "arder",
    "ardessem": "arder",
    "ardesses": "arder",
    "ardeste": "arder",
    "ardestes": "arder",
    "ardeu": "arder",
    "ardeídas": "ardeída",
    "ardeídea": "ardeídeo",
    "ardeídeas": "ardeídeo",
    "ardeídeos": "ardeídeo",
    "ardi": "arder",
    "ardia": "arder",
    "ardiam": "arder",
    "ardias": "arder",
    "ardida": "ardido",
    "ardidas": "ardido",
    "ardido": "arder",
    "ardidos": "ardido",
    "ardidíssima": "ardido",
    "ardidíssimas": "ardido",
    "ardidíssimo": "ardido",
    "ardidíssimos": "ardido",
    "ardilezas": "ardileza",
    "ardilosa": "ardiloso",
    "ardilosas": "ardiloso",
    "ardilosos": "ardiloso",
    "ardimentos": "ardimento",
    "ardinas": "ardina",
    "ardis": "ardil",
    "ardisiácea": "ardisiáceo",
    "ardisiáceas": "ardisiáceo",
    "ardisiáceos": "ardisiáceo",
    "ardo": "arder",
    "ardores": "ardor",
    "ardorosa": "ardoroso",
    "ardorosas": "ardoroso",
    "ardorosos": "ardoroso",
    "ardosieiras": "ardosieira",
    "ardosieiros": "ardosieiro",
    "arduidades": "arduidade",
    "ardumes": "ardume",
    "ardências": "ardência",
    "ardêramo": "arder",
    "ardêramos": "arder",
    "ardêreis": "arder",
    "ardêsseis": "arder",
    "ardêssemos": "arder",
    "ardíamo": "arder",
    "ardíamos": "arder",
    "ardíeis": "arder",
    "ardífera": "ardífero",
    "ardíferas": "ardífero",
    "ardíferos": "ardífero",
    "ardómetros": "ardómetro",
    "ardósias": "ardósia",
    "are": "arar",
    "areada": "arear",
    "areadas": "arear",
    "areado": "arear",
    "areadora": "areador",
    "areadoras": "areador",
    "areadores": "areador",
    "areados": "arear",
    "areadíssima": "areado",
    "areadíssimas": "areado",
    "areadíssimo": "areado",
    "areadíssimos": "areado",
    "areai": "arear",
    "areais": "arear",
    "areamentos": "areamento",
    "areamo": "arear",
    "areamos": "arear",
    "areando": "arear",
    "areara": "arear",
    "arearam": "arear",
    "arearas": "arear",
    "arearde": "arear",
    "areardes": "arear",
    "areare": "arear",
    "arearei": "arear",
    "areareis": "arear",
    "arearem": "arear",
    "arearemos": "arear",
    "areares": "arear",
    "arearia": "arear",
    "areariam": "arear",
    "arearias": "arear",
    "arearmo": "arear",
    "arearmos": "arear",
    "areará": "arear",
    "arearás": "arear",
    "arearão": "arear",
    "arearíamos": "arear",
    "arearíeis": "arear",
    "areasse": "arear",
    "areassem": "arear",
    "areasses": "arear",
    "areaste": "arear",
    "areastes": "arear",
    "areava": "arear",
    "areavam": "arear",
    "areavas": "arear",
    "areações": "areação",
    "arecais": "arecal",
    "arecas": "areca",
    "arecaínas": "arecaína",
    "arecinas": "arecina",
    "arecínea": "arecíneo",
    "arecíneas": "arecíneo",
    "arecíneos": "arecíneo",
    "areei": "arear",
    "areeiros": "areeiro",
    "areeis": "arear",
    "areemo": "arear",
    "areemos": "arear",
    "areenta": "areento",
    "areentas": "areento",
    "areentos": "areento",
    "arefacções": "arefacção",
    "arefeçada": "arefeçado",
    "arefeçadas": "arefeçado",
    "arefeçados": "arefeçado",
    "arei": "arar",
    "areia": "arear",
    "areiam": "arear",
    "areias": "areia",
    "areie": "arear",
    "areiem": "arear",
    "areies": "arear",
    "areinhos": "areinho",
    "areio": "arear",
    "areis": "arar",
    "areja": "arejar",
    "arejada": "arejar",
    "arejadas": "arejar",
    "arejado": "arejar",
    "arejadora": "arejador",
    "arejadoras": "arejador",
    "arejadores": "arejador",
    "arejados": "arejar",
    "arejai": "arejar",
    "arejais": "arejar",
    "arejam": "arejar",
    "arejamentos": "arejamento",
    "arejamo": "arejar",
    "arejamos": "arejar",
    "arejando": "arejar",
    "arejara": "arejar",
    "arejaram": "arejar",
    "arejaras": "arejar",
    "arejarde": "arejar",
    "arejardes": "arejar",
    "arejare": "arejar",
    "arejarei": "arejar",
    "arejareis": "arejar",
    "arejarem": "arejar",
    "arejaremos": "arejar",
    "arejares": "arejar",
    "arejaria": "arejar",
    "arejariam": "arejar",
    "arejarias": "arejar",
    "arejarmo": "arejar",
    "arejarmos": "arejar",
    "arejará": "arejar",
    "arejarás": "arejar",
    "arejarão": "arejar",
    "arejaríamos": "arejar",
    "arejaríeis": "arejar",
    "arejas": "arejar",
    "arejasse": "arejar",
    "arejassem": "arejar",
    "arejasses": "arejar",
    "arejaste": "arejar",
    "arejastes": "arejar",
    "arejava": "arejar",
    "arejavam": "arejar",
    "arejavas": "arejar",
    "areje": "arejar",
    "arejei": "arejar",
    "arejeis": "arejar",
    "arejem": "arejar",
    "arejemo": "arejar",
    "arejemos": "arejar",
    "arejes": "arejar",
    "arejo": "arejar",
    "arejos": "arejo",
    "arejou": "arejar",
    "arejá": "arejar",
    "arejámo": "arejar",
    "arejámos": "arejar",
    "arejáramo": "arejar",
    "arejáramos": "arejar",
    "arejárei": "arejar",
    "arejáreis": "arejar",
    "arejásseis": "arejar",
    "arejássemos": "arejar",
    "arejávamo": "arejar",
    "arejávamos": "arejar",
    "arejávei": "arejar",
    "arejáveis": "arejar",
    "arelhas": "arelha",
    "arem": "arar",
    "aremo": "arar",
    "aremos": "arar",
    "arenares": "arenar",
    "arenas": "arena",
    "arenata": "arenato",
    "arenatas": "arenato",
    "arenatos": "arenato",
    "arenações": "arenação",
    "arenga": "arengar",
    "arengada": "arengar",
    "arengadas": "arengar",
    "arengado": "arengar",
    "arengadora": "arengador",
    "arengadoras": "arengador",
    "arengadores": "arengador",
    "arengados": "arengar",
    "arengai": "arengar",
    "arengais": "arengar",
    "arengam": "arengar",
    "arengamo": "arengar",
    "arengamos": "arengar",
    "arengando": "arengar",
    "arengara": "arengar",
    "arengaram": "arengar",
    "arengaras": "arengar",
    "arengarde": "arengar",
    "arengardes": "arengar",
    "arengare": "arengar",
    "arengarei": "arengar",
    "arengareis": "arengar",
    "arengarem": "arengar",
    "arengaremos": "arengar",
    "arengares": "arengar",
    "arengaria": "arengar",
    "arengariam": "arengar",
    "arengarias": "arengar",
    "arengarmo": "arengar",
    "arengarmos": "arengar",
    "arengará": "arengar",
    "arengarás": "arengar",
    "arengarão": "arengar",
    "arengaríamos": "arengar",
    "arengaríeis": "arengar",
    "arengas": "arengar",
    "arengasse": "arengar",
    "arengassem": "arengar",
    "arengasses": "arengar",
    "arengaste": "arengar",
    "arengastes": "arengar",
    "arengava": "arengar",
    "arengavam": "arengar",
    "arengavas": "arengar",
    "arengo": "arengar",
    "arengou": "arengar",
    "arengue": "arengar",
    "arenguei": "arengar",
    "arengueira": "arengueiro",
    "arengueiras": "arengueiro",
    "arengueiros": "arengueiro",
    "arengueis": "arengar",
    "arenguem": "arengar",
    "arenguemo": "arengar",
    "arenguemos": "arengar",
    "arengues": "arengar",
    "arengá": "arengar",
    "arengámo": "arengar",
    "arengámos": "arengar",
    "arengáramo": "arengar",
    "arengáramos": "arengar",
    "arengárei": "arengar",
    "arengáreis": "arengar",
    "arengásseis": "arengar",
    "arengássemos": "arengar",
    "arengávamo": "arengar",
    "arengávamos": "arengar",
    "arengávei": "arengar",
    "arengáveis": "arengar",
    "areniformes": "areniforme",
    "arenisca": "arenisco",
    "areniscas": "arenisco",
    "areniscos": "arenisco",
    "arenitos": "arenito",
    "arenonaves": "arenonave",
    "arenosa": "arenoso",
    "arenosas": "arenoso",
    "arenosos": "arenoso",
    "arenqueiros": "arenqueiro",
    "arenques": "arenque",
    "arensa": "arensar",
    "arensada": "arensar",
    "arensadas": "arensar",
    "arensado": "arensar",
    "arensados": "arensar",
    "arensai": "arensar",
    "arensais": "arensar",
    "arensam": "arensar",
    "arensamo": "arensar",
    "arensamos": "arensar",
    "arensando": "arensar",
    "arensara": "arensar",
    "arensaram": "arensar",
    "arensaras": "arensar",
    "arensardes": "arensar",
    "arensarei": "arensar",
    "arensareis": "arensar",
    "arensarem": "arensar",
    "arensaremos": "arensar",
    "arensares": "arensar",
    "arensaria": "arensar",
    "arensariam": "arensar",
    "arensarias": "arensar",
    "arensarmo": "arensar",
    "arensarmos": "arensar",
    "arensará": "arensar",
    "arensarás": "arensar",
    "arensarão": "arensar",
    "arensaríamos": "arensar",
    "arensaríeis": "arensar",
    "arensas": "arensar",
    "arensasse": "arensar",
    "arensassem": "arensar",
    "arensasses": "arensar",
    "arensaste": "arensar",
    "arensastes": "arensar",
    "arensava": "arensar",
    "arensavam": "arensar",
    "arensavas": "arensar",
    "arense": "arensar",
    "arensei": "arensar",
    "arenseis": "arensar",
    "arensem": "arensar",
    "arensemo": "arensar",
    "arensemos": "arensar",
    "arenses": "arensar",
    "arenso": "arensar",
    "arensou": "arensar",
    "arensámo": "arensar",
    "arensámos": "arensar",
    "arensáramo": "arensar",
    "arensáramos": "arensar",
    "arensáreis": "arensar",
    "arensásseis": "arensar",
    "arensássemos": "arensar",
    "arensávamo": "arensar",
    "arensávamos": "arensar",
    "arensáveis": "arensar",
    "arenulácea": "arenuláceo",
    "arenuláceas": "arenuláceo",
    "arenuláceos": "arenuláceo",
    "arenácea": "arenáceo",
    "arenáceas": "arenáceo",
    "arenáceos": "arenáceo",
    "arenária": "arenário",
    "arenárias": "arenário",
    "arenários": "arenário",
    "arenícolas": "arenícola",
    "arenífera": "arenífero",
    "areníferas": "arenífero",
    "areníferos": "arenífero",
    "areolada": "areolado",
    "areoladas": "areolado",
    "areolados": "areolado",
    "areolações": "areolação",
    "areolites": "areolite",
    "areometrias": "areometria",
    "areométrica": "areométrico",
    "areométricas": "areométrico",
    "areométricos": "areométrico",
    "areopagitas": "areopagita",
    "areosa": "areoso",
    "areosas": "areoso",
    "areosos": "areoso",
    "areotectónicas": "areotectónica",
    "areou": "arear",
    "arequeiras": "arequeira",
    "ares": "are",
    "arestada": "arestado",
    "arestadas": "arestado",
    "arestados": "arestado",
    "arestais": "arestal",
    "arestas": "aresta",
    "aresteiros": "aresteiro",
    "arestelada": "arestelado",
    "aresteladas": "arestelado",
    "arestelados": "arestelado",
    "arestiza": "arestizar",
    "arestizada": "arestizar",
    "arestizadas": "arestizar",
    "arestizado": "arestizar",
    "arestizados": "arestizar",
    "arestizai": "arestizar",
    "arestizais": "arestizar",
    "arestizam": "arestizar",
    "arestizamo": "arestizar",
    "arestizamos": "arestizar",
    "arestizando": "arestizar",
    "arestizara": "arestizar",
    "arestizaram": "arestizar",
    "arestizaras": "arestizar",
    "arestizarde": "arestizar",
    "arestizardes": "arestizar",
    "arestizare": "arestizar",
    "arestizarei": "arestizar",
    "arestizareis": "arestizar",
    "arestizarem": "arestizar",
    "arestizaremos": "arestizar",
    "arestizares": "arestizar",
    "arestizaria": "arestizar",
    "arestizariam": "arestizar",
    "arestizarias": "arestizar",
    "arestizarmo": "arestizar",
    "arestizarmos": "arestizar",
    "arestizará": "arestizar",
    "arestizarás": "arestizar",
    "arestizarão": "arestizar",
    "arestizaríamos": "arestizar",
    "arestizaríeis": "arestizar",
    "arestizas": "arestizar",
    "arestizasse": "arestizar",
    "arestizassem": "arestizar",
    "arestizasses": "arestizar",
    "arestizaste": "arestizar",
    "arestizastes": "arestizar",
    "arestizava": "arestizar",
    "arestizavam": "arestizar",
    "arestizavas": "arestizar",
    "arestize": "arestizar",
    "arestizei": "arestizar",
    "arestizeis": "arestizar",
    "arestizem": "arestizar",
    "arestizemo": "arestizar",
    "arestizemos": "arestizar",
    "arestizes": "arestizar",
    "arestizo": "arestizar",
    "arestizou": "arestizar",
    "arestizá": "arestizar",
    "arestizámo": "arestizar",
    "arestizámos": "arestizar",
    "arestizáramo": "arestizar",
    "arestizáramos": "arestizar",
    "arestizárei": "arestizar",
    "arestizáreis": "arestizar",
    "arestizásseis": "arestizar",
    "arestizássemos": "arestizar",
    "arestizávamo": "arestizar",
    "arestizávamos": "arestizar",
    "arestizávei": "arestizar",
    "arestizáveis": "arestizar",
    "arestos": "aresto",
    "arestosa": "arestoso",
    "arestosas": "arestoso",
    "arestosos": "arestoso",
    "arestuda": "arestudo",
    "arestudas": "arestudo",
    "arestudos": "arestudo",
    "aretologias": "aretologia",
    "aretológica": "aretológico",
    "aretológicas": "aretológico",
    "aretológicos": "aretológico",
    "aretóloga": "aretólogo",
    "aretólogas": "aretólogo",
    "aretólogos": "aretólogo",
    "areá": "arear",
    "areámo": "arear",
    "areámos": "arear",
    "areáramo": "arear",
    "areáramos": "arear",
    "areárei": "arear",
    "areáreis": "arear",
    "areásseis": "arear",
    "areássemos": "arear",
    "areávamo": "arear",
    "areávamos": "arear",
    "areávei": "arear",
    "areáveis": "arear",
    "areísca": "areísco",
    "areíscas": "areísco",
    "areíscos": "areísco",
    "areómetros": "areómetro",
    "areópagos": "areópago",
    "areões": "areão",
    "arfa": "arfar",
    "arfada": "arfar",
    "arfadas": "arfar",
    "arfado": "arfar",
    "arfados": "arfar",
    "arfaduras": "arfadura",
    "arfagens": "arfagem",
    "arfai": "arfar",
    "arfais": "arfar",
    "arfam": "arfar",
    "arfamo": "arfar",
    "arfamos": "arfar",
    "arfando": "arfar",
    "arfantes": "arfante",
    "arfara": "arfar",
    "arfaram": "arfar",
    "arfaras": "arfar",
    "arfardes": "arfar",
    "arfarei": "arfar",
    "arfareis": "arfar",
    "arfarem": "arfar",
    "arfaremos": "arfar",
    "arfares": "arfar",
    "arfaria": "arfar",
    "arfariam": "arfar",
    "arfarias": "arfar",
    "arfarmo": "arfar",
    "arfarmos": "arfar",
    "arfará": "arfar",
    "arfarás": "arfar",
    "arfarão": "arfar",
    "arfaríamos": "arfar",
    "arfaríeis": "arfar",
    "arfas": "arfar",
    "arfasse": "arfar",
    "arfassem": "arfar",
    "arfasses": "arfar",
    "arfaste": "arfar",
    "arfastes": "arfar",
    "arfava": "arfar",
    "arfavam": "arfar",
    "arfavas": "arfar",
    "arfe": "arfar",
    "arfei": "arfar",
    "arfeis": "arfar",
    "arfem": "arfar",
    "arfemo": "arfar",
    "arfemos": "arfar",
    "arfes": "arfar",
    "arfo": "arfar",
    "arfou": "arfar",
    "arfámo": "arfar",
    "arfámos": "arfar",
    "arfáramo": "arfar",
    "arfáramos": "arfar",
    "arfáreis": "arfar",
    "arfásseis": "arfar",
    "arfássemos": "arfar",
    "arfávamo": "arfar",
    "arfávamos": "arfar",
    "arfáveis": "arfar",
    "argalhas": "argalha",
    "argamassa": "argamassar",
    "argamassada": "argamassar",
    "argamassadas": "argamassar",
    "argamassado": "argamassar",
    "argamassadora": "argamassador",
    "argamassadoras": "argamassador",
    "argamassadores": "argamassador",
    "argamassados": "argamassar",
    "argamassai": "argamassar",
    "argamassais": "argamassar",
    "argamassam": "argamassar",
    "argamassamo": "argamassar",
    "argamassamos": "argamassar",
    "argamassando": "argamassar",
    "argamassara": "argamassar",
    "argamassaram": "argamassar",
    "argamassaras": "argamassar",
    "argamassarde": "argamassar",
    "argamassardes": "argamassar",
    "argamassare": "argamassar",
    "argamassarei": "argamassar",
    "argamassareis": "argamassar",
    "argamassarem": "argamassar",
    "argamassaremos": "argamassar",
    "argamassares": "argamassar",
    "argamassaria": "argamassar",
    "argamassariam": "argamassar",
    "argamassarias": "argamassar",
    "argamassarmo": "argamassar",
    "argamassarmos": "argamassar",
    "argamassará": "argamassar",
    "argamassarás": "argamassar",
    "argamassarão": "argamassar",
    "argamassaríamos": "argamassar",
    "argamassaríeis": "argamassar",
    "argamassas": "argamassar",
    "argamassasse": "argamassar",
    "argamassassem": "argamassar",
    "argamassasses": "argamassar",
    "argamassaste": "argamassar",
    "argamassastes": "argamassar",
    "argamassava": "argamassar",
    "argamassavam": "argamassar",
    "argamassavas": "argamassar",
    "argamasse": "argamassar",
    "argamassei": "argamassar",
    "argamasseis": "argamassar",
    "argamassem": "argamassar",
    "argamassemo": "argamassar",
    "argamassemos": "argamassar",
    "argamasses": "argamassar",
    "argamasso": "argamassar",
    "argamassou": "argamassar",
    "argamassá": "argamassar",
    "argamassámo": "argamassar",
    "argamassámos": "argamassar",
    "argamassáramo": "argamassar",
    "argamassáramos": "argamassar",
    "argamassárei": "argamassar",
    "argamassáreis": "argamassar",
    "argamassásseis": "argamassar",
    "argamassássemos": "argamassar",
    "argamassávamo": "argamassar",
    "argamassávamos": "argamassar",
    "argamassávei": "argamassar",
    "argamassáveis": "argamassar",
    "arganazes": "arganaz",
    "arganaças": "arganaça",
    "arganis": "arganil",
    "arganos": "argano",
    "arganéis": "arganel",
    "arganéus": "arganéu",
    "argas": "arga",
    "argaus": "argau",
    "argaçeiros": "argaçeiro",
    "argaços": "argaço",
    "argeis": "argel",
    "argelina": "argelino",
    "argelinas": "argelino",
    "argelinos": "argelino",
    "argenta": "argentar",
    "argentada": "argentar",
    "argentadas": "argentar",
    "argentado": "argentar",
    "argentadora": "argentador",
    "argentadoras": "argentador",
    "argentadores": "argentador",
    "argentados": "argentar",
    "argentai": "argentar",
    "argentais": "argentar",
    "argentam": "argentar",
    "argentaminas": "argentamina",
    "argentamo": "argentar",
    "argentamos": "argentar",
    "argentando": "argentar",
    "argentara": "argentar",
    "argentaram": "argentar",
    "argentaras": "argentar",
    "argentarde": "argentar",
    "argentardes": "argentar",
    "argentare": "argentar",
    "argentarei": "argentar",
    "argentareis": "argentar",
    "argentarem": "argentar",
    "argentaremos": "argentar",
    "argentares": "argentar",
    "argentaria": "argentar",
    "argentariam": "argentar",
    "argentarias": "argentaria",
    "argentarismos": "argentarismo",
    "argentarmo": "argentar",
    "argentarmos": "argentar",
    "argentará": "argentar",
    "argentarás": "argentar",
    "argentarão": "argentar",
    "argentaríamos": "argentar",
    "argentaríeis": "argentar",
    "argentas": "argentar",
    "argentasse": "argentar",
    "argentassem": "argentar",
    "argentasses": "argentar",
    "argentaste": "argentar",
    "argentastes": "argentar",
    "argentatos": "argentato",
    "argentava": "argentar",
    "argentavam": "argentar",
    "argentavas": "argentar",
    "argente": "argentar",
    "argentei": "argentar",
    "argenteis": "argentar",
    "argentem": "argentar",
    "argentemo": "argentar",
    "argentemos": "argentar",
    "argentes": "argentar",
    "argenticerúlea": "argenticerúleo",
    "argenticerúleas": "argenticerúleo",
    "argenticerúleos": "argenticerúleo",
    "argenticérula": "argenticérulo",
    "argenticérulas": "argenticérulo",
    "argenticérulos": "argenticérulo",
    "argentifólia": "argentifólio",
    "argentifólias": "argentifólio",
    "argentifólios": "argentifólio",
    "argentina": "argentino",
    "argentinas": "argentino",
    "argentinos": "argentino",
    "argentitas": "argentita",
    "argentites": "argentite",
    "argento": "argentar",
    "argentou": "argentar",
    "argentá": "argentar",
    "argentámo": "argentar",
    "argentámos": "argentar",
    "argentáramo": "argentar",
    "argentáramos": "argentar",
    "argentárei": "argentar",
    "argentáreis": "argentar",
    "argentária": "argentário",
    "argentárias": "argentário",
    "argentários": "argentário",
    "argentásseis": "argentar",
    "argentássemos": "argentar",
    "argentávamo": "argentar",
    "argentávamos": "argentar",
    "argentávei": "argentar",
    "argentáveis": "argentar",
    "argentífera": "argentífero",
    "argentíferas": "argentífero",
    "argentíferos": "argentífero",
    "argentífica": "argentífico",
    "argentíficas": "argentífico",
    "argentíficos": "argentífico",
    "argentões": "argentão",
    "argilas": "argila",
    "argileiras": "argileira",
    "argiliformes": "argiliforme",
    "argilites": "argilite",
    "argilofagias": "argilofagia",
    "argilosa": "argiloso",
    "argilosas": "argiloso",
    "argilosos": "argiloso",
    "argilácea": "argiláceo",
    "argiláceas": "argiláceo",
    "argiláceos": "argiláceo",
    "argilífera": "argilífero",
    "argilíferas": "argilífero",
    "argilíferos": "argilífero",
    "argilófaga": "argilófago",
    "argilófagas": "argilófago",
    "argilófagos": "argilófago",
    "argilóides": "argilóide",
    "argilólitos": "argilólito",
    "argirismos": "argirismo",
    "argirites": "argirite",
    "argiroses": "argirose",
    "argiróis": "argirol",
    "argirólitos": "argirólito",
    "argiva": "argivo",
    "argivas": "argivo",
    "argivos": "argivo",
    "argoladas": "argolada",
    "argolagens": "argolagem",
    "argolas": "argola",
    "argolaços": "argolaço",
    "argoleira": "argoleiro",
    "argoleiras": "argoleiro",
    "argoleiros": "argoleiro",
    "argolinha": "argola",
    "argolinhas": "argola",
    "argolistas": "argolista",
    "argolita": "argola",
    "argolitas": "argola",
    "argolões": "argolão",
    "argonautas": "argonauta",
    "argoninas": "argonina",
    "argonáutica": "argonáutico",
    "argonáuticas": "argonáutico",
    "argonáuticos": "argonáutico",
    "argos": "argo",
    "argua": "arguir",
    "arguais": "arguir",
    "arguam": "arguir",
    "arguamo": "arguir",
    "arguamos": "arguir",
    "arguas": "arguir",
    "arguciosa": "argucioso",
    "arguciosas": "argucioso",
    "arguciosos": "argucioso",
    "arguciosíssima": "argucioso",
    "arguciosíssimas": "argucioso",
    "arguciosíssimo": "argucioso",
    "arguciosíssimos": "argucioso",
    "argueirices": "argueirice",
    "argueirinhas": "argueirinha",
    "argueiros": "argueiro",
    "arguentes": "arguente",
    "argui": "arguir",
    "arguia": "arguir",
    "arguiam": "arguir",
    "arguias": "arguir",
    "arguida": "arguir",
    "arguidas": "arguir",
    "arguido": "arguir",
    "arguidora": "arguidor",
    "arguidoras": "arguidor",
    "arguidores": "arguidor",
    "arguidos": "arguir",
    "arguimo": "arguir",
    "arguimos": "arguir",
    "arguindo": "arguir",
    "arguira": "arguir",
    "arguiram": "arguir",
    "arguiras": "arguir",
    "arguirde": "arguir",
    "arguirdes": "arguir",
    "arguire": "arguir",
    "arguirei": "arguir",
    "arguireis": "arguir",
    "arguirem": "arguir",
    "arguiremos": "arguir",
    "arguires": "arguir",
    "arguiria": "arguir",
    "arguiriam": "arguir",
    "arguirias": "arguir",
    "arguirmo": "arguir",
    "arguirmos": "arguir",
    "arguirá": "arguir",
    "arguirás": "arguir",
    "arguirão": "arguir",
    "arguiríamos": "arguir",
    "arguiríeis": "arguir",
    "arguis": "arguir",
    "arguisse": "arguir",
    "arguissem": "arguir",
    "arguisses": "arguir",
    "arguiste": "arguir",
    "arguistes": "arguir",
    "arguitiva": "arguitivo",
    "arguitivas": "arguitivo",
    "arguitivos": "arguitivo",
    "arguiu": "arguir",
    "arguiços": "arguiço",
    "arguições": "arguição",
    "argumenta": "argumentar",
    "argumentada": "argumentar",
    "argumentadas": "argumentar",
    "argumentado": "argumentar",
    "argumentadora": "argumentador",
    "argumentadoras": "argumentador",
    "argumentadores": "argumentador",
    "argumentados": "argumentar",
    "argumentai": "argumentar",
    "argumentais": "argumentar",
    "argumentam": "argumentar",
    "argumentamo": "argumentar",
    "argumentamos": "argumentar",
    "argumentando": "argumentar",
    "argumentantes": "argumentante",
    "argumentara": "argumentar",
    "argumentaram": "argumentar",
    "argumentaras": "argumentar",
    "argumentarde": "argumentar",
    "argumentardes": "argumentar",
    "argumentare": "argumentar",
    "argumentarei": "argumentar",
    "argumentareis": "argumentar",
    "argumentarem": "argumentar",
    "argumentaremos": "argumentar",
    "argumentares": "argumentar",
    "argumentaria": "argumentar",
    "argumentariam": "argumentar",
    "argumentarias": "argumentar",
    "argumentarmo": "argumentar",
    "argumentarmos": "argumentar",
    "argumentará": "argumentar",
    "argumentarás": "argumentar",
    "argumentarão": "argumentar",
    "argumentaríamos": "argumentar",
    "argumentaríeis": "argumentar",
    "argumentas": "argumentar",
    "argumentasse": "argumentar",
    "argumentassem": "argumentar",
    "argumentasses": "argumentar",
    "argumentaste": "argumentar",
    "argumentastes": "argumentar",
    "argumentativa": "argumentativo",
    "argumentativas": "argumentativo",
    "argumentativos": "argumentativo",
    "argumentava": "argumentar",
    "argumentavam": "argumentar",
    "argumentavas": "argumentar",
    "argumentações": "argumentação",
    "argumente": "argumentar",
    "argumentei": "argumentar",
    "argumenteis": "argumentar",
    "argumentem": "argumentar",
    "argumentemo": "argumentar",
    "argumentemos": "argumentar",
    "argumentes": "argumentar",
    "argumentilhos": "argumentilho",
    "argumentistas": "argumentista",
    "argumento": "argumentar",
    "argumentos": "argumento",
    "argumentou": "argumentar",
    "argumentá": "argumentar",
    "argumentámo": "argumentar",
    "argumentámos": "argumentar",
    "argumentáramo": "argumentar",
    "argumentáramos": "argumentar",
    "argumentárei": "argumentar",
    "argumentáreis": "argumentar",
    "argumentásseis": "argumentar",
    "argumentássemos": "argumentar",
    "argumentávamo": "argumentar",
    "argumentávamos": "argumentar",
    "argumentávei": "argumentar",
    "argumentáveis": "argumentável",
    "arguo": "arguir",
    "arguta": "arguto",
    "argutas": "arguto",
    "argutos": "arguto",
    "argutíssima": "arguto",
    "argutíssimas": "arguto",
    "argutíssimo": "arguto",
    "argutíssimos": "arguto",
    "arguíamo": "arguir",
    "arguíamos": "arguir",
    "arguíei": "arguir",
    "arguíeis": "arguir",
    "arguíramo": "arguir",
    "arguíramos": "arguir",
    "arguírei": "arguir",
    "arguíreis": "arguir",
    "arguísseis": "arguir",
    "arguíssemos": "arguir",
    "arguíveis": "arguível",
    "argânias": "argânia",
    "argêntea": "argênteo",
    "argênteas": "argênteo",
    "argênteos": "argênteo",
    "argêntica": "argêntico",
    "argênticas": "argêntico",
    "argênticos": "argêntico",
    "argóis": "argol",
    "argões": "argão",
    "argúcias": "argúcia",
    "argúem": "arguir",
    "argúi": "arguir",
    "argúis": "arguir",
    "ariana": "ariano",
    "arianas": "ariano",
    "arianismos": "arianismo",
    "arianiza": "arianizar",
    "arianizada": "arianizar",
    "arianizadas": "arianizar",
    "arianizado": "arianizar",
    "arianizados": "arianizar",
    "arianizai": "arianizar",
    "arianizais": "arianizar",
    "arianizam": "arianizar",
    "arianizamo": "arianizar",
    "arianizamos": "arianizar",
    "arianizando": "arianizar",
    "arianizara": "arianizar",
    "arianizaram": "arianizar",
    "arianizaras": "arianizar",
    "arianizarde": "arianizar",
    "arianizardes": "arianizar",
    "arianizare": "arianizar",
    "arianizarei": "arianizar",
    "arianizareis": "arianizar",
    "arianizarem": "arianizar",
    "arianizaremos": "arianizar",
    "arianizares": "arianizar",
    "arianizaria": "arianizar",
    "arianizariam": "arianizar",
    "arianizarias": "arianizar",
    "arianizarmo": "arianizar",
    "arianizarmos": "arianizar",
    "arianizará": "arianizar",
    "arianizarás": "arianizar",
    "arianizarão": "arianizar",
    "arianizaríamos": "arianizar",
    "arianizaríeis": "arianizar",
    "arianizas": "arianizar",
    "arianizasse": "arianizar",
    "arianizassem": "arianizar",
    "arianizasses": "arianizar",
    "arianizaste": "arianizar",
    "arianizastes": "arianizar",
    "arianizava": "arianizar",
    "arianizavam": "arianizar",
    "arianizavas": "arianizar",
    "arianize": "arianizar",
    "arianizei": "arianizar",
    "arianizeis": "arianizar",
    "arianizem": "arianizar",
    "arianizemo": "arianizar",
    "arianizemos": "arianizar",
    "arianizes": "arianizar",
    "arianizo": "arianizar",
    "arianizou": "arianizar",
    "arianizá": "arianizar",
    "arianizámo": "arianizar",
    "arianizámos": "arianizar",
    "arianizáramo": "arianizar",
    "arianizáramos": "arianizar",
    "arianizárei": "arianizar",
    "arianizáreis": "arianizar",
    "arianizásseis": "arianizar",
    "arianizássemos": "arianizar",
    "arianizávamo": "arianizar",
    "arianizávamos": "arianizar",
    "arianizávei": "arianizar",
    "arianizáveis": "arianizar",
    "arianos": "ariano",
    "ariciídea": "ariciídeo",
    "ariciídeas": "ariciídeo",
    "ariciídeos": "ariciídeo",
    "aricás": "aricá",
    "aricíidas": "aricíida",
    "aricínea": "aricíneo",
    "aricíneas": "aricíneo",
    "aricíneos": "aricíneo",
    "aridifica": "aridificar",
    "aridificada": "aridificar",
    "aridificadas": "aridificar",
    "aridificado": "aridificar",
    "aridificados": "aridificar",
    "aridificai": "aridificar",
    "aridificais": "aridificar",
    "aridificam": "aridificar",
    "aridificamo": "aridificar",
    "aridificamos": "aridificar",
    "aridificando": "aridificar",
    "aridificara": "aridificar",
    "aridificaram": "aridificar",
    "aridificaras": "aridificar",
    "aridificarde": "aridificar",
    "aridificardes": "aridificar",
    "aridificare": "aridificar",
    "aridificarei": "aridificar",
    "aridificareis": "aridificar",
    "aridificarem": "aridificar",
    "aridificaremos": "aridificar",
    "aridificares": "aridificar",
    "aridificaria": "aridificar",
    "aridificariam": "aridificar",
    "aridificarias": "aridificar",
    "aridificarmo": "aridificar",
    "aridificarmos": "aridificar",
    "aridificará": "aridificar",
    "aridificarás": "aridificar",
    "aridificarão": "aridificar",
    "aridificaríamos": "aridificar",
    "aridificaríeis": "aridificar",
    "aridificas": "aridificar",
    "aridificasse": "aridificar",
    "aridificassem": "aridificar",
    "aridificasses": "aridificar",
    "aridificaste": "aridificar",
    "aridificastes": "aridificar",
    "aridificava": "aridificar",
    "aridificavam": "aridificar",
    "aridificavas": "aridificar",
    "aridifico": "aridificar",
    "aridificou": "aridificar",
    "aridificá": "aridificar",
    "aridificámo": "aridificar",
    "aridificámos": "aridificar",
    "aridificáramo": "aridificar",
    "aridificáramos": "aridificar",
    "aridificárei": "aridificar",
    "aridificáreis": "aridificar",
    "aridificásseis": "aridificar",
    "aridificássemos": "aridificar",
    "aridificávamo": "aridificar",
    "aridificávamos": "aridificar",
    "aridificávei": "aridificar",
    "aridificáveis": "aridificar",
    "aridifique": "aridificar",
    "aridifiquei": "aridificar",
    "aridifiqueis": "aridificar",
    "aridifiquem": "aridificar",
    "aridifiquemo": "aridificar",
    "aridifiquemos": "aridificar",
    "aridifiques": "aridificar",
    "aridíssima": "árido",
    "aridíssimas": "árido",
    "aridíssimo": "árido",
    "aridíssimos": "árido",
    "arietas": "arieta",
    "arietes": "ariete",
    "arietina": "arietino",
    "arietinas": "arietino",
    "arietinos": "arietino",
    "arilada": "arilado",
    "ariladas": "arilado",
    "arilados": "arilado",
    "arilos": "arilo",
    "arimãs": "arimã",
    "arincus": "arincu",
    "aringas": "aringa",
    "arinques": "arinque",
    "arintas": "arinta",
    "arintos": "arinto",
    "ariosos": "arioso",
    "aripeiros": "aripeiro",
    "aripos": "aripo",
    "ariquenas": "ariquena",
    "ariranhas": "ariranha",
    "arisca": "arisco",
    "ariscas": "arisco",
    "ariscos": "arisco",
    "aristada": "aristado",
    "aristadas": "aristado",
    "aristados": "aristado",
    "aristarcos": "aristarco",
    "aristas": "arista",
    "aristiformes": "aristiforme",
    "aristocracias": "aristocracia",
    "aristocracismos": "aristocracismo",
    "aristocratas": "aristocrata",
    "aristocratismos": "aristocratismo",
    "aristocratiza": "aristocratizar",
    "aristocratizada": "aristocratizar",
    "aristocratizadas": "aristocratizar",
    "aristocratizado": "aristocratizar",
    "aristocratizados": "aristocratizar",
    "aristocratizai": "aristocratizar",
    "aristocratizais": "aristocratizar",
    "aristocratizam": "aristocratizar",
    "aristocratizamo": "aristocratizar",
    "aristocratizamos": "aristocratizar",
    "aristocratizando": "aristocratizar",
    "aristocratizara": "aristocratizar",
    "aristocratizaram": "aristocratizar",
    "aristocratizaras": "aristocratizar",
    "aristocratizarde": "aristocratizar",
    "aristocratizardes": "aristocratizar",
    "aristocratizare": "aristocratizar",
    "aristocratizarei": "aristocratizar",
    "aristocratizareis": "aristocratizar",
    "aristocratizarem": "aristocratizar",
    "aristocratizaremos": "aristocratizar",
    "aristocratizares": "aristocratizar",
    "aristocratizaria": "aristocratizar",
    "aristocratizariam": "aristocratizar",
    "aristocratizarias": "aristocratizar",
    "aristocratizarmo": "aristocratizar",
    "aristocratizarmos": "aristocratizar",
    "aristocratizará": "aristocratizar",
    "aristocratizarás": "aristocratizar",
    "aristocratizarão": "aristocratizar",
    "aristocratizaríamos": "aristocratizar",
    "aristocratizaríeis": "aristocratizar",
    "aristocratizas": "aristocratizar",
    "aristocratizasse": "aristocratizar",
    "aristocratizassem": "aristocratizar",
    "aristocratizasses": "aristocratizar",
    "aristocratizaste": "aristocratizar",
    "aristocratizastes": "aristocratizar",
    "aristocratizava": "aristocratizar",
    "aristocratizavam": "aristocratizar",
    "aristocratizavas": "aristocratizar",
    "aristocratizações": "aristocratização",
    "aristocratize": "aristocratizar",
    "aristocratizei": "aristocratizar",
    "aristocratizeis": "aristocratizar",
    "aristocratizem": "aristocratizar",
    "aristocratizemo": "aristocratizar",
    "aristocratizemos": "aristocratizar",
    "aristocratizes": "aristocratizar",
    "aristocratizo": "aristocratizar",
    "aristocratizou": "aristocratizar",
    "aristocratizá": "aristocratizar",
    "aristocratizámo": "aristocratizar",
    "aristocratizámos": "aristocratizar",
    "aristocratizáramo": "aristocratizar",
    "aristocratizáramos": "aristocratizar",
    "aristocratizárei": "aristocratizar",
    "aristocratizáreis": "aristocratizar",
    "aristocratizásseis": "aristocratizar",
    "aristocratizássemos": "aristocratizar",
    "aristocratizávamo": "aristocratizar",
    "aristocratizávamos": "aristocratizar",
    "aristocratizávei": "aristocratizar",
    "aristocratizáveis": "aristocratizar",
    "aristocrática": "aristocrático",
    "aristocráticas": "aristocrático",
    "aristocráticos": "aristocrático",
    "aristodemocracias": "aristodemocracia",
    "aristolóquias": "aristolóquia",
    "aristosa": "aristoso",
    "aristosas": "aristoso",
    "aristosos": "aristoso",
    "aristotelismos": "aristotelismo",
    "aristotélica": "aristotélico",
    "aristotélicas": "aristotélico",
    "aristotélicos": "aristotélico",
    "aritenoideia": "aritenoideu",
    "aritenoideias": "aritenoideu",
    "aritenoideus": "aritenoideu",
    "aritenoidites": "aritenoidite",
    "aritenóidea": "aritenóideo",
    "aritenóideas": "aritenóideo",
    "aritenóideos": "aritenóideo",
    "aritenóides": "aritenóide",
    "aritmancias": "aritmancia",
    "aritmantes": "aritmante",
    "aritmetógrafos": "aritmetógrafo",
    "aritmografias": "aritmografia",
    "aritmologias": "aritmologia",
    "aritmomancias": "aritmomancia",
    "aritmomantes": "aritmomante",
    "aritmometrias": "aritmometria",
    "aritmomântica": "aritmomântico",
    "aritmomânticas": "aritmomântico",
    "aritmomânticos": "aritmomântico",
    "aritmométrica": "aritmométrico",
    "aritmométricas": "aritmométrico",
    "aritmométricos": "aritmométrico",
    "aritmântica": "aritmântico",
    "aritmânticas": "aritmântico",
    "aritmânticos": "aritmântico",
    "aritmética": "aritmético",
    "aritméticas": "aritmético",
    "aritméticos": "aritmético",
    "aritmógrafos": "aritmógrafo",
    "aritmómetros": "aritmómetro",
    "arivologistas": "arivologista",
    "arjozes": "arjoz",
    "arjunças": "arjunça",
    "arjões": "arjão",
    "arlequina": "arlequim",
    "arlequinadas": "arlequinada",
    "arlequinas": "arlequina",
    "arlequins": "arlequim",
    "arlequínea": "arlequíneo",
    "arlequíneas": "arlequíneo",
    "arlequíneos": "arlequíneo",
    "arlesiana": "arlesiano",
    "arlesianas": "arlesiano",
    "arlesianos": "arlesiano",
    "arma": "armar",
    "armada": "armar",
    "armadas": "armar",
    "armadilha": "armadilhar",
    "armadilhada": "armadilhar",
    "armadilhadas": "armadilhar",
    "armadilhado": "armadilhar",
    "armadilhados": "armadilhar",
    "armadilhai": "armadilhar",
    "armadilhais": "armadilhar",
    "armadilham": "armadilhar",
    "armadilhamo": "armadilhar",
    "armadilhamos": "armadilhar",
    "armadilhando": "armadilhar",
    "armadilhara": "armadilhar",
    "armadilharam": "armadilhar",
    "armadilharas": "armadilhar",
    "armadilharde": "armadilhar",
    "armadilhardes": "armadilhar",
    "armadilhare": "armadilhar",
    "armadilharei": "armadilhar",
    "armadilhareis": "armadilhar",
    "armadilharem": "armadilhar",
    "armadilharemos": "armadilhar",
    "armadilhares": "armadilhar",
    "armadilharia": "armadilhar",
    "armadilhariam": "armadilhar",
    "armadilharias": "armadilhar",
    "armadilharmo": "armadilhar",
    "armadilharmos": "armadilhar",
    "armadilhará": "armadilhar",
    "armadilharás": "armadilhar",
    "armadilharão": "armadilhar",
    "armadilharíamos": "armadilhar",
    "armadilharíeis": "armadilhar",
    "armadilhas": "armadilhar",
    "armadilhasse": "armadilhar",
    "armadilhassem": "armadilhar",
    "armadilhasses": "armadilhar",
    "armadilhaste": "armadilhar",
    "armadilhastes": "armadilhar",
    "armadilhava": "armadilhar",
    "armadilhavam": "armadilhar",
    "armadilhavas": "armadilhar",
    "armadilhe": "armadilhar",
    "armadilhei": "armadilhar",
    "armadilheis": "armadilhar",
    "armadilhem": "armadilhar",
    "armadilhemo": "armadilhar",
    "armadilhemos": "armadilhar",
    "armadilhes": "armadilhar",
    "armadilho": "armadilhar",
    "armadilhos": "armadilho",
    "armadilhou": "armadilhar",
    "armadilhá": "armadilhar",
    "armadilhámo": "armadilhar",
    "armadilhámos": "armadilhar",
    "armadilháramo": "armadilhar",
    "armadilháramos": "armadilhar",
    "armadilhárei": "armadilhar",
    "armadilháreis": "armadilhar",
    "armadilhásseis": "armadilhar",
    "armadilhássemos": "armadilhar",
    "armadilhávamo": "armadilhar",
    "armadilhávamos": "armadilhar",
    "armadilhávei": "armadilhar",
    "armadilháveis": "armadilhar",
    "armado": "armar",
    "armadora": "armador",
    "armadoras": "armador",
    "armadores": "armador",
    "armados": "armar",
    "armadouras": "armadoura",
    "armaduras": "armadura",
    "armadíssima": "armado",
    "armadíssimas": "armado",
    "armadíssimo": "armado",
    "armadíssimos": "armado",
    "armai": "armar",
    "armais": "armar",
    "armam": "armar",
    "armamentismos": "armamentismo",
    "armamentistas": "armamentista",
    "armamentos": "armamento",
    "armamo": "armar",
    "armamos": "armar",
    "armando": "armar",
    "armandos": "armando",
    "armanhaques": "armanhaque",
    "armara": "armar",
    "armaram": "armar",
    "armaras": "armar",
    "armarde": "armar",
    "armardes": "armar",
    "armare": "armar",
    "armarei": "armar",
    "armareis": "armar",
    "armarem": "armar",
    "armaremos": "armar",
    "armares": "armar",
    "armaria": "armar",
    "armariam": "armar",
    "armarias": "armaria",
    "armarinheiros": "armarinheiro",
    "armarinhos": "armarinho",
    "armarmo": "armar",
    "armarmos": "armar",
    "armará": "armar",
    "armarás": "armar",
    "armarão": "armar",
    "armaríamos": "armar",
    "armaríeis": "armar",
    "armas": "armar",
    "armasse": "armar",
    "armassem": "armar",
    "armasses": "armar",
    "armaste": "armar",
    "armastes": "armar",
    "armava": "armar",
    "armavam": "armar",
    "armavas": "armar",
    "armazelos": "armazelo",
    "armazena": "armazenar",
    "armazenada": "armazenar",
    "armazenadas": "armazenar",
    "armazenado": "armazenar",
    "armazenadora": "armazenador",
    "armazenadoras": "armazenador",
    "armazenadores": "armazenador",
    "armazenados": "armazenar",
    "armazenagens": "armazenagem",
    "armazenai": "armazenar",
    "armazenais": "armazenar",
    "armazenam": "armazenar",
    "armazenamentos": "armazenamento",
    "armazenamo": "armazenar",
    "armazenamos": "armazenar",
    "armazenando": "armazenar",
    "armazenara": "armazenar",
    "armazenaram": "armazenar",
    "armazenaras": "armazenar",
    "armazenarde": "armazenar",
    "armazenardes": "armazenar",
    "armazenare": "armazenar",
    "armazenarei": "armazenar",
    "armazenareis": "armazenar",
    "armazenarem": "armazenar",
    "armazenaremos": "armazenar",
    "armazenares": "armazenar",
    "armazenaria": "armazenar",
    "armazenariam": "armazenar",
    "armazenarias": "armazenar",
    "armazenarmo": "armazenar",
    "armazenarmos": "armazenar",
    "armazenará": "armazenar",
    "armazenarás": "armazenar",
    "armazenarão": "armazenar",
    "armazenaríamos": "armazenar",
    "armazenaríeis": "armazenar",
    "armazenas": "armazenar",
    "armazenasse": "armazenar",
    "armazenassem": "armazenar",
    "armazenasses": "armazenar",
    "armazenaste": "armazenar",
    "armazenastes": "armazenar",
    "armazenava": "armazenar",
    "armazenavam": "armazenar",
    "armazenavas": "armazenar",
    "armazene": "armazenar",
    "armazenei": "armazenar",
    "armazeneira": "armazeneiro",
    "armazeneiras": "armazeneiro",
    "armazeneiros": "armazeneiro",
    "armazeneis": "armazenar",
    "armazenem": "armazenar",
    "armazenemo": "armazenar",
    "armazenemos": "armazenar",
    "armazenes": "armazenar",
    "armazenistas": "armazenista",
    "armazeno": "armazenar",
    "armazenou": "armazenar",
    "armazená": "armazenar",
    "armazenámo": "armazenar",
    "armazenámos": "armazenar",
    "armazenáramo": "armazenar",
    "armazenáramos": "armazenar",
    "armazenárei": "armazenar",
    "armazenáreis": "armazenar",
    "armazenária": "armazenário",
    "armazenárias": "armazenário",
    "armazenários": "armazenário",
    "armazenásseis": "armazenar",
    "armazenássemos": "armazenar",
    "armazenávamo": "armazenar",
    "armazenávamos": "armazenar",
    "armazenávei": "armazenar",
    "armazenáveis": "armazenar",
    "armazéns": "armazém",
    "armações": "armação",
    "arme": "armar",
    "armei": "armar",
    "armeiros": "armeiro",
    "armeis": "armar",
    "armelas": "armela",
    "armelina": "armelino",
    "armelinas": "armelino",
    "armelinos": "armelino",
    "armelos": "armelo",
    "armem": "armar",
    "armemo": "armar",
    "armemos": "armar",
    "armenhas": "armenha",
    "armentais": "armental",
    "armentios": "armentio",
    "armentos": "armento",
    "armentosa": "armentoso",
    "armentosas": "armentoso",
    "armentosos": "armentoso",
    "armes": "armar",
    "armezins": "armezim",
    "armilada": "armilado",
    "armiladas": "armilado",
    "armilados": "armilado",
    "armilares": "armilar",
    "armilas": "armila",
    "armilheiros": "armilheiro",
    "arminada": "arminado",
    "arminadas": "arminado",
    "arminados": "arminado",
    "arminhada": "arminhado",
    "arminhadas": "arminhado",
    "arminhados": "arminhado",
    "arminhos": "arminho",
    "arminiana": "arminiano",
    "arminianas": "arminiano",
    "arminianos": "arminiano",
    "arminos": "armino",
    "armins": "armim",
    "armipotentes": "armipotente",
    "armistas": "armista",
    "armistrondos": "armistrondo",
    "armistícios": "armistício",
    "armo": "armar",
    "armolas": "armola",
    "armoles": "armole",
    "armolões": "armolão",
    "armorejada": "armorejado",
    "armorejadas": "armorejado",
    "armorejados": "armorejado",
    "armoriada": "armoriado",
    "armoriadas": "armoriado",
    "armoriados": "armoriado",
    "armoriais": "armorial",
    "armorácias": "armorácia",
    "armos": "armo",
    "armou": "armar",
    "armures": "armur",
    "armuzelos": "armuzelo",
    "armá": "armar",
    "armámo": "armar",
    "armámos": "armar",
    "armáramo": "armar",
    "armáramos": "armar",
    "armárei": "armar",
    "armáreis": "armar",
    "armários": "armário",
    "armásseis": "armar",
    "armássemos": "armar",
    "armávamo": "armar",
    "armávamos": "armar",
    "armávei": "armar",
    "armáveis": "armar",
    "arménia": "arménio",
    "arménias": "arménio",
    "arménios": "arménio",
    "arméus": "arméu",
    "armífera": "armífero",
    "armíferas": "armífero",
    "armíferos": "armífero",
    "armígera": "armígero",
    "armígeras": "armígero",
    "armígeros": "armígero",
    "armíssona": "armíssono",
    "armíssonas": "armíssono",
    "armíssonos": "armíssono",
    "armões": "armão",
    "arnados": "arnado",
    "arnais": "arnal",
    "arnazes": "arnaz",
    "arneiros": "arneiro",
    "arnelas": "arnela",
    "arneses": "arnês",
    "arnicas": "arnica",
    "arnicinas": "arnicina",
    "arnilhas": "arnilha",
    "arnoglossas": "arnoglossa",
    "arnosa": "arnoso",
    "arnosas": "arnoso",
    "arnosos": "arnoso",
    "arnotos": "arnoto",
    "aro": "arar",
    "aroeiras": "aroeira",
    "aroeiros": "aroeiro",
    "aroma": "aromar",
    "aromada": "aromar",
    "aromadas": "aromar",
    "aromado": "aromar",
    "aromados": "aromar",
    "aromai": "aromar",
    "aromais": "aromar",
    "aromam": "aromar",
    "aromamo": "aromar",
    "aromamos": "aromar",
    "aromando": "aromar",
    "aromara": "aromar",
    "aromaram": "aromar",
    "aromaras": "aromar",
    "aromarde": "aromar",
    "aromardes": "aromar",
    "aromare": "aromar",
    "aromarei": "aromar",
    "aromareis": "aromar",
    "aromarem": "aromar",
    "aromaremos": "aromar",
    "aromares": "aromar",
    "aromaria": "aromar",
    "aromariam": "aromar",
    "aromarias": "aromar",
    "aromarmo": "aromar",
    "aromarmos": "aromar",
    "aromará": "aromar",
    "aromarás": "aromar",
    "aromarão": "aromar",
    "aromaríamos": "aromar",
    "aromaríeis": "aromar",
    "aromas": "aromar",
    "aromasse": "aromar",
    "aromassem": "aromar",
    "aromasses": "aromar",
    "aromaste": "aromar",
    "aromastes": "aromar",
    "aromaticidades": "aromaticidade",
    "aromatismos": "aromatismo",
    "aromatiza": "aromatizar",
    "aromatizada": "aromatizar",
    "aromatizadas": "aromatizar",
    "aromatizado": "aromatizar",
    "aromatizados": "aromatizar",
    "aromatizai": "aromatizar",
    "aromatizais": "aromatizar",
    "aromatizam": "aromatizar",
    "aromatizamo": "aromatizar",
    "aromatizamos": "aromatizar",
    "aromatizando": "aromatizar",
    "aromatizantes": "aromatizante",
    "aromatizara": "aromatizar",
    "aromatizaram": "aromatizar",
    "aromatizaras": "aromatizar",
    "aromatizarde": "aromatizar",
    "aromatizardes": "aromatizar",
    "aromatizare": "aromatizar",
    "aromatizarei": "aromatizar",
    "aromatizareis": "aromatizar",
    "aromatizarem": "aromatizar",
    "aromatizaremos": "aromatizar",
    "aromatizares": "aromatizar",
    "aromatizaria": "aromatizar",
    "aromatizariam": "aromatizar",
    "aromatizarias": "aromatizar",
    "aromatizarmo": "aromatizar",
    "aromatizarmos": "aromatizar",
    "aromatizará": "aromatizar",
    "aromatizarás": "aromatizar",
    "aromatizarão": "aromatizar",
    "aromatizaríamos": "aromatizar",
    "aromatizaríeis": "aromatizar",
    "aromatizas": "aromatizar",
    "aromatizasse": "aromatizar",
    "aromatizassem": "aromatizar",
    "aromatizasses": "aromatizar",
    "aromatizaste": "aromatizar",
    "aromatizastes": "aromatizar",
    "aromatizava": "aromatizar",
    "aromatizavam": "aromatizar",
    "aromatizavas": "aromatizar",
    "aromatizações": "aromatização",
    "aromatize": "aromatizar",
    "aromatizei": "aromatizar",
    "aromatizeis": "aromatizar",
    "aromatizem": "aromatizar",
    "aromatizemo": "aromatizar",
    "aromatizemos": "aromatizar",
    "aromatizes": "aromatizar",
    "aromatizo": "aromatizar",
    "aromatizou": "aromatizar",
    "aromatizá": "aromatizar",
    "aromatizámo": "aromatizar",
    "aromatizámos": "aromatizar",
    "aromatizáramo": "aromatizar",
    "aromatizáramos": "aromatizar",
    "aromatizárei": "aromatizar",
    "aromatizáreis": "aromatizar",
    "aromatizásseis": "aromatizar",
    "aromatizássemos": "aromatizar",
    "aromatizávamo": "aromatizar",
    "aromatizávamos": "aromatizar",
    "aromatizávei": "aromatizar",
    "aromatizáveis": "aromatizável",
    "aromatos": "aromato",
    "aromatóforos": "aromatóforo",
    "aromava": "aromar",
    "aromavam": "aromar",
    "aromavas": "aromar",
    "arome": "aromar",
    "aromei": "aromar",
    "aromeis": "aromar",
    "aromem": "aromar",
    "aromemo": "aromar",
    "aromemos": "aromar",
    "aromes": "aromar",
    "aromo": "aromar",
    "aromosa": "aromoso",
    "aromosas": "aromoso",
    "aromosos": "aromoso",
    "aromou": "aromar",
    "aromá": "aromar",
    "aromámo": "aromar",
    "aromámos": "aromar",
    "aromáramo": "aromar",
    "aromáramos": "aromar",
    "aromárei": "aromar",
    "aromáreis": "aromar",
    "aromásseis": "aromar",
    "aromássemos": "aromar",
    "aromática": "aromático",
    "aromáticas": "aromático",
    "aromáticos": "aromático",
    "aromávamo": "aromar",
    "aromávamos": "aromar",
    "aromávei": "aromar",
    "aromáveis": "aromar",
    "aros": "aro",
    "arou": "arar",
    "arouquenses": "arouquense",
    "arouquesa": "arouquês",
    "arouquesas": "arouquês",
    "arouqueses": "arouquês",
    "arozinho": "aro",
    "arozinhos": "aro",
    "arozito": "aro",
    "arozitos": "aro",
    "aroídea": "aroídeo",
    "aroídeas": "aroídeo",
    "aroídeos": "aroídeo",
    "arpa": "arpar",
    "arpada": "arpar",
    "arpadas": "arpar",
    "arpado": "arpar",
    "arpados": "arpar",
    "arpai": "arpar",
    "arpais": "arpar",
    "arpam": "arpar",
    "arpamo": "arpar",
    "arpamos": "arpar",
    "arpando": "arpar",
    "arpara": "arpar",
    "arparam": "arpar",
    "arparas": "arpar",
    "arparde": "arpar",
    "arpardes": "arpar",
    "arpare": "arpar",
    "arparei": "arpar",
    "arpareis": "arpar",
    "arparem": "arpar",
    "arparemos": "arpar",
    "arpares": "arpar",
    "arparia": "arpar",
    "arpariam": "arpar",
    "arparias": "arpar",
    "arparmo": "arpar",
    "arparmos": "arpar",
    "arpará": "arpar",
    "arparás": "arpar",
    "arparão": "arpar",
    "arparíamos": "arpar",
    "arparíeis": "arpar",
    "arpas": "arpar",
    "arpasse": "arpar",
    "arpassem": "arpar",
    "arpasses": "arpar",
    "arpaste": "arpar",
    "arpastes": "arpar",
    "arpava": "arpar",
    "arpavam": "arpar",
    "arpavas": "arpar",
    "arpe": "arpar",
    "arpei": "arpar",
    "arpeis": "arpar",
    "arpejos": "arpejo",
    "arpem": "arpar",
    "arpemo": "arpar",
    "arpemos": "arpar",
    "arpentagens": "arpentagem",
    "arpentes": "arpente",
    "arpentos": "arpento",
    "arpes": "arpar",
    "arpo": "arpar",
    "arpoadora": "arpoador",
    "arpoadoras": "arpoador",
    "arpoadores": "arpoador",
    "arpoações": "arpoação",
    "arpoeira": "arpoeiro",
    "arpoeiras": "arpoeiro",
    "arpoeiros": "arpoeiro",
    "arpou": "arpar",
    "arpá": "arpar",
    "arpámo": "arpar",
    "arpámos": "arpar",
    "arpáramo": "arpar",
    "arpáramos": "arpar",
    "arpárei": "arpar",
    "arpáreis": "arpar",
    "arpásseis": "arpar",
    "arpássemos": "arpar",
    "arpávamo": "arpar",
    "arpávamos": "arpar",
    "arpávei": "arpar",
    "arpáveis": "arpar",
    "arpéus": "arpéu",
    "arpões": "arpão",
    "arque": "arcar",
    "arqueada": "arquear",
    "arqueadas": "arquear",
    "arqueado": "arquear",
    "arqueadora": "arqueador",
    "arqueadoras": "arqueador",
    "arqueadores": "arqueador",
    "arqueados": "arquear",
    "arqueaduras": "arqueadura",
    "arqueai": "arquear",
    "arqueais": "arquear",
    "arqueamentos": "arqueamento",
    "arqueamo": "arquear",
    "arqueamos": "arquear",
    "arqueando": "arquear",
    "arqueanos": "arqueano",
    "arqueara": "arquear",
    "arquearam": "arquear",
    "arquearas": "arquear",
    "arquearde": "arquear",
    "arqueardes": "arquear",
    "arqueare": "arquear",
    "arquearei": "arquear",
    "arqueareis": "arquear",
    "arquearem": "arquear",
    "arquearemos": "arquear",
    "arqueares": "arquear",
    "arquearia": "arquear",
    "arqueariam": "arquear",
    "arquearias": "arquear",
    "arquearmo": "arquear",
    "arquearmos": "arquear",
    "arqueará": "arquear",
    "arquearás": "arquear",
    "arquearão": "arquear",
    "arquearíamos": "arquear",
    "arquearíeis": "arquear",
    "arqueasse": "arquear",
    "arqueassem": "arquear",
    "arqueasses": "arquear",
    "arqueaste": "arquear",
    "arqueastes": "arquear",
    "arqueava": "arquear",
    "arqueavam": "arquear",
    "arqueavas": "arquear",
    "arqueações": "arqueação",
    "arqueei": "arquear",
    "arqueeis": "arquear",
    "arqueemo": "arquear",
    "arqueemos": "arquear",
    "arquegoniada": "arquegoniado",
    "arquegoniadas": "arquegoniado",
    "arquegoniados": "arquegoniado",
    "arquegónios": "arquegónio",
    "arquei": "arcar",
    "arqueia": "arquear",
    "arqueiam": "arquear",
    "arqueias": "arquear",
    "arqueie": "arquear",
    "arqueiem": "arquear",
    "arqueies": "arquear",
    "arqueio": "arquear",
    "arqueios": "arqueio",
    "arqueiros": "arqueiro",
    "arqueis": "arcar",
    "arqueja": "arquejar",
    "arquejada": "arquejar",
    "arquejadas": "arquejar",
    "arquejado": "arquejar",
    "arquejados": "arquejar",
    "arquejai": "arquejar",
    "arquejais": "arquejar",
    "arquejam": "arquejar",
    "arquejamo": "arquejar",
    "arquejamos": "arquejar",
    "arquejando": "arquejar",
    "arquejantes": "arquejante",
    "arquejara": "arquejar",
    "arquejaram": "arquejar",
    "arquejaras": "arquejar",
    "arquejardes": "arquejar",
    "arquejarei": "arquejar",
    "arquejareis": "arquejar",
    "arquejarem": "arquejar",
    "arquejaremos": "arquejar",
    "arquejares": "arquejar",
    "arquejaria": "arquejar",
    "arquejariam": "arquejar",
    "arquejarias": "arquejar",
    "arquejarmo": "arquejar",
    "arquejarmos": "arquejar",
    "arquejará": "arquejar",
    "arquejarás": "arquejar",
    "arquejarão": "arquejar",
    "arquejaríamos": "arquejar",
    "arquejaríeis": "arquejar",
    "arquejas": "arquejar",
    "arquejasse": "arquejar",
    "arquejassem": "arquejar",
    "arquejasses": "arquejar",
    "arquejaste": "arquejar",
    "arquejastes": "arquejar",
    "arquejava": "arquejar",
    "arquejavam": "arquejar",
    "arquejavas": "arquejar",
    "arqueje": "arquejar",
    "arquejei": "arquejar",
    "arquejeis": "arquejar",
    "arquejem": "arquejar",
    "arquejemo": "arquejar",
    "arquejemos": "arquejar",
    "arquejes": "arquejar",
    "arquejo": "arquejar",
    "arquejos": "arquejo",
    "arquejou": "arquejar",
    "arquejámo": "arquejar",
    "arquejámos": "arquejar",
    "arquejáramo": "arquejar",
    "arquejáramos": "arquejar",
    "arquejáreis": "arquejar",
    "arquejásseis": "arquejar",
    "arquejássemos": "arquejar",
    "arquejávamo": "arquejar",
    "arquejávamos": "arquejar",
    "arquejáveis": "arquejar",
    "arquem": "arcar",
    "arquemos": "arcar",
    "arqueoastronomias": "arqueoastronomia",
    "arqueografias": "arqueografia",
    "arqueologias": "arqueologia",
    "arqueológica": "arqueológico",
    "arqueológicas": "arqueológico",
    "arqueológicos": "arqueológico",
    "arqueou": "arquear",
    "arques": "arcar",
    "arquetas": "arqueta",
    "arquetes": "arquete",
    "arquetípica": "arquetípico",
    "arquetípicas": "arquetípico",
    "arquetípicos": "arquetípico",
    "arqueá": "arquear",
    "arqueámo": "arquear",
    "arqueámos": "arquear",
    "arqueáramo": "arquear",
    "arqueáramos": "arquear",
    "arqueárei": "arquear",
    "arqueáreis": "arquear",
    "arqueásseis": "arquear",
    "arqueássemos": "arquear",
    "arqueávamo": "arquear",
    "arqueávamos": "arquear",
    "arqueávei": "arquear",
    "arqueáveis": "arquear",
    "arqueógrafos": "arqueógrafo",
    "arqueóloga": "arqueólogo",
    "arqueólogas": "arqueólogo",
    "arqueólogos": "arqueólogo",
    "arqueórnita": "arqueórnito",
    "arqueórnitas": "arqueórnito",
    "arqueórnitos": "arqueórnito",
    "arquiacólitos": "arquiacólito",
    "arquiapóstatas": "arquiapóstata",
    "arquiatros": "arquiatro",
    "arquibancadas": "arquibancada",
    "arquibancos": "arquibanco",
    "arquiburra": "arquiburro",
    "arquiburras": "arquiburro",
    "arquiburros": "arquiburro",
    "arquicancelários": "arquicancelário",
    "arquicantora": "arquicantor",
    "arquicantoras": "arquicantor",
    "arquicantores": "arquicantor",
    "arquiconfrarias": "arquiconfraria",
    "arquidiocesana": "arquidiocesano",
    "arquidiocesanas": "arquidiocesano",
    "arquidiocesanos": "arquidiocesano",
    "arquidioceses": "arquidiocese",
    "arquidiáconos": "arquidiácono",
    "arquiducados": "arquiducado",
    "arquiducais": "arquiducal",
    "arquiduques": "arquiduque",
    "arquiduquesa": "arquiduque",
    "arquiduquesas": "arquiduque",
    "arquiepiscopados": "arquiepiscopado",
    "arquiepiscopais": "arquiepiscopal",
    "arquifonemas": "arquifonema",
    "arquiinimiga": "arquiinimigo",
    "arquiinimigas": "arquiinimigo",
    "arquiinimigos": "arquiinimigo",
    "arquilevitas": "arquilevita",
    "arquilhos": "arquilho",
    "arquimandritas": "arquimandrita",
    "arquimilionária": "arquimilionário",
    "arquimilionárias": "arquimilionário",
    "arquimilionários": "arquimilionário",
    "arquimosteiros": "arquimosteiro",
    "arquimártires": "arquimártir",
    "arquinaves": "arquinave",
    "arquinha": "arca",
    "arquinhas": "arca",
    "arquinho": "arco",
    "arquinhos": "arco",
    "arquipotentes": "arquipotente",
    "arquipresbíteros": "arquipresbítero",
    "arquipriora": "arquiprior",
    "arquipriorados": "arquipriorado",
    "arquiprioras": "arquiprior",
    "arquipriores": "arquiprior",
    "arquiprioresa": "arquiprior",
    "arquiprioresas": "arquiprior",
    "arquiprofetas": "arquiprofeta",
    "arquipélagos": "arquipélago",
    "arquita": "arca",
    "arquitas": "arca",
    "arquitecta": "arquitecto",
    "arquitectada": "arquitectar",
    "arquitectadas": "arquitectar",
    "arquitectado": "arquitectar",
    "arquitectados": "arquitectar",
    "arquitectai": "arquitectar",
    "arquitectais": "arquitectar",
    "arquitectam": "arquitectar",
    "arquitectamo": "arquitectar",
    "arquitectamos": "arquitectar",
    "arquitectando": "arquitectar",
    "arquitectara": "arquitectar",
    "arquitectaram": "arquitectar",
    "arquitectaras": "arquitectar",
    "arquitectarde": "arquitectar",
    "arquitectardes": "arquitectar",
    "arquitectare": "arquitectar",
    "arquitectarei": "arquitectar",
    "arquitectareis": "arquitectar",
    "arquitectarem": "arquitectar",
    "arquitectaremos": "arquitectar",
    "arquitectares": "arquitectar",
    "arquitectaria": "arquitectar",
    "arquitectariam": "arquitectar",
    "arquitectarias": "arquitectar",
    "arquitectarmo": "arquitectar",
    "arquitectarmos": "arquitectar",
    "arquitectará": "arquitectar",
    "arquitectarás": "arquitectar",
    "arquitectarão": "arquitectar",
    "arquitectaríamos": "arquitectar",
    "arquitectaríeis": "arquitectar",
    "arquitectas": "arquitecto",
    "arquitectasse": "arquitectar",
    "arquitectassem": "arquitectar",
    "arquitectasses": "arquitectar",
    "arquitectaste": "arquitectar",
    "arquitectastes": "arquitectar",
    "arquitectava": "arquitectar",
    "arquitectavam": "arquitectar",
    "arquitectavas": "arquitectar",
    "arquitectações": "arquitectação",
    "arquitecte": "arquitectar",
    "arquitectei": "arquitectar",
    "arquitecteis": "arquitectar",
    "arquitectem": "arquitectar",
    "arquitectemo": "arquitectar",
    "arquitectemos": "arquitectar",
    "arquitectes": "arquitectar",
    "arquitecto": "arquitectar",
    "arquitectora": "arquitector",
    "arquitectoras": "arquitector",
    "arquitectores": "arquitector",
    "arquitectos": "arquitecto",
    "arquitectou": "arquitectar",
    "arquitecturais": "arquitectural",
    "arquitecturas": "arquitectura",
    "arquitectá": "arquitectar",
    "arquitectámo": "arquitectar",
    "arquitectámos": "arquitectar",
    "arquitectáramo": "arquitectar",
    "arquitectáramos": "arquitectar",
    "arquitectárei": "arquitectar",
    "arquitectáreis": "arquitectar",
    "arquitectásseis": "arquitectar",
    "arquitectássemos": "arquitectar",
    "arquitectávamo": "arquitectar",
    "arquitectávamos": "arquitectar",
    "arquitectávei": "arquitectar",
    "arquitectáveis": "arquitectável",
    "arquitectónica": "arquitectónico",
    "arquitectónicas": "arquitectónico",
    "arquitectónicos": "arquitectónico",
    "arquito": "arco",
    "arquitola": "arquitolo",
    "arquitolas": "arquitolo",
    "arquitolos": "arquitolo",
    "arquitos": "arco",
    "arquitravada": "arquitravado",
    "arquitravadas": "arquitravado",
    "arquitravados": "arquitravado",
    "arquitraves": "arquitrave",
    "arquitriclinos": "arquitriclino",
    "arquiva": "arquivar",
    "arquivada": "arquivar",
    "arquivadas": "arquivar",
    "arquivado": "arquivar",
    "arquivados": "arquivar",
    "arquivai": "arquivar",
    "arquivais": "arquivar",
    "arquivam": "arquivar",
    "arquivamentos": "arquivamento",
    "arquivamo": "arquivar",
    "arquivamos": "arquivar",
    "arquivando": "arquivar",
    "arquivara": "arquivar",
    "arquivaram": "arquivar",
    "arquivaras": "arquivar",
    "arquivarde": "arquivar",
    "arquivardes": "arquivar",
    "arquivare": "arquivar",
    "arquivarei": "arquivar",
    "arquivareis": "arquivar",
    "arquivarem": "arquivar",
    "arquivaremos": "arquivar",
    "arquivares": "arquivar",
    "arquivaria": "arquivar",
    "arquivariam": "arquivar",
    "arquivarias": "arquivar",
    "arquivarmo": "arquivar",
    "arquivarmos": "arquivar",
    "arquivará": "arquivar",
    "arquivarás": "arquivar",
    "arquivarão": "arquivar",
    "arquivaríamos": "arquivar",
    "arquivaríeis": "arquivar",
    "arquivas": "arquivar",
    "arquivasse": "arquivar",
    "arquivassem": "arquivar",
    "arquivasses": "arquivar",
    "arquivaste": "arquivar",
    "arquivastes": "arquivar",
    "arquivava": "arquivar",
    "arquivavam": "arquivar",
    "arquivavas": "arquivar",
    "arquive": "arquivar",
    "arquivei": "arquivar",
    "arquiveis": "arquivar",
    "arquivem": "arquivar",
    "arquivemo": "arquivar",
    "arquivemos": "arquivar",
    "arquives": "arquivar",
    "arquivistas": "arquivista",
    "arquivo": "arquivar",
    "arquivologias": "arquivologia",
    "arquivoltas": "arquivolta",
    "arquivológica": "arquivológico",
    "arquivológicas": "arquivológico",
    "arquivológicos": "arquivológico",
    "arquivos": "arquivo",
    "arquivou": "arquivar",
    "arquivá": "arquivar",
    "arquivámo": "arquivar",
    "arquivámos": "arquivar",
    "arquiváramo": "arquivar",
    "arquiváramos": "arquivar",
    "arquivárei": "arquivar",
    "arquiváreis": "arquivar",
    "arquivásseis": "arquivar",
    "arquivássemos": "arquivar",
    "arquivávamo": "arquivar",
    "arquivávamos": "arquivar",
    "arquivávei": "arquivar",
    "arquiváveis": "arquivável",
    "arquivística": "arquivístico",
    "arquivísticas": "arquivístico",
    "arquivísticos": "arquivístico",
    "arquétipos": "arquétipo",
    "arquênteros": "arquêntero",
    "arquídios": "arquídio",
    "arquípteros": "arquíptero",
    "arrabaldeira": "arrabaldeiro",
    "arrabaldeiras": "arrabaldeiro",
    "arrabaldeiros": "arrabaldeiro",
    "arrabaldes": "arrabalde",
    "arrabaldina": "arrabaldino",
    "arrabaldinas": "arrabaldino",
    "arrabaldinos": "arrabaldino",
    "arrabileiros": "arrabileiro",
    "arrabinada": "arrabinado",
    "arrabinadas": "arrabinado",
    "arrabinados": "arrabinado",
    "arrabios": "arrabio",
    "arrabis": "arrabil",
    "arrace": "arraçarraçar",
    "arracei": "arraçar",
    "arraceis": "arraçarraçar",
    "arracem": "arraçarraçar",
    "arracemo": "arraçar",
    "arracemos": "arraçarraçar",
    "arraces": "arraçarraçar",
    "arraiadas": "arraiada",
    "arraiais": "arraial",
    "arraialesca": "arraialesco",
    "arraialescas": "arraialesco",
    "arraialescos": "arraialesco",
    "arraiana": "arraiano",
    "arraianas": "arraiano",
    "arraianos": "arraiano",
    "arraias": "arraia",
    "arraieiras": "arraieira",
    "arraigada": "arraigado",
    "arraigadas": "arraigado",
    "arraigados": "arraigado",
    "arraigamentos": "arraigamento",
    "arraigotas": "arraigota",
    "arraiões": "arraião",
    "arrampadoiros": "arrampadoiro",
    "arrampados": "arrampado",
    "arrampadouros": "arrampadouro",
    "arranca": "arrancar",
    "arrancada": "arrancar",
    "arrancadas": "arrancar",
    "arrancadeiras": "arrancadeira",
    "arrancadelas": "arrancadela",
    "arrancado": "arrancar",
    "arrancadores": "arrancador",
    "arrancados": "arrancar",
    "arrancaduras": "arrancadura",
    "arrancai": "arrancar",
    "arrancais": "arrancar",
    "arrancam": "arrancar",
    "arrancamentos": "arrancamento",
    "arrancamo": "arrancar",
    "arrancamos": "arrancar",
    "arrancando": "arrancar",
    "arrancara": "arrancar",
    "arrancaram": "arrancar",
    "arrancaras": "arrancar",
    "arrancarde": "arrancar",
    "arrancardes": "arrancar",
    "arrancare": "arrancar",
    "arrancarei": "arrancar",
    "arrancareis": "arrancar",
    "arrancarem": "arrancar",
    "arrancaremos": "arrancar",
    "arrancares": "arrancar",
    "arrancaria": "arrancar",
    "arrancariam": "arrancar",
    "arrancarias": "arrancar",
    "arrancarmo": "arrancar",
    "arrancarmos": "arrancar",
    "arrancará": "arrancar",
    "arrancarás": "arrancar",
    "arrancarão": "arrancar",
    "arrancaríamos": "arrancar",
    "arrancaríeis": "arrancar",
    "arrancas": "arrancar",
    "arrancasse": "arrancar",
    "arrancassem": "arrancar",
    "arrancasses": "arrancar",
    "arrancaste": "arrancar",
    "arrancastes": "arrancar",
    "arrancava": "arrancar",
    "arrancavam": "arrancar",
    "arrancavas": "arrancar",
    "arranchamentos": "arranchamento",
    "arranchações": "arranchação",
    "arranchos": "arrancho",
    "arranco": "arrancar",
    "arrancos": "arranco",
    "arrancou": "arrancar",
    "arrancá": "arrancar",
    "arrancámo": "arrancar",
    "arrancámos": "arrancar",
    "arrancáramo": "arrancar",
    "arrancáramos": "arrancar",
    "arrancárei": "arrancar",
    "arrancáreis": "arrancar",
    "arrancásseis": "arrancar",
    "arrancássemos": "arrancar",
    "arrancávamo": "arrancar",
    "arrancávamos": "arrancar",
    "arrancávei": "arrancar",
    "arrancáveis": "arrancável",
    "arrancões": "arrancão",
    "arranha": "arranhar",
    "arranhada": "arranhar",
    "arranhadas": "arranhar",
    "arranhadelas": "arranhadela",
    "arranhado": "arranhar",
    "arranhadora": "arranhador",
    "arranhadoras": "arranhador",
    "arranhadores": "arranhador",
    "arranhados": "arranhar",
    "arranhaduras": "arranhadura",
    "arranhai": "arranhar",
    "arranhais": "arranhar",
    "arranham": "arranhar",
    "arranhamo": "arranhar",
    "arranhamos": "arranhar",
    "arranhando": "arranhar",
    "arranhara": "arranhar",
    "arranharam": "arranhar",
    "arranharas": "arranhar",
    "arranharde": "arranhar",
    "arranhardes": "arranhar",
    "arranhare": "arranhar",
    "arranharei": "arranhar",
    "arranhareis": "arranhar",
    "arranharem": "arranhar",
    "arranharemos": "arranhar",
    "arranhares": "arranhar",
    "arranharia": "arranhar",
    "arranhariam": "arranhar",
    "arranharias": "arranhar",
    "arranharmo": "arranhar",
    "arranharmos": "arranhar",
    "arranhará": "arranhar",
    "arranharás": "arranhar",
    "arranharão": "arranhar",
    "arranharíamos": "arranhar",
    "arranharíeis": "arranhar",
    "arranhas": "arranhar",
    "arranhasse": "arranhar",
    "arranhassem": "arranhar",
    "arranhasses": "arranhar",
    "arranhaste": "arranhar",
    "arranhastes": "arranhar",
    "arranhava": "arranhar",
    "arranhavam": "arranhar",
    "arranhavas": "arranhar",
    "arranhe": "arranhar",
    "arranhei": "arranhar",
    "arranheis": "arranhar",
    "arranhem": "arranhar",
    "arranhemo": "arranhar",
    "arranhemos": "arranhar",
    "arranhes": "arranhar",
    "arranho": "arranhar",
    "arranhou": "arranhar",
    "arranhá": "arranhar",
    "arranhámo": "arranhar",
    "arranhámos": "arranhar",
    "arranháramo": "arranhar",
    "arranháramos": "arranhar",
    "arranhárei": "arranhar",
    "arranháreis": "arranhar",
    "arranhásseis": "arranhar",
    "arranhássemos": "arranhar",
    "arranhávamo": "arranhar",
    "arranhávamos": "arranhar",
    "arranhávei": "arranhar",
    "arranháveis": "arranhar",
    "arranhãozinho": "arranhão",
    "arranhãozito": "arranhão",
    "arranhões": "arranhão",
    "arranhõezinhos": "arranhão",
    "arranhõezitos": "arranhão",
    "arranja": "arranjar",
    "arranjada": "arranjar",
    "arranjadas": "arranjar",
    "arranjadelas": "arranjadela",
    "arranjadinha": "arranjado",
    "arranjadinhas": "arranjado",
    "arranjadinho": "arranjado",
    "arranjadinhos": "arranjado",
    "arranjadita": "arranjado",
    "arranjaditas": "arranjado",
    "arranjadito": "arranjado",
    "arranjaditos": "arranjado",
    "arranjado": "arranjar",
    "arranjadora": "arranjador",
    "arranjadoras": "arranjador",
    "arranjadores": "arranjador",
    "arranjados": "arranjar",
    "arranjadíssima": "arranjado",
    "arranjadíssimas": "arranjado",
    "arranjadíssimo": "arranjado",
    "arranjadíssimos": "arranjado",
    "arranjai": "arranjar",
    "arranjais": "arranjar",
    "arranjam": "arranjar",
    "arranjamentos": "arranjamento",
    "arranjamo": "arranjar",
    "arranjamos": "arranjar",
    "arranjando": "arranjar",
    "arranjara": "arranjar",
    "arranjaram": "arranjar",
    "arranjaras": "arranjar",
    "arranjarde": "arranjar",
    "arranjardes": "arranjar",
    "arranjare": "arranjar",
    "arranjarei": "arranjar",
    "arranjareis": "arranjar",
    "arranjarem": "arranjar",
    "arranjaremos": "arranjar",
    "arranjares": "arranjar",
    "arranjaria": "arranjar",
    "arranjariam": "arranjar",
    "arranjarias": "arranjar",
    "arranjarmo": "arranjar",
    "arranjarmos": "arranjar",
    "arranjará": "arranjar",
    "arranjarás": "arranjar",
    "arranjarão": "arranjar",
    "arranjaríamos": "arranjar",
    "arranjaríeis": "arranjar",
    "arranjas": "arranjar",
    "arranjasse": "arranjar",
    "arranjassem": "arranjar",
    "arranjasses": "arranjar",
    "arranjaste": "arranjar",
    "arranjastes": "arranjar",
    "arranjava": "arranjar",
    "arranjavam": "arranjar",
    "arranjavas": "arranjar",
    "arranje": "arranjar",
    "arranjei": "arranjar",
    "arranjeis": "arranjar",
    "arranjem": "arranjar",
    "arranjemo": "arranjar",
    "arranjemos": "arranjar",
    "arranjes": "arranjar",
    "arranjinho": "arranjo",
    "arranjinhos": "arranjo",
    "arranjismos": "arranjismo",
    "arranjistas": "arranjista",
    "arranjito": "arranjo",
    "arranjitos": "arranjo",
    "arranjo": "arranjar",
    "arranjos": "arranjo",
    "arranjou": "arranjar",
    "arranjá": "arranjar",
    "arranjámo": "arranjar",
    "arranjámos": "arranjar",
    "arranjáramo": "arranjar",
    "arranjáramos": "arranjar",
    "arranjárei": "arranjar",
    "arranjáreis": "arranjar",
    "arranjásseis": "arranjar",
    "arranjássemos": "arranjar",
    "arranjávamo": "arranjar",
    "arranjávamos": "arranjar",
    "arranjávei": "arranjar",
    "arranjáveis": "arranjável",
    "arranjões": "arranjão",
    "arranque": "arrancar",
    "arranquei": "arrancar",
    "arranqueis": "arrancar",
    "arranquem": "arrancar",
    "arranquemo": "arrancar",
    "arranquemos": "arrancar",
    "arranques": "arranque",
    "arrapaza": "arrapazar",
    "arrapazada": "arrapazar",
    "arrapazadas": "arrapazar",
    "arrapazado": "arrapazar",
    "arrapazados": "arrapazar",
    "arrapazai": "arrapazar",
    "arrapazais": "arrapazar",
    "arrapazam": "arrapazar",
    "arrapazamo": "arrapazar",
    "arrapazamos": "arrapazar",
    "arrapazando": "arrapazar",
    "arrapazara": "arrapazar",
    "arrapazaram": "arrapazar",
    "arrapazaras": "arrapazar",
    "arrapazarde": "arrapazar",
    "arrapazardes": "arrapazar",
    "arrapazare": "arrapazar",
    "arrapazarei": "arrapazar",
    "arrapazareis": "arrapazar",
    "arrapazarem": "arrapazar",
    "arrapazaremos": "arrapazar",
    "arrapazares": "arrapazar",
    "arrapazaria": "arrapazar",
    "arrapazariam": "arrapazar",
    "arrapazarias": "arrapazar",
    "arrapazarmo": "arrapazar",
    "arrapazarmos": "arrapazar",
    "arrapazará": "arrapazar",
    "arrapazarás": "arrapazar",
    "arrapazarão": "arrapazar",
    "arrapazaríamos": "arrapazar",
    "arrapazaríeis": "arrapazar",
    "arrapazas": "arrapazar",
    "arrapazasse": "arrapazar",
    "arrapazassem": "arrapazar",
    "arrapazasses": "arrapazar",
    "arrapazaste": "arrapazar",
    "arrapazastes": "arrapazar",
    "arrapazava": "arrapazar",
    "arrapazavam": "arrapazar",
    "arrapazavas": "arrapazar",
    "arrapaze": "arrapazar",
    "arrapazei": "arrapazar",
    "arrapazeis": "arrapazar",
    "arrapazem": "arrapazar",
    "arrapazemo": "arrapazar",
    "arrapazemos": "arrapazar",
    "arrapazes": "arrapazar",
    "arrapazo": "arrapazar",
    "arrapazou": "arrapazar",
    "arrapazá": "arrapazar",
    "arrapazámo": "arrapazar",
    "arrapazámos": "arrapazar",
    "arrapazáramo": "arrapazar",
    "arrapazáramos": "arrapazar",
    "arrapazárei": "arrapazar",
    "arrapazáreis": "arrapazar",
    "arrapazásseis": "arrapazar",
    "arrapazássemos": "arrapazar",
    "arrapazávamo": "arrapazar",
    "arrapazávamos": "arrapazar",
    "arrapazávei": "arrapazar",
    "arrapazáveis": "arrapazar",
    "arras": "arra",
    "arrasa": "arrasar",
    "arrasada": "arrasar",
    "arrasadas": "arrasar",
    "arrasadeiras": "arrasadeira",
    "arrasado": "arrasar",
    "arrasadora": "arrasador",
    "arrasadoras": "arrasador",
    "arrasadores": "arrasador",
    "arrasados": "arrasar",
    "arrasaduras": "arrasadura",
    "arrasadíssima": "arrasado",
    "arrasadíssimas": "arrasado",
    "arrasadíssimo": "arrasado",
    "arrasadíssimos": "arrasado",
    "arrasai": "arrasar",
    "arrasais": "arrasar",
    "arrasam": "arrasar",
    "arrasamentos": "arrasamento",
    "arrasamo": "arrasar",
    "arrasamos": "arrasar",
    "arrasando": "arrasar",
    "arrasara": "arrasar",
    "arrasaram": "arrasar",
    "arrasaras": "arrasar",
    "arrasarde": "arrasar",
    "arrasardes": "arrasar",
    "arrasare": "arrasar",
    "arrasarei": "arrasar",
    "arrasareis": "arrasar",
    "arrasarem": "arrasar",
    "arrasaremos": "arrasar",
    "arrasares": "arrasar",
    "arrasaria": "arrasar",
    "arrasariam": "arrasar",
    "arrasarias": "arrasar",
    "arrasarmo": "arrasar",
    "arrasarmos": "arrasar",
    "arrasará": "arrasar",
    "arrasarás": "arrasar",
    "arrasarão": "arrasar",
    "arrasaríamos": "arrasar",
    "arrasaríeis": "arrasar",
    "arrasas": "arrasar",
    "arrasasse": "arrasar",
    "arrasassem": "arrasar",
    "arrasasses": "arrasar",
    "arrasaste": "arrasar",
    "arrasastes": "arrasar",
    "arrasava": "arrasar",
    "arrasavam": "arrasar",
    "arrasavas": "arrasar",
    "arrase": "arrasar",
    "arrasei": "arrasar",
    "arraseis": "arrasar",
    "arrasem": "arrasar",
    "arrasemo": "arrasar",
    "arrasemos": "arrasar",
    "arrases": "arrasar",
    "arraso": "arrasar",
    "arrasou": "arrasar",
    "arrasta": "arrastar",
    "arrastada": "arrastar",
    "arrastadas": "arrastar",
    "arrastadeira": "arrastadeiro",
    "arrastadeiras": "arrastadeiro",
    "arrastadeiros": "arrastadeiro",
    "arrastadiça": "arrastadiço",
    "arrastadiças": "arrastadiço",
    "arrastadiços": "arrastadiço",
    "arrastado": "arrastar",
    "arrastadora": "arrastador",
    "arrastadoras": "arrastador",
    "arrastadores": "arrastador",
    "arrastados": "arrastar",
    "arrastaduras": "arrastadura",
    "arrastai": "arrastar",
    "arrastais": "arrastar",
    "arrastam": "arrastar",
    "arrastamentos": "arrastamento",
    "arrastamo": "arrastar",
    "arrastamos": "arrastar",
    "arrastando": "arrastar",
    "arrastara": "arrastar",
    "arrastaram": "arrastar",
    "arrastaras": "arrastar",
    "arrastarde": "arrastar",
    "arrastardes": "arrastar",
    "arrastare": "arrastar",
    "arrastarei": "arrastar",
    "arrastareis": "arrastar",
    "arrastarem": "arrastar",
    "arrastaremos": "arrastar",
    "arrastares": "arrastar",
    "arrastaria": "arrastar",
    "arrastariam": "arrastar",
    "arrastarias": "arrastar",
    "arrastarmo": "arrastar",
    "arrastarmos": "arrastar",
    "arrastará": "arrastar",
    "arrastarás": "arrastar",
    "arrastarão": "arrastar",
    "arrastaríamos": "arrastar",
    "arrastaríeis": "arrastar",
    "arrastas": "arrastar",
    "arrastasse": "arrastar",
    "arrastassem": "arrastar",
    "arrastasses": "arrastar",
    "arrastaste": "arrastar",
    "arrastastes": "arrastar",
    "arrastava": "arrastar",
    "arrastavam": "arrastar",
    "arrastavas": "arrastar",
    "arraste": "arrastar",
    "arrastei": "arrastar",
    "arrasteis": "arrastar",
    "arrastem": "arrastar",
    "arrastemo": "arrastar",
    "arrastemos": "arrastar",
    "arrastes": "arraste",
    "arrasto": "arrastar",
    "arrastos": "arrasto",
    "arrastou": "arrastar",
    "arrastá": "arrastar",
    "arrastámo": "arrastar",
    "arrastámos": "arrastar",
    "arrastáramo": "arrastar",
    "arrastáramos": "arrastar",
    "arrastárei": "arrastar",
    "arrastáreis": "arrastar",
    "arrastásseis": "arrastar",
    "arrastássemos": "arrastar",
    "arrastávamo": "arrastar",
    "arrastávamos": "arrastar",
    "arrastávei": "arrastar",
    "arrastáveis": "arrastar",
    "arrastões": "arrastão",
    "arrasá": "arrasar",
    "arrasámo": "arrasar",
    "arrasámos": "arrasar",
    "arrasáramo": "arrasar",
    "arrasáramos": "arrasar",
    "arrasárei": "arrasar",
    "arrasáreis": "arrasar",
    "arrasásseis": "arrasar",
    "arrasássemos": "arrasar",
    "arrasávamo": "arrasar",
    "arrasávamos": "arrasar",
    "arrasávei": "arrasar",
    "arrasáveis": "arrasar",
    "arrazoa": "arrazoar",
    "arrazoada": "arrazoar",
    "arrazoadas": "arrazoar",
    "arrazoado": "arrazoar",
    "arrazoadora": "arrazoador",
    "arrazoadoras": "arrazoador",
    "arrazoadores": "arrazoador",
    "arrazoados": "arrazoar",
    "arrazoai": "arrazoar",
    "arrazoais": "arrazoar",
    "arrazoam": "arrazoar",
    "arrazoamentos": "arrazoamento",
    "arrazoamo": "arrazoar",
    "arrazoamos": "arrazoar",
    "arrazoando": "arrazoar",
    "arrazoara": "arrazoar",
    "arrazoaram": "arrazoar",
    "arrazoaras": "arrazoar",
    "arrazoarde": "arrazoar",
    "arrazoardes": "arrazoar",
    "arrazoare": "arrazoar",
    "arrazoarei": "arrazoar",
    "arrazoareis": "arrazoar",
    "arrazoarem": "arrazoar",
    "arrazoaremos": "arrazoar",
    "arrazoares": "arrazoar",
    "arrazoaria": "arrazoar",
    "arrazoariam": "arrazoar",
    "arrazoarias": "arrazoar",
    "arrazoarmo": "arrazoar",
    "arrazoarmos": "arrazoar",
    "arrazoará": "arrazoar",
    "arrazoarás": "arrazoar",
    "arrazoarão": "arrazoar",
    "arrazoaríamos": "arrazoar",
    "arrazoaríeis": "arrazoar",
    "arrazoas": "arrazoar",
    "arrazoasse": "arrazoar",
    "arrazoassem": "arrazoar",
    "arrazoasses": "arrazoar",
    "arrazoaste": "arrazoar",
    "arrazoastes": "arrazoar",
    "arrazoava": "arrazoar",
    "arrazoavam": "arrazoar",
    "arrazoavas": "arrazoar",
    "arrazoe": "arrazoar",
    "arrazoei": "arrazoar",
    "arrazoeis": "arrazoar",
    "arrazoem": "arrazoar",
    "arrazoemo": "arrazoar",
    "arrazoemos": "arrazoar",
    "arrazoes": "arrazoar",
    "arrazoo": "arrazoar",
    "arrazoou": "arrazoar",
    "arrazoá": "arrazoar",
    "arrazoámo": "arrazoar",
    "arrazoámos": "arrazoar",
    "arrazoáramo": "arrazoar",
    "arrazoáramos": "arrazoar",
    "arrazoárei": "arrazoar",
    "arrazoáreis": "arrazoar",
    "arrazoásseis": "arrazoar",
    "arrazoássemos": "arrazoar",
    "arrazoávamo": "arrazoar",
    "arrazoávamos": "arrazoar",
    "arrazoávei": "arrazoar",
    "arrazoáveis": "arrazoar",
    "arraça": "arraçarraçar",
    "arraçada": "arraçar",
    "arraçadas": "arraçar",
    "arraçado": "arraçar",
    "arraçados": "arraçar",
    "arraçai": "arraçarraçar",
    "arraçais": "arraçar",
    "arraçam": "arraçar",
    "arraçamo": "arraçar",
    "arraçamos": "arraçar",
    "arraçando": "arraçar",
    "arraçar": "arraçarraçar",
    "arraçara": "arraçarraçar",
    "arraçaram": "arraçarraçar",
    "arraçaras": "arraçar",
    "arraçarde": "arraçar",
    "arraçardes": "arraçarraçar",
    "arraçare": "arraçar",
    "arraçarei": "arraçar",
    "arraçareis": "arraçar",
    "arraçarem": "arraçarraçar",
    "arraçaremos": "arraçar",
    "arraçares": "arraçarraçar",
    "arraçaria": "arraçarraçar",
    "arraçariam": "arraçar",
    "arraçarias": "arraçar",
    "arraçarmo": "arraçar",
    "arraçarmos": "arraçarraçar",
    "arraçará": "arraçar",
    "arraçarás": "arraçar",
    "arraçarão": "arraçar",
    "arraçaríamos": "arraçar",
    "arraçaríeis": "arraçar",
    "arraças": "arraçar",
    "arraçasse": "arraçarraçar",
    "arraçassem": "arraçar",
    "arraçasses": "arraçar",
    "arraçaste": "arraçarraçar",
    "arraçastes": "arraçar",
    "arraçava": "arraçarraçar",
    "arraçavam": "arraçar",
    "arraçavas": "arraçar",
    "arraço": "arraçar",
    "arraçoamentos": "arraçoamento",
    "arraçou": "arraçar",
    "arraçá": "arraçarraçar",
    "arraçámo": "arraçar",
    "arraçámos": "arraçar",
    "arraçáramo": "arraçar",
    "arraçáramos": "arraçar",
    "arraçárei": "arraçar",
    "arraçáreis": "arraçar",
    "arraçásseis": "arraçar",
    "arraçássemos": "arraçar",
    "arraçávamo": "arraçar",
    "arraçávamos": "arraçar",
    "arraçávei": "arraçar",
    "arraçáveis": "arraçar",
    "arreada": "arrear",
    "arreadas": "arrear",
    "arreado": "arrear",
    "arreadores": "arreador",
    "arreados": "arrear",
    "arreai": "arrear",
    "arreais": "arrear",
    "arreamentos": "arreamento",
    "arreamo": "arrear",
    "arreamos": "arrear",
    "arreando": "arrear",
    "arreara": "arrear",
    "arrearam": "arrear",
    "arrearas": "arrear",
    "arrearde": "arrear",
    "arreardes": "arrear",
    "arreare": "arrear",
    "arrearei": "arrear",
    "arreareis": "arrear",
    "arrearem": "arrear",
    "arrearemos": "arrear",
    "arreares": "arrear",
    "arrearia": "arrear",
    "arreariam": "arrear",
    "arrearias": "arrearia",
    "arrearmo": "arrear",
    "arrearmos": "arrear",
    "arreará": "arrear",
    "arrearás": "arrear",
    "arrearão": "arrear",
    "arrearíamos": "arrear",
    "arrearíeis": "arrear",
    "arreasse": "arrear",
    "arreassem": "arrear",
    "arreasses": "arrear",
    "arreaste": "arrear",
    "arreastes": "arrear",
    "arreatadas": "arreatada",
    "arreataduras": "arreatadura",
    "arreatas": "arreata",
    "arreava": "arrear",
    "arreavam": "arrear",
    "arreavas": "arrear",
    "arreações": "arreação",
    "arrebanha": "arrebanhar",
    "arrebanhada": "arrebanhar",
    "arrebanhadas": "arrebanhar",
    "arrebanhado": "arrebanhar",
    "arrebanhadora": "arrebanhador",
    "arrebanhadoras": "arrebanhador",
    "arrebanhadores": "arrebanhador",
    "arrebanhados": "arrebanhar",
    "arrebanhaduras": "arrebanhadura",
    "arrebanhai": "arrebanhar",
    "arrebanhais": "arrebanhar",
    "arrebanham": "arrebanhar",
    "arrebanhamo": "arrebanhar",
    "arrebanhamos": "arrebanhar",
    "arrebanhando": "arrebanhar",
    "arrebanhara": "arrebanhar",
    "arrebanharam": "arrebanhar",
    "arrebanharas": "arrebanhar",
    "arrebanharde": "arrebanhar",
    "arrebanhardes": "arrebanhar",
    "arrebanhare": "arrebanhar",
    "arrebanharei": "arrebanhar",
    "arrebanhareis": "arrebanhar",
    "arrebanharem": "arrebanhar",
    "arrebanharemos": "arrebanhar",
    "arrebanhares": "arrebanhar",
    "arrebanharia": "arrebanhar",
    "arrebanhariam": "arrebanhar",
    "arrebanharias": "arrebanhar",
    "arrebanharmo": "arrebanhar",
    "arrebanharmos": "arrebanhar",
    "arrebanhará": "arrebanhar",
    "arrebanharás": "arrebanhar",
    "arrebanharão": "arrebanhar",
    "arrebanharíamos": "arrebanhar",
    "arrebanharíeis": "arrebanhar",
    "arrebanhas": "arrebanhar",
    "arrebanhasse": "arrebanhar",
    "arrebanhassem": "arrebanhar",
    "arrebanhasses": "arrebanhar",
    "arrebanhaste": "arrebanhar",
    "arrebanhastes": "arrebanhar",
    "arrebanhava": "arrebanhar",
    "arrebanhavam": "arrebanhar",
    "arrebanhavas": "arrebanhar",
    "arrebanhe": "arrebanhar",
    "arrebanhei": "arrebanhar",
    "arrebanheis": "arrebanhar",
    "arrebanhem": "arrebanhar",
    "arrebanhemo": "arrebanhar",
    "arrebanhemos": "arrebanhar",
    "arrebanhes": "arrebanhar",
    "arrebanho": "arrebanhar",
    "arrebanhos": "arrebanho",
    "arrebanhou": "arrebanhar",
    "arrebanhá": "arrebanhar",
    "arrebanhámo": "arrebanhar",
    "arrebanhámos": "arrebanhar",
    "arrebanháramo": "arrebanhar",
    "arrebanháramos": "arrebanhar",
    "arrebanhárei": "arrebanhar",
    "arrebanháreis": "arrebanhar",
    "arrebanhásseis": "arrebanhar",
    "arrebanhássemos": "arrebanhar",
    "arrebanhávamo": "arrebanhar",
    "arrebanhávamos": "arrebanhar",
    "arrebanhávei": "arrebanhar",
    "arrebanháveis": "arrebanhar",
    "arrebata": "arrebatar",
    "arrebatada": "arrebatar",
    "arrebatadas": "arrebatar",
    "arrebatadinha": "arrebatado",
    "arrebatadinhas": "arrebatado",
    "arrebatadinho": "arrebatado",
    "arrebatadinhos": "arrebatado",
    "arrebatadita": "arrebatado",
    "arrebataditas": "arrebatado",
    "arrebatadito": "arrebatado",
    "arrebataditos": "arrebatado",
    "arrebatado": "arrebatar",
    "arrebatadora": "arrebatador",
    "arrebatadoras": "arrebatador",
    "arrebatadores": "arrebatador",
    "arrebatados": "arrebatar",
    "arrebatadíssima": "arrebatado",
    "arrebatadíssimas": "arrebatado",
    "arrebatadíssimo": "arrebatado",
    "arrebatadíssimos": "arrebatado",
    "arrebatai": "arrebatar",
    "arrebatais": "arrebatar",
    "arrebatam": "arrebatar",
    "arrebatamentos": "arrebatamento",
    "arrebatamo": "arrebatar",
    "arrebatamos": "arrebatar",
    "arrebatando": "arrebatar",
    "arrebatantes": "arrebatante",
    "arrebatara": "arrebatar",
    "arrebataram": "arrebatar",
    "arrebataras": "arrebatar",
    "arrebatarde": "arrebatar",
    "arrebatardes": "arrebatar",
    "arrebatare": "arrebatar",
    "arrebatarei": "arrebatar",
    "arrebatareis": "arrebatar",
    "arrebatarem": "arrebatar",
    "arrebataremos": "arrebatar",
    "arrebatares": "arrebatar",
    "arrebataria": "arrebatar",
    "arrebatariam": "arrebatar",
    "arrebatarias": "arrebatar",
    "arrebatarmo": "arrebatar",
    "arrebatarmos": "arrebatar",
    "arrebatará": "arrebatar",
    "arrebatarás": "arrebatar",
    "arrebatarão": "arrebatar",
    "arrebataríamos": "arrebatar",
    "arrebataríeis": "arrebatar",
    "arrebatas": "arrebatar",
    "arrebatasse": "arrebatar",
    "arrebatassem": "arrebatar",
    "arrebatasses": "arrebatar",
    "arrebataste": "arrebatar",
    "arrebatastes": "arrebatar",
    "arrebatava": "arrebatar",
    "arrebatavam": "arrebatar",
    "arrebatavas": "arrebatar",
    "arrebate": "arrebatar",
    "arrebatei": "arrebatar",
    "arrebateis": "arrebatar",
    "arrebatem": "arrebatar",
    "arrebatemo": "arrebatar",
    "arrebatemos": "arrebatar",
    "arrebates": "arrebate",
    "arrebato": "arrebatar",
    "arrebatos": "arrebato",
    "arrebatou": "arrebatar",
    "arrebatá": "arrebatar",
    "arrebatámo": "arrebatar",
    "arrebatámos": "arrebatar",
    "arrebatáramo": "arrebatar",
    "arrebatáramos": "arrebatar",
    "arrebatárei": "arrebatar",
    "arrebatáreis": "arrebatar",
    "arrebatásseis": "arrebatar",
    "arrebatássemos": "arrebatar",
    "arrebatávamo": "arrebatar",
    "arrebatávamos": "arrebatar",
    "arrebatávei": "arrebatar",
    "arrebatáveis": "arrebatável",
    "arrebenta": "arrebentar",
    "arrebentada": "arrebentar",
    "arrebentadas": "arrebentar",
    "arrebentadiça": "arrebentadiço",
    "arrebentadiças": "arrebentadiço",
    "arrebentadiços": "arrebentadiço",
    "arrebentado": "arrebentar",
    "arrebentados": "arrebentar",
    "arrebentai": "arrebentar",
    "arrebentais": "arrebentar",
    "arrebentam": "arrebentar",
    "arrebentamentos": "arrebentamento",
    "arrebentamo": "arrebentar",
    "arrebentamos": "arrebentar",
    "arrebentando": "arrebentar",
    "arrebentara": "arrebentar",
    "arrebentaram": "arrebentar",
    "arrebentaras": "arrebentar",
    "arrebentarde": "arrebentar",
    "arrebentardes": "arrebentar",
    "arrebentare": "arrebentar",
    "arrebentarei": "arrebentar",
    "arrebentareis": "arrebentar",
    "arrebentarem": "arrebentar",
    "arrebentaremos": "arrebentar",
    "arrebentares": "arrebentar",
    "arrebentaria": "arrebentar",
    "arrebentariam": "arrebentar",
    "arrebentarias": "arrebentar",
    "arrebentarmo": "arrebentar",
    "arrebentarmos": "arrebentar",
    "arrebentará": "arrebentar",
    "arrebentarás": "arrebentar",
    "arrebentarão": "arrebentar",
    "arrebentaríamos": "arrebentar",
    "arrebentaríeis": "arrebentar",
    "arrebentas": "arrebentar",
    "arrebentasse": "arrebentar",
    "arrebentassem": "arrebentar",
    "arrebentasses": "arrebentar",
    "arrebentaste": "arrebentar",
    "arrebentastes": "arrebentar",
    "arrebentava": "arrebentar",
    "arrebentavam": "arrebentar",
    "arrebentavas": "arrebentar",
    "arrebentações": "arrebentação",
    "arrebente": "arrebentar",
    "arrebentei": "arrebentar",
    "arrebenteis": "arrebentar",
    "arrebentem": "arrebentar",
    "arrebentemo": "arrebentar",
    "arrebentemos": "arrebentar",
    "arrebentes": "arrebentar",
    "arrebento": "arrebentar",
    "arrebentos": "arrebento",
    "arrebentou": "arrebentar",
    "arrebentá": "arrebentar",
    "arrebentámo": "arrebentar",
    "arrebentámos": "arrebentar",
    "arrebentáramo": "arrebentar",
    "arrebentáramos": "arrebentar",
    "arrebentárei": "arrebentar",
    "arrebentáreis": "arrebentar",
    "arrebentásseis": "arrebentar",
    "arrebentássemos": "arrebentar",
    "arrebentávamo": "arrebentar",
    "arrebentávamos": "arrebentar",
    "arrebentávei": "arrebentar",
    "arrebentáveis": "arrebentar",
    "arrebentões": "arrebentão",
    "arrebiques": "arrebique",
    "arrebita": "arrebitar",
    "arrebitada": "arrebitar",
    "arrebitadas": "arrebitar",
    "arrebitadinha": "arrebitado",
    "arrebitadinhas": "arrebitado",
    "arrebitadinho": "arrebitado",
    "arrebitadinhos": "arrebitado",
    "arrebitadita": "arrebitado",
    "arrebitaditas": "arrebitado",
    "arrebitadito": "arrebitado",
    "arrebitaditos": "arrebitado",
    "arrebitado": "arrebitar",
    "arrebitados": "arrebitar",
    "arrebitadíssima": "arrebitado",
    "arrebitadíssimas": "arrebitado",
    "arrebitadíssimo": "arrebitado",
    "arrebitadíssimos": "arrebitado",
    "arrebitai": "arrebitar",
    "arrebitais": "arrebitar",
    "arrebitam": "arrebitar",
    "arrebitamentos": "arrebitamento",
    "arrebitamo": "arrebitar",
    "arrebitamos": "arrebitar",
    "arrebitando": "arrebitar",
    "arrebitara": "arrebitar",
    "arrebitaram": "arrebitar",
    "arrebitaras": "arrebitar",
    "arrebitarde": "arrebitar",
    "arrebitardes": "arrebitar",
    "arrebitare": "arrebitar",
    "arrebitarei": "arrebitar",
    "arrebitareis": "arrebitar",
    "arrebitarem": "arrebitar",
    "arrebitaremos": "arrebitar",
    "arrebitares": "arrebitar",
    "arrebitaria": "arrebitar",
    "arrebitariam": "arrebitar",
    "arrebitarias": "arrebitar",
    "arrebitarmo": "arrebitar",
    "arrebitarmos": "arrebitar",
    "arrebitará": "arrebitar",
    "arrebitarás": "arrebitar",
    "arrebitarão": "arrebitar",
    "arrebitaríamos": "arrebitar",
    "arrebitaríeis": "arrebitar",
    "arrebitas": "arrebitar",
    "arrebitasse": "arrebitar",
    "arrebitassem": "arrebitar",
    "arrebitasses": "arrebitar",
    "arrebitaste": "arrebitar",
    "arrebitastes": "arrebitar",
    "arrebitava": "arrebitar",
    "arrebitavam": "arrebitar",
    "arrebitavas": "arrebitar",
    "arrebitaços": "arrebitaço",
    "arrebite": "arrebitar",
    "arrebitei": "arrebitar",
    "arrebiteis": "arrebitar",
    "arrebitem": "arrebitar",
    "arrebitemo": "arrebitar",
    "arrebitemos": "arrebitar",
    "arrebites": "arrebite",
    "arrebito": "arrebitar",
    "arrebitos": "arrebito",
    "arrebitou": "arrebitar",
    "arrebitá": "arrebitar",
    "arrebitámo": "arrebitar",
    "arrebitámos": "arrebitar",
    "arrebitáramo": "arrebitar",
    "arrebitáramos": "arrebitar",
    "arrebitárei": "arrebitar",
    "arrebitáreis": "arrebitar",
    "arrebitásseis": "arrebitar",
    "arrebitássemos": "arrebitar",
    "arrebitávamo": "arrebitar",
    "arrebitávamos": "arrebitar",
    "arrebitávei": "arrebitar",
    "arrebitáveis": "arrebitar",
    "arrebéns": "arrebém",
    "arrebóis": "arrebol",
    "arrecabes": "arrecabe",
    "arrecabos": "arrecabo",
    "arrecada": "arrecadar",
    "arrecadada": "arrecadar",
    "arrecadadas": "arrecadar",
    "arrecadado": "arrecadar",
    "arrecadadora": "arrecadador",
    "arrecadadoras": "arrecadador",
    "arrecadadores": "arrecadador",
    "arrecadados": "arrecadar",
    "arrecadai": "arrecadar",
    "arrecadais": "arrecadar",
    "arrecadam": "arrecadar",
    "arrecadamentos": "arrecadamento",
    "arrecadamo": "arrecadar",
    "arrecadamos": "arrecadar",
    "arrecadando": "arrecadar",
    "arrecadara": "arrecadar",
    "arrecadaram": "arrecadar",
    "arrecadaras": "arrecadar",
    "arrecadarde": "arrecadar",
    "arrecadardes": "arrecadar",
    "arrecadare": "arrecadar",
    "arrecadarei": "arrecadar",
    "arrecadareis": "arrecadar",
    "arrecadarem": "arrecadar",
    "arrecadaremos": "arrecadar",
    "arrecadares": "arrecadar",
    "arrecadaria": "arrecadar",
    "arrecadariam": "arrecadar",
    "arrecadarias": "arrecadar",
    "arrecadarmo": "arrecadar",
    "arrecadarmos": "arrecadar",
    "arrecadará": "arrecadar",
    "arrecadarás": "arrecadar",
    "arrecadarão": "arrecadar",
    "arrecadaríamos": "arrecadar",
    "arrecadaríeis": "arrecadar",
    "arrecadas": "arrecadar",
    "arrecadasse": "arrecadar",
    "arrecadassem": "arrecadar",
    "arrecadasses": "arrecadar",
    "arrecadaste": "arrecadar",
    "arrecadastes": "arrecadar",
    "arrecadava": "arrecadar",
    "arrecadavam": "arrecadar",
    "arrecadavas": "arrecadar",
    "arrecadações": "arrecadação",
    "arrecade": "arrecadar",
    "arrecadei": "arrecadar",
    "arrecadeis": "arrecadar",
    "arrecadem": "arrecadar",
    "arrecademo": "arrecadar",
    "arrecademos": "arrecadar",
    "arrecades": "arrecadar",
    "arrecado": "arrecadar",
    "arrecadou": "arrecadar",
    "arrecadá": "arrecadar",
    "arrecadámo": "arrecadar",
    "arrecadámos": "arrecadar",
    "arrecadáramo": "arrecadar",
    "arrecadáramos": "arrecadar",
    "arrecadárei": "arrecadar",
    "arrecadáreis": "arrecadar",
    "arrecadásseis": "arrecadar",
    "arrecadássemos": "arrecadar",
    "arrecadávamo": "arrecadar",
    "arrecadávamos": "arrecadar",
    "arrecadávei": "arrecadar",
    "arrecadáveis": "arrecadar",
    "arrecifes": "arrecife",
    "arrecuões": "arrecuão",
    "arreda": "arredar",
    "arredada": "arredar",
    "arredadas": "arredar",
    "arredado": "arredar",
    "arredados": "arredar",
    "arredai": "arredar",
    "arredais": "arredar",
    "arredam": "arredar",
    "arredamentos": "arredamento",
    "arredamo": "arredar",
    "arredamos": "arredar",
    "arredando": "arredar",
    "arredara": "arredar",
    "arredaram": "arredar",
    "arredaras": "arredar",
    "arredarde": "arredar",
    "arredardes": "arredar",
    "arredare": "arredar",
    "arredarei": "arredar",
    "arredareis": "arredar",
    "arredarem": "arredar",
    "arredaremos": "arredar",
    "arredares": "arredar",
    "arredaria": "arredar",
    "arredariam": "arredar",
    "arredarias": "arredar",
    "arredarmo": "arredar",
    "arredarmos": "arredar",
    "arredará": "arredar",
    "arredarás": "arredar",
    "arredarão": "arredar",
    "arredaríamos": "arredar",
    "arredaríeis": "arredar",
    "arredas": "arredar",
    "arredasse": "arredar",
    "arredassem": "arredar",
    "arredasses": "arredar",
    "arredaste": "arredar",
    "arredastes": "arredar",
    "arredava": "arredar",
    "arredavam": "arredar",
    "arredavas": "arredar",
    "arrede": "arredar",
    "arredei": "arredar",
    "arredeis": "arredar",
    "arredem": "arredar",
    "arredemo": "arredar",
    "arredemos": "arredar",
    "arredes": "arredar",
    "arredia": "arredio",
    "arredias": "arredio",
    "arredios": "arredio",
    "arredo": "arredar",
    "arredonda": "arredondar",
    "arredondada": "arredondar",
    "arredondadas": "arredondar",
    "arredondado": "arredondar",
    "arredondados": "arredondar",
    "arredondai": "arredondar",
    "arredondais": "arredondar",
    "arredondam": "arredondar",
    "arredondamentos": "arredondamento",
    "arredondamo": "arredondar",
    "arredondamos": "arredondar",
    "arredondando": "arredondar",
    "arredondara": "arredondar",
    "arredondaram": "arredondar",
    "arredondaras": "arredondar",
    "arredondarde": "arredondar",
    "arredondardes": "arredondar",
    "arredondare": "arredondar",
    "arredondarei": "arredondar",
    "arredondareis": "arredondar",
    "arredondarem": "arredondar",
    "arredondaremos": "arredondar",
    "arredondares": "arredondar",
    "arredondaria": "arredondar",
    "arredondariam": "arredondar",
    "arredondarias": "arredondar",
    "arredondarmo": "arredondar",
    "arredondarmos": "arredondar",
    "arredondará": "arredondar",
    "arredondarás": "arredondar",
    "arredondarão": "arredondar",
    "arredondaríamos": "arredondar",
    "arredondaríeis": "arredondar",
    "arredondas": "arredondar",
    "arredondasse": "arredondar",
    "arredondassem": "arredondar",
    "arredondasses": "arredondar",
    "arredondaste": "arredondar",
    "arredondastes": "arredondar",
    "arredondava": "arredondar",
    "arredondavam": "arredondar",
    "arredondavas": "arredondar",
    "arredonde": "arredondar",
    "arredondei": "arredondar",
    "arredondeis": "arredondar",
    "arredondem": "arredondar",
    "arredondemo": "arredondar",
    "arredondemos": "arredondar",
    "arredondes": "arredondar",
    "arredondo": "arredondar",
    "arredondou": "arredondar",
    "arredondá": "arredondar",
    "arredondámo": "arredondar",
    "arredondámos": "arredondar",
    "arredondáramo": "arredondar",
    "arredondáramos": "arredondar",
    "arredondárei": "arredondar",
    "arredondáreis": "arredondar",
    "arredondásseis": "arredondar",
    "arredondássemos": "arredondar",
    "arredondávamo": "arredondar",
    "arredondávamos": "arredondar",
    "arredondávei": "arredondar",
    "arredondáveis": "arredondável",
    "arredores": "arredor",
    "arredou": "arredar",
    "arredá": "arredar",
    "arredámo": "arredar",
    "arredámos": "arredar",
    "arredáramo": "arredar",
    "arredáramos": "arredar",
    "arredárei": "arredar",
    "arredáreis": "arredar",
    "arredásseis": "arredar",
    "arredássemos": "arredar",
    "arredávamo": "arredar",
    "arredávamos": "arredar",
    "arredávei": "arredar",
    "arredáveis": "arredar",
    "arreei": "arrear",
    "arreeis": "arrear",
    "arreemo": "arrear",
    "arreemos": "arrear",
    "arrefece": "arrefecer",
    "arrefecedora": "arrefecedor",
    "arrefecedoras": "arrefecedor",
    "arrefecedores": "arrefecedor",
    "arrefecei": "arrefecer",
    "arrefeceis": "arrefecer",
    "arrefecem": "arrefecer",
    "arrefecemo": "arrefecer",
    "arrefecemos": "arrefecer",
    "arrefecendo": "arrefecer",
    "arrefecera": "arrefecer",
    "arrefeceram": "arrefecer",
    "arrefeceras": "arrefecer",
    "arrefecerde": "arrefecer",
    "arrefecerdes": "arrefecer",
    "arrefecere": "arrefecer",
    "arrefecerei": "arrefecer",
    "arrefecereis": "arrefecer",
    "arrefecerem": "arrefecer",
    "arrefeceremos": "arrefecer",
    "arrefeceres": "arrefecer",
    "arrefeceria": "arrefecer",
    "arrefeceriam": "arrefecer",
    "arrefecerias": "arrefecer",
    "arrefecermo": "arrefecer",
    "arrefecermos": "arrefecer",
    "arrefecerá": "arrefecer",
    "arrefecerás": "arrefecer",
    "arrefecerão": "arrefecer",
    "arrefeceríamos": "arrefecer",
    "arrefeceríeis": "arrefecer",
    "arrefeces": "arrefecer",
    "arrefecesse": "arrefecer",
    "arrefecessem": "arrefecer",
    "arrefecesses": "arrefecer",
    "arrefeceste": "arrefecer",
    "arrefecestes": "arrefecer",
    "arrefeceu": "arrefecer",
    "arrefeci": "arrefecer",
    "arrefecia": "arrefecer",
    "arrefeciam": "arrefecer",
    "arrefecias": "arrefecer",
    "arrefecida": "arrefecido",
    "arrefecidas": "arrefecido",
    "arrefecido": "arrefecer",
    "arrefecidos": "arrefecido",
    "arrefecimentos": "arrefecimento",
    "arrefecê": "arrefecer",
    "arrefecêramo": "arrefecer",
    "arrefecêramos": "arrefecer",
    "arrefecêrei": "arrefecer",
    "arrefecêreis": "arrefecer",
    "arrefecêsseis": "arrefecer",
    "arrefecêssemos": "arrefecer",
    "arrefecíamo": "arrefecer",
    "arrefecíamos": "arrefecer",
    "arrefecíei": "arrefecer",
    "arrefecíeis": "arrefecer",
    "arrefeça": "arrefecer",
    "arrefeçais": "arrefecer",
    "arrefeçam": "arrefecer",
    "arrefeçamo": "arrefecer",
    "arrefeçamos": "arrefecer",
    "arrefeças": "arrefecer",
    "arrefeço": "arrefecer",
    "arregace": "arregaçarregaçar",
    "arregacei": "arregaçar",
    "arregaceis": "arregaçarregaçar",
    "arregacem": "arregaçarregaçar",
    "arregacemo": "arregaçar",
    "arregacemos": "arregaçarregaçar",
    "arregaces": "arregaçarregaçar",
    "arregachas": "arregacha",
    "arregala": "arregalar",
    "arregalada": "arregalar",
    "arregaladas": "arregalar",
    "arregalado": "arregalar",
    "arregalados": "arregalar",
    "arregalai": "arregalar",
    "arregalais": "arregalar",
    "arregalam": "arregalar",
    "arregalamo": "arregalar",
    "arregalamos": "arregalar",
    "arregalando": "arregalar",
    "arregalara": "arregalar",
    "arregalaram": "arregalar",
    "arregalaras": "arregalar",
    "arregalarde": "arregalar",
    "arregalardes": "arregalar",
    "arregalare": "arregalar",
    "arregalarei": "arregalar",
    "arregalareis": "arregalar",
    "arregalarem": "arregalar",
    "arregalaremos": "arregalar",
    "arregalares": "arregalar",
    "arregalaria": "arregalar",
    "arregalariam": "arregalar",
    "arregalarias": "arregalar",
    "arregalarmo": "arregalar",
    "arregalarmos": "arregalar",
    "arregalará": "arregalar",
    "arregalarás": "arregalar",
    "arregalarão": "arregalar",
    "arregalaríamos": "arregalar",
    "arregalaríeis": "arregalar",
    "arregalas": "arregalar",
    "arregalasse": "arregalar",
    "arregalassem": "arregalar",
    "arregalasses": "arregalar",
    "arregalaste": "arregalar",
    "arregalastes": "arregalar",
    "arregalava": "arregalar",
    "arregalavam": "arregalar",
    "arregalavas": "arregalar",
    "arregale": "arregalar",
    "arregalei": "arregalar",
    "arregaleis": "arregalar",
    "arregalem": "arregalar",
    "arregalemo": "arregalar",
    "arregalemos": "arregalar",
    "arregales": "arregalar",
    "arregalo": "arregalar",
    "arregalou": "arregalar",
    "arregalá": "arregalar",
    "arregalámo": "arregalar",
    "arregalámos": "arregalar",
    "arregaláramo": "arregalar",
    "arregaláramos": "arregalar",
    "arregalárei": "arregalar",
    "arregaláreis": "arregalar",
    "arregalásseis": "arregalar",
    "arregalássemos": "arregalar",
    "arregalávamo": "arregalar",
    "arregalávamos": "arregalar",
    "arregalávei": "arregalar",
    "arregaláveis": "arregalar",
    "arreganha": "arreganhar",
    "arreganhada": "arreganhar",
    "arreganhadas": "arreganhar",
    "arreganhadinha": "arreganhado",
    "arreganhadinhas": "arreganhado",
    "arreganhadinho": "arreganhado",
    "arreganhadinhos": "arreganhado",
    "arreganhadita": "arreganhado",
    "arreganhaditas": "arreganhado",
    "arreganhadito": "arreganhado",
    "arreganhaditos": "arreganhado",
    "arreganhado": "arreganhar",
    "arreganhados": "arreganhar",
    "arreganhadíssima": "arreganhado",
    "arreganhadíssimas": "arreganhado",
    "arreganhadíssimo": "arreganhado",
    "arreganhadíssimos": "arreganhado",
    "arreganhai": "arreganhar",
    "arreganhais": "arreganhar",
    "arreganham": "arreganhar",
    "arreganhamo": "arreganhar",
    "arreganhamos": "arreganhar",
    "arreganhando": "arreganhar",
    "arreganhara": "arreganhar",
    "arreganharam": "arreganhar",
    "arreganharas": "arreganhar",
    "arreganharde": "arreganhar",
    "arreganhardes": "arreganhar",
    "arreganhare": "arreganhar",
    "arreganharei": "arreganhar",
    "arreganhareis": "arreganhar",
    "arreganharem": "arreganhar",
    "arreganharemos": "arreganhar",
    "arreganhares": "arreganhar",
    "arreganharia": "arreganhar",
    "arreganhariam": "arreganhar",
    "arreganharias": "arreganhar",
    "arreganharmo": "arreganhar",
    "arreganharmos": "arreganhar",
    "arreganhará": "arreganhar",
    "arreganharás": "arreganhar",
    "arreganharão": "arreganhar",
    "arreganharíamos": "arreganhar",
    "arreganharíeis": "arreganhar",
    "arreganhas": "arreganhar",
    "arreganhasse": "arreganhar",
    "arreganhassem": "arreganhar",
    "arreganhasses": "arreganhar",
    "arreganhaste": "arreganhar",
    "arreganhastes": "arreganhar",
    "arreganhava": "arreganhar",
    "arreganhavam": "arreganhar",
    "arreganhavas": "arreganhar",
    "arreganhe": "arreganhar",
    "arreganhei": "arreganhar",
    "arreganheis": "arreganhar",
    "arreganhem": "arreganhar",
    "arreganhemo": "arreganhar",
    "arreganhemos": "arreganhar",
    "arreganhes": "arreganhar",
    "arreganho": "arreganhar",
    "arreganhos": "arreganho",
    "arreganhou": "arreganhar",
    "arreganhá": "arreganhar",
    "arreganhámo": "arreganhar",
    "arreganhámos": "arreganhar",
    "arreganháramo": "arreganhar",
    "arreganháramos": "arreganhar",
    "arreganhárei": "arreganhar",
    "arreganháreis": "arreganhar",
    "arreganhásseis": "arreganhar",
    "arreganhássemos": "arreganhar",
    "arreganhávamo": "arreganhar",
    "arreganhávamos": "arreganhar",
    "arreganhávei": "arreganhar",
    "arreganháveis": "arreganhar",
    "arregaça": "arregaçarregaçar",
    "arregaçada": "arregaçar",
    "arregaçadas": "arregaçar",
    "arregaçado": "arregaçar",
    "arregaçados": "arregaçar",
    "arregaçai": "arregaçarregaçar",
    "arregaçais": "arregaçar",
    "arregaçam": "arregaçar",
    "arregaçamo": "arregaçar",
    "arregaçamos": "arregaçar",
    "arregaçando": "arregaçar",
    "arregaçar": "arregaçarregaçar",
    "arregaçara": "arregaçarregaçar",
    "arregaçaram": "arregaçarregaçar",
    "arregaçaras": "arregaçar",
    "arregaçarde": "arregaçar",
    "arregaçardes": "arregaçarregaçar",
    "arregaçare": "arregaçar",
    "arregaçarei": "arregaçar",
    "arregaçareis": "arregaçar",
    "arregaçarem": "arregaçarregaçar",
    "arregaçaremos": "arregaçar",
    "arregaçares": "arregaçarregaçar",
    "arregaçaria": "arregaçarregaçar",
    "arregaçariam": "arregaçar",
    "arregaçarias": "arregaçar",
    "arregaçarmo": "arregaçar",
    "arregaçarmos": "arregaçarregaçar",
    "arregaçará": "arregaçar",
    "arregaçarás": "arregaçar",
    "arregaçarão": "arregaçar",
    "arregaçaríamos": "arregaçar",
    "arregaçaríeis": "arregaçar",
    "arregaças": "arregaçar",
    "arregaçasse": "arregaçarregaçar",
    "arregaçassem": "arregaçar",
    "arregaçasses": "arregaçar",
    "arregaçaste": "arregaçarregaçar",
    "arregaçastes": "arregaçar",
    "arregaçava": "arregaçarregaçar",
    "arregaçavam": "arregaçar",
    "arregaçavas": "arregaçar",
    "arregaço": "arregaçar",
    "arregaços": "arregaço",
    "arregaçou": "arregaçar",
    "arregaçá": "arregaçarregaçar",
    "arregaçámo": "arregaçar",
    "arregaçámos": "arregaçar",
    "arregaçáramo": "arregaçar",
    "arregaçáramos": "arregaçar",
    "arregaçárei": "arregaçar",
    "arregaçáreis": "arregaçar",
    "arregaçásseis": "arregaçar",
    "arregaçássemos": "arregaçar",
    "arregaçávamo": "arregaçar",
    "arregaçávamos": "arregaçar",
    "arregaçávei": "arregaçar",
    "arregaçáveis": "arregaçar",
    "arregimenta": "arregimentar",
    "arregimentada": "arregimentar",
    "arregimentadas": "arregimentar",
    "arregimentado": "arregimentar",
    "arregimentados": "arregimentar",
    "arregimentai": "arregimentar",
    "arregimentais": "arregimentar",
    "arregimentam": "arregimentar",
    "arregimentamo": "arregimentar",
    "arregimentamos": "arregimentar",
    "arregimentando": "arregimentar",
    "arregimentara": "arregimentar",
    "arregimentaram": "arregimentar",
    "arregimentaras": "arregimentar",
    "arregimentarde": "arregimentar",
    "arregimentardes": "arregimentar",
    "arregimentare": "arregimentar",
    "arregimentarei": "arregimentar",
    "arregimentareis": "arregimentar",
    "arregimentarem": "arregimentar",
    "arregimentaremos": "arregimentar",
    "arregimentares": "arregimentar",
    "arregimentaria": "arregimentar",
    "arregimentariam": "arregimentar",
    "arregimentarias": "arregimentar",
    "arregimentarmo": "arregimentar",
    "arregimentarmos": "arregimentar",
    "arregimentará": "arregimentar",
    "arregimentarás": "arregimentar",
    "arregimentarão": "arregimentar",
    "arregimentaríamos": "arregimentar",
    "arregimentaríeis": "arregimentar",
    "arregimentas": "arregimentar",
    "arregimentasse": "arregimentar",
    "arregimentassem": "arregimentar",
    "arregimentasses": "arregimentar",
    "arregimentaste": "arregimentar",
    "arregimentastes": "arregimentar",
    "arregimentava": "arregimentar",
    "arregimentavam": "arregimentar",
    "arregimentavas": "arregimentar",
    "arregimentações": "arregimentação",
    "arregimente": "arregimentar",
    "arregimentei": "arregimentar",
    "arregimenteis": "arregimentar",
    "arregimentem": "arregimentar",
    "arregimentemo": "arregimentar",
    "arregimentemos": "arregimentar",
    "arregimentes": "arregimentar",
    "arregimento": "arregimentar",
    "arregimentou": "arregimentar",
    "arregimentá": "arregimentar",
    "arregimentámo": "arregimentar",
    "arregimentámos": "arregimentar",
    "arregimentáramo": "arregimentar",
    "arregimentáramos": "arregimentar",
    "arregimentárei": "arregimentar",
    "arregimentáreis": "arregimentar",
    "arregimentásseis": "arregimentar",
    "arregimentássemos": "arregimentar",
    "arregimentávamo": "arregimentar",
    "arregimentávamos": "arregimentar",
    "arregimentávei": "arregimentar",
    "arregimentáveis": "arregimentar",
    "arreglos": "arreglo",
    "arregos": "arrego",
    "arregougada": "arregougado",
    "arregougadas": "arregougado",
    "arregougados": "arregougado",
    "arreia": "arriar",
    "arreiam": "arriar",
    "arreias": "arriar",
    "arreica": "arreico",
    "arreicas": "arreico",
    "arreicos": "arreico",
    "arreie": "arriar",
    "arreiem": "arriar",
    "arreies": "arriar",
    "arreiga": "arreigar",
    "arreigada": "arreigar",
    "arreigadas": "arreigar",
    "arreigado": "arreigar",
    "arreigados": "arreigar",
    "arreigai": "arreigar",
    "arreigais": "arreigar",
    "arreigam": "arreigar",
    "arreigamentos": "arreigamento",
    "arreigamo": "arreigar",
    "arreigamos": "arreigar",
    "arreigando": "arreigar",
    "arreigara": "arreigar",
    "arreigaram": "arreigar",
    "arreigaras": "arreigar",
    "arreigarde": "arreigar",
    "arreigardes": "arreigar",
    "arreigare": "arreigar",
    "arreigarei": "arreigar",
    "arreigareis": "arreigar",
    "arreigarem": "arreigar",
    "arreigaremos": "arreigar",
    "arreigares": "arreigar",
    "arreigaria": "arreigar",
    "arreigariam": "arreigar",
    "arreigarias": "arreigar",
    "arreigarmo": "arreigar",
    "arreigarmos": "arreigar",
    "arreigará": "arreigar",
    "arreigarás": "arreigar",
    "arreigarão": "arreigar",
    "arreigaríamos": "arreigar",
    "arreigaríeis": "arreigar",
    "arreigas": "arreigar",
    "arreigasse": "arreigar",
    "arreigassem": "arreigar",
    "arreigasses": "arreigar",
    "arreigaste": "arreigar",
    "arreigastes": "arreigar",
    "arreigava": "arreigar",
    "arreigavam": "arreigar",
    "arreigavas": "arreigar",
    "arreigo": "arreigar",
    "arreigou": "arreigar",
    "arreigue": "arreigar",
    "arreiguei": "arreigar",
    "arreigueis": "arreigar",
    "arreiguem": "arreigar",
    "arreiguemo": "arreigar",
    "arreiguemos": "arreigar",
    "arreigues": "arreigar",
    "arreigá": "arreigar",
    "arreigámo": "arreigar",
    "arreigámos": "arreigar",
    "arreigáramo": "arreigar",
    "arreigáramos": "arreigar",
    "arreigárei": "arreigar",
    "arreigáreis": "arreigar",
    "arreigásseis": "arreigar",
    "arreigássemos": "arreigar",
    "arreigávamo": "arreigar",
    "arreigávamos": "arreigar",
    "arreigávei": "arreigar",
    "arreigáveis": "arreigar",
    "arreio": "arriar",
    "arreios": "arreio",
    "arreitada": "arreitado",
    "arreitadas": "arreitado",
    "arreitados": "arreitado",
    "arreitamentos": "arreitamento",
    "arrelampada": "arrelampado",
    "arrelampadas": "arrelampado",
    "arrelampados": "arrelampado",
    "arrelhadas": "arrelhada",
    "arrelhadora": "arrelhador",
    "arrelhadoras": "arrelhador",
    "arrelhadores": "arrelhador",
    "arrelia": "arreliar",
    "arreliada": "arreliar",
    "arreliadas": "arreliar",
    "arreliado": "arreliar",
    "arreliadora": "arreliador",
    "arreliadoras": "arreliador",
    "arreliadores": "arreliador",
    "arreliados": "arreliar",
    "arreliadíssima": "arreliado",
    "arreliadíssimas": "arreliado",
    "arreliadíssimo": "arreliado",
    "arreliadíssimos": "arreliado",
    "arreliai": "arreliar",
    "arreliais": "arreliar",
    "arreliam": "arreliar",
    "arreliamo": "arreliar",
    "arreliamos": "arreliar",
    "arreliando": "arreliar",
    "arreliantes": "arreliante",
    "arreliara": "arreliar",
    "arreliaram": "arreliar",
    "arreliaras": "arreliar",
    "arreliarde": "arreliar",
    "arreliardes": "arreliar",
    "arreliare": "arreliar",
    "arreliarei": "arreliar",
    "arreliareis": "arreliar",
    "arreliarem": "arreliar",
    "arreliaremos": "arreliar",
    "arreliares": "arreliar",
    "arreliaria": "arreliar",
    "arreliariam": "arreliar",
    "arreliarias": "arreliar",
    "arreliarmo": "arreliar",
    "arreliarmos": "arreliar",
    "arreliará": "arreliar",
    "arreliarás": "arreliar",
    "arreliarão": "arreliar",
    "arreliaríamos": "arreliar",
    "arreliaríeis": "arreliar",
    "arrelias": "arreliar",
    "arreliasse": "arreliar",
    "arreliassem": "arreliar",
    "arreliasses": "arreliar",
    "arreliaste": "arreliar",
    "arreliastes": "arreliar",
    "arreliava": "arreliar",
    "arreliavam": "arreliar",
    "arreliavas": "arreliar",
    "arreliações": "arreliação",
    "arrelie": "arreliar",
    "arreliei": "arreliar",
    "arrelieis": "arreliar",
    "arreliem": "arreliar",
    "arreliemo": "arreliar",
    "arreliemos": "arreliar",
    "arrelienta": "arreliento",
    "arrelientas": "arreliento",
    "arrelientos": "arreliento",
    "arrelies": "arreliar",
    "arrelio": "arreliar",
    "arreliou": "arreliar",
    "arreliá": "arreliar",
    "arreliámo": "arreliar",
    "arreliámos": "arreliar",
    "arreliáramo": "arreliar",
    "arreliáramos": "arreliar",
    "arreliárei": "arreliar",
    "arreliáreis": "arreliar",
    "arreliásseis": "arreliar",
    "arreliássemos": "arreliar",
    "arreliávamo": "arreliar",
    "arreliávamos": "arreliar",
    "arreliávei": "arreliar",
    "arreliáveis": "arreliar",
    "arrelva": "arrelvar",
    "arrelvada": "arrelvar",
    "arrelvadas": "arrelvar",
    "arrelvado": "arrelvar",
    "arrelvados": "arrelvar",
    "arrelvai": "arrelvar",
    "arrelvais": "arrelvar",
    "arrelvam": "arrelvar",
    "arrelvamentos": "arrelvamento",
    "arrelvamo": "arrelvar",
    "arrelvamos": "arrelvar",
    "arrelvando": "arrelvar",
    "arrelvara": "arrelvar",
    "arrelvaram": "arrelvar",
    "arrelvaras": "arrelvar",
    "arrelvarde": "arrelvar",
    "arrelvardes": "arrelvar",
    "arrelvare": "arrelvar",
    "arrelvarei": "arrelvar",
    "arrelvareis": "arrelvar",
    "arrelvarem": "arrelvar",
    "arrelvaremos": "arrelvar",
    "arrelvares": "arrelvar",
    "arrelvaria": "arrelvar",
    "arrelvariam": "arrelvar",
    "arrelvarias": "arrelvar",
    "arrelvarmo": "arrelvar",
    "arrelvarmos": "arrelvar",
    "arrelvará": "arrelvar",
    "arrelvarás": "arrelvar",
    "arrelvarão": "arrelvar",
    "arrelvaríamos": "arrelvar",
    "arrelvaríeis": "arrelvar",
    "arrelvas": "arrelvar",
    "arrelvasse": "arrelvar",
    "arrelvassem": "arrelvar",
    "arrelvasses": "arrelvar",
    "arrelvaste": "arrelvar",
    "arrelvastes": "arrelvar",
    "arrelvava": "arrelvar",
    "arrelvavam": "arrelvar",
    "arrelvavas": "arrelvar",
    "arrelve": "arrelvar",
    "arrelvei": "arrelvar",
    "arrelveis": "arrelvar",
    "arrelvem": "arrelvar",
    "arrelvemo": "arrelvar",
    "arrelvemos": "arrelvar",
    "arrelves": "arrelvar",
    "arrelvo": "arrelvar",
    "arrelvou": "arrelvar",
    "arrelvá": "arrelvar",
    "arrelvámo": "arrelvar",
    "arrelvámos": "arrelvar",
    "arrelváramo": "arrelvar",
    "arrelváramos": "arrelvar",
    "arrelvárei": "arrelvar",
    "arrelváreis": "arrelvar",
    "arrelvásseis": "arrelvar",
    "arrelvássemos": "arrelvar",
    "arrelvávamo": "arrelvar",
    "arrelvávamos": "arrelvar",
    "arrelvávei": "arrelvar",
    "arrelváveis": "arrelvar",
    "arremata": "arrematar",
    "arrematada": "arrematar",
    "arrematadas": "arrematar",
    "arrematado": "arrematar",
    "arrematadora": "arrematador",
    "arrematadoras": "arrematador",
    "arrematadores": "arrematador",
    "arrematados": "arrematar",
    "arrematai": "arrematar",
    "arrematais": "arrematar",
    "arrematam": "arrematar",
    "arrematamo": "arrematar",
    "arrematamos": "arrematar",
    "arrematando": "arrematar",
    "arrematantes": "arrematante",
    "arrematara": "arrematar",
    "arremataram": "arrematar",
    "arremataras": "arrematar",
    "arrematarde": "arrematar",
    "arrematardes": "arrematar",
    "arrematare": "arrematar",
    "arrematarei": "arrematar",
    "arrematareis": "arrematar",
    "arrematarem": "arrematar",
    "arremataremos": "arrematar",
    "arrematares": "arrematar",
    "arremataria": "arrematar",
    "arrematariam": "arrematar",
    "arrematarias": "arrematar",
    "arrematarmo": "arrematar",
    "arrematarmos": "arrematar",
    "arrematará": "arrematar",
    "arrematarás": "arrematar",
    "arrematarão": "arrematar",
    "arremataríamos": "arrematar",
    "arremataríeis": "arrematar",
    "arrematas": "arrematar",
    "arrematasse": "arrematar",
    "arrematassem": "arrematar",
    "arrematasses": "arrematar",
    "arremataste": "arrematar",
    "arrematastes": "arrematar",
    "arrematava": "arrematar",
    "arrematavam": "arrematar",
    "arrematavas": "arrematar",
    "arrematações": "arrematação",
    "arremate": "arrematar",
    "arrematei": "arrematar",
    "arremateis": "arrematar",
    "arrematem": "arrematar",
    "arrematemo": "arrematar",
    "arrematemos": "arrematar",
    "arremates": "arremate",
    "arremato": "arrematar",
    "arrematou": "arrematar",
    "arrematá": "arrematar",
    "arrematámo": "arrematar",
    "arrematámos": "arrematar",
    "arrematáramo": "arrematar",
    "arrematáramos": "arrematar",
    "arrematárei": "arrematar",
    "arrematáreis": "arrematar",
    "arrematásseis": "arrematar",
    "arrematássemos": "arrematar",
    "arrematávamo": "arrematar",
    "arrematávamos": "arrematar",
    "arrematávei": "arrematar",
    "arrematáveis": "arrematável",
    "arremedadora": "arremedador",
    "arremedadoras": "arremedador",
    "arremedadores": "arremedador",
    "arremedilhos": "arremedilho",
    "arremedos": "arremedo",
    "arremendada": "arremendado",
    "arremendadas": "arremendado",
    "arremendados": "arremendado",
    "arremententes": "arrementente",
    "arremesquinhos": "arremesquinho",
    "arremessa": "arremessar",
    "arremessada": "arremessar",
    "arremessadas": "arremessar",
    "arremessado": "arremessar",
    "arremessadora": "arremessador",
    "arremessadoras": "arremessador",
    "arremessadores": "arremessador",
    "arremessados": "arremessar",
    "arremessai": "arremessar",
    "arremessais": "arremessar",
    "arremessam": "arremessar",
    "arremessamentos": "arremessamento",
    "arremessamo": "arremessar",
    "arremessamos": "arremessar",
    "arremessando": "arremessar",
    "arremessara": "arremessar",
    "arremessaram": "arremessar",
    "arremessaras": "arremessar",
    "arremessarde": "arremessar",
    "arremessardes": "arremessar",
    "arremessare": "arremessar",
    "arremessarei": "arremessar",
    "arremessareis": "arremessar",
    "arremessarem": "arremessar",
    "arremessaremos": "arremessar",
    "arremessares": "arremessar",
    "arremessaria": "arremessar",
    "arremessariam": "arremessar",
    "arremessarias": "arremessar",
    "arremessarmo": "arremessar",
    "arremessarmos": "arremessar",
    "arremessará": "arremessar",
    "arremessarás": "arremessar",
    "arremessarão": "arremessar",
    "arremessaríamos": "arremessar",
    "arremessaríeis": "arremessar",
    "arremessas": "arremessar",
    "arremessasse": "arremessar",
    "arremessassem": "arremessar",
    "arremessasses": "arremessar",
    "arremessaste": "arremessar",
    "arremessastes": "arremessar",
    "arremessava": "arremessar",
    "arremessavam": "arremessar",
    "arremessavas": "arremessar",
    "arremesse": "arremessar",
    "arremessei": "arremessar",
    "arremesseis": "arremessar",
    "arremessem": "arremessar",
    "arremessemo": "arremessar",
    "arremessemos": "arremessar",
    "arremesses": "arremessar",
    "arremesso": "arremessar",
    "arremessos": "arremesso",
    "arremessou": "arremessar",
    "arremessá": "arremessar",
    "arremessámo": "arremessar",
    "arremessámos": "arremessar",
    "arremessáramo": "arremessar",
    "arremessáramos": "arremessar",
    "arremessárei": "arremessar",
    "arremessáreis": "arremessar",
    "arremessásseis": "arremessar",
    "arremessássemos": "arremessar",
    "arremessávamo": "arremessar",
    "arremessávamos": "arremessar",
    "arremessávei": "arremessar",
    "arremessáveis": "arremessar",
    "arremessões": "arremessão",
    "arremeta": "arremeter",
    "arremetais": "arremeter",
    "arremetam": "arremeter",
    "arremetamo": "arremeter",
    "arremetamos": "arremeter",
    "arremetas": "arremeter",
    "arremete": "arremeter",
    "arremetedora": "arremetedor",
    "arremetedoras": "arremetedor",
    "arremetedores": "arremetedor",
    "arremetei": "arremeter",
    "arremeteis": "arremeter",
    "arremetem": "arremeter",
    "arremetemo": "arremeter",
    "arremetemos": "arremeter",
    "arremetendo": "arremeter",
    "arremetera": "arremeter",
    "arremeteram": "arremeter",
    "arremeteras": "arremeter",
    "arremeterdes": "arremeter",
    "arremeterei": "arremeter",
    "arremetereis": "arremeter",
    "arremeterem": "arremeter",
    "arremeteremos": "arremeter",
    "arremeteres": "arremeter",
    "arremeteria": "arremeter",
    "arremeteriam": "arremeter",
    "arremeterias": "arremeter",
    "arremetermo": "arremeter",
    "arremetermos": "arremeter",
    "arremeterá": "arremeter",
    "arremeterás": "arremeter",
    "arremeterão": "arremeter",
    "arremeteríamos": "arremeter",
    "arremeteríeis": "arremeter",
    "arremetes": "arremeter",
    "arremetesse": "arremeter",
    "arremetessem": "arremeter",
    "arremetesses": "arremeter",
    "arremeteste": "arremeter",
    "arremetestes": "arremeter",
    "arremeteu": "arremeter",
    "arremeti": "arremeter",
    "arremetia": "arremeter",
    "arremetiam": "arremeter",
    "arremetias": "arremeter",
    "arremetida": "arremeter",
    "arremetidas": "arremetida",
    "arremetido": "arremeter",
    "arremetidos": "arremeter",
    "arremetimentos": "arremetimento",
    "arremeto": "arremeter",
    "arremetêramo": "arremeter",
    "arremetêramos": "arremeter",
    "arremetêreis": "arremeter",
    "arremetêsseis": "arremeter",
    "arremetêssemos": "arremeter",
    "arremetíamo": "arremeter",
    "arremetíamos": "arremeter",
    "arremetíeis": "arremeter",
    "arremeções": "arremeção",
    "arreminações": "arreminação",
    "arrenagados": "arrenagado",
    "arrenais": "arrenal",
    "arrenda": "arrendar",
    "arrendada": "arrendar",
    "arrendadas": "arrendar",
    "arrendado": "arrendar",
    "arrendadora": "arrendador",
    "arrendadoras": "arrendador",
    "arrendadores": "arrendador",
    "arrendados": "arrendar",
    "arrendai": "arrendar",
    "arrendais": "arrendar",
    "arrendam": "arrendar",
    "arrendamentos": "arrendamento",
    "arrendamo": "arrendar",
    "arrendamos": "arrendar",
    "arrendando": "arrendar",
    "arrendara": "arrendar",
    "arrendaram": "arrendar",
    "arrendaras": "arrendar",
    "arrendarde": "arrendar",
    "arrendardes": "arrendar",
    "arrendare": "arrendar",
    "arrendarei": "arrendar",
    "arrendareis": "arrendar",
    "arrendarem": "arrendar",
    "arrendaremos": "arrendar",
    "arrendares": "arrendar",
    "arrendaria": "arrendar",
    "arrendariam": "arrendar",
    "arrendarias": "arrendar",
    "arrendarmo": "arrendar",
    "arrendarmos": "arrendar",
    "arrendará": "arrendar",
    "arrendarás": "arrendar",
    "arrendarão": "arrendar",
    "arrendaríamos": "arrendar",
    "arrendaríeis": "arrendar",
    "arrendas": "arrendar",
    "arrendasse": "arrendar",
    "arrendassem": "arrendar",
    "arrendasses": "arrendar",
    "arrendaste": "arrendar",
    "arrendastes": "arrendar",
    "arrendatários": "arrendatário",
    "arrendava": "arrendar",
    "arrendavam": "arrendar",
    "arrendavas": "arrendar",
    "arrendações": "arrendação",
    "arrende": "arrendar",
    "arrendei": "arrendar",
    "arrendeis": "arrendar",
    "arrendem": "arrendar",
    "arrendemo": "arrendar",
    "arrendemos": "arrendar",
    "arrendes": "arrendar",
    "arrendo": "arrendar",
    "arrendou": "arrendar",
    "arrendá": "arrendar",
    "arrendámo": "arrendar",
    "arrendámos": "arrendar",
    "arrendáramo": "arrendar",
    "arrendáramos": "arrendar",
    "arrendárei": "arrendar",
    "arrendáreis": "arrendar",
    "arrendásseis": "arrendar",
    "arrendássemos": "arrendar",
    "arrendávamo": "arrendar",
    "arrendávamos": "arrendar",
    "arrendávei": "arrendar",
    "arrendáveis": "arrendável",
    "arrenega": "arrenegar",
    "arrenegada": "arrenegar",
    "arrenegadas": "arrenegar",
    "arrenegado": "arrenegar",
    "arrenegadora": "arrenegador",
    "arrenegadoras": "arrenegador",
    "arrenegadores": "arrenegador",
    "arrenegados": "arrenegar",
    "arrenegai": "arrenegar",
    "arrenegais": "arrenegar",
    "arrenegam": "arrenegar",
    "arrenegamo": "arrenegar",
    "arrenegamos": "arrenegar",
    "arrenegando": "arrenegar",
    "arrenegara": "arrenegar",
    "arrenegaram": "arrenegar",
    "arrenegaras": "arrenegar",
    "arrenegarde": "arrenegar",
    "arrenegardes": "arrenegar",
    "arrenegare": "arrenegar",
    "arrenegarei": "arrenegar",
    "arrenegareis": "arrenegar",
    "arrenegarem": "arrenegar",
    "arrenegaremos": "arrenegar",
    "arrenegares": "arrenegar",
    "arrenegaria": "arrenegar",
    "arrenegariam": "arrenegar",
    "arrenegarias": "arrenegar",
    "arrenegarmo": "arrenegar",
    "arrenegarmos": "arrenegar",
    "arrenegará": "arrenegar",
    "arrenegarás": "arrenegar",
    "arrenegarão": "arrenegar",
    "arrenegaríamos": "arrenegar",
    "arrenegaríeis": "arrenegar",
    "arrenegas": "arrenegar",
    "arrenegasse": "arrenegar",
    "arrenegassem": "arrenegar",
    "arrenegasses": "arrenegar",
    "arrenegaste": "arrenegar",
    "arrenegastes": "arrenegar",
    "arrenegava": "arrenegar",
    "arrenegavam": "arrenegar",
    "arrenegavas": "arrenegar",
    "arrenegações": "arrenegação",
    "arrenego": "arrenegar",
    "arrenegos": "arrenego",
    "arrenegou": "arrenegar",
    "arrenegue": "arrenegar",
    "arreneguei": "arrenegar",
    "arrenegueis": "arrenegar",
    "arreneguem": "arrenegar",
    "arreneguemo": "arrenegar",
    "arreneguemos": "arrenegar",
    "arrenegues": "arrenegar",
    "arrenegá": "arrenegar",
    "arrenegámo": "arrenegar",
    "arrenegámos": "arrenegar",
    "arrenegáramo": "arrenegar",
    "arrenegáramos": "arrenegar",
    "arrenegárei": "arrenegar",
    "arrenegáreis": "arrenegar",
    "arrenegásseis": "arrenegar",
    "arrenegássemos": "arrenegar",
    "arrenegávamo": "arrenegar",
    "arrenegávamos": "arrenegar",
    "arrenegávei": "arrenegar",
    "arrenegáveis": "arrenegar",
    "arreneiros": "arreneiro",
    "arreou": "arrear",
    "arrepanha": "arrepanhar",
    "arrepanhada": "arrepanhar",
    "arrepanhadas": "arrepanhar",
    "arrepanhado": "arrepanhar",
    "arrepanhados": "arrepanhar",
    "arrepanhai": "arrepanhar",
    "arrepanhais": "arrepanhar",
    "arrepanham": "arrepanhar",
    "arrepanhamo": "arrepanhar",
    "arrepanhamos": "arrepanhar",
    "arrepanhando": "arrepanhar",
    "arrepanhara": "arrepanhar",
    "arrepanharam": "arrepanhar",
    "arrepanharas": "arrepanhar",
    "arrepanharde": "arrepanhar",
    "arrepanhardes": "arrepanhar",
    "arrepanhare": "arrepanhar",
    "arrepanharei": "arrepanhar",
    "arrepanhareis": "arrepanhar",
    "arrepanharem": "arrepanhar",
    "arrepanharemos": "arrepanhar",
    "arrepanhares": "arrepanhar",
    "arrepanharia": "arrepanhar",
    "arrepanhariam": "arrepanhar",
    "arrepanharias": "arrepanhar",
    "arrepanharmo": "arrepanhar",
    "arrepanharmos": "arrepanhar",
    "arrepanhará": "arrepanhar",
    "arrepanharás": "arrepanhar",
    "arrepanharão": "arrepanhar",
    "arrepanharíamos": "arrepanhar",
    "arrepanharíeis": "arrepanhar",
    "arrepanhas": "arrepanhar",
    "arrepanhasse": "arrepanhar",
    "arrepanhassem": "arrepanhar",
    "arrepanhasses": "arrepanhar",
    "arrepanhaste": "arrepanhar",
    "arrepanhastes": "arrepanhar",
    "arrepanhava": "arrepanhar",
    "arrepanhavam": "arrepanhar",
    "arrepanhavas": "arrepanhar",
    "arrepanhe": "arrepanhar",
    "arrepanhei": "arrepanhar",
    "arrepanheis": "arrepanhar",
    "arrepanhem": "arrepanhar",
    "arrepanhemo": "arrepanhar",
    "arrepanhemos": "arrepanhar",
    "arrepanhes": "arrepanhar",
    "arrepanho": "arrepanhar",
    "arrepanhos": "arrepanho",
    "arrepanhou": "arrepanhar",
    "arrepanhá": "arrepanhar",
    "arrepanhámo": "arrepanhar",
    "arrepanhámos": "arrepanhar",
    "arrepanháramo": "arrepanhar",
    "arrepanháramos": "arrepanhar",
    "arrepanhárei": "arrepanhar",
    "arrepanháreis": "arrepanhar",
    "arrepanhásseis": "arrepanhar",
    "arrepanhássemos": "arrepanhar",
    "arrepanhávamo": "arrepanhar",
    "arrepanhávamos": "arrepanhar",
    "arrepanhávei": "arrepanhar",
    "arrepanháveis": "arrepanhar",
    "arrepela": "arrepelar",
    "arrepelada": "arrepelar",
    "arrepeladas": "arrepelar",
    "arrepeladelas": "arrepeladela",
    "arrepelado": "arrepelar",
    "arrepeladora": "arrepelador",
    "arrepeladoras": "arrepelador",
    "arrepeladores": "arrepelador",
    "arrepelados": "arrepelar",
    "arrepelai": "arrepelar",
    "arrepelais": "arrepelar",
    "arrepelam": "arrepelar",
    "arrepelamo": "arrepelar",
    "arrepelamos": "arrepelar",
    "arrepelando": "arrepelar",
    "arrepelara": "arrepelar",
    "arrepelaram": "arrepelar",
    "arrepelaras": "arrepelar",
    "arrepelarde": "arrepelar",
    "arrepelardes": "arrepelar",
    "arrepelare": "arrepelar",
    "arrepelarei": "arrepelar",
    "arrepelareis": "arrepelar",
    "arrepelarem": "arrepelar",
    "arrepelaremos": "arrepelar",
    "arrepelares": "arrepelar",
    "arrepelaria": "arrepelar",
    "arrepelariam": "arrepelar",
    "arrepelarias": "arrepelar",
    "arrepelarmo": "arrepelar",
    "arrepelarmos": "arrepelar",
    "arrepelará": "arrepelar",
    "arrepelarás": "arrepelar",
    "arrepelarão": "arrepelar",
    "arrepelaríamos": "arrepelar",
    "arrepelaríeis": "arrepelar",
    "arrepelas": "arrepelar",
    "arrepelasse": "arrepelar",
    "arrepelassem": "arrepelar",
    "arrepelasses": "arrepelar",
    "arrepelaste": "arrepelar",
    "arrepelastes": "arrepelar",
    "arrepelava": "arrepelar",
    "arrepelavam": "arrepelar",
    "arrepelavas": "arrepelar",
    "arrepelações": "arrepelação",
    "arrepele": "arrepelar",
    "arrepelei": "arrepelar",
    "arrepeleis": "arrepelar",
    "arrepelem": "arrepelar",
    "arrepelemo": "arrepelar",
    "arrepelemos": "arrepelar",
    "arrepeles": "arrepelar",
    "arrepelo": "arrepelar",
    "arrepelos": "arrepelo",
    "arrepelou": "arrepelar",
    "arrepelá": "arrepelar",
    "arrepelámo": "arrepelar",
    "arrepelámos": "arrepelar",
    "arrepeláramo": "arrepelar",
    "arrepeláramos": "arrepelar",
    "arrepelárei": "arrepelar",
    "arrepeláreis": "arrepelar",
    "arrepelásseis": "arrepelar",
    "arrepelássemos": "arrepelar",
    "arrepelávamo": "arrepelar",
    "arrepelávamos": "arrepelar",
    "arrepelávei": "arrepelar",
    "arrepeláveis": "arrepelar",
    "arrepelões": "arrepelão",
    "arrependa": "arrepender",
    "arrependais": "arrepender",
    "arrependam": "arrepender",
    "arrependamo": "arrepender",
    "arrependamos": "arrepender",
    "arrependas": "arrepender",
    "arrepende": "arrepender",
    "arrependei": "arrepender",
    "arrependeis": "arrepender",
    "arrependem": "arrepender",
    "arrependemo": "arrepender",
    "arrependemos": "arrepender",
    "arrependendo": "arrepender",
    "arrependera": "arrepender",
    "arrependeram": "arrepender",
    "arrependeras": "arrepender",
    "arrependerde": "arrepender",
    "arrependerdes": "arrepender",
    "arrependere": "arrepender",
    "arrependerei": "arrepender",
    "arrependereis": "arrepender",
    "arrependerem": "arrepender",
    "arrependeremos": "arrepender",
    "arrependeres": "arrepender",
    "arrependeria": "arrepender",
    "arrependeriam": "arrepender",
    "arrependerias": "arrepender",
    "arrependermo": "arrepender",
    "arrependermos": "arrepender",
    "arrependerá": "arrepender",
    "arrependerás": "arrepender",
    "arrependerão": "arrepender",
    "arrependeríamos": "arrepender",
    "arrependeríeis": "arrepender",
    "arrependes": "arrepender",
    "arrependesse": "arrepender",
    "arrependessem": "arrepender",
    "arrependesses": "arrepender",
    "arrependeste": "arrepender",
    "arrependestes": "arrepender",
    "arrependeu": "arrepender",
    "arrependi": "arrepender",
    "arrependia": "arrepender",
    "arrependiam": "arrepender",
    "arrependias": "arrepender",
    "arrependida": "arrependido",
    "arrependidas": "arrependido",
    "arrependidinha": "arrependido",
    "arrependidinhas": "arrependido",
    "arrependidinho": "arrependido",
    "arrependidinhos": "arrependido",
    "arrependidita": "arrependido",
    "arrependiditas": "arrependido",
    "arrependidito": "arrependido",
    "arrependiditos": "arrependido",
    "arrependido": "arrepender",
    "arrependidos": "arrependido",
    "arrependidíssima": "arrependido",
    "arrependidíssimas": "arrependido",
    "arrependidíssimo": "arrependido",
    "arrependidíssimos": "arrependido",
    "arrependimentos": "arrependimento",
    "arrependo": "arrepender",
    "arrependê": "arrepender",
    "arrependêramo": "arrepender",
    "arrependêramos": "arrepender",
    "arrependêrei": "arrepender",
    "arrependêreis": "arrepender",
    "arrependêsseis": "arrepender",
    "arrependêssemos": "arrepender",
    "arrependíamo": "arrepender",
    "arrependíamos": "arrepender",
    "arrependíei": "arrepender",
    "arrependíeis": "arrepender",
    "arrepia": "arrepiar",
    "arrepiada": "arrepiar",
    "arrepiadas": "arrepiar",
    "arrepiado": "arrepiar",
    "arrepiadora": "arrepiador",
    "arrepiadoras": "arrepiador",
    "arrepiadores": "arrepiador",
    "arrepiados": "arrepiar",
    "arrepiadíssima": "arrepiado",
    "arrepiadíssimas": "arrepiado",
    "arrepiadíssimo": "arrepiado",
    "arrepiadíssimos": "arrepiado",
    "arrepiai": "arrepiar",
    "arrepiais": "arrepiar",
    "arrepiam": "arrepiar",
    "arrepiamentos": "arrepiamento",
    "arrepiamo": "arrepiar",
    "arrepiamos": "arrepiar",
    "arrepiando": "arrepiar",
    "arrepiantes": "arrepiante",
    "arrepiara": "arrepiar",
    "arrepiaram": "arrepiar",
    "arrepiaras": "arrepiar",
    "arrepiarde": "arrepiar",
    "arrepiardes": "arrepiar",
    "arrepiare": "arrepiar",
    "arrepiarei": "arrepiar",
    "arrepiareis": "arrepiar",
    "arrepiarem": "arrepiar",
    "arrepiaremos": "arrepiar",
    "arrepiares": "arrepiar",
    "arrepiaria": "arrepiar",
    "arrepiariam": "arrepiar",
    "arrepiarias": "arrepiar",
    "arrepiarmo": "arrepiar",
    "arrepiarmos": "arrepiar",
    "arrepiará": "arrepiar",
    "arrepiarás": "arrepiar",
    "arrepiarão": "arrepiar",
    "arrepiaríamos": "arrepiar",
    "arrepiaríeis": "arrepiar",
    "arrepias": "arrepiar",
    "arrepiasse": "arrepiar",
    "arrepiassem": "arrepiar",
    "arrepiasses": "arrepiar",
    "arrepiaste": "arrepiar",
    "arrepiastes": "arrepiar",
    "arrepiava": "arrepiar",
    "arrepiavam": "arrepiar",
    "arrepiavas": "arrepiar",
    "arrepie": "arrepiar",
    "arrepiei": "arrepiar",
    "arrepieis": "arrepiar",
    "arrepiem": "arrepiar",
    "arrepiemo": "arrepiar",
    "arrepiemos": "arrepiar",
    "arrepies": "arrepiar",
    "arrepio": "arrepiar",
    "arrepios": "arrepio",
    "arrepiou": "arrepiar",
    "arrepiá": "arrepiar",
    "arrepiámo": "arrepiar",
    "arrepiámos": "arrepiar",
    "arrepiáramo": "arrepiar",
    "arrepiáramos": "arrepiar",
    "arrepiárei": "arrepiar",
    "arrepiáreis": "arrepiar",
    "arrepiásseis": "arrepiar",
    "arrepiássemos": "arrepiar",
    "arrepiávamo": "arrepiar",
    "arrepiávamos": "arrepiar",
    "arrepiávei": "arrepiar",
    "arrepiáveis": "arrepiar",
    "arrepsias": "arrepsia",
    "arrequifes": "arrequife",
    "arrequins": "arrequim",
    "arresta": "arrestar",
    "arrestada": "arrestar",
    "arrestadas": "arrestar",
    "arrestado": "arrestar",
    "arrestados": "arrestar",
    "arrestai": "arrestar",
    "arrestais": "arrestar",
    "arrestam": "arrestar",
    "arrestamentos": "arrestamento",
    "arrestamo": "arrestar",
    "arrestamos": "arrestar",
    "arrestando": "arrestar",
    "arrestantes": "arrestante",
    "arrestara": "arrestar",
    "arrestaram": "arrestar",
    "arrestaras": "arrestar",
    "arrestarde": "arrestar",
    "arrestardes": "arrestar",
    "arrestare": "arrestar",
    "arrestarei": "arrestar",
    "arrestareis": "arrestar",
    "arrestarem": "arrestar",
    "arrestaremos": "arrestar",
    "arrestares": "arrestar",
    "arrestaria": "arrestar",
    "arrestariam": "arrestar",
    "arrestarias": "arrestar",
    "arrestarmo": "arrestar",
    "arrestarmos": "arrestar",
    "arrestará": "arrestar",
    "arrestarás": "arrestar",
    "arrestarão": "arrestar",
    "arrestaríamos": "arrestar",
    "arrestaríeis": "arrestar",
    "arrestas": "arrestar",
    "arrestasse": "arrestar",
    "arrestassem": "arrestar",
    "arrestasses": "arrestar",
    "arrestaste": "arrestar",
    "arrestastes": "arrestar",
    "arrestava": "arrestar",
    "arrestavam": "arrestar",
    "arrestavas": "arrestar",
    "arreste": "arrestar",
    "arrestei": "arrestar",
    "arresteis": "arrestar",
    "arrestem": "arrestar",
    "arrestemo": "arrestar",
    "arrestemos": "arrestar",
    "arrestes": "arrestar",
    "arresto": "arrestar",
    "arrestos": "arresto",
    "arrestou": "arrestar",
    "arrestá": "arrestar",
    "arrestámo": "arrestar",
    "arrestámos": "arrestar",
    "arrestáramo": "arrestar",
    "arrestáramos": "arrestar",
    "arrestárei": "arrestar",
    "arrestáreis": "arrestar",
    "arrestásseis": "arrestar",
    "arrestássemos": "arrestar",
    "arrestávamo": "arrestar",
    "arrestávamos": "arrestar",
    "arrestávei": "arrestar",
    "arrestáveis": "arrestar",
    "arreta": "arretar",
    "arretada": "arretar",
    "arretadas": "arretar",
    "arretado": "arretar",
    "arretados": "arretar",
    "arretaduras": "arretadura",
    "arretai": "arretar",
    "arretais": "arretar",
    "arretam": "arretar",
    "arretamo": "arretar",
    "arretamos": "arretar",
    "arretando": "arretar",
    "arretara": "arretar",
    "arretaram": "arretar",
    "arretaras": "arretar",
    "arretarde": "arretar",
    "arretardes": "arretar",
    "arretare": "arretar",
    "arretarei": "arretar",
    "arretareis": "arretar",
    "arretarem": "arretar",
    "arretaremos": "arretar",
    "arretares": "arretar",
    "arretaria": "arretar",
    "arretariam": "arretar",
    "arretarias": "arretar",
    "arretarmo": "arretar",
    "arretarmos": "arretar",
    "arretará": "arretar",
    "arretarás": "arretar",
    "arretarão": "arretar",
    "arretaríamos": "arretar",
    "arretaríeis": "arretar",
    "arretas": "arretar",
    "arretasse": "arretar",
    "arretassem": "arretar",
    "arretasses": "arretar",
    "arretaste": "arretar",
    "arretastes": "arretar",
    "arretava": "arretar",
    "arretavam": "arretar",
    "arretavas": "arretar",
    "arrete": "arretar",
    "arretei": "arretar",
    "arreteis": "arretel",
    "arretem": "arretar",
    "arretemo": "arretar",
    "arretemos": "arretar",
    "arretes": "arretar",
    "arreto": "arretar",
    "arretos": "arreto",
    "arretou": "arretar",
    "arretrasada": "arretrasado",
    "arretrasadas": "arretrasado",
    "arretrasados": "arretrasado",
    "arretá": "arretar",
    "arretámo": "arretar",
    "arretámos": "arretar",
    "arretáramo": "arretar",
    "arretáramos": "arretar",
    "arretárei": "arretar",
    "arretáreis": "arretar",
    "arretásseis": "arretar",
    "arretássemos": "arretar",
    "arretávamo": "arretar",
    "arretávamos": "arretar",
    "arretávei": "arretar",
    "arretáveis": "arretar",
    "arrevesa": "arrevesar",
    "arrevesada": "arrevesar",
    "arrevesadas": "arrevesar",
    "arrevesadinha": "arrevesado",
    "arrevesadinhas": "arrevesado",
    "arrevesadinho": "arrevesado",
    "arrevesadinhos": "arrevesado",
    "arrevesadita": "arrevesado",
    "arrevesaditas": "arrevesado",
    "arrevesadito": "arrevesado",
    "arrevesaditos": "arrevesado",
    "arrevesado": "arrevesar",
    "arrevesados": "arrevesar",
    "arrevesadíssima": "arrevesado",
    "arrevesadíssimas": "arrevesado",
    "arrevesadíssimo": "arrevesado",
    "arrevesadíssimos": "arrevesado",
    "arrevesai": "arrevesar",
    "arrevesais": "arrevesar",
    "arrevesam": "arrevesar",
    "arrevesamentos": "arrevesamento",
    "arrevesamo": "arrevesar",
    "arrevesamos": "arrevesar",
    "arrevesando": "arrevesar",
    "arrevesara": "arrevesar",
    "arrevesaram": "arrevesar",
    "arrevesaras": "arrevesar",
    "arrevesarde": "arrevesar",
    "arrevesardes": "arrevesar",
    "arrevesare": "arrevesar",
    "arrevesarei": "arrevesar",
    "arrevesareis": "arrevesar",
    "arrevesarem": "arrevesar",
    "arrevesaremos": "arrevesar",
    "arrevesares": "arrevesar",
    "arrevesaria": "arrevesar",
    "arrevesariam": "arrevesar",
    "arrevesarias": "arrevesar",
    "arrevesarmo": "arrevesar",
    "arrevesarmos": "arrevesar",
    "arrevesará": "arrevesar",
    "arrevesarás": "arrevesar",
    "arrevesarão": "arrevesar",
    "arrevesaríamos": "arrevesar",
    "arrevesaríeis": "arrevesar",
    "arrevesas": "arrevesar",
    "arrevesasse": "arrevesar",
    "arrevesassem": "arrevesar",
    "arrevesasses": "arrevesar",
    "arrevesaste": "arrevesar",
    "arrevesastes": "arrevesar",
    "arrevesava": "arrevesar",
    "arrevesavam": "arrevesar",
    "arrevesavas": "arrevesar",
    "arrevese": "arrevesar",
    "arrevesei": "arrevesar",
    "arreveseis": "arrevesar",
    "arrevesem": "arrevesar",
    "arrevesemo": "arrevesar",
    "arrevesemos": "arrevesar",
    "arreveses": "arrevesar",
    "arreveso": "arrevesar",
    "arrevesou": "arrevesar",
    "arrevessos": "arrevesso",
    "arrevesá": "arrevesar",
    "arrevesámo": "arrevesar",
    "arrevesámos": "arrevesar",
    "arrevesáramo": "arrevesar",
    "arrevesáramos": "arrevesar",
    "arrevesárei": "arrevesar",
    "arrevesáreis": "arrevesar",
    "arrevesásseis": "arrevesar",
    "arrevesássemos": "arrevesar",
    "arrevesávamo": "arrevesar",
    "arrevesávamos": "arrevesar",
    "arrevesávei": "arrevesar",
    "arrevesáveis": "arrevesar",
    "arreá": "arrear",
    "arreámo": "arrear",
    "arreámos": "arrear",
    "arreáramo": "arrear",
    "arreáramos": "arrear",
    "arreárei": "arrear",
    "arreáreis": "arrear",
    "arreásseis": "arrear",
    "arreássemos": "arrear",
    "arreávamo": "arrear",
    "arreávamos": "arrear",
    "arreávei": "arrear",
    "arreáveis": "arrear",
    "arriada": "arriar",
    "arriadas": "arriar",
    "arriadeiras": "arriadeira",
    "arriado": "arriar",
    "arriados": "arriar",
    "arriai": "arriar",
    "arriais": "arriar",
    "arriamentos": "arriamento",
    "arriamo": "arriar",
    "arriamos": "arriar",
    "arriando": "arriar",
    "arriara": "arriar",
    "arriaram": "arriar",
    "arriaras": "arriar",
    "arriarde": "arriar",
    "arriardes": "arriar",
    "arriare": "arriar",
    "arriarei": "arriar",
    "arriareis": "arriar",
    "arriarem": "arriar",
    "arriaremos": "arriar",
    "arriares": "arriar",
    "arriaria": "arriar",
    "arriariam": "arriar",
    "arriarias": "arriar",
    "arriarmo": "arriar",
    "arriarmos": "arriar",
    "arriará": "arriar",
    "arriarás": "arriar",
    "arriarão": "arriar",
    "arriaríamos": "arriar",
    "arriaríeis": "arriar",
    "arriasse": "arriar",
    "arriassem": "arriar",
    "arriasses": "arriar",
    "arriaste": "arriar",
    "arriastes": "arriar",
    "arriava": "arriar",
    "arriavam": "arriar",
    "arriavas": "arriar",
    "arriazes": "arriaz",
    "arriações": "arriação",
    "arriba": "arribar",
    "arribada": "arribar",
    "arribadas": "arribar",
    "arribadeiras": "arribadeira",
    "arribadeiros": "arribadeiro",
    "arribadiça": "arribadiço",
    "arribadiças": "arribadiço",
    "arribadiços": "arribadiço",
    "arribado": "arribar",
    "arribados": "arribar",
    "arribai": "arribar",
    "arribais": "arribar",
    "arribam": "arribar",
    "arribamo": "arribar",
    "arribamos": "arribar",
    "arribanas": "arribana",
    "arribanceirados": "arribanceirado",
    "arribando": "arribar",
    "arribara": "arribar",
    "arribaram": "arribar",
    "arribaras": "arribar",
    "arribardes": "arribar",
    "arribarei": "arribar",
    "arribareis": "arribar",
    "arribarem": "arribar",
    "arribaremos": "arribar",
    "arribares": "arribar",
    "arribaria": "arribar",
    "arribariam": "arribar",
    "arribarias": "arribar",
    "arribarmo": "arribar",
    "arribarmos": "arribar",
    "arribará": "arribar",
    "arribarás": "arribar",
    "arribarão": "arribar",
    "arribaríamos": "arribar",
    "arribaríeis": "arribar",
    "arribas": "arribar",
    "arribasse": "arribar",
    "arribassem": "arribar",
    "arribasses": "arribar",
    "arribaste": "arribar",
    "arribastes": "arribar",
    "arribava": "arribar",
    "arribavam": "arribar",
    "arribavas": "arribar",
    "arribações": "arribação",
    "arribe": "arribar",
    "arribei": "arribar",
    "arribeis": "arribar",
    "arribem": "arribar",
    "arribemo": "arribar",
    "arribemos": "arribar",
    "arribes": "arribe",
    "arribo": "arribar",
    "arribou": "arribar",
    "arribámo": "arribar",
    "arribámos": "arribar",
    "arribáramo": "arribar",
    "arribáramos": "arribar",
    "arribáreis": "arribar",
    "arribásseis": "arribar",
    "arribássemos": "arribar",
    "arribávamo": "arribar",
    "arribávamos": "arribar",
    "arribáveis": "arribar",
    "arrice": "arriçarriçar",
    "arricei": "arriçar",
    "arriceis": "arriçarriçar",
    "arricem": "arriçarriçar",
    "arricemo": "arriçar",
    "arricemos": "arriçarriçar",
    "arrices": "arriçarriçar",
    "arridas": "arrida",
    "arriei": "arriar",
    "arrieirada": "arrieirado",
    "arrieiradas": "arrieirado",
    "arrieirados": "arrieirado",
    "arrieirais": "arrieiral",
    "arrieiros": "arrieiro",
    "arrieirática": "arrieirático",
    "arrieiráticas": "arrieirático",
    "arrieiráticos": "arrieirático",
    "arrieis": "arriel",
    "arriemo": "arriar",
    "arriemos": "arriar",
    "arrifanas": "arrifana",
    "arrifeiros": "arrifeiro",
    "arrifes": "arrife",
    "arrilhadas": "arrilhada",
    "arrima": "arrimar",
    "arrimada": "arrimar",
    "arrimadas": "arrimar",
    "arrimadiça": "arrimadiço",
    "arrimadiças": "arrimadiço",
    "arrimadiços": "arrimadiço",
    "arrimado": "arrimar",
    "arrimadora": "arrimador",
    "arrimadoras": "arrimador",
    "arrimadores": "arrimador",
    "arrimados": "arrimar",
    "arrimai": "arrimar",
    "arrimais": "arrimar",
    "arrimam": "arrimar",
    "arrimamo": "arrimar",
    "arrimamos": "arrimar",
    "arrimando": "arrimar",
    "arrimara": "arrimar",
    "arrimaram": "arrimar",
    "arrimaras": "arrimar",
    "arrimarde": "arrimar",
    "arrimardes": "arrimar",
    "arrimare": "arrimar",
    "arrimarei": "arrimar",
    "arrimareis": "arrimar",
    "arrimarem": "arrimar",
    "arrimaremos": "arrimar",
    "arrimares": "arrimar",
    "arrimaria": "arrimar",
    "arrimariam": "arrimar",
    "arrimarias": "arrimar",
    "arrimarmo": "arrimar",
    "arrimarmos": "arrimar",
    "arrimará": "arrimar",
    "arrimarás": "arrimar",
    "arrimarão": "arrimar",
    "arrimaríamos": "arrimar",
    "arrimaríeis": "arrimar",
    "arrimas": "arrimar",
    "arrimasse": "arrimar",
    "arrimassem": "arrimar",
    "arrimasses": "arrimar",
    "arrimaste": "arrimar",
    "arrimastes": "arrimar",
    "arrimava": "arrimar",
    "arrimavam": "arrimar",
    "arrimavas": "arrimar",
    "arrime": "arrimar",
    "arrimei": "arrimar",
    "arrimeis": "arrimar",
    "arrimem": "arrimar",
    "arrimemo": "arrimar",
    "arrimemos": "arrimar",
    "arrimes": "arrimar",
    "arrimo": "arrimar",
    "arrimos": "arrimo",
    "arrimou": "arrimar",
    "arrimá": "arrimar",
    "arrimámo": "arrimar",
    "arrimámos": "arrimar",
    "arrimáramo": "arrimar",
    "arrimáramos": "arrimar",
    "arrimárei": "arrimar",
    "arrimáreis": "arrimar",
    "arrimásseis": "arrimar",
    "arrimássemos": "arrimar",
    "arrimávamo": "arrimar",
    "arrimávamos": "arrimar",
    "arrimávei": "arrimar",
    "arrimáveis": "arrimar",
    "arrioscas": "arriosca",
    "arrioses": "arriós",
    "arriotas": "arriota",
    "arriou": "arriar",
    "arrisca": "arriscar",
    "arriscada": "arriscar",
    "arriscadas": "arriscar",
    "arriscado": "arriscar",
    "arriscados": "arriscar",
    "arriscadíssima": "arriscado",
    "arriscadíssimas": "arriscado",
    "arriscadíssimo": "arriscado",
    "arriscadíssimos": "arriscado",
    "arriscai": "arriscar",
    "arriscais": "arriscar",
    "arriscam": "arriscar",
    "arriscamo": "arriscar",
    "arriscamos": "arriscar",
    "arriscando": "arriscar",
    "arriscanços": "arriscanço",
    "arriscara": "arriscar",
    "arriscaram": "arriscar",
    "arriscaras": "arriscar",
    "arriscarde": "arriscar",
    "arriscardes": "arriscar",
    "arriscare": "arriscar",
    "arriscarei": "arriscar",
    "arriscareis": "arriscar",
    "arriscarem": "arriscar",
    "arriscaremos": "arriscar",
    "arriscares": "arriscar",
    "arriscaria": "arriscar",
    "arriscariam": "arriscar",
    "arriscarias": "arriscar",
    "arriscarmo": "arriscar",
    "arriscarmos": "arriscar",
    "arriscará": "arriscar",
    "arriscarás": "arriscar",
    "arriscarão": "arriscar",
    "arriscaríamos": "arriscar",
    "arriscaríeis": "arriscar",
    "arriscas": "arriscar",
    "arriscasse": "arriscar",
    "arriscassem": "arriscar",
    "arriscasses": "arriscar",
    "arriscaste": "arriscar",
    "arriscastes": "arriscar",
    "arriscava": "arriscar",
    "arriscavam": "arriscar",
    "arriscavas": "arriscar",
    "arrisco": "arriscar",
    "arriscou": "arriscar",
    "arriscá": "arriscar",
    "arriscámo": "arriscar",
    "arriscámos": "arriscar",
    "arriscáramo": "arriscar",
    "arriscáramos": "arriscar",
    "arriscárei": "arriscar",
    "arriscáreis": "arriscar",
    "arriscásseis": "arriscar",
    "arriscássemos": "arriscar",
    "arriscávamo": "arriscar",
    "arriscávamos": "arriscar",
    "arriscávei": "arriscar",
    "arriscáveis": "arriscar",
    "arrisque": "arriscar",
    "arrisquei": "arriscar",
    "arrisqueis": "arriscar",
    "arrisquem": "arriscar",
    "arrisquemo": "arriscar",
    "arrisquemos": "arriscar",
    "arrisques": "arriscar",
    "arritma": "arritmo",
    "arritmas": "arritmo",
    "arritmias": "arritmia",
    "arritmos": "arritmo",
    "arrivismos": "arrivismo",
    "arrivistas": "arrivista",
    "arriza": "arrizo",
    "arrizas": "arrizo",
    "arrizos": "arrizo",
    "arrizotónica": "arrizotónico",
    "arrizotónicas": "arrizotónico",
    "arrizotónicos": "arrizotónico",
    "arrizófitos": "arrizófito",
    "arriá": "arriar",
    "arriámo": "arriar",
    "arriámos": "arriar",
    "arriáramo": "arriar",
    "arriáramos": "arriar",
    "arriárei": "arriar",
    "arriáreis": "arriar",
    "arriásseis": "arriar",
    "arriássemos": "arriar",
    "arriávamo": "arriar",
    "arriávamos": "arriar",
    "arriávei": "arriar",
    "arriáveis": "arriar",
    "arriça": "arriçarriçar",
    "arriçada": "arriçar",
    "arriçadas": "arriçar",
    "arriçado": "arriçar",
    "arriçados": "arriçar",
    "arriçai": "arriçarriçar",
    "arriçais": "arriçar",
    "arriçam": "arriçar",
    "arriçamo": "arriçar",
    "arriçamos": "arriçar",
    "arriçando": "arriçar",
    "arriçar": "arriçarriçar",
    "arriçara": "arriçarriçar",
    "arriçaram": "arriçarriçar",
    "arriçaras": "arriçar",
    "arriçarde": "arriçar",
    "arriçardes": "arriçarriçar",
    "arriçare": "arriçar",
    "arriçarei": "arriçar",
    "arriçareis": "arriçar",
    "arriçarem": "arriçarriçar",
    "arriçaremos": "arriçar",
    "arriçares": "arriçarriçar",
    "arriçaria": "arriçarriçar",
    "arriçariam": "arriçar",
    "arriçarias": "arriçar",
    "arriçarmo": "arriçar",
    "arriçarmos": "arriçarriçar",
    "arriçará": "arriçar",
    "arriçarás": "arriçar",
    "arriçarão": "arriçar",
    "arriçaríamos": "arriçar",
    "arriçaríeis": "arriçar",
    "arriças": "arriçar",
    "arriçasse": "arriçarriçar",
    "arriçassem": "arriçar",
    "arriçasses": "arriçar",
    "arriçaste": "arriçarriçar",
    "arriçastes": "arriçar",
    "arriçava": "arriçarriçar",
    "arriçavam": "arriçar",
    "arriçavas": "arriçar",
    "arriço": "arriçar",
    "arriçou": "arriçar",
    "arriçá": "arriçarriçar",
    "arriçámo": "arriçar",
    "arriçámos": "arriçar",
    "arriçáramo": "arriçar",
    "arriçáramos": "arriçar",
    "arriçárei": "arriçar",
    "arriçáreis": "arriçar",
    "arriçásseis": "arriçar",
    "arriçássemos": "arriçar",
    "arriçávamo": "arriçar",
    "arriçávamos": "arriçar",
    "arriçávei": "arriçar",
    "arriçáveis": "arriçar",
    "arriós": "arriól",
    "arroba": "arrobar",
    "arrobada": "arrobar",
    "arrobadas": "arrobar",
    "arrobado": "arrobar",
    "arrobados": "arrobar",
    "arrobagens": "arrobagem",
    "arrobai": "arrobar",
    "arrobais": "arrobar",
    "arrobam": "arrobar",
    "arrobamentos": "arrobamento",
    "arrobamo": "arrobar",
    "arrobamos": "arrobar",
    "arrobando": "arrobar",
    "arrobara": "arrobar",
    "arrobaram": "arrobar",
    "arrobaras": "arrobar",
    "arrobarde": "arrobar",
    "arrobardes": "arrobar",
    "arrobare": "arrobar",
    "arrobarei": "arrobar",
    "arrobareis": "arrobar",
    "arrobarem": "arrobar",
    "arrobaremos": "arrobar",
    "arrobares": "arrobar",
    "arrobaria": "arrobar",
    "arrobariam": "arrobar",
    "arrobarias": "arrobar",
    "arrobarmo": "arrobar",
    "arrobarmos": "arrobar",
    "arrobará": "arrobar",
    "arrobarás": "arrobar",
    "arrobarão": "arrobar",
    "arrobaríamos": "arrobar",
    "arrobaríeis": "arrobar",
    "arrobas": "arrobar",
    "arrobasse": "arrobar",
    "arrobassem": "arrobar",
    "arrobasses": "arrobar",
    "arrobaste": "arrobar",
    "arrobastes": "arrobar",
    "arrobava": "arrobar",
    "arrobavam": "arrobar",
    "arrobavas": "arrobar",
    "arrobações": "arrobação",
    "arrobe": "arrobar",
    "arrobei": "arrobar",
    "arrobeis": "arrobar",
    "arrobem": "arrobar",
    "arrobemo": "arrobar",
    "arrobemos": "arrobar",
    "arrobes": "arrobe",
    "arrobo": "arrobar",
    "arrobou": "arrobar",
    "arrobustada": "arrobustado",
    "arrobustadas": "arrobustado",
    "arrobustados": "arrobustado",
    "arrobá": "arrobar",
    "arrobámo": "arrobar",
    "arrobámos": "arrobar",
    "arrobáramo": "arrobar",
    "arrobáramos": "arrobar",
    "arrobárei": "arrobar",
    "arrobáreis": "arrobar",
    "arrobásseis": "arrobar",
    "arrobássemos": "arrobar",
    "arrobávamo": "arrobar",
    "arrobávamos": "arrobar",
    "arrobávei": "arrobar",
    "arrobáveis": "arrobar",
    "arrochadas": "arrochada",
    "arrochaduras": "arrochadura",
    "arrocheira": "arrocheiro",
    "arrocheiras": "arrocheiro",
    "arrocheiros": "arrocheiro",
    "arrochos": "arrocho",
    "arrofos": "arrofo",
    "arroga": "arrogar",
    "arrogada": "arrogar",
    "arrogadas": "arrogar",
    "arrogado": "arrogar",
    "arrogadora": "arrogador",
    "arrogadoras": "arrogador",
    "arrogadores": "arrogador",
    "arrogados": "arrogar",
    "arrogai": "arrogar",
    "arrogais": "arrogar",
    "arrogam": "arrogar",
    "arrogamo": "arrogar",
    "arrogamos": "arrogar",
    "arrogando": "arrogar",
    "arrogantes": "arrogante",
    "arrogara": "arrogar",
    "arrogaram": "arrogar",
    "arrogaras": "arrogar",
    "arrogarde": "arrogar",
    "arrogardes": "arrogar",
    "arrogare": "arrogar",
    "arrogarei": "arrogar",
    "arrogareis": "arrogar",
    "arrogarem": "arrogar",
    "arrogaremos": "arrogar",
    "arrogares": "arrogar",
    "arrogaria": "arrogar",
    "arrogariam": "arrogar",
    "arrogarias": "arrogar",
    "arrogarmo": "arrogar",
    "arrogarmos": "arrogar",
    "arrogará": "arrogar",
    "arrogarás": "arrogar",
    "arrogarão": "arrogar",
    "arrogaríamos": "arrogar",
    "arrogaríeis": "arrogar",
    "arrogas": "arrogar",
    "arrogasse": "arrogar",
    "arrogassem": "arrogar",
    "arrogasses": "arrogar",
    "arrogaste": "arrogar",
    "arrogastes": "arrogar",
    "arrogava": "arrogar",
    "arrogavam": "arrogar",
    "arrogavas": "arrogar",
    "arrogações": "arrogação",
    "arrogo": "arrogar",
    "arrogou": "arrogar",
    "arrogue": "arrogar",
    "arroguei": "arrogar",
    "arrogueis": "arrogar",
    "arroguem": "arrogar",
    "arroguemo": "arrogar",
    "arroguemos": "arrogar",
    "arrogues": "arrogar",
    "arrogá": "arrogar",
    "arrogámo": "arrogar",
    "arrogámos": "arrogar",
    "arrogáramo": "arrogar",
    "arrogáramos": "arrogar",
    "arrogárei": "arrogar",
    "arrogáreis": "arrogar",
    "arrogásseis": "arrogar",
    "arrogássemos": "arrogar",
    "arrogávamo": "arrogar",
    "arrogávamos": "arrogar",
    "arrogávei": "arrogar",
    "arrogáveis": "arrogar",
    "arrogâncias": "arrogância",
    "arroios": "arroio",
    "arroja": "arrojar",
    "arrojada": "arrojar",
    "arrojadas": "arrojar",
    "arrojado": "arrojar",
    "arrojadora": "arrojador",
    "arrojadoras": "arrojador",
    "arrojadores": "arrojador",
    "arrojados": "arrojar",
    "arrojadíssima": "arrojado",
    "arrojadíssimas": "arrojado",
    "arrojadíssimo": "arrojado",
    "arrojadíssimos": "arrojado",
    "arrojai": "arrojar",
    "arrojais": "arrojar",
    "arrojam": "arrojar",
    "arrojamentos": "arrojamento",
    "arrojamo": "arrojar",
    "arrojamos": "arrojar",
    "arrojando": "arrojar",
    "arrojara": "arrojar",
    "arrojaram": "arrojar",
    "arrojaras": "arrojar",
    "arrojarde": "arrojar",
    "arrojardes": "arrojar",
    "arrojare": "arrojar",
    "arrojarei": "arrojar",
    "arrojareis": "arrojar",
    "arrojarem": "arrojar",
    "arrojaremos": "arrojar",
    "arrojares": "arrojar",
    "arrojaria": "arrojar",
    "arrojariam": "arrojar",
    "arrojarias": "arrojar",
    "arrojarmo": "arrojar",
    "arrojarmos": "arrojar",
    "arrojará": "arrojar",
    "arrojarás": "arrojar",
    "arrojarão": "arrojar",
    "arrojaríamos": "arrojar",
    "arrojaríeis": "arrojar",
    "arrojas": "arrojar",
    "arrojasse": "arrojar",
    "arrojassem": "arrojar",
    "arrojasses": "arrojar",
    "arrojaste": "arrojar",
    "arrojastes": "arrojar",
    "arrojava": "arrojar",
    "arrojavam": "arrojar",
    "arrojavas": "arrojar",
    "arroje": "arrojar",
    "arrojei": "arrojar",
    "arrojeis": "arrojar",
    "arrojeitos": "arrojeito",
    "arrojem": "arrojar",
    "arrojemo": "arrojar",
    "arrojemos": "arrojar",
    "arrojes": "arrojar",
    "arrojo": "arrojar",
    "arrojos": "arrojo",
    "arrojou": "arrojar",
    "arrojá": "arrojar",
    "arrojámo": "arrojar",
    "arrojámos": "arrojar",
    "arrojáramo": "arrojar",
    "arrojáramos": "arrojar",
    "arrojárei": "arrojar",
    "arrojáreis": "arrojar",
    "arrojásseis": "arrojar",
    "arrojássemos": "arrojar",
    "arrojávamo": "arrojar",
    "arrojávamos": "arrojar",
    "arrojávei": "arrojar",
    "arrojáveis": "arrojar",
    "arrojões": "arrojão",
    "arrola": "arrolar",
    "arrolada": "arrolar",
    "arroladas": "arrolar",
    "arrolado": "arrolar",
    "arroladora": "arrolador",
    "arroladoras": "arrolador",
    "arroladores": "arrolador",
    "arrolados": "arrolar",
    "arrolai": "arrolar",
    "arrolais": "arrolar",
    "arrolam": "arrolar",
    "arrolamentos": "arrolamento",
    "arrolamo": "arrolar",
    "arrolamos": "arrolar",
    "arrolando": "arrolar",
    "arrolara": "arrolar",
    "arrolaram": "arrolar",
    "arrolaras": "arrolar",
    "arrolarde": "arrolar",
    "arrolardes": "arrolar",
    "arrolare": "arrolar",
    "arrolarei": "arrolar",
    "arrolareis": "arrolar",
    "arrolarem": "arrolar",
    "arrolaremos": "arrolar",
    "arrolares": "arrolar",
    "arrolaria": "arrolar",
    "arrolariam": "arrolar",
    "arrolarias": "arrolar",
    "arrolarmo": "arrolar",
    "arrolarmos": "arrolar",
    "arrolará": "arrolar",
    "arrolarás": "arrolar",
    "arrolarão": "arrolar",
    "arrolaríamos": "arrolar",
    "arrolaríeis": "arrolar",
    "arrolas": "arrolar",
    "arrolasse": "arrolar",
    "arrolassem": "arrolar",
    "arrolasses": "arrolar",
    "arrolaste": "arrolar",
    "arrolastes": "arrolar",
    "arrolava": "arrolar",
    "arrolavam": "arrolar",
    "arrolavas": "arrolar",
    "arrole": "arrolar",
    "arrolei": "arrolar",
    "arroleis": "arrolar",
    "arrolem": "arrolar",
    "arrolemo": "arrolar",
    "arrolemos": "arrolar",
    "arroles": "arrolar",
    "arrolhadora": "arrolhador",
    "arrolhadoras": "arrolhador",
    "arrolhadores": "arrolhador",
    "arrolhamentos": "arrolhamento",
    "arrolhos": "arrolho",
    "arrolo": "arrolar",
    "arrolos": "arrolo",
    "arrolou": "arrolar",
    "arrolá": "arrolar",
    "arrolámo": "arrolar",
    "arrolámos": "arrolar",
    "arroláramo": "arrolar",
    "arroláramos": "arrolar",
    "arrolárei": "arrolar",
    "arroláreis": "arrolar",
    "arrolásseis": "arrolar",
    "arrolássemos": "arrolar",
    "arrolávamo": "arrolar",
    "arrolávamos": "arrolar",
    "arrolávei": "arrolar",
    "arroláveis": "arrolar",
    "arromba": "arrombar",
    "arrombada": "arrombar",
    "arrombadas": "arrombar",
    "arrombadelas": "arrombadela",
    "arrombado": "arrombar",
    "arrombadora": "arrombador",
    "arrombadoras": "arrombador",
    "arrombadores": "arrombador",
    "arrombados": "arrombar",
    "arrombai": "arrombar",
    "arrombais": "arrombar",
    "arrombam": "arrombar",
    "arrombamentos": "arrombamento",
    "arrombamo": "arrombar",
    "arrombamos": "arrombar",
    "arrombando": "arrombar",
    "arrombara": "arrombar",
    "arrombaram": "arrombar",
    "arrombaras": "arrombar",
    "arrombarde": "arrombar",
    "arrombardes": "arrombar",
    "arrombare": "arrombar",
    "arrombarei": "arrombar",
    "arrombareis": "arrombar",
    "arrombarem": "arrombar",
    "arrombaremos": "arrombar",
    "arrombares": "arrombar",
    "arrombaria": "arrombar",
    "arrombariam": "arrombar",
    "arrombarias": "arrombar",
    "arrombarmo": "arrombar",
    "arrombarmos": "arrombar",
    "arrombará": "arrombar",
    "arrombarás": "arrombar",
    "arrombarão": "arrombar",
    "arrombaríamos": "arrombar",
    "arrombaríeis": "arrombar",
    "arrombas": "arrombar",
    "arrombasse": "arrombar",
    "arrombassem": "arrombar",
    "arrombasses": "arrombar",
    "arrombaste": "arrombar",
    "arrombastes": "arrombar",
    "arrombava": "arrombar",
    "arrombavam": "arrombar",
    "arrombavas": "arrombar",
    "arrombe": "arrombar",
    "arrombei": "arrombar",
    "arrombeis": "arrombar",
    "arrombem": "arrombar",
    "arrombemo": "arrombar",
    "arrombemos": "arrombar",
    "arrombes": "arrombar",
    "arrombo": "arrombar",
    "arrombou": "arrombar",
    "arrombá": "arrombar",
    "arrombámo": "arrombar",
    "arrombámos": "arrombar",
    "arrombáramo": "arrombar",
    "arrombáramos": "arrombar",
    "arrombárei": "arrombar",
    "arrombáreis": "arrombar",
    "arrombásseis": "arrombar",
    "arrombássemos": "arrombar",
    "arrombávamo": "arrombar",
    "arrombávamos": "arrombar",
    "arrombávei": "arrombar",
    "arrombáveis": "arrombável",
    "arrosta": "arrostar",
    "arrostada": "arrostar",
    "arrostadas": "arrostar",
    "arrostado": "arrostar",
    "arrostados": "arrostar",
    "arrostai": "arrostar",
    "arrostais": "arrostar",
    "arrostam": "arrostar",
    "arrostamo": "arrostar",
    "arrostamos": "arrostar",
    "arrostando": "arrostar",
    "arrostara": "arrostar",
    "arrostaram": "arrostar",
    "arrostaras": "arrostar",
    "arrostarde": "arrostar",
    "arrostardes": "arrostar",
    "arrostare": "arrostar",
    "arrostarei": "arrostar",
    "arrostareis": "arrostar",
    "arrostarem": "arrostar",
    "arrostaremos": "arrostar",
    "arrostares": "arrostar",
    "arrostaria": "arrostar",
    "arrostariam": "arrostar",
    "arrostarias": "arrostar",
    "arrostarmo": "arrostar",
    "arrostarmos": "arrostar",
    "arrostará": "arrostar",
    "arrostarás": "arrostar",
    "arrostarão": "arrostar",
    "arrostaríamos": "arrostar",
    "arrostaríeis": "arrostar",
    "arrostas": "arrostar",
    "arrostasse": "arrostar",
    "arrostassem": "arrostar",
    "arrostasses": "arrostar",
    "arrostaste": "arrostar",
    "arrostastes": "arrostar",
    "arrostava": "arrostar",
    "arrostavam": "arrostar",
    "arrostavas": "arrostar",
    "arroste": "arrostar",
    "arrostei": "arrostar",
    "arrosteis": "arrostar",
    "arrostem": "arrostar",
    "arrostemo": "arrostar",
    "arrostemos": "arrostar",
    "arrostes": "arrostar",
    "arrosto": "arrostar",
    "arrostou": "arrostar",
    "arrostá": "arrostar",
    "arrostámo": "arrostar",
    "arrostámos": "arrostar",
    "arrostáramo": "arrostar",
    "arrostáramos": "arrostar",
    "arrostárei": "arrostar",
    "arrostáreis": "arrostar",
    "arrostásseis": "arrostar",
    "arrostássemos": "arrostar",
    "arrostávamo": "arrostar",
    "arrostávamos": "arrostar",
    "arrostávei": "arrostar",
    "arrostáveis": "arrostar",
    "arrota": "arrotar",
    "arrotada": "arrotar",
    "arrotadas": "arrotar",
    "arrotado": "arrotar",
    "arrotadora": "arrotador",
    "arrotadoras": "arrotador",
    "arrotadores": "arrotador",
    "arrotados": "arrotar",
    "arrotaduras": "arrotadura",
    "arrotai": "arrotar",
    "arrotais": "arrotar",
    "arrotam": "arrotar",
    "arrotamo": "arrotar",
    "arrotamos": "arrotar",
    "arrotando": "arrotar",
    "arrotara": "arrotar",
    "arrotaram": "arrotar",
    "arrotaras": "arrotar",
    "arrotardes": "arrotar",
    "arrotarei": "arrotar",
    "arrotareis": "arrotar",
    "arrotarem": "arrotar",
    "arrotaremos": "arrotar",
    "arrotares": "arrotar",
    "arrotaria": "arrotar",
    "arrotariam": "arrotar",
    "arrotarias": "arrotar",
    "arrotarmo": "arrotar",
    "arrotarmos": "arrotar",
    "arrotará": "arrotar",
    "arrotarás": "arrotar",
    "arrotarão": "arrotar",
    "arrotaríamos": "arrotar",
    "arrotaríeis": "arrotar",
    "arrotas": "arrotar",
    "arrotasse": "arrotar",
    "arrotassem": "arrotar",
    "arrotasses": "arrotar",
    "arrotaste": "arrotar",
    "arrotastes": "arrotar",
    "arrotava": "arrotar",
    "arrotavam": "arrotar",
    "arrotavas": "arrotar",
    "arrotações": "arrotação",
    "arrote": "arrotar",
    "arroteada": "arrotear",
    "arroteadas": "arrotear",
    "arroteado": "arrotear",
    "arroteadora": "arroteador",
    "arroteadoras": "arroteador",
    "arroteadores": "arroteador",
    "arroteados": "arrotear",
    "arroteai": "arrotear",
    "arroteais": "arrotear",
    "arroteamentos": "arroteamento",
    "arroteamo": "arrotear",
    "arroteamos": "arrotear",
    "arroteando": "arrotear",
    "arroteara": "arrotear",
    "arrotearam": "arrotear",
    "arrotearas": "arrotear",
    "arrotearde": "arrotear",
    "arroteardes": "arrotear",
    "arroteare": "arrotear",
    "arrotearei": "arrotear",
    "arroteareis": "arrotear",
    "arrotearem": "arrotear",
    "arrotearemos": "arrotear",
    "arroteares": "arrotear",
    "arrotearia": "arrotear",
    "arroteariam": "arrotear",
    "arrotearias": "arrotear",
    "arrotearmo": "arrotear",
    "arrotearmos": "arrotear",
    "arroteará": "arrotear",
    "arrotearás": "arrotear",
    "arrotearão": "arrotear",
    "arrotearíamos": "arrotear",
    "arrotearíeis": "arrotear",
    "arroteasse": "arrotear",
    "arroteassem": "arrotear",
    "arroteasses": "arrotear",
    "arroteaste": "arrotear",
    "arroteastes": "arrotear",
    "arroteava": "arrotear",
    "arroteavam": "arrotear",
    "arroteavas": "arrotear",
    "arroteei": "arrotear",
    "arroteeis": "arrotear",
    "arroteemo": "arrotear",
    "arroteemos": "arrotear",
    "arrotei": "arrotar",
    "arroteia": "arrotear",
    "arroteiam": "arrotear",
    "arroteias": "arroteia",
    "arroteie": "arrotear",
    "arroteiem": "arrotear",
    "arroteies": "arrotear",
    "arroteio": "arrotear",
    "arroteis": "arrotar",
    "arrotem": "arrotar",
    "arrotemo": "arrotar",
    "arrotemos": "arrotar",
    "arroteou": "arrotear",
    "arrotes": "arrotar",
    "arroteá": "arrotear",
    "arroteámo": "arrotear",
    "arroteámos": "arrotear",
    "arroteáramo": "arrotear",
    "arroteáramos": "arrotear",
    "arroteárei": "arrotear",
    "arroteáreis": "arrotear",
    "arroteásseis": "arrotear",
    "arroteássemos": "arrotear",
    "arroteávamo": "arrotear",
    "arroteávamos": "arrotear",
    "arroteávei": "arrotear",
    "arroteáveis": "arrotear",
    "arroto": "arrotar",
    "arrotos": "arroto",
    "arrotou": "arrotar",
    "arrotámo": "arrotar",
    "arrotámos": "arrotar",
    "arrotáramo": "arrotar",
    "arrotáramos": "arrotar",
    "arrotáreis": "arrotar",
    "arrotásseis": "arrotar",
    "arrotássemos": "arrotar",
    "arrotávamo": "arrotar",
    "arrotávamos": "arrotar",
    "arrotáveis": "arrotar",
    "arroubamentos": "arroubamento",
    "arroubos": "arroubo",
    "arroxada": "arroxado",
    "arroxadas": "arroxado",
    "arroxados": "arroxado",
    "arroxeada": "arroxeado",
    "arroxeadas": "arroxeado",
    "arroxeados": "arroxeado",
    "arrozadas": "arrozada",
    "arrozais": "arrozal",
    "arrozalvas": "arrozalva",
    "arrozeira": "arrozeiro",
    "arrozeiras": "arrozeiro",
    "arrozeiros": "arrozeiro",
    "arrozes": "arroz",
    "arrozinho": "arroz",
    "arrozinhos": "arroz",
    "arrozito": "arroz",
    "arrozitos": "arroz",
    "arruaceira": "arruaceiro",
    "arruaceiras": "arruaceiro",
    "arruaceiros": "arruaceiro",
    "arruada": "arruado",
    "arruadas": "arruado",
    "arruadeiras": "arruadeira",
    "arruadora": "arruador",
    "arruadoras": "arruador",
    "arruadores": "arruador",
    "arruados": "arruado",
    "arruamentos": "arruamento",
    "arruaças": "arruaça",
    "arruações": "arruação",
    "arrubés": "arrubé",
    "arrudas": "arruda",
    "arrudenses": "arrudense",
    "arrudões": "arrudão",
    "arruelada": "arruelado",
    "arrueladas": "arruelado",
    "arruelados": "arruelado",
    "arruelas": "arruela",
    "arrufa": "arrufar",
    "arrufada": "arrufar",
    "arrufadas": "arrufar",
    "arrufadiça": "arrufadiço",
    "arrufadiças": "arrufadiço",
    "arrufadiços": "arrufadiço",
    "arrufado": "arrufar",
    "arrufados": "arrufar",
    "arrufadíssima": "arrufado",
    "arrufadíssimas": "arrufado",
    "arrufadíssimo": "arrufado",
    "arrufadíssimos": "arrufado",
    "arrufai": "arrufar",
    "arrufais": "arrufar",
    "arrufam": "arrufar",
    "arrufamo": "arrufar",
    "arrufamos": "arrufar",
    "arrufando": "arrufar",
    "arrufara": "arrufar",
    "arrufaram": "arrufar",
    "arrufaras": "arrufar",
    "arrufarde": "arrufar",
    "arrufardes": "arrufar",
    "arrufare": "arrufar",
    "arrufarei": "arrufar",
    "arrufareis": "arrufar",
    "arrufarem": "arrufar",
    "arrufaremos": "arrufar",
    "arrufares": "arrufar",
    "arrufaria": "arrufar",
    "arrufariam": "arrufar",
    "arrufarias": "arrufar",
    "arrufarmo": "arrufar",
    "arrufarmos": "arrufar",
    "arrufará": "arrufar",
    "arrufarás": "arrufar",
    "arrufarão": "arrufar",
    "arrufaríamos": "arrufar",
    "arrufaríeis": "arrufar",
    "arrufas": "arrufar",
    "arrufasse": "arrufar",
    "arrufassem": "arrufar",
    "arrufasses": "arrufar",
    "arrufaste": "arrufar",
    "arrufastes": "arrufar",
    "arrufava": "arrufar",
    "arrufavam": "arrufar",
    "arrufavas": "arrufar",
    "arrufe": "arrufar",
    "arrufei": "arrufar",
    "arrufeis": "arrufar",
    "arrufem": "arrufar",
    "arrufemo": "arrufar",
    "arrufemos": "arrufar",
    "arrufes": "arrufar",
    "arrufianada": "arrufianado",
    "arrufianadas": "arrufianado",
    "arrufianados": "arrufianado",
    "arrufo": "arrufar",
    "arrufos": "arrufo",
    "arrufou": "arrufar",
    "arrufá": "arrufar",
    "arrufámo": "arrufar",
    "arrufámos": "arrufar",
    "arrufáramo": "arrufar",
    "arrufáramos": "arrufar",
    "arrufárei": "arrufar",
    "arrufáreis": "arrufar",
    "arrufásseis": "arrufar",
    "arrufássemos": "arrufar",
    "arrufávamo": "arrufar",
    "arrufávamos": "arrufar",
    "arrufávei": "arrufar",
    "arrufáveis": "arrufar",
    "arrugaduras": "arrugadura",
    "arrugamentos": "arrugamento",
    "arruinada": "arruinar",
    "arruinadas": "arruinar",
    "arruinado": "arruinar",
    "arruinadora": "arruinador",
    "arruinadoras": "arruinador",
    "arruinadores": "arruinador",
    "arruinados": "arruinar",
    "arruinai": "arruinar",
    "arruinais": "arruinar",
    "arruinamentos": "arruinamento",
    "arruinamo": "arruinar",
    "arruinamos": "arruinar",
    "arruinando": "arruinar",
    "arruinara": "arruinar",
    "arruinaram": "arruinar",
    "arruinaras": "arruinar",
    "arruinarde": "arruinar",
    "arruinardes": "arruinar",
    "arruinare": "arruinar",
    "arruinarei": "arruinar",
    "arruinareis": "arruinar",
    "arruinarem": "arruinar",
    "arruinaremos": "arruinar",
    "arruinares": "arruinar",
    "arruinaria": "arruinar",
    "arruinariam": "arruinar",
    "arruinarias": "arruinar",
    "arruinarmo": "arruinar",
    "arruinarmos": "arruinar",
    "arruinará": "arruinar",
    "arruinarás": "arruinar",
    "arruinarão": "arruinar",
    "arruinaríamos": "arruinar",
    "arruinaríeis": "arruinar",
    "arruinasse": "arruinar",
    "arruinassem": "arruinar",
    "arruinasses": "arruinar",
    "arruinaste": "arruinar",
    "arruinastes": "arruinar",
    "arruinava": "arruinar",
    "arruinavam": "arruinar",
    "arruinavas": "arruinar",
    "arruinei": "arruinar",
    "arruineis": "arruinar",
    "arruinemos": "arruinar",
    "arruinou": "arruinar",
    "arruiná": "arruinar",
    "arruinámo": "arruinar",
    "arruinámos": "arruinar",
    "arruináramo": "arruinar",
    "arruináramos": "arruinar",
    "arruinárei": "arruinar",
    "arruináreis": "arruinar",
    "arruinásseis": "arruinar",
    "arruinássemos": "arruinar",
    "arruinávamo": "arruinar",
    "arruinávamos": "arruinar",
    "arruinávei": "arruinar",
    "arruináveis": "arruinável",
    "arruivada": "arruivado",
    "arruivadas": "arruivado",
    "arruivados": "arruivado",
    "arruivascada": "arruivascado",
    "arruivascadas": "arruivascado",
    "arruivascados": "arruivascado",
    "arrulha": "arrulhar",
    "arrulhada": "arrulhar",
    "arrulhadas": "arrulhar",
    "arrulhado": "arrulhar",
    "arrulhadora": "arrulhador",
    "arrulhadoras": "arrulhador",
    "arrulhadores": "arrulhador",
    "arrulhados": "arrulhar",
    "arrulhai": "arrulhar",
    "arrulhais": "arrulhar",
    "arrulham": "arrulhar",
    "arrulhamo": "arrulhar",
    "arrulhamos": "arrulhar",
    "arrulhando": "arrulhar",
    "arrulhara": "arrulhar",
    "arrulharam": "arrulhar",
    "arrulharas": "arrulhar",
    "arrulhardes": "arrulhar",
    "arrulharei": "arrulhar",
    "arrulhareis": "arrulhar",
    "arrulharem": "arrulhar",
    "arrulharemos": "arrulhar",
    "arrulhares": "arrulhar",
    "arrulharia": "arrulhar",
    "arrulhariam": "arrulhar",
    "arrulharias": "arrulhar",
    "arrulharmo": "arrulhar",
    "arrulharmos": "arrulhar",
    "arrulhará": "arrulhar",
    "arrulharás": "arrulhar",
    "arrulharão": "arrulhar",
    "arrulharíamos": "arrulhar",
    "arrulharíeis": "arrulhar",
    "arrulhas": "arrulhar",
    "arrulhasse": "arrulhar",
    "arrulhassem": "arrulhar",
    "arrulhasses": "arrulhar",
    "arrulhaste": "arrulhar",
    "arrulhastes": "arrulhar",
    "arrulhava": "arrulhar",
    "arrulhavam": "arrulhar",
    "arrulhavas": "arrulhar",
    "arrulhe": "arrulhar",
    "arrulhei": "arrulhar",
    "arrulheis": "arrulhar",
    "arrulhem": "arrulhar",
    "arrulhemo": "arrulhar",
    "arrulhemos": "arrulhar",
    "arrulhes": "arrulhar",
    "arrulho": "arrulhar",
    "arrulhos": "arrulho",
    "arrulhou": "arrulhar",
    "arrulhámo": "arrulhar",
    "arrulhámos": "arrulhar",
    "arrulháramo": "arrulhar",
    "arrulháramos": "arrulhar",
    "arrulháreis": "arrulhar",
    "arrulhásseis": "arrulhar",
    "arrulhássemos": "arrulhar",
    "arrulhávamo": "arrulhar",
    "arrulhávamos": "arrulhar",
    "arrulháveis": "arrulhar",
    "arruma": "arrumar",
    "arrumada": "arrumar",
    "arrumadas": "arrumar",
    "arrumadeiras": "arrumadeira",
    "arrumadelas": "arrumadela",
    "arrumadinha": "arrumado",
    "arrumadinhas": "arrumado",
    "arrumadinho": "arrumado",
    "arrumadinhos": "arrumado",
    "arrumadita": "arrumado",
    "arrumaditas": "arrumado",
    "arrumadito": "arrumado",
    "arrumaditos": "arrumado",
    "arrumado": "arrumar",
    "arrumadora": "arrumador",
    "arrumadoras": "arrumador",
    "arrumadores": "arrumador",
    "arrumados": "arrumar",
    "arrumadíssima": "arrumado",
    "arrumadíssimas": "arrumado",
    "arrumadíssimo": "arrumado",
    "arrumadíssimos": "arrumado",
    "arrumai": "arrumar",
    "arrumais": "arrumar",
    "arrumam": "arrumar",
    "arrumamo": "arrumar",
    "arrumamos": "arrumar",
    "arrumando": "arrumar",
    "arrumara": "arrumar",
    "arrumaram": "arrumar",
    "arrumaras": "arrumar",
    "arrumarde": "arrumar",
    "arrumardes": "arrumar",
    "arrumare": "arrumar",
    "arrumarei": "arrumar",
    "arrumareis": "arrumar",
    "arrumarem": "arrumar",
    "arrumaremos": "arrumar",
    "arrumares": "arrumar",
    "arrumaria": "arrumar",
    "arrumariam": "arrumar",
    "arrumarias": "arrumar",
    "arrumarmo": "arrumar",
    "arrumarmos": "arrumar",
    "arrumará": "arrumar",
    "arrumarás": "arrumar",
    "arrumarão": "arrumar",
    "arrumaríamos": "arrumar",
    "arrumaríeis": "arrumar",
    "arrumas": "arrumar",
    "arrumasse": "arrumar",
    "arrumassem": "arrumar",
    "arrumasses": "arrumar",
    "arrumaste": "arrumar",
    "arrumastes": "arrumar",
    "arrumava": "arrumar",
    "arrumavam": "arrumar",
    "arrumavas": "arrumar",
    "arrumaços": "arrumaço",
    "arrumações": "arrumação",
    "arrume": "arrumar",
    "arrumei": "arrumar",
    "arrumeis": "arrumar",
    "arrumem": "arrumar",
    "arrumemo": "arrumar",
    "arrumemos": "arrumar",
    "arrumes": "arrumar",
    "arrumo": "arrumar",
    "arrumos": "arrumo",
    "arrumou": "arrumar",
    "arrumá": "arrumar",
    "arrumámo": "arrumar",
    "arrumámos": "arrumar",
    "arrumáramo": "arrumar",
    "arrumáramos": "arrumar",
    "arrumárei": "arrumar",
    "arrumáreis": "arrumar",
    "arrumásseis": "arrumar",
    "arrumássemos": "arrumar",
    "arrumávamo": "arrumar",
    "arrumávamos": "arrumar",
    "arrumávei": "arrumar",
    "arrumáveis": "arrumar",
    "arruídos": "arruído",
    "arruína": "arruinar",
    "arruínam": "arruinar",
    "arruínas": "arruinar",
    "arruíne": "arruinar",
    "arruínem": "arruinar",
    "arruínes": "arruinar",
    "arruíno": "arruinar",
    "arrábida": "arrábido",
    "arrábidas": "arrábido",
    "arrábidos": "arrábido",
    "arráteis": "arrátel",
    "arrãs": "arrã",
    "arrítmica": "arrítmico",
    "arrítmicas": "arrítmico",
    "arrítmicos": "arrítmico",
    "arrúgias": "arrúgia",
    "arsenais": "arsenal",
    "arseniada": "arseniado",
    "arseniadas": "arseniado",
    "arseniados": "arseniado",
    "arseniatos": "arseniato",
    "arsenicada": "arsenicado",
    "arsenicadas": "arsenicado",
    "arsenicados": "arsenicado",
    "arsenicais": "arsenical",
    "arsenicismos": "arsenicismo",
    "arsenicofagias": "arsenicofagia",
    "arsenicíases": "arsenicíase",
    "arsenicófaga": "arsenicófago",
    "arsenicófagas": "arsenicófago",
    "arsenicófagos": "arsenicófago",
    "arsenietos": "arsenieto",
    "arseniosa": "arsenioso",
    "arseniosas": "arsenioso",
    "arseniosos": "arsenioso",
    "arsenitos": "arsenito",
    "arsenopirites": "arsenopirite",
    "arsenífera": "arsenífero",
    "arseníferas": "arsenífero",
    "arseníferos": "arsenífero",
    "arses": "arse",
    "arsinas": "arsina",
    "arsénicos": "arsénico",
    "arsénios": "arsénio",
    "artanitas": "artanita",
    "artefactos": "artefacto",
    "arteira": "arteiro",
    "arteiras": "arteiro",
    "arteirices": "arteirice",
    "arteiros": "arteiro",
    "arteletes": "artelete",
    "artelhos": "artelho",
    "artemisinas": "artemisina",
    "artemísias": "artemísia",
    "artemões": "artemão",
    "arteriais": "arterial",
    "arterialidades": "arterialidade",
    "arterializa": "arterializar",
    "arterializada": "arterializar",
    "arterializadas": "arterializar",
    "arterializado": "arterializar",
    "arterializados": "arterializar",
    "arterializai": "arterializar",
    "arterializais": "arterializar",
    "arterializam": "arterializar",
    "arterializamo": "arterializar",
    "arterializamos": "arterializar",
    "arterializando": "arterializar",
    "arterializara": "arterializar",
    "arterializaram": "arterializar",
    "arterializaras": "arterializar",
    "arterializarde": "arterializar",
    "arterializardes": "arterializar",
    "arterializare": "arterializar",
    "arterializarei": "arterializar",
    "arterializareis": "arterializar",
    "arterializarem": "arterializar",
    "arterializaremos": "arterializar",
    "arterializares": "arterializar",
    "arterializaria": "arterializar",
    "arterializariam": "arterializar",
    "arterializarias": "arterializar",
    "arterializarmo": "arterializar",
    "arterializarmos": "arterializar",
    "arterializará": "arterializar",
    "arterializarás": "arterializar",
    "arterializarão": "arterializar",
    "arterializaríamos": "arterializar",
    "arterializaríeis": "arterializar",
    "arterializas": "arterializar",
    "arterializasse": "arterializar",
    "arterializassem": "arterializar",
    "arterializasses": "arterializar",
    "arterializaste": "arterializar",
    "arterializastes": "arterializar",
    "arterializava": "arterializar",
    "arterializavam": "arterializar",
    "arterializavas": "arterializar",
    "arterializações": "arterialização",
    "arterialize": "arterializar",
    "arterializei": "arterializar",
    "arterializeis": "arterializar",
    "arterializem": "arterializar",
    "arterializemo": "arterializar",
    "arterializemos": "arterializar",
    "arterializes": "arterializar",
    "arterializo": "arterializar",
    "arterializou": "arterializar",
    "arterializá": "arterializar",
    "arterializámo": "arterializar",
    "arterializámos": "arterializar",
    "arterializáramo": "arterializar",
    "arterializáramos": "arterializar",
    "arterializárei": "arterializar",
    "arterializáreis": "arterializar",
    "arterializásseis": "arterializar",
    "arterializássemos": "arterializar",
    "arterializávamo": "arterializar",
    "arterializávamos": "arterializar",
    "arterializávei": "arterializar",
    "arterializáveis": "arterializar",
    "arteriarctias": "arteriarctia",
    "arteriectasias": "arteriectasia",
    "arteriectomias": "arteriectomia",
    "arteriografias": "arteriografia",
    "arteriográfica": "arteriográfico",
    "arteriográficas": "arteriográfico",
    "arteriográficos": "arteriográfico",
    "arteriologias": "arteriologia",
    "arteriorrafias": "arteriorrafia",
    "arteriorragias": "arteriorragia",
    "arteriosa": "arterioso",
    "arteriosas": "arterioso",
    "arterioscleroses": "arteriosclerose",
    "arteriosclerótica": "arteriosclerótico",
    "arterioscleróticas": "arteriosclerótico",
    "arterioscleróticos": "arteriosclerótico",
    "arteriosos": "arterioso",
    "arterites": "arterite",
    "arteriógrafos": "arteriógrafo",
    "arterióloga": "arteriólogo",
    "arteriólogas": "arteriólogo",
    "arteriólogos": "arteriólogo",
    "arteríolas": "arteríola",
    "artes": "arte",
    "artesanais": "artesanal",
    "artesanatos": "artesanato",
    "artesas": "artesa",
    "artesiana": "artesiano",
    "artesianas": "artesiano",
    "artesianos": "artesiano",
    "artesã": "artesão",
    "artesãos": "artesão",
    "artesãs": "artesão",
    "artesões": "artesão",
    "artices": "artice",
    "articidas": "articida",
    "articula": "articular",
    "articulada": "articular",
    "articuladas": "articular",
    "articulado": "articular",
    "articuladora": "articulador",
    "articuladoras": "articulador",
    "articuladores": "articulador",
    "articulados": "articular",
    "articulai": "articular",
    "articulais": "articular",
    "articulam": "articular",
    "articulamo": "articular",
    "articulamos": "articular",
    "articulando": "articular",
    "articulantes": "articulante",
    "articulara": "articular",
    "articularam": "articular",
    "articularas": "articular",
    "articularde": "articular",
    "articulardes": "articular",
    "articulare": "articular",
    "articularei": "articular",
    "articulareis": "articular",
    "articularem": "articular",
    "articularemos": "articular",
    "articulares": "articular",
    "articularia": "articular",
    "articulariam": "articular",
    "articularias": "articular",
    "articularmo": "articular",
    "articularmos": "articular",
    "articulará": "articular",
    "articularás": "articular",
    "articularão": "articular",
    "articularíamos": "articular",
    "articularíeis": "articular",
    "articulas": "articular",
    "articulasse": "articular",
    "articulassem": "articular",
    "articulasses": "articular",
    "articulaste": "articular",
    "articulastes": "articular",
    "articulatória": "articulatório",
    "articulatórias": "articulatório",
    "articulatórios": "articulatório",
    "articulava": "articular",
    "articulavam": "articular",
    "articulavas": "articular",
    "articulações": "articulação",
    "articule": "articular",
    "articulei": "articular",
    "articuleis": "articular",
    "articulem": "articular",
    "articulemo": "articular",
    "articulemos": "articular",
    "articules": "articular",
    "articulistas": "articulista",
    "articulo": "articular",
    "articulosa": "articuloso",
    "articulosas": "articuloso",
    "articulosos": "articuloso",
    "articulou": "articular",
    "articulá": "articular",
    "articulámo": "articular",
    "articulámos": "articular",
    "articuláramo": "articular",
    "articuláramos": "articular",
    "articulárei": "articular",
    "articuláreis": "articular",
    "articulásseis": "articular",
    "articulássemos": "articular",
    "articulávamo": "articular",
    "articulávamos": "articular",
    "articulávei": "articular",
    "articuláveis": "articulável",
    "artificia": "artificiar",
    "artificiada": "artificiar",
    "artificiadas": "artificiar",
    "artificiado": "artificiar",
    "artificiados": "artificiar",
    "artificiai": "artificiar",
    "artificiais": "artificiar",
    "artificialidades": "artificialidade",
    "artificialismos": "artificialismo",
    "artificializa": "artificializar",
    "artificializada": "artificializar",
    "artificializadas": "artificializar",
    "artificializado": "artificializar",
    "artificializados": "artificializar",
    "artificializai": "artificializar",
    "artificializais": "artificializar",
    "artificializam": "artificializar",
    "artificializamo": "artificializar",
    "artificializamos": "artificializar",
    "artificializando": "artificializar",
    "artificializara": "artificializar",
    "artificializaram": "artificializar",
    "artificializaras": "artificializar",
    "artificializarde": "artificializar",
    "artificializardes": "artificializar",
    "artificializare": "artificializar",
    "artificializarei": "artificializar",
    "artificializareis": "artificializar",
    "artificializarem": "artificializar",
    "artificializaremos": "artificializar",
    "artificializares": "artificializar",
    "artificializaria": "artificializar",
    "artificializariam": "artificializar",
    "artificializarias": "artificializar",
    "artificializarmo": "artificializar",
    "artificializarmos": "artificializar",
    "artificializará": "artificializar",
    "artificializarás": "artificializar",
    "artificializarão": "artificializar",
    "artificializaríamos": "artificializar",
    "artificializaríeis": "artificializar",
    "artificializas": "artificializar",
    "artificializasse": "artificializar",
    "artificializassem": "artificializar",
    "artificializasses": "artificializar",
    "artificializaste": "artificializar",
    "artificializastes": "artificializar",
    "artificializava": "artificializar",
    "artificializavam": "artificializar",
    "artificializavas": "artificializar",
    "artificialize": "artificializar",
    "artificializei": "artificializar",
    "artificializeis": "artificializar",
    "artificializem": "artificializar",
    "artificializemo": "artificializar",
    "artificializemos": "artificializar",
    "artificializes": "artificializar",
    "artificializo": "artificializar",
    "artificializou": "artificializar",
    "artificializá": "artificializar",
    "artificializámo": "artificializar",
    "artificializámos": "artificializar",
    "artificializáramo": "artificializar",
    "artificializáramos": "artificializar",
    "artificializárei": "artificializar",
    "artificializáreis": "artificializar",
    "artificializásseis": "artificializar",
    "artificializássemos": "artificializar",
    "artificializávamo": "artificializar",
    "artificializávamos": "artificializar",
    "artificializávei": "artificializar",
    "artificializáveis": "artificializar",
    "artificiam": "artificiar",
    "artificiamo": "artificiar",
    "artificiamos": "artificiar",
    "artificiando": "artificiar",
    "artificiara": "artificiar",
    "artificiaram": "artificiar",
    "artificiaras": "artificiar",
    "artificiarde": "artificiar",
    "artificiardes": "artificiar",
    "artificiare": "artificiar",
    "artificiarei": "artificiar",
    "artificiareis": "artificiar",
    "artificiarem": "artificiar",
    "artificiaremos": "artificiar",
    "artificiares": "artificiar",
    "artificiaria": "artificiar",
    "artificiariam": "artificiar",
    "artificiarias": "artificiar",
    "artificiarmo": "artificiar",
    "artificiarmos": "artificiar",
    "artificiará": "artificiar",
    "artificiarás": "artificiar",
    "artificiarão": "artificiar",
    "artificiaríamos": "artificiar",
    "artificiaríeis": "artificiar",
    "artificias": "artificiar",
    "artificiasse": "artificiar",
    "artificiassem": "artificiar",
    "artificiasses": "artificiar",
    "artificiaste": "artificiar",
    "artificiastes": "artificiar",
    "artificiava": "artificiar",
    "artificiavam": "artificiar",
    "artificiavas": "artificiar",
    "artificie": "artificiar",
    "artificiei": "artificiar",
    "artificieis": "artificiar",
    "artificiem": "artificiar",
    "artificiemo": "artificiar",
    "artificiemos": "artificiar",
    "artificies": "artificiar",
    "artificio": "artificiar",
    "artificiosa": "artificioso",
    "artificiosas": "artificioso",
    "artificiosidades": "artificiosidade",
    "artificiosos": "artificioso",
    "artificiou": "artificiar",
    "artificiá": "artificiar",
    "artificiámo": "artificiar",
    "artificiámos": "artificiar",
    "artificiáramo": "artificiar",
    "artificiáramos": "artificiar",
    "artificiárei": "artificiar",
    "artificiáreis": "artificiar",
    "artificiásseis": "artificiar",
    "artificiássemos": "artificiar",
    "artificiávamo": "artificiar",
    "artificiávamos": "artificiar",
    "artificiávei": "artificiar",
    "artificiáveis": "artificiar",
    "artifícios": "artifício",
    "artigos": "artigo",
    "artiguelhos": "artiguelho",
    "artiguetes": "artiguete",
    "artiguinho": "artigo",
    "artiguinhos": "artigo",
    "artiguito": "artigo",
    "artiguitos": "artigo",
    "artilha": "artilhar",
    "artilhada": "artilhar",
    "artilhadas": "artilhar",
    "artilhado": "artilhar",
    "artilhados": "artilhar",
    "artilhai": "artilhar",
    "artilhais": "artilhar",
    "artilham": "artilhar",
    "artilhamentos": "artilhamento",
    "artilhamo": "artilhar",
    "artilhamos": "artilhar",
    "artilhando": "artilhar",
    "artilhara": "artilhar",
    "artilharam": "artilhar",
    "artilharas": "artilhar",
    "artilharde": "artilhar",
    "artilhardes": "artilhar",
    "artilhare": "artilhar",
    "artilharei": "artilhar",
    "artilhareis": "artilhar",
    "artilharem": "artilhar",
    "artilharemos": "artilhar",
    "artilhares": "artilhar",
    "artilharia": "artilhar",
    "artilhariam": "artilhar",
    "artilharias": "artilharia",
    "artilharmo": "artilhar",
    "artilharmos": "artilhar",
    "artilhará": "artilhar",
    "artilharás": "artilhar",
    "artilharão": "artilhar",
    "artilharíamos": "artilhar",
    "artilharíeis": "artilhar",
    "artilhas": "artilhar",
    "artilhasse": "artilhar",
    "artilhassem": "artilhar",
    "artilhasses": "artilhar",
    "artilhaste": "artilhar",
    "artilhastes": "artilhar",
    "artilhava": "artilhar",
    "artilhavam": "artilhar",
    "artilhavas": "artilhar",
    "artilhe": "artilhar",
    "artilhei": "artilhar",
    "artilheira": "artilheiro",
    "artilheiras": "artilheiro",
    "artilheiros": "artilheiro",
    "artilheis": "artilhar",
    "artilhem": "artilhar",
    "artilhemo": "artilhar",
    "artilhemos": "artilhar",
    "artilherias": "artilheria",
    "artilhes": "artilhar",
    "artilho": "artilhar",
    "artilhou": "artilhar",
    "artilhá": "artilhar",
    "artilhámo": "artilhar",
    "artilhámos": "artilhar",
    "artilháramo": "artilhar",
    "artilháramos": "artilhar",
    "artilhárei": "artilhar",
    "artilháreis": "artilhar",
    "artilhásseis": "artilhar",
    "artilhássemos": "artilhar",
    "artilhávamo": "artilhar",
    "artilhávamos": "artilhar",
    "artilhávei": "artilhar",
    "artilháveis": "artilhar",
    "artimanhas": "artimanha",
    "artinhas": "artinha",
    "artiodáctila": "artiodáctilo",
    "artiodáctilas": "artiodáctilo",
    "artiodáctilos": "artiodáctilo",
    "artiozoária": "artiozoário",
    "artiozoárias": "artiozoário",
    "artiozoários": "artiozoário",
    "artistas": "artista",
    "artolas": "artola",
    "artolatrias": "artolatria",
    "artomeles": "artomel",
    "artoméis": "artomel",
    "artonomias": "artonomia",
    "artonómica": "artonómico",
    "artonómicas": "artonómico",
    "artonómicos": "artonómico",
    "artralgias": "artralgia",
    "artrites": "artrite",
    "artritismos": "artritismo",
    "artrobrânquias": "artrobrânquia",
    "artrocéfala": "artrocéfalo",
    "artrocéfalas": "artrocéfalo",
    "artrocéfalos": "artrocéfalo",
    "artrodinias": "artrodinia",
    "artrografias": "artrografia",
    "artrologias": "artrologia",
    "artropatias": "artropatia",
    "artropioses": "artropiose",
    "artroses": "artrose",
    "artrotomias": "artrotomia",
    "artrozoária": "artrozoário",
    "artrozoárias": "artrozoário",
    "artrozoários": "artrozoário",
    "artrítica": "artrítico",
    "artríticas": "artrítico",
    "artríticos": "artrítico",
    "artrópodes": "artrópode",
    "artérias": "artéria",
    "artículos": "artículo",
    "artífices": "artífice",
    "artística": "artístico",
    "artísticas": "artístico",
    "artísticos": "artístico",
    "artócopos": "artócopo",
    "artófaga": "artófago",
    "artófagas": "artófago",
    "artófagos": "artófago",
    "artófora": "artóforo",
    "artóforas": "artóforo",
    "artóforos": "artóforo",
    "artólatras": "artólatra",
    "arugas": "aruga",
    "arujos": "arujo",
    "aruncos": "arunco",
    "arundinosa": "arundinoso",
    "arundinosas": "arundinoso",
    "arundinosos": "arundinoso",
    "arundinácea": "arundináceo",
    "arundináceas": "arundináceo",
    "arundináceos": "arundináceo",
    "arundínea": "arundíneo",
    "arundíneas": "arundíneo",
    "arundíneos": "arundíneo",
    "aruspicatória": "aruspicatório",
    "aruspicatórias": "aruspicatório",
    "aruspicatórios": "aruspicatório",
    "aruspicações": "aruspicação",
    "aruspicina": "aruspicino",
    "aruspicinas": "aruspicino",
    "aruspicinos": "aruspicino",
    "aruspicismos": "aruspicismo",
    "aruspícios": "aruspício",
    "arvais": "arval",
    "arvelas": "arvela",
    "arvenses": "arvense",
    "arvicolídea": "arvicolídeo",
    "arvicolídeas": "arvicolídeo",
    "arvicolídeos": "arvicolídeo",
    "arvicultora": "arvicultor",
    "arvicultoras": "arvicultor",
    "arvicultores": "arvicultor",
    "arviculturas": "arvicultura",
    "arvingéis": "arvingel",
    "arviões": "arvião",
    "arvoamentos": "arvoamento",
    "arvora": "arvorar",
    "arvorada": "arvorar",
    "arvoradas": "arvorar",
    "arvorado": "arvorar",
    "arvorados": "arvorar",
    "arvoragens": "arvoragem",
    "arvorai": "arvorar",
    "arvorais": "arvorar",
    "arvoram": "arvorar",
    "arvoramo": "arvorar",
    "arvoramos": "arvorar",
    "arvorando": "arvorar",
    "arvorara": "arvorar",
    "arvoraram": "arvorar",
    "arvoraras": "arvorar",
    "arvorardes": "arvorar",
    "arvorarei": "arvorar",
    "arvorareis": "arvorar",
    "arvorarem": "arvorar",
    "arvoraremos": "arvorar",
    "arvorares": "arvorar",
    "arvoraria": "arvorar",
    "arvorariam": "arvorar",
    "arvorarias": "arvorar",
    "arvorarmo": "arvorar",
    "arvorarmos": "arvorar",
    "arvorará": "arvorar",
    "arvorarás": "arvorar",
    "arvorarão": "arvorar",
    "arvoraríamos": "arvorar",
    "arvoraríeis": "arvorar",
    "arvoras": "arvorar",
    "arvorasse": "arvorar",
    "arvorassem": "arvorar",
    "arvorasses": "arvorar",
    "arvoraste": "arvorar",
    "arvorastes": "arvorar",
    "arvorava": "arvorar",
    "arvoravam": "arvorar",
    "arvoravas": "arvorar",
    "arvore": "arvorar",
    "arvoredos": "arvoredo",
    "arvorei": "arvorar",
    "arvoreis": "arvorar",
    "arvorem": "arvorar",
    "arvoremo": "arvorar",
    "arvoremos": "arvorar",
    "arvores": "arvorar",
    "arvorezinha": "árvore",
    "arvorezinhas": "árvore",
    "arvorezita": "árvore",
    "arvorezitas": "árvore",
    "arvoro": "arvorar",
    "arvorou": "arvorar",
    "arvorámo": "arvorar",
    "arvorámos": "arvorar",
    "arvoráramo": "arvorar",
    "arvoráramos": "arvorar",
    "arvoráreis": "arvorar",
    "arvorásseis": "arvorar",
    "arvorássemos": "arvorar",
    "arvorávamo": "arvorar",
    "arvorávamos": "arvorar",
    "arvoráveis": "arvorar",
    "arvéloas": "arvéloa",
    "arvícolas": "arvícola",
    "arzegaias": "arzegaia",
    "arzinho": "ar",
    "arzinhos": "ar",
    "arzito": "ar",
    "arzitos": "ar",
    "arzolas": "arzola",
    "ará": "arar",
    "arábia": "arábio",
    "arábias": "arábio",
    "arábica": "arábico",
    "arábicas": "arábico",
    "arábicos": "arábico",
    "arábiga": "arábigo",
    "arábigas": "arábigo",
    "arábigos": "arábigo",
    "arábios": "arábio",
    "arácea": "aráceo",
    "aráceas": "aráceo",
    "aráceos": "aráceo",
    "arámo": "arar",
    "arámos": "arar",
    "aráramo": "arar",
    "aráramos": "arar",
    "arárei": "arar",
    "aráreis": "arar",
    "arás": "ará",
    "arásseis": "arar",
    "arássemos": "arar",
    "arávamo": "arar",
    "arávamos": "arar",
    "arávei": "arar",
    "aráveis": "arável",
    "arâmica": "arâmico",
    "arâmicas": "arâmico",
    "arâmicos": "arâmico",
    "arçanhais": "arçanhal",
    "arçãs": "arçã",
    "arções": "arção",
    "aréolas": "aréola",
    "aríolos": "aríolo",
    "arómatas": "arómata",
    "arões": "arão",
    "arúndines": "arúndine",
    "arúspices": "arúspice",
    "as": "o",
    "asa": "asar",
    "asada": "asar",
    "asadas": "asar",
    "asado": "asar",
    "asadores": "asador",
    "asados": "asar",
    "asafias": "asafia",
    "asai": "asar",
    "asais": "asar",
    "asam": "asar",
    "asamo": "asar",
    "asamos": "asar",
    "asando": "asar",
    "asaproles": "asaprol",
    "asara": "asar",
    "asaram": "asar",
    "asaras": "asar",
    "asarde": "asar",
    "asardes": "asar",
    "asare": "asar",
    "asarei": "asar",
    "asareis": "asar",
    "asarem": "asar",
    "asaremos": "asar",
    "asares": "asar",
    "asaria": "asar",
    "asariam": "asar",
    "asarias": "asar",
    "asarinas": "asarina",
    "asarmo": "asar",
    "asarmos": "asar",
    "asaronas": "asarona",
    "asará": "asar",
    "asarás": "asar",
    "asarão": "asar",
    "asaríamos": "asar",
    "asaríeis": "asar",
    "asas": "asar",
    "asasse": "asar",
    "asassem": "asar",
    "asasses": "asar",
    "asaste": "asar",
    "asastes": "asar",
    "asava": "asar",
    "asavam": "asar",
    "asavas": "asar",
    "asbestina": "asbestino",
    "asbestinas": "asbestino",
    "asbestinos": "asbestino",
    "asbestos": "asbesto",
    "asbulinas": "asbulina",
    "ascaricidas": "ascaricida",
    "ascaridíases": "ascaridíase",
    "ascarídea": "ascarídeo",
    "ascarídeas": "ascarídeo",
    "ascarídeos": "ascarídeo",
    "ascas": "asca",
    "ascaulas": "ascaula",
    "ascelias": "ascelia",
    "ascencionistas": "ascencionista",
    "ascenda": "ascender",
    "ascendais": "ascender",
    "ascendam": "ascender",
    "ascendamo": "ascender",
    "ascendamos": "ascender",
    "ascendas": "ascender",
    "ascende": "ascender",
    "ascendei": "ascender",
    "ascendeis": "ascender",
    "ascendem": "ascender",
    "ascendemo": "ascender",
    "ascendemos": "ascender",
    "ascendendo": "ascender",
    "ascendentes": "ascendente",
    "ascendera": "ascender",
    "ascenderam": "ascender",
    "ascenderas": "ascender",
    "ascenderdes": "ascender",
    "ascenderei": "ascender",
    "ascendereis": "ascender",
    "ascenderem": "ascender",
    "ascenderemos": "ascender",
    "ascenderes": "ascender",
    "ascenderia": "ascender",
    "ascenderiam": "ascender",
    "ascenderias": "ascender",
    "ascendermo": "ascender",
    "ascendermos": "ascender",
    "ascenderá": "ascender",
    "ascenderás": "ascender",
    "ascenderão": "ascender",
    "ascenderíamos": "ascender",
    "ascenderíeis": "ascender",
    "ascendes": "ascender",
    "ascendesse": "ascender",
    "ascendessem": "ascender",
    "ascendesses": "ascender",
    "ascendeste": "ascender",
    "ascendestes": "ascender",
    "ascendeu": "ascender",
    "ascendi": "ascender",
    "ascendia": "ascender",
    "ascendiam": "ascender",
    "ascendias": "ascender",
    "ascendida": "ascendido",
    "ascendidas": "ascendido",
    "ascendido": "ascender",
    "ascendidos": "ascendido",
    "ascendimentos": "ascendimento",
    "ascendo": "ascender",
    "ascendências": "ascendência",
    "ascendêramo": "ascender",
    "ascendêramos": "ascender",
    "ascendêreis": "ascender",
    "ascendêsseis": "ascender",
    "ascendêssemos": "ascender",
    "ascendíamo": "ascender",
    "ascendíamos": "ascender",
    "ascendíeis": "ascender",
    "ascensa": "ascenso",
    "ascensas": "ascenso",
    "ascensionais": "ascensional",
    "ascensionistas": "ascensionista",
    "ascensora": "ascensor",
    "ascensoras": "ascensor",
    "ascensores": "ascensor",
    "ascensoristas": "ascensorista",
    "ascensos": "ascenso",
    "ascensões": "ascensão",
    "asceses": "ascese",
    "ascetas": "asceta",
    "ascetismos": "ascetismo",
    "ascetiza": "ascetizar",
    "ascetizada": "ascetizar",
    "ascetizadas": "ascetizar",
    "ascetizado": "ascetizar",
    "ascetizados": "ascetizar",
    "ascetizai": "ascetizar",
    "ascetizais": "ascetizar",
    "ascetizam": "ascetizar",
    "ascetizamo": "ascetizar",
    "ascetizamos": "ascetizar",
    "ascetizando": "ascetizar",
    "ascetizara": "ascetizar",
    "ascetizaram": "ascetizar",
    "ascetizaras": "ascetizar",
    "ascetizarde": "ascetizar",
    "ascetizardes": "ascetizar",
    "ascetizare": "ascetizar",
    "ascetizarei": "ascetizar",
    "ascetizareis": "ascetizar",
    "ascetizarem": "ascetizar",
    "ascetizaremos": "ascetizar",
    "ascetizares": "ascetizar",
    "ascetizaria": "ascetizar",
    "ascetizariam": "ascetizar",
    "ascetizarias": "ascetizar",
    "ascetizarmo": "ascetizar",
    "ascetizarmos": "ascetizar",
    "ascetizará": "ascetizar",
    "ascetizarás": "ascetizar",
    "ascetizarão": "ascetizar",
    "ascetizaríamos": "ascetizar",
    "ascetizaríeis": "ascetizar",
    "ascetizas": "ascetizar",
    "ascetizasse": "ascetizar",
    "ascetizassem": "ascetizar",
    "ascetizasses": "ascetizar",
    "ascetizaste": "ascetizar",
    "ascetizastes": "ascetizar",
    "ascetizava": "ascetizar",
    "ascetizavam": "ascetizar",
    "ascetizavas": "ascetizar",
    "ascetize": "ascetizar",
    "ascetizei": "ascetizar",
    "ascetizeis": "ascetizar",
    "ascetizem": "ascetizar",
    "ascetizemo": "ascetizar",
    "ascetizemos": "ascetizar",
    "ascetizes": "ascetizar",
    "ascetizo": "ascetizar",
    "ascetizou": "ascetizar",
    "ascetizá": "ascetizar",
    "ascetizámo": "ascetizar",
    "ascetizámos": "ascetizar",
    "ascetizáramo": "ascetizar",
    "ascetizáramos": "ascetizar",
    "ascetizárei": "ascetizar",
    "ascetizáreis": "ascetizar",
    "ascetizásseis": "ascetizar",
    "ascetizássemos": "ascetizar",
    "ascetizávamo": "ascetizar",
    "ascetizávamos": "ascetizar",
    "ascetizávei": "ascetizar",
    "ascetizáveis": "ascetizar",
    "ascetérios": "ascetério",
    "ascidiácea": "ascidiáceo",
    "ascidiáceas": "ascidiáceo",
    "ascidiáceos": "ascidiáceo",
    "ascites": "ascite",
    "asclepiadeia": "asclepiadeu",
    "asclepiadeias": "asclepiadeu",
    "asclepiadeus": "asclepiadeu",
    "asclepiadácea": "asclepiadáceo",
    "asclepiadáceas": "asclepiadáceo",
    "asclepiadáceos": "asclepiadáceo",
    "ascomas": "ascoma",
    "ascomícetes": "ascomícete",
    "ascomícetos": "ascomíceto",
    "ascorosa": "ascoroso",
    "ascorosas": "ascoroso",
    "ascorosidades": "ascorosidade",
    "ascorosos": "ascoroso",
    "ascos": "asco",
    "ascáridas": "ascárida",
    "ascás": "ascá",
    "ascética": "ascético",
    "ascéticas": "ascético",
    "ascéticos": "ascético",
    "ascídia": "ascídio",
    "ascídias": "ascídio",
    "ascídios": "ascídio",
    "ascófora": "ascóforo",
    "ascóforas": "ascóforo",
    "ascóforos": "ascóforo",
    "ascórbica": "ascórbico",
    "ascórbicas": "ascórbico",
    "ascórbicos": "ascórbico",
    "ascósporos": "ascósporo",
    "ase": "asar",
    "asei": "asar",
    "aseidades": "aseidade",
    "aseis": "asar",
    "aselhas": "aselha",
    "aselos": "aselo",
    "aselídea": "aselídeo",
    "aselídeas": "aselídeo",
    "aselídeos": "aselídeo",
    "asem": "asar",
    "asemo": "asar",
    "asemos": "asar",
    "ases": "asar",
    "asfalinas": "asfalina",
    "asfalta": "asfaltar",
    "asfaltada": "asfaltar",
    "asfaltadas": "asfaltar",
    "asfaltado": "asfaltar",
    "asfaltadores": "asfaltador",
    "asfaltados": "asfaltar",
    "asfaltagens": "asfaltagem",
    "asfaltai": "asfaltar",
    "asfaltais": "asfaltar",
    "asfaltam": "asfaltar",
    "asfaltamentos": "asfaltamento",
    "asfaltamo": "asfaltar",
    "asfaltamos": "asfaltar",
    "asfaltando": "asfaltar",
    "asfaltara": "asfaltar",
    "asfaltaram": "asfaltar",
    "asfaltaras": "asfaltar",
    "asfaltarde": "asfaltar",
    "asfaltardes": "asfaltar",
    "asfaltare": "asfaltar",
    "asfaltarei": "asfaltar",
    "asfaltareis": "asfaltar",
    "asfaltarem": "asfaltar",
    "asfaltaremos": "asfaltar",
    "asfaltares": "asfaltar",
    "asfaltaria": "asfaltar",
    "asfaltariam": "asfaltar",
    "asfaltarias": "asfaltar",
    "asfaltarmo": "asfaltar",
    "asfaltarmos": "asfaltar",
    "asfaltará": "asfaltar",
    "asfaltarás": "asfaltar",
    "asfaltarão": "asfaltar",
    "asfaltaríamos": "asfaltar",
    "asfaltaríeis": "asfaltar",
    "asfaltas": "asfaltar",
    "asfaltasse": "asfaltar",
    "asfaltassem": "asfaltar",
    "asfaltasses": "asfaltar",
    "asfaltaste": "asfaltar",
    "asfaltastes": "asfaltar",
    "asfaltava": "asfaltar",
    "asfaltavam": "asfaltar",
    "asfaltavas": "asfaltar",
    "asfalte": "asfaltar",
    "asfaltei": "asfaltar",
    "asfalteis": "asfaltar",
    "asfaltem": "asfaltar",
    "asfaltemo": "asfaltar",
    "asfaltemos": "asfaltar",
    "asfaltes": "asfaltar",
    "asfaltitas": "asfaltita",
    "asfaltites": "asfaltite",
    "asfalto": "asfaltar",
    "asfaltos": "asfalto",
    "asfaltou": "asfaltar",
    "asfaltá": "asfaltar",
    "asfaltámo": "asfaltar",
    "asfaltámos": "asfaltar",
    "asfaltáramo": "asfaltar",
    "asfaltáramos": "asfaltar",
    "asfaltárei": "asfaltar",
    "asfaltáreis": "asfaltar",
    "asfaltásseis": "asfaltar",
    "asfaltássemos": "asfaltar",
    "asfaltávamo": "asfaltar",
    "asfaltávamos": "asfaltar",
    "asfaltávei": "asfaltar",
    "asfaltáveis": "asfaltar",
    "asfixia": "asfixiar",
    "asfixiada": "asfixiar",
    "asfixiadas": "asfixiar",
    "asfixiado": "asfixiar",
    "asfixiados": "asfixiar",
    "asfixiai": "asfixiar",
    "asfixiais": "asfixiar",
    "asfixiam": "asfixiar",
    "asfixiamentos": "asfixiamento",
    "asfixiamo": "asfixiar",
    "asfixiamos": "asfixiar",
    "asfixiando": "asfixiar",
    "asfixiantes": "asfixiante",
    "asfixiara": "asfixiar",
    "asfixiaram": "asfixiar",
    "asfixiaras": "asfixiar",
    "asfixiarde": "asfixiar",
    "asfixiardes": "asfixiar",
    "asfixiare": "asfixiar",
    "asfixiarei": "asfixiar",
    "asfixiareis": "asfixiar",
    "asfixiarem": "asfixiar",
    "asfixiaremos": "asfixiar",
    "asfixiares": "asfixiar",
    "asfixiaria": "asfixiar",
    "asfixiariam": "asfixiar",
    "asfixiarias": "asfixiar",
    "asfixiarmo": "asfixiar",
    "asfixiarmos": "asfixiar",
    "asfixiará": "asfixiar",
    "asfixiarás": "asfixiar",
    "asfixiarão": "asfixiar",
    "asfixiaríamos": "asfixiar",
    "asfixiaríeis": "asfixiar",
    "asfixias": "asfixiar",
    "asfixiasse": "asfixiar",
    "asfixiassem": "asfixiar",
    "asfixiasses": "asfixiar",
    "asfixiaste": "asfixiar",
    "asfixiastes": "asfixiar",
    "asfixiava": "asfixiar",
    "asfixiavam": "asfixiar",
    "asfixiavas": "asfixiar",
    "asfixie": "asfixiar",
    "asfixiei": "asfixiar",
    "asfixieis": "asfixiar",
    "asfixiem": "asfixiar",
    "asfixiemo": "asfixiar",
    "asfixiemos": "asfixiar",
    "asfixies": "asfixiar",
    "asfixio": "asfixiar",
    "asfixiou": "asfixiar",
    "asfixiá": "asfixiar",
    "asfixiámo": "asfixiar",
    "asfixiámos": "asfixiar",
    "asfixiáramo": "asfixiar",
    "asfixiáramos": "asfixiar",
    "asfixiárei": "asfixiar",
    "asfixiáreis": "asfixiar",
    "asfixiásseis": "asfixiar",
    "asfixiássemos": "asfixiar",
    "asfixiávamo": "asfixiar",
    "asfixiávamos": "asfixiar",
    "asfixiávei": "asfixiar",
    "asfixiáveis": "asfixiar",
    "asfáltica": "asfáltico",
    "asfálticas": "asfáltico",
    "asfálticos": "asfáltico",
    "asfódela": "asfódelo",
    "asfódelas": "asfódelo",
    "asfódelos": "asfódelo",
    "asiarcas": "asiarca",
    "asiaticismos": "asiaticismo",
    "asiatismos": "asiatismo",
    "asila": "asilar",
    "asilada": "asilar",
    "asiladas": "asilar",
    "asilado": "asilar",
    "asilados": "asilar",
    "asilai": "asilar",
    "asilais": "asilar",
    "asilam": "asilar",
    "asilamo": "asilar",
    "asilamos": "asilar",
    "asilando": "asilar",
    "asilara": "asilar",
    "asilaram": "asilar",
    "asilaras": "asilar",
    "asilarde": "asilar",
    "asilardes": "asilar",
    "asilare": "asilar",
    "asilarei": "asilar",
    "asilareis": "asilar",
    "asilarem": "asilar",
    "asilaremos": "asilar",
    "asilares": "asilar",
    "asilaria": "asilar",
    "asilariam": "asilar",
    "asilarias": "asilar",
    "asilarmo": "asilar",
    "asilarmos": "asilar",
    "asilará": "asilar",
    "asilarás": "asilar",
    "asilarão": "asilar",
    "asilaríamos": "asilar",
    "asilaríeis": "asilar",
    "asilas": "asilar",
    "asilasse": "asilar",
    "asilassem": "asilar",
    "asilasses": "asilar",
    "asilaste": "asilar",
    "asilastes": "asilar",
    "asilava": "asilar",
    "asilavam": "asilar",
    "asilavas": "asilar",
    "asile": "asilar",
    "asilei": "asilar",
    "asileis": "asilar",
    "asilem": "asilar",
    "asilemo": "asilar",
    "asilemos": "asilar",
    "asiles": "asilar",
    "asilo": "asilar",
    "asilos": "asilo",
    "asilou": "asilar",
    "asilá": "asilar",
    "asilámo": "asilar",
    "asilámos": "asilar",
    "asiláramo": "asilar",
    "asiláramos": "asilar",
    "asilárei": "asilar",
    "asiláreis": "asilar",
    "asilásseis": "asilar",
    "asilássemos": "asilar",
    "asilávamo": "asilar",
    "asilávamos": "asilar",
    "asilávei": "asilar",
    "asiláveis": "asilar",
    "asiminas": "asimina",
    "asimineiros": "asimineiro",
    "asinha": "asa",
    "asinhas": "asa",
    "asinina": "asinino",
    "asininas": "asinino",
    "asininos": "asinino",
    "asinária": "asinário",
    "asinárias": "asinário",
    "asinários": "asinário",
    "asita": "asa",
    "asitas": "asa",
    "asiática": "asiático",
    "asiáticas": "asiático",
    "asiáticos": "asiático",
    "asmas": "asma",
    "asmentos": "asmento",
    "asmodeus": "asmodeu",
    "asmática": "asmático",
    "asmáticas": "asmático",
    "asmáticos": "asmático",
    "asnadas": "asnada",
    "asnais": "asnal",
    "asnamentos": "asnamento",
    "asnarias": "asnaria",
    "asnas": "asna",
    "asneira": "asneiro",
    "asneiradas": "asneirada",
    "asneiras": "asneiro",
    "asneirenta": "asneirento",
    "asneirentas": "asneirento",
    "asneirentos": "asneirento",
    "asneirolas": "asneirola",
    "asneironas": "asneirona",
    "asneiros": "asneiro",
    "asneirões": "asneirão",
    "asnices": "asnice",
    "asnidades": "asnidade",
    "asniis": "asnil",
    "asnos": "asno",
    "asnática": "asnático",
    "asnáticas": "asnático",
    "asnáticos": "asnático",
    "aso": "asar",
    "asou": "asar",
    "asparaginas": "asparagina",
    "asparagos": "asparago",
    "asparagácea": "asparagáceo",
    "asparagáceas": "asparagáceo",
    "asparagáceos": "asparagáceo",
    "aspargos": "aspargo",
    "aspas": "aspa",
    "aspaços": "aspaço",
    "aspectos": "aspecto",
    "aspectuais": "aspectual",
    "aspectáveis": "aspectável",
    "aspeitos": "aspeito",
    "asperezas": "aspereza",
    "asperge": "aspergir",
    "aspergem": "aspergir",
    "asperges": "aspergir",
    "aspergi": "aspergir",
    "aspergia": "aspergir",
    "aspergiam": "aspergir",
    "aspergias": "aspergir",
    "aspergida": "aspergir",
    "aspergidas": "aspergir",
    "aspergido": "aspergir",
    "aspergidos": "aspergir",
    "aspergiloformes": "aspergiloforme",
    "aspergilos": "aspergilo",
    "aspergiloses": "aspergilose",
    "aspergilários": "aspergilário",
    "aspergimentos": "aspergimento",
    "aspergimo": "aspergir",
    "aspergimos": "aspergir",
    "aspergindo": "aspergir",
    "aspergira": "aspergir",
    "aspergiram": "aspergir",
    "aspergiras": "aspergir",
    "aspergirde": "aspergir",
    "aspergirdes": "aspergir",
    "aspergire": "aspergir",
    "aspergirei": "aspergir",
    "aspergireis": "aspergir",
    "aspergirem": "aspergir",
    "aspergiremos": "aspergir",
    "aspergires": "aspergir",
    "aspergiria": "aspergir",
    "aspergiriam": "aspergir",
    "aspergirias": "aspergir",
    "aspergirmo": "aspergir",
    "aspergirmos": "aspergir",
    "aspergirá": "aspergir",
    "aspergirás": "aspergir",
    "aspergirão": "aspergir",
    "aspergiríamos": "aspergir",
    "aspergiríeis": "aspergir",
    "aspergis": "aspergir",
    "aspergisse": "aspergir",
    "aspergissem": "aspergir",
    "aspergisses": "aspergir",
    "aspergiste": "aspergir",
    "aspergistes": "aspergir",
    "aspergiu": "aspergir",
    "aspergíamo": "aspergir",
    "aspergíamos": "aspergir",
    "aspergíei": "aspergir",
    "aspergíeis": "aspergir",
    "aspergíramo": "aspergir",
    "aspergíramos": "aspergir",
    "aspergírei": "aspergir",
    "aspergíreis": "aspergir",
    "aspergísseis": "aspergir",
    "aspergíssemos": "aspergir",
    "aspericornes": "aspericorne",
    "asperidades": "asperidade",
    "asperifoliácea": "asperifoliáceo",
    "asperifoliáceas": "asperifoliáceo",
    "asperifoliáceos": "asperifoliáceo",
    "asperifólia": "asperifólio",
    "asperifólias": "asperifólio",
    "asperifólios": "asperifólio",
    "asperinórnea": "asperinórneo",
    "asperinórneas": "asperinórneo",
    "asperinórneos": "asperinórneo",
    "asperma": "aspermo",
    "aspermada": "aspermado",
    "aspermadas": "aspermado",
    "aspermados": "aspermado",
    "aspermas": "aspermo",
    "aspermatismos": "aspermatismo",
    "aspermias": "aspermia",
    "aspermos": "aspermo",
    "aspersa": "asperso",
    "aspersas": "asperso",
    "aspersionismos": "aspersionismo",
    "aspersora": "aspersor",
    "aspersoras": "aspersor",
    "aspersores": "aspersor",
    "aspersos": "asperso",
    "aspersórios": "aspersório",
    "aspersões": "aspersão",
    "asperíssima": "áspero",
    "asperíssimas": "áspero",
    "asperíssimo": "áspero",
    "asperíssimos": "áspero",
    "aspicientes": "aspiciente",
    "aspiciências": "aspiciência",
    "aspideristas": "aspiderista",
    "aspidocéfala": "aspidocéfalo",
    "aspidocéfalas": "aspidocéfalo",
    "aspidocéfalos": "aspidocéfalo",
    "aspidospermas": "aspidosperma",
    "aspidosperminas": "aspidospermina",
    "aspidospérmica": "aspidospérmico",
    "aspidospérmicas": "aspidospérmico",
    "aspidospérmicos": "aspidospérmico",
    "aspira": "aspirar",
    "aspirada": "aspirar",
    "aspiradas": "aspirar",
    "aspirado": "aspirar",
    "aspiradora": "aspirador",
    "aspiradoras": "aspirador",
    "aspiradores": "aspirador",
    "aspirados": "aspirar",
    "aspirai": "aspirar",
    "aspirais": "aspirar",
    "aspiram": "aspirar",
    "aspiramo": "aspirar",
    "aspiramos": "aspirar",
    "aspirando": "aspirar",
    "aspirantes": "aspirante",
    "aspirara": "aspirar",
    "aspiraram": "aspirar",
    "aspiraras": "aspirar",
    "aspirarde": "aspirar",
    "aspirardes": "aspirar",
    "aspirare": "aspirar",
    "aspirarei": "aspirar",
    "aspirareis": "aspirar",
    "aspirarem": "aspirar",
    "aspiraremos": "aspirar",
    "aspirares": "aspirar",
    "aspiraria": "aspirar",
    "aspirariam": "aspirar",
    "aspirarias": "aspirar",
    "aspirarmo": "aspirar",
    "aspirarmos": "aspirar",
    "aspirará": "aspirar",
    "aspirarás": "aspirar",
    "aspirarão": "aspirar",
    "aspiraríamos": "aspirar",
    "aspiraríeis": "aspirar",
    "aspiras": "aspirar",
    "aspirasse": "aspirar",
    "aspirassem": "aspirar",
    "aspirasses": "aspirar",
    "aspiraste": "aspirar",
    "aspirastes": "aspirar",
    "aspirativa": "aspirativo",
    "aspirativas": "aspirativo",
    "aspirativos": "aspirativo",
    "aspiratória": "aspiratório",
    "aspiratórias": "aspiratório",
    "aspiratórios": "aspiratório",
    "aspirava": "aspirar",
    "aspiravam": "aspirar",
    "aspiravas": "aspirar",
    "aspirações": "aspiração",
    "aspire": "aspirar",
    "aspirei": "aspirar",
    "aspireis": "aspirar",
    "aspirem": "aspirar",
    "aspiremo": "aspirar",
    "aspiremos": "aspirar",
    "aspires": "aspirar",
    "aspirinas": "aspirina",
    "aspirja": "aspergir",
    "aspirjais": "aspergir",
    "aspirjam": "aspergir",
    "aspirjamo": "aspergir",
    "aspirjamos": "aspergir",
    "aspirjas": "aspergir",
    "aspirjo": "aspergir",
    "aspiro": "aspirar",
    "aspirou": "aspirar",
    "aspirá": "aspirar",
    "aspirámo": "aspirar",
    "aspirámos": "aspirar",
    "aspiráramo": "aspirar",
    "aspiráramos": "aspirar",
    "aspirárei": "aspirar",
    "aspiráreis": "aspirar",
    "aspirásseis": "aspirar",
    "aspirássemos": "aspirar",
    "aspirávamo": "aspirar",
    "aspirávamos": "aspirar",
    "aspirávei": "aspirar",
    "aspiráveis": "aspirável",
    "aspártica": "aspártico",
    "aspárticas": "aspártico",
    "aspárticos": "aspártico",
    "aspérrima": "áspero",
    "aspérrimas": "áspero",
    "aspérrimo": "áspero",
    "aspérrimos": "áspero",
    "aspérulas": "aspérula",
    "asquerosa": "asqueroso",
    "asquerosas": "asqueroso",
    "asquerosidades": "asquerosidade",
    "asquerosos": "asqueroso",
    "assa": "assar",
    "assaca": "assacar",
    "assacada": "assacar",
    "assacadas": "assacar",
    "assacadilhas": "assacadilha",
    "assacado": "assacar",
    "assacadora": "assacador",
    "assacadoras": "assacador",
    "assacadores": "assacador",
    "assacados": "assacar",
    "assacai": "assacar",
    "assacais": "assacar",
    "assacam": "assacar",
    "assacamo": "assacar",
    "assacamos": "assacar",
    "assacando": "assacar",
    "assacara": "assacar",
    "assacaram": "assacar",
    "assacaras": "assacar",
    "assacarde": "assacar",
    "assacardes": "assacar",
    "assacare": "assacar",
    "assacarei": "assacar",
    "assacareis": "assacar",
    "assacarem": "assacar",
    "assacaremos": "assacar",
    "assacares": "assacar",
    "assacaria": "assacar",
    "assacariam": "assacar",
    "assacarias": "assacar",
    "assacarmo": "assacar",
    "assacarmos": "assacar",
    "assacará": "assacar",
    "assacarás": "assacar",
    "assacarão": "assacar",
    "assacaríamos": "assacar",
    "assacaríeis": "assacar",
    "assacas": "assacar",
    "assacasse": "assacar",
    "assacassem": "assacar",
    "assacasses": "assacar",
    "assacaste": "assacar",
    "assacastes": "assacar",
    "assacates": "assacate",
    "assacava": "assacar",
    "assacavam": "assacar",
    "assacavas": "assacar",
    "assaco": "assacar",
    "assacou": "assacar",
    "assacá": "assacar",
    "assacámo": "assacar",
    "assacámos": "assacar",
    "assacáramo": "assacar",
    "assacáramos": "assacar",
    "assacárei": "assacar",
    "assacáreis": "assacar",
    "assacásseis": "assacar",
    "assacássemos": "assacar",
    "assacávamo": "assacar",
    "assacávamos": "assacar",
    "assacávei": "assacar",
    "assacáveis": "assacável",
    "assada": "assar",
    "assadas": "assar",
    "assadeira": "assadeiro",
    "assadeiras": "assadeiro",
    "assadeiros": "assadeiro",
    "assadinha": "assado",
    "assadinhas": "assado",
    "assadinho": "assado",
    "assadinhos": "assado",
    "assadita": "assado",
    "assaditas": "assado",
    "assadito": "assado",
    "assaditos": "assado",
    "assado": "assar",
    "assadora": "assador",
    "assadoras": "assador",
    "assadores": "assador",
    "assados": "assar",
    "assaduras": "assadura",
    "assadíssima": "assado",
    "assadíssimas": "assado",
    "assadíssimo": "assado",
    "assadíssimos": "assado",
    "assai": "assar",
    "assais": "assar",
    "assalaria": "assalariar",
    "assalariada": "assalariar",
    "assalariadas": "assalariar",
    "assalariado": "assalariar",
    "assalariados": "assalariar",
    "assalariai": "assalariar",
    "assalariais": "assalariar",
    "assalariam": "assalariar",
    "assalariamo": "assalariar",
    "assalariamos": "assalariar",
    "assalariando": "assalariar",
    "assalariara": "assalariar",
    "assalariaram": "assalariar",
    "assalariaras": "assalariar",
    "assalariarde": "assalariar",
    "assalariardes": "assalariar",
    "assalariare": "assalariar",
    "assalariarei": "assalariar",
    "assalariareis": "assalariar",
    "assalariarem": "assalariar",
    "assalariaremos": "assalariar",
    "assalariares": "assalariar",
    "assalariaria": "assalariar",
    "assalariariam": "assalariar",
    "assalariarias": "assalariar",
    "assalariarmo": "assalariar",
    "assalariarmos": "assalariar",
    "assalariará": "assalariar",
    "assalariarás": "assalariar",
    "assalariarão": "assalariar",
    "assalariaríamos": "assalariar",
    "assalariaríeis": "assalariar",
    "assalarias": "assalariar",
    "assalariasse": "assalariar",
    "assalariassem": "assalariar",
    "assalariasses": "assalariar",
    "assalariaste": "assalariar",
    "assalariastes": "assalariar",
    "assalariava": "assalariar",
    "assalariavam": "assalariar",
    "assalariavas": "assalariar",
    "assalarie": "assalariar",
    "assalariei": "assalariar",
    "assalarieis": "assalariar",
    "assalariem": "assalariar",
    "assalariemo": "assalariar",
    "assalariemos": "assalariar",
    "assalaries": "assalariar",
    "assalario": "assalariar",
    "assalariou": "assalariar",
    "assalariá": "assalariar",
    "assalariámo": "assalariar",
    "assalariámos": "assalariar",
    "assalariáramo": "assalariar",
    "assalariáramos": "assalariar",
    "assalariárei": "assalariar",
    "assalariáreis": "assalariar",
    "assalariásseis": "assalariar",
    "assalariássemos": "assalariar",
    "assalariávamo": "assalariar",
    "assalariávamos": "assalariar",
    "assalariávei": "assalariar",
    "assalariáveis": "assalariar",
    "assalmonada": "assalmonado",
    "assalmonadas": "assalmonado",
    "assalmonados": "assalmonado",
    "assaloiada": "assaloiado",
    "assaloiadas": "assaloiado",
    "assaloiados": "assaloiado",
    "assalta": "assaltar",
    "assaltada": "assaltar",
    "assaltadas": "assaltar",
    "assaltado": "assaltar",
    "assaltados": "assaltar",
    "assaltai": "assaltar",
    "assaltais": "assaltar",
    "assaltam": "assaltar",
    "assaltamo": "assaltar",
    "assaltamos": "assaltar",
    "assaltando": "assaltar",
    "assaltantes": "assaltante",
    "assaltara": "assaltar",
    "assaltaram": "assaltar",
    "assaltaras": "assaltar",
    "assaltarde": "assaltar",
    "assaltardes": "assaltar",
    "assaltare": "assaltar",
    "assaltarei": "assaltar",
    "assaltareis": "assaltar",
    "assaltarem": "assaltar",
    "assaltaremos": "assaltar",
    "assaltares": "assaltar",
    "assaltaria": "assaltar",
    "assaltariam": "assaltar",
    "assaltarias": "assaltar",
    "assaltarmo": "assaltar",
    "assaltarmos": "assaltar",
    "assaltará": "assaltar",
    "assaltarás": "assaltar",
    "assaltarão": "assaltar",
    "assaltaríamos": "assaltar",
    "assaltaríeis": "assaltar",
    "assaltas": "assaltar",
    "assaltasse": "assaltar",
    "assaltassem": "assaltar",
    "assaltasses": "assaltar",
    "assaltaste": "assaltar",
    "assaltastes": "assaltar",
    "assaltava": "assaltar",
    "assaltavam": "assaltar",
    "assaltavas": "assaltar",
    "assalte": "assaltar",
    "assaltei": "assaltar",
    "assalteis": "assaltar",
    "assaltem": "assaltar",
    "assaltemo": "assaltar",
    "assaltemos": "assaltar",
    "assaltes": "assaltar",
    "assalto": "assaltar",
    "assaltos": "assalto",
    "assaltou": "assaltar",
    "assaltá": "assaltar",
    "assaltámo": "assaltar",
    "assaltámos": "assaltar",
    "assaltáramo": "assaltar",
    "assaltáramos": "assaltar",
    "assaltárei": "assaltar",
    "assaltáreis": "assaltar",
    "assaltásseis": "assaltar",
    "assaltássemos": "assaltar",
    "assaltávamo": "assaltar",
    "assaltávamos": "assaltar",
    "assaltávei": "assaltar",
    "assaltáveis": "assaltar",
    "assam": "assar",
    "assamo": "assar",
    "assamos": "assar",
    "assando": "assar",
    "assanha": "assanhar",
    "assanhada": "assanhar",
    "assanhadas": "assanhar",
    "assanhado": "assanhar",
    "assanhados": "assanhar",
    "assanhai": "assanhar",
    "assanhais": "assanhar",
    "assanham": "assanhar",
    "assanhamo": "assanhar",
    "assanhamos": "assanhar",
    "assanhando": "assanhar",
    "assanhara": "assanhar",
    "assanharam": "assanhar",
    "assanharas": "assanhar",
    "assanharde": "assanhar",
    "assanhardes": "assanhar",
    "assanhare": "assanhar",
    "assanharei": "assanhar",
    "assanhareis": "assanhar",
    "assanharem": "assanhar",
    "assanharemos": "assanhar",
    "assanhares": "assanhar",
    "assanharia": "assanhar",
    "assanhariam": "assanhar",
    "assanharias": "assanhar",
    "assanharmo": "assanhar",
    "assanharmos": "assanhar",
    "assanhará": "assanhar",
    "assanharás": "assanhar",
    "assanharão": "assanhar",
    "assanharíamos": "assanhar",
    "assanharíeis": "assanhar",
    "assanhas": "assanhar",
    "assanhasse": "assanhar",
    "assanhassem": "assanhar",
    "assanhasses": "assanhar",
    "assanhaste": "assanhar",
    "assanhastes": "assanhar",
    "assanhava": "assanhar",
    "assanhavam": "assanhar",
    "assanhavas": "assanhar",
    "assanhe": "assanhar",
    "assanhei": "assanhar",
    "assanheis": "assanhar",
    "assanhem": "assanhar",
    "assanhemo": "assanhar",
    "assanhemos": "assanhar",
    "assanhes": "assanhar",
    "assanho": "assanhar",
    "assanhou": "assanhar",
    "assanhá": "assanhar",
    "assanhámo": "assanhar",
    "assanhámos": "assanhar",
    "assanháramo": "assanhar",
    "assanháramos": "assanhar",
    "assanhárei": "assanhar",
    "assanháreis": "assanhar",
    "assanhásseis": "assanhar",
    "assanhássemos": "assanhar",
    "assanhávamo": "assanhar",
    "assanhávamos": "assanhar",
    "assanhávei": "assanhar",
    "assanháveis": "assanhar",
    "assaque": "assacar",
    "assaquei": "assacar",
    "assaqueis": "assacar",
    "assaquem": "assacar",
    "assaquemo": "assacar",
    "assaquemos": "assacar",
    "assaques": "assacar",
    "assara": "assar",
    "assaram": "assar",
    "assarapanta": "assarapantar",
    "assarapantada": "assarapantar",
    "assarapantadas": "assarapantar",
    "assarapantado": "assarapantar",
    "assarapantados": "assarapantar",
    "assarapantai": "assarapantar",
    "assarapantais": "assarapantar",
    "assarapantam": "assarapantar",
    "assarapantamo": "assarapantar",
    "assarapantamos": "assarapantar",
    "assarapantando": "assarapantar",
    "assarapantara": "assarapantar",
    "assarapantaram": "assarapantar",
    "assarapantaras": "assarapantar",
    "assarapantarde": "assarapantar",
    "assarapantardes": "assarapantar",
    "assarapantare": "assarapantar",
    "assarapantarei": "assarapantar",
    "assarapantareis": "assarapantar",
    "assarapantarem": "assarapantar",
    "assarapantaremos": "assarapantar",
    "assarapantares": "assarapantar",
    "assarapantaria": "assarapantar",
    "assarapantariam": "assarapantar",
    "assarapantarias": "assarapantar",
    "assarapantarmo": "assarapantar",
    "assarapantarmos": "assarapantar",
    "assarapantará": "assarapantar",
    "assarapantarás": "assarapantar",
    "assarapantarão": "assarapantar",
    "assarapantaríamos": "assarapantar",
    "assarapantaríeis": "assarapantar",
    "assarapantas": "assarapantar",
    "assarapantasse": "assarapantar",
    "assarapantassem": "assarapantar",
    "assarapantasses": "assarapantar",
    "assarapantaste": "assarapantar",
    "assarapantastes": "assarapantar",
    "assarapantava": "assarapantar",
    "assarapantavam": "assarapantar",
    "assarapantavas": "assarapantar",
    "assarapante": "assarapantar",
    "assarapantei": "assarapantar",
    "assarapanteis": "assarapantar",
    "assarapantem": "assarapantar",
    "assarapantemo": "assarapantar",
    "assarapantemos": "assarapantar",
    "assarapantes": "assarapantar",
    "assarapanto": "assarapantar",
    "assarapantou": "assarapantar",
    "assarapantá": "assarapantar",
    "assarapantámo": "assarapantar",
    "assarapantámos": "assarapantar",
    "assarapantáramo": "assarapantar",
    "assarapantáramos": "assarapantar",
    "assarapantárei": "assarapantar",
    "assarapantáreis": "assarapantar",
    "assarapantásseis": "assarapantar",
    "assarapantássemos": "assarapantar",
    "assarapantávamo": "assarapantar",
    "assarapantávamos": "assarapantar",
    "assarapantávei": "assarapantar",
    "assarapantáveis": "assarapantar",
    "assaras": "assar",
    "assarde": "assar",
    "assardes": "assar",
    "assare": "assar",
    "assarei": "assar",
    "assareis": "assar",
    "assarem": "assar",
    "assaremos": "assar",
    "assares": "assar",
    "assaria": "assar",
    "assariam": "assar",
    "assarias": "assar",
    "assarmo": "assar",
    "assarmos": "assar",
    "assará": "assar",
    "assarás": "assar",
    "assarão": "assar",
    "assaríamos": "assar",
    "assaríeis": "assar",
    "assas": "assar",
    "assasse": "assar",
    "assassem": "assar",
    "assasses": "assar",
    "assassina": "assassino",
    "assassinada": "assassinar",
    "assassinadas": "assassinar",
    "assassinado": "assassinar",
    "assassinados": "assassinar",
    "assassinai": "assassinar",
    "assassinais": "assassinar",
    "assassinam": "assassinar",
    "assassinamo": "assassinar",
    "assassinamos": "assassinar",
    "assassinando": "assassinar",
    "assassinara": "assassinar",
    "assassinaram": "assassinar",
    "assassinaras": "assassinar",
    "assassinarde": "assassinar",
    "assassinardes": "assassinar",
    "assassinare": "assassinar",
    "assassinarei": "assassinar",
    "assassinareis": "assassinar",
    "assassinarem": "assassinar",
    "assassinaremos": "assassinar",
    "assassinares": "assassinar",
    "assassinaria": "assassinar",
    "assassinariam": "assassinar",
    "assassinarias": "assassinar",
    "assassinarmo": "assassinar",
    "assassinarmos": "assassinar",
    "assassinará": "assassinar",
    "assassinarás": "assassinar",
    "assassinarão": "assassinar",
    "assassinaríamos": "assassinar",
    "assassinaríeis": "assassinar",
    "assassinas": "assassino",
    "assassinasse": "assassinar",
    "assassinassem": "assassinar",
    "assassinasses": "assassinar",
    "assassinaste": "assassinar",
    "assassinastes": "assassinar",
    "assassinatos": "assassinato",
    "assassinava": "assassinar",
    "assassinavam": "assassinar",
    "assassinavas": "assassinar",
    "assassine": "assassinar",
    "assassinei": "assassinar",
    "assassineis": "assassinar",
    "assassinem": "assassinar",
    "assassinemo": "assassinar",
    "assassinemos": "assassinar",
    "assassines": "assassinar",
    "assassino": "assassinar",
    "assassinos": "assassino",
    "assassinou": "assassinar",
    "assassiná": "assassinar",
    "assassinámo": "assassinar",
    "assassinámos": "assassinar",
    "assassináramo": "assassinar",
    "assassináramos": "assassinar",
    "assassinárei": "assassinar",
    "assassináreis": "assassinar",
    "assassinásseis": "assassinar",
    "assassinássemos": "assassinar",
    "assassinávamo": "assassinar",
    "assassinávamos": "assassinar",
    "assassinávei": "assassinar",
    "assassináveis": "assassinar",
    "assassínios": "assassínio",
    "assaste": "assar",
    "assastes": "assar",
    "assava": "assar",
    "assavam": "assar",
    "assavas": "assar",
    "asse": "assar",
    "asseada": "assear",
    "asseadas": "assear",
    "asseadinha": "asseado",
    "asseadinhas": "asseado",
    "asseadinho": "asseado",
    "asseadinhos": "asseado",
    "asseadita": "asseado",
    "asseaditas": "asseado",
    "asseadito": "asseado",
    "asseaditos": "asseado",
    "asseado": "assear",
    "asseados": "assear",
    "asseadíssima": "asseado",
    "asseadíssimas": "asseado",
    "asseadíssimo": "asseado",
    "asseadíssimos": "asseado",
    "asseai": "assear",
    "asseais": "assear",
    "asseamo": "assear",
    "asseamos": "assear",
    "asseando": "assear",
    "asseara": "assear",
    "assearam": "assear",
    "assearas": "assear",
    "assearde": "assear",
    "asseardes": "assear",
    "asseare": "assear",
    "assearei": "assear",
    "asseareis": "assear",
    "assearem": "assear",
    "assearemos": "assear",
    "asseares": "assear",
    "assearia": "assear",
    "asseariam": "assear",
    "assearias": "assear",
    "assearmo": "assear",
    "assearmos": "assear",
    "asseará": "assear",
    "assearás": "assear",
    "assearão": "assear",
    "assearíamos": "assear",
    "assearíeis": "assear",
    "asseasse": "assear",
    "asseassem": "assear",
    "asseasses": "assear",
    "asseaste": "assear",
    "asseastes": "assear",
    "asseava": "assear",
    "asseavam": "assear",
    "asseavas": "assear",
    "assedadeiras": "assedadeira",
    "assedadores": "assedador",
    "assedagens": "assedagem",
    "assedentada": "assedentado",
    "assedentadas": "assedentado",
    "assedentados": "assedentado",
    "assedia": "assediar",
    "assediada": "assediar",
    "assediadas": "assediar",
    "assediado": "assediar",
    "assediadora": "assediador",
    "assediadoras": "assediador",
    "assediadores": "assediador",
    "assediados": "assediar",
    "assediai": "assediar",
    "assediais": "assediar",
    "assediam": "assediar",
    "assediamo": "assediar",
    "assediamos": "assediar",
    "assediando": "assediar",
    "assediara": "assediar",
    "assediaram": "assediar",
    "assediaras": "assediar",
    "assediarde": "assediar",
    "assediardes": "assediar",
    "assediare": "assediar",
    "assediarei": "assediar",
    "assediareis": "assediar",
    "assediarem": "assediar",
    "assediaremos": "assediar",
    "assediares": "assediar",
    "assediaria": "assediar",
    "assediariam": "assediar",
    "assediarias": "assediar",
    "assediarmo": "assediar",
    "assediarmos": "assediar",
    "assediará": "assediar",
    "assediarás": "assediar",
    "assediarão": "assediar",
    "assediaríamos": "assediar",
    "assediaríeis": "assediar",
    "assedias": "assediar",
    "assediasse": "assediar",
    "assediassem": "assediar",
    "assediasses": "assediar",
    "assediaste": "assediar",
    "assediastes": "assediar",
    "assediava": "assediar",
    "assediavam": "assediar",
    "assediavas": "assediar",
    "assedie": "assediar",
    "assediei": "assediar",
    "assedieis": "assediar",
    "assediem": "assediar",
    "assediemo": "assediar",
    "assediemos": "assediar",
    "assedies": "assediar",
    "assedilhada": "assedilhado",
    "assedilhadas": "assedilhado",
    "assedilhados": "assedilhado",
    "assedio": "assediar",
    "assediou": "assediar",
    "assediá": "assediar",
    "assediámo": "assediar",
    "assediámos": "assediar",
    "assediáramo": "assediar",
    "assediáramos": "assediar",
    "assediárei": "assediar",
    "assediáreis": "assediar",
    "assediásseis": "assediar",
    "assediássemos": "assediar",
    "assediávamo": "assediar",
    "assediávamos": "assediar",
    "assediávei": "assediar",
    "assediáveis": "assediar",
    "asseei": "assear",
    "asseeis": "assear",
    "asseemo": "assear",
    "asseemos": "assear",
    "assegura": "assegurar",
    "assegurada": "assegurar",
    "asseguradas": "assegurar",
    "assegurado": "assegurar",
    "asseguradora": "assegurador",
    "asseguradoras": "assegurador",
    "asseguradores": "assegurador",
    "assegurados": "assegurar",
    "assegurai": "assegurar",
    "assegurais": "assegurar",
    "asseguram": "assegurar",
    "asseguramo": "assegurar",
    "asseguramos": "assegurar",
    "assegurando": "assegurar",
    "assegurara": "assegurar",
    "asseguraram": "assegurar",
    "asseguraras": "assegurar",
    "assegurarde": "assegurar",
    "assegurardes": "assegurar",
    "assegurare": "assegurar",
    "assegurarei": "assegurar",
    "assegurareis": "assegurar",
    "assegurarem": "assegurar",
    "asseguraremos": "assegurar",
    "assegurares": "assegurar",
    "asseguraria": "assegurar",
    "assegurariam": "assegurar",
    "assegurarias": "assegurar",
    "assegurarmo": "assegurar",
    "assegurarmos": "assegurar",
    "assegurará": "assegurar",
    "assegurarás": "assegurar",
    "assegurarão": "assegurar",
    "asseguraríamos": "assegurar",
    "asseguraríeis": "assegurar",
    "asseguras": "assegurar",
    "assegurasse": "assegurar",
    "assegurassem": "assegurar",
    "assegurasses": "assegurar",
    "asseguraste": "assegurar",
    "assegurastes": "assegurar",
    "assegurava": "assegurar",
    "asseguravam": "assegurar",
    "asseguravas": "assegurar",
    "assegurações": "asseguração",
    "assegure": "assegurar",
    "assegurei": "assegurar",
    "assegureis": "assegurar",
    "assegurem": "assegurar",
    "asseguremo": "assegurar",
    "asseguremos": "assegurar",
    "assegures": "assegurar",
    "asseguro": "assegurar",
    "assegurou": "assegurar",
    "assegurá": "assegurar",
    "assegurámo": "assegurar",
    "assegurámos": "assegurar",
    "asseguráramo": "assegurar",
    "asseguráramos": "assegurar",
    "assegurárei": "assegurar",
    "asseguráreis": "assegurar",
    "assegurásseis": "assegurar",
    "assegurássemos": "assegurar",
    "assegurávamo": "assegurar",
    "assegurávamos": "assegurar",
    "assegurávei": "assegurar",
    "asseguráveis": "assegurar",
    "assei": "assar",
    "asseia": "assear",
    "asseiam": "assear",
    "asseias": "assear",
    "asseidades": "asseidade",
    "asseie": "assear",
    "asseiem": "assear",
    "asseies": "assear",
    "asseio": "assear",
    "asseios": "asseio",
    "asseis": "assar",
    "asselada": "asselado",
    "asseladas": "asselado",
    "asselados": "asselado",
    "asselvaja": "asselvajar",
    "asselvajada": "asselvajar",
    "asselvajadas": "asselvajar",
    "asselvajado": "asselvajar",
    "asselvajados": "asselvajar",
    "asselvajai": "asselvajar",
    "asselvajais": "asselvajar",
    "asselvajam": "asselvajar",
    "asselvajamentos": "asselvajamento",
    "asselvajamo": "asselvajar",
    "asselvajamos": "asselvajar",
    "asselvajando": "asselvajar",
    "asselvajara": "asselvajar",
    "asselvajaram": "asselvajar",
    "asselvajaras": "asselvajar",
    "asselvajarde": "asselvajar",
    "asselvajardes": "asselvajar",
    "asselvajare": "asselvajar",
    "asselvajarei": "asselvajar",
    "asselvajareis": "asselvajar",
    "asselvajarem": "asselvajar",
    "asselvajaremos": "asselvajar",
    "asselvajares": "asselvajar",
    "asselvajaria": "asselvajar",
    "asselvajariam": "asselvajar",
    "asselvajarias": "asselvajar",
    "asselvajarmo": "asselvajar",
    "asselvajarmos": "asselvajar",
    "asselvajará": "asselvajar",
    "asselvajarás": "asselvajar",
    "asselvajarão": "asselvajar",
    "asselvajaríamos": "asselvajar",
    "asselvajaríeis": "asselvajar",
    "asselvajas": "asselvajar",
    "asselvajasse": "asselvajar",
    "asselvajassem": "asselvajar",
    "asselvajasses": "asselvajar",
    "asselvajaste": "asselvajar",
    "asselvajastes": "asselvajar",
    "asselvajava": "asselvajar",
    "asselvajavam": "asselvajar",
    "asselvajavas": "asselvajar",
    "asselvaje": "asselvajar",
    "asselvajei": "asselvajar",
    "asselvajeis": "asselvajar",
    "asselvajem": "asselvajar",
    "asselvajemo": "asselvajar",
    "asselvajemos": "asselvajar",
    "asselvajes": "asselvajar",
    "asselvajo": "asselvajar",
    "asselvajou": "asselvajar",
    "asselvajá": "asselvajar",
    "asselvajámo": "asselvajar",
    "asselvajámos": "asselvajar",
    "asselvajáramo": "asselvajar",
    "asselvajáramos": "asselvajar",
    "asselvajárei": "asselvajar",
    "asselvajáreis": "asselvajar",
    "asselvajásseis": "asselvajar",
    "asselvajássemos": "asselvajar",
    "asselvajávamo": "asselvajar",
    "asselvajávamos": "asselvajar",
    "asselvajávei": "asselvajar",
    "asselvajáveis": "asselvajar",
    "assem": "assar",
    "assema": "assemo",
    "assemas": "assemo",
    "assembleias": "assembleia",
    "assemelha": "assemelhar",
    "assemelhada": "assemelhar",
    "assemelhadas": "assemelhar",
    "assemelhado": "assemelhar",
    "assemelhados": "assemelhar",
    "assemelhai": "assemelhar",
    "assemelhais": "assemelhar",
    "assemelham": "assemelhar",
    "assemelhamo": "assemelhar",
    "assemelhamos": "assemelhar",
    "assemelhando": "assemelhar",
    "assemelhara": "assemelhar",
    "assemelharam": "assemelhar",
    "assemelharas": "assemelhar",
    "assemelharde": "assemelhar",
    "assemelhardes": "assemelhar",
    "assemelhare": "assemelhar",
    "assemelharei": "assemelhar",
    "assemelhareis": "assemelhar",
    "assemelharem": "assemelhar",
    "assemelharemos": "assemelhar",
    "assemelhares": "assemelhar",
    "assemelharia": "assemelhar",
    "assemelhariam": "assemelhar",
    "assemelharias": "assemelhar",
    "assemelharmo": "assemelhar",
    "assemelharmos": "assemelhar",
    "assemelhará": "assemelhar",
    "assemelharás": "assemelhar",
    "assemelharão": "assemelhar",
    "assemelharíamos": "assemelhar",
    "assemelharíeis": "assemelhar",
    "assemelhas": "assemelhar",
    "assemelhasse": "assemelhar",
    "assemelhassem": "assemelhar",
    "assemelhasses": "assemelhar",
    "assemelhaste": "assemelhar",
    "assemelhastes": "assemelhar",
    "assemelhava": "assemelhar",
    "assemelhavam": "assemelhar",
    "assemelhavas": "assemelhar",
    "assemelhações": "assemelhação",
    "assemelhe": "assemelhar",
    "assemelhei": "assemelhar",
    "assemelheis": "assemelhar",
    "assemelhem": "assemelhar",
    "assemelhemo": "assemelhar",
    "assemelhemos": "assemelhar",
    "assemelhes": "assemelhar",
    "assemelho": "assemelhar",
    "assemelhou": "assemelhar",
    "assemelhá": "assemelhar",
    "assemelhámo": "assemelhar",
    "assemelhámos": "assemelhar",
    "assemelháramo": "assemelhar",
    "assemelháramos": "assemelhar",
    "assemelhárei": "assemelhar",
    "assemelháreis": "assemelhar",
    "assemelhásseis": "assemelhar",
    "assemelhássemos": "assemelhar",
    "assemelhávamo": "assemelhar",
    "assemelhávamos": "assemelhar",
    "assemelhávei": "assemelhar",
    "assemelháveis": "assemelhável",
    "assemias": "assemia",
    "assemo": "assar",
    "assemos": "assemo",
    "assenhora": "assenhorar",
    "assenhorada": "assenhorar",
    "assenhoradas": "assenhorar",
    "assenhorado": "assenhorar",
    "assenhorados": "assenhorar",
    "assenhorai": "assenhorar",
    "assenhorais": "assenhorar",
    "assenhoram": "assenhorar",
    "assenhoramo": "assenhorar",
    "assenhoramos": "assenhorar",
    "assenhorando": "assenhorar",
    "assenhorara": "assenhorar",
    "assenhoraram": "assenhorar",
    "assenhoraras": "assenhorar",
    "assenhorarde": "assenhorar",
    "assenhorardes": "assenhorar",
    "assenhorare": "assenhorar",
    "assenhorarei": "assenhorar",
    "assenhorareis": "assenhorar",
    "assenhorarem": "assenhorar",
    "assenhoraremos": "assenhorar",
    "assenhorares": "assenhorar",
    "assenhoraria": "assenhorar",
    "assenhorariam": "assenhorar",
    "assenhorarias": "assenhorar",
    "assenhorarmo": "assenhorar",
    "assenhorarmos": "assenhorar",
    "assenhorará": "assenhorar",
    "assenhorarás": "assenhorar",
    "assenhorarão": "assenhorar",
    "assenhoraríamos": "assenhorar",
    "assenhoraríeis": "assenhorar",
    "assenhoras": "assenhorar",
    "assenhorasse": "assenhorar",
    "assenhorassem": "assenhorar",
    "assenhorasses": "assenhorar",
    "assenhoraste": "assenhorar",
    "assenhorastes": "assenhorar",
    "assenhorava": "assenhorar",
    "assenhoravam": "assenhorar",
    "assenhoravas": "assenhorar",
    "assenhore": "assenhorar",
    "assenhoreada": "assenhorear",
    "assenhoreadas": "assenhorear",
    "assenhoreado": "assenhorear",
    "assenhoreados": "assenhorear",
    "assenhoreai": "assenhorear",
    "assenhoreais": "assenhorear",
    "assenhoreamentos": "assenhoreamento",
    "assenhoreamo": "assenhorear",
    "assenhoreamos": "assenhorear",
    "assenhoreando": "assenhorear",
    "assenhoreara": "assenhorear",
    "assenhorearam": "assenhorear",
    "assenhorearas": "assenhorear",
    "assenhorearde": "assenhorear",
    "assenhoreardes": "assenhorear",
    "assenhoreare": "assenhorear",
    "assenhorearei": "assenhorear",
    "assenhoreareis": "assenhorear",
    "assenhorearem": "assenhorear",
    "assenhorearemos": "assenhorear",
    "assenhoreares": "assenhorear",
    "assenhorearia": "assenhorear",
    "assenhoreariam": "assenhorear",
    "assenhorearias": "assenhorear",
    "assenhorearmo": "assenhorear",
    "assenhorearmos": "assenhorear",
    "assenhoreará": "assenhorear",
    "assenhorearás": "assenhorear",
    "assenhorearão": "assenhorear",
    "assenhorearíamos": "assenhorear",
    "assenhorearíeis": "assenhorear",
    "assenhoreasse": "assenhorear",
    "assenhoreassem": "assenhorear",
    "assenhoreasses": "assenhorear",
    "assenhoreaste": "assenhorear",
    "assenhoreastes": "assenhorear",
    "assenhoreava": "assenhorear",
    "assenhoreavam": "assenhorear",
    "assenhoreavas": "assenhorear",
    "assenhoreei": "assenhorear",
    "assenhoreeis": "assenhorear",
    "assenhoreemo": "assenhorear",
    "assenhoreemos": "assenhorear",
    "assenhorei": "assenhorar",
    "assenhoreia": "assenhorear",
    "assenhoreiam": "assenhorear",
    "assenhoreias": "assenhorear",
    "assenhoreie": "assenhorear",
    "assenhoreiem": "assenhorear",
    "assenhoreies": "assenhorear",
    "assenhoreio": "assenhorear",
    "assenhoreis": "assenhorar",
    "assenhorem": "assenhorar",
    "assenhoremo": "assenhorar",
    "assenhoremos": "assenhorar",
    "assenhoreou": "assenhorear",
    "assenhores": "assenhorar",
    "assenhoreá": "assenhorear",
    "assenhoreámo": "assenhorear",
    "assenhoreámos": "assenhorear",
    "assenhoreáramo": "assenhorear",
    "assenhoreáramos": "assenhorear",
    "assenhoreárei": "assenhorear",
    "assenhoreáreis": "assenhorear",
    "assenhoreásseis": "assenhorear",
    "assenhoreássemos": "assenhorear",
    "assenhoreávamo": "assenhorear",
    "assenhoreávamos": "assenhorear",
    "assenhoreávei": "assenhorear",
    "assenhoreáveis": "assenhorear",
    "assenhoro": "assenhorar",
    "assenhorou": "assenhorar",
    "assenhorá": "assenhorar",
    "assenhorámo": "assenhorar",
    "assenhorámos": "assenhorar",
    "assenhoráramo": "assenhorar",
    "assenhoráramos": "assenhorar",
    "assenhorárei": "assenhorar",
    "assenhoráreis": "assenhorar",
    "assenhorásseis": "assenhorar",
    "assenhorássemos": "assenhorar",
    "assenhorávamo": "assenhorar",
    "assenhorávamos": "assenhorar",
    "assenhorávei": "assenhorar",
    "assenhoráveis": "assenhorar",
    "assensos": "assenso",
    "assenta": "assentir",
    "assentada": "assentar",
    "assentadas": "assentar",
    "assentadeiras": "assentadeira",
    "assentado": "assentar",
    "assentadora": "assentador",
    "assentadoras": "assentador",
    "assentadores": "assentador",
    "assentados": "assentar",
    "assentadíssima": "assentado",
    "assentadíssimas": "assentado",
    "assentadíssimo": "assentado",
    "assentadíssimos": "assentado",
    "assentai": "assentar",
    "assentais": "assentir",
    "assentam": "assentir",
    "assentamentos": "assentamento",
    "assentamo": "assentir",
    "assentamos": "assentir",
    "assentando": "assentar",
    "assentara": "assentar",
    "assentaram": "assentar",
    "assentaras": "assentar",
    "assentarde": "assentar",
    "assentardes": "assentar",
    "assentare": "assentar",
    "assentarei": "assentar",
    "assentareis": "assentar",
    "assentarem": "assentar",
    "assentaremos": "assentar",
    "assentares": "assentar",
    "assentaria": "assentar",
    "assentariam": "assentar",
    "assentarias": "assentar",
    "assentarmo": "assentar",
    "assentarmos": "assentar",
    "assentará": "assentar",
    "assentarás": "assentar",
    "assentarão": "assentar",
    "assentaríamos": "assentar",
    "assentaríeis": "assentar",
    "assentas": "assentir",
    "assentasse": "assentar",
    "assentassem": "assentar",
    "assentasses": "assentar",
    "assentaste": "assentar",
    "assentastes": "assentar",
    "assentava": "assentar",
    "assentavam": "assentar",
    "assentavas": "assentar",
    "assente": "assentir",
    "assentei": "assentar",
    "assenteis": "assentar",
    "assentem": "assentir",
    "assentemo": "assentar",
    "assentemos": "assentar",
    "assentes": "assentir",
    "assenti": "assentir",
    "assentia": "assentir",
    "assentiam": "assentir",
    "assentias": "assentir",
    "assentida": "assentir",
    "assentidas": "assentir",
    "assentido": "assentir",
    "assentidos": "assentir",
    "assentimentos": "assentimento",
    "assentimo": "assentir",
    "assentimos": "assentir",
    "assentindo": "assentir",
    "assentira": "assentir",
    "assentiram": "assentir",
    "assentiras": "assentir",
    "assentirdes": "assentir",
    "assentirei": "assentir",
    "assentireis": "assentir",
    "assentirem": "assentir",
    "assentiremos": "assentir",
    "assentires": "assentir",
    "assentiria": "assentir",
    "assentiriam": "assentir",
    "assentirias": "assentir",
    "assentirmo": "assentir",
    "assentirmos": "assentir",
    "assentirá": "assentir",
    "assentirás": "assentir",
    "assentirão": "assentir",
    "assentiríamos": "assentir",
    "assentiríeis": "assentir",
    "assentis": "assentir",
    "assentisse": "assentir",
    "assentissem": "assentir",
    "assentisses": "assentir",
    "assentiste": "assentir",
    "assentistes": "assentir",
    "assentiu": "assentir",
    "assento": "assentir",
    "assentos": "assento",
    "assentou": "assentar",
    "assentá": "assentar",
    "assentámo": "assentar",
    "assentámos": "assentar",
    "assentáramo": "assentar",
    "assentáramos": "assentar",
    "assentárei": "assentar",
    "assentáreis": "assentar",
    "assentásseis": "assentar",
    "assentássemos": "assentar",
    "assentávamo": "assentar",
    "assentávamos": "assentar",
    "assentávei": "assentar",
    "assentáveis": "assentar",
    "assentíamo": "assentir",
    "assentíamos": "assentir",
    "assentíeis": "assentir",
    "assentíramo": "assentir",
    "assentíramos": "assentir",
    "assentíreis": "assentir",
    "assentísseis": "assentir",
    "assentíssemos": "assentir",
    "asseou": "assear",
    "assepsia": "assepsiar",
    "assepsiada": "assepsiar",
    "assepsiadas": "assepsiar",
    "assepsiado": "assepsiar",
    "assepsiados": "assepsiar",
    "assepsiai": "assepsiar",
    "assepsiais": "assepsiar",
    "assepsiam": "assepsiar",
    "assepsiamo": "assepsiar",
    "assepsiamos": "assepsiar",
    "assepsiando": "assepsiar",
    "assepsiara": "assepsiar",
    "assepsiaram": "assepsiar",
    "assepsiaras": "assepsiar",
    "assepsiarde": "assepsiar",
    "assepsiardes": "assepsiar",
    "assepsiare": "assepsiar",
    "assepsiarei": "assepsiar",
    "assepsiareis": "assepsiar",
    "assepsiarem": "assepsiar",
    "assepsiaremos": "assepsiar",
    "assepsiares": "assepsiar",
    "assepsiaria": "assepsiar",
    "assepsiariam": "assepsiar",
    "assepsiarias": "assepsiar",
    "assepsiarmo": "assepsiar",
    "assepsiarmos": "assepsiar",
    "assepsiará": "assepsiar",
    "assepsiarás": "assepsiar",
    "assepsiarão": "assepsiar",
    "assepsiaríamos": "assepsiar",
    "assepsiaríeis": "assepsiar",
    "assepsias": "assepsiar",
    "assepsiasse": "assepsiar",
    "assepsiassem": "assepsiar",
    "assepsiasses": "assepsiar",
    "assepsiaste": "assepsiar",
    "assepsiastes": "assepsiar",
    "assepsiava": "assepsiar",
    "assepsiavam": "assepsiar",
    "assepsiavas": "assepsiar",
    "assepsie": "assepsiar",
    "assepsiei": "assepsiar",
    "assepsieis": "assepsiar",
    "assepsiem": "assepsiar",
    "assepsiemo": "assepsiar",
    "assepsiemos": "assepsiar",
    "assepsies": "assepsiar",
    "assepsio": "assepsiar",
    "assepsiou": "assepsiar",
    "assepsiá": "assepsiar",
    "assepsiámo": "assepsiar",
    "assepsiámos": "assepsiar",
    "assepsiáramo": "assepsiar",
    "assepsiáramos": "assepsiar",
    "assepsiárei": "assepsiar",
    "assepsiáreis": "assepsiar",
    "assepsiásseis": "assepsiar",
    "assepsiássemos": "assepsiar",
    "assepsiávamo": "assepsiar",
    "assepsiávamos": "assepsiar",
    "assepsiávei": "assepsiar",
    "assepsiáveis": "assepsiar",
    "asseptóis": "asseptol",
    "asserios": "asserio",
    "asserta": "assertar",
    "assertada": "assertar",
    "assertadas": "assertar",
    "assertado": "assertar",
    "assertados": "assertar",
    "assertai": "assertar",
    "assertais": "assertar",
    "assertam": "assertar",
    "assertamo": "assertar",
    "assertamos": "assertar",
    "assertando": "assertar",
    "assertara": "assertar",
    "assertaram": "assertar",
    "assertaras": "assertar",
    "assertarde": "assertar",
    "assertardes": "assertar",
    "assertare": "assertar",
    "assertarei": "assertar",
    "assertareis": "assertar",
    "assertarem": "assertar",
    "assertaremos": "assertar",
    "assertares": "assertar",
    "assertaria": "assertar",
    "assertariam": "assertar",
    "assertarias": "assertar",
    "assertarmo": "assertar",
    "assertarmos": "assertar",
    "assertará": "assertar",
    "assertarás": "assertar",
    "assertarão": "assertar",
    "assertaríamos": "assertar",
    "assertaríeis": "assertar",
    "assertas": "assertar",
    "assertasse": "assertar",
    "assertassem": "assertar",
    "assertasses": "assertar",
    "assertaste": "assertar",
    "assertastes": "assertar",
    "assertava": "assertar",
    "assertavam": "assertar",
    "assertavas": "assertar",
    "asserte": "assertar",
    "assertei": "assertar",
    "asserteis": "assertar",
    "assertem": "assertar",
    "assertemo": "assertar",
    "assertemos": "assertar",
    "assertes": "assertar",
    "assertiva": "assertivo",
    "assertivas": "assertivo",
    "assertivos": "assertivo",
    "asserto": "assertar",
    "assertoada": "assertoado",
    "assertoadas": "assertoado",
    "assertoados": "assertoado",
    "assertora": "assertor",
    "assertoras": "assertor",
    "assertores": "assertor",
    "assertos": "asserto",
    "assertou": "assertar",
    "assertá": "assertar",
    "assertámo": "assertar",
    "assertámos": "assertar",
    "assertáramo": "assertar",
    "assertáramos": "assertar",
    "assertárei": "assertar",
    "assertáreis": "assertar",
    "assertásseis": "assertar",
    "assertássemos": "assertar",
    "assertávamo": "assertar",
    "assertávamos": "assertar",
    "assertávei": "assertar",
    "assertáveis": "assertar",
    "assertória": "assertório",
    "assertórias": "assertório",
    "assertórica": "assertórico",
    "assertóricas": "assertórico",
    "assertóricos": "assertórico",
    "assertórios": "assertório",
    "asserções": "asserção",
    "asses": "asse",
    "assessora": "assessorar",
    "assessorada": "assessorar",
    "assessoradas": "assessorar",
    "assessorado": "assessorar",
    "assessorados": "assessorar",
    "assessorai": "assessorar",
    "assessorais": "assessorar",
    "assessoram": "assessorar",
    "assessoramo": "assessorar",
    "assessoramos": "assessorar",
    "assessorando": "assessorar",
    "assessorara": "assessorar",
    "assessoraram": "assessorar",
    "assessoraras": "assessorar",
    "assessorarde": "assessorar",
    "assessorardes": "assessorar",
    "assessorare": "assessorar",
    "assessorarei": "assessorar",
    "assessorareis": "assessorar",
    "assessorarem": "assessorar",
    "assessoraremos": "assessorar",
    "assessorares": "assessorar",
    "assessoraria": "assessorar",
    "assessorariam": "assessorar",
    "assessorarias": "assessorar",
    "assessorarmo": "assessorar",
    "assessorarmos": "assessorar",
    "assessorará": "assessorar",
    "assessorarás": "assessorar",
    "assessorarão": "assessorar",
    "assessoraríamos": "assessorar",
    "assessoraríeis": "assessorar",
    "assessoras": "assessorar",
    "assessorasse": "assessorar",
    "assessorassem": "assessorar",
    "assessorasses": "assessorar",
    "assessoraste": "assessorar",
    "assessorastes": "assessorar",
    "assessorava": "assessorar",
    "assessoravam": "assessorar",
    "assessoravas": "assessorar",
    "assessore": "assessorar",
    "assessorei": "assessorar",
    "assessoreis": "assessorar",
    "assessorem": "assessorar",
    "assessoremo": "assessorar",
    "assessoremos": "assessorar",
    "assessores": "assessorar",
    "assessoriais": "assessorial",
    "assessorias": "assessoria",
    "assessoro": "assessorar",
    "assessorou": "assessorar",
    "assessorá": "assessorar",
    "assessorámo": "assessorar",
    "assessorámos": "assessorar",
    "assessoráramo": "assessorar",
    "assessoráramos": "assessorar",
    "assessorárei": "assessorar",
    "assessoráreis": "assessorar",
    "assessorásseis": "assessorar",
    "assessorássemos": "assessorar",
    "assessorávamo": "assessorar",
    "assessorávamos": "assessorar",
    "assessorávei": "assessorar",
    "assessoráveis": "assessorar",
    "assessória": "assessório",
    "assessórias": "assessório",
    "assessórios": "assessório",
    "assesta": "assestar",
    "assestada": "assestar",
    "assestadas": "assestar",
    "assestado": "assestar",
    "assestados": "assestar",
    "assestai": "assestar",
    "assestais": "assestar",
    "assestam": "assestar",
    "assestamo": "assestar",
    "assestamos": "assestar",
    "assestando": "assestar",
    "assestara": "assestar",
    "assestaram": "assestar",
    "assestaras": "assestar",
    "assestarde": "assestar",
    "assestardes": "assestar",
    "assestare": "assestar",
    "assestarei": "assestar",
    "assestareis": "assestar",
    "assestarem": "assestar",
    "assestaremos": "assestar",
    "assestares": "assestar",
    "assestaria": "assestar",
    "assestariam": "assestar",
    "assestarias": "assestar",
    "assestarmo": "assestar",
    "assestarmos": "assestar",
    "assestará": "assestar",
    "assestarás": "assestar",
    "assestarão": "assestar",
    "assestaríamos": "assestar",
    "assestaríeis": "assestar",
    "assestas": "assestar",
    "assestasse": "assestar",
    "assestassem": "assestar",
    "assestasses": "assestar",
    "assestaste": "assestar",
    "assestastes": "assestar",
    "assestava": "assestar",
    "assestavam": "assestar",
    "assestavas": "assestar",
    "asseste": "assestar",
    "assestei": "assestar",
    "assesteis": "assestar",
    "assestem": "assestar",
    "assestemo": "assestar",
    "assestemos": "assestar",
    "assestes": "assestar",
    "assesto": "assestar",
    "assestos": "assesto",
    "assestou": "assestar",
    "assestá": "assestar",
    "assestámo": "assestar",
    "assestámos": "assestar",
    "assestáramo": "assestar",
    "assestáramos": "assestar",
    "assestárei": "assestar",
    "assestáreis": "assestar",
    "assestásseis": "assestar",
    "assestássemos": "assestar",
    "assestávamo": "assestar",
    "assestávamos": "assestar",
    "assestávei": "assestar",
    "assestáveis": "assestar",
    "assetiadora": "assetiador",
    "assetiadoras": "assetiador",
    "assetiadores": "assetiador",
    "assevandijamentos": "assevandijamento",
    "assevera": "asseverar",
    "asseverada": "asseverar",
    "asseveradas": "asseverar",
    "asseverado": "asseverar",
    "asseveradora": "asseverador",
    "asseveradoras": "asseverador",
    "asseveradores": "asseverador",
    "asseverados": "asseverar",
    "asseverai": "asseverar",
    "asseverais": "asseverar",
    "asseveram": "asseverar",
    "asseveramo": "asseverar",
    "asseveramos": "asseverar",
    "asseverando": "asseverar",
    "asseverantes": "asseverante",
    "asseverara": "asseverar",
    "asseveraram": "asseverar",
    "asseveraras": "asseverar",
    "asseverarde": "asseverar",
    "asseverardes": "asseverar",
    "asseverare": "asseverar",
    "asseverarei": "asseverar",
    "asseverareis": "asseverar",
    "asseverarem": "asseverar",
    "asseveraremos": "asseverar",
    "asseverares": "asseverar",
    "asseveraria": "asseverar",
    "asseverariam": "asseverar",
    "asseverarias": "asseverar",
    "asseverarmo": "asseverar",
    "asseverarmos": "asseverar",
    "asseverará": "asseverar",
    "asseverarás": "asseverar",
    "asseverarão": "asseverar",
    "asseveraríamos": "asseverar",
    "asseveraríeis": "asseverar",
    "asseveras": "asseverar",
    "asseverasse": "asseverar",
    "asseverassem": "asseverar",
    "asseverasses": "asseverar",
    "asseveraste": "asseverar",
    "asseverastes": "asseverar",
    "asseverativa": "asseverativo",
    "asseverativas": "asseverativo",
    "asseverativos": "asseverativo",
    "asseverava": "asseverar",
    "asseveravam": "asseverar",
    "asseveravas": "asseverar",
    "asseverações": "asseveração",
    "assevere": "asseverar",
    "asseverei": "asseverar",
    "assevereis": "asseverar",
    "asseverem": "asseverar",
    "asseveremo": "asseverar",
    "asseveremos": "asseverar",
    "asseveres": "asseverar",
    "assevero": "asseverar",
    "asseverou": "asseverar",
    "asseverá": "asseverar",
    "asseverámo": "asseverar",
    "asseverámos": "asseverar",
    "asseveráramo": "asseverar",
    "asseveráramos": "asseverar",
    "asseverárei": "asseverar",
    "asseveráreis": "asseverar",
    "asseverásseis": "asseverar",
    "asseverássemos": "asseverar",
    "asseverávamo": "asseverar",
    "asseverávamos": "asseverar",
    "asseverávei": "asseverar",
    "asseveráveis": "asseverar",
    "assexa": "assexo",
    "assexas": "assexo",
    "assexos": "assexo",
    "assexuada": "assexuado",
    "assexuadas": "assexuado",
    "assexuados": "assexuado",
    "assexuais": "assexual",
    "assexualidades": "assexualidade",
    "asseá": "assear",
    "asseámo": "assear",
    "asseámos": "assear",
    "asseáramo": "assear",
    "asseáramos": "assear",
    "asseárei": "assear",
    "asseáreis": "assear",
    "asseásseis": "assear",
    "asseássemos": "assear",
    "asseávamo": "assear",
    "asseávamos": "assear",
    "asseávei": "assear",
    "asseáveis": "assear",
    "assialias": "assialia",
    "assibilações": "assibilação",
    "assiderações": "assideração",
    "assiduidades": "assiduidade",
    "assigmática": "assigmático",
    "assigmáticas": "assigmático",
    "assigmáticos": "assigmático",
    "assilabias": "assilabia",
    "assilábica": "assilábico",
    "assilábicas": "assilábico",
    "assilábicos": "assilábico",
    "assimbolias": "assimbolia",
    "assimetrias": "assimetria",
    "assimila": "assimilar",
    "assimilabilidades": "assimilabilidade",
    "assimilada": "assimilar",
    "assimiladas": "assimilar",
    "assimilado": "assimilar",
    "assimiladora": "assimilador",
    "assimiladoras": "assimilador",
    "assimiladores": "assimilador",
    "assimilados": "assimilar",
    "assimilai": "assimilar",
    "assimilais": "assimilar",
    "assimilam": "assimilar",
    "assimilamo": "assimilar",
    "assimilamos": "assimilar",
    "assimilando": "assimilar",
    "assimilara": "assimilar",
    "assimilaram": "assimilar",
    "assimilaras": "assimilar",
    "assimilarde": "assimilar",
    "assimilardes": "assimilar",
    "assimilare": "assimilar",
    "assimilarei": "assimilar",
    "assimilareis": "assimilar",
    "assimilarem": "assimilar",
    "assimilaremos": "assimilar",
    "assimilares": "assimilar",
    "assimilaria": "assimilar",
    "assimilariam": "assimilar",
    "assimilarias": "assimilar",
    "assimilarmo": "assimilar",
    "assimilarmos": "assimilar",
    "assimilará": "assimilar",
    "assimilarás": "assimilar",
    "assimilarão": "assimilar",
    "assimilaríamos": "assimilar",
    "assimilaríeis": "assimilar",
    "assimilas": "assimilar",
    "assimilasse": "assimilar",
    "assimilassem": "assimilar",
    "assimilasses": "assimilar",
    "assimilaste": "assimilar",
    "assimilastes": "assimilar",
    "assimilativa": "assimilativo",
    "assimilativas": "assimilativo",
    "assimilativos": "assimilativo",
    "assimilava": "assimilar",
    "assimilavam": "assimilar",
    "assimilavas": "assimilar",
    "assimilações": "assimilação",
    "assimile": "assimilar",
    "assimilei": "assimilar",
    "assimileis": "assimilar",
    "assimilem": "assimilar",
    "assimilemo": "assimilar",
    "assimilemos": "assimilar",
    "assimiles": "assimilar",
    "assimilo": "assimilar",
    "assimilou": "assimilar",
    "assimilá": "assimilar",
    "assimilámo": "assimilar",
    "assimilámos": "assimilar",
    "assimiláramo": "assimilar",
    "assimiláramos": "assimilar",
    "assimilárei": "assimilar",
    "assimiláreis": "assimilar",
    "assimilásseis": "assimilar",
    "assimilássemos": "assimilar",
    "assimilávamo": "assimilar",
    "assimilávamos": "assimilar",
    "assimilávei": "assimilar",
    "assimiláveis": "assimilável",
    "assimptótica": "assimptótico",
    "assimptóticas": "assimptótico",
    "assimptóticos": "assimptótico",
    "assimulações": "assimulação",
    "assimétrica": "assimétrico",
    "assimétricas": "assimétrico",
    "assimétricos": "assimétrico",
    "assina": "assinar",
    "assinada": "assinar",
    "assinadas": "assinar",
    "assinado": "assinar",
    "assinados": "assinar",
    "assinai": "assinar",
    "assinais": "assinar",
    "assinala": "assinalar",
    "assinalada": "assinalar",
    "assinaladas": "assinalar",
    "assinalado": "assinalar",
    "assinaladora": "assinalador",
    "assinaladoras": "assinalador",
    "assinaladores": "assinalador",
    "assinalados": "assinalar",
    "assinaladíssima": "assinalado",
    "assinaladíssimas": "assinalado",
    "assinaladíssimo": "assinalado",
    "assinaladíssimos": "assinalado",
    "assinalai": "assinalar",
    "assinalais": "assinalar",
    "assinalam": "assinalar",
    "assinalamentos": "assinalamento",
    "assinalamo": "assinalar",
    "assinalamos": "assinalar",
    "assinalando": "assinalar",
    "assinalantes": "assinalante",
    "assinalara": "assinalar",
    "assinalaram": "assinalar",
    "assinalaras": "assinalar",
    "assinalarde": "assinalar",
    "assinalardes": "assinalar",
    "assinalare": "assinalar",
    "assinalarei": "assinalar",
    "assinalareis": "assinalar",
    "assinalarem": "assinalar",
    "assinalaremos": "assinalar",
    "assinalares": "assinalar",
    "assinalaria": "assinalar",
    "assinalariam": "assinalar",
    "assinalarias": "assinalar",
    "assinalarmo": "assinalar",
    "assinalarmos": "assinalar",
    "assinalará": "assinalar",
    "assinalarás": "assinalar",
    "assinalarão": "assinalar",
    "assinalaríamos": "assinalar",
    "assinalaríeis": "assinalar",
    "assinalas": "assinalar",
    "assinalasse": "assinalar",
    "assinalassem": "assinalar",
    "assinalasses": "assinalar",
    "assinalaste": "assinalar",
    "assinalastes": "assinalar",
    "assinalava": "assinalar",
    "assinalavam": "assinalar",
    "assinalavas": "assinalar",
    "assinalações": "assinalação",
    "assinale": "assinalar",
    "assinalei": "assinalar",
    "assinaleis": "assinalar",
    "assinalem": "assinalar",
    "assinalemo": "assinalar",
    "assinalemos": "assinalar",
    "assinales": "assinalar",
    "assinalo": "assinalar",
    "assinalou": "assinalar",
    "assinalá": "assinalar",
    "assinalámo": "assinalar",
    "assinalámos": "assinalar",
    "assinaláramo": "assinalar",
    "assinaláramos": "assinalar",
    "assinalárei": "assinalar",
    "assinaláreis": "assinalar",
    "assinalásseis": "assinalar",
    "assinalássemos": "assinalar",
    "assinalávamo": "assinalar",
    "assinalávamos": "assinalar",
    "assinalávei": "assinalar",
    "assinaláveis": "assinalável",
    "assinam": "assinar",
    "assinamentos": "assinamento",
    "assinamo": "assinar",
    "assinamos": "assinar",
    "assinando": "assinar",
    "assinantes": "assinante",
    "assinapses": "assinapse",
    "assinara": "assinar",
    "assinaram": "assinar",
    "assinaras": "assinar",
    "assinarde": "assinar",
    "assinardes": "assinar",
    "assinare": "assinar",
    "assinarei": "assinar",
    "assinareis": "assinar",
    "assinarem": "assinar",
    "assinaremos": "assinar",
    "assinares": "assinar",
    "assinaria": "assinar",
    "assinariam": "assinar",
    "assinarias": "assinar",
    "assinarmo": "assinar",
    "assinarmos": "assinar",
    "assinará": "assinar",
    "assinarás": "assinar",
    "assinarão": "assinar",
    "assinaríamos": "assinar",
    "assinaríeis": "assinar",
    "assinas": "assinar",
    "assinasse": "assinar",
    "assinassem": "assinar",
    "assinasses": "assinar",
    "assinaste": "assinar",
    "assinastes": "assinar",
    "assinaturas": "assinatura",
    "assinava": "assinar",
    "assinavam": "assinar",
    "assinavas": "assinar",
    "assinações": "assinação",
    "assindética": "assindético",
    "assindéticas": "assindético",
    "assindéticos": "assindético",
    "assine": "assinar",
    "assinei": "assinar",
    "assineis": "assinar",
    "assinem": "assinar",
    "assinemo": "assinar",
    "assinemos": "assinar",
    "assinergias": "assinergia",
    "assines": "assinar",
    "assingelada": "assingelado",
    "assingeladas": "assingelado",
    "assingelados": "assingelado",
    "assino": "assinar",
    "assinou": "assinar",
    "assintomática": "assintomático",
    "assintomáticas": "assintomático",
    "assintomáticos": "assintomático",
    "assintáctica": "assintáctico",
    "assintácticas": "assintáctico",
    "assintácticos": "assintáctico",
    "assiná": "assinar",
    "assinámo": "assinar",
    "assinámos": "assinar",
    "assináramo": "assinar",
    "assináramos": "assinar",
    "assinárei": "assinar",
    "assináreis": "assinar",
    "assinásseis": "assinar",
    "assinássemos": "assinar",
    "assinávamo": "assinar",
    "assinávamos": "assinar",
    "assinávei": "assinar",
    "assináveis": "assinável",
    "assinérgica": "assinérgico",
    "assinérgicas": "assinérgico",
    "assinérgicos": "assinérgico",
    "assiriologias": "assiriologia",
    "assiriologistas": "assiriologista",
    "assiriológica": "assiriológico",
    "assiriológicas": "assiriológico",
    "assiriológicos": "assiriológico",
    "assirióloga": "assiriólogo",
    "assiriólogas": "assiriólogo",
    "assiriólogos": "assiriólogo",
    "assisada": "assisado",
    "assisadas": "assisado",
    "assisadinha": "assisado",
    "assisadinhas": "assisado",
    "assisadinho": "assisado",
    "assisadinhos": "assisado",
    "assisadita": "assisado",
    "assisaditas": "assisado",
    "assisadito": "assisado",
    "assisaditos": "assisado",
    "assisados": "assisado",
    "assisadíssima": "assisado",
    "assisadíssimas": "assisado",
    "assisadíssimo": "assisado",
    "assisadíssimos": "assisado",
    "assista": "assistir",
    "assistais": "assistir",
    "assistam": "assistir",
    "assistamo": "assistir",
    "assistamos": "assistir",
    "assistas": "assistir",
    "assiste": "assistir",
    "assistem": "assistir",
    "assistemática": "assistemático",
    "assistemáticas": "assistemático",
    "assistemáticos": "assistemático",
    "assistenciais": "assistencial",
    "assistentes": "assistente",
    "assistes": "assistir",
    "assisti": "assistir",
    "assistia": "assistir",
    "assistiam": "assistir",
    "assistias": "assistir",
    "assistida": "assistir",
    "assistidas": "assistir",
    "assistido": "assistir",
    "assistidos": "assistir",
    "assistimentos": "assistimento",
    "assistimo": "assistir",
    "assistimos": "assistir",
    "assistindo": "assistir",
    "assistira": "assistir",
    "assistiram": "assistir",
    "assistiras": "assistir",
    "assistirde": "assistir",
    "assistirdes": "assistir",
    "assistire": "assistir",
    "assistirei": "assistir",
    "assistireis": "assistir",
    "assistirem": "assistir",
    "assistiremos": "assistir",
    "assistires": "assistir",
    "assistiria": "assistir",
    "assistiriam": "assistir",
    "assistirias": "assistir",
    "assistirmo": "assistir",
    "assistirmos": "assistir",
    "assistirá": "assistir",
    "assistirás": "assistir",
    "assistirão": "assistir",
    "assistiríamos": "assistir",
    "assistiríeis": "assistir",
    "assistis": "assistir",
    "assistisse": "assistir",
    "assistissem": "assistir",
    "assistisses": "assistir",
    "assististe": "assistir",
    "assististes": "assistir",
    "assistiu": "assistir",
    "assisto": "assistir",
    "assistolias": "assistolia",
    "assistências": "assistência",
    "assistíamo": "assistir",
    "assistíamos": "assistir",
    "assistíei": "assistir",
    "assistíeis": "assistir",
    "assistíramo": "assistir",
    "assistíramos": "assistir",
    "assistírei": "assistir",
    "assistíreis": "assistir",
    "assistísseis": "assistir",
    "assistíssemos": "assistir",
    "asso": "assar",
    "assoa": "assoar",
    "assoada": "assoar",
    "assoadas": "assoar",
    "assoadelas": "assoadela",
    "assoadinha": "assoado",
    "assoadinhas": "assoado",
    "assoadinho": "assoado",
    "assoadinhos": "assoado",
    "assoadita": "assoado",
    "assoaditas": "assoado",
    "assoadito": "assoado",
    "assoaditos": "assoado",
    "assoado": "assoar",
    "assoados": "assoar",
    "assoai": "assoar",
    "assoais": "assoar",
    "assoalhada": "assoalhado",
    "assoalhadas": "assoalhado",
    "assoalhadora": "assoalhador",
    "assoalhadoras": "assoalhador",
    "assoalhadores": "assoalhador",
    "assoalhados": "assoalhado",
    "assoalhaduras": "assoalhadura",
    "assoalhamentos": "assoalhamento",
    "assoam": "assoar",
    "assoamo": "assoar",
    "assoamos": "assoar",
    "assoando": "assoar",
    "assoantes": "assoante",
    "assoara": "assoar",
    "assoaram": "assoar",
    "assoaras": "assoar",
    "assoarde": "assoar",
    "assoardes": "assoar",
    "assoare": "assoar",
    "assoarei": "assoar",
    "assoareis": "assoar",
    "assoarem": "assoar",
    "assoaremos": "assoar",
    "assoares": "assoar",
    "assoaria": "assoar",
    "assoariam": "assoar",
    "assoarias": "assoar",
    "assoarmo": "assoar",
    "assoarmos": "assoar",
    "assoará": "assoar",
    "assoarás": "assoar",
    "assoarão": "assoar",
    "assoaríamos": "assoar",
    "assoaríeis": "assoar",
    "assoas": "assoar",
    "assoasse": "assoar",
    "assoassem": "assoar",
    "assoasses": "assoar",
    "assoaste": "assoar",
    "assoastes": "assoar",
    "assoava": "assoar",
    "assoavam": "assoar",
    "assoavas": "assoar",
    "assoberba": "assoberbar",
    "assoberbada": "assoberbar",
    "assoberbadas": "assoberbar",
    "assoberbado": "assoberbar",
    "assoberbados": "assoberbar",
    "assoberbai": "assoberbar",
    "assoberbais": "assoberbar",
    "assoberbam": "assoberbar",
    "assoberbamentos": "assoberbamento",
    "assoberbamo": "assoberbar",
    "assoberbamos": "assoberbar",
    "assoberbando": "assoberbar",
    "assoberbantes": "assoberbante",
    "assoberbara": "assoberbar",
    "assoberbaram": "assoberbar",
    "assoberbaras": "assoberbar",
    "assoberbarde": "assoberbar",
    "assoberbardes": "assoberbar",
    "assoberbare": "assoberbar",
    "assoberbarei": "assoberbar",
    "assoberbareis": "assoberbar",
    "assoberbarem": "assoberbar",
    "assoberbaremos": "assoberbar",
    "assoberbares": "assoberbar",
    "assoberbaria": "assoberbar",
    "assoberbariam": "assoberbar",
    "assoberbarias": "assoberbar",
    "assoberbarmo": "assoberbar",
    "assoberbarmos": "assoberbar",
    "assoberbará": "assoberbar",
    "assoberbarás": "assoberbar",
    "assoberbarão": "assoberbar",
    "assoberbaríamos": "assoberbar",
    "assoberbaríeis": "assoberbar",
    "assoberbas": "assoberbar",
    "assoberbasse": "assoberbar",
    "assoberbassem": "assoberbar",
    "assoberbasses": "assoberbar",
    "assoberbaste": "assoberbar",
    "assoberbastes": "assoberbar",
    "assoberbava": "assoberbar",
    "assoberbavam": "assoberbar",
    "assoberbavas": "assoberbar",
    "assoberbe": "assoberbar",
    "assoberbei": "assoberbar",
    "assoberbeis": "assoberbar",
    "assoberbem": "assoberbar",
    "assoberbemo": "assoberbar",
    "assoberbemos": "assoberbar",
    "assoberbes": "assoberbar",
    "assoberbo": "assoberbar",
    "assoberbou": "assoberbar",
    "assoberbá": "assoberbar",
    "assoberbámo": "assoberbar",
    "assoberbámos": "assoberbar",
    "assoberbáramo": "assoberbar",
    "assoberbáramos": "assoberbar",
    "assoberbárei": "assoberbar",
    "assoberbáreis": "assoberbar",
    "assoberbásseis": "assoberbar",
    "assoberbássemos": "assoberbar",
    "assoberbávamo": "assoberbar",
    "assoberbávamos": "assoberbar",
    "assoberbávei": "assoberbar",
    "assoberbáveis": "assoberbar",
    "assobia": "assobiar",
    "assobiada": "assobiar",
    "assobiadas": "assobiar",
    "assobiadeira": "assobiador",
    "assobiadeiras": "assobiador",
    "assobiadeiros": "assobiadeiro",
    "assobiadelas": "assobiadela",
    "assobiado": "assobiar",
    "assobiadora": "assobiador",
    "assobiadoras": "assobiador",
    "assobiadores": "assobiador",
    "assobiados": "assobiar",
    "assobiai": "assobiar",
    "assobiais": "assobiar",
    "assobiam": "assobiar",
    "assobiamo": "assobiar",
    "assobiamos": "assobiar",
    "assobiando": "assobiar",
    "assobiantes": "assobiante",
    "assobiara": "assobiar",
    "assobiaram": "assobiar",
    "assobiaras": "assobiar",
    "assobiardes": "assobiar",
    "assobiarei": "assobiar",
    "assobiareis": "assobiar",
    "assobiarem": "assobiar",
    "assobiaremos": "assobiar",
    "assobiares": "assobiar",
    "assobiaria": "assobiar",
    "assobiariam": "assobiar",
    "assobiarias": "assobiar",
    "assobiarmo": "assobiar",
    "assobiarmos": "assobiar",
    "assobiará": "assobiar",
    "assobiarás": "assobiar",
    "assobiarão": "assobiar",
    "assobiaríamos": "assobiar",
    "assobiaríeis": "assobiar",
    "assobias": "assobiar",
    "assobiasse": "assobiar",
    "assobiassem": "assobiar",
    "assobiasses": "assobiar",
    "assobiaste": "assobiar",
    "assobiastes": "assobiar",
    "assobiava": "assobiar",
    "assobiavam": "assobiar",
    "assobiavas": "assobiar",
    "assobie": "assobiar",
    "assobiei": "assobiar",
    "assobieis": "assobiar",
    "assobiem": "assobiar",
    "assobiemo": "assobiar",
    "assobiemos": "assobiar",
    "assobies": "assobiar",
    "assobio": "assobiar",
    "assobios": "assobio",
    "assobiou": "assobiar",
    "assobiámo": "assobiar",
    "assobiámos": "assobiar",
    "assobiáramo": "assobiar",
    "assobiáramos": "assobiar",
    "assobiáreis": "assobiar",
    "assobiásseis": "assobiar",
    "assobiássemos": "assobiar",
    "assobiávamo": "assobiar",
    "assobiávamos": "assobiar",
    "assobiáveis": "assobiar",
    "associa": "associar",
    "associabilidades": "associabilidade",
    "associacionismos": "associacionismo",
    "associada": "associar",
    "associadas": "associar",
    "associado": "associar",
    "associados": "associar",
    "associai": "associar",
    "associais": "associar",
    "assocializações": "associalização",
    "associam": "associar",
    "associamo": "associar",
    "associamos": "associar",
    "associando": "associar",
    "associara": "associar",
    "associaram": "associar",
    "associaras": "associar",
    "associarde": "associar",
    "associardes": "associar",
    "associare": "associar",
    "associarei": "associar",
    "associareis": "associar",
    "associarem": "associar",
    "associaremos": "associar",
    "associares": "associar",
    "associaria": "associar",
    "associariam": "associar",
    "associarias": "associar",
    "associarmo": "associar",
    "associarmos": "associar",
    "associará": "associar",
    "associarás": "associar",
    "associarão": "associar",
    "associaríamos": "associar",
    "associaríeis": "associar",
    "associas": "associar",
    "associasse": "associar",
    "associassem": "associar",
    "associasses": "associar",
    "associaste": "associar",
    "associastes": "associar",
    "associativa": "associativo",
    "associativas": "associativo",
    "associatividades": "associatividade",
    "associativismos": "associativismo",
    "associativos": "associativo",
    "associava": "associar",
    "associavam": "associar",
    "associavas": "associar",
    "associações": "associação",
    "associe": "associar",
    "associei": "associar",
    "associeis": "associar",
    "associem": "associar",
    "associemo": "associar",
    "associemos": "associar",
    "associes": "associar",
    "associo": "associar",
    "associonismos": "associonismo",
    "associou": "associar",
    "associá": "associar",
    "associámo": "associar",
    "associámos": "associar",
    "associáramo": "associar",
    "associáramos": "associar",
    "associárei": "associar",
    "associáreis": "associar",
    "associásseis": "associar",
    "associássemos": "associar",
    "associávamo": "associar",
    "associávamos": "associar",
    "associávei": "associar",
    "associáveis": "associar",
    "assoe": "assoar",
    "assoei": "assoar",
    "assoeis": "assoar",
    "assoem": "assoar",
    "assoemo": "assoar",
    "assoemos": "assoar",
    "assoes": "assoar",
    "assola": "assolar",
    "assolada": "assolar",
    "assoladas": "assolar",
    "assolado": "assolar",
    "assoladora": "assolador",
    "assoladoras": "assolador",
    "assoladores": "assolador",
    "assolados": "assolar",
    "assoladíssima": "assolado",
    "assoladíssimas": "assolado",
    "assoladíssimo": "assolado",
    "assoladíssimos": "assolado",
    "assolai": "assolar",
    "assolais": "assolar",
    "assolam": "assolar",
    "assolamentos": "assolamento",
    "assolamo": "assolar",
    "assolamos": "assolar",
    "assolando": "assolar",
    "assolapada": "assolapado",
    "assolapadas": "assolapado",
    "assolapados": "assolapado",
    "assolara": "assolar",
    "assolaram": "assolar",
    "assolaras": "assolar",
    "assolarde": "assolar",
    "assolardes": "assolar",
    "assolare": "assolar",
    "assolarei": "assolar",
    "assolareis": "assolar",
    "assolarem": "assolar",
    "assolaremos": "assolar",
    "assolares": "assolar",
    "assolaria": "assolar",
    "assolariam": "assolar",
    "assolarias": "assolar",
    "assolarmo": "assolar",
    "assolarmos": "assolar",
    "assolará": "assolar",
    "assolarás": "assolar",
    "assolarão": "assolar",
    "assolaríamos": "assolar",
    "assolaríeis": "assolar",
    "assolas": "assolar",
    "assolasse": "assolar",
    "assolassem": "assolar",
    "assolasses": "assolar",
    "assolaste": "assolar",
    "assolastes": "assolar",
    "assolava": "assolar",
    "assolavam": "assolar",
    "assolavas": "assolar",
    "assolações": "assolação",
    "assoldada": "assoldado",
    "assoldadada": "assoldadado",
    "assoldadadas": "assoldadado",
    "assoldadados": "assoldadado",
    "assoldadas": "assoldado",
    "assoldados": "assoldado",
    "assole": "assolar",
    "assolei": "assolar",
    "assoleis": "assolar",
    "assolem": "assolar",
    "assolemo": "assolar",
    "assolemos": "assolar",
    "assoles": "assolar",
    "assoliamentos": "assoliamento",
    "assolo": "assolar",
    "assolou": "assolar",
    "assolá": "assolar",
    "assolámo": "assolar",
    "assolámos": "assolar",
    "assoláramo": "assolar",
    "assoláramos": "assolar",
    "assolárei": "assolar",
    "assoláreis": "assolar",
    "assolásseis": "assolar",
    "assolássemos": "assolar",
    "assolávamo": "assolar",
    "assolávamos": "assolar",
    "assolávei": "assolar",
    "assoláveis": "assolar",
    "assoma": "assomar",
    "assomada": "assomar",
    "assomadas": "assomar",
    "assomadiça": "assomadiço",
    "assomadiças": "assomadiço",
    "assomadiços": "assomadiço",
    "assomado": "assomar",
    "assomadoiros": "assomadoiro",
    "assomados": "assomar",
    "assomadouros": "assomadouro",
    "assomai": "assomar",
    "assomais": "assomar",
    "assomam": "assomar",
    "assomamo": "assomar",
    "assomamos": "assomar",
    "assomando": "assomar",
    "assomara": "assomar",
    "assomaram": "assomar",
    "assomaras": "assomar",
    "assomardes": "assomar",
    "assomarei": "assomar",
    "assomareis": "assomar",
    "assomarem": "assomar",
    "assomaremos": "assomar",
    "assomares": "assomar",
    "assomaria": "assomar",
    "assomariam": "assomar",
    "assomarias": "assomar",
    "assomarmo": "assomar",
    "assomarmos": "assomar",
    "assomará": "assomar",
    "assomarás": "assomar",
    "assomarão": "assomar",
    "assomaríamos": "assomar",
    "assomaríeis": "assomar",
    "assomas": "assomar",
    "assomasse": "assomar",
    "assomassem": "assomar",
    "assomasses": "assomar",
    "assomaste": "assomar",
    "assomastes": "assomar",
    "assomava": "assomar",
    "assomavam": "assomar",
    "assomavas": "assomar",
    "assombra": "assombrar",
    "assombrada": "assombrar",
    "assombradas": "assombrar",
    "assombradiça": "assombradiço",
    "assombradiças": "assombradiço",
    "assombradiços": "assombradiço",
    "assombrado": "assombrar",
    "assombrados": "assombrar",
    "assombrai": "assombrar",
    "assombrais": "assombrar",
    "assombram": "assombrar",
    "assombramentos": "assombramento",
    "assombramo": "assombrar",
    "assombramos": "assombrar",
    "assombrando": "assombrar",
    "assombrara": "assombrar",
    "assombraram": "assombrar",
    "assombraras": "assombrar",
    "assombrarde": "assombrar",
    "assombrardes": "assombrar",
    "assombrare": "assombrar",
    "assombrarei": "assombrar",
    "assombrareis": "assombrar",
    "assombrarem": "assombrar",
    "assombraremos": "assombrar",
    "assombrares": "assombrar",
    "assombraria": "assombrar",
    "assombrariam": "assombrar",
    "assombrarias": "assombrar",
    "assombrarmo": "assombrar",
    "assombrarmos": "assombrar",
    "assombrará": "assombrar",
    "assombrarás": "assombrar",
    "assombrarão": "assombrar",
    "assombraríamos": "assombrar",
    "assombraríeis": "assombrar",
    "assombras": "assombrar",
    "assombrasse": "assombrar",
    "assombrassem": "assombrar",
    "assombrasses": "assombrar",
    "assombraste": "assombrar",
    "assombrastes": "assombrar",
    "assombrava": "assombrar",
    "assombravam": "assombrar",
    "assombravas": "assombrar",
    "assombrações": "assombração",
    "assombre": "assombrar",
    "assombreada": "assombrear",
    "assombreadas": "assombrear",
    "assombreado": "assombrear",
    "assombreados": "assombrear",
    "assombreai": "assombrear",
    "assombreais": "assombrear",
    "assombreamentos": "assombreamento",
    "assombreamo": "assombrear",
    "assombreamos": "assombrear",
    "assombreando": "assombrear",
    "assombreara": "assombrear",
    "assombrearam": "assombrear",
    "assombrearas": "assombrear",
    "assombrearde": "assombrear",
    "assombreardes": "assombrear",
    "assombreare": "assombrear",
    "assombrearei": "assombrear",
    "assombreareis": "assombrear",
    "assombrearem": "assombrear",
    "assombrearemos": "assombrear",
    "assombreares": "assombrear",
    "assombrearia": "assombrear",
    "assombreariam": "assombrear",
    "assombrearias": "assombrear",
    "assombrearmo": "assombrear",
    "assombrearmos": "assombrear",
    "assombreará": "assombrear",
    "assombrearás": "assombrear",
    "assombrearão": "assombrear",
    "assombrearíamos": "assombrear",
    "assombrearíeis": "assombrear",
    "assombreasse": "assombrear",
    "assombreassem": "assombrear",
    "assombreasses": "assombrear",
    "assombreaste": "assombrear",
    "assombreastes": "assombrear",
    "assombreava": "assombrear",
    "assombreavam": "assombrear",
    "assombreavas": "assombrear",
    "assombreei": "assombrear",
    "assombreeis": "assombrear",
    "assombreemo": "assombrear",
    "assombreemos": "assombrear",
    "assombrei": "assombrar",
    "assombreia": "assombrear",
    "assombreiam": "assombrear",
    "assombreias": "assombrear",
    "assombreie": "assombrear",
    "assombreiem": "assombrear",
    "assombreies": "assombrear",
    "assombreio": "assombrear",
    "assombreis": "assombrar",
    "assombrem": "assombrar",
    "assombremo": "assombrar",
    "assombremos": "assombrar",
    "assombreou": "assombrear",
    "assombres": "assombrar",
    "assombreá": "assombrear",
    "assombreámo": "assombrear",
    "assombreámos": "assombrear",
    "assombreáramo": "assombrear",
    "assombreáramos": "assombrear",
    "assombreárei": "assombrear",
    "assombreáreis": "assombrear",
    "assombreásseis": "assombrear",
    "assombreássemos": "assombrear",
    "assombreávamo": "assombrear",
    "assombreávamos": "assombrear",
    "assombreávei": "assombrear",
    "assombreáveis": "assombrear",
    "assombro": "assombrar",
    "assombros": "assombro",
    "assombrosa": "assombroso",
    "assombrosas": "assombroso",
    "assombrosos": "assombroso",
    "assombrou": "assombrar",
    "assombrá": "assombrar",
    "assombrámo": "assombrar",
    "assombrámos": "assombrar",
    "assombráramo": "assombrar",
    "assombráramos": "assombrar",
    "assombrárei": "assombrar",
    "assombráreis": "assombrar",
    "assombrásseis": "assombrar",
    "assombrássemos": "assombrar",
    "assombrávamo": "assombrar",
    "assombrávamos": "assombrar",
    "assombrávei": "assombrar",
    "assombráveis": "assombrar",
    "assome": "assomar",
    "assomei": "assomar",
    "assomeis": "assomar",
    "assomem": "assomar",
    "assomemo": "assomar",
    "assomemos": "assomar",
    "assomes": "assomar",
    "assomo": "assomar",
    "assomos": "assomo",
    "assomou": "assomar",
    "assomámo": "assomar",
    "assomámos": "assomar",
    "assomáramo": "assomar",
    "assomáramos": "assomar",
    "assomáreis": "assomar",
    "assomásseis": "assomar",
    "assomássemos": "assomar",
    "assomávamo": "assomar",
    "assomávamos": "assomar",
    "assomáveis": "assomar",
    "assonantes": "assonante",
    "assonorentada": "assonorentado",
    "assonorentadas": "assonorentado",
    "assonorentados": "assonorentado",
    "assonâncias": "assonância",
    "assoo": "assoar",
    "assoou": "assoar",
    "assopeada": "assopeado",
    "assopeadas": "assopeado",
    "assopeados": "assopeado",
    "assopra": "assoprar",
    "assoprada": "assoprar",
    "assopradas": "assoprar",
    "assopradelas": "assopradela",
    "assoprado": "assoprar",
    "assopradora": "assoprador",
    "assopradoras": "assoprador",
    "assopradores": "assoprador",
    "assoprados": "assoprar",
    "assopraduras": "assopradura",
    "assoprai": "assoprar",
    "assoprais": "assoprar",
    "assopram": "assoprar",
    "assopramentos": "assopramento",
    "assopramo": "assoprar",
    "assopramos": "assoprar",
    "assoprando": "assoprar",
    "assoprara": "assoprar",
    "assopraram": "assoprar",
    "assopraras": "assoprar",
    "assoprarde": "assoprar",
    "assoprardes": "assoprar",
    "assoprare": "assoprar",
    "assoprarei": "assoprar",
    "assoprareis": "assoprar",
    "assoprarem": "assoprar",
    "assopraremos": "assoprar",
    "assoprares": "assoprar",
    "assopraria": "assoprar",
    "assoprariam": "assoprar",
    "assoprarias": "assoprar",
    "assoprarmo": "assoprar",
    "assoprarmos": "assoprar",
    "assoprará": "assoprar",
    "assoprarás": "assoprar",
    "assoprarão": "assoprar",
    "assopraríamos": "assoprar",
    "assopraríeis": "assoprar",
    "assopras": "assoprar",
    "assoprasse": "assoprar",
    "assoprassem": "assoprar",
    "assoprasses": "assoprar",
    "assopraste": "assoprar",
    "assoprastes": "assoprar",
    "assoprava": "assoprar",
    "assopravam": "assoprar",
    "assopravas": "assoprar",
    "assopre": "assoprar",
    "assoprei": "assoprar",
    "assopreis": "assoprar",
    "assoprem": "assoprar",
    "assopremo": "assoprar",
    "assopremos": "assoprar",
    "assopres": "assoprar",
    "assopro": "assoprar",
    "assopros": "assopro",
    "assoprou": "assoprar",
    "assoprá": "assoprar",
    "assoprámo": "assoprar",
    "assoprámos": "assoprar",
    "assopráramo": "assoprar",
    "assopráramos": "assoprar",
    "assoprárei": "assoprar",
    "assopráreis": "assoprar",
    "assoprásseis": "assoprar",
    "assoprássemos": "assoprar",
    "assoprávamo": "assoprar",
    "assoprávamos": "assoprar",
    "assoprávei": "assoprar",
    "assopráveis": "assoprar",
    "assoreamentos": "assoreamento",
    "assossegada": "assossegado",
    "assossegadas": "assossegado",
    "assossegados": "assossegado",
    "assotada": "assotado",
    "assotadas": "assotado",
    "assotados": "assotado",
    "assou": "assar",
    "assovelada": "assovelado",
    "assoveladas": "assovelado",
    "assovelados": "assovelado",
    "assovelamentos": "assovelamento",
    "assovinada": "assovinado",
    "assovinadas": "assovinado",
    "assovinados": "assovinado",
    "assoá": "assoar",
    "assoámo": "assoar",
    "assoámos": "assoar",
    "assoáramo": "assoar",
    "assoáramos": "assoar",
    "assoárei": "assoar",
    "assoáreis": "assoar",
    "assoásseis": "assoar",
    "assoássemos": "assoar",
    "assoávamo": "assoar",
    "assoávamos": "assoar",
    "assoávei": "assoar",
    "assoáveis": "assoar",
    "assuadas": "assuada",
    "assucadoiros": "assucadoiro",
    "assucadora": "assucador",
    "assucadoras": "assucador",
    "assucadores": "assucador",
    "assuma": "assumir",
    "assumais": "assumir",
    "assumam": "assumir",
    "assumamo": "assumir",
    "assumamos": "assumir",
    "assumas": "assumir",
    "assume": "assumir",
    "assumem": "assumir",
    "assumes": "assumir",
    "assumi": "assumir",
    "assumia": "assumir",
    "assumiam": "assumir",
    "assumias": "assumir",
    "assumida": "assumir",
    "assumidas": "assumir",
    "assumido": "assumir",
    "assumidos": "assumir",
    "assumimo": "assumir",
    "assumimos": "assumir",
    "assumindo": "assumir",
    "assumira": "assumir",
    "assumiram": "assumir",
    "assumiras": "assumir",
    "assumirde": "assumir",
    "assumirdes": "assumir",
    "assumire": "assumir",
    "assumirei": "assumir",
    "assumireis": "assumir",
    "assumirem": "assumir",
    "assumiremos": "assumir",
    "assumires": "assumir",
    "assumiria": "assumir",
    "assumiriam": "assumir",
    "assumirias": "assumir",
    "assumirmo": "assumir",
    "assumirmos": "assumir",
    "assumirá": "assumir",
    "assumirás": "assumir",
    "assumirão": "assumir",
    "assumiríamos": "assumir",
    "assumiríeis": "assumir",
    "assumis": "assumir",
    "assumisse": "assumir",
    "assumissem": "assumir",
    "assumisses": "assumir",
    "assumiste": "assumir",
    "assumistes": "assumir",
    "assumiu": "assumir",
    "assumo": "assumir",
    "assumpta": "assumpto",
    "assumptas": "assumpto",
    "assumptiva": "assumptivo",
    "assumptivas": "assumptivo",
    "assumptivos": "assumptivo",
    "assumptos": "assumpto",
    "assumptíveis": "assumptível",
    "assumpções": "assumpção",
    "assumíamo": "assumir",
    "assumíamos": "assumir",
    "assumíei": "assumir",
    "assumíeis": "assumir",
    "assumíramo": "assumir",
    "assumíramos": "assumir",
    "assumírei": "assumir",
    "assumíreis": "assumir",
    "assumísseis": "assumir",
    "assumíssemos": "assumir",
    "assumíveis": "assumível",
    "assuntos": "assunto",
    "assunções": "assunção",
    "assurgentes": "assurgente",
    "assusta": "assustar",
    "assustada": "assustar",
    "assustadas": "assustar",
    "assustadiça": "assustadiço",
    "assustadiças": "assustadiço",
    "assustadiços": "assustadiço",
    "assustado": "assustar",
    "assustadora": "assustador",
    "assustadoras": "assustador",
    "assustadores": "assustador",
    "assustados": "assustar",
    "assustadíssima": "assustado",
    "assustadíssimas": "assustado",
    "assustadíssimo": "assustado",
    "assustadíssimos": "assustado",
    "assustai": "assustar",
    "assustais": "assustar",
    "assustam": "assustar",
    "assustamo": "assustar",
    "assustamos": "assustar",
    "assustando": "assustar",
    "assustara": "assustar",
    "assustaram": "assustar",
    "assustaras": "assustar",
    "assustarde": "assustar",
    "assustardes": "assustar",
    "assustare": "assustar",
    "assustarei": "assustar",
    "assustareis": "assustar",
    "assustarem": "assustar",
    "assustaremos": "assustar",
    "assustares": "assustar",
    "assustaria": "assustar",
    "assustariam": "assustar",
    "assustarias": "assustar",
    "assustarmo": "assustar",
    "assustarmos": "assustar",
    "assustará": "assustar",
    "assustarás": "assustar",
    "assustarão": "assustar",
    "assustaríamos": "assustar",
    "assustaríeis": "assustar",
    "assustas": "assustar",
    "assustasse": "assustar",
    "assustassem": "assustar",
    "assustasses": "assustar",
    "assustaste": "assustar",
    "assustastes": "assustar",
    "assustava": "assustar",
    "assustavam": "assustar",
    "assustavas": "assustar",
    "assuste": "assustar",
    "assustei": "assustar",
    "assusteis": "assustar",
    "assustem": "assustar",
    "assustemo": "assustar",
    "assustemos": "assustar",
    "assustes": "assustar",
    "assusto": "assustar",
    "assustosa": "assustoso",
    "assustosas": "assustoso",
    "assustosos": "assustoso",
    "assustou": "assustar",
    "assustá": "assustar",
    "assustámo": "assustar",
    "assustámos": "assustar",
    "assustáramo": "assustar",
    "assustáramos": "assustar",
    "assustárei": "assustar",
    "assustáreis": "assustar",
    "assustásseis": "assustar",
    "assustássemos": "assustar",
    "assustávamo": "assustar",
    "assustávamos": "assustar",
    "assustávei": "assustar",
    "assustáveis": "assustável",
    "assutada": "assutado",
    "assutadas": "assutado",
    "assutados": "assutado",
    "assá": "assar",
    "assámo": "assar",
    "assámos": "assar",
    "assáramo": "assar",
    "assáramos": "assar",
    "assárei": "assar",
    "assáreis": "assar",
    "assásseis": "assar",
    "assássemos": "assar",
    "assávamo": "assar",
    "assávamos": "assar",
    "assávei": "assar",
    "assáveis": "assar",
    "assédios": "assédio",
    "assémia": "assémio",
    "assémias": "assémio",
    "assémica": "assémico",
    "assémicas": "assémico",
    "assémicos": "assémico",
    "assémios": "assémio",
    "assépala": "assépalo",
    "assépalas": "assépalo",
    "assépalos": "assépalo",
    "asséptica": "asséptico",
    "assépticas": "asséptico",
    "assépticos": "asséptico",
    "assídua": "assíduo",
    "assíduas": "assíduo",
    "assíduos": "assíduo",
    "assímptota": "assímptoto",
    "assímptotas": "assímptoto",
    "assímptotos": "assímptoto",
    "assíncrona": "assíncrono",
    "assíncronas": "assíncrono",
    "assíncronos": "assíncrono",
    "assíndetons": "assíndeton",
    "assíndetos": "assíndeto",
    "assíria": "assírio",
    "assírias": "assírio",
    "assírios": "assírio",
    "assísmica": "assísmico",
    "assísmicas": "assísmico",
    "assísmicos": "assísmico",
    "astacídea": "astacídeo",
    "astacídeas": "astacídeo",
    "astacídeos": "astacídeo",
    "astasias": "astasia",
    "astaticidades": "astaticidade",
    "astatos": "astato",
    "astecas": "asteca",
    "astelas": "astela",
    "astenias": "astenia",
    "astenofonias": "astenofonia",
    "astenofónica": "astenofónico",
    "astenofónicas": "astenofónico",
    "astenofónicos": "astenofónico",
    "astenopias": "astenopia",
    "astenópica": "astenópico",
    "astenópicas": "astenópico",
    "astenópicos": "astenópico",
    "astereognossias": "astereognossia",
    "asteriformes": "asteriforme",
    "asteriscos": "asterisco",
    "asterismos": "asterismo",
    "asteriídea": "asteriídeo",
    "asteriídeas": "asteriídeo",
    "asteriídeos": "asteriídeo",
    "asternais": "asternal",
    "asterácea": "asteráceo",
    "asteráceas": "asteráceo",
    "asteráceos": "asteráceo",
    "asterífera": "asterífero",
    "asteríferas": "asterífero",
    "asteríferos": "asterífero",
    "asterígera": "asterígero",
    "asterígeras": "asterígero",
    "asterígeros": "asterígero",
    "asteríidas": "asteríida",
    "asteríoda": "asteríodo",
    "asteríodas": "asteríodo",
    "asteríodos": "asteríodo",
    "asteróides": "asteróide",
    "asteróis": "asterol",
    "asteísmos": "asteísmo",
    "astigmatismos": "astigmatismo",
    "astigmática": "astigmático",
    "astigmáticas": "astigmático",
    "astigmáticos": "astigmático",
    "astigmómetros": "astigmómetro",
    "astilhas": "astilha",
    "astinomias": "astinomia",
    "astomias": "astomia",
    "astomática": "astomático",
    "astomáticas": "astomático",
    "astomáticos": "astomático",
    "astracãs": "astracã",
    "astragaliana": "astragaliano",
    "astragalianas": "astragaliano",
    "astragalianos": "astragaliano",
    "astragalomancias": "astragalomancia",
    "astragalomantes": "astragalomante",
    "astragalomântica": "astragalomântico",
    "astragalomânticas": "astragalomântico",
    "astragalomânticos": "astragalomântico",
    "astragalóides": "astragalóide",
    "astragálias": "astragália",
    "astragálica": "astragálico",
    "astragálicas": "astragálico",
    "astragálicos": "astragálico",
    "astrais": "astral",
    "astralidades": "astralidade",
    "astralizações": "astralização",
    "astralões": "astralão",
    "astranças": "astrança",
    "astriónicas": "astriónica",
    "astrobiologias": "astrobiologia",
    "astrobiológica": "astrobiológico",
    "astrobiológicas": "astrobiológico",
    "astrobiológicos": "astrobiológico",
    "astrobióloga": "astrobiólogo",
    "astrobiólogas": "astrobiólogo",
    "astrobiólogos": "astrobiólogo",
    "astrobolismos": "astrobolismo",
    "astrocentros": "astrocentro",
    "astrocárpia": "astrocárpio",
    "astrocárpias": "astrocárpio",
    "astrocárpios": "astrocárpio",
    "astrodinâmica": "astrodinâmico",
    "astrodinâmicas": "astrodinâmico",
    "astrodinâmicos": "astrodinâmico",
    "astrofobias": "astrofobia",
    "astrofotografias": "astrofotografia",
    "astrofotometrias": "astrofotometria",
    "astrofotométrica": "astrofotométrico",
    "astrofotométricas": "astrofotométrico",
    "astrofotométricos": "astrofotométrico",
    "astrofotómetros": "astrofotómetro",
    "astrofísica": "astrofísico",
    "astrofísicas": "astrofísico",
    "astrofísicos": "astrofísico",
    "astrogenias": "astrogenia",
    "astrognoses": "astrognose",
    "astrognosias": "astrognosia",
    "astrognosiológica": "astrognosiológico",
    "astrognosiológicas": "astrognosiológico",
    "astrognosiológicos": "astrognosiológico",
    "astrognósica": "astrognósico",
    "astrognósicas": "astrognósico",
    "astrognósicos": "astrognósico",
    "astrografias": "astrografia",
    "astrográfica": "astrográfico",
    "astrográficas": "astrográfico",
    "astrográficos": "astrográfico",
    "astrolatrias": "astrolatria",
    "astrologias": "astrologia",
    "astrolábios": "astrolábio",
    "astrológica": "astrológico",
    "astrológicas": "astrológico",
    "astrológicos": "astrológico",
    "astromancias": "astromancia",
    "astromantes": "astromante",
    "astrometrias": "astrometria",
    "astromântica": "astromântico",
    "astromânticas": "astromântico",
    "astromânticos": "astromântico",
    "astrométrica": "astrométrico",
    "astrométricas": "astrométrico",
    "astrométricos": "astrométrico",
    "astronautas": "astronauta",
    "astronavegações": "astronavegação",
    "astronaves": "astronave",
    "astronomias": "astronomia",
    "astronáutica": "astronáutico",
    "astronáuticas": "astronáutico",
    "astronáuticos": "astronáutico",
    "astronímias": "astronímia",
    "astronímica": "astronímico",
    "astronímicas": "astronímico",
    "astronímicos": "astronímico",
    "astronómica": "astronómico",
    "astronómicas": "astronómico",
    "astronómicos": "astronómico",
    "astroquímica": "astroquímico",
    "astroquímicas": "astroquímico",
    "astroquímicos": "astroquímico",
    "astros": "astro",
    "astroscopias": "astroscopia",
    "astroscópica": "astroscópico",
    "astroscópicas": "astroscópico",
    "astroscópicos": "astroscópico",
    "astroscópios": "astroscópio",
    "astrosferas": "astrosfera",
    "astrosférica": "astrosférico",
    "astrosféricas": "astrosférico",
    "astrosféricos": "astrosférico",
    "astrágalos": "astrágalo",
    "astrâncias": "astrância",
    "astrófoba": "astrófobo",
    "astrófobas": "astrófobo",
    "astrófobos": "astrófobo",
    "astrógrafos": "astrógrafo",
    "astróides": "astróide",
    "astrólatras": "astrólatra",
    "astróloga": "astrólogo",
    "astrólogas": "astrólogo",
    "astrólogos": "astrólogo",
    "astrómetros": "astrómetro",
    "astrónimos": "astrónimo",
    "astrónoma": "astrónomo",
    "astrónomas": "astrónomo",
    "astrónomos": "astrónomo",
    "astuciosa": "astucioso",
    "astuciosas": "astucioso",
    "astuciosos": "astucioso",
    "asturiana": "asturiano",
    "asturianas": "asturiano",
    "asturianos": "asturiano",
    "astuta": "astuto",
    "astutas": "astuto",
    "astutos": "astuto",
    "astutíssima": "astuto",
    "astutíssimas": "astuto",
    "astutíssimo": "astuto",
    "astutíssimos": "astuto",
    "astácida": "astácido",
    "astácidas": "astácido",
    "astácidos": "astácido",
    "astática": "astático",
    "astáticas": "astático",
    "astáticos": "astático",
    "astélicas": "astélica",
    "asténica": "asténico",
    "asténicas": "asténico",
    "asténicos": "asténico",
    "astérias": "astéria",
    "astérios": "astério",
    "astínomos": "astínomo",
    "astómata": "astómato",
    "astómatas": "astómato",
    "astómatos": "astómato",
    "astúcias": "astúcia",
    "asufias": "asufia",
    "asá": "asar",
    "asámo": "asar",
    "asámos": "asar",
    "asáramo": "asar",
    "asáramos": "asar",
    "asárei": "asar",
    "asáreis": "asar",
    "asásseis": "asar",
    "asássemos": "asar",
    "asáticas": "asática",
    "asávamo": "asar",
    "asávamos": "asar",
    "asávei": "asar",
    "asáveis": "asar",
    "asélidas": "asélida",
    "ata": "atar",
    "atabacada": "atabacado",
    "atabacadas": "atabacado",
    "atabacados": "atabacado",
    "atabafa": "atabafar",
    "atabafada": "atabafar",
    "atabafadas": "atabafar",
    "atabafado": "atabafar",
    "atabafadora": "atabafador",
    "atabafadoras": "atabafador",
    "atabafadores": "atabafador",
    "atabafados": "atabafar",
    "atabafai": "atabafar",
    "atabafais": "atabafar",
    "atabafam": "atabafar",
    "atabafamentos": "atabafamento",
    "atabafamo": "atabafar",
    "atabafamos": "atabafar",
    "atabafando": "atabafar",
    "atabafantes": "atabafante",
    "atabafara": "atabafar",
    "atabafaram": "atabafar",
    "atabafaras": "atabafar",
    "atabafarde": "atabafar",
    "atabafardes": "atabafar",
    "atabafare": "atabafar",
    "atabafarei": "atabafar",
    "atabafareis": "atabafar",
    "atabafarem": "atabafar",
    "atabafaremos": "atabafar",
    "atabafares": "atabafar",
    "atabafaria": "atabafar",
    "atabafariam": "atabafar",
    "atabafarias": "atabafar",
    "atabafarmo": "atabafar",
    "atabafarmos": "atabafar",
    "atabafará": "atabafar",
    "atabafarás": "atabafar",
    "atabafarão": "atabafar",
    "atabafaríamos": "atabafar",
    "atabafaríeis": "atabafar",
    "atabafas": "atabafar",
    "atabafasse": "atabafar",
    "atabafassem": "atabafar",
    "atabafasses": "atabafar",
    "atabafaste": "atabafar",
    "atabafastes": "atabafar",
    "atabafava": "atabafar",
    "atabafavam": "atabafar",
    "atabafavas": "atabafar",
    "atabafe": "atabafar",
    "atabafei": "atabafar",
    "atabafeiras": "atabafeira",
    "atabafeis": "atabafar",
    "atabafem": "atabafar",
    "atabafemo": "atabafar",
    "atabafemos": "atabafar",
    "atabafes": "atabafar",
    "atabafo": "atabafar",
    "atabafou": "atabafar",
    "atabafá": "atabafar",
    "atabafámo": "atabafar",
    "atabafámos": "atabafar",
    "atabafáramo": "atabafar",
    "atabafáramos": "atabafar",
    "atabafárei": "atabafar",
    "atabafáreis": "atabafar",
    "atabafásseis": "atabafar",
    "atabafássemos": "atabafar",
    "atabafávamo": "atabafar",
    "atabafávamos": "atabafar",
    "atabafávei": "atabafar",
    "atabafáveis": "atabafar",
    "atabaleira": "atabaleiro",
    "atabaleiras": "atabaleiro",
    "atabaleiros": "atabaleiro",
    "atabales": "atabale",
    "atabalhoa": "atabalhoar",
    "atabalhoada": "atabalhoar",
    "atabalhoadas": "atabalhoar",
    "atabalhoadinha": "atabalhoado",
    "atabalhoadinhas": "atabalhoado",
    "atabalhoadinho": "atabalhoado",
    "atabalhoadinhos": "atabalhoado",
    "atabalhoadita": "atabalhoado",
    "atabalhoaditas": "atabalhoado",
    "atabalhoadito": "atabalhoado",
    "atabalhoaditos": "atabalhoado",
    "atabalhoado": "atabalhoar",
    "atabalhoados": "atabalhoar",
    "atabalhoadíssima": "atabalhoado",
    "atabalhoadíssimas": "atabalhoado",
    "atabalhoadíssimo": "atabalhoado",
    "atabalhoadíssimos": "atabalhoado",
    "atabalhoai": "atabalhoar",
    "atabalhoais": "atabalhoar",
    "atabalhoam": "atabalhoar",
    "atabalhoamentos": "atabalhoamento",
    "atabalhoamo": "atabalhoar",
    "atabalhoamos": "atabalhoar",
    "atabalhoando": "atabalhoar",
    "atabalhoara": "atabalhoar",
    "atabalhoaram": "atabalhoar",
    "atabalhoaras": "atabalhoar",
    "atabalhoarde": "atabalhoar",
    "atabalhoardes": "atabalhoar",
    "atabalhoare": "atabalhoar",
    "atabalhoarei": "atabalhoar",
    "atabalhoareis": "atabalhoar",
    "atabalhoarem": "atabalhoar",
    "atabalhoaremos": "atabalhoar",
    "atabalhoares": "atabalhoar",
    "atabalhoaria": "atabalhoar",
    "atabalhoariam": "atabalhoar",
    "atabalhoarias": "atabalhoar",
    "atabalhoarmo": "atabalhoar",
    "atabalhoarmos": "atabalhoar",
    "atabalhoará": "atabalhoar",
    "atabalhoarás": "atabalhoar",
    "atabalhoarão": "atabalhoar",
    "atabalhoaríamos": "atabalhoar",
    "atabalhoaríeis": "atabalhoar",
    "atabalhoas": "atabalhoar",
    "atabalhoasse": "atabalhoar",
    "atabalhoassem": "atabalhoar",
    "atabalhoasses": "atabalhoar",
    "atabalhoaste": "atabalhoar",
    "atabalhoastes": "atabalhoar",
    "atabalhoava": "atabalhoar",
    "atabalhoavam": "atabalhoar",
    "atabalhoavas": "atabalhoar",
    "atabalhoações": "atabalhoação",
    "atabalhoe": "atabalhoar",
    "atabalhoei": "atabalhoar",
    "atabalhoeis": "atabalhoar",
    "atabalhoem": "atabalhoar",
    "atabalhoemo": "atabalhoar",
    "atabalhoemos": "atabalhoar",
    "atabalhoes": "atabalhoar",
    "atabalhoo": "atabalhoar",
    "atabalhoou": "atabalhoar",
    "atabalhoá": "atabalhoar",
    "atabalhoámo": "atabalhoar",
    "atabalhoámos": "atabalhoar",
    "atabalhoáramo": "atabalhoar",
    "atabalhoáramos": "atabalhoar",
    "atabalhoárei": "atabalhoar",
    "atabalhoáreis": "atabalhoar",
    "atabalhoásseis": "atabalhoar",
    "atabalhoássemos": "atabalhoar",
    "atabalhoávamo": "atabalhoar",
    "atabalhoávamos": "atabalhoar",
    "atabalhoávei": "atabalhoar",
    "atabalhoáveis": "atabalhoar",
    "atabaqueira": "atabaqueiro",
    "atabaqueiras": "atabaqueiro",
    "atabaqueiros": "atabaqueiro",
    "atabaques": "atabaque",
    "atabardas": "atabarda",
    "ataberna": "atabernar",
    "atabernada": "atabernar",
    "atabernadas": "atabernar",
    "atabernado": "atabernar",
    "atabernados": "atabernar",
    "atabernai": "atabernar",
    "atabernais": "atabernar",
    "atabernam": "atabernar",
    "atabernamo": "atabernar",
    "atabernamos": "atabernar",
    "atabernando": "atabernar",
    "atabernara": "atabernar",
    "atabernaram": "atabernar",
    "atabernaras": "atabernar",
    "atabernarde": "atabernar",
    "atabernardes": "atabernar",
    "atabernare": "atabernar",
    "atabernarei": "atabernar",
    "atabernareis": "atabernar",
    "atabernarem": "atabernar",
    "atabernaremos": "atabernar",
    "atabernares": "atabernar",
    "atabernaria": "atabernar",
    "atabernariam": "atabernar",
    "atabernarias": "atabernar",
    "atabernarmo": "atabernar",
    "atabernarmos": "atabernar",
    "atabernará": "atabernar",
    "atabernarás": "atabernar",
    "atabernarão": "atabernar",
    "atabernaríamos": "atabernar",
    "atabernaríeis": "atabernar",
    "atabernas": "atabernar",
    "atabernasse": "atabernar",
    "atabernassem": "atabernar",
    "atabernasses": "atabernar",
    "atabernaste": "atabernar",
    "atabernastes": "atabernar",
    "atabernava": "atabernar",
    "atabernavam": "atabernar",
    "atabernavas": "atabernar",
    "ataberne": "atabernar",
    "atabernei": "atabernar",
    "ataberneis": "atabernar",
    "atabernem": "atabernar",
    "atabernemo": "atabernar",
    "atabernemos": "atabernar",
    "atabernes": "atabernar",
    "ataberno": "atabernar",
    "atabernou": "atabernar",
    "ataberná": "atabernar",
    "atabernámo": "atabernar",
    "atabernámos": "atabernar",
    "atabernáramo": "atabernar",
    "atabernáramos": "atabernar",
    "atabernárei": "atabernar",
    "atabernáreis": "atabernar",
    "atabernásseis": "atabernar",
    "atabernássemos": "atabernar",
    "atabernávamo": "atabernar",
    "atabernávamos": "atabernar",
    "atabernávei": "atabernar",
    "atabernáveis": "atabernar",
    "atabões": "atabão",
    "ataca": "atacar",
    "atacada": "atacar",
    "atacadas": "atacar",
    "atacadistas": "atacadista",
    "atacado": "atacar",
    "atacadora": "atacador",
    "atacadoras": "atacador",
    "atacadores": "atacador",
    "atacados": "atacar",
    "atacaduras": "atacadura",
    "atacadíssima": "atacado",
    "atacadíssimas": "atacado",
    "atacadíssimo": "atacado",
    "atacadíssimos": "atacado",
    "atacai": "atacar",
    "atacais": "atacar",
    "atacam": "atacar",
    "atacamitas": "atacamita",
    "atacamo": "atacar",
    "atacamos": "atacar",
    "atacando": "atacar",
    "atacaniças": "atacaniça",
    "atacantes": "atacante",
    "atacara": "atacar",
    "atacaram": "atacar",
    "atacaras": "atacar",
    "atacarde": "atacar",
    "atacardes": "atacar",
    "atacare": "atacar",
    "atacarei": "atacar",
    "atacareis": "atacar",
    "atacarem": "atacar",
    "atacaremos": "atacar",
    "atacares": "atacar",
    "atacaria": "atacar",
    "atacariam": "atacar",
    "atacarias": "atacar",
    "atacarmo": "atacar",
    "atacarmos": "atacar",
    "atacará": "atacar",
    "atacarás": "atacar",
    "atacarão": "atacar",
    "atacaríamos": "atacar",
    "atacaríeis": "atacar",
    "atacas": "atacar",
    "atacasse": "atacar",
    "atacassem": "atacar",
    "atacasses": "atacar",
    "atacaste": "atacar",
    "atacastes": "atacar",
    "atacava": "atacar",
    "atacavam": "atacar",
    "atacavas": "atacar",
    "ataco": "atacar",
    "atacou": "atacar",
    "atacá": "atacar",
    "atacámo": "atacar",
    "atacámos": "atacar",
    "atacáramo": "atacar",
    "atacáramos": "atacar",
    "atacárei": "atacar",
    "atacáreis": "atacar",
    "atacásseis": "atacar",
    "atacássemos": "atacar",
    "atacávamo": "atacar",
    "atacávamos": "atacar",
    "atacávei": "atacar",
    "atacáveis": "atacar",
    "atada": "atar",
    "atadas": "atar",
    "atadeira": "atadeiro",
    "atadeiras": "atadeiro",
    "atadeiros": "atadeiro",
    "atadilhos": "atadilho",
    "atadinha": "atado",
    "atadinhas": "atado",
    "atadinho": "atado",
    "atadinhos": "atado",
    "atadita": "atado",
    "ataditas": "atado",
    "atadito": "atado",
    "ataditos": "atado",
    "atado": "atar",
    "atadora": "atador",
    "atadoras": "atador",
    "atadores": "atador",
    "atados": "atar",
    "ataduras": "atadura",
    "atadíssima": "atado",
    "atadíssimas": "atado",
    "atadíssimo": "atado",
    "atadíssimos": "atado",
    "atafais": "atafal",
    "atafegações": "atafegação",
    "atafegos": "atafego",
    "ataferas": "atafera",
    "atafonas": "atafona",
    "atafoneiros": "atafoneiro",
    "atafulha": "atafulhar",
    "atafulhada": "atafulhar",
    "atafulhadas": "atafulhar",
    "atafulhado": "atafulhar",
    "atafulhados": "atafulhar",
    "atafulhai": "atafulhar",
    "atafulhais": "atafulhar",
    "atafulham": "atafulhar",
    "atafulhamentos": "atafulhamento",
    "atafulhamo": "atafulhar",
    "atafulhamos": "atafulhar",
    "atafulhando": "atafulhar",
    "atafulhara": "atafulhar",
    "atafulharam": "atafulhar",
    "atafulharas": "atafulhar",
    "atafulharde": "atafulhar",
    "atafulhardes": "atafulhar",
    "atafulhare": "atafulhar",
    "atafulharei": "atafulhar",
    "atafulhareis": "atafulhar",
    "atafulharem": "atafulhar",
    "atafulharemos": "atafulhar",
    "atafulhares": "atafulhar",
    "atafulharia": "atafulhar",
    "atafulhariam": "atafulhar",
    "atafulharias": "atafulhar",
    "atafulharmo": "atafulhar",
    "atafulharmos": "atafulhar",
    "atafulhará": "atafulhar",
    "atafulharás": "atafulhar",
    "atafulharão": "atafulhar",
    "atafulharíamos": "atafulhar",
    "atafulharíeis": "atafulhar",
    "atafulhas": "atafulhar",
    "atafulhasse": "atafulhar",
    "atafulhassem": "atafulhar",
    "atafulhasses": "atafulhar",
    "atafulhaste": "atafulhar",
    "atafulhastes": "atafulhar",
    "atafulhava": "atafulhar",
    "atafulhavam": "atafulhar",
    "atafulhavas": "atafulhar",
    "atafulhe": "atafulhar",
    "atafulhei": "atafulhar",
    "atafulheis": "atafulhar",
    "atafulhem": "atafulhar",
    "atafulhemo": "atafulhar",
    "atafulhemos": "atafulhar",
    "atafulhes": "atafulhar",
    "atafulho": "atafulhar",
    "atafulhou": "atafulhar",
    "atafulhá": "atafulhar",
    "atafulhámo": "atafulhar",
    "atafulhámos": "atafulhar",
    "atafulháramo": "atafulhar",
    "atafulháramos": "atafulhar",
    "atafulhárei": "atafulhar",
    "atafulháreis": "atafulhar",
    "atafulhásseis": "atafulhar",
    "atafulhássemos": "atafulhar",
    "atafulhávamo": "atafulhar",
    "atafulhávamos": "atafulhar",
    "atafulhávei": "atafulhar",
    "atafulháveis": "atafulhar",
    "atai": "atar",
    "atais": "atar",
    "atalaiadora": "atalaiador",
    "atalaiadoras": "atalaiador",
    "atalaiadores": "atalaiador",
    "atalaias": "atalaia",
    "atalantas": "atalanta",
    "atalantes": "atalante",
    "atalha": "atalhar",
    "atalhada": "atalhar",
    "atalhadas": "atalhar",
    "atalhado": "atalhar",
    "atalhadoiros": "atalhadoiro",
    "atalhadora": "atalhador",
    "atalhadoras": "atalhador",
    "atalhadores": "atalhador",
    "atalhados": "atalhar",
    "atalhadouros": "atalhadouro",
    "atalhai": "atalhar",
    "atalhais": "atalhar",
    "atalham": "atalhar",
    "atalhamentos": "atalhamento",
    "atalhamo": "atalhar",
    "atalhamos": "atalhar",
    "atalhando": "atalhar",
    "atalhara": "atalhar",
    "atalharam": "atalhar",
    "atalharas": "atalhar",
    "atalharde": "atalhar",
    "atalhardes": "atalhar",
    "atalhare": "atalhar",
    "atalharei": "atalhar",
    "atalhareis": "atalhar",
    "atalharem": "atalhar",
    "atalharemos": "atalhar",
    "atalhares": "atalhar",
    "atalharia": "atalhar",
    "atalhariam": "atalhar",
    "atalharias": "atalhar",
    "atalharmo": "atalhar",
    "atalharmos": "atalhar",
    "atalhará": "atalhar",
    "atalharás": "atalhar",
    "atalharão": "atalhar",
    "atalharíamos": "atalhar",
    "atalharíeis": "atalhar",
    "atalhas": "atalhar",
    "atalhasse": "atalhar",
    "atalhassem": "atalhar",
    "atalhasses": "atalhar",
    "atalhaste": "atalhar",
    "atalhastes": "atalhar",
    "atalhava": "atalhar",
    "atalhavam": "atalhar",
    "atalhavas": "atalhar",
    "atalhe": "atalhar",
    "atalhei": "atalhar",
    "atalheis": "atalhar",
    "atalhem": "atalhar",
    "atalhemo": "atalhar",
    "atalhemos": "atalhar",
    "atalhes": "atalhar",
    "atalho": "atalhar",
    "atalhos": "atalho",
    "atalhou": "atalhar",
    "atalhá": "atalhar",
    "atalhámo": "atalhar",
    "atalhámos": "atalhar",
    "atalháramo": "atalhar",
    "atalháramos": "atalhar",
    "atalhárei": "atalhar",
    "atalháreis": "atalhar",
    "atalhásseis": "atalhar",
    "atalhássemos": "atalhar",
    "atalhávamo": "atalhar",
    "atalhávamos": "atalhar",
    "atalhávei": "atalhar",
    "atalháveis": "atalhar",
    "atalochas": "atalocha",
    "atam": "atar",
    "atamanca": "atamancar",
    "atamancada": "atamancar",
    "atamancadas": "atamancar",
    "atamancado": "atamancar",
    "atamancadora": "atamancador",
    "atamancadoras": "atamancador",
    "atamancadores": "atamancador",
    "atamancados": "atamancar",
    "atamancai": "atamancar",
    "atamancais": "atamancar",
    "atamancam": "atamancar",
    "atamancamentos": "atamancamento",
    "atamancamo": "atamancar",
    "atamancamos": "atamancar",
    "atamancando": "atamancar",
    "atamancara": "atamancar",
    "atamancaram": "atamancar",
    "atamancaras": "atamancar",
    "atamancarde": "atamancar",
    "atamancardes": "atamancar",
    "atamancare": "atamancar",
    "atamancarei": "atamancar",
    "atamancareis": "atamancar",
    "atamancarem": "atamancar",
    "atamancaremos": "atamancar",
    "atamancares": "atamancar",
    "atamancaria": "atamancar",
    "atamancariam": "atamancar",
    "atamancarias": "atamancar",
    "atamancarmo": "atamancar",
    "atamancarmos": "atamancar",
    "atamancará": "atamancar",
    "atamancarás": "atamancar",
    "atamancarão": "atamancar",
    "atamancaríamos": "atamancar",
    "atamancaríeis": "atamancar",
    "atamancas": "atamancar",
    "atamancasse": "atamancar",
    "atamancassem": "atamancar",
    "atamancasses": "atamancar",
    "atamancaste": "atamancar",
    "atamancastes": "atamancar",
    "atamancava": "atamancar",
    "atamancavam": "atamancar",
    "atamancavas": "atamancar",
    "atamanco": "atamancar",
    "atamancou": "atamancar",
    "atamancá": "atamancar",
    "atamancámo": "atamancar",
    "atamancámos": "atamancar",
    "atamancáramo": "atamancar",
    "atamancáramos": "atamancar",
    "atamancárei": "atamancar",
    "atamancáreis": "atamancar",
    "atamancásseis": "atamancar",
    "atamancássemos": "atamancar",
    "atamancávamo": "atamancar",
    "atamancávamos": "atamancar",
    "atamancávei": "atamancar",
    "atamancáveis": "atamancar",
    "atamanque": "atamancar",
    "atamanquei": "atamancar",
    "atamanqueis": "atamancar",
    "atamanquem": "atamancar",
    "atamanquemo": "atamancar",
    "atamanquemos": "atamancar",
    "atamanques": "atamancar",
    "atamarada": "atamarado",
    "atamaradas": "atamarado",
    "atamarados": "atamarado",
    "atambias": "atambia",
    "atambores": "atambor",
    "atamentos": "atamento",
    "atamo": "atar",
    "atamos": "atar",
    "atanados": "atanado",
    "atanazada": "atanazado",
    "atanazadas": "atanazado",
    "atanazados": "atanazado",
    "atando": "atar",
    "atanária": "atanário",
    "atanárias": "atanário",
    "atanários": "atanário",
    "atanásias": "atanásia",
    "atapeta": "atapetar",
    "atapetada": "atapetar",
    "atapetadas": "atapetar",
    "atapetado": "atapetar",
    "atapetados": "atapetar",
    "atapetai": "atapetar",
    "atapetais": "atapetar",
    "atapetam": "atapetar",
    "atapetamo": "atapetar",
    "atapetamos": "atapetar",
    "atapetando": "atapetar",
    "atapetara": "atapetar",
    "atapetaram": "atapetar",
    "atapetaras": "atapetar",
    "atapetarde": "atapetar",
    "atapetardes": "atapetar",
    "atapetare": "atapetar",
    "atapetarei": "atapetar",
    "atapetareis": "atapetar",
    "atapetarem": "atapetar",
    "atapetaremos": "atapetar",
    "atapetares": "atapetar",
    "atapetaria": "atapetar",
    "atapetariam": "atapetar",
    "atapetarias": "atapetar",
    "atapetarmo": "atapetar",
    "atapetarmos": "atapetar",
    "atapetará": "atapetar",
    "atapetarás": "atapetar",
    "atapetarão": "atapetar",
    "atapetaríamos": "atapetar",
    "atapetaríeis": "atapetar",
    "atapetas": "atapetar",
    "atapetasse": "atapetar",
    "atapetassem": "atapetar",
    "atapetasses": "atapetar",
    "atapetaste": "atapetar",
    "atapetastes": "atapetar",
    "atapetava": "atapetar",
    "atapetavam": "atapetar",
    "atapetavas": "atapetar",
    "atapete": "atapetar",
    "atapetei": "atapetar",
    "atapeteis": "atapetar",
    "atapetem": "atapetar",
    "atapetemo": "atapetar",
    "atapetemos": "atapetar",
    "atapetes": "atapetar",
    "atapeto": "atapetar",
    "atapetou": "atapetar",
    "atapetá": "atapetar",
    "atapetámo": "atapetar",
    "atapetámos": "atapetar",
    "atapetáramo": "atapetar",
    "atapetáramos": "atapetar",
    "atapetárei": "atapetar",
    "atapetáreis": "atapetar",
    "atapetásseis": "atapetar",
    "atapetássemos": "atapetar",
    "atapetávamo": "atapetar",
    "atapetávamos": "atapetar",
    "atapetávei": "atapetar",
    "atapetáveis": "atapetar",
    "ataque": "atacar",
    "ataquei": "atacar",
    "ataqueiras": "ataqueira",
    "ataqueis": "atacar",
    "ataquem": "atacar",
    "ataquemo": "atacar",
    "ataquemos": "atacar",
    "ataques": "ataque",
    "atara": "atar",
    "ataram": "atar",
    "ataranta": "atarantar",
    "atarantada": "atarantar",
    "atarantadas": "atarantar",
    "atarantadinha": "atarantado",
    "atarantadinhas": "atarantado",
    "atarantadinho": "atarantado",
    "atarantadinhos": "atarantado",
    "atarantadita": "atarantado",
    "atarantaditas": "atarantado",
    "atarantadito": "atarantado",
    "atarantaditos": "atarantado",
    "atarantado": "atarantar",
    "atarantados": "atarantar",
    "atarantadíssima": "atarantado",
    "atarantadíssimas": "atarantado",
    "atarantadíssimo": "atarantado",
    "atarantadíssimos": "atarantado",
    "atarantai": "atarantar",
    "atarantais": "atarantar",
    "atarantam": "atarantar",
    "atarantamentos": "atarantamento",
    "atarantamo": "atarantar",
    "atarantamos": "atarantar",
    "atarantando": "atarantar",
    "atarantara": "atarantar",
    "atarantaram": "atarantar",
    "atarantaras": "atarantar",
    "atarantarde": "atarantar",
    "atarantardes": "atarantar",
    "atarantare": "atarantar",
    "atarantarei": "atarantar",
    "atarantareis": "atarantar",
    "atarantarem": "atarantar",
    "atarantaremos": "atarantar",
    "atarantares": "atarantar",
    "atarantaria": "atarantar",
    "atarantariam": "atarantar",
    "atarantarias": "atarantar",
    "atarantarmo": "atarantar",
    "atarantarmos": "atarantar",
    "atarantará": "atarantar",
    "atarantarás": "atarantar",
    "atarantarão": "atarantar",
    "atarantaríamos": "atarantar",
    "atarantaríeis": "atarantar",
    "atarantas": "atarantar",
    "atarantasse": "atarantar",
    "atarantassem": "atarantar",
    "atarantasses": "atarantar",
    "atarantaste": "atarantar",
    "atarantastes": "atarantar",
    "atarantava": "atarantar",
    "atarantavam": "atarantar",
    "atarantavas": "atarantar",
    "atarantações": "atarantação",
    "atarante": "atarantar",
    "atarantei": "atarantar",
    "ataranteis": "atarantar",
    "atarantem": "atarantar",
    "atarantemo": "atarantar",
    "atarantemos": "atarantar",
    "atarantes": "atarantar",
    "ataranto": "atarantar",
    "atarantos": "ataranto",
    "atarantou": "atarantar",
    "atarantá": "atarantar",
    "atarantámo": "atarantar",
    "atarantámos": "atarantar",
    "atarantáramo": "atarantar",
    "atarantáramos": "atarantar",
    "atarantárei": "atarantar",
    "atarantáreis": "atarantar",
    "atarantásseis": "atarantar",
    "atarantássemos": "atarantar",
    "atarantávamo": "atarantar",
    "atarantávamos": "atarantar",
    "atarantávei": "atarantar",
    "atarantáveis": "atarantar",
    "ataras": "atar",
    "ataraxias": "ataraxia",
    "atarda": "atardar",
    "atardada": "atardar",
    "atardadas": "atardar",
    "atardado": "atardar",
    "atardados": "atardar",
    "atardai": "atardar",
    "atardais": "atardar",
    "atardam": "atardar",
    "atardamo": "atardar",
    "atardamos": "atardar",
    "atardando": "atardar",
    "atardara": "atardar",
    "atardaram": "atardar",
    "atardaras": "atardar",
    "atardarde": "atardar",
    "atardardes": "atardar",
    "atardare": "atardar",
    "atardarei": "atardar",
    "atardareis": "atardar",
    "atardarem": "atardar",
    "atardaremos": "atardar",
    "atardares": "atardar",
    "atardaria": "atardar",
    "atardariam": "atardar",
    "atardarias": "atardar",
    "atardarmo": "atardar",
    "atardarmos": "atardar",
    "atardará": "atardar",
    "atardarás": "atardar",
    "atardarão": "atardar",
    "atardaríamos": "atardar",
    "atardaríeis": "atardar",
    "atardas": "atardar",
    "atardasse": "atardar",
    "atardassem": "atardar",
    "atardasses": "atardar",
    "atardaste": "atardar",
    "atardastes": "atardar",
    "atardava": "atardar",
    "atardavam": "atardar",
    "atardavas": "atardar",
    "atarde": "atardar",
    "atardei": "atardar",
    "atardeis": "atardar",
    "atardem": "atardar",
    "atardemo": "atardar",
    "atardemos": "atardar",
    "atardes": "atardar",
    "atardo": "atardar",
    "atardou": "atardar",
    "atardá": "atardar",
    "atardámo": "atardar",
    "atardámos": "atardar",
    "atardáramo": "atardar",
    "atardáramos": "atardar",
    "atardárei": "atardar",
    "atardáreis": "atardar",
    "atardásseis": "atardar",
    "atardássemos": "atardar",
    "atardávamo": "atardar",
    "atardávamos": "atardar",
    "atardávei": "atardar",
    "atardáveis": "atardar",
    "atare": "atar",
    "atarefa": "atarefar",
    "atarefada": "atarefar",
    "atarefadas": "atarefar",
    "atarefadinha": "atarefado",
    "atarefadinhas": "atarefado",
    "atarefadinho": "atarefado",
    "atarefadinhos": "atarefado",
    "atarefadita": "atarefado",
    "atarefaditas": "atarefado",
    "atarefadito": "atarefado",
    "atarefaditos": "atarefado",
    "atarefado": "atarefar",
    "atarefados": "atarefar",
    "atarefadíssima": "atarefado",
    "atarefadíssimas": "atarefado",
    "atarefadíssimo": "atarefado",
    "atarefadíssimos": "atarefado",
    "atarefai": "atarefar",
    "atarefais": "atarefar",
    "atarefam": "atarefar",
    "atarefamentos": "atarefamento",
    "atarefamo": "atarefar",
    "atarefamos": "atarefar",
    "atarefando": "atarefar",
    "atarefara": "atarefar",
    "atarefaram": "atarefar",
    "atarefaras": "atarefar",
    "atarefarde": "atarefar",
    "atarefardes": "atarefar",
    "atarefare": "atarefar",
    "atarefarei": "atarefar",
    "atarefareis": "atarefar",
    "atarefarem": "atarefar",
    "atarefaremos": "atarefar",
    "atarefares": "atarefar",
    "atarefaria": "atarefar",
    "atarefariam": "atarefar",
    "atarefarias": "atarefar",
    "atarefarmo": "atarefar",
    "atarefarmos": "atarefar",
    "atarefará": "atarefar",
    "atarefarás": "atarefar",
    "atarefarão": "atarefar",
    "atarefaríamos": "atarefar",
    "atarefaríeis": "atarefar",
    "atarefas": "atarefar",
    "atarefasse": "atarefar",
    "atarefassem": "atarefar",
    "atarefasses": "atarefar",
    "atarefaste": "atarefar",
    "atarefastes": "atarefar",
    "atarefava": "atarefar",
    "atarefavam": "atarefar",
    "atarefavas": "atarefar",
    "atarefe": "atarefar",
    "atarefei": "atarefar",
    "atarefeis": "atarefar",
    "atarefem": "atarefar",
    "atarefemo": "atarefar",
    "atarefemos": "atarefar",
    "atarefes": "atarefar",
    "atarefo": "atarefar",
    "atarefou": "atarefar",
    "atarefá": "atarefar",
    "atarefámo": "atarefar",
    "atarefámos": "atarefar",
    "atarefáramo": "atarefar",
    "atarefáramos": "atarefar",
    "atarefárei": "atarefar",
    "atarefáreis": "atarefar",
    "atarefásseis": "atarefar",
    "atarefássemos": "atarefar",
    "atarefávamo": "atarefar",
    "atarefávamos": "atarefar",
    "atarefávei": "atarefar",
    "atarefáveis": "atarefar",
    "atarei": "atar",
    "atareis": "atar",
    "atarem": "atar",
    "ataremos": "atar",
    "atares": "atar",
    "ataria": "atar",
    "atariam": "atar",
    "atarias": "atar",
    "atarmo": "atar",
    "atarmos": "atar",
    "atarraca": "atarracar",
    "atarracada": "atarracar",
    "atarracadas": "atarracar",
    "atarracadinha": "atarracado",
    "atarracadinhas": "atarracado",
    "atarracadinho": "atarracado",
    "atarracadinhos": "atarracado",
    "atarracadita": "atarracado",
    "atarracaditas": "atarracado",
    "atarracadito": "atarracado",
    "atarracaditos": "atarracado",
    "atarracado": "atarracar",
    "atarracados": "atarracar",
    "atarracadíssima": "atarracado",
    "atarracadíssimas": "atarracado",
    "atarracadíssimo": "atarracado",
    "atarracadíssimos": "atarracado",
    "atarracai": "atarracar",
    "atarracais": "atarracar",
    "atarracam": "atarracar",
    "atarracamo": "atarracar",
    "atarracamos": "atarracar",
    "atarracando": "atarracar",
    "atarracara": "atarracar",
    "atarracaram": "atarracar",
    "atarracaras": "atarracar",
    "atarracarde": "atarracar",
    "atarracardes": "atarracar",
    "atarracare": "atarracar",
    "atarracarei": "atarracar",
    "atarracareis": "atarracar",
    "atarracarem": "atarracar",
    "atarracaremos": "atarracar",
    "atarracares": "atarracar",
    "atarracaria": "atarracar",
    "atarracariam": "atarracar",
    "atarracarias": "atarracar",
    "atarracarmo": "atarracar",
    "atarracarmos": "atarracar",
    "atarracará": "atarracar",
    "atarracarás": "atarracar",
    "atarracarão": "atarracar",
    "atarracaríamos": "atarracar",
    "atarracaríeis": "atarracar",
    "atarracas": "atarracar",
    "atarracasse": "atarracar",
    "atarracassem": "atarracar",
    "atarracasses": "atarracar",
    "atarracaste": "atarracar",
    "atarracastes": "atarracar",
    "atarracava": "atarracar",
    "atarracavam": "atarracar",
    "atarracavas": "atarracar",
    "atarrachadores": "atarrachador",
    "atarraco": "atarracar",
    "atarracou": "atarracar",
    "atarracá": "atarracar",
    "atarracámo": "atarracar",
    "atarracámos": "atarracar",
    "atarracáramo": "atarracar",
    "atarracáramos": "atarracar",
    "atarracárei": "atarracar",
    "atarracáreis": "atarracar",
    "atarracásseis": "atarracar",
    "atarracássemos": "atarracar",
    "atarracávamo": "atarracar",
    "atarracávamos": "atarracar",
    "atarracávei": "atarracar",
    "atarracáveis": "atarracar",
    "atarrafada": "atarrafado",
    "atarrafadas": "atarrafado",
    "atarrafados": "atarrafado",
    "atarraque": "atarracar",
    "atarraquei": "atarracar",
    "atarraqueis": "atarracar",
    "atarraquem": "atarracar",
    "atarraquemo": "atarracar",
    "atarraquemos": "atarracar",
    "atarraques": "atarracar",
    "atarraxa": "atarraxar",
    "atarraxada": "atarraxar",
    "atarraxadas": "atarraxar",
    "atarraxado": "atarraxar",
    "atarraxados": "atarraxar",
    "atarraxai": "atarraxar",
    "atarraxais": "atarraxar",
    "atarraxam": "atarraxar",
    "atarraxamo": "atarraxar",
    "atarraxamos": "atarraxar",
    "atarraxando": "atarraxar",
    "atarraxara": "atarraxar",
    "atarraxaram": "atarraxar",
    "atarraxaras": "atarraxar",
    "atarraxarde": "atarraxar",
    "atarraxardes": "atarraxar",
    "atarraxare": "atarraxar",
    "atarraxarei": "atarraxar",
    "atarraxareis": "atarraxar",
    "atarraxarem": "atarraxar",
    "atarraxaremos": "atarraxar",
    "atarraxares": "atarraxar",
    "atarraxaria": "atarraxar",
    "atarraxariam": "atarraxar",
    "atarraxarias": "atarraxar",
    "atarraxarmo": "atarraxar",
    "atarraxarmos": "atarraxar",
    "atarraxará": "atarraxar",
    "atarraxarás": "atarraxar",
    "atarraxarão": "atarraxar",
    "atarraxaríamos": "atarraxar",
    "atarraxaríeis": "atarraxar",
    "atarraxas": "atarraxar",
    "atarraxasse": "atarraxar",
    "atarraxassem": "atarraxar",
    "atarraxasses": "atarraxar",
    "atarraxaste": "atarraxar",
    "atarraxastes": "atarraxar",
    "atarraxava": "atarraxar",
    "atarraxavam": "atarraxar",
    "atarraxavas": "atarraxar",
    "atarraxe": "atarraxar",
    "atarraxei": "atarraxar",
    "atarraxeis": "atarraxar",
    "atarraxem": "atarraxar",
    "atarraxemo": "atarraxar",
    "atarraxemos": "atarraxar",
    "atarraxes": "atarraxar",
    "atarraxo": "atarraxar",
    "atarraxou": "atarraxar",
    "atarraxá": "atarraxar",
    "atarraxámo": "atarraxar",
    "atarraxámos": "atarraxar",
    "atarraxáramo": "atarraxar",
    "atarraxáramos": "atarraxar",
    "atarraxárei": "atarraxar",
    "atarraxáreis": "atarraxar",
    "atarraxásseis": "atarraxar",
    "atarraxássemos": "atarraxar",
    "atarraxávamo": "atarraxar",
    "atarraxávamos": "atarraxar",
    "atarraxávei": "atarraxar",
    "atarraxáveis": "atarraxar",
    "atarraçada": "atarraçado",
    "atarraçadas": "atarraçado",
    "atarraçados": "atarraçado",
    "atartamelada": "atartamelado",
    "atartameladas": "atartamelado",
    "atartamelados": "atartamelado",
    "atartarugada": "atartarugado",
    "atartarugadas": "atartarugado",
    "atartarugados": "atartarugado",
    "atará": "atar",
    "atarás": "atar",
    "atarão": "atar",
    "ataríamos": "atar",
    "ataríeis": "atar",
    "atas": "atar",
    "atasca": "atascar",
    "atascada": "atascar",
    "atascadas": "atascar",
    "atascadeiros": "atascadeiro",
    "atascado": "atascar",
    "atascados": "atascar",
    "atascai": "atascar",
    "atascais": "atascar",
    "atascam": "atascar",
    "atascamo": "atascar",
    "atascamos": "atascar",
    "atascando": "atascar",
    "atascara": "atascar",
    "atascaram": "atascar",
    "atascaras": "atascar",
    "atascarde": "atascar",
    "atascardes": "atascar",
    "atascare": "atascar",
    "atascarei": "atascar",
    "atascareis": "atascar",
    "atascarem": "atascar",
    "atascaremos": "atascar",
    "atascares": "atascar",
    "atascaria": "atascar",
    "atascariam": "atascar",
    "atascarias": "atascar",
    "atascarmo": "atascar",
    "atascarmos": "atascar",
    "atascará": "atascar",
    "atascarás": "atascar",
    "atascarão": "atascar",
    "atascaríamos": "atascar",
    "atascaríeis": "atascar",
    "atascas": "atascar",
    "atascasse": "atascar",
    "atascassem": "atascar",
    "atascasses": "atascar",
    "atascaste": "atascar",
    "atascastes": "atascar",
    "atascava": "atascar",
    "atascavam": "atascar",
    "atascavas": "atascar",
    "atasco": "atascar",
    "atascou": "atascar",
    "atascá": "atascar",
    "atascámo": "atascar",
    "atascámos": "atascar",
    "atascáramo": "atascar",
    "atascáramos": "atascar",
    "atascárei": "atascar",
    "atascáreis": "atascar",
    "atascásseis": "atascar",
    "atascássemos": "atascar",
    "atascávamo": "atascar",
    "atascávamos": "atascar",
    "atascávei": "atascar",
    "atascáveis": "atascar",
    "atasque": "atascar",
    "atasquei": "atascar",
    "atasqueiros": "atasqueiro",
    "atasqueis": "atascar",
    "atasquem": "atascar",
    "atasquemo": "atascar",
    "atasquemos": "atascar",
    "atasques": "atascar",
    "atassalhadora": "atassalhador",
    "atassalhadoras": "atassalhador",
    "atassalhadores": "atassalhador",
    "atassalhaduras": "atassalhadura",
    "atasse": "atar",
    "atassem": "atar",
    "atasses": "atar",
    "atassins": "atassim",
    "ataste": "atar",
    "atastes": "atar",
    "atava": "atar",
    "atavam": "atar",
    "atavanada": "atavanado",
    "atavanadas": "atavanado",
    "atavanados": "atavanado",
    "atavas": "atar",
    "atavia": "ataviar",
    "ataviada": "ataviar",
    "ataviadas": "ataviar",
    "ataviado": "ataviar",
    "ataviadora": "ataviador",
    "ataviadoras": "ataviador",
    "ataviadores": "ataviador",
    "ataviados": "ataviar",
    "ataviai": "ataviar",
    "ataviais": "ataviar",
    "ataviam": "ataviar",
    "ataviamentos": "ataviamento",
    "ataviamo": "ataviar",
    "ataviamos": "ataviar",
    "ataviando": "ataviar",
    "ataviara": "ataviar",
    "ataviaram": "ataviar",
    "ataviaras": "ataviar",
    "ataviarde": "ataviar",
    "ataviardes": "ataviar",
    "ataviare": "ataviar",
    "ataviarei": "ataviar",
    "ataviareis": "ataviar",
    "ataviarem": "ataviar",
    "ataviaremos": "ataviar",
    "ataviares": "ataviar",
    "ataviaria": "ataviar",
    "ataviariam": "ataviar",
    "ataviarias": "ataviar",
    "ataviarmo": "ataviar",
    "ataviarmos": "ataviar",
    "ataviará": "ataviar",
    "ataviarás": "ataviar",
    "ataviarão": "ataviar",
    "ataviaríamos": "ataviar",
    "ataviaríeis": "ataviar",
    "atavias": "ataviar",
    "ataviasse": "ataviar",
    "ataviassem": "ataviar",
    "ataviasses": "ataviar",
    "ataviaste": "ataviar",
    "ataviastes": "ataviar",
    "ataviava": "ataviar",
    "ataviavam": "ataviar",
    "ataviavas": "ataviar",
    "atavie": "ataviar",
    "ataviei": "ataviar",
    "atavieis": "ataviar",
    "ataviem": "ataviar",
    "ataviemo": "ataviar",
    "ataviemos": "ataviar",
    "atavies": "ataviar",
    "atavio": "ataviar",
    "atavios": "atavio",
    "ataviou": "ataviar",
    "atavismos": "atavismo",
    "ataviá": "ataviar",
    "ataviámo": "ataviar",
    "ataviámos": "ataviar",
    "ataviáramo": "ataviar",
    "ataviáramos": "ataviar",
    "ataviárei": "ataviar",
    "ataviáreis": "ataviar",
    "ataviásseis": "ataviar",
    "ataviássemos": "ataviar",
    "ataviávamo": "ataviar",
    "ataviávamos": "ataviar",
    "ataviávei": "ataviar",
    "ataviáveis": "ataviar",
    "atavona": "atavão",
    "atavonada": "atavonado",
    "atavonadas": "atavonado",
    "atavonados": "atavonado",
    "atavonas": "atavão",
    "atavões": "atavão",
    "ataxias": "ataxia",
    "atazana": "atazanar",
    "atazanada": "atazanar",
    "atazanadas": "atazanar",
    "atazanado": "atazanar",
    "atazanados": "atazanar",
    "atazanai": "atazanar",
    "atazanais": "atazanar",
    "atazanam": "atazanar",
    "atazanamo": "atazanar",
    "atazanamos": "atazanar",
    "atazanando": "atazanar",
    "atazanara": "atazanar",
    "atazanaram": "atazanar",
    "atazanaras": "atazanar",
    "atazanarde": "atazanar",
    "atazanardes": "atazanar",
    "atazanare": "atazanar",
    "atazanarei": "atazanar",
    "atazanareis": "atazanar",
    "atazanarem": "atazanar",
    "atazanaremos": "atazanar",
    "atazanares": "atazanar",
    "atazanaria": "atazanar",
    "atazanariam": "atazanar",
    "atazanarias": "atazanar",
    "atazanarmo": "atazanar",
    "atazanarmos": "atazanar",
    "atazanará": "atazanar",
    "atazanarás": "atazanar",
    "atazanarão": "atazanar",
    "atazanaríamos": "atazanar",
    "atazanaríeis": "atazanar",
    "atazanas": "atazanar",
    "atazanasse": "atazanar",
    "atazanassem": "atazanar",
    "atazanasses": "atazanar",
    "atazanaste": "atazanar",
    "atazanastes": "atazanar",
    "atazanava": "atazanar",
    "atazanavam": "atazanar",
    "atazanavas": "atazanar",
    "atazane": "atazanar",
    "atazanei": "atazanar",
    "atazaneis": "atazanar",
    "atazanem": "atazanar",
    "atazanemo": "atazanar",
    "atazanemos": "atazanar",
    "atazanes": "atazanar",
    "atazano": "atazanar",
    "atazanou": "atazanar",
    "atazaná": "atazanar",
    "atazanámo": "atazanar",
    "atazanámos": "atazanar",
    "atazanáramo": "atazanar",
    "atazanáramos": "atazanar",
    "atazanárei": "atazanar",
    "atazanáreis": "atazanar",
    "atazanásseis": "atazanar",
    "atazanássemos": "atazanar",
    "atazanávamo": "atazanar",
    "atazanávamos": "atazanar",
    "atazanávei": "atazanar",
    "atazanáveis": "atazanar",
    "atações": "atação",
    "ataúdes": "ataúde",
    "ate": "atar",
    "ateada": "atear",
    "ateadas": "atear",
    "ateado": "atear",
    "ateadora": "ateador",
    "ateadoras": "ateador",
    "ateadores": "ateador",
    "ateados": "atear",
    "ateai": "atear",
    "ateais": "atear",
    "ateamo": "atear",
    "ateamos": "atear",
    "ateando": "atear",
    "ateara": "atear",
    "atearam": "atear",
    "atearas": "atear",
    "atearde": "atear",
    "ateardes": "atear",
    "ateare": "atear",
    "atearei": "atear",
    "ateareis": "atear",
    "atearem": "atear",
    "atearemos": "atear",
    "ateares": "atear",
    "atearia": "atear",
    "ateariam": "atear",
    "atearias": "atear",
    "atearmo": "atear",
    "atearmos": "atear",
    "ateará": "atear",
    "atearás": "atear",
    "atearão": "atear",
    "atearíamos": "atear",
    "atearíeis": "atear",
    "ateasse": "atear",
    "ateassem": "atear",
    "ateasses": "atear",
    "ateaste": "atear",
    "ateastes": "atear",
    "ateatrada": "ateatrado",
    "ateatradas": "ateatrado",
    "ateatrados": "ateatrado",
    "ateava": "atear",
    "ateavam": "atear",
    "ateavas": "atear",
    "atecnias": "atecnia",
    "ateei": "atear",
    "ateeis": "atear",
    "ateemo": "atear",
    "ateemos": "atear",
    "atei": "atar",
    "ateia": "ateu",
    "ateiam": "atear",
    "ateias": "ateu",
    "ateie": "atear",
    "ateiem": "atear",
    "ateies": "atear",
    "ateigamentos": "ateigamento",
    "ateima": "ateimar",
    "ateimada": "ateimar",
    "ateimadas": "ateimar",
    "ateimado": "ateimar",
    "ateimados": "ateimar",
    "ateimai": "ateimar",
    "ateimais": "ateimar",
    "ateimam": "ateimar",
    "ateimamo": "ateimar",
    "ateimamos": "ateimar",
    "ateimando": "ateimar",
    "ateimara": "ateimar",
    "ateimaram": "ateimar",
    "ateimaras": "ateimar",
    "ateimardes": "ateimar",
    "ateimarei": "ateimar",
    "ateimareis": "ateimar",
    "ateimarem": "ateimar",
    "ateimaremos": "ateimar",
    "ateimares": "ateimar",
    "ateimaria": "ateimar",
    "ateimariam": "ateimar",
    "ateimarias": "ateimar",
    "ateimarmo": "ateimar",
    "ateimarmos": "ateimar",
    "ateimará": "ateimar",
    "ateimarás": "ateimar",
    "ateimarão": "ateimar",
    "ateimaríamos": "ateimar",
    "ateimaríeis": "ateimar",
    "ateimas": "ateimar",
    "ateimasse": "ateimar",
    "ateimassem": "ateimar",
    "ateimasses": "ateimar",
    "ateimaste": "ateimar",
    "ateimastes": "ateimar",
    "ateimava": "ateimar",
    "ateimavam": "ateimar",
    "ateimavas": "ateimar",
    "ateime": "ateimar",
    "ateimei": "ateimar",
    "ateimeis": "ateimar",
    "ateimem": "ateimar",
    "ateimemo": "ateimar",
    "ateimemos": "ateimar",
    "ateimes": "ateimar",
    "ateimo": "ateimar",
    "ateimou": "ateimar",
    "ateimámo": "ateimar",
    "ateimámos": "ateimar",
    "ateimáramo": "ateimar",
    "ateimáramos": "ateimar",
    "ateimáreis": "ateimar",
    "ateimásseis": "ateimar",
    "ateimássemos": "ateimar",
    "ateimávamo": "ateimar",
    "ateimávamos": "ateimar",
    "ateimáveis": "ateimar",
    "ateio": "atear",
    "ateiras": "ateira",
    "ateirós": "ateiró",
    "ateis": "atar",
    "ateizações": "ateização",
    "atelanas": "atelana",
    "atelectasias": "atelectasia",
    "atelencefalias": "atelencefalia",
    "atelencéfala": "atelencéfalo",
    "atelencéfalas": "atelencéfalo",
    "atelencéfalos": "atelencéfalo",
    "ateliers": "atelier",
    "ateliês": "ateliê",
    "atelocardias": "atelocardia",
    "atelocárdica": "atelocárdico",
    "atelocárdicas": "atelocárdico",
    "atelocárdicos": "atelocárdico",
    "atelopodias": "atelopodia",
    "atelópodes": "atelópode",
    "atem": "atar",
    "atemo": "ater",
    "atemoriza": "atemorizar",
    "atemorizada": "atemorizar",
    "atemorizadas": "atemorizar",
    "atemorizado": "atemorizar",
    "atemorizadora": "atemorizador",
    "atemorizadoras": "atemorizador",
    "atemorizadores": "atemorizador",
    "atemorizados": "atemorizar",
    "atemorizadíssima": "atemorizado",
    "atemorizadíssimas": "atemorizado",
    "atemorizadíssimo": "atemorizado",
    "atemorizadíssimos": "atemorizado",
    "atemorizai": "atemorizar",
    "atemorizais": "atemorizar",
    "atemorizam": "atemorizar",
    "atemorizamentos": "atemorizamento",
    "atemorizamo": "atemorizar",
    "atemorizamos": "atemorizar",
    "atemorizando": "atemorizar",
    "atemorizara": "atemorizar",
    "atemorizaram": "atemorizar",
    "atemorizaras": "atemorizar",
    "atemorizarde": "atemorizar",
    "atemorizardes": "atemorizar",
    "atemorizare": "atemorizar",
    "atemorizarei": "atemorizar",
    "atemorizareis": "atemorizar",
    "atemorizarem": "atemorizar",
    "atemorizaremos": "atemorizar",
    "atemorizares": "atemorizar",
    "atemorizaria": "atemorizar",
    "atemorizariam": "atemorizar",
    "atemorizarias": "atemorizar",
    "atemorizarmo": "atemorizar",
    "atemorizarmos": "atemorizar",
    "atemorizará": "atemorizar",
    "atemorizarás": "atemorizar",
    "atemorizarão": "atemorizar",
    "atemorizaríamos": "atemorizar",
    "atemorizaríeis": "atemorizar",
    "atemorizas": "atemorizar",
    "atemorizasse": "atemorizar",
    "atemorizassem": "atemorizar",
    "atemorizasses": "atemorizar",
    "atemorizaste": "atemorizar",
    "atemorizastes": "atemorizar",
    "atemorizava": "atemorizar",
    "atemorizavam": "atemorizar",
    "atemorizavas": "atemorizar",
    "atemorizações": "atemorização",
    "atemorize": "atemorizar",
    "atemorizei": "atemorizar",
    "atemorizeis": "atemorizar",
    "atemorizem": "atemorizar",
    "atemorizemo": "atemorizar",
    "atemorizemos": "atemorizar",
    "atemorizes": "atemorizar",
    "atemorizo": "atemorizar",
    "atemorizou": "atemorizar",
    "atemorizá": "atemorizar",
    "atemorizámo": "atemorizar",
    "atemorizámos": "atemorizar",
    "atemorizáramo": "atemorizar",
    "atemorizáramos": "atemorizar",
    "atemorizárei": "atemorizar",
    "atemorizáreis": "atemorizar",
    "atemorizásseis": "atemorizar",
    "atemorizássemos": "atemorizar",
    "atemorizávamo": "atemorizar",
    "atemorizávamos": "atemorizar",
    "atemorizávei": "atemorizar",
    "atemorizáveis": "atemorizar",
    "atemos": "ater",
    "atempa": "atempar",
    "atempada": "atempar",
    "atempadas": "atempar",
    "atempado": "atempar",
    "atempados": "atempar",
    "atempai": "atempar",
    "atempais": "atempar",
    "atempam": "atempar",
    "atempamo": "atempar",
    "atempamos": "atempar",
    "atempando": "atempar",
    "atempara": "atempar",
    "atemparam": "atempar",
    "atemparas": "atempar",
    "atempardes": "atempar",
    "atemparei": "atempar",
    "atempareis": "atempar",
    "atemparem": "atempar",
    "atemparemos": "atempar",
    "atempares": "atempar",
    "atemparia": "atempar",
    "atempariam": "atempar",
    "atemparias": "atempar",
    "atemparmo": "atempar",
    "atemparmos": "atempar",
    "atempará": "atempar",
    "atemparás": "atempar",
    "atemparão": "atempar",
    "atemparíamos": "atempar",
    "atemparíeis": "atempar",
    "atempas": "atempar",
    "atempasse": "atempar",
    "atempassem": "atempar",
    "atempasses": "atempar",
    "atempaste": "atempar",
    "atempastes": "atempar",
    "atempava": "atempar",
    "atempavam": "atempar",
    "atempavas": "atempar",
    "atempações": "atempação",
    "atempe": "atempar",
    "atempei": "atempar",
    "atempeis": "atempar",
    "atempem": "atempar",
    "atempemo": "atempar",
    "atempemos": "atempar",
    "atempes": "atempar",
    "atempo": "atempar",
    "atemporais": "atemporal",
    "atempou": "atempar",
    "atempámo": "atempar",
    "atempámos": "atempar",
    "atempáramo": "atempar",
    "atempáramos": "atempar",
    "atempáreis": "atempar",
    "atempásseis": "atempar",
    "atempássemos": "atempar",
    "atempávamo": "atempar",
    "atempávamos": "atempar",
    "atempáveis": "atempar",
    "atenaza": "atenazar",
    "atenazada": "atenazar",
    "atenazadas": "atenazar",
    "atenazado": "atenazar",
    "atenazados": "atenazar",
    "atenazai": "atenazar",
    "atenazais": "atenazar",
    "atenazam": "atenazar",
    "atenazamo": "atenazar",
    "atenazamos": "atenazar",
    "atenazando": "atenazar",
    "atenazara": "atenazar",
    "atenazaram": "atenazar",
    "atenazaras": "atenazar",
    "atenazarde": "atenazar",
    "atenazardes": "atenazar",
    "atenazare": "atenazar",
    "atenazarei": "atenazar",
    "atenazareis": "atenazar",
    "atenazarem": "atenazar",
    "atenazaremos": "atenazar",
    "atenazares": "atenazar",
    "atenazaria": "atenazar",
    "atenazariam": "atenazar",
    "atenazarias": "atenazar",
    "atenazarmo": "atenazar",
    "atenazarmos": "atenazar",
    "atenazará": "atenazar",
    "atenazarás": "atenazar",
    "atenazarão": "atenazar",
    "atenazaríamos": "atenazar",
    "atenazaríeis": "atenazar",
    "atenazas": "atenazar",
    "atenazasse": "atenazar",
    "atenazassem": "atenazar",
    "atenazasses": "atenazar",
    "atenazaste": "atenazar",
    "atenazastes": "atenazar",
    "atenazava": "atenazar",
    "atenazavam": "atenazar",
    "atenazavas": "atenazar",
    "atenaze": "atenazar",
    "atenazei": "atenazar",
    "atenazeis": "atenazar",
    "atenazem": "atenazar",
    "atenazemo": "atenazar",
    "atenazemos": "atenazar",
    "atenazes": "atenazar",
    "atenazo": "atenazar",
    "atenazou": "atenazar",
    "atenazá": "atenazar",
    "atenazámo": "atenazar",
    "atenazámos": "atenazar",
    "atenazáramo": "atenazar",
    "atenazáramos": "atenazar",
    "atenazárei": "atenazar",
    "atenazáreis": "atenazar",
    "atenazásseis": "atenazar",
    "atenazássemos": "atenazar",
    "atenazávamo": "atenazar",
    "atenazávamos": "atenazar",
    "atenazávei": "atenazar",
    "atenazáveis": "atenazar",
    "atenciosa": "atencioso",
    "atenciosas": "atencioso",
    "atenciosos": "atencioso",
    "atenciosíssima": "atencioso",
    "atenciosíssimas": "atencioso",
    "atenciosíssimo": "atencioso",
    "atenciosíssimos": "atencioso",
    "atenda": "atender",
    "atendais": "atender",
    "atendam": "atender",
    "atendamo": "atender",
    "atendamos": "atender",
    "atendas": "atender",
    "atende": "ater",
    "atendedora": "atendedor",
    "atendedoras": "atendedor",
    "atendedores": "atendedor",
    "atendei": "atender",
    "atendeis": "atender",
    "atendem": "atender",
    "atendemo": "atender",
    "atendemos": "atender",
    "atendendo": "atender",
    "atendera": "atender",
    "atenderam": "atender",
    "atenderas": "atender",
    "atenderde": "atender",
    "atenderdes": "atender",
    "atendere": "atender",
    "atenderei": "atender",
    "atendereis": "atender",
    "atenderem": "atender",
    "atenderemos": "atender",
    "atenderes": "atender",
    "atenderia": "atender",
    "atenderiam": "atender",
    "atenderias": "atender",
    "atendermo": "atender",
    "atendermos": "atender",
    "atenderá": "atender",
    "atenderás": "atender",
    "atenderão": "atender",
    "atenderíamos": "atender",
    "atenderíeis": "atender",
    "atendes": "ater",
    "atendesse": "atender",
    "atendessem": "atender",
    "atendesses": "atender",
    "atendeste": "atender",
    "atendestes": "atender",
    "atendeu": "atender",
    "atendi": "atender",
    "atendia": "atender",
    "atendiam": "atender",
    "atendias": "atender",
    "atendida": "atendido",
    "atendidas": "atendido",
    "atendido": "atender",
    "atendidos": "atendido",
    "atendimentos": "atendimento",
    "atendo": "ater",
    "atendê": "atender",
    "atendêramo": "atender",
    "atendêramos": "atender",
    "atendêrei": "atender",
    "atendêreis": "atender",
    "atendêsseis": "atender",
    "atendêssemos": "atender",
    "atendíamo": "atender",
    "atendíamos": "atender",
    "atendíei": "atender",
    "atendíeis": "atender",
    "atendíveis": "atendível",
    "ateneus": "ateneu",
    "atenha": "ater",
    "atenhais": "ater",
    "atenham": "ater",
    "atenhamo": "ater",
    "atenhamos": "ater",
    "atenhas": "ater",
    "atenho": "ater",
    "atenienses": "ateniense",
    "atenta": "atento",
    "atentada": "atentar",
    "atentadas": "atentar",
    "atentado": "atentar",
    "atentados": "atentar",
    "atentai": "atentar",
    "atentais": "atentar",
    "atentam": "atentar",
    "atentamo": "atentar",
    "atentamos": "atentar",
    "atentando": "atentar",
    "atentara": "atentar",
    "atentaram": "atentar",
    "atentaras": "atentar",
    "atentarde": "atentar",
    "atentardes": "atentar",
    "atentare": "atentar",
    "atentarei": "atentar",
    "atentareis": "atentar",
    "atentarem": "atentar",
    "atentaremos": "atentar",
    "atentares": "atentar",
    "atentaria": "atentar",
    "atentariam": "atentar",
    "atentarias": "atentar",
    "atentarmo": "atentar",
    "atentarmos": "atentar",
    "atentará": "atentar",
    "atentarás": "atentar",
    "atentarão": "atentar",
    "atentaríamos": "atentar",
    "atentaríeis": "atentar",
    "atentas": "atento",
    "atentasse": "atentar",
    "atentassem": "atentar",
    "atentasses": "atentar",
    "atentaste": "atentar",
    "atentastes": "atentar",
    "atentatória": "atentatório",
    "atentatórias": "atentatório",
    "atentatórios": "atentatório",
    "atentava": "atentar",
    "atentavam": "atentar",
    "atentavas": "atentar",
    "atente": "atentar",
    "atentei": "atentar",
    "atenteis": "atentar",
    "atentem": "atentar",
    "atentemo": "atentar",
    "atentemos": "atentar",
    "atentes": "atentar",
    "atentiva": "atentivo",
    "atentivas": "atentivo",
    "atentivazinha": "atentivo",
    "atentivazinhas": "atentivo",
    "atentivazita": "atentivo",
    "atentivazitas": "atentivo",
    "atentivos": "atentivo",
    "atentivozinho": "atentivo",
    "atentivozinhos": "atentivo",
    "atentivozito": "atentivo",
    "atentivozitos": "atentivo",
    "atento": "atentar",
    "atentos": "atento",
    "atentou": "atentar",
    "atentá": "atentar",
    "atentámo": "atentar",
    "atentámos": "atentar",
    "atentáramo": "atentar",
    "atentáramos": "atentar",
    "atentárei": "atentar",
    "atentáreis": "atentar",
    "atentásseis": "atentar",
    "atentássemos": "atentar",
    "atentávamo": "atentar",
    "atentávamos": "atentar",
    "atentávei": "atentar",
    "atentáveis": "atentar",
    "atentíssima": "atento",
    "atentíssimas": "atento",
    "atentíssimo": "atento",
    "atentíssimos": "atento",
    "atenua": "atenuar",
    "atenuada": "atenuar",
    "atenuadas": "atenuar",
    "atenuado": "atenuar",
    "atenuadora": "atenuador",
    "atenuadoras": "atenuador",
    "atenuadores": "atenuador",
    "atenuados": "atenuar",
    "atenuai": "atenuar",
    "atenuais": "atenuar",
    "atenuam": "atenuar",
    "atenuamo": "atenuar",
    "atenuamos": "atenuar",
    "atenuando": "atenuar",
    "atenuantes": "atenuante",
    "atenuara": "atenuar",
    "atenuaram": "atenuar",
    "atenuaras": "atenuar",
    "atenuarde": "atenuar",
    "atenuardes": "atenuar",
    "atenuare": "atenuar",
    "atenuarei": "atenuar",
    "atenuareis": "atenuar",
    "atenuarem": "atenuar",
    "atenuaremos": "atenuar",
    "atenuares": "atenuar",
    "atenuaria": "atenuar",
    "atenuariam": "atenuar",
    "atenuarias": "atenuar",
    "atenuarmo": "atenuar",
    "atenuarmos": "atenuar",
    "atenuará": "atenuar",
    "atenuarás": "atenuar",
    "atenuarão": "atenuar",
    "atenuaríamos": "atenuar",
    "atenuaríeis": "atenuar",
    "atenuas": "atenuar",
    "atenuasse": "atenuar",
    "atenuassem": "atenuar",
    "atenuasses": "atenuar",
    "atenuaste": "atenuar",
    "atenuastes": "atenuar",
    "atenuativa": "atenuativo",
    "atenuativas": "atenuativo",
    "atenuativos": "atenuativo",
    "atenuava": "atenuar",
    "atenuavam": "atenuar",
    "atenuavas": "atenuar",
    "atenuações": "atenuação",
    "atenue": "atenuar",
    "atenuei": "atenuar",
    "atenueis": "atenuar",
    "atenuem": "atenuar",
    "atenuemo": "atenuar",
    "atenuemos": "atenuar",
    "atenues": "atenuar",
    "atenuo": "atenuar",
    "atenuou": "atenuar",
    "atenuá": "atenuar",
    "atenuámo": "atenuar",
    "atenuámos": "atenuar",
    "atenuáramo": "atenuar",
    "atenuáramos": "atenuar",
    "atenuárei": "atenuar",
    "atenuáreis": "atenuar",
    "atenuásseis": "atenuar",
    "atenuássemos": "atenuar",
    "atenuávamo": "atenuar",
    "atenuávamos": "atenuar",
    "atenuávei": "atenuar",
    "atenuáveis": "atenuável",
    "atenças": "atença",
    "atenções": "atenção",
    "ateou": "atear",
    "aterde": "ater",
    "aterdes": "ater",
    "atere": "ater",
    "aterei": "ater",
    "atereis": "ater",
    "aterem": "ater",
    "ateremos": "ater",
    "ateres": "ater",
    "ateria": "ater",
    "ateriam": "ater",
    "aterias": "ater",
    "atermais": "atermal",
    "atermias": "atermia",
    "atermo": "ater",
    "atermos": "ater",
    "ateromas": "ateroma",
    "ateromatosa": "ateromatoso",
    "ateromatosas": "ateromatoso",
    "ateromatosos": "ateromatoso",
    "aterra": "aterrar",
    "aterrada": "aterrar",
    "aterradas": "aterrar",
    "aterrado": "aterrar",
    "aterradora": "aterrador",
    "aterradoras": "aterrador",
    "aterradores": "aterrador",
    "aterrados": "aterrar",
    "aterradíssima": "aterrado",
    "aterradíssimas": "aterrado",
    "aterradíssimo": "aterrado",
    "aterradíssimos": "aterrado",
    "aterragens": "aterragem",
    "aterrai": "aterrar",
    "aterrais": "aterrar",
    "aterram": "aterrar",
    "aterramo": "aterrar",
    "aterramos": "aterrar",
    "aterrando": "aterrar",
    "aterraplena": "aterraplenar",
    "aterraplenada": "aterraplenar",
    "aterraplenadas": "aterraplenar",
    "aterraplenado": "aterraplenar",
    "aterraplenados": "aterraplenar",
    "aterraplenai": "aterraplenar",
    "aterraplenais": "aterraplenar",
    "aterraplenam": "aterraplenar",
    "aterraplenamo": "aterraplenar",
    "aterraplenamos": "aterraplenar",
    "aterraplenando": "aterraplenar",
    "aterraplenara": "aterraplenar",
    "aterraplenaram": "aterraplenar",
    "aterraplenaras": "aterraplenar",
    "aterraplenarde": "aterraplenar",
    "aterraplenardes": "aterraplenar",
    "aterraplenare": "aterraplenar",
    "aterraplenarei": "aterraplenar",
    "aterraplenareis": "aterraplenar",
    "aterraplenarem": "aterraplenar",
    "aterraplenaremos": "aterraplenar",
    "aterraplenares": "aterraplenar",
    "aterraplenaria": "aterraplenar",
    "aterraplenariam": "aterraplenar",
    "aterraplenarias": "aterraplenar",
    "aterraplenarmo": "aterraplenar",
    "aterraplenarmos": "aterraplenar",
    "aterraplenará": "aterraplenar",
    "aterraplenarás": "aterraplenar",
    "aterraplenarão": "aterraplenar",
    "aterraplenaríamos": "aterraplenar",
    "aterraplenaríeis": "aterraplenar",
    "aterraplenas": "aterraplenar",
    "aterraplenasse": "aterraplenar",
    "aterraplenassem": "aterraplenar",
    "aterraplenasses": "aterraplenar",
    "aterraplenaste": "aterraplenar",
    "aterraplenastes": "aterraplenar",
    "aterraplenava": "aterraplenar",
    "aterraplenavam": "aterraplenar",
    "aterraplenavas": "aterraplenar",
    "aterraplene": "aterraplenar",
    "aterraplenei": "aterraplenar",
    "aterrapleneis": "aterraplenar",
    "aterraplenem": "aterraplenar",
    "aterraplenemo": "aterraplenar",
    "aterraplenemos": "aterraplenar",
    "aterraplenes": "aterraplenar",
    "aterrapleno": "aterraplenar",
    "aterraplenou": "aterraplenar",
    "aterraplená": "aterraplenar",
    "aterraplenámo": "aterraplenar",
    "aterraplenámos": "aterraplenar",
    "aterraplenáramo": "aterraplenar",
    "aterraplenáramos": "aterraplenar",
    "aterraplenárei": "aterraplenar",
    "aterraplenáreis": "aterraplenar",
    "aterraplenásseis": "aterraplenar",
    "aterraplenássemos": "aterraplenar",
    "aterraplenávamo": "aterraplenar",
    "aterraplenávamos": "aterraplenar",
    "aterraplenávei": "aterraplenar",
    "aterraplenáveis": "aterraplenar",
    "aterrara": "aterrar",
    "aterraram": "aterrar",
    "aterraras": "aterrar",
    "aterrarde": "aterrar",
    "aterrardes": "aterrar",
    "aterrare": "aterrar",
    "aterrarei": "aterrar",
    "aterrareis": "aterrar",
    "aterrarem": "aterrar",
    "aterraremos": "aterrar",
    "aterrares": "aterrar",
    "aterraria": "aterrar",
    "aterrariam": "aterrar",
    "aterrarias": "aterrar",
    "aterrarmo": "aterrar",
    "aterrarmos": "aterrar",
    "aterrará": "aterrar",
    "aterrarás": "aterrar",
    "aterrarão": "aterrar",
    "aterraríamos": "aterrar",
    "aterraríeis": "aterrar",
    "aterras": "aterrar",
    "aterrasse": "aterrar",
    "aterrassem": "aterrar",
    "aterrasses": "aterrar",
    "aterraste": "aterrar",
    "aterrastes": "aterrar",
    "aterrava": "aterrar",
    "aterravam": "aterrar",
    "aterravas": "aterrar",
    "aterre": "aterrar",
    "aterrei": "aterrar",
    "aterreis": "aterrar",
    "aterrem": "aterrar",
    "aterremo": "aterrar",
    "aterremos": "aterrar",
    "aterres": "aterrar",
    "aterrissagens": "aterrissagem",
    "aterro": "aterrar",
    "aterroriza": "aterrorizar",
    "aterrorizada": "aterrorizar",
    "aterrorizadas": "aterrorizar",
    "aterrorizado": "aterrorizar",
    "aterrorizadora": "aterrorizador",
    "aterrorizadoras": "aterrorizador",
    "aterrorizadores": "aterrorizador",
    "aterrorizados": "aterrorizar",
    "aterrorizadíssima": "aterrorizado",
    "aterrorizadíssimas": "aterrorizado",
    "aterrorizadíssimo": "aterrorizado",
    "aterrorizadíssimos": "aterrorizado",
    "aterrorizai": "aterrorizar",
    "aterrorizais": "aterrorizar",
    "aterrorizam": "aterrorizar",
    "aterrorizamo": "aterrorizar",
    "aterrorizamos": "aterrorizar",
    "aterrorizando": "aterrorizar",
    "aterrorizantes": "aterrorizante",
    "aterrorizara": "aterrorizar",
    "aterrorizaram": "aterrorizar",
    "aterrorizaras": "aterrorizar",
    "aterrorizarde": "aterrorizar",
    "aterrorizardes": "aterrorizar",
    "aterrorizare": "aterrorizar",
    "aterrorizarei": "aterrorizar",
    "aterrorizareis": "aterrorizar",
    "aterrorizarem": "aterrorizar",
    "aterrorizaremos": "aterrorizar",
    "aterrorizares": "aterrorizar",
    "aterrorizaria": "aterrorizar",
    "aterrorizariam": "aterrorizar",
    "aterrorizarias": "aterrorizar",
    "aterrorizarmo": "aterrorizar",
    "aterrorizarmos": "aterrorizar",
    "aterrorizará": "aterrorizar",
    "aterrorizarás": "aterrorizar",
    "aterrorizarão": "aterrorizar",
    "aterrorizaríamos": "aterrorizar",
    "aterrorizaríeis": "aterrorizar",
    "aterrorizas": "aterrorizar",
    "aterrorizasse": "aterrorizar",
    "aterrorizassem": "aterrorizar",
    "aterrorizasses": "aterrorizar",
    "aterrorizaste": "aterrorizar",
    "aterrorizastes": "aterrorizar",
    "aterrorizava": "aterrorizar",
    "aterrorizavam": "aterrorizar",
    "aterrorizavas": "aterrorizar",
    "aterrorize": "aterrorizar",
    "aterrorizei": "aterrorizar",
    "aterrorizeis": "aterrorizar",
    "aterrorizem": "aterrorizar",
    "aterrorizemo": "aterrorizar",
    "aterrorizemos": "aterrorizar",
    "aterrorizes": "aterrorizar",
    "aterrorizo": "aterrorizar",
    "aterrorizou": "aterrorizar",
    "aterrorizá": "aterrorizar",
    "aterrorizámo": "aterrorizar",
    "aterrorizámos": "aterrorizar",
    "aterrorizáramo": "aterrorizar",
    "aterrorizáramos": "aterrorizar",
    "aterrorizárei": "aterrorizar",
    "aterrorizáreis": "aterrorizar",
    "aterrorizásseis": "aterrorizar",
    "aterrorizássemos": "aterrorizar",
    "aterrorizávamo": "aterrorizar",
    "aterrorizávamos": "aterrorizar",
    "aterrorizávei": "aterrorizar",
    "aterrorizáveis": "aterrorizar",
    "aterros": "aterro",
    "aterrou": "aterrar",
    "aterruadas": "aterruada",
    "aterrá": "aterrar",
    "aterrámo": "aterrar",
    "aterrámos": "aterrar",
    "aterráramo": "aterrar",
    "aterráramos": "aterrar",
    "aterrárei": "aterrar",
    "aterráreis": "aterrar",
    "aterrásseis": "aterrar",
    "aterrássemos": "aterrar",
    "aterrávamo": "aterrar",
    "aterrávamos": "aterrar",
    "aterrávei": "aterrar",
    "aterráveis": "aterrar",
    "aterá": "ater",
    "aterás": "ater",
    "aterão": "ater",
    "ateríamos": "ater",
    "ateríeis": "ater",
    "ates": "atar",
    "atesta": "atestar",
    "atestada": "atestar",
    "atestadas": "atestar",
    "atestadinha": "atestado",
    "atestadinhas": "atestado",
    "atestadinho": "atestado",
    "atestadinhos": "atestado",
    "atestadita": "atestado",
    "atestaditas": "atestado",
    "atestadito": "atestado",
    "atestaditos": "atestado",
    "atestado": "atestar",
    "atestadora": "atestador",
    "atestadoras": "atestador",
    "atestadores": "atestador",
    "atestados": "atestar",
    "atestaduras": "atestadura",
    "atestadíssima": "atestado",
    "atestadíssimas": "atestado",
    "atestadíssimo": "atestado",
    "atestadíssimos": "atestado",
    "atestai": "atestar",
    "atestais": "atestar",
    "atestam": "atestar",
    "atestamentos": "atestamento",
    "atestamo": "atestar",
    "atestamos": "atestar",
    "atestando": "atestar",
    "atestantes": "atestante",
    "atestara": "atestar",
    "atestaram": "atestar",
    "atestaras": "atestar",
    "atestarde": "atestar",
    "atestardes": "atestar",
    "atestare": "atestar",
    "atestarei": "atestar",
    "atestareis": "atestar",
    "atestarem": "atestar",
    "atestaremos": "atestar",
    "atestares": "atestar",
    "atestaria": "atestar",
    "atestariam": "atestar",
    "atestarias": "atestar",
    "atestarmo": "atestar",
    "atestarmos": "atestar",
    "atestará": "atestar",
    "atestarás": "atestar",
    "atestarão": "atestar",
    "atestaríamos": "atestar",
    "atestaríeis": "atestar",
    "atestas": "atestar",
    "atestasse": "atestar",
    "atestassem": "atestar",
    "atestasses": "atestar",
    "atestaste": "atestar",
    "atestastes": "atestar",
    "atestava": "atestar",
    "atestavam": "atestar",
    "atestavas": "atestar",
    "atestações": "atestação",
    "ateste": "atestar",
    "atestei": "atestar",
    "atesteis": "atestar",
    "atestem": "atestar",
    "atestemo": "atestar",
    "atestemos": "atestar",
    "atestes": "atestar",
    "atesto": "atestar",
    "atestos": "atesto",
    "atestou": "atestar",
    "atestá": "atestar",
    "atestámo": "atestar",
    "atestámos": "atestar",
    "atestáramo": "atestar",
    "atestáramos": "atestar",
    "atestárei": "atestar",
    "atestáreis": "atestar",
    "atestásseis": "atestar",
    "atestássemos": "atestar",
    "atestávamo": "atestar",
    "atestávamos": "atestar",
    "atestávei": "atestar",
    "atestáveis": "atestar",
    "atetoses": "atetose",
    "ateus": "ateu",
    "ateve": "ater",
    "atextos": "atexto",
    "ateá": "atear",
    "ateámo": "atear",
    "ateámos": "atear",
    "ateáramo": "atear",
    "ateáramos": "atear",
    "ateárei": "atear",
    "ateáreis": "atear",
    "ateásseis": "atear",
    "ateássemos": "atear",
    "ateávamo": "atear",
    "ateávamos": "atear",
    "ateávei": "atear",
    "ateáveis": "atear",
    "ateísmos": "ateísmo",
    "ateístas": "ateísta",
    "ateística": "ateístico",
    "ateísticas": "ateístico",
    "ateísticos": "ateístico",
    "atice": "atiçar",
    "aticei": "atiçar",
    "aticeis": "atiçar",
    "aticem": "atiçar",
    "aticemo": "atiçar",
    "aticemos": "atiçar",
    "atices": "atiçar",
    "aticismos": "aticismo",
    "aticistas": "aticista",
    "aticurga": "aticurgo",
    "aticurgas": "aticurgo",
    "aticurgos": "aticurgo",
    "atida": "atido",
    "atidas": "atido",
    "atido": "ater",
    "atidos": "atido",
    "atigrada": "atigrado",
    "atigradas": "atigrado",
    "atigrados": "atigrado",
    "atijolada": "atijolado",
    "atijoladas": "atijolado",
    "atijolados": "atijolado",
    "atilada": "atilado",
    "atiladas": "atilado",
    "atiladinha": "atilado",
    "atiladinhas": "atilado",
    "atiladinho": "atilado",
    "atiladinhos": "atilado",
    "atiladita": "atilado",
    "atiladitas": "atilado",
    "atiladito": "atilado",
    "atiladitos": "atilado",
    "atilados": "atilado",
    "atiladíssima": "atilado",
    "atiladíssimas": "atilado",
    "atiladíssimo": "atilado",
    "atiladíssimos": "atilado",
    "atilhos": "atilho",
    "atina": "atinar",
    "atinada": "atinar",
    "atinadas": "atinar",
    "atinadinha": "atinado",
    "atinadinhas": "atinado",
    "atinadinho": "atinado",
    "atinadinhos": "atinado",
    "atinadita": "atinado",
    "atinaditas": "atinado",
    "atinadito": "atinado",
    "atinaditos": "atinado",
    "atinado": "atinar",
    "atinados": "atinar",
    "atinadíssima": "atinado",
    "atinadíssimas": "atinado",
    "atinadíssimo": "atinado",
    "atinadíssimos": "atinado",
    "atinai": "atinar",
    "atinais": "atinar",
    "atinam": "atinar",
    "atinamo": "atinar",
    "atinamos": "atinar",
    "atinando": "atinar",
    "atinara": "atinar",
    "atinaram": "atinar",
    "atinaras": "atinar",
    "atinardes": "atinar",
    "atinarei": "atinar",
    "atinareis": "atinar",
    "atinarem": "atinar",
    "atinaremos": "atinar",
    "atinares": "atinar",
    "atinaria": "atinar",
    "atinariam": "atinar",
    "atinarias": "atinar",
    "atinarmo": "atinar",
    "atinarmos": "atinar",
    "atinará": "atinar",
    "atinarás": "atinar",
    "atinarão": "atinar",
    "atinaríamos": "atinar",
    "atinaríeis": "atinar",
    "atinas": "atinar",
    "atinasse": "atinar",
    "atinassem": "atinar",
    "atinasses": "atinar",
    "atinaste": "atinar",
    "atinastes": "atinar",
    "atinava": "atinar",
    "atinavam": "atinar",
    "atinavas": "atinar",
    "atine": "atinar",
    "atinei": "atinar",
    "atineis": "atinar",
    "atinem": "atinar",
    "atinemo": "atinar",
    "atinemos": "atinar",
    "atinentes": "atinente",
    "atines": "atinar",
    "atinge": "atingir",
    "atingem": "atingir",
    "atinges": "atingir",
    "atingi": "atingir",
    "atingia": "atingir",
    "atingiam": "atingir",
    "atingias": "atingir",
    "atingida": "atingir",
    "atingidas": "atingir",
    "atingido": "atingir",
    "atingidos": "atingir",
    "atingimo": "atingir",
    "atingimos": "atingir",
    "atingindo": "atingir",
    "atingira": "atingir",
    "atingiram": "atingir",
    "atingiras": "atingir",
    "atingirde": "atingir",
    "atingirdes": "atingir",
    "atingire": "atingir",
    "atingirei": "atingir",
    "atingireis": "atingir",
    "atingirem": "atingir",
    "atingiremos": "atingir",
    "atingires": "atingir",
    "atingiria": "atingir",
    "atingiriam": "atingir",
    "atingirias": "atingir",
    "atingirmo": "atingir",
    "atingirmos": "atingir",
    "atingirá": "atingir",
    "atingirás": "atingir",
    "atingirão": "atingir",
    "atingiríamos": "atingir",
    "atingiríeis": "atingir",
    "atingis": "atingir",
    "atingisse": "atingir",
    "atingissem": "atingir",
    "atingisses": "atingir",
    "atingiste": "atingir",
    "atingistes": "atingir",
    "atingiu": "atingir",
    "atingíamo": "atingir",
    "atingíamos": "atingir",
    "atingíei": "atingir",
    "atingíeis": "atingir",
    "atingíramo": "atingir",
    "atingíramos": "atingir",
    "atingírei": "atingir",
    "atingíreis": "atingir",
    "atingísseis": "atingir",
    "atingíssemos": "atingir",
    "atingíveis": "atingível",
    "atinha": "ater",
    "atinham": "ater",
    "atinhas": "ater",
    "atinias": "atinia",
    "atinja": "atingir",
    "atinjais": "atingir",
    "atinjam": "atingir",
    "atinjamo": "atingir",
    "atinjamos": "atingir",
    "atinjas": "atingir",
    "atinjo": "atingir",
    "atino": "atinar",
    "atinos": "atino",
    "atinou": "atinar",
    "atins": "atim",
    "atinámo": "atinar",
    "atinámos": "atinar",
    "atináramo": "atinar",
    "atináramos": "atinar",
    "atináreis": "atinar",
    "atinásseis": "atinar",
    "atinássemos": "atinar",
    "atinávamo": "atinar",
    "atinávamos": "atinar",
    "atináveis": "atinar",
    "atipias": "atipia",
    "atipicidades": "atipicidade",
    "atiplada": "atiplado",
    "atipladas": "atiplado",
    "atiplados": "atiplado",
    "atira": "atirar",
    "atirada": "atirar",
    "atiradas": "atirar",
    "atiradeira": "atirador",
    "atiradeiras": "atirador",
    "atiradiça": "atiradiço",
    "atiradiças": "atiradiço",
    "atiradiços": "atiradiço",
    "atirado": "atirar",
    "atiradora": "atirador",
    "atiradoras": "atirador",
    "atiradores": "atirador",
    "atirados": "atirar",
    "atirai": "atirar",
    "atirais": "atirar",
    "atiram": "atirar",
    "atiramo": "atirar",
    "atiramos": "atirar",
    "atirando": "atirar",
    "atirara": "atirar",
    "atiraram": "atirar",
    "atiraras": "atirar",
    "atirarde": "atirar",
    "atirardes": "atirar",
    "atirare": "atirar",
    "atirarei": "atirar",
    "atirareis": "atirar",
    "atirarem": "atirar",
    "atiraremos": "atirar",
    "atirares": "atirar",
    "atiraria": "atirar",
    "atirariam": "atirar",
    "atirarias": "atirar",
    "atirarmo": "atirar",
    "atirarmos": "atirar",
    "atirará": "atirar",
    "atirarás": "atirar",
    "atirarão": "atirar",
    "atiraríamos": "atirar",
    "atiraríeis": "atirar",
    "atiras": "atirar",
    "atirasse": "atirar",
    "atirassem": "atirar",
    "atirasses": "atirar",
    "atiraste": "atirar",
    "atirastes": "atirar",
    "atirava": "atirar",
    "atiravam": "atirar",
    "atiravas": "atirar",
    "atire": "atirar",
    "atirei": "atirar",
    "atireis": "atirar",
    "atirem": "atirar",
    "atiremo": "atirar",
    "atiremos": "atirar",
    "atires": "atirar",
    "atiro": "atirar",
    "atirou": "atirar",
    "atirá": "atirar",
    "atirámo": "atirar",
    "atirámos": "atirar",
    "atiráramo": "atirar",
    "atiráramos": "atirar",
    "atirárei": "atirar",
    "atiráreis": "atirar",
    "atirásseis": "atirar",
    "atirássemos": "atirar",
    "atirávamo": "atirar",
    "atirávamos": "atirar",
    "atirávei": "atirar",
    "atiráveis": "atirar",
    "atitos": "atito",
    "atitudes": "atitude",
    "ativas": "ativa",
    "ative": "ater",
    "ativemo": "ater",
    "ativemos": "ater",
    "ativer": "ater",
    "ativera": "ater",
    "ativeram": "ater",
    "ativeras": "ater",
    "ativerdes": "ater",
    "ativerem": "ater",
    "ativeres": "ater",
    "ativermos": "ater",
    "ativesse": "ater",
    "ativessem": "ater",
    "ativesses": "ater",
    "ativeste": "ater",
    "ativestes": "ater",
    "ativéramo": "ater",
    "ativéramos": "ater",
    "ativérei": "ater",
    "ativéreis": "ater",
    "ativésseis": "ater",
    "ativéssemos": "ater",
    "atiça": "atiçar",
    "atiçada": "atiçar",
    "atiçadas": "atiçar",
    "atiçado": "atiçar",
    "atiçadora": "atiçador",
    "atiçadoras": "atiçador",
    "atiçadores": "atiçador",
    "atiçados": "atiçar",
    "atiçadíssima": "atiçado",
    "atiçadíssimas": "atiçado",
    "atiçadíssimo": "atiçado",
    "atiçadíssimos": "atiçado",
    "atiçai": "atiçar",
    "atiçais": "atiçar",
    "atiçam": "atiçar",
    "atiçamentos": "atiçamento",
    "atiçamo": "atiçar",
    "atiçamos": "atiçar",
    "atiçando": "atiçar",
    "atiçara": "atiçar",
    "atiçaram": "atiçar",
    "atiçaras": "atiçar",
    "atiçarde": "atiçar",
    "atiçardes": "atiçar",
    "atiçare": "atiçar",
    "atiçarei": "atiçar",
    "atiçareis": "atiçar",
    "atiçarem": "atiçar",
    "atiçaremos": "atiçar",
    "atiçares": "atiçar",
    "atiçaria": "atiçar",
    "atiçariam": "atiçar",
    "atiçarias": "atiçar",
    "atiçarmo": "atiçar",
    "atiçarmos": "atiçar",
    "atiçará": "atiçar",
    "atiçarás": "atiçar",
    "atiçarão": "atiçar",
    "atiçaríamos": "atiçar",
    "atiçaríeis": "atiçar",
    "atiças": "atiçar",
    "atiçasse": "atiçar",
    "atiçassem": "atiçar",
    "atiçasses": "atiçar",
    "atiçaste": "atiçar",
    "atiçastes": "atiçar",
    "atiçava": "atiçar",
    "atiçavam": "atiçar",
    "atiçavas": "atiçar",
    "atiçações": "atiçação",
    "atiço": "atiçar",
    "atiçou": "atiçar",
    "atiçá": "atiçar",
    "atiçámo": "atiçar",
    "atiçámos": "atiçar",
    "atiçáramo": "atiçar",
    "atiçáramos": "atiçar",
    "atiçárei": "atiçar",
    "atiçáreis": "atiçar",
    "atiçásseis": "atiçar",
    "atiçássemos": "atiçar",
    "atiçávamo": "atiçar",
    "atiçávamos": "atiçar",
    "atiçávei": "atiçar",
    "atiçáveis": "atiçar",
    "atlantes": "atlante",
    "atlantismos": "atlantismo",
    "atletas": "atleta",
    "atletismos": "atletismo",
    "atlântica": "atlântico",
    "atlânticas": "atlântico",
    "atlânticos": "atlântico",
    "atlética": "atlético",
    "atléticas": "atlético",
    "atléticos": "atlético",
    "atlóides": "atlóide",
    "atlótedas": "atlóteda",
    "atmiatrias": "atmiatria",
    "atmidiatrias": "atmidiatria",
    "atmidométrica": "atmidométrico",
    "atmidométricas": "atmidométrico",
    "atmidométricos": "atmidométrico",
    "atmidómetros": "atmidómetro",
    "atmometrias": "atmometria",
    "atmométrica": "atmométrico",
    "atmométricas": "atmométrico",
    "atmométricos": "atmométrico",
    "atmosferas": "atmosfera",
    "atmosferografias": "atmosferografia",
    "atmosférica": "atmosférico",
    "atmosféricas": "atmosférico",
    "atmosféricos": "atmosférico",
    "atmófila": "atmófilo",
    "atmófilas": "atmófilo",
    "atmófilos": "atmófilo",
    "atmólises": "atmólise",
    "atmómetros": "atmómetro",
    "ato": "atar",
    "atoadas": "atoada",
    "atoagens": "atoagem",
    "atoalhada": "atoalhado",
    "atoalhadas": "atoalhado",
    "atoalhados": "atoalhado",
    "atoardas": "atoarda",
    "atochada": "atochado",
    "atochadas": "atochado",
    "atochadora": "atochador",
    "atochadoras": "atochador",
    "atochadores": "atochador",
    "atochados": "atochado",
    "atochos": "atocho",
    "atocias": "atocia",
    "atola": "atolar",
    "atolada": "atolar",
    "atoladas": "atolar",
    "atoladeiros": "atoladeiro",
    "atoladelas": "atoladela",
    "atoladiça": "atoladiço",
    "atoladiças": "atoladiço",
    "atoladiços": "atoladiço",
    "atolado": "atolar",
    "atoladoiros": "atoladoiro",
    "atolados": "atolar",
    "atoladouros": "atoladouro",
    "atolai": "atolar",
    "atolais": "atolar",
    "atolam": "atolar",
    "atolamo": "atolar",
    "atolamos": "atolar",
    "atolando": "atolar",
    "atolara": "atolar",
    "atolaram": "atolar",
    "atolaras": "atolar",
    "atolarde": "atolar",
    "atolardes": "atolar",
    "atolare": "atolar",
    "atolarei": "atolar",
    "atolareis": "atolar",
    "atolarem": "atolar",
    "atolaremos": "atolar",
    "atolares": "atolar",
    "atolaria": "atolar",
    "atolariam": "atolar",
    "atolarias": "atolar",
    "atolarmo": "atolar",
    "atolarmos": "atolar",
    "atolará": "atolar",
    "atolarás": "atolar",
    "atolarão": "atolar",
    "atolaríamos": "atolar",
    "atolaríeis": "atolar",
    "atolas": "atolar",
    "atolasse": "atolar",
    "atolassem": "atolar",
    "atolasses": "atolar",
    "atolaste": "atolar",
    "atolastes": "atolar",
    "atolava": "atolar",
    "atolavam": "atolar",
    "atolavas": "atolar",
    "atole": "atolar",
    "atolei": "atolar",
    "atoleimada": "atoleimado",
    "atoleimadas": "atoleimado",
    "atoleimados": "atoleimado",
    "atoleiros": "atoleiro",
    "atoleis": "atolar",
    "atolem": "atolar",
    "atolemo": "atolar",
    "atolemos": "atolar",
    "atoles": "atolar",
    "atolo": "atolar",
    "atolou": "atolar",
    "atolá": "atolar",
    "atolámo": "atolar",
    "atolámos": "atolar",
    "atoláramo": "atolar",
    "atoláramos": "atolar",
    "atolárei": "atolar",
    "atoláreis": "atolar",
    "atolásseis": "atolar",
    "atolássemos": "atolar",
    "atolávamo": "atolar",
    "atolávamos": "atolar",
    "atolávei": "atolar",
    "atoláveis": "atolar",
    "atomicidades": "atomicidade",
    "atomismos": "atomismo",
    "atomistas": "atomista",
    "atomiza": "atomizar",
    "atomizada": "atomizar",
    "atomizadas": "atomizar",
    "atomizado": "atomizar",
    "atomizadores": "atomizador",
    "atomizados": "atomizar",
    "atomizai": "atomizar",
    "atomizais": "atomizar",
    "atomizam": "atomizar",
    "atomizamo": "atomizar",
    "atomizamos": "atomizar",
    "atomizando": "atomizar",
    "atomizara": "atomizar",
    "atomizaram": "atomizar",
    "atomizaras": "atomizar",
    "atomizarde": "atomizar",
    "atomizardes": "atomizar",
    "atomizare": "atomizar",
    "atomizarei": "atomizar",
    "atomizareis": "atomizar",
    "atomizarem": "atomizar",
    "atomizaremos": "atomizar",
    "atomizares": "atomizar",
    "atomizaria": "atomizar",
    "atomizariam": "atomizar",
    "atomizarias": "atomizar",
    "atomizarmo": "atomizar",
    "atomizarmos": "atomizar",
    "atomizará": "atomizar",
    "atomizarás": "atomizar",
    "atomizarão": "atomizar",
    "atomizaríamos": "atomizar",
    "atomizaríeis": "atomizar",
    "atomizas": "atomizar",
    "atomizasse": "atomizar",
    "atomizassem": "atomizar",
    "atomizasses": "atomizar",
    "atomizaste": "atomizar",
    "atomizastes": "atomizar",
    "atomizava": "atomizar",
    "atomizavam": "atomizar",
    "atomizavas": "atomizar",
    "atomizações": "atomização",
    "atomize": "atomizar",
    "atomizei": "atomizar",
    "atomizeis": "atomizar",
    "atomizem": "atomizar",
    "atomizemo": "atomizar",
    "atomizemos": "atomizar",
    "atomizes": "atomizar",
    "atomizo": "atomizar",
    "atomizou": "atomizar",
    "atomizá": "atomizar",
    "atomizámo": "atomizar",
    "atomizámos": "atomizar",
    "atomizáramo": "atomizar",
    "atomizáramos": "atomizar",
    "atomizárei": "atomizar",
    "atomizáreis": "atomizar",
    "atomizásseis": "atomizar",
    "atomizássemos": "atomizar",
    "atomizávamo": "atomizar",
    "atomizávamos": "atomizar",
    "atomizávei": "atomizar",
    "atomizáveis": "atomizável",
    "atomogramas": "atomograma",
    "atomística": "atomístico",
    "atomísticas": "atomístico",
    "atomísticos": "atomístico",
    "atonada": "atonado",
    "atonadas": "atonado",
    "atonados": "atonado",
    "atonais": "atonal",
    "atonalidades": "atonalidade",
    "atonelada": "atonelado",
    "atoneladas": "atonelado",
    "atonelados": "atonelado",
    "atonias": "atonia",
    "atonismos": "atonismo",
    "atoniza": "atonizar",
    "atonizada": "atonizar",
    "atonizadas": "atonizar",
    "atonizado": "atonizar",
    "atonizados": "atonizar",
    "atonizai": "atonizar",
    "atonizais": "atonizar",
    "atonizam": "atonizar",
    "atonizamo": "atonizar",
    "atonizamos": "atonizar",
    "atonizando": "atonizar",
    "atonizara": "atonizar",
    "atonizaram": "atonizar",
    "atonizaras": "atonizar",
    "atonizarde": "atonizar",
    "atonizardes": "atonizar",
    "atonizare": "atonizar",
    "atonizarei": "atonizar",
    "atonizareis": "atonizar",
    "atonizarem": "atonizar",
    "atonizaremos": "atonizar",
    "atonizares": "atonizar",
    "atonizaria": "atonizar",
    "atonizariam": "atonizar",
    "atonizarias": "atonizar",
    "atonizarmo": "atonizar",
    "atonizarmos": "atonizar",
    "atonizará": "atonizar",
    "atonizarás": "atonizar",
    "atonizarão": "atonizar",
    "atonizaríamos": "atonizar",
    "atonizaríeis": "atonizar",
    "atonizas": "atonizar",
    "atonizasse": "atonizar",
    "atonizassem": "atonizar",
    "atonizasses": "atonizar",
    "atonizaste": "atonizar",
    "atonizastes": "atonizar",
    "atonizava": "atonizar",
    "atonizavam": "atonizar",
    "atonizavas": "atonizar",
    "atonizações": "atonização",
    "atonize": "atonizar",
    "atonizei": "atonizar",
    "atonizeis": "atonizar",
    "atonizem": "atonizar",
    "atonizemo": "atonizar",
    "atonizemos": "atonizar",
    "atonizes": "atonizar",
    "atonizo": "atonizar",
    "atonizou": "atonizar",
    "atonizá": "atonizar",
    "atonizámo": "atonizar",
    "atonizámos": "atonizar",
    "atonizáramo": "atonizar",
    "atonizáramos": "atonizar",
    "atonizárei": "atonizar",
    "atonizáreis": "atonizar",
    "atonizásseis": "atonizar",
    "atonizássemos": "atonizar",
    "atonizávamo": "atonizar",
    "atonizávamos": "atonizar",
    "atonizávei": "atonizar",
    "atonizáveis": "atonizar",
    "atontadiça": "atontadiço",
    "atontadiças": "atontadiço",
    "atontadiços": "atontadiço",
    "atoras": "atora",
    "atordoa": "atordoar",
    "atordoada": "atordoar",
    "atordoadas": "atordoar",
    "atordoado": "atordoar",
    "atordoadora": "atordoador",
    "atordoadoras": "atordoador",
    "atordoadores": "atordoador",
    "atordoados": "atordoar",
    "atordoadíssima": "atordoado",
    "atordoadíssimas": "atordoado",
    "atordoadíssimo": "atordoado",
    "atordoadíssimos": "atordoado",
    "atordoai": "atordoar",
    "atordoais": "atordoar",
    "atordoam": "atordoar",
    "atordoamentos": "atordoamento",
    "atordoamo": "atordoar",
    "atordoamos": "atordoar",
    "atordoando": "atordoar",
    "atordoantes": "atordoante",
    "atordoara": "atordoar",
    "atordoaram": "atordoar",
    "atordoaras": "atordoar",
    "atordoarde": "atordoar",
    "atordoardes": "atordoar",
    "atordoare": "atordoar",
    "atordoarei": "atordoar",
    "atordoareis": "atordoar",
    "atordoarem": "atordoar",
    "atordoaremos": "atordoar",
    "atordoares": "atordoar",
    "atordoaria": "atordoar",
    "atordoariam": "atordoar",
    "atordoarias": "atordoar",
    "atordoarmo": "atordoar",
    "atordoarmos": "atordoar",
    "atordoará": "atordoar",
    "atordoarás": "atordoar",
    "atordoarão": "atordoar",
    "atordoaríamos": "atordoar",
    "atordoaríeis": "atordoar",
    "atordoas": "atordoar",
    "atordoasse": "atordoar",
    "atordoassem": "atordoar",
    "atordoasses": "atordoar",
    "atordoaste": "atordoar",
    "atordoastes": "atordoar",
    "atordoava": "atordoar",
    "atordoavam": "atordoar",
    "atordoavas": "atordoar",
    "atordoe": "atordoar",
    "atordoei": "atordoar",
    "atordoeis": "atordoar",
    "atordoem": "atordoar",
    "atordoemo": "atordoar",
    "atordoemos": "atordoar",
    "atordoes": "atordoar",
    "atordoo": "atordoar",
    "atordoou": "atordoar",
    "atordoá": "atordoar",
    "atordoámo": "atordoar",
    "atordoámos": "atordoar",
    "atordoáramo": "atordoar",
    "atordoáramos": "atordoar",
    "atordoárei": "atordoar",
    "atordoáreis": "atordoar",
    "atordoásseis": "atordoar",
    "atordoássemos": "atordoar",
    "atordoávamo": "atordoar",
    "atordoávamos": "atordoar",
    "atordoávei": "atordoar",
    "atordoáveis": "atordoar",
    "atormenta": "atormentar",
    "atormentada": "atormentar",
    "atormentadas": "atormentar",
    "atormentadiça": "atormentadiço",
    "atormentadiças": "atormentadiço",
    "atormentadiços": "atormentadiço",
    "atormentado": "atormentar",
    "atormentadora": "atormentador",
    "atormentadoras": "atormentador",
    "atormentadores": "atormentador",
    "atormentados": "atormentar",
    "atormentadíssima": "atormentado",
    "atormentadíssimas": "atormentado",
    "atormentadíssimo": "atormentado",
    "atormentadíssimos": "atormentado",
    "atormentai": "atormentar",
    "atormentais": "atormentar",
    "atormentam": "atormentar",
    "atormentamo": "atormentar",
    "atormentamos": "atormentar",
    "atormentando": "atormentar",
    "atormentara": "atormentar",
    "atormentaram": "atormentar",
    "atormentaras": "atormentar",
    "atormentarde": "atormentar",
    "atormentardes": "atormentar",
    "atormentare": "atormentar",
    "atormentarei": "atormentar",
    "atormentareis": "atormentar",
    "atormentarem": "atormentar",
    "atormentaremos": "atormentar",
    "atormentares": "atormentar",
    "atormentaria": "atormentar",
    "atormentariam": "atormentar",
    "atormentarias": "atormentar",
    "atormentarmo": "atormentar",
    "atormentarmos": "atormentar",
    "atormentará": "atormentar",
    "atormentarás": "atormentar",
    "atormentarão": "atormentar",
    "atormentaríamos": "atormentar",
    "atormentaríeis": "atormentar",
    "atormentas": "atormentar",
    "atormentasse": "atormentar",
    "atormentassem": "atormentar",
    "atormentasses": "atormentar",
    "atormentaste": "atormentar",
    "atormentastes": "atormentar",
    "atormentava": "atormentar",
    "atormentavam": "atormentar",
    "atormentavas": "atormentar",
    "atormentações": "atormentação",
    "atormente": "atormentar",
    "atormentei": "atormentar",
    "atormenteis": "atormentar",
    "atormentem": "atormentar",
    "atormentemo": "atormentar",
    "atormentemos": "atormentar",
    "atormentes": "atormentar",
    "atormento": "atormentar",
    "atormentou": "atormentar",
    "atormentá": "atormentar",
    "atormentámo": "atormentar",
    "atormentámos": "atormentar",
    "atormentáramo": "atormentar",
    "atormentáramos": "atormentar",
    "atormentárei": "atormentar",
    "atormentáreis": "atormentar",
    "atormentásseis": "atormentar",
    "atormentássemos": "atormentar",
    "atormentávamo": "atormentar",
    "atormentávamos": "atormentar",
    "atormentávei": "atormentar",
    "atormentáveis": "atormentar",
    "atortemelada": "atortemelado",
    "atortemeladas": "atortemelado",
    "atortemelados": "atortemelado",
    "atorácica": "atorácico",
    "atorácicas": "atorácico",
    "atorácicos": "atorácico",
    "atoscalhada": "atoscalhado",
    "atoscalhadas": "atoscalhado",
    "atoscalhados": "atoscalhado",
    "atou": "atar",
    "atoucada": "atoucado",
    "atoucadas": "atoucado",
    "atoucados": "atoucado",
    "atra": "atro",
    "atrabiis": "atrabil",
    "atrabiliosa": "atrabilioso",
    "atrabiliosas": "atrabilioso",
    "atrabiliosos": "atrabilioso",
    "atrabiliária": "atrabiliário",
    "atrabiliárias": "atrabiliário",
    "atrabiliários": "atrabiliário",
    "atraca": "atracar",
    "atracada": "atracar",
    "atracadas": "atracar",
    "atracadelas": "atracadela",
    "atracado": "atracar",
    "atracadoiros": "atracadoiro",
    "atracadora": "atracador",
    "atracadoras": "atracador",
    "atracadores": "atracador",
    "atracados": "atracar",
    "atracadouros": "atracadouro",
    "atracaduras": "atracadura",
    "atracagens": "atracagem",
    "atracai": "atracar",
    "atracais": "atracar",
    "atracam": "atracar",
    "atracamo": "atracar",
    "atracamos": "atracar",
    "atracando": "atracar",
    "atracara": "atracar",
    "atracaram": "atracar",
    "atracaras": "atracar",
    "atracarde": "atracar",
    "atracardes": "atracar",
    "atracare": "atracar",
    "atracarei": "atracar",
    "atracareis": "atracar",
    "atracarem": "atracar",
    "atracaremos": "atracar",
    "atracares": "atracar",
    "atracaria": "atracar",
    "atracariam": "atracar",
    "atracarias": "atracar",
    "atracarmo": "atracar",
    "atracarmos": "atracar",
    "atracará": "atracar",
    "atracarás": "atracar",
    "atracarão": "atracar",
    "atracaríamos": "atracar",
    "atracaríeis": "atracar",
    "atracas": "atracar",
    "atracasse": "atracar",
    "atracassem": "atracar",
    "atracasses": "atracar",
    "atracaste": "atracar",
    "atracastes": "atracar",
    "atracava": "atracar",
    "atracavam": "atracar",
    "atracavas": "atracar",
    "atracações": "atracação",
    "atraco": "atracar",
    "atracou": "atracar",
    "atractiva": "atractivo",
    "atractivas": "atractivo",
    "atractividades": "atractividade",
    "atractivos": "atractivo",
    "atracá": "atracar",
    "atracámo": "atracar",
    "atracámos": "atracar",
    "atracáramo": "atracar",
    "atracáramos": "atracar",
    "atracárei": "atracar",
    "atracáreis": "atracar",
    "atracásseis": "atracar",
    "atracássemos": "atracar",
    "atracávamo": "atracar",
    "atracávamos": "atracar",
    "atracávei": "atracar",
    "atracáveis": "atracar",
    "atracções": "atracção",
    "atracões": "atracão",
    "atraem": "atrair",
    "atraentes": "atraente",
    "atrai": "atrair",
    "atraia": "atrair",
    "atraiais": "atrair",
    "atraiam": "atrair",
    "atraiamo": "atrair",
    "atraiamos": "atrair",
    "atraias": "atrair",
    "atraimentos": "atraimento",
    "atraindo": "atrair",
    "atraio": "atrair",
    "atrairde": "atrair",
    "atrairdes": "atrair",
    "atrairei": "atrair",
    "atraireis": "atrair",
    "atrairemos": "atrair",
    "atrairia": "atrair",
    "atrairiam": "atrair",
    "atrairias": "atrair",
    "atrairmo": "atrair",
    "atrairmos": "atrair",
    "atrairá": "atrair",
    "atrairás": "atrair",
    "atrairão": "atrair",
    "atrairíamos": "atrair",
    "atrairíeis": "atrair",
    "atrais": "atrair",
    "atraiu": "atrair",
    "atraiçoa": "atraiçoar",
    "atraiçoada": "atraiçoar",
    "atraiçoadas": "atraiçoar",
    "atraiçoado": "atraiçoar",
    "atraiçoadora": "atraiçoador",
    "atraiçoadoras": "atraiçoador",
    "atraiçoadores": "atraiçoador",
    "atraiçoados": "atraiçoar",
    "atraiçoai": "atraiçoar",
    "atraiçoais": "atraiçoar",
    "atraiçoam": "atraiçoar",
    "atraiçoamo": "atraiçoar",
    "atraiçoamos": "atraiçoar",
    "atraiçoando": "atraiçoar",
    "atraiçoara": "atraiçoar",
    "atraiçoaram": "atraiçoar",
    "atraiçoaras": "atraiçoar",
    "atraiçoarde": "atraiçoar",
    "atraiçoardes": "atraiçoar",
    "atraiçoare": "atraiçoar",
    "atraiçoarei": "atraiçoar",
    "atraiçoareis": "atraiçoar",
    "atraiçoarem": "atraiçoar",
    "atraiçoaremos": "atraiçoar",
    "atraiçoares": "atraiçoar",
    "atraiçoaria": "atraiçoar",
    "atraiçoariam": "atraiçoar",
    "atraiçoarias": "atraiçoar",
    "atraiçoarmo": "atraiçoar",
    "atraiçoarmos": "atraiçoar",
    "atraiçoará": "atraiçoar",
    "atraiçoarás": "atraiçoar",
    "atraiçoarão": "atraiçoar",
    "atraiçoaríamos": "atraiçoar",
    "atraiçoaríeis": "atraiçoar",
    "atraiçoas": "atraiçoar",
    "atraiçoasse": "atraiçoar",
    "atraiçoassem": "atraiçoar",
    "atraiçoasses": "atraiçoar",
    "atraiçoaste": "atraiçoar",
    "atraiçoastes": "atraiçoar",
    "atraiçoava": "atraiçoar",
    "atraiçoavam": "atraiçoar",
    "atraiçoavas": "atraiçoar",
    "atraiçoe": "atraiçoar",
    "atraiçoei": "atraiçoar",
    "atraiçoeis": "atraiçoar",
    "atraiçoem": "atraiçoar",
    "atraiçoemo": "atraiçoar",
    "atraiçoemos": "atraiçoar",
    "atraiçoes": "atraiçoar",
    "atraiçoo": "atraiçoar",
    "atraiçoou": "atraiçoar",
    "atraiçoá": "atraiçoar",
    "atraiçoámo": "atraiçoar",
    "atraiçoámos": "atraiçoar",
    "atraiçoáramo": "atraiçoar",
    "atraiçoáramos": "atraiçoar",
    "atraiçoárei": "atraiçoar",
    "atraiçoáreis": "atraiçoar",
    "atraiçoásseis": "atraiçoar",
    "atraiçoássemos": "atraiçoar",
    "atraiçoávamo": "atraiçoar",
    "atraiçoávamos": "atraiçoar",
    "atraiçoávei": "atraiçoar",
    "atraiçoáveis": "atraiçoável",
    "atramentos": "atramento",
    "atrancadas": "atrancada",
    "atrancamentos": "atrancamento",
    "atrancos": "atranco",
    "atranqueirada": "atranqueirado",
    "atranqueiradas": "atranqueirado",
    "atranqueirados": "atranqueirado",
    "atrapalha": "atrapalhar",
    "atrapalhada": "atrapalhar",
    "atrapalhadas": "atrapalhar",
    "atrapalhado": "atrapalhar",
    "atrapalhadora": "atrapalhador",
    "atrapalhadoras": "atrapalhador",
    "atrapalhadores": "atrapalhador",
    "atrapalhados": "atrapalhar",
    "atrapalhadíssima": "atrapalhado",
    "atrapalhadíssimas": "atrapalhado",
    "atrapalhadíssimo": "atrapalhado",
    "atrapalhadíssimos": "atrapalhado",
    "atrapalhai": "atrapalhar",
    "atrapalhais": "atrapalhar",
    "atrapalham": "atrapalhar",
    "atrapalhamo": "atrapalhar",
    "atrapalhamos": "atrapalhar",
    "atrapalhando": "atrapalhar",
    "atrapalhara": "atrapalhar",
    "atrapalharam": "atrapalhar",
    "atrapalharas": "atrapalhar",
    "atrapalharde": "atrapalhar",
    "atrapalhardes": "atrapalhar",
    "atrapalhare": "atrapalhar",
    "atrapalharei": "atrapalhar",
    "atrapalhareis": "atrapalhar",
    "atrapalharem": "atrapalhar",
    "atrapalharemos": "atrapalhar",
    "atrapalhares": "atrapalhar",
    "atrapalharia": "atrapalhar",
    "atrapalhariam": "atrapalhar",
    "atrapalharias": "atrapalhar",
    "atrapalharmo": "atrapalhar",
    "atrapalharmos": "atrapalhar",
    "atrapalhará": "atrapalhar",
    "atrapalharás": "atrapalhar",
    "atrapalharão": "atrapalhar",
    "atrapalharíamos": "atrapalhar",
    "atrapalharíeis": "atrapalhar",
    "atrapalhas": "atrapalhar",
    "atrapalhasse": "atrapalhar",
    "atrapalhassem": "atrapalhar",
    "atrapalhasses": "atrapalhar",
    "atrapalhaste": "atrapalhar",
    "atrapalhastes": "atrapalhar",
    "atrapalhava": "atrapalhar",
    "atrapalhavam": "atrapalhar",
    "atrapalhavas": "atrapalhar",
    "atrapalhações": "atrapalhação",
    "atrapalhe": "atrapalhar",
    "atrapalhei": "atrapalhar",
    "atrapalheis": "atrapalhar",
    "atrapalhem": "atrapalhar",
    "atrapalhemo": "atrapalhar",
    "atrapalhemos": "atrapalhar",
    "atrapalhes": "atrapalhar",
    "atrapalho": "atrapalhar",
    "atrapalhou": "atrapalhar",
    "atrapalhá": "atrapalhar",
    "atrapalhámo": "atrapalhar",
    "atrapalhámos": "atrapalhar",
    "atrapalháramo": "atrapalhar",
    "atrapalháramos": "atrapalhar",
    "atrapalhárei": "atrapalhar",
    "atrapalháreis": "atrapalhar",
    "atrapalhásseis": "atrapalhar",
    "atrapalhássemos": "atrapalhar",
    "atrapalhávamo": "atrapalhar",
    "atrapalhávamos": "atrapalhar",
    "atrapalhávei": "atrapalhar",
    "atrapalháveis": "atrapalhar",
    "atraque": "atracar",
    "atraquei": "atracar",
    "atraqueis": "atracar",
    "atraquelias": "atraquelia",
    "atraquem": "atracar",
    "atraquemo": "atracar",
    "atraquemos": "atracar",
    "atraques": "atracar",
    "atras": "atro",
    "atrasa": "atrasar",
    "atrasada": "atrasar",
    "atrasadas": "atrasar",
    "atrasadinha": "atrasado",
    "atrasadinhas": "atrasado",
    "atrasadinho": "atrasado",
    "atrasadinhos": "atrasado",
    "atrasadita": "atrasado",
    "atrasaditas": "atrasado",
    "atrasadito": "atrasado",
    "atrasaditos": "atrasado",
    "atrasado": "atrasar",
    "atrasadora": "atrasador",
    "atrasadoras": "atrasador",
    "atrasadores": "atrasador",
    "atrasados": "atrasar",
    "atrasadíssima": "atrasado",
    "atrasadíssimas": "atrasado",
    "atrasadíssimo": "atrasado",
    "atrasadíssimos": "atrasado",
    "atrasai": "atrasar",
    "atrasais": "atrasar",
    "atrasam": "atrasar",
    "atrasamentos": "atrasamento",
    "atrasamo": "atrasar",
    "atrasamos": "atrasar",
    "atrasando": "atrasar",
    "atrasara": "atrasar",
    "atrasaram": "atrasar",
    "atrasaras": "atrasar",
    "atrasarde": "atrasar",
    "atrasardes": "atrasar",
    "atrasare": "atrasar",
    "atrasarei": "atrasar",
    "atrasareis": "atrasar",
    "atrasarem": "atrasar",
    "atrasaremos": "atrasar",
    "atrasares": "atrasar",
    "atrasaria": "atrasar",
    "atrasariam": "atrasar",
    "atrasarias": "atrasar",
    "atrasarmo": "atrasar",
    "atrasarmos": "atrasar",
    "atrasará": "atrasar",
    "atrasarás": "atrasar",
    "atrasarão": "atrasar",
    "atrasaríamos": "atrasar",
    "atrasaríeis": "atrasar",
    "atrasas": "atrasar",
    "atrasasse": "atrasar",
    "atrasassem": "atrasar",
    "atrasasses": "atrasar",
    "atrasaste": "atrasar",
    "atrasastes": "atrasar",
    "atrasava": "atrasar",
    "atrasavam": "atrasar",
    "atrasavas": "atrasar",
    "atrase": "atrasar",
    "atrasei": "atrasar",
    "atraseis": "atrasar",
    "atrasem": "atrasar",
    "atrasemo": "atrasar",
    "atrasemos": "atrasar",
    "atrases": "atrasar",
    "atraso": "atrasar",
    "atrasos": "atraso",
    "atrasou": "atrasar",
    "atrasá": "atrasar",
    "atrasámo": "atrasar",
    "atrasámos": "atrasar",
    "atrasáramo": "atrasar",
    "atrasáramos": "atrasar",
    "atrasárei": "atrasar",
    "atrasáreis": "atrasar",
    "atrasásseis": "atrasar",
    "atrasássemos": "atrasar",
    "atrasávamo": "atrasar",
    "atrasávamos": "atrasar",
    "atrasávei": "atrasar",
    "atrasáveis": "atrasar",
    "atravanca": "atravancar",
    "atravancada": "atravancar",
    "atravancadas": "atravancar",
    "atravancado": "atravancar",
    "atravancados": "atravancar",
    "atravancai": "atravancar",
    "atravancais": "atravancar",
    "atravancam": "atravancar",
    "atravancamentos": "atravancamento",
    "atravancamo": "atravancar",
    "atravancamos": "atravancar",
    "atravancando": "atravancar",
    "atravancara": "atravancar",
    "atravancaram": "atravancar",
    "atravancaras": "atravancar",
    "atravancarde": "atravancar",
    "atravancardes": "atravancar",
    "atravancare": "atravancar",
    "atravancarei": "atravancar",
    "atravancareis": "atravancar",
    "atravancarem": "atravancar",
    "atravancaremos": "atravancar",
    "atravancares": "atravancar",
    "atravancaria": "atravancar",
    "atravancariam": "atravancar",
    "atravancarias": "atravancar",
    "atravancarmo": "atravancar",
    "atravancarmos": "atravancar",
    "atravancará": "atravancar",
    "atravancarás": "atravancar",
    "atravancarão": "atravancar",
    "atravancaríamos": "atravancar",
    "atravancaríeis": "atravancar",
    "atravancas": "atravancar",
    "atravancasse": "atravancar",
    "atravancassem": "atravancar",
    "atravancasses": "atravancar",
    "atravancaste": "atravancar",
    "atravancastes": "atravancar",
    "atravancava": "atravancar",
    "atravancavam": "atravancar",
    "atravancavas": "atravancar",
    "atravanco": "atravancar",
    "atravancos": "atravanco",
    "atravancou": "atravancar",
    "atravancá": "atravancar",
    "atravancámo": "atravancar",
    "atravancámos": "atravancar",
    "atravancáramo": "atravancar",
    "atravancáramos": "atravancar",
    "atravancárei": "atravancar",
    "atravancáreis": "atravancar",
    "atravancásseis": "atravancar",
    "atravancássemos": "atravancar",
    "atravancávamo": "atravancar",
    "atravancávamos": "atravancar",
    "atravancávei": "atravancar",
    "atravancáveis": "atravancar",
    "atravanque": "atravancar",
    "atravanquei": "atravancar",
    "atravanqueis": "atravancar",
    "atravanquem": "atravancar",
    "atravanquemo": "atravancar",
    "atravanquemos": "atravancar",
    "atravanques": "atravancar",
    "atravessa": "atravessar",
    "atravessada": "atravessar",
    "atravessadas": "atravessar",
    "atravessadeiras": "atravessadeira",
    "atravessadinha": "atravessado",
    "atravessadinhas": "atravessado",
    "atravessadinho": "atravessado",
    "atravessadinhos": "atravessado",
    "atravessadita": "atravessado",
    "atravessaditas": "atravessado",
    "atravessadito": "atravessado",
    "atravessaditos": "atravessado",
    "atravessadiça": "atravessadiço",
    "atravessadiças": "atravessadiço",
    "atravessadiços": "atravessadiço",
    "atravessado": "atravessar",
    "atravessadoiros": "atravessadoiro",
    "atravessadora": "atravessador",
    "atravessadoras": "atravessador",
    "atravessadores": "atravessador",
    "atravessados": "atravessar",
    "atravessadouros": "atravessadouro",
    "atravessadíssima": "atravessado",
    "atravessadíssimas": "atravessado",
    "atravessadíssimo": "atravessado",
    "atravessadíssimos": "atravessado",
    "atravessai": "atravessar",
    "atravessais": "atravessar",
    "atravessam": "atravessar",
    "atravessamentos": "atravessamento",
    "atravessamo": "atravessar",
    "atravessamos": "atravessar",
    "atravessando": "atravessar",
    "atravessantes": "atravessante",
    "atravessara": "atravessar",
    "atravessaram": "atravessar",
    "atravessaras": "atravessar",
    "atravessarde": "atravessar",
    "atravessardes": "atravessar",
    "atravessare": "atravessar",
    "atravessarei": "atravessar",
    "atravessareis": "atravessar",
    "atravessarem": "atravessar",
    "atravessaremos": "atravessar",
    "atravessares": "atravessar",
    "atravessaria": "atravessar",
    "atravessariam": "atravessar",
    "atravessarias": "atravessar",
    "atravessarmo": "atravessar",
    "atravessarmos": "atravessar",
    "atravessará": "atravessar",
    "atravessarás": "atravessar",
    "atravessarão": "atravessar",
    "atravessaríamos": "atravessar",
    "atravessaríeis": "atravessar",
    "atravessas": "atravessar",
    "atravessasse": "atravessar",
    "atravessassem": "atravessar",
    "atravessasses": "atravessar",
    "atravessaste": "atravessar",
    "atravessastes": "atravessar",
    "atravessava": "atravessar",
    "atravessavam": "atravessar",
    "atravessavas": "atravessar",
    "atravesse": "atravessar",
    "atravessei": "atravessar",
    "atravesseis": "atravessar",
    "atravessem": "atravessar",
    "atravessemo": "atravessar",
    "atravessemos": "atravessar",
    "atravesses": "atravessar",
    "atravesso": "atravessar",
    "atravessou": "atravessar",
    "atravessá": "atravessar",
    "atravessámo": "atravessar",
    "atravessámos": "atravessar",
    "atravessáramo": "atravessar",
    "atravessáramos": "atravessar",
    "atravessárei": "atravessar",
    "atravessáreis": "atravessar",
    "atravessásseis": "atravessar",
    "atravessássemos": "atravessar",
    "atravessávamo": "atravessar",
    "atravessávamos": "atravessar",
    "atravessávei": "atravessar",
    "atravessáveis": "atravessável",
    "atraí": "atrair",
    "atraía": "atrair",
    "atraíam": "atrair",
    "atraíamo": "atrair",
    "atraíamos": "atrair",
    "atraías": "atrair",
    "atraída": "atrair",
    "atraídas": "atrair",
    "atraído": "atrair",
    "atraídos": "atrair",
    "atraíei": "atrair",
    "atraíeis": "atrair",
    "atraímo": "atrair",
    "atraímos": "atrair",
    "atraíra": "atrair",
    "atraíram": "atrair",
    "atraíramo": "atrair",
    "atraíramos": "atrair",
    "atraíras": "atrair",
    "atraíre": "atrair",
    "atraírei": "atrair",
    "atraíreis": "atrair",
    "atraírem": "atrair",
    "atraíres": "atrair",
    "atraís": "atrair",
    "atraísse": "atrair",
    "atraísseis": "atrair",
    "atraíssem": "atrair",
    "atraíssemos": "atrair",
    "atraísses": "atrair",
    "atraíste": "atrair",
    "atraístes": "atrair",
    "atraíveis": "atraível",
    "atreita": "atreito",
    "atreitas": "atreito",
    "atreitos": "atreito",
    "atrela": "atrelar",
    "atrelada": "atrelar",
    "atreladas": "atrelar",
    "atrelado": "atrelar",
    "atrelados": "atrelar",
    "atrelagens": "atrelagem",
    "atrelai": "atrelar",
    "atrelais": "atrelar",
    "atrelam": "atrelar",
    "atrelamo": "atrelar",
    "atrelamos": "atrelar",
    "atrelando": "atrelar",
    "atrelara": "atrelar",
    "atrelaram": "atrelar",
    "atrelaras": "atrelar",
    "atrelarde": "atrelar",
    "atrelardes": "atrelar",
    "atrelare": "atrelar",
    "atrelarei": "atrelar",
    "atrelareis": "atrelar",
    "atrelarem": "atrelar",
    "atrelaremos": "atrelar",
    "atrelares": "atrelar",
    "atrelaria": "atrelar",
    "atrelariam": "atrelar",
    "atrelarias": "atrelar",
    "atrelarmo": "atrelar",
    "atrelarmos": "atrelar",
    "atrelará": "atrelar",
    "atrelarás": "atrelar",
    "atrelarão": "atrelar",
    "atrelaríamos": "atrelar",
    "atrelaríeis": "atrelar",
    "atrelas": "atrelar",
    "atrelasse": "atrelar",
    "atrelassem": "atrelar",
    "atrelasses": "atrelar",
    "atrelaste": "atrelar",
    "atrelastes": "atrelar",
    "atrelava": "atrelar",
    "atrelavam": "atrelar",
    "atrelavas": "atrelar",
    "atrele": "atrelar",
    "atrelei": "atrelar",
    "atreleis": "atrelar",
    "atrelem": "atrelar",
    "atrelemo": "atrelar",
    "atrelemos": "atrelar",
    "atreles": "atrelar",
    "atrelo": "atrelar",
    "atrelou": "atrelar",
    "atrelá": "atrelar",
    "atrelámo": "atrelar",
    "atrelámos": "atrelar",
    "atreláramo": "atrelar",
    "atreláramos": "atrelar",
    "atrelárei": "atrelar",
    "atreláreis": "atrelar",
    "atrelásseis": "atrelar",
    "atrelássemos": "atrelar",
    "atrelávamo": "atrelar",
    "atrelávamos": "atrelar",
    "atrelávei": "atrelar",
    "atreláveis": "atrelável",
    "atrepas": "atrepa",
    "atrepesias": "atrepesia",
    "atresias": "atresia",
    "atreva": "atrever",
    "atrevais": "atrever",
    "atrevam": "atrever",
    "atrevamo": "atrever",
    "atrevamos": "atrever",
    "atrevas": "atrever",
    "atreve": "atrever",
    "atrevei": "atrever",
    "atreveis": "atrever",
    "atrevem": "atrever",
    "atrevemo": "atrever",
    "atrevemos": "atrever",
    "atrevendo": "atrever",
    "atrevera": "atrever",
    "atreveram": "atrever",
    "atreveras": "atrever",
    "atreverde": "atrever",
    "atreverdes": "atrever",
    "atrevere": "atrever",
    "atreverei": "atrever",
    "atrevereis": "atrever",
    "atreverem": "atrever",
    "atreveremos": "atrever",
    "atreveres": "atrever",
    "atreveria": "atrever",
    "atreveriam": "atrever",
    "atreverias": "atrever",
    "atrevermo": "atrever",
    "atrevermos": "atrever",
    "atreverá": "atrever",
    "atreverás": "atrever",
    "atreverão": "atrever",
    "atreveríamos": "atrever",
    "atreveríeis": "atrever",
    "atreves": "atrever",
    "atrevesse": "atrever",
    "atrevessem": "atrever",
    "atrevesses": "atrever",
    "atreveste": "atrever",
    "atrevestes": "atrever",
    "atreveu": "atrever",
    "atrevi": "atrever",
    "atrevia": "atrever",
    "atreviam": "atrever",
    "atrevias": "atrever",
    "atrevida": "atrevido",
    "atrevidas": "atrevido",
    "atrevidazinha": "atrevido",
    "atrevidazinhas": "atrevido",
    "atrevidazita": "atrevido",
    "atrevidazitas": "atrevido",
    "atrevidaça": "atrevido",
    "atrevidaças": "atrevido",
    "atrevidaço": "atrevido",
    "atrevidaços": "atrevido",
    "atrevidinha": "atrevido",
    "atrevidinhas": "atrevido",
    "atrevidinho": "atrevido",
    "atrevidinhos": "atrevido",
    "atrevidita": "atrevido",
    "atreviditas": "atrevido",
    "atrevidito": "atrevido",
    "atreviditos": "atrevido",
    "atrevido": "atrever",
    "atrevidona": "atrevido",
    "atrevidonas": "atrevido",
    "atrevidos": "atrevido",
    "atrevidota": "atrevidote",
    "atrevidotas": "atrevidote",
    "atrevidotes": "atrevidote",
    "atrevidozinho": "atrevido",
    "atrevidozinhos": "atrevido",
    "atrevidozito": "atrevido",
    "atrevidozitos": "atrevido",
    "atrevidão": "atrevido",
    "atrevidíssima": "atrevido",
    "atrevidíssimas": "atrevido",
    "atrevidíssimo": "atrevido",
    "atrevidíssimos": "atrevido",
    "atrevidões": "atrevido",
    "atrevimentos": "atrevimento",
    "atrevo": "atrever",
    "atrevê": "atrever",
    "atrevêramo": "atrever",
    "atrevêramos": "atrever",
    "atrevêrei": "atrever",
    "atrevêreis": "atrever",
    "atrevêsseis": "atrever",
    "atrevêssemos": "atrever",
    "atrevíamo": "atrever",
    "atrevíamos": "atrever",
    "atrevíei": "atrever",
    "atrevíeis": "atrever",
    "atriais": "atrial",
    "atribua": "atribuir",
    "atribuais": "atribuir",
    "atribuam": "atribuir",
    "atribuamo": "atribuir",
    "atribuamos": "atribuir",
    "atribuas": "atribuir",
    "atribuem": "atribuir",
    "atribui": "atribuir",
    "atribuidora": "atribuidor",
    "atribuidoras": "atribuidor",
    "atribuidores": "atribuidor",
    "atribuindo": "atribuir",
    "atribuirde": "atribuir",
    "atribuirdes": "atribuir",
    "atribuirei": "atribuir",
    "atribuireis": "atribuir",
    "atribuiremos": "atribuir",
    "atribuiria": "atribuir",
    "atribuiriam": "atribuir",
    "atribuirias": "atribuir",
    "atribuirmo": "atribuir",
    "atribuirmos": "atribuir",
    "atribuirá": "atribuir",
    "atribuirás": "atribuir",
    "atribuirão": "atribuir",
    "atribuiríamos": "atribuir",
    "atribuiríeis": "atribuir",
    "atribuis": "atribuir",
    "atribuiu": "atribuir",
    "atribuições": "atribuição",
    "atribula": "atribular",
    "atribulada": "atribular",
    "atribuladas": "atribular",
    "atribulado": "atribular",
    "atribuladora": "atribulador",
    "atribuladoras": "atribulador",
    "atribuladores": "atribulador",
    "atribulados": "atribular",
    "atribuladíssima": "atribulado",
    "atribuladíssimas": "atribulado",
    "atribuladíssimo": "atribulado",
    "atribuladíssimos": "atribulado",
    "atribulai": "atribular",
    "atribulais": "atribular",
    "atribulam": "atribular",
    "atribulamo": "atribular",
    "atribulamos": "atribular",
    "atribulando": "atribular",
    "atribulara": "atribular",
    "atribularam": "atribular",
    "atribularas": "atribular",
    "atribularde": "atribular",
    "atribulardes": "atribular",
    "atribulare": "atribular",
    "atribularei": "atribular",
    "atribulareis": "atribular",
    "atribularem": "atribular",
    "atribularemos": "atribular",
    "atribulares": "atribular",
    "atribularia": "atribular",
    "atribulariam": "atribular",
    "atribularias": "atribular",
    "atribularmo": "atribular",
    "atribularmos": "atribular",
    "atribulará": "atribular",
    "atribularás": "atribular",
    "atribularão": "atribular",
    "atribularíamos": "atribular",
    "atribularíeis": "atribular",
    "atribulas": "atribular",
    "atribulasse": "atribular",
    "atribulassem": "atribular",
    "atribulasses": "atribular",
    "atribulaste": "atribular",
    "atribulastes": "atribular",
    "atribulava": "atribular",
    "atribulavam": "atribular",
    "atribulavas": "atribular",
    "atribulações": "atribulação",
    "atribule": "atribular",
    "atribulei": "atribular",
    "atribuleis": "atribular",
    "atribulem": "atribular",
    "atribulemo": "atribular",
    "atribulemos": "atribular",
    "atribules": "atribular",
    "atribulo": "atribular",
    "atribulou": "atribular",
    "atribulá": "atribular",
    "atribulámo": "atribular",
    "atribulámos": "atribular",
    "atribuláramo": "atribular",
    "atribuláramos": "atribular",
    "atribulárei": "atribular",
    "atribuláreis": "atribular",
    "atribulásseis": "atribular",
    "atribulássemos": "atribular",
    "atribulávamo": "atribular",
    "atribulávamos": "atribular",
    "atribulávei": "atribular",
    "atribuláveis": "atribular",
    "atribuo": "atribuir",
    "atributiva": "atributivo",
    "atributivas": "atributivo",
    "atributivos": "atributivo",
    "atributos": "atributo",
    "atribuí": "atribuir",
    "atribuía": "atribuir",
    "atribuíam": "atribuir",
    "atribuíamo": "atribuir",
    "atribuíamos": "atribuir",
    "atribuías": "atribuir",
    "atribuída": "atribuir",
    "atribuídas": "atribuir",
    "atribuído": "atribuir",
    "atribuídos": "atribuir",
    "atribuíei": "atribuir",
    "atribuíeis": "atribuir",
    "atribuímo": "atribuir",
    "atribuímos": "atribuir",
    "atribuíra": "atribuir",
    "atribuíram": "atribuir",
    "atribuíramo": "atribuir",
    "atribuíramos": "atribuir",
    "atribuíras": "atribuir",
    "atribuíre": "atribuir",
    "atribuírei": "atribuir",
    "atribuíreis": "atribuir",
    "atribuírem": "atribuir",
    "atribuíres": "atribuir",
    "atribuís": "atribuir",
    "atribuísse": "atribuir",
    "atribuísseis": "atribuir",
    "atribuíssem": "atribuir",
    "atribuíssemos": "atribuir",
    "atribuísses": "atribuir",
    "atribuíste": "atribuir",
    "atribuístes": "atribuir",
    "atribuíveis": "atribuível",
    "atricada": "atricado",
    "atricadas": "atricado",
    "atricados": "atricado",
    "atricapila": "atricapilo",
    "atricapilas": "atricapilo",
    "atricapilos": "atricapilo",
    "atricaudes": "atricaude",
    "atricoses": "atricose",
    "atrigada": "atrigado",
    "atrigadas": "atrigado",
    "atrigados": "atrigado",
    "atrigueirada": "atrigueirado",
    "atrigueiradas": "atrigueirado",
    "atrigueirados": "atrigueirado",
    "atriis": "atril",
    "atriquias": "atriquia",
    "atrirrostra": "atrirrostro",
    "atrirrostras": "atrirrostro",
    "atrirrostros": "atrirrostro",
    "atritos": "atrito",
    "atrições": "atrição",
    "atroa": "atroar",
    "atroada": "atroar",
    "atroadas": "atroar",
    "atroado": "atroar",
    "atroadora": "atroador",
    "atroadoras": "atroador",
    "atroadores": "atroador",
    "atroados": "atroar",
    "atroai": "atroar",
    "atroais": "atroar",
    "atroam": "atroar",
    "atroamentos": "atroamento",
    "atroamo": "atroar",
    "atroamos": "atroar",
    "atroando": "atroar",
    "atroantes": "atroante",
    "atroara": "atroar",
    "atroaram": "atroar",
    "atroaras": "atroar",
    "atroarde": "atroar",
    "atroardes": "atroar",
    "atroare": "atroar",
    "atroarei": "atroar",
    "atroareis": "atroar",
    "atroarem": "atroar",
    "atroaremos": "atroar",
    "atroares": "atroar",
    "atroaria": "atroar",
    "atroariam": "atroar",
    "atroarias": "atroar",
    "atroarmo": "atroar",
    "atroarmos": "atroar",
    "atroará": "atroar",
    "atroarás": "atroar",
    "atroarão": "atroar",
    "atroaríamos": "atroar",
    "atroaríeis": "atroar",
    "atroas": "atroar",
    "atroasse": "atroar",
    "atroassem": "atroar",
    "atroasses": "atroar",
    "atroaste": "atroar",
    "atroastes": "atroar",
    "atroava": "atroar",
    "atroavam": "atroar",
    "atroavas": "atroar",
    "atrocidades": "atrocidade",
    "atroe": "atroar",
    "atroei": "atroar",
    "atroeis": "atroar",
    "atroem": "atroar",
    "atroemo": "atroar",
    "atroemos": "atroar",
    "atroes": "atroar",
    "atrofia": "atrofiar",
    "atrofiada": "atrofiar",
    "atrofiadas": "atrofiar",
    "atrofiado": "atrofiar",
    "atrofiadora": "atrofiador",
    "atrofiadoras": "atrofiador",
    "atrofiadores": "atrofiador",
    "atrofiados": "atrofiar",
    "atrofiai": "atrofiar",
    "atrofiais": "atrofiar",
    "atrofiam": "atrofiar",
    "atrofiamentos": "atrofiamento",
    "atrofiamo": "atrofiar",
    "atrofiamos": "atrofiar",
    "atrofiando": "atrofiar",
    "atrofiantes": "atrofiante",
    "atrofiara": "atrofiar",
    "atrofiaram": "atrofiar",
    "atrofiaras": "atrofiar",
    "atrofiarde": "atrofiar",
    "atrofiardes": "atrofiar",
    "atrofiare": "atrofiar",
    "atrofiarei": "atrofiar",
    "atrofiareis": "atrofiar",
    "atrofiarem": "atrofiar",
    "atrofiaremos": "atrofiar",
    "atrofiares": "atrofiar",
    "atrofiaria": "atrofiar",
    "atrofiariam": "atrofiar",
    "atrofiarias": "atrofiar",
    "atrofiarmo": "atrofiar",
    "atrofiarmos": "atrofiar",
    "atrofiará": "atrofiar",
    "atrofiarás": "atrofiar",
    "atrofiarão": "atrofiar",
    "atrofiaríamos": "atrofiar",
    "atrofiaríeis": "atrofiar",
    "atrofias": "atrofiar",
    "atrofiasse": "atrofiar",
    "atrofiassem": "atrofiar",
    "atrofiasses": "atrofiar",
    "atrofiaste": "atrofiar",
    "atrofiastes": "atrofiar",
    "atrofiava": "atrofiar",
    "atrofiavam": "atrofiar",
    "atrofiavas": "atrofiar",
    "atrofie": "atrofiar",
    "atrofiei": "atrofiar",
    "atrofieis": "atrofiar",
    "atrofiem": "atrofiar",
    "atrofiemo": "atrofiar",
    "atrofiemos": "atrofiar",
    "atrofies": "atrofiar",
    "atrofio": "atrofiar",
    "atrofiou": "atrofiar",
    "atrofiá": "atrofiar",
    "atrofiámo": "atrofiar",
    "atrofiámos": "atrofiar",
    "atrofiáramo": "atrofiar",
    "atrofiáramos": "atrofiar",
    "atrofiárei": "atrofiar",
    "atrofiáreis": "atrofiar",
    "atrofiásseis": "atrofiar",
    "atrofiássemos": "atrofiar",
    "atrofiávamo": "atrofiar",
    "atrofiávamos": "atrofiar",
    "atrofiávei": "atrofiar",
    "atrofiáveis": "atrofiar",
    "atrombetada": "atrombetado",
    "atrombetadas": "atrombetado",
    "atrombetados": "atrombetado",
    "atronchada": "atronchado",
    "atronchadas": "atronchado",
    "atronchados": "atronchado",
    "atroo": "atroar",
    "atroou": "atroar",
    "atropela": "atropelar",
    "atropelada": "atropelar",
    "atropeladas": "atropelar",
    "atropelado": "atropelar",
    "atropeladora": "atropelador",
    "atropeladoras": "atropelador",
    "atropeladores": "atropelador",
    "atropelados": "atropelar",
    "atropelai": "atropelar",
    "atropelais": "atropelar",
    "atropelam": "atropelar",
    "atropelamentos": "atropelamento",
    "atropelamo": "atropelar",
    "atropelamos": "atropelar",
    "atropelando": "atropelar",
    "atropelantes": "atropelante",
    "atropelara": "atropelar",
    "atropelaram": "atropelar",
    "atropelaras": "atropelar",
    "atropelarde": "atropelar",
    "atropelardes": "atropelar",
    "atropelare": "atropelar",
    "atropelarei": "atropelar",
    "atropelareis": "atropelar",
    "atropelarem": "atropelar",
    "atropelaremos": "atropelar",
    "atropelares": "atropelar",
    "atropelaria": "atropelar",
    "atropelariam": "atropelar",
    "atropelarias": "atropelar",
    "atropelarmo": "atropelar",
    "atropelarmos": "atropelar",
    "atropelará": "atropelar",
    "atropelarás": "atropelar",
    "atropelarão": "atropelar",
    "atropelaríamos": "atropelar",
    "atropelaríeis": "atropelar",
    "atropelas": "atropelar",
    "atropelasse": "atropelar",
    "atropelassem": "atropelar",
    "atropelasses": "atropelar",
    "atropelaste": "atropelar",
    "atropelastes": "atropelar",
    "atropelava": "atropelar",
    "atropelavam": "atropelar",
    "atropelavas": "atropelar",
    "atropelações": "atropelação",
    "atropele": "atropelar",
    "atropelei": "atropelar",
    "atropeleis": "atropelar",
    "atropelem": "atropelar",
    "atropelemo": "atropelar",
    "atropelemos": "atropelar",
    "atropeles": "atropelar",
    "atropelo": "atropelar",
    "atropelos": "atropelo",
    "atropelou": "atropelar",
    "atropelá": "atropelar",
    "atropelámo": "atropelar",
    "atropelámos": "atropelar",
    "atropeláramo": "atropelar",
    "atropeláramos": "atropelar",
    "atropelárei": "atropelar",
    "atropeláreis": "atropelar",
    "atropelásseis": "atropelar",
    "atropelássemos": "atropelar",
    "atropelávamo": "atropelar",
    "atropelávamos": "atropelar",
    "atropelávei": "atropelar",
    "atropeláveis": "atropelar",
    "atropinas": "atropina",
    "atros": "atro",
    "atrouchemouchada": "atrouchemouchado",
    "atrouchemouchadas": "atrouchemouchado",
    "atrouchemouchados": "atrouchemouchado",
    "atroviscada": "atroviscado",
    "atroviscadas": "atroviscado",
    "atroviscados": "atroviscado",
    "atrozes": "atroz",
    "atroá": "atroar",
    "atroámo": "atroar",
    "atroámos": "atroar",
    "atroáramo": "atroar",
    "atroáramos": "atroar",
    "atroárei": "atroar",
    "atroáreis": "atroar",
    "atroásseis": "atroar",
    "atroássemos": "atroar",
    "atroávamo": "atroar",
    "atroávamos": "atroar",
    "atroávei": "atroar",
    "atroáveis": "atroar",
    "atrupidos": "atrupido",
    "atrutada": "atrutado",
    "atrutadas": "atrutado",
    "atrutados": "atrutado",
    "atrícula": "atrículo",
    "atrículas": "atrículo",
    "atrículos": "atrículo",
    "atríolos": "atríolo",
    "atrípedes": "atrípede",
    "atrófica": "atrófico",
    "atróficas": "atrófico",
    "atróficos": "atrófico",
    "atrófitas": "atrófita",
    "atrôos": "atrôo",
    "atuadora": "atuador",
    "atuadoras": "atuador",
    "atuadores": "atuador",
    "atuarros": "atuarro",
    "atueiras": "atueira",
    "atulha": "atulhar",
    "atulhada": "atulhar",
    "atulhadas": "atulhar",
    "atulhado": "atulhar",
    "atulhados": "atulhar",
    "atulhai": "atulhar",
    "atulhais": "atulhar",
    "atulham": "atulhar",
    "atulhamentos": "atulhamento",
    "atulhamo": "atulhar",
    "atulhamos": "atulhar",
    "atulhando": "atulhar",
    "atulhara": "atulhar",
    "atulharam": "atulhar",
    "atulharas": "atulhar",
    "atulharde": "atulhar",
    "atulhardes": "atulhar",
    "atulhare": "atulhar",
    "atulharei": "atulhar",
    "atulhareis": "atulhar",
    "atulharem": "atulhar",
    "atulharemos": "atulhar",
    "atulhares": "atulhar",
    "atulharia": "atulhar",
    "atulhariam": "atulhar",
    "atulharias": "atulhar",
    "atulharmo": "atulhar",
    "atulharmos": "atulhar",
    "atulhará": "atulhar",
    "atulharás": "atulhar",
    "atulharão": "atulhar",
    "atulharíamos": "atulhar",
    "atulharíeis": "atulhar",
    "atulhas": "atulhar",
    "atulhasse": "atulhar",
    "atulhassem": "atulhar",
    "atulhasses": "atulhar",
    "atulhaste": "atulhar",
    "atulhastes": "atulhar",
    "atulhava": "atulhar",
    "atulhavam": "atulhar",
    "atulhavas": "atulhar",
    "atulhe": "atulhar",
    "atulhei": "atulhar",
    "atulheis": "atulhar",
    "atulhem": "atulhar",
    "atulhemo": "atulhar",
    "atulhemos": "atulhar",
    "atulhes": "atulhar",
    "atulho": "atulhar",
    "atulhos": "atulho",
    "atulhou": "atulhar",
    "atulhá": "atulhar",
    "atulhámo": "atulhar",
    "atulhámos": "atulhar",
    "atulháramo": "atulhar",
    "atulháramos": "atulhar",
    "atulhárei": "atulhar",
    "atulháreis": "atulhar",
    "atulhásseis": "atulhar",
    "atulhássemos": "atulhar",
    "atulhávamo": "atulhar",
    "atulhávamos": "atulhar",
    "atulhávei": "atulhar",
    "atulháveis": "atulhar",
    "atumultua": "atumultuar",
    "atumultuada": "atumultuar",
    "atumultuadas": "atumultuar",
    "atumultuado": "atumultuar",
    "atumultuadora": "atumultuador",
    "atumultuadoras": "atumultuador",
    "atumultuadores": "atumultuador",
    "atumultuados": "atumultuar",
    "atumultuai": "atumultuar",
    "atumultuais": "atumultuar",
    "atumultuam": "atumultuar",
    "atumultuamo": "atumultuar",
    "atumultuamos": "atumultuar",
    "atumultuando": "atumultuar",
    "atumultuara": "atumultuar",
    "atumultuaram": "atumultuar",
    "atumultuaras": "atumultuar",
    "atumultuarde": "atumultuar",
    "atumultuardes": "atumultuar",
    "atumultuare": "atumultuar",
    "atumultuarei": "atumultuar",
    "atumultuareis": "atumultuar",
    "atumultuarem": "atumultuar",
    "atumultuaremos": "atumultuar",
    "atumultuares": "atumultuar",
    "atumultuaria": "atumultuar",
    "atumultuariam": "atumultuar",
    "atumultuarias": "atumultuar",
    "atumultuarmo": "atumultuar",
    "atumultuarmos": "atumultuar",
    "atumultuará": "atumultuar",
    "atumultuarás": "atumultuar",
    "atumultuarão": "atumultuar",
    "atumultuaríamos": "atumultuar",
    "atumultuaríeis": "atumultuar",
    "atumultuas": "atumultuar",
    "atumultuasse": "atumultuar",
    "atumultuassem": "atumultuar",
    "atumultuasses": "atumultuar",
    "atumultuaste": "atumultuar",
    "atumultuastes": "atumultuar",
    "atumultuava": "atumultuar",
    "atumultuavam": "atumultuar",
    "atumultuavas": "atumultuar",
    "atumultue": "atumultuar",
    "atumultuei": "atumultuar",
    "atumultueis": "atumultuar",
    "atumultuem": "atumultuar",
    "atumultuemo": "atumultuar",
    "atumultuemos": "atumultuar",
    "atumultues": "atumultuar",
    "atumultuo": "atumultuar",
    "atumultuou": "atumultuar",
    "atumultuá": "atumultuar",
    "atumultuámo": "atumultuar",
    "atumultuámos": "atumultuar",
    "atumultuáramo": "atumultuar",
    "atumultuáramos": "atumultuar",
    "atumultuárei": "atumultuar",
    "atumultuáreis": "atumultuar",
    "atumultuásseis": "atumultuar",
    "atumultuássemos": "atumultuar",
    "atumultuávamo": "atumultuar",
    "atumultuávamos": "atumultuar",
    "atumultuávei": "atumultuar",
    "atumultuáveis": "atumultuar",
    "atundos": "atundo",
    "atuneiras": "atuneira",
    "atuneiros": "atuneiro",
    "atuns": "atum",
    "atura": "aturar",
    "aturada": "aturar",
    "aturadas": "aturar",
    "aturado": "aturar",
    "aturadoira": "aturadoiro",
    "aturadoiras": "aturadoiro",
    "aturadoiros": "aturadoiro",
    "aturadora": "aturador",
    "aturadoras": "aturador",
    "aturadores": "aturador",
    "aturados": "aturar",
    "aturadoura": "aturadouro",
    "aturadouras": "aturadouro",
    "aturadouros": "aturadouro",
    "aturadíssima": "aturado",
    "aturadíssimas": "aturado",
    "aturadíssimo": "aturado",
    "aturadíssimos": "aturado",
    "aturai": "aturar",
    "aturais": "aturar",
    "aturam": "aturar",
    "aturamo": "aturar",
    "aturamos": "aturar",
    "aturando": "aturar",
    "aturara": "aturar",
    "aturaram": "aturar",
    "aturaras": "aturar",
    "aturarde": "aturar",
    "aturardes": "aturar",
    "aturare": "aturar",
    "aturarei": "aturar",
    "aturareis": "aturar",
    "aturarem": "aturar",
    "aturaremos": "aturar",
    "aturares": "aturar",
    "aturaria": "aturar",
    "aturariam": "aturar",
    "aturarias": "aturar",
    "aturarmo": "aturar",
    "aturarmos": "aturar",
    "aturará": "aturar",
    "aturarás": "aturar",
    "aturarão": "aturar",
    "aturaríamos": "aturar",
    "aturaríeis": "aturar",
    "aturas": "aturar",
    "aturasse": "aturar",
    "aturassem": "aturar",
    "aturasses": "aturar",
    "aturaste": "aturar",
    "aturastes": "aturar",
    "aturava": "aturar",
    "aturavam": "aturar",
    "aturavas": "aturar",
    "aturda": "aturdir",
    "aturdais": "aturdir",
    "aturdam": "aturdir",
    "aturdamo": "aturdir",
    "aturdamos": "aturdir",
    "aturdas": "aturdir",
    "aturde": "aturdir",
    "aturdem": "aturdir",
    "aturdes": "aturdir",
    "aturdi": "aturdir",
    "aturdia": "aturdir",
    "aturdiam": "aturdir",
    "aturdias": "aturdir",
    "aturdida": "aturdir",
    "aturdidas": "aturdir",
    "aturdido": "aturdir",
    "aturdidora": "aturdidor",
    "aturdidoras": "aturdidor",
    "aturdidores": "aturdidor",
    "aturdidos": "aturdir",
    "aturdidíssima": "aturdido",
    "aturdidíssimas": "aturdido",
    "aturdidíssimo": "aturdido",
    "aturdidíssimos": "aturdido",
    "aturdimentos": "aturdimento",
    "aturdimo": "aturdir",
    "aturdimos": "aturdir",
    "aturdindo": "aturdir",
    "aturdira": "aturdir",
    "aturdiram": "aturdir",
    "aturdiras": "aturdir",
    "aturdirde": "aturdir",
    "aturdirdes": "aturdir",
    "aturdire": "aturdir",
    "aturdirei": "aturdir",
    "aturdireis": "aturdir",
    "aturdirem": "aturdir",
    "aturdiremos": "aturdir",
    "aturdires": "aturdir",
    "aturdiria": "aturdir",
    "aturdiriam": "aturdir",
    "aturdirias": "aturdir",
    "aturdirmo": "aturdir",
    "aturdirmos": "aturdir",
    "aturdirá": "aturdir",
    "aturdirás": "aturdir",
    "aturdirão": "aturdir",
    "aturdiríamos": "aturdir",
    "aturdiríeis": "aturdir",
    "aturdis": "aturdir",
    "aturdisse": "aturdir",
    "aturdissem": "aturdir",
    "aturdisses": "aturdir",
    "aturdiste": "aturdir",
    "aturdistes": "aturdir",
    "aturdiu": "aturdir",
    "aturdo": "aturdir",
    "aturdíamo": "aturdir",
    "aturdíamos": "aturdir",
    "aturdíei": "aturdir",
    "aturdíeis": "aturdir",
    "aturdíramo": "aturdir",
    "aturdíramos": "aturdir",
    "aturdírei": "aturdir",
    "aturdíreis": "aturdir",
    "aturdísseis": "aturdir",
    "aturdíssemos": "aturdir",
    "ature": "aturar",
    "aturei": "aturar",
    "atureis": "aturar",
    "aturem": "aturar",
    "aturemo": "aturar",
    "aturemos": "aturar",
    "atures": "aturar",
    "aturo": "aturar",
    "aturou": "aturar",
    "aturá": "aturar",
    "aturámo": "aturar",
    "aturámos": "aturar",
    "aturáramo": "aturar",
    "aturáramos": "aturar",
    "aturárei": "aturar",
    "aturáreis": "aturar",
    "aturásseis": "aturar",
    "aturássemos": "aturar",
    "aturávamo": "aturar",
    "aturávamos": "aturar",
    "aturávei": "aturar",
    "aturáveis": "aturável",
    "atxins": "atxim",
    "atá": "atar",
    "atáctica": "atáctico",
    "atácticas": "atáctico",
    "atácticos": "atáctico",
    "atálama": "atálamo",
    "atálamas": "atálamo",
    "atálamos": "atálamo",
    "atámo": "atar",
    "atámos": "atar",
    "atáramo": "atar",
    "atáramos": "atar",
    "atárei": "atar",
    "atáreis": "atar",
    "atásseis": "atar",
    "atássemos": "atar",
    "atávamo": "atar",
    "atávamos": "atar",
    "atávei": "atar",
    "atáveis": "atar",
    "atávica": "atávico",
    "atávicas": "atávico",
    "atávicos": "atávico",
    "atáxica": "atáxico",
    "atáxicas": "atáxico",
    "atáxicos": "atáxico",
    "atém": "ater",
    "aténs": "ater",
    "atérmana": "atérmano",
    "atérmanas": "atérmano",
    "atérmanos": "atérmano",
    "atérmica": "atérmico",
    "atérmicas": "atérmico",
    "atérmicos": "atérmico",
    "atê": "ater",
    "atêm": "ater",
    "atímica": "atímico",
    "atímicas": "atímico",
    "atímicos": "atímico",
    "atínhamo": "ater",
    "atínhamos": "ater",
    "atínhei": "ater",
    "atínheis": "ater",
    "atípica": "atípico",
    "atípicas": "atípico",
    "atípicos": "atípico",
    "atóis": "atol",
    "atómica": "atómico",
    "atómicas": "atómico",
    "atómicos": "atómico",
    "atónica": "atónico",
    "atónicas": "atónico",
    "atónicos": "atónico",
    "atónita": "atónito",
    "atónitas": "atónito",
    "atónitos": "atónito",
    "atóxica": "atóxico",
    "atóxicas": "atóxico",
    "atóxicos": "atóxico",
    "audaciosa": "audacioso",
    "audaciosas": "audacioso",
    "audaciosos": "audacioso",
    "audaciosíssima": "audacioso",
    "audaciosíssimas": "audacioso",
    "audaciosíssimo": "audacioso",
    "audaciosíssimos": "audacioso",
    "audazes": "audaz",
    "audibilidades": "audibilidade",
    "audientes": "audiente",
    "audimetrias": "audimetria",
    "audimudezes": "audimudez",
    "audioamplificadores": "audioamplificador",
    "audiofones": "audiofone",
    "audiofonos": "audiofono",
    "audiofrequências": "audiofrequência",
    "audiogramas": "audiograma",
    "audiometrias": "audiometria",
    "audiométrica": "audiométrico",
    "audiométricas": "audiométrico",
    "audiométricos": "audiométrico",
    "audios": "audio",
    "audiovisuais": "audiovisual",
    "auditagens": "auditagem",
    "auditiva": "auditivo",
    "auditivas": "auditivo",
    "auditivos": "auditivo",
    "auditora": "auditor",
    "auditoras": "auditor",
    "auditores": "auditor",
    "auditorias": "auditoria",
    "auditória": "auditório",
    "auditórias": "auditório",
    "auditórios": "auditório",
    "audições": "audição",
    "audiências": "audiência",
    "audiómetros": "audiómetro",
    "audiões": "audião",
    "audácias": "audácia",
    "audíveis": "audível",
    "aufere": "auferir",
    "auferem": "auferir",
    "auferes": "auferir",
    "auferi": "auferir",
    "auferia": "auferir",
    "auferiam": "auferir",
    "auferias": "auferir",
    "auferida": "auferir",
    "auferidas": "auferir",
    "auferido": "auferir",
    "auferidos": "auferir",
    "auferimentos": "auferimento",
    "auferimo": "auferir",
    "auferimos": "auferir",
    "auferindo": "auferir",
    "auferira": "auferir",
    "auferiram": "auferir",
    "auferiras": "auferir",
    "auferirde": "auferir",
    "auferirdes": "auferir",
    "auferire": "auferir",
    "auferirei": "auferir",
    "auferireis": "auferir",
    "auferirem": "auferir",
    "auferiremos": "auferir",
    "auferires": "auferir",
    "auferiria": "auferir",
    "aufeririam": "auferir",
    "auferirias": "auferir",
    "auferirmo": "auferir",
    "auferirmos": "auferir",
    "auferirá": "auferir",
    "auferirás": "auferir",
    "auferirão": "auferir",
    "auferiríamos": "auferir",
    "auferiríeis": "auferir",
    "auferis": "auferir",
    "auferisse": "auferir",
    "auferissem": "auferir",
    "auferisses": "auferir",
    "auferiste": "auferir",
    "auferistes": "auferir",
    "auferiu": "auferir",
    "auferíamo": "auferir",
    "auferíamos": "auferir",
    "auferíei": "auferir",
    "auferíeis": "auferir",
    "auferíramo": "auferir",
    "auferíramos": "auferir",
    "auferírei": "auferir",
    "auferíreis": "auferir",
    "auferísseis": "auferir",
    "auferíssemos": "auferir",
    "auferíveis": "auferível",
    "aufira": "auferir",
    "aufirais": "auferir",
    "aufiram": "auferir",
    "aufiramo": "auferir",
    "aufiramos": "auferir",
    "aufiras": "auferir",
    "aufiro": "auferir",
    "auges": "auge",
    "augitas": "augita",
    "augites": "augite",
    "augititos": "augitito",
    "augueiras": "augueira",
    "augueiros": "augueiro",
    "augura": "augurar",
    "augurada": "augurar",
    "auguradas": "augurar",
    "augurado": "augurar",
    "augurados": "augurar",
    "augurai": "augurar",
    "augurais": "augurar",
    "auguram": "augurar",
    "auguramo": "augurar",
    "auguramos": "augurar",
    "augurando": "augurar",
    "augurara": "augurar",
    "auguraram": "augurar",
    "auguraras": "augurar",
    "augurarde": "augurar",
    "augurardes": "augurar",
    "augurare": "augurar",
    "augurarei": "augurar",
    "augurareis": "augurar",
    "augurarem": "augurar",
    "auguraremos": "augurar",
    "augurares": "augurar",
    "auguraria": "augurar",
    "augurariam": "augurar",
    "augurarias": "augurar",
    "augurarmo": "augurar",
    "augurarmos": "augurar",
    "augurará": "augurar",
    "augurarás": "augurar",
    "augurarão": "augurar",
    "auguraríamos": "augurar",
    "auguraríeis": "augurar",
    "auguras": "augurar",
    "augurasse": "augurar",
    "augurassem": "augurar",
    "augurasses": "augurar",
    "auguraste": "augurar",
    "augurastes": "augurar",
    "auguratória": "auguratório",
    "auguratórias": "auguratório",
    "auguratórios": "auguratório",
    "augurava": "augurar",
    "auguravam": "augurar",
    "auguravas": "augurar",
    "augurações": "auguração",
    "augure": "augurar",
    "augurei": "augurar",
    "augureis": "augurar",
    "augurem": "augurar",
    "auguremo": "augurar",
    "auguremos": "augurar",
    "augures": "augurar",
    "auguro": "augurar",
    "augurou": "augurar",
    "augurá": "augurar",
    "augurámo": "augurar",
    "augurámos": "augurar",
    "auguráramo": "augurar",
    "auguráramos": "augurar",
    "augurárei": "augurar",
    "auguráreis": "augurar",
    "augurásseis": "augurar",
    "augurássemos": "augurar",
    "augurávamo": "augurar",
    "augurávamos": "augurar",
    "augurávei": "augurar",
    "auguráveis": "augurar",
    "augusta": "augusto",
    "augustais": "augustal",
    "augustas": "augusto",
    "augustianismos": "augustianismo",
    "augustinhos": "augustinho",
    "augustos": "augusto",
    "augúrios": "augúrio",
    "aularcas": "aularca",
    "aulas": "aula",
    "auletas": "auleta",
    "auletes": "aulete",
    "aulicana": "aulicano",
    "aulicanas": "aulicano",
    "aulicanos": "aulicano",
    "aulidos": "aulido",
    "aulinha": "aula",
    "aulinhas": "aula",
    "aulistas": "aulista",
    "aulita": "aula",
    "aulitas": "aula",
    "aulodias": "aulodia",
    "aulos": "aulo",
    "aulética": "aulético",
    "auléticas": "aulético",
    "auléticos": "aulético",
    "aulétrides": "aulétride",
    "aumenta": "aumentar",
    "aumentada": "aumentar",
    "aumentadas": "aumentar",
    "aumentadinha": "aumentado",
    "aumentadinhas": "aumentado",
    "aumentadinho": "aumentado",
    "aumentadinhos": "aumentado",
    "aumentadita": "aumentado",
    "aumentaditas": "aumentado",
    "aumentadito": "aumentado",
    "aumentaditos": "aumentado",
    "aumentado": "aumentar",
    "aumentadora": "aumentador",
    "aumentadoras": "aumentador",
    "aumentadores": "aumentador",
    "aumentados": "aumentar",
    "aumentadíssima": "aumentado",
    "aumentadíssimas": "aumentado",
    "aumentadíssimo": "aumentado",
    "aumentadíssimos": "aumentado",
    "aumentai": "aumentar",
    "aumentais": "aumentar",
    "aumentam": "aumentar",
    "aumentamo": "aumentar",
    "aumentamos": "aumentar",
    "aumentando": "aumentar",
    "aumentara": "aumentar",
    "aumentaram": "aumentar",
    "aumentaras": "aumentar",
    "aumentarde": "aumentar",
    "aumentardes": "aumentar",
    "aumentare": "aumentar",
    "aumentarei": "aumentar",
    "aumentareis": "aumentar",
    "aumentarem": "aumentar",
    "aumentaremos": "aumentar",
    "aumentares": "aumentar",
    "aumentaria": "aumentar",
    "aumentariam": "aumentar",
    "aumentarias": "aumentar",
    "aumentarmo": "aumentar",
    "aumentarmos": "aumentar",
    "aumentará": "aumentar",
    "aumentarás": "aumentar",
    "aumentarão": "aumentar",
    "aumentaríamos": "aumentar",
    "aumentaríeis": "aumentar",
    "aumentas": "aumentar",
    "aumentasse": "aumentar",
    "aumentassem": "aumentar",
    "aumentasses": "aumentar",
    "aumentaste": "aumentar",
    "aumentastes": "aumentar",
    "aumentativa": "aumentativo",
    "aumentativas": "aumentativo",
    "aumentativos": "aumentativo",
    "aumentava": "aumentar",
    "aumentavam": "aumentar",
    "aumentavas": "aumentar",
    "aumentações": "aumentação",
    "aumente": "aumentar",
    "aumentei": "aumentar",
    "aumenteis": "aumentar",
    "aumentem": "aumentar",
    "aumentemo": "aumentar",
    "aumentemos": "aumentar",
    "aumentes": "aumentar",
    "aumento": "aumentar",
    "aumentos": "aumento",
    "aumentou": "aumentar",
    "aumentá": "aumentar",
    "aumentámo": "aumentar",
    "aumentámos": "aumentar",
    "aumentáramo": "aumentar",
    "aumentáramos": "aumentar",
    "aumentárei": "aumentar",
    "aumentáreis": "aumentar",
    "aumentásseis": "aumentar",
    "aumentássemos": "aumentar",
    "aumentávamo": "aumentar",
    "aumentávamos": "aumentar",
    "aumentávei": "aumentar",
    "aumentáveis": "aumentável",
    "auraciácea": "auraciáceo",
    "auraciáceas": "auraciáceo",
    "auraciáceos": "auraciáceo",
    "auranciócidea": "auranciócideo",
    "auranciócideas": "auranciócideo",
    "auranciócideos": "auranciócideo",
    "aurantinas": "aurantina",
    "auras": "aura",
    "auratos": "aurato",
    "aureliídea": "aureliídeo",
    "aureliídeas": "aureliídeo",
    "aureliídeos": "aureliídeo",
    "aureola": "aureolar",
    "aureolada": "aureolar",
    "aureoladas": "aureolar",
    "aureolado": "aureolar",
    "aureolados": "aureolar",
    "aureolai": "aureolar",
    "aureolais": "aureolar",
    "aureolam": "aureolar",
    "aureolamo": "aureolar",
    "aureolamos": "aureolar",
    "aureolando": "aureolar",
    "aureolara": "aureolar",
    "aureolaram": "aureolar",
    "aureolaras": "aureolar",
    "aureolarde": "aureolar",
    "aureolardes": "aureolar",
    "aureolare": "aureolar",
    "aureolarei": "aureolar",
    "aureolareis": "aureolar",
    "aureolarem": "aureolar",
    "aureolaremos": "aureolar",
    "aureolares": "aureolar",
    "aureolaria": "aureolar",
    "aureolariam": "aureolar",
    "aureolarias": "aureolar",
    "aureolarmo": "aureolar",
    "aureolarmos": "aureolar",
    "aureolará": "aureolar",
    "aureolarás": "aureolar",
    "aureolarão": "aureolar",
    "aureolaríamos": "aureolar",
    "aureolaríeis": "aureolar",
    "aureolas": "aureolar",
    "aureolasse": "aureolar",
    "aureolassem": "aureolar",
    "aureolasses": "aureolar",
    "aureolaste": "aureolar",
    "aureolastes": "aureolar",
    "aureolava": "aureolar",
    "aureolavam": "aureolar",
    "aureolavas": "aureolar",
    "aureole": "aureolar",
    "aureolei": "aureolar",
    "aureoleis": "aureolar",
    "aureolem": "aureolar",
    "aureolemo": "aureolar",
    "aureolemos": "aureolar",
    "aureoles": "aureolar",
    "aureolo": "aureolar",
    "aureolou": "aureolar",
    "aureolá": "aureolar",
    "aureolámo": "aureolar",
    "aureolámos": "aureolar",
    "aureoláramo": "aureolar",
    "aureoláramos": "aureolar",
    "aureolárei": "aureolar",
    "aureoláreis": "aureolar",
    "aureolásseis": "aureolar",
    "aureolássemos": "aureolar",
    "aureolávamo": "aureolar",
    "aureolávamos": "aureolar",
    "aureolávei": "aureolar",
    "aureoláveis": "aureolar",
    "aureomicinas": "aureomicina",
    "auricalcos": "auricalco",
    "auricerúlea": "auricerúleo",
    "auricerúleas": "auricerúleo",
    "auricerúleos": "auricerúleo",
    "auriclípia": "auriclípio",
    "auriclípias": "auriclípio",
    "auriclípios": "auriclípio",
    "auricolores": "auricolor",
    "auricrinita": "auricrinito",
    "auricrinitas": "auricrinito",
    "auricrinitos": "auricrinito",
    "auriculada": "auriculado",
    "auriculadas": "auriculado",
    "auriculados": "auriculado",
    "auriculares": "auricular",
    "auriculiformes": "auriculiforme",
    "auriculistas": "auriculista",
    "auricórnea": "auricórneo",
    "auricórneas": "auricórneo",
    "auricórneos": "auricórneo",
    "aurifica": "aurificar",
    "aurificada": "aurificar",
    "aurificadas": "aurificar",
    "aurificado": "aurificar",
    "aurificados": "aurificar",
    "aurificai": "aurificar",
    "aurificais": "aurificar",
    "aurificam": "aurificar",
    "aurificamo": "aurificar",
    "aurificamos": "aurificar",
    "aurificando": "aurificar",
    "aurificara": "aurificar",
    "aurificaram": "aurificar",
    "aurificaras": "aurificar",
    "aurificarde": "aurificar",
    "aurificardes": "aurificar",
    "aurificare": "aurificar",
    "aurificarei": "aurificar",
    "aurificareis": "aurificar",
    "aurificarem": "aurificar",
    "aurificaremos": "aurificar",
    "aurificares": "aurificar",
    "aurificaria": "aurificar",
    "aurificariam": "aurificar",
    "aurificarias": "aurificar",
    "aurificarmo": "aurificar",
    "aurificarmos": "aurificar",
    "aurificará": "aurificar",
    "aurificarás": "aurificar",
    "aurificarão": "aurificar",
    "aurificaríamos": "aurificar",
    "aurificaríeis": "aurificar",
    "aurificas": "aurificar",
    "aurificasse": "aurificar",
    "aurificassem": "aurificar",
    "aurificasses": "aurificar",
    "aurificaste": "aurificar",
    "aurificastes": "aurificar",
    "aurificava": "aurificar",
    "aurificavam": "aurificar",
    "aurificavas": "aurificar",
    "aurificações": "aurificação",
    "aurifico": "aurificar",
    "aurificou": "aurificar",
    "aurificá": "aurificar",
    "aurificámo": "aurificar",
    "aurificámos": "aurificar",
    "aurificáramo": "aurificar",
    "aurificáramos": "aurificar",
    "aurificárei": "aurificar",
    "aurificáreis": "aurificar",
    "aurificásseis": "aurificar",
    "aurificássemos": "aurificar",
    "aurificávamo": "aurificar",
    "aurificávamos": "aurificar",
    "aurificávei": "aurificar",
    "aurificáveis": "aurificar",
    "aurifique": "aurificar",
    "aurifiquei": "aurificar",
    "aurifiqueis": "aurificar",
    "aurifiquem": "aurificar",
    "aurifiquemo": "aurificar",
    "aurifiquemos": "aurificar",
    "aurifiques": "aurificar",
    "auriflamantes": "auriflamante",
    "auriflamas": "auriflama",
    "auriformes": "auriforme",
    "aurifrigiada": "aurifrigiado",
    "aurifrigiadas": "aurifrigiado",
    "aurifrigiados": "aurifrigiado",
    "aurifrígios": "aurifrígio",
    "aurifrísios": "aurifrísio",
    "aurifulgantes": "aurifulgante",
    "aurifícia": "aurifício",
    "aurifícias": "aurifício",
    "aurifícios": "aurifício",
    "aurifúlgida": "aurifúlgido",
    "aurifúlgidas": "aurifúlgido",
    "aurifúlgidos": "aurifúlgido",
    "aurigas": "auriga",
    "aurigastra": "aurigastro",
    "aurigastras": "aurigastro",
    "aurigastros": "aurigastro",
    "aurigos": "aurigo",
    "aurigários": "aurigário",
    "aurilavrada": "aurilavrado",
    "aurilavradas": "aurilavrado",
    "aurilavrados": "aurilavrado",
    "auriluzentes": "auriluzente",
    "aurimesclada": "aurimesclado",
    "aurimescladas": "aurimesclado",
    "aurimesclados": "aurimesclado",
    "auripenes": "auripene",
    "auripigmentos": "auripigmento",
    "auripúria": "auripúrio",
    "auripúrias": "auripúrio",
    "auripúrios": "auripúrio",
    "aurirosada": "aurirosado",
    "aurirosadas": "aurirosado",
    "aurirosados": "aurirosado",
    "aurirósea": "auriróseo",
    "auriróseas": "auriróseo",
    "auriróseos": "auriróseo",
    "aurisplendentes": "aurisplendente",
    "aurita": "aurito",
    "auritas": "aurito",
    "auriterapias": "auriterapia",
    "auritos": "aurito",
    "auritrémula": "auritrémulo",
    "auritrémulas": "auritrémulo",
    "auritrémulos": "auritrémulo",
    "auriverdes": "auriverde",
    "auroques": "auroque",
    "auroras": "aurora",
    "aurécias": "aurécia",
    "aurélias": "aurélia",
    "auréolas": "auréola",
    "aurícoma": "aurícomo",
    "aurícomas": "aurícomo",
    "aurícomos": "aurícomo",
    "aurícula": "aurículo",
    "aurículas": "aurículo",
    "aurículos": "aurículo",
    "aurífera": "aurífero",
    "auríferas": "aurífero",
    "auríferos": "aurífero",
    "aurífica": "aurífico",
    "auríficas": "aurífico",
    "aurífices": "aurífice",
    "auríficos": "aurífico",
    "aurígeas": "aurígea",
    "aurígera": "aurígero",
    "aurígeras": "aurígero",
    "aurígeros": "aurígero",
    "aurígicos": "aurígico",
    "ausculta": "auscultar",
    "auscultada": "auscultar",
    "auscultadas": "auscultar",
    "auscultado": "auscultar",
    "auscultadora": "auscultador",
    "auscultadoras": "auscultador",
    "auscultadores": "auscultador",
    "auscultados": "auscultar",
    "auscultai": "auscultar",
    "auscultais": "auscultar",
    "auscultam": "auscultar",
    "auscultamo": "auscultar",
    "auscultamos": "auscultar",
    "auscultando": "auscultar",
    "auscultara": "auscultar",
    "auscultaram": "auscultar",
    "auscultaras": "auscultar",
    "auscultarde": "auscultar",
    "auscultardes": "auscultar",
    "auscultare": "auscultar",
    "auscultarei": "auscultar",
    "auscultareis": "auscultar",
    "auscultarem": "auscultar",
    "auscultaremos": "auscultar",
    "auscultares": "auscultar",
    "auscultaria": "auscultar",
    "auscultariam": "auscultar",
    "auscultarias": "auscultar",
    "auscultarmo": "auscultar",
    "auscultarmos": "auscultar",
    "auscultará": "auscultar",
    "auscultarás": "auscultar",
    "auscultarão": "auscultar",
    "auscultaríamos": "auscultar",
    "auscultaríeis": "auscultar",
    "auscultas": "auscultar",
    "auscultasse": "auscultar",
    "auscultassem": "auscultar",
    "auscultasses": "auscultar",
    "auscultaste": "auscultar",
    "auscultastes": "auscultar",
    "auscultava": "auscultar",
    "auscultavam": "auscultar",
    "auscultavas": "auscultar",
    "auscultações": "auscultação",
    "ausculte": "auscultar",
    "auscultei": "auscultar",
    "ausculteis": "auscultar",
    "auscultem": "auscultar",
    "auscultemo": "auscultar",
    "auscultemos": "auscultar",
    "auscultes": "auscultar",
    "ausculto": "auscultar",
    "auscultou": "auscultar",
    "auscultá": "auscultar",
    "auscultámo": "auscultar",
    "auscultámos": "auscultar",
    "auscultáramo": "auscultar",
    "auscultáramos": "auscultar",
    "auscultárei": "auscultar",
    "auscultáreis": "auscultar",
    "auscultásseis": "auscultar",
    "auscultássemos": "auscultar",
    "auscultávamo": "auscultar",
    "auscultávamos": "auscultar",
    "auscultávei": "auscultar",
    "auscultáveis": "auscultar",
    "ausenta": "ausentar",
    "ausentada": "ausentar",
    "ausentadas": "ausentar",
    "ausentado": "ausentar",
    "ausentados": "ausentar",
    "ausentai": "ausentar",
    "ausentais": "ausentar",
    "ausentam": "ausentar",
    "ausentamo": "ausentar",
    "ausentamos": "ausentar",
    "ausentando": "ausentar",
    "ausentara": "ausentar",
    "ausentaram": "ausentar",
    "ausentaras": "ausentar",
    "ausentarde": "ausentar",
    "ausentardes": "ausentar",
    "ausentare": "ausentar",
    "ausentarei": "ausentar",
    "ausentareis": "ausentar",
    "ausentarem": "ausentar",
    "ausentaremos": "ausentar",
    "ausentares": "ausentar",
    "ausentaria": "ausentar",
    "ausentariam": "ausentar",
    "ausentarias": "ausentar",
    "ausentarmo": "ausentar",
    "ausentarmos": "ausentar",
    "ausentará": "ausentar",
    "ausentarás": "ausentar",
    "ausentarão": "ausentar",
    "ausentaríamos": "ausentar",
    "ausentaríeis": "ausentar",
    "ausentas": "ausentar",
    "ausentasse": "ausentar",
    "ausentassem": "ausentar",
    "ausentasses": "ausentar",
    "ausentaste": "ausentar",
    "ausentastes": "ausentar",
    "ausentava": "ausentar",
    "ausentavam": "ausentar",
    "ausentavas": "ausentar",
    "ausente": "ausentar",
    "ausentei": "ausentar",
    "ausenteis": "ausentar",
    "ausentem": "ausentar",
    "ausentemo": "ausentar",
    "ausentemos": "ausentar",
    "ausentes": "ausente",
    "ausento": "ausentar",
    "ausentou": "ausentar",
    "ausentá": "ausentar",
    "ausentámo": "ausentar",
    "ausentámos": "ausentar",
    "ausentáramo": "ausentar",
    "ausentáramos": "ausentar",
    "ausentárei": "ausentar",
    "ausentáreis": "ausentar",
    "ausentásseis": "ausentar",
    "ausentássemos": "ausentar",
    "ausentávamo": "ausentar",
    "ausentávamos": "ausentar",
    "ausentávei": "ausentar",
    "ausentáveis": "ausentar",
    "ausos": "auso",
    "auspicia": "auspiciar",
    "auspiciada": "auspiciar",
    "auspiciadas": "auspiciar",
    "auspiciado": "auspiciar",
    "auspiciados": "auspiciar",
    "auspiciai": "auspiciar",
    "auspiciais": "auspiciar",
    "auspiciam": "auspiciar",
    "auspiciamo": "auspiciar",
    "auspiciamos": "auspiciar",
    "auspiciando": "auspiciar",
    "auspiciara": "auspiciar",
    "auspiciaram": "auspiciar",
    "auspiciaras": "auspiciar",
    "auspiciardes": "auspiciar",
    "auspiciarei": "auspiciar",
    "auspiciareis": "auspiciar",
    "auspiciarem": "auspiciar",
    "auspiciaremos": "auspiciar",
    "auspiciares": "auspiciar",
    "auspiciaria": "auspiciar",
    "auspiciariam": "auspiciar",
    "auspiciarias": "auspiciar",
    "auspiciarmo": "auspiciar",
    "auspiciarmos": "auspiciar",
    "auspiciará": "auspiciar",
    "auspiciarás": "auspiciar",
    "auspiciarão": "auspiciar",
    "auspiciaríamos": "auspiciar",
    "auspiciaríeis": "auspiciar",
    "auspicias": "auspiciar",
    "auspiciasse": "auspiciar",
    "auspiciassem": "auspiciar",
    "auspiciasses": "auspiciar",
    "auspiciaste": "auspiciar",
    "auspiciastes": "auspiciar",
    "auspiciava": "auspiciar",
    "auspiciavam": "auspiciar",
    "auspiciavas": "auspiciar",
    "auspicie": "auspiciar",
    "auspiciei": "auspiciar",
    "auspicieis": "auspiciar",
    "auspiciem": "auspiciar",
    "auspiciemo": "auspiciar",
    "auspiciemos": "auspiciar",
    "auspicies": "auspiciar",
    "auspicio": "auspiciar",
    "auspiciosa": "auspicioso",
    "auspiciosas": "auspicioso",
    "auspiciosos": "auspicioso",
    "auspiciou": "auspiciar",
    "auspiciámo": "auspiciar",
    "auspiciámos": "auspiciar",
    "auspiciáramo": "auspiciar",
    "auspiciáramos": "auspiciar",
    "auspiciáreis": "auspiciar",
    "auspiciásseis": "auspiciar",
    "auspiciássemos": "auspiciar",
    "auspiciávamo": "auspiciar",
    "auspiciávamos": "auspiciar",
    "auspiciáveis": "auspiciar",
    "auspícios": "auspício",
    "austera": "austero",
    "austeras": "austero",
    "austeridades": "austeridade",
    "austeriza": "austerizar",
    "austerizada": "austerizar",
    "austerizadas": "austerizar",
    "austerizado": "austerizar",
    "austerizados": "austerizar",
    "austerizai": "austerizar",
    "austerizais": "austerizar",
    "austerizam": "austerizar",
    "austerizamo": "austerizar",
    "austerizamos": "austerizar",
    "austerizando": "austerizar",
    "austerizara": "austerizar",
    "austerizaram": "austerizar",
    "austerizaras": "austerizar",
    "austerizardes": "austerizar",
    "austerizarei": "austerizar",
    "austerizareis": "austerizar",
    "austerizarem": "austerizar",
    "austerizaremos": "austerizar",
    "austerizares": "austerizar",
    "austerizaria": "austerizar",
    "austerizariam": "austerizar",
    "austerizarias": "austerizar",
    "austerizarmo": "austerizar",
    "austerizarmos": "austerizar",
    "austerizará": "austerizar",
    "austerizarás": "austerizar",
    "austerizarão": "austerizar",
    "austerizaríamos": "austerizar",
    "austerizaríeis": "austerizar",
    "austerizas": "austerizar",
    "austerizasse": "austerizar",
    "austerizassem": "austerizar",
    "austerizasses": "austerizar",
    "austerizaste": "austerizar",
    "austerizastes": "austerizar",
    "austerizava": "austerizar",
    "austerizavam": "austerizar",
    "austerizavas": "austerizar",
    "austerize": "austerizar",
    "austerizei": "austerizar",
    "austerizeis": "austerizar",
    "austerizem": "austerizar",
    "austerizemo": "austerizar",
    "austerizemos": "austerizar",
    "austerizes": "austerizar",
    "austerizo": "austerizar",
    "austerizou": "austerizar",
    "austerizámo": "austerizar",
    "austerizámos": "austerizar",
    "austerizáramo": "austerizar",
    "austerizáramos": "austerizar",
    "austerizáreis": "austerizar",
    "austerizásseis": "austerizar",
    "austerizássemos": "austerizar",
    "austerizávamo": "austerizar",
    "austerizávamos": "austerizar",
    "austerizáveis": "austerizar",
    "austeros": "austero",
    "austrais": "austral",
    "australiana": "australiano",
    "australianas": "australiano",
    "australianos": "australiano",
    "austros": "austro",
    "austríaca": "austríaco",
    "austríacas": "austríaco",
    "austríacos": "austríaco",
    "ausências": "ausência",
    "autarcas": "autarca",
    "autarcias": "autarcia",
    "autarquias": "autarquia",
    "autarquica": "autarquico",
    "autarquicas": "autarquico",
    "autarquicos": "autarquico",
    "autentica": "autenticar",
    "autenticada": "autenticar",
    "autenticadas": "autenticar",
    "autenticado": "autenticar",
    "autenticados": "autenticar",
    "autenticai": "autenticar",
    "autenticais": "autenticar",
    "autenticam": "autenticar",
    "autenticamo": "autenticar",
    "autenticamos": "autenticar",
    "autenticando": "autenticar",
    "autenticara": "autenticar",
    "autenticaram": "autenticar",
    "autenticaras": "autenticar",
    "autenticarde": "autenticar",
    "autenticardes": "autenticar",
    "autenticare": "autenticar",
    "autenticarei": "autenticar",
    "autenticareis": "autenticar",
    "autenticarem": "autenticar",
    "autenticaremos": "autenticar",
    "autenticares": "autenticar",
    "autenticaria": "autenticar",
    "autenticariam": "autenticar",
    "autenticarias": "autenticar",
    "autenticarmo": "autenticar",
    "autenticarmos": "autenticar",
    "autenticará": "autenticar",
    "autenticarás": "autenticar",
    "autenticarão": "autenticar",
    "autenticaríamos": "autenticar",
    "autenticaríeis": "autenticar",
    "autenticas": "autenticar",
    "autenticasse": "autenticar",
    "autenticassem": "autenticar",
    "autenticasses": "autenticar",
    "autenticaste": "autenticar",
    "autenticastes": "autenticar",
    "autenticava": "autenticar",
    "autenticavam": "autenticar",
    "autenticavas": "autenticar",
    "autenticações": "autenticação",
    "autenticidades": "autenticidade",
    "autentico": "autenticar",
    "autenticou": "autenticar",
    "autenticá": "autenticar",
    "autenticámo": "autenticar",
    "autenticámos": "autenticar",
    "autenticáramo": "autenticar",
    "autenticáramos": "autenticar",
    "autenticárei": "autenticar",
    "autenticáreis": "autenticar",
    "autenticásseis": "autenticar",
    "autenticássemos": "autenticar",
    "autenticávamo": "autenticar",
    "autenticávamos": "autenticar",
    "autenticávei": "autenticar",
    "autenticáveis": "autenticar",
    "autentifica": "autentificar",
    "autentificada": "autentificar",
    "autentificadas": "autentificar",
    "autentificado": "autentificar",
    "autentificados": "autentificar",
    "autentificai": "autentificar",
    "autentificais": "autentificar",
    "autentificam": "autentificar",
    "autentificamo": "autentificar",
    "autentificamos": "autentificar",
    "autentificando": "autentificar",
    "autentificara": "autentificar",
    "autentificaram": "autentificar",
    "autentificaras": "autentificar",
    "autentificarde": "autentificar",
    "autentificardes": "autentificar",
    "autentificare": "autentificar",
    "autentificarei": "autentificar",
    "autentificareis": "autentificar",
    "autentificarem": "autentificar",
    "autentificaremos": "autentificar",
    "autentificares": "autentificar",
    "autentificaria": "autentificar",
    "autentificariam": "autentificar",
    "autentificarias": "autentificar",
    "autentificarmo": "autentificar",
    "autentificarmos": "autentificar",
    "autentificará": "autentificar",
    "autentificarás": "autentificar",
    "autentificarão": "autentificar",
    "autentificaríamos": "autentificar",
    "autentificaríeis": "autentificar",
    "autentificas": "autentificar",
    "autentificasse": "autentificar",
    "autentificassem": "autentificar",
    "autentificasses": "autentificar",
    "autentificaste": "autentificar",
    "autentificastes": "autentificar",
    "autentificava": "autentificar",
    "autentificavam": "autentificar",
    "autentificavas": "autentificar",
    "autentifico": "autentificar",
    "autentificou": "autentificar",
    "autentificá": "autentificar",
    "autentificámo": "autentificar",
    "autentificámos": "autentificar",
    "autentificáramo": "autentificar",
    "autentificáramos": "autentificar",
    "autentificárei": "autentificar",
    "autentificáreis": "autentificar",
    "autentificásseis": "autentificar",
    "autentificássemos": "autentificar",
    "autentificávamo": "autentificar",
    "autentificávamos": "autentificar",
    "autentificávei": "autentificar",
    "autentificáveis": "autentificável",
    "autentifique": "autentificar",
    "autentifiquei": "autentificar",
    "autentifiqueis": "autentificar",
    "autentifiquem": "autentificar",
    "autentifiquemo": "autentificar",
    "autentifiquemos": "autentificar",
    "autentifiques": "autentificar",
    "autentique": "autenticar",
    "autentiquei": "autenticar",
    "autentiqueis": "autenticar",
    "autentiquem": "autenticar",
    "autentiquemo": "autenticar",
    "autentiquemos": "autenticar",
    "autentiques": "autenticar",
    "autismos": "autismo",
    "autistas": "autista",
    "autobiografias": "autobiografia",
    "autobiográfica": "autobiográfico",
    "autobiográficas": "autobiográfico",
    "autobiográficos": "autobiográfico",
    "autobiógrafa": "autobiógrafo",
    "autobiógrafas": "autobiógrafo",
    "autobiógrafos": "autobiógrafo",
    "autocarros": "autocarro",
    "autocatálises": "autocatálise",
    "autocensuras": "autocensura",
    "autociclos": "autociclo",
    "autocineses": "autocinese",
    "autocinesias": "autocinesia",
    "autocitações": "autocitação",
    "autoclaves": "autoclave",
    "autoclismos": "autoclismo",
    "autoclínicas": "autoclínica",
    "autocolantes": "autocolante",
    "autocolimadores": "autocolimador",
    "autocombustões": "autocombustão",
    "autocomiserações": "autocomiseração",
    "autocomplacências": "autocomplacência",
    "autoconduções": "autocondução",
    "autoconfiantes": "autoconfiante",
    "autoconfianças": "autoconfiança",
    "autoconfina": "autoconfinar",
    "autoconfinada": "autoconfinar",
    "autoconfinadas": "autoconfinar",
    "autoconfinado": "autoconfinar",
    "autoconfinados": "autoconfinar",
    "autoconfinai": "autoconfinar",
    "autoconfinais": "autoconfinar",
    "autoconfinam": "autoconfinar",
    "autoconfinamo": "autoconfinar",
    "autoconfinamos": "autoconfinar",
    "autoconfinando": "autoconfinar",
    "autoconfinara": "autoconfinar",
    "autoconfinaram": "autoconfinar",
    "autoconfinaras": "autoconfinar",
    "autoconfinardes": "autoconfinar",
    "autoconfinarei": "autoconfinar",
    "autoconfinareis": "autoconfinar",
    "autoconfinarem": "autoconfinar",
    "autoconfinaremos": "autoconfinar",
    "autoconfinares": "autoconfinar",
    "autoconfinaria": "autoconfinar",
    "autoconfinariam": "autoconfinar",
    "autoconfinarias": "autoconfinar",
    "autoconfinarmo": "autoconfinar",
    "autoconfinarmos": "autoconfinar",
    "autoconfinará": "autoconfinar",
    "autoconfinarás": "autoconfinar",
    "autoconfinarão": "autoconfinar",
    "autoconfinaríamos": "autoconfinar",
    "autoconfinaríeis": "autoconfinar",
    "autoconfinas": "autoconfinar",
    "autoconfinasse": "autoconfinar",
    "autoconfinassem": "autoconfinar",
    "autoconfinasses": "autoconfinar",
    "autoconfinaste": "autoconfinar",
    "autoconfinastes": "autoconfinar",
    "autoconfinava": "autoconfinar",
    "autoconfinavam": "autoconfinar",
    "autoconfinavas": "autoconfinar",
    "autoconfine": "autoconfinar",
    "autoconfinei": "autoconfinar",
    "autoconfineis": "autoconfinar",
    "autoconfinem": "autoconfinar",
    "autoconfinemo": "autoconfinar",
    "autoconfinemos": "autoconfinar",
    "autoconfines": "autoconfinar",
    "autoconfino": "autoconfinar",
    "autoconfinou": "autoconfinar",
    "autoconfinámo": "autoconfinar",
    "autoconfinámos": "autoconfinar",
    "autoconfináramo": "autoconfinar",
    "autoconfináramos": "autoconfinar",
    "autoconfináreis": "autoconfinar",
    "autoconfinásseis": "autoconfinar",
    "autoconfinássemos": "autoconfinar",
    "autoconfinávamo": "autoconfinar",
    "autoconfinávamos": "autoconfinar",
    "autoconfináveis": "autoconfinar",
    "autoconsciências": "autoconsciência",
    "autoconsidera": "autoconsiderar",
    "autoconsiderada": "autoconsiderar",
    "autoconsideradas": "autoconsiderar",
    "autoconsiderado": "autoconsiderar",
    "autoconsiderados": "autoconsiderar",
    "autoconsiderai": "autoconsiderar",
    "autoconsiderais": "autoconsiderar",
    "autoconsideram": "autoconsiderar",
    "autoconsideramo": "autoconsiderar",
    "autoconsideramos": "autoconsiderar",
    "autoconsiderando": "autoconsiderar",
    "autoconsiderara": "autoconsiderar",
    "autoconsideraram": "autoconsiderar",
    "autoconsideraras": "autoconsiderar",
    "autoconsiderarde": "autoconsiderar",
    "autoconsiderardes": "autoconsiderar",
    "autoconsiderare": "autoconsiderar",
    "autoconsiderarei": "autoconsiderar",
    "autoconsiderareis": "autoconsiderar",
    "autoconsiderarem": "autoconsiderar",
    "autoconsideraremos": "autoconsiderar",
    "autoconsiderares": "autoconsiderar",
    "autoconsideraria": "autoconsiderar",
    "autoconsiderariam": "autoconsiderar",
    "autoconsiderarias": "autoconsiderar",
    "autoconsiderarmo": "autoconsiderar",
    "autoconsiderarmos": "autoconsiderar",
    "autoconsiderará": "autoconsiderar",
    "autoconsiderarás": "autoconsiderar",
    "autoconsiderarão": "autoconsiderar",
    "autoconsideraríamos": "autoconsiderar",
    "autoconsideraríeis": "autoconsiderar",
    "autoconsideras": "autoconsiderar",
    "autoconsiderasse": "autoconsiderar",
    "autoconsiderassem": "autoconsiderar",
    "autoconsiderasses": "autoconsiderar",
    "autoconsideraste": "autoconsiderar",
    "autoconsiderastes": "autoconsiderar",
    "autoconsiderava": "autoconsiderar",
    "autoconsideravam": "autoconsiderar",
    "autoconsideravas": "autoconsiderar",
    "autoconsidere": "autoconsiderar",
    "autoconsiderei": "autoconsiderar",
    "autoconsidereis": "autoconsiderar",
    "autoconsiderem": "autoconsiderar",
    "autoconsideremo": "autoconsiderar",
    "autoconsideremos": "autoconsiderar",
    "autoconsideres": "autoconsiderar",
    "autoconsidero": "autoconsiderar",
    "autoconsiderou": "autoconsiderar",
    "autoconsiderá": "autoconsiderar",
    "autoconsiderámo": "autoconsiderar",
    "autoconsiderámos": "autoconsiderar",
    "autoconsideráramo": "autoconsiderar",
    "autoconsideráramos": "autoconsiderar",
    "autoconsiderárei": "autoconsiderar",
    "autoconsideráreis": "autoconsiderar",
    "autoconsiderásseis": "autoconsiderar",
    "autoconsiderássemos": "autoconsiderar",
    "autoconsiderávamo": "autoconsiderar",
    "autoconsiderávamos": "autoconsiderar",
    "autoconsiderávei": "autoconsiderar",
    "autoconsideráveis": "autoconsiderar",
    "autoconstruções": "autoconstrução",
    "autocontemplações": "autocontemplação",
    "autocontenções": "autocontenção",
    "autocontratos": "autocontrato",
    "autocontroles": "autocontrole",
    "autocontrolos": "autocontrolo",
    "autoconvencimentos": "autoconvencimento",
    "autocopistas": "autocopista",
    "autocorrectores": "autocorrector",
    "autocorrecções": "autocorrecção",
    "autocracias": "autocracia",
    "autocratas": "autocrata",
    "autocratismos": "autocratismo",
    "autocritica": "autocriticar",
    "autocriticada": "autocriticar",
    "autocriticadas": "autocriticar",
    "autocriticado": "autocriticar",
    "autocriticados": "autocriticar",
    "autocriticai": "autocriticar",
    "autocriticais": "autocriticar",
    "autocriticam": "autocriticar",
    "autocriticamo": "autocriticar",
    "autocriticamos": "autocriticar",
    "autocriticando": "autocriticar",
    "autocriticara": "autocriticar",
    "autocriticaram": "autocriticar",
    "autocriticaras": "autocriticar",
    "autocriticarde": "autocriticar",
    "autocriticardes": "autocriticar",
    "autocriticare": "autocriticar",
    "autocriticarei": "autocriticar",
    "autocriticareis": "autocriticar",
    "autocriticarem": "autocriticar",
    "autocriticaremos": "autocriticar",
    "autocriticares": "autocriticar",
    "autocriticaria": "autocriticar",
    "autocriticariam": "autocriticar",
    "autocriticarias": "autocriticar",
    "autocriticarmo": "autocriticar",
    "autocriticarmos": "autocriticar",
    "autocriticará": "autocriticar",
    "autocriticarás": "autocriticar",
    "autocriticarão": "autocriticar",
    "autocriticaríamos": "autocriticar",
    "autocriticaríeis": "autocriticar",
    "autocriticas": "autocriticar",
    "autocriticasse": "autocriticar",
    "autocriticassem": "autocriticar",
    "autocriticasses": "autocriticar",
    "autocriticaste": "autocriticar",
    "autocriticastes": "autocriticar",
    "autocriticava": "autocriticar",
    "autocriticavam": "autocriticar",
    "autocriticavas": "autocriticar",
    "autocritico": "autocriticar",
    "autocriticou": "autocriticar",
    "autocriticá": "autocriticar",
    "autocriticámo": "autocriticar",
    "autocriticámos": "autocriticar",
    "autocriticáramo": "autocriticar",
    "autocriticáramos": "autocriticar",
    "autocriticárei": "autocriticar",
    "autocriticáreis": "autocriticar",
    "autocriticásseis": "autocriticar",
    "autocriticássemos": "autocriticar",
    "autocriticávamo": "autocriticar",
    "autocriticávamos": "autocriticar",
    "autocriticávei": "autocriticar",
    "autocriticáveis": "autocriticar",
    "autocritique": "autocriticar",
    "autocritiquei": "autocriticar",
    "autocritiqueis": "autocriticar",
    "autocritiquem": "autocriticar",
    "autocritiquemo": "autocriticar",
    "autocritiquemos": "autocriticar",
    "autocritiques": "autocriticar",
    "autocromias": "autocromia",
    "autocrática": "autocrático",
    "autocráticas": "autocrático",
    "autocráticos": "autocrático",
    "autocríticas": "autocrítica",
    "autoctonias": "autoctonia",
    "autoctonismos": "autoctonismo",
    "autocéfala": "autocéfalo",
    "autocéfalas": "autocéfalo",
    "autocéfalos": "autocéfalo",
    "autocópias": "autocópia",
    "autodecomposições": "autodecomposição",
    "autodefesas": "autodefesa",
    "autodefinida": "autodefinido",
    "autodefinidas": "autodefinido",
    "autodefinidos": "autodefinido",
    "autodenominada": "autodenominado",
    "autodenominadas": "autodenominado",
    "autodenominados": "autodenominado",
    "autodesignada": "autodesignado",
    "autodesignadas": "autodesignado",
    "autodesignados": "autodesignado",
    "autodestri": "autodestruir",
    "autodestroem": "autodestruir",
    "autodestrua": "autodestruir",
    "autodestruais": "autodestruir",
    "autodestruam": "autodestruir",
    "autodestruamo": "autodestruir",
    "autodestruamos": "autodestruir",
    "autodestruas": "autodestruir",
    "autodestruem": "autodestruir",
    "autodestrui": "autodestruir",
    "autodestruindo": "autodestruir",
    "autodestruirde": "autodestruir",
    "autodestruirdes": "autodestruir",
    "autodestruirei": "autodestruir",
    "autodestruireis": "autodestruir",
    "autodestruiremos": "autodestruir",
    "autodestruiria": "autodestruir",
    "autodestruiriam": "autodestruir",
    "autodestruirias": "autodestruir",
    "autodestruirmo": "autodestruir",
    "autodestruirmos": "autodestruir",
    "autodestruirá": "autodestruir",
    "autodestruirás": "autodestruir",
    "autodestruirão": "autodestruir",
    "autodestruiríamos": "autodestruir",
    "autodestruiríeis": "autodestruir",
    "autodestruis": "autodestruir",
    "autodestruiu": "autodestruir",
    "autodestruições": "autodestruição",
    "autodestruo": "autodestruir",
    "autodestrutiva": "autodestrutivo",
    "autodestrutivas": "autodestrutivo",
    "autodestrutivos": "autodestrutivo",
    "autodestruí": "autodestruir",
    "autodestruía": "autodestruir",
    "autodestruíam": "autodestruir",
    "autodestruíamo": "autodestruir",
    "autodestruíamos": "autodestruir",
    "autodestruías": "autodestruir",
    "autodestruída": "autodestruir",
    "autodestruídas": "autodestruir",
    "autodestruído": "autodestruir",
    "autodestruídos": "autodestruir",
    "autodestruíei": "autodestruir",
    "autodestruíeis": "autodestruir",
    "autodestruímo": "autodestruir",
    "autodestruímos": "autodestruir",
    "autodestruíra": "autodestruir",
    "autodestruíram": "autodestruir",
    "autodestruíramo": "autodestruir",
    "autodestruíramos": "autodestruir",
    "autodestruíras": "autodestruir",
    "autodestruíre": "autodestruir",
    "autodestruírei": "autodestruir",
    "autodestruíreis": "autodestruir",
    "autodestruírem": "autodestruir",
    "autodestruíres": "autodestruir",
    "autodestruís": "autodestruir",
    "autodestruísse": "autodestruir",
    "autodestruísseis": "autodestruir",
    "autodestruíssem": "autodestruir",
    "autodestruíssemos": "autodestruir",
    "autodestruísses": "autodestruir",
    "autodestruíste": "autodestruir",
    "autodestruístes": "autodestruir",
    "autodestrói": "autodestruir",
    "autodestróis": "autodestruir",
    "autodeterminações": "autodeterminação",
    "autodeterminismos": "autodeterminismo",
    "autodidactas": "autodidacta",
    "autodidactismos": "autodidactismo",
    "autodidaxias": "autodidaxia",
    "autodidáctica": "autodidáctico",
    "autodidácticas": "autodidáctico",
    "autodidácticos": "autodidáctico",
    "autodigestões": "autodigestão",
    "autodinamias": "autodinamia",
    "autodinâmica": "autodinâmico",
    "autodinâmicas": "autodinâmico",
    "autodinâmicos": "autodinâmico",
    "autodisciplinas": "autodisciplina",
    "autodissolva": "autodissolver",
    "autodissolvais": "autodissolver",
    "autodissolvam": "autodissolver",
    "autodissolvamo": "autodissolver",
    "autodissolvamos": "autodissolver",
    "autodissolvas": "autodissolver",
    "autodissolve": "autodissolver",
    "autodissolvei": "autodissolver",
    "autodissolveis": "autodissolver",
    "autodissolvem": "autodissolver",
    "autodissolvemo": "autodissolver",
    "autodissolvemos": "autodissolver",
    "autodissolvendo": "autodissolver",
    "autodissolvera": "autodissolver",
    "autodissolveram": "autodissolver",
    "autodissolveras": "autodissolver",
    "autodissolverde": "autodissolver",
    "autodissolverdes": "autodissolver",
    "autodissolvere": "autodissolver",
    "autodissolverei": "autodissolver",
    "autodissolvereis": "autodissolver",
    "autodissolverem": "autodissolver",
    "autodissolveremos": "autodissolver",
    "autodissolveres": "autodissolver",
    "autodissolveria": "autodissolver",
    "autodissolveriam": "autodissolver",
    "autodissolverias": "autodissolver",
    "autodissolvermo": "autodissolver",
    "autodissolvermos": "autodissolver",
    "autodissolverá": "autodissolver",
    "autodissolverás": "autodissolver",
    "autodissolverão": "autodissolver",
    "autodissolveríamos": "autodissolver",
    "autodissolveríeis": "autodissolver",
    "autodissolves": "autodissolver",
    "autodissolvesse": "autodissolver",
    "autodissolvessem": "autodissolver",
    "autodissolvesses": "autodissolver",
    "autodissolveste": "autodissolver",
    "autodissolvestes": "autodissolver",
    "autodissolveu": "autodissolver",
    "autodissolvi": "autodissolver",
    "autodissolvia": "autodissolver",
    "autodissolviam": "autodissolver",
    "autodissolvias": "autodissolver",
    "autodissolvida": "autodissolver",
    "autodissolvidas": "autodissolver",
    "autodissolvido": "autodissolver",
    "autodissolvidos": "autodissolver",
    "autodissolvo": "autodissolver",
    "autodissolvê": "autodissolver",
    "autodissolvêramo": "autodissolver",
    "autodissolvêramos": "autodissolver",
    "autodissolvêrei": "autodissolver",
    "autodissolvêreis": "autodissolver",
    "autodissolvêsseis": "autodissolver",
    "autodissolvêssemos": "autodissolver",
    "autodissolvíamo": "autodissolver",
    "autodissolvíamos": "autodissolver",
    "autodissolvíei": "autodissolver",
    "autodissolvíeis": "autodissolver",
    "autodomínios": "autodomínio",
    "autoestimas": "autoestima",
    "autoestradas": "autoestrada",
    "autofagias": "autofagia",
    "autofalências": "autofalência",
    "autofecundações": "autofecundação",
    "autofilias": "autofilia",
    "autofilismos": "autofilismo",
    "autofinancia": "autofinanciar",
    "autofinanciada": "autofinanciar",
    "autofinanciadas": "autofinanciar",
    "autofinanciado": "autofinanciar",
    "autofinanciados": "autofinanciar",
    "autofinanciai": "autofinanciar",
    "autofinanciais": "autofinanciar",
    "autofinanciam": "autofinanciar",
    "autofinanciamentos": "autofinanciamento",
    "autofinanciamo": "autofinanciar",
    "autofinanciamos": "autofinanciar",
    "autofinanciando": "autofinanciar",
    "autofinanciara": "autofinanciar",
    "autofinanciaram": "autofinanciar",
    "autofinanciaras": "autofinanciar",
    "autofinanciarde": "autofinanciar",
    "autofinanciardes": "autofinanciar",
    "autofinanciare": "autofinanciar",
    "autofinanciarei": "autofinanciar",
    "autofinanciareis": "autofinanciar",
    "autofinanciarem": "autofinanciar",
    "autofinanciaremos": "autofinanciar",
    "autofinanciares": "autofinanciar",
    "autofinanciaria": "autofinanciar",
    "autofinanciariam": "autofinanciar",
    "autofinanciarias": "autofinanciar",
    "autofinanciarmo": "autofinanciar",
    "autofinanciarmos": "autofinanciar",
    "autofinanciará": "autofinanciar",
    "autofinanciarás": "autofinanciar",
    "autofinanciarão": "autofinanciar",
    "autofinanciaríamos": "autofinanciar",
    "autofinanciaríeis": "autofinanciar",
    "autofinancias": "autofinanciar",
    "autofinanciasse": "autofinanciar",
    "autofinanciassem": "autofinanciar",
    "autofinanciasses": "autofinanciar",
    "autofinanciaste": "autofinanciar",
    "autofinanciastes": "autofinanciar",
    "autofinanciava": "autofinanciar",
    "autofinanciavam": "autofinanciar",
    "autofinanciavas": "autofinanciar",
    "autofinancie": "autofinanciar",
    "autofinanciei": "autofinanciar",
    "autofinancieis": "autofinanciar",
    "autofinanciem": "autofinanciar",
    "autofinanciemo": "autofinanciar",
    "autofinanciemos": "autofinanciar",
    "autofinancies": "autofinanciar",
    "autofinancio": "autofinanciar",
    "autofinanciou": "autofinanciar",
    "autofinanciá": "autofinanciar",
    "autofinanciámo": "autofinanciar",
    "autofinanciámos": "autofinanciar",
    "autofinanciáramo": "autofinanciar",
    "autofinanciáramos": "autofinanciar",
    "autofinanciárei": "autofinanciar",
    "autofinanciáreis": "autofinanciar",
    "autofinanciásseis": "autofinanciar",
    "autofinanciássemos": "autofinanciar",
    "autofinanciávamo": "autofinanciar",
    "autofinanciávamos": "autofinanciar",
    "autofinanciávei": "autofinanciar",
    "autofinanciáveis": "autofinanciar",
    "autoflagelações": "autoflagelação",
    "autofotografias": "autofotografia",
    "autofunções": "autofunção",
    "autofágica": "autofágico",
    "autofágicas": "autofágico",
    "autofágicos": "autofágico",
    "autogamias": "autogamia",
    "autogenética": "autogenético",
    "autogenéticas": "autogenético",
    "autogenéticos": "autogenético",
    "autogerida": "autogerido",
    "autogeridas": "autogerido",
    "autogeridos": "autogerido",
    "autogestões": "autogestão",
    "autogiros": "autogiro",
    "autognoses": "autognose",
    "autografa": "autografar",
    "autografada": "autografar",
    "autografadas": "autografar",
    "autografado": "autografar",
    "autografados": "autografar",
    "autografai": "autografar",
    "autografais": "autografar",
    "autografam": "autografar",
    "autografamo": "autografar",
    "autografamos": "autografar",
    "autografando": "autografar",
    "autografara": "autografar",
    "autografaram": "autografar",
    "autografaras": "autografar",
    "autografarde": "autografar",
    "autografardes": "autografar",
    "autografare": "autografar",
    "autografarei": "autografar",
    "autografareis": "autografar",
    "autografarem": "autografar",
    "autografaremos": "autografar",
    "autografares": "autografar",
    "autografaria": "autografar",
    "autografariam": "autografar",
    "autografarias": "autografar",
    "autografarmo": "autografar",
    "autografarmos": "autografar",
    "autografará": "autografar",
    "autografarás": "autografar",
    "autografarão": "autografar",
    "autografaríamos": "autografar",
    "autografaríeis": "autografar",
    "autografas": "autografar",
    "autografasse": "autografar",
    "autografassem": "autografar",
    "autografasses": "autografar",
    "autografaste": "autografar",
    "autografastes": "autografar",
    "autografava": "autografar",
    "autografavam": "autografar",
    "autografavas": "autografar",
    "autografe": "autografar",
    "autografei": "autografar",
    "autografeis": "autografar",
    "autografem": "autografar",
    "autografemo": "autografar",
    "autografemos": "autografar",
    "autografes": "autografar",
    "autografias": "autografia",
    "autografo": "autografar",
    "autografomanias": "autografomania",
    "autografomaníaca": "autografomaníaco",
    "autografomaníacas": "autografomaníaco",
    "autografomaníacos": "autografomaníaco",
    "autografou": "autografar",
    "autografá": "autografar",
    "autografámo": "autografar",
    "autografámos": "autografar",
    "autografáramo": "autografar",
    "autografáramos": "autografar",
    "autografárei": "autografar",
    "autografáreis": "autografar",
    "autografásseis": "autografar",
    "autografássemos": "autografar",
    "autografávamo": "autografar",
    "autografávamos": "autografar",
    "autografávei": "autografar",
    "autografáveis": "autografar",
    "autográfica": "autográfico",
    "autográficas": "autográfico",
    "autográficos": "autográfico",
    "autogéneses": "autogénese",
    "autogénia": "autogénio",
    "autogénias": "autogénio",
    "autogénios": "autogénio",
    "autolatrias": "autolatria",
    "autolábios": "autolábio",
    "autolítica": "autolítico",
    "autolíticas": "autolítico",
    "autolíticos": "autolítico",
    "automacas": "automaca",
    "automarginaliza": "automarginalizar",
    "automarginalizada": "automarginalizar",
    "automarginalizadas": "automarginalizar",
    "automarginalizado": "automarginalizar",
    "automarginalizados": "automarginalizar",
    "automarginalizai": "automarginalizar",
    "automarginalizais": "automarginalizar",
    "automarginalizam": "automarginalizar",
    "automarginalizamo": "automarginalizar",
    "automarginalizamos": "automarginalizar",
    "automarginalizando": "automarginalizar",
    "automarginalizara": "automarginalizar",
    "automarginalizaram": "automarginalizar",
    "automarginalizaras": "automarginalizar",
    "automarginalizarde": "automarginalizar",
    "automarginalizardes": "automarginalizar",
    "automarginalizare": "automarginalizar",
    "automarginalizarei": "automarginalizar",
    "automarginalizareis": "automarginalizar",
    "automarginalizarem": "automarginalizar",
    "automarginalizaremos": "automarginalizar",
    "automarginalizares": "automarginalizar",
    "automarginalizaria": "automarginalizar",
    "automarginalizariam": "automarginalizar",
    "automarginalizarias": "automarginalizar",
    "automarginalizarmo": "automarginalizar",
    "automarginalizarmos": "automarginalizar",
    "automarginalizará": "automarginalizar",
    "automarginalizarás": "automarginalizar",
    "automarginalizarão": "automarginalizar",
    "automarginalizaríamos": "automarginalizar",
    "automarginalizaríeis": "automarginalizar",
    "automarginalizas": "automarginalizar",
    "automarginalizasse": "automarginalizar",
    "automarginalizassem": "automarginalizar",
    "automarginalizasses": "automarginalizar",
    "automarginalizaste": "automarginalizar",
    "automarginalizastes": "automarginalizar",
    "automarginalizava": "automarginalizar",
    "automarginalizavam": "automarginalizar",
    "automarginalizavas": "automarginalizar",
    "automarginalize": "automarginalizar",
    "automarginalizei": "automarginalizar",
    "automarginalizeis": "automarginalizar",
    "automarginalizem": "automarginalizar",
    "automarginalizemo": "automarginalizar",
    "automarginalizemos": "automarginalizar",
    "automarginalizes": "automarginalizar",
    "automarginalizo": "automarginalizar",
    "automarginalizou": "automarginalizar",
    "automarginalizá": "automarginalizar",
    "automarginalizámo": "automarginalizar",
    "automarginalizámos": "automarginalizar",
    "automarginalizáramo": "automarginalizar",
    "automarginalizáramos": "automarginalizar",
    "automarginalizárei": "automarginalizar",
    "automarginalizáreis": "automarginalizar",
    "automarginalizásseis": "automarginalizar",
    "automarginalizássemos": "automarginalizar",
    "automarginalizávamo": "automarginalizar",
    "automarginalizávamos": "automarginalizar",
    "automarginalizávei": "automarginalizar",
    "automarginalizáveis": "automarginalizar",
    "automaticidades": "automaticidade",
    "automatismos": "automatismo",
    "automatiza": "automatizar",
    "automatizada": "automatizar",
    "automatizadas": "automatizar",
    "automatizado": "automatizar",
    "automatizados": "automatizar",
    "automatizai": "automatizar",
    "automatizais": "automatizar",
    "automatizam": "automatizar",
    "automatizamo": "automatizar",
    "automatizamos": "automatizar",
    "automatizando": "automatizar",
    "automatizara": "automatizar",
    "automatizaram": "automatizar",
    "automatizaras": "automatizar",
    "automatizarde": "automatizar",
    "automatizardes": "automatizar",
    "automatizare": "automatizar",
    "automatizarei": "automatizar",
    "automatizareis": "automatizar",
    "automatizarem": "automatizar",
    "automatizaremos": "automatizar",
    "automatizares": "automatizar",
    "automatizaria": "automatizar",
    "automatizariam": "automatizar",
    "automatizarias": "automatizar",
    "automatizarmo": "automatizar",
    "automatizarmos": "automatizar",
    "automatizará": "automatizar",
    "automatizarás": "automatizar",
    "automatizarão": "automatizar",
    "automatizaríamos": "automatizar",
    "automatizaríeis": "automatizar",
    "automatizas": "automatizar",
    "automatizasse": "automatizar",
    "automatizassem": "automatizar",
    "automatizasses": "automatizar",
    "automatizaste": "automatizar",
    "automatizastes": "automatizar",
    "automatizava": "automatizar",
    "automatizavam": "automatizar",
    "automatizavas": "automatizar",
    "automatizações": "automatização",
    "automatize": "automatizar",
    "automatizei": "automatizar",
    "automatizeis": "automatizar",
    "automatizem": "automatizar",
    "automatizemo": "automatizar",
    "automatizemos": "automatizar",
    "automatizes": "automatizar",
    "automatizo": "automatizar",
    "automatizou": "automatizar",
    "automatizá": "automatizar",
    "automatizámo": "automatizar",
    "automatizámos": "automatizar",
    "automatizáramo": "automatizar",
    "automatizáramos": "automatizar",
    "automatizárei": "automatizar",
    "automatizáreis": "automatizar",
    "automatizásseis": "automatizar",
    "automatizássemos": "automatizar",
    "automatizávamo": "automatizar",
    "automatizávamos": "automatizar",
    "automatizávei": "automatizar",
    "automatizáveis": "automatizável",
    "automações": "automação",
    "automedica": "automedicar",
    "automedicada": "automedicar",
    "automedicadas": "automedicar",
    "automedicado": "automedicar",
    "automedicados": "automedicar",
    "automedicai": "automedicar",
    "automedicais": "automedicar",
    "automedicam": "automedicar",
    "automedicamo": "automedicar",
    "automedicamos": "automedicar",
    "automedicando": "automedicar",
    "automedicara": "automedicar",
    "automedicaram": "automedicar",
    "automedicaras": "automedicar",
    "automedicarde": "automedicar",
    "automedicardes": "automedicar",
    "automedicare": "automedicar",
    "automedicarei": "automedicar",
    "automedicareis": "automedicar",
    "automedicarem": "automedicar",
    "automedicaremos": "automedicar",
    "automedicares": "automedicar",
    "automedicaria": "automedicar",
    "automedicariam": "automedicar",
    "automedicarias": "automedicar",
    "automedicarmo": "automedicar",
    "automedicarmos": "automedicar",
    "automedicará": "automedicar",
    "automedicarás": "automedicar",
    "automedicarão": "automedicar",
    "automedicaríamos": "automedicar",
    "automedicaríeis": "automedicar",
    "automedicas": "automedicar",
    "automedicasse": "automedicar",
    "automedicassem": "automedicar",
    "automedicasses": "automedicar",
    "automedicaste": "automedicar",
    "automedicastes": "automedicar",
    "automedicava": "automedicar",
    "automedicavam": "automedicar",
    "automedicavas": "automedicar",
    "automedicações": "automedicação",
    "automedico": "automedicar",
    "automedicou": "automedicar",
    "automedicá": "automedicar",
    "automedicámo": "automedicar",
    "automedicámos": "automedicar",
    "automedicáramo": "automedicar",
    "automedicáramos": "automedicar",
    "automedicárei": "automedicar",
    "automedicáreis": "automedicar",
    "automedicásseis": "automedicar",
    "automedicássemos": "automedicar",
    "automedicávamo": "automedicar",
    "automedicávamos": "automedicar",
    "automedicávei": "automedicar",
    "automedicáveis": "automedicar",
    "automedique": "automedicar",
    "automediquei": "automedicar",
    "automediqueis": "automedicar",
    "automediquem": "automedicar",
    "automediquemo": "automedicar",
    "automediquemos": "automedicar",
    "automediques": "automedicar",
    "automedontes": "automedonte",
    "autometralhadoras": "autometralhadora",
    "automobilismos": "automobilismo",
    "automobilistas": "automobilista",
    "automobilística": "automobilístico",
    "automobilísticas": "automobilístico",
    "automobilísticos": "automobilístico",
    "automorfa": "automorfo",
    "automorfas": "automorfo",
    "automorfismos": "automorfismo",
    "automorfos": "automorfo",
    "automotora": "automotor",
    "automotoras": "automotora",
    "automotores": "automotor",
    "automática": "automático",
    "automáticas": "automático",
    "automáticos": "automático",
    "automórfica": "automórfico",
    "automórficas": "automórfico",
    "automórficos": "automórfico",
    "automóveis": "automóvel",
    "autonomeada": "autonomeado",
    "autonomeadas": "autonomeado",
    "autonomeados": "autonomeado",
    "autonomias": "autonomia",
    "autonomismos": "autonomismo",
    "autonomistas": "autonomista",
    "autonomiza": "autonomizar",
    "autonomizada": "autonomizar",
    "autonomizadas": "autonomizar",
    "autonomizado": "autonomizar",
    "autonomizados": "autonomizar",
    "autonomizai": "autonomizar",
    "autonomizais": "autonomizar",
    "autonomizam": "autonomizar",
    "autonomizamo": "autonomizar",
    "autonomizamos": "autonomizar",
    "autonomizando": "autonomizar",
    "autonomizara": "autonomizar",
    "autonomizaram": "autonomizar",
    "autonomizaras": "autonomizar",
    "autonomizarde": "autonomizar",
    "autonomizardes": "autonomizar",
    "autonomizare": "autonomizar",
    "autonomizarei": "autonomizar",
    "autonomizareis": "autonomizar",
    "autonomizarem": "autonomizar",
    "autonomizaremos": "autonomizar",
    "autonomizares": "autonomizar",
    "autonomizaria": "autonomizar",
    "autonomizariam": "autonomizar",
    "autonomizarias": "autonomizar",
    "autonomizarmo": "autonomizar",
    "autonomizarmos": "autonomizar",
    "autonomizará": "autonomizar",
    "autonomizarás": "autonomizar",
    "autonomizarão": "autonomizar",
    "autonomizaríamos": "autonomizar",
    "autonomizaríeis": "autonomizar",
    "autonomizas": "autonomizar",
    "autonomizasse": "autonomizar",
    "autonomizassem": "autonomizar",
    "autonomizasses": "autonomizar",
    "autonomizaste": "autonomizar",
    "autonomizastes": "autonomizar",
    "autonomizava": "autonomizar",
    "autonomizavam": "autonomizar",
    "autonomizavas": "autonomizar",
    "autonomizações": "autonomização",
    "autonomize": "autonomizar",
    "autonomizei": "autonomizar",
    "autonomizeis": "autonomizar",
    "autonomizem": "autonomizar",
    "autonomizemo": "autonomizar",
    "autonomizemos": "autonomizar",
    "autonomizes": "autonomizar",
    "autonomizo": "autonomizar",
    "autonomizou": "autonomizar",
    "autonomizá": "autonomizar",
    "autonomizámo": "autonomizar",
    "autonomizámos": "autonomizar",
    "autonomizáramo": "autonomizar",
    "autonomizáramos": "autonomizar",
    "autonomizárei": "autonomizar",
    "autonomizáreis": "autonomizar",
    "autonomizásseis": "autonomizar",
    "autonomizássemos": "autonomizar",
    "autonomizávamo": "autonomizar",
    "autonomizávamos": "autonomizar",
    "autonomizávei": "autonomizar",
    "autonomizáveis": "autonomizar",
    "autonómica": "autonómico",
    "autonómicas": "autonómico",
    "autonómicos": "autonómico",
    "autopatas": "autopata",
    "autopatias": "autopatia",
    "autopianos": "autopiano",
    "autopistas": "autopista",
    "autoplastias": "autoplastia",
    "autoproclama": "autoproclamar",
    "autoproclamada": "autoproclamar",
    "autoproclamadas": "autoproclamar",
    "autoproclamado": "autoproclamar",
    "autoproclamados": "autoproclamar",
    "autoproclamai": "autoproclamar",
    "autoproclamais": "autoproclamar",
    "autoproclamam": "autoproclamar",
    "autoproclamamo": "autoproclamar",
    "autoproclamamos": "autoproclamar",
    "autoproclamando": "autoproclamar",
    "autoproclamara": "autoproclamar",
    "autoproclamaram": "autoproclamar",
    "autoproclamaras": "autoproclamar",
    "autoproclamarde": "autoproclamar",
    "autoproclamardes": "autoproclamar",
    "autoproclamare": "autoproclamar",
    "autoproclamarei": "autoproclamar",
    "autoproclamareis": "autoproclamar",
    "autoproclamarem": "autoproclamar",
    "autoproclamaremos": "autoproclamar",
    "autoproclamares": "autoproclamar",
    "autoproclamaria": "autoproclamar",
    "autoproclamariam": "autoproclamar",
    "autoproclamarias": "autoproclamar",
    "autoproclamarmo": "autoproclamar",
    "autoproclamarmos": "autoproclamar",
    "autoproclamará": "autoproclamar",
    "autoproclamarás": "autoproclamar",
    "autoproclamarão": "autoproclamar",
    "autoproclamaríamos": "autoproclamar",
    "autoproclamaríeis": "autoproclamar",
    "autoproclamas": "autoproclamar",
    "autoproclamasse": "autoproclamar",
    "autoproclamassem": "autoproclamar",
    "autoproclamasses": "autoproclamar",
    "autoproclamaste": "autoproclamar",
    "autoproclamastes": "autoproclamar",
    "autoproclamava": "autoproclamar",
    "autoproclamavam": "autoproclamar",
    "autoproclamavas": "autoproclamar",
    "autoproclame": "autoproclamar",
    "autoproclamei": "autoproclamar",
    "autoproclameis": "autoproclamar",
    "autoproclamem": "autoproclamar",
    "autoproclamemo": "autoproclamar",
    "autoproclamemos": "autoproclamar",
    "autoproclames": "autoproclamar",
    "autoproclamo": "autoproclamar",
    "autoproclamou": "autoproclamar",
    "autoproclamá": "autoproclamar",
    "autoproclamámo": "autoproclamar",
    "autoproclamámos": "autoproclamar",
    "autoproclamáramo": "autoproclamar",
    "autoproclamáramos": "autoproclamar",
    "autoproclamárei": "autoproclamar",
    "autoproclamáreis": "autoproclamar",
    "autoproclamásseis": "autoproclamar",
    "autoproclamássemos": "autoproclamar",
    "autoproclamávamo": "autoproclamar",
    "autoproclamávamos": "autoproclamar",
    "autoproclamávei": "autoproclamar",
    "autoproclamáveis": "autoproclamar",
    "autopromovida": "autopromovido",
    "autopromovidas": "autopromovido",
    "autopromovidos": "autopromovido",
    "autopromoções": "autopromoção",
    "autoproposta": "autoproposto",
    "autopropostas": "autoproposto",
    "autopropostos": "autoproposto",
    "autopsia": "autopsiar",
    "autopsiada": "autopsiar",
    "autopsiadas": "autopsiar",
    "autopsiado": "autopsiar",
    "autopsiados": "autopsiar",
    "autopsiai": "autopsiar",
    "autopsiais": "autopsiar",
    "autopsiam": "autopsiar",
    "autopsiamo": "autopsiar",
    "autopsiamos": "autopsiar",
    "autopsiando": "autopsiar",
    "autopsiara": "autopsiar",
    "autopsiaram": "autopsiar",
    "autopsiaras": "autopsiar",
    "autopsiarde": "autopsiar",
    "autopsiardes": "autopsiar",
    "autopsiare": "autopsiar",
    "autopsiarei": "autopsiar",
    "autopsiareis": "autopsiar",
    "autopsiarem": "autopsiar",
    "autopsiaremos": "autopsiar",
    "autopsiares": "autopsiar",
    "autopsiaria": "autopsiar",
    "autopsiariam": "autopsiar",
    "autopsiarias": "autopsiar",
    "autopsiarmo": "autopsiar",
    "autopsiarmos": "autopsiar",
    "autopsiará": "autopsiar",
    "autopsiarás": "autopsiar",
    "autopsiarão": "autopsiar",
    "autopsiaríamos": "autopsiar",
    "autopsiaríeis": "autopsiar",
    "autopsias": "autopsiar",
    "autopsiasse": "autopsiar",
    "autopsiassem": "autopsiar",
    "autopsiasses": "autopsiar",
    "autopsiaste": "autopsiar",
    "autopsiastes": "autopsiar",
    "autopsiava": "autopsiar",
    "autopsiavam": "autopsiar",
    "autopsiavas": "autopsiar",
    "autopsie": "autopsiar",
    "autopsiei": "autopsiar",
    "autopsieis": "autopsiar",
    "autopsiem": "autopsiar",
    "autopsiemo": "autopsiar",
    "autopsiemos": "autopsiar",
    "autopsies": "autopsiar",
    "autopsio": "autopsiar",
    "autopsiou": "autopsiar",
    "autopsiá": "autopsiar",
    "autopsiámo": "autopsiar",
    "autopsiámos": "autopsiar",
    "autopsiáramo": "autopsiar",
    "autopsiáramos": "autopsiar",
    "autopsiárei": "autopsiar",
    "autopsiáreis": "autopsiar",
    "autopsiásseis": "autopsiar",
    "autopsiássemos": "autopsiar",
    "autopsiávamo": "autopsiar",
    "autopsiávamos": "autopsiar",
    "autopsiávei": "autopsiar",
    "autopsiáveis": "autopsiar",
    "autopática": "autopático",
    "autopáticas": "autopático",
    "autopáticos": "autopático",
    "autora": "autor",
    "autorais": "autoral",
    "autoramas": "autorama",
    "autoras": "autor",
    "autores": "autor",
    "autorias": "autoria",
    "autoricidas": "autoricida",
    "autoridades": "autoridade",
    "autoritarismos": "autoritarismo",
    "autoritaristas": "autoritarista",
    "autoritária": "autoritário",
    "autoritárias": "autoritário",
    "autoritários": "autoritário",
    "autoriza": "autorizar",
    "autorizada": "autorizar",
    "autorizadas": "autorizar",
    "autorizado": "autorizar",
    "autorizadora": "autorizador",
    "autorizadoras": "autorizador",
    "autorizadores": "autorizador",
    "autorizados": "autorizar",
    "autorizadíssima": "autorizado",
    "autorizadíssimas": "autorizado",
    "autorizadíssimo": "autorizado",
    "autorizadíssimos": "autorizado",
    "autorizai": "autorizar",
    "autorizais": "autorizar",
    "autorizam": "autorizar",
    "autorizamo": "autorizar",
    "autorizamos": "autorizar",
    "autorizando": "autorizar",
    "autorizara": "autorizar",
    "autorizaram": "autorizar",
    "autorizaras": "autorizar",
    "autorizarde": "autorizar",
    "autorizardes": "autorizar",
    "autorizare": "autorizar",
    "autorizarei": "autorizar",
    "autorizareis": "autorizar",
    "autorizarem": "autorizar",
    "autorizaremos": "autorizar",
    "autorizares": "autorizar",
    "autorizaria": "autorizar",
    "autorizariam": "autorizar",
    "autorizarias": "autorizar",
    "autorizarmo": "autorizar",
    "autorizarmos": "autorizar",
    "autorizará": "autorizar",
    "autorizarás": "autorizar",
    "autorizarão": "autorizar",
    "autorizaríamos": "autorizar",
    "autorizaríeis": "autorizar",
    "autorizas": "autorizar",
    "autorizasse": "autorizar",
    "autorizassem": "autorizar",
    "autorizasses": "autorizar",
    "autorizaste": "autorizar",
    "autorizastes": "autorizar",
    "autorizava": "autorizar",
    "autorizavam": "autorizar",
    "autorizavas": "autorizar",
    "autorizações": "autorização",
    "autorize": "autorizar",
    "autorizei": "autorizar",
    "autorizeis": "autorizar",
    "autorizem": "autorizar",
    "autorizemo": "autorizar",
    "autorizemos": "autorizar",
    "autorizes": "autorizar",
    "autorizo": "autorizar",
    "autorizou": "autorizar",
    "autorizá": "autorizar",
    "autorizámo": "autorizar",
    "autorizámos": "autorizar",
    "autorizáramo": "autorizar",
    "autorizáramos": "autorizar",
    "autorizárei": "autorizar",
    "autorizáreis": "autorizar",
    "autorizásseis": "autorizar",
    "autorizássemos": "autorizar",
    "autorizávamo": "autorizar",
    "autorizávamos": "autorizar",
    "autorizávei": "autorizar",
    "autorizáveis": "autorizável",
    "autos": "auto",
    "autoscopias": "autoscopia",
    "autoscópica": "autoscópico",
    "autoscópicas": "autoscópico",
    "autoscópicos": "autoscópico",
    "autoscópios": "autoscópio",
    "autossomas": "autossoma",
    "autosuficientes": "autosuficiente",
    "autotanques": "autotanque",
    "autotelias": "autotelia",
    "autoterapias": "autoterapia",
    "autoterapêutica": "autoterapêutico",
    "autoterapêuticas": "autoterapêutico",
    "autoterapêuticos": "autoterapêutico",
    "autoterápica": "autoterápico",
    "autoterápicas": "autoterápico",
    "autoterápicos": "autoterápico",
    "autotipias": "autotipia",
    "autotomias": "autotomia",
    "autotoxinas": "autotoxina",
    "autotransformadores": "autotransformador",
    "autotrófica": "autotrófico",
    "autotróficas": "autotrófico",
    "autotróficos": "autotrófico",
    "autotélica": "autotélico",
    "autotélicas": "autotélico",
    "autotélicos": "autotélico",
    "autovacinas": "autovacina",
    "autoviações": "autoviação",
    "autua": "autuar",
    "autuada": "autuar",
    "autuadas": "autuar",
    "autuado": "autuar",
    "autuados": "autuar",
    "autuai": "autuar",
    "autuais": "autuar",
    "autuam": "autuar",
    "autuamo": "autuar",
    "autuamos": "autuar",
    "autuando": "autuar",
    "autuara": "autuar",
    "autuaram": "autuar",
    "autuaras": "autuar",
    "autuarde": "autuar",
    "autuardes": "autuar",
    "autuare": "autuar",
    "autuarei": "autuar",
    "autuareis": "autuar",
    "autuarem": "autuar",
    "autuaremos": "autuar",
    "autuares": "autuar",
    "autuaria": "autuar",
    "autuariam": "autuar",
    "autuarias": "autuar",
    "autuarmo": "autuar",
    "autuarmos": "autuar",
    "autuará": "autuar",
    "autuarás": "autuar",
    "autuarão": "autuar",
    "autuaríamos": "autuar",
    "autuaríeis": "autuar",
    "autuas": "autuar",
    "autuasse": "autuar",
    "autuassem": "autuar",
    "autuasses": "autuar",
    "autuaste": "autuar",
    "autuastes": "autuar",
    "autuava": "autuar",
    "autuavam": "autuar",
    "autuavas": "autuar",
    "autuações": "autuação",
    "autue": "autuar",
    "autuei": "autuar",
    "autueis": "autuar",
    "autuem": "autuar",
    "autuemo": "autuar",
    "autuemos": "autuar",
    "autues": "autuar",
    "autumenações": "autumenação",
    "autunais": "autunal",
    "autunitas": "autunita",
    "autunites": "autunite",
    "autuo": "autuar",
    "autuou": "autuar",
    "autuá": "autuar",
    "autuámo": "autuar",
    "autuámos": "autuar",
    "autuáramo": "autuar",
    "autuáramos": "autuar",
    "autuárei": "autuar",
    "autuáreis": "autuar",
    "autuásseis": "autuar",
    "autuássemos": "autuar",
    "autuávamo": "autuar",
    "autuávamos": "autuar",
    "autuávei": "autuar",
    "autuáveis": "autuar",
    "autárquica": "autárquico",
    "autárquicas": "autárquico",
    "autárquicos": "autárquico",
    "autêntica": "autêntico",
    "autênticas": "autêntico",
    "autênticos": "autêntico",
    "autóclises": "autóclise",
    "autóctones": "autóctone",
    "autódromos": "autódromo",
    "autófaga": "autófago",
    "autófagas": "autófago",
    "autófagos": "autófago",
    "autófila": "autófilo",
    "autófilas": "autófilo",
    "autófilos": "autófilo",
    "autógama": "autógamo",
    "autógamas": "autógamo",
    "autógamos": "autógamo",
    "autógena": "autógeno",
    "autógenas": "autógeno",
    "autógenos": "autógeno",
    "autógrafos": "autógrafo",
    "autólatras": "autólatra",
    "autólises": "autólise",
    "autómatos": "autómato",
    "autónima": "autónimo",
    "autónimas": "autónimo",
    "autónimos": "autónimo",
    "autónoma": "autónomo",
    "autónomas": "autónomo",
    "autónomos": "autónomo",
    "autópsias": "autópsia",
    "autóptica": "autóptico",
    "autópticas": "autóptico",
    "autópticos": "autóptico",
    "auxanométrica": "auxanométrico",
    "auxanométricas": "auxanométrico",
    "auxanométricos": "auxanométrico",
    "auxanómetros": "auxanómetro",
    "auxeses": "auxese",
    "auxilia": "auxiliar",
    "auxiliada": "auxiliar",
    "auxiliadas": "auxiliar",
    "auxiliado": "auxiliar",
    "auxiliadora": "auxiliador",
    "auxiliadoras": "auxiliador",
    "auxiliadores": "auxiliador",
    "auxiliados": "auxiliar",
    "auxiliai": "auxiliar",
    "auxiliais": "auxiliar",
    "auxiliam": "auxiliar",
    "auxiliamo": "auxiliar",
    "auxiliamos": "auxiliar",
    "auxiliando": "auxiliar",
    "auxiliantes": "auxiliante",
    "auxiliara": "auxiliar",
    "auxiliaram": "auxiliar",
    "auxiliaras": "auxiliar",
    "auxiliarde": "auxiliar",
    "auxiliardes": "auxiliar",
    "auxiliare": "auxiliar",
    "auxiliarei": "auxiliar",
    "auxiliareis": "auxiliar",
    "auxiliarem": "auxiliar",
    "auxiliaremos": "auxiliar",
    "auxiliares": "auxiliar",
    "auxiliaria": "auxiliar",
    "auxiliariam": "auxiliar",
    "auxiliarias": "auxiliar",
    "auxiliarmo": "auxiliar",
    "auxiliarmos": "auxiliar",
    "auxiliará": "auxiliar",
    "auxiliarás": "auxiliar",
    "auxiliarão": "auxiliar",
    "auxiliaríamos": "auxiliar",
    "auxiliaríeis": "auxiliar",
    "auxilias": "auxiliar",
    "auxiliasse": "auxiliar",
    "auxiliassem": "auxiliar",
    "auxiliasses": "auxiliar",
    "auxiliaste": "auxiliar",
    "auxiliastes": "auxiliar",
    "auxiliava": "auxiliar",
    "auxiliavam": "auxiliar",
    "auxiliavas": "auxiliar",
    "auxilie": "auxiliar",
    "auxiliei": "auxiliar",
    "auxilieis": "auxiliar",
    "auxiliem": "auxiliar",
    "auxiliemo": "auxiliar",
    "auxiliemos": "auxiliar",
    "auxilies": "auxiliar",
    "auxilio": "auxiliar",
    "auxiliou": "auxiliar",
    "auxiliá": "auxiliar",
    "auxiliámo": "auxiliar",
    "auxiliámos": "auxiliar",
    "auxiliáramo": "auxiliar",
    "auxiliáramos": "auxiliar",
    "auxiliárei": "auxiliar",
    "auxiliáreis": "auxiliar",
    "auxiliária": "auxiliário",
    "auxiliárias": "auxiliário",
    "auxiliários": "auxiliário",
    "auxiliásseis": "auxiliar",
    "auxiliássemos": "auxiliar",
    "auxiliávamo": "auxiliar",
    "auxiliávamos": "auxiliar",
    "auxiliávei": "auxiliar",
    "auxiliáveis": "auxiliar",
    "auxílios": "auxílio",
    "auxómetros": "auxómetro",
    "avacalhamentos": "avacalhamento",
    "avacalhações": "avacalhação",
    "avacás": "avacá",
    "avais": "aval",
    "avalanchas": "avalancha",
    "avalanches": "avalanche",
    "avalentoada": "avalentoado",
    "avalentoadas": "avalentoado",
    "avalentoados": "avalentoado",
    "avales": "aval",
    "avalia": "avaliar",
    "avaliada": "avaliar",
    "avaliadas": "avaliar",
    "avaliado": "avaliar",
    "avaliadora": "avaliador",
    "avaliadoras": "avaliador",
    "avaliadores": "avaliador",
    "avaliados": "avaliar",
    "avaliai": "avaliar",
    "avaliais": "avaliar",
    "avaliam": "avaliar",
    "avaliamentos": "avaliamento",
    "avaliamo": "avaliar",
    "avaliamos": "avaliar",
    "avaliando": "avaliar",
    "avaliara": "avaliar",
    "avaliaram": "avaliar",
    "avaliaras": "avaliar",
    "avaliarde": "avaliar",
    "avaliardes": "avaliar",
    "avaliare": "avaliar",
    "avaliarei": "avaliar",
    "avaliareis": "avaliar",
    "avaliarem": "avaliar",
    "avaliaremos": "avaliar",
    "avaliares": "avaliar",
    "avaliaria": "avaliar",
    "avaliariam": "avaliar",
    "avaliarias": "avaliar",
    "avaliarmo": "avaliar",
    "avaliarmos": "avaliar",
    "avaliará": "avaliar",
    "avaliarás": "avaliar",
    "avaliarão": "avaliar",
    "avaliaríamos": "avaliar",
    "avaliaríeis": "avaliar",
    "avalias": "avaliar",
    "avaliasse": "avaliar",
    "avaliassem": "avaliar",
    "avaliasses": "avaliar",
    "avaliaste": "avaliar",
    "avaliastes": "avaliar",
    "avaliativa": "avaliativo",
    "avaliativas": "avaliativo",
    "avaliativos": "avaliativo",
    "avaliava": "avaliar",
    "avaliavam": "avaliar",
    "avaliavas": "avaliar",
    "avaliações": "avaliação",
    "avalie": "avaliar",
    "avaliei": "avaliar",
    "avalieis": "avaliar",
    "avaliem": "avaliar",
    "avaliemo": "avaliar",
    "avaliemos": "avaliar",
    "avalies": "avaliar",
    "avalio": "avaliar",
    "avaliou": "avaliar",
    "avalistas": "avalista",
    "avaliza": "avalizar",
    "avalizada": "avalizar",
    "avalizadas": "avalizar",
    "avalizado": "avalizar",
    "avalizadora": "avalizador",
    "avalizadoras": "avalizador",
    "avalizadores": "avalizador",
    "avalizados": "avalizar",
    "avalizai": "avalizar",
    "avalizais": "avalizar",
    "avalizam": "avalizar",
    "avalizamo": "avalizar",
    "avalizamos": "avalizar",
    "avalizando": "avalizar",
    "avalizara": "avalizar",
    "avalizaram": "avalizar",
    "avalizaras": "avalizar",
    "avalizarde": "avalizar",
    "avalizardes": "avalizar",
    "avalizare": "avalizar",
    "avalizarei": "avalizar",
    "avalizareis": "avalizar",
    "avalizarem": "avalizar",
    "avalizaremos": "avalizar",
    "avalizares": "avalizar",
    "avalizaria": "avalizar",
    "avalizariam": "avalizar",
    "avalizarias": "avalizar",
    "avalizarmo": "avalizar",
    "avalizarmos": "avalizar",
    "avalizará": "avalizar",
    "avalizarás": "avalizar",
    "avalizarão": "avalizar",
    "avalizaríamos": "avalizar",
    "avalizaríeis": "avalizar",
    "avalizas": "avalizar",
    "avalizasse": "avalizar",
    "avalizassem": "avalizar",
    "avalizasses": "avalizar",
    "avalizaste": "avalizar",
    "avalizastes": "avalizar",
    "avalizava": "avalizar",
    "avalizavam": "avalizar",
    "avalizavas": "avalizar",
    "avalize": "avalizar",
    "avalizei": "avalizar",
    "avalizeis": "avalizar",
    "avalizem": "avalizar",
    "avalizemo": "avalizar",
    "avalizemos": "avalizar",
    "avalizes": "avalizar",
    "avalizo": "avalizar",
    "avalizou": "avalizar",
    "avalizá": "avalizar",
    "avalizámo": "avalizar",
    "avalizámos": "avalizar",
    "avalizáramo": "avalizar",
    "avalizáramos": "avalizar",
    "avalizárei": "avalizar",
    "avalizáreis": "avalizar",
    "avalizásseis": "avalizar",
    "avalizássemos": "avalizar",
    "avalizávamo": "avalizar",
    "avalizávamos": "avalizar",
    "avalizávei": "avalizar",
    "avalizáveis": "avalizável",
    "avaliá": "avaliar",
    "avaliámo": "avaliar",
    "avaliámos": "avaliar",
    "avaliáramo": "avaliar",
    "avaliáramos": "avaliar",
    "avaliárei": "avaliar",
    "avaliáreis": "avaliar",
    "avaliásseis": "avaliar",
    "avaliássemos": "avaliar",
    "avaliávamo": "avaliar",
    "avaliávamos": "avaliar",
    "avaliávei": "avaliar",
    "avaliáveis": "avaliável",
    "avance": "avançar",
    "avancei": "avançar",
    "avanceis": "avançar",
    "avancem": "avançar",
    "avancemo": "avançar",
    "avancemos": "avançar",
    "avances": "avance",
    "avanias": "avania",
    "avantaja": "avantajar",
    "avantajada": "avantajar",
    "avantajadas": "avantajar",
    "avantajadinha": "avantajado",
    "avantajadinhas": "avantajado",
    "avantajadinho": "avantajado",
    "avantajadinhos": "avantajado",
    "avantajadita": "avantajado",
    "avantajaditas": "avantajado",
    "avantajadito": "avantajado",
    "avantajaditos": "avantajado",
    "avantajado": "avantajar",
    "avantajados": "avantajar",
    "avantajadíssima": "avantajado",
    "avantajadíssimas": "avantajado",
    "avantajadíssimo": "avantajado",
    "avantajadíssimos": "avantajado",
    "avantajai": "avantajar",
    "avantajais": "avantajar",
    "avantajam": "avantajar",
    "avantajamo": "avantajar",
    "avantajamos": "avantajar",
    "avantajando": "avantajar",
    "avantajara": "avantajar",
    "avantajaram": "avantajar",
    "avantajaras": "avantajar",
    "avantajarde": "avantajar",
    "avantajardes": "avantajar",
    "avantajare": "avantajar",
    "avantajarei": "avantajar",
    "avantajareis": "avantajar",
    "avantajarem": "avantajar",
    "avantajaremos": "avantajar",
    "avantajares": "avantajar",
    "avantajaria": "avantajar",
    "avantajariam": "avantajar",
    "avantajarias": "avantajar",
    "avantajarmo": "avantajar",
    "avantajarmos": "avantajar",
    "avantajará": "avantajar",
    "avantajarás": "avantajar",
    "avantajarão": "avantajar",
    "avantajaríamos": "avantajar",
    "avantajaríeis": "avantajar",
    "avantajas": "avantajar",
    "avantajasse": "avantajar",
    "avantajassem": "avantajar",
    "avantajasses": "avantajar",
    "avantajaste": "avantajar",
    "avantajastes": "avantajar",
    "avantajava": "avantajar",
    "avantajavam": "avantajar",
    "avantajavas": "avantajar",
    "avantaje": "avantajar",
    "avantajei": "avantajar",
    "avantajeis": "avantajar",
    "avantajem": "avantajar",
    "avantajemo": "avantajar",
    "avantajemos": "avantajar",
    "avantajes": "avantajar",
    "avantajo": "avantajar",
    "avantajou": "avantajar",
    "avantajá": "avantajar",
    "avantajámo": "avantajar",
    "avantajámos": "avantajar",
    "avantajáramo": "avantajar",
    "avantajáramos": "avantajar",
    "avantajárei": "avantajar",
    "avantajáreis": "avantajar",
    "avantajásseis": "avantajar",
    "avantajássemos": "avantajar",
    "avantajávamo": "avantajar",
    "avantajávamos": "avantajar",
    "avantajávei": "avantajar",
    "avantajáveis": "avantajar",
    "avantesmas": "avantesma",
    "avança": "avançar",
    "avançada": "avançar",
    "avançadas": "avançar",
    "avançadinha": "avançado",
    "avançadinhas": "avançado",
    "avançadinho": "avançado",
    "avançadinhos": "avançado",
    "avançadita": "avançado",
    "avançaditas": "avançado",
    "avançadito": "avançado",
    "avançaditos": "avançado",
    "avançado": "avançar",
    "avançadora": "avançador",
    "avançadoras": "avançador",
    "avançadores": "avançador",
    "avançados": "avançar",
    "avançadíssima": "avançado",
    "avançadíssimas": "avançado",
    "avançadíssimo": "avançado",
    "avançadíssimos": "avançado",
    "avançai": "avançar",
    "avançais": "avançar",
    "avançam": "avançar",
    "avançamentos": "avançamento",
    "avançamo": "avançar",
    "avançamos": "avançar",
    "avançando": "avançar",
    "avançara": "avançar",
    "avançaram": "avançar",
    "avançaras": "avançar",
    "avançarde": "avançar",
    "avançardes": "avançar",
    "avançare": "avançar",
    "avançarei": "avançar",
    "avançareis": "avançar",
    "avançarem": "avançar",
    "avançaremos": "avançar",
    "avançares": "avançar",
    "avançaria": "avançar",
    "avançariam": "avançar",
    "avançarias": "avançar",
    "avançarmo": "avançar",
    "avançarmos": "avançar",
    "avançará": "avançar",
    "avançarás": "avançar",
    "avançarão": "avançar",
    "avançaríamos": "avançar",
    "avançaríeis": "avançar",
    "avanças": "avançar",
    "avançasse": "avançar",
    "avançassem": "avançar",
    "avançasses": "avançar",
    "avançaste": "avançar",
    "avançastes": "avançar",
    "avançava": "avançar",
    "avançavam": "avançar",
    "avançavas": "avançar",
    "avanço": "avançar",
    "avanços": "avanço",
    "avançou": "avançar",
    "avançá": "avançar",
    "avançámo": "avançar",
    "avançámos": "avançar",
    "avançáramo": "avançar",
    "avançáramos": "avançar",
    "avançárei": "avançar",
    "avançáreis": "avançar",
    "avançásseis": "avançar",
    "avançássemos": "avançar",
    "avançávamo": "avançar",
    "avançávamos": "avançar",
    "avançávei": "avançar",
    "avançáveis": "avançar",
    "avaqueirada": "avaqueirado",
    "avaqueiradas": "avaqueirado",
    "avaqueirados": "avaqueirado",
    "avara": "avaro",
    "avarandada": "avarandado",
    "avarandadas": "avarandado",
    "avarandados": "avarandado",
    "avaras": "avaro",
    "avarenta": "avarento",
    "avarentas": "avarento",
    "avarentinha": "avarento",
    "avarentinhas": "avarento",
    "avarentinho": "avarento",
    "avarentinhos": "avarento",
    "avarentita": "avarento",
    "avarentitas": "avarento",
    "avarentito": "avarento",
    "avarentitos": "avarento",
    "avarentos": "avarento",
    "avarentíssima": "avarento",
    "avarentíssimas": "avarento",
    "avarentíssimo": "avarento",
    "avarentíssimos": "avarento",
    "avarezas": "avareza",
    "avaria": "avariar",
    "avariada": "avariar",
    "avariadas": "avariar",
    "avariadinha": "avariado",
    "avariadinhas": "avariado",
    "avariadinho": "avariado",
    "avariadinhos": "avariado",
    "avariadita": "avariado",
    "avariaditas": "avariado",
    "avariadito": "avariado",
    "avariaditos": "avariado",
    "avariado": "avariar",
    "avariados": "avariar",
    "avariadíssima": "avariado",
    "avariadíssimas": "avariado",
    "avariadíssimo": "avariado",
    "avariadíssimos": "avariado",
    "avariai": "avariar",
    "avariais": "avariar",
    "avariam": "avariar",
    "avariamo": "avariar",
    "avariamos": "avariar",
    "avariando": "avariar",
    "avariara": "avariar",
    "avariaram": "avariar",
    "avariaras": "avariar",
    "avariarde": "avariar",
    "avariardes": "avariar",
    "avariare": "avariar",
    "avariarei": "avariar",
    "avariareis": "avariar",
    "avariarem": "avariar",
    "avariaremos": "avariar",
    "avariares": "avariar",
    "avariaria": "avariar",
    "avariariam": "avariar",
    "avariarias": "avariar",
    "avariarmo": "avariar",
    "avariarmos": "avariar",
    "avariará": "avariar",
    "avariarás": "avariar",
    "avariarão": "avariar",
    "avariaríamos": "avariar",
    "avariaríeis": "avariar",
    "avarias": "avariar",
    "avariasse": "avariar",
    "avariassem": "avariar",
    "avariasses": "avariar",
    "avariaste": "avariar",
    "avariastes": "avariar",
    "avariava": "avariar",
    "avariavam": "avariar",
    "avariavas": "avariar",
    "avarie": "avariar",
    "avariei": "avariar",
    "avarieis": "avariar",
    "avariem": "avariar",
    "avariemo": "avariar",
    "avariemos": "avariar",
    "avaries": "avariar",
    "avario": "avariar",
    "avariou": "avariar",
    "avariá": "avariar",
    "avariámo": "avariar",
    "avariámos": "avariar",
    "avariáramo": "avariar",
    "avariáramos": "avariar",
    "avariárei": "avariar",
    "avariáreis": "avariar",
    "avariásseis": "avariar",
    "avariássemos": "avariar",
    "avariávamo": "avariar",
    "avariávamos": "avariar",
    "avariávei": "avariar",
    "avariáveis": "avariar",
    "avaros": "avaro",
    "avarzeada": "avarzeado",
    "avarzeadas": "avarzeado",
    "avarzeados": "avarzeado",
    "avaríssima": "avaro",
    "avaríssimas": "avaro",
    "avaríssimo": "avaro",
    "avaríssimos": "avaro",
    "avasconçada": "avasconçado",
    "avasconçadas": "avasconçado",
    "avasconçados": "avasconçado",
    "avassala": "avassalar",
    "avassalada": "avassalar",
    "avassaladas": "avassalar",
    "avassalado": "avassalar",
    "avassaladora": "avassalador",
    "avassaladoras": "avassalador",
    "avassaladores": "avassalador",
    "avassalados": "avassalar",
    "avassalai": "avassalar",
    "avassalais": "avassalar",
    "avassalam": "avassalar",
    "avassalamo": "avassalar",
    "avassalamos": "avassalar",
    "avassalando": "avassalar",
    "avassalantes": "avassalante",
    "avassalara": "avassalar",
    "avassalaram": "avassalar",
    "avassalaras": "avassalar",
    "avassalarde": "avassalar",
    "avassalardes": "avassalar",
    "avassalare": "avassalar",
    "avassalarei": "avassalar",
    "avassalareis": "avassalar",
    "avassalarem": "avassalar",
    "avassalaremos": "avassalar",
    "avassalares": "avassalar",
    "avassalaria": "avassalar",
    "avassalariam": "avassalar",
    "avassalarias": "avassalar",
    "avassalarmo": "avassalar",
    "avassalarmos": "avassalar",
    "avassalará": "avassalar",
    "avassalarás": "avassalar",
    "avassalarão": "avassalar",
    "avassalaríamos": "avassalar",
    "avassalaríeis": "avassalar",
    "avassalas": "avassalar",
    "avassalasse": "avassalar",
    "avassalassem": "avassalar",
    "avassalasses": "avassalar",
    "avassalaste": "avassalar",
    "avassalastes": "avassalar",
    "avassalava": "avassalar",
    "avassalavam": "avassalar",
    "avassalavas": "avassalar",
    "avassale": "avassalar",
    "avassalei": "avassalar",
    "avassaleis": "avassalar",
    "avassalem": "avassalar",
    "avassalemo": "avassalar",
    "avassalemos": "avassalar",
    "avassales": "avassalar",
    "avassalo": "avassalar",
    "avassalou": "avassalar",
    "avassalá": "avassalar",
    "avassalámo": "avassalar",
    "avassalámos": "avassalar",
    "avassaláramo": "avassalar",
    "avassaláramos": "avassalar",
    "avassalárei": "avassalar",
    "avassaláreis": "avassalar",
    "avassalásseis": "avassalar",
    "avassalássemos": "avassalar",
    "avassalávamo": "avassalar",
    "avassalávamos": "avassalar",
    "avassalávei": "avassalar",
    "avassaláveis": "avassalar",
    "avatares": "avatar",
    "aveais": "aveal",
    "aveconhas": "aveconha",
    "aveias": "aveia",
    "aveirenses": "aveirense",
    "avejões": "avejão",
    "avelada": "avelado",
    "aveladas": "avelado",
    "avelados": "avelado",
    "avelais": "avelal",
    "avelamentos": "avelamento",
    "avelanada": "avelanado",
    "avelanadas": "avelanado",
    "avelanados": "avelanado",
    "avelanais": "avelanal",
    "avelaneiras": "avelaneira",
    "avelanzeiras": "avelanzeira",
    "avelares": "avelar",
    "aveleirais": "aveleiral",
    "aveleiras": "aveleira",
    "avelhaca": "avelhacar",
    "avelhacada": "avelhacar",
    "avelhacadas": "avelhacar",
    "avelhacado": "avelhacar",
    "avelhacados": "avelhacar",
    "avelhacai": "avelhacar",
    "avelhacais": "avelhacar",
    "avelhacam": "avelhacar",
    "avelhacamo": "avelhacar",
    "avelhacamos": "avelhacar",
    "avelhacando": "avelhacar",
    "avelhacara": "avelhacar",
    "avelhacaram": "avelhacar",
    "avelhacaras": "avelhacar",
    "avelhacarde": "avelhacar",
    "avelhacardes": "avelhacar",
    "avelhacare": "avelhacar",
    "avelhacarei": "avelhacar",
    "avelhacareis": "avelhacar",
    "avelhacarem": "avelhacar",
    "avelhacaremos": "avelhacar",
    "avelhacares": "avelhacar",
    "avelhacaria": "avelhacar",
    "avelhacariam": "avelhacar",
    "avelhacarias": "avelhacar",
    "avelhacarmo": "avelhacar",
    "avelhacarmos": "avelhacar",
    "avelhacará": "avelhacar",
    "avelhacarás": "avelhacar",
    "avelhacarão": "avelhacar",
    "avelhacaríamos": "avelhacar",
    "avelhacaríeis": "avelhacar",
    "avelhacas": "avelhacar",
    "avelhacasse": "avelhacar",
    "avelhacassem": "avelhacar",
    "avelhacasses": "avelhacar",
    "avelhacaste": "avelhacar",
    "avelhacastes": "avelhacar",
    "avelhacava": "avelhacar",
    "avelhacavam": "avelhacar",
    "avelhacavas": "avelhacar",
    "avelhaco": "avelhacar",
    "avelhacou": "avelhacar",
    "avelhacá": "avelhacar",
    "avelhacámo": "avelhacar",
    "avelhacámos": "avelhacar",
    "avelhacáramo": "avelhacar",
    "avelhacáramos": "avelhacar",
    "avelhacárei": "avelhacar",
    "avelhacáreis": "avelhacar",
    "avelhacásseis": "avelhacar",
    "avelhacássemos": "avelhacar",
    "avelhacávamo": "avelhacar",
    "avelhacávamos": "avelhacar",
    "avelhacávei": "avelhacar",
    "avelhacáveis": "avelhacar",
    "avelhada": "avelhado",
    "avelhadas": "avelhado",
    "avelhados": "avelhado",
    "avelhaque": "avelhacar",
    "avelhaquei": "avelhacar",
    "avelhaqueis": "avelhacar",
    "avelhaquem": "avelhacar",
    "avelhaquemo": "avelhacar",
    "avelhaquemos": "avelhacar",
    "avelhaques": "avelhacar",
    "avelhentada": "avelhentado",
    "avelhentadas": "avelhentado",
    "avelhentadinha": "avelhentado",
    "avelhentadinhas": "avelhentado",
    "avelhentadinho": "avelhentado",
    "avelhentadinhos": "avelhentado",
    "avelhentadita": "avelhentado",
    "avelhentaditas": "avelhentado",
    "avelhentadito": "avelhentado",
    "avelhentaditos": "avelhentado",
    "avelhentadora": "avelhentador",
    "avelhentadoras": "avelhentador",
    "avelhentadores": "avelhentador",
    "avelhentados": "avelhentado",
    "avelhentadíssima": "avelhentado",
    "avelhentadíssimas": "avelhentado",
    "avelhentadíssimo": "avelhentado",
    "avelhentadíssimos": "avelhentado",
    "aveluda": "aveludar",
    "aveludada": "aveludar",
    "aveludadas": "aveludar",
    "aveludadinha": "aveludado",
    "aveludadinhas": "aveludado",
    "aveludadinho": "aveludado",
    "aveludadinhos": "aveludado",
    "aveludadita": "aveludado",
    "aveludaditas": "aveludado",
    "aveludadito": "aveludado",
    "aveludaditos": "aveludado",
    "aveludado": "aveludar",
    "aveludadoras": "aveludadora",
    "aveludados": "aveludar",
    "aveludadíssima": "aveludado",
    "aveludadíssimas": "aveludado",
    "aveludadíssimo": "aveludado",
    "aveludadíssimos": "aveludado",
    "aveludai": "aveludar",
    "aveludais": "aveludar",
    "aveludam": "aveludar",
    "aveludamo": "aveludar",
    "aveludamos": "aveludar",
    "aveludando": "aveludar",
    "aveludara": "aveludar",
    "aveludaram": "aveludar",
    "aveludaras": "aveludar",
    "aveludarde": "aveludar",
    "aveludardes": "aveludar",
    "aveludare": "aveludar",
    "aveludarei": "aveludar",
    "aveludareis": "aveludar",
    "aveludarem": "aveludar",
    "aveludaremos": "aveludar",
    "aveludares": "aveludar",
    "aveludaria": "aveludar",
    "aveludariam": "aveludar",
    "aveludarias": "aveludar",
    "aveludarmo": "aveludar",
    "aveludarmos": "aveludar",
    "aveludará": "aveludar",
    "aveludarás": "aveludar",
    "aveludarão": "aveludar",
    "aveludaríamos": "aveludar",
    "aveludaríeis": "aveludar",
    "aveludas": "aveludar",
    "aveludasse": "aveludar",
    "aveludassem": "aveludar",
    "aveludasses": "aveludar",
    "aveludaste": "aveludar",
    "aveludastes": "aveludar",
    "aveludava": "aveludar",
    "aveludavam": "aveludar",
    "aveludavas": "aveludar",
    "avelude": "aveludar",
    "aveludei": "aveludar",
    "aveludeis": "aveludar",
    "aveludem": "aveludar",
    "aveludemo": "aveludar",
    "aveludemos": "aveludar",
    "aveludes": "aveludar",
    "aveludo": "aveludar",
    "aveludou": "aveludar",
    "aveludá": "aveludar",
    "aveludámo": "aveludar",
    "aveludámos": "aveludar",
    "aveludáramo": "aveludar",
    "aveludáramos": "aveludar",
    "aveludárei": "aveludar",
    "aveludáreis": "aveludar",
    "aveludásseis": "aveludar",
    "aveludássemos": "aveludar",
    "aveludávamo": "aveludar",
    "aveludávamos": "aveludar",
    "aveludávei": "aveludar",
    "aveludáveis": "aveludar",
    "avelãs": "avelã",
    "avelórios": "avelório",
    "avenada": "avenado",
    "avenadas": "avenado",
    "avenados": "avenado",
    "avenais": "avenal",
    "avenas": "avena",
    "avenaínas": "avenaína",
    "avencas": "avenca",
    "avence": "avençar",
    "avencei": "avençar",
    "avenceis": "avençar",
    "avencem": "avençar",
    "avencemo": "avençar",
    "avencemos": "avençar",
    "avences": "avençar",
    "avencões": "avencão",
    "aveneínas": "aveneína",
    "avenidas": "avenida",
    "aventa": "aventar",
    "aventada": "aventar",
    "aventadas": "aventar",
    "aventado": "aventar",
    "aventados": "aventar",
    "aventai": "aventar",
    "aventais": "aventar",
    "aventam": "aventar",
    "aventamo": "aventar",
    "aventamos": "aventar",
    "aventando": "aventar",
    "aventara": "aventar",
    "aventaram": "aventar",
    "aventaras": "aventar",
    "aventarde": "aventar",
    "aventardes": "aventar",
    "aventare": "aventar",
    "aventarei": "aventar",
    "aventareis": "aventar",
    "aventarem": "aventar",
    "aventaremos": "aventar",
    "aventares": "aventar",
    "aventaria": "aventar",
    "aventariam": "aventar",
    "aventarias": "aventar",
    "aventarmo": "aventar",
    "aventarmos": "aventar",
    "aventará": "aventar",
    "aventarás": "aventar",
    "aventarão": "aventar",
    "aventaríamos": "aventar",
    "aventaríeis": "aventar",
    "aventas": "aventar",
    "aventasse": "aventar",
    "aventassem": "aventar",
    "aventasses": "aventar",
    "aventaste": "aventar",
    "aventastes": "aventar",
    "aventava": "aventar",
    "aventavam": "aventar",
    "aventavas": "aventar",
    "avente": "aventar",
    "aventei": "aventar",
    "aventeis": "aventar",
    "aventem": "aventar",
    "aventemo": "aventar",
    "aventemos": "aventar",
    "aventes": "aventar",
    "aventesmas": "aventesma",
    "avento": "aventar",
    "aventou": "aventar",
    "aventura": "aventurar",
    "aventurada": "aventurar",
    "aventuradas": "aventurar",
    "aventurado": "aventurar",
    "aventurados": "aventurar",
    "aventurai": "aventurar",
    "aventurais": "aventurar",
    "aventuram": "aventurar",
    "aventuramo": "aventurar",
    "aventuramos": "aventurar",
    "aventurando": "aventurar",
    "aventurara": "aventurar",
    "aventuraram": "aventurar",
    "aventuraras": "aventurar",
    "aventurarde": "aventurar",
    "aventurardes": "aventurar",
    "aventurare": "aventurar",
    "aventurarei": "aventurar",
    "aventurareis": "aventurar",
    "aventurarem": "aventurar",
    "aventuraremos": "aventurar",
    "aventurares": "aventurar",
    "aventuraria": "aventurar",
    "aventurariam": "aventurar",
    "aventurarias": "aventurar",
    "aventurarmo": "aventurar",
    "aventurarmos": "aventurar",
    "aventurará": "aventurar",
    "aventurarás": "aventurar",
    "aventurarão": "aventurar",
    "aventuraríamos": "aventurar",
    "aventuraríeis": "aventurar",
    "aventuras": "aventurar",
    "aventurasse": "aventurar",
    "aventurassem": "aventurar",
    "aventurasses": "aventurar",
    "aventuraste": "aventurar",
    "aventurastes": "aventurar",
    "aventurava": "aventurar",
    "aventuravam": "aventurar",
    "aventuravas": "aventurar",
    "aventurazinha": "aventura",
    "aventurazinhas": "aventura",
    "aventurazita": "aventura",
    "aventurazitas": "aventura",
    "aventure": "aventurar",
    "aventurei": "aventurar",
    "aventureira": "aventureiro",
    "aventureiras": "aventureiro",
    "aventureirismos": "aventureirismo",
    "aventureiros": "aventureiro",
    "aventureis": "aventurar",
    "aventurem": "aventurar",
    "aventuremo": "aventurar",
    "aventuremos": "aventurar",
    "aventures": "aventurar",
    "aventurinas": "aventurina",
    "aventuro": "aventurar",
    "aventurosa": "aventuroso",
    "aventurosas": "aventuroso",
    "aventurosos": "aventuroso",
    "aventurou": "aventurar",
    "aventurá": "aventurar",
    "aventurámo": "aventurar",
    "aventurámos": "aventurar",
    "aventuráramo": "aventurar",
    "aventuráramos": "aventurar",
    "aventurárei": "aventurar",
    "aventuráreis": "aventurar",
    "aventurásseis": "aventurar",
    "aventurássemos": "aventurar",
    "aventurávamo": "aventurar",
    "aventurávamos": "aventurar",
    "aventurávei": "aventurar",
    "aventuráveis": "aventurar",
    "aventá": "aventar",
    "aventámo": "aventar",
    "aventámos": "aventar",
    "aventáramo": "aventar",
    "aventáramos": "aventar",
    "aventárei": "aventar",
    "aventáreis": "aventar",
    "aventásseis": "aventar",
    "aventássemos": "aventar",
    "aventávamo": "aventar",
    "aventávamos": "aventar",
    "aventávei": "aventar",
    "aventáveis": "aventar",
    "avenácea": "avenáceo",
    "avenáceas": "avenáceo",
    "avenáceos": "avenáceo",
    "avença": "avençar",
    "avençada": "avençar",
    "avençadas": "avençar",
    "avençado": "avençar",
    "avençados": "avençar",
    "avençai": "avençar",
    "avençais": "avençar",
    "avençam": "avençar",
    "avençamo": "avençar",
    "avençamos": "avençar",
    "avençando": "avençar",
    "avençara": "avençar",
    "avençaram": "avençar",
    "avençaras": "avençar",
    "avençarde": "avençar",
    "avençardes": "avençar",
    "avençare": "avençar",
    "avençarei": "avençar",
    "avençareis": "avençar",
    "avençarem": "avençar",
    "avençaremos": "avençar",
    "avençares": "avençar",
    "avençaria": "avençar",
    "avençariam": "avençar",
    "avençarias": "avençar",
    "avençarmo": "avençar",
    "avençarmos": "avençar",
    "avençará": "avençar",
    "avençarás": "avençar",
    "avençarão": "avençar",
    "avençaríamos": "avençar",
    "avençaríeis": "avençar",
    "avenças": "avençar",
    "avençasse": "avençar",
    "avençassem": "avençar",
    "avençasses": "avençar",
    "avençaste": "avençar",
    "avençastes": "avençar",
    "avençava": "avençar",
    "avençavam": "avençar",
    "avençavas": "avençar",
    "avenço": "avençar",
    "avençou": "avençar",
    "avençá": "avençar",
    "avençámo": "avençar",
    "avençámos": "avençar",
    "avençáramo": "avençar",
    "avençáramos": "avençar",
    "avençárei": "avençar",
    "avençáreis": "avençar",
    "avençásseis": "avençar",
    "avençássemos": "avençar",
    "avençávamo": "avençar",
    "avençávamos": "avençar",
    "avençávei": "avençar",
    "avençáveis": "avençar",
    "averba": "averbar",
    "averbada": "averbar",
    "averbadas": "averbar",
    "averbado": "averbar",
    "averbados": "averbar",
    "averbai": "averbar",
    "averbais": "averbar",
    "averbam": "averbar",
    "averbamentos": "averbamento",
    "averbamo": "averbar",
    "averbamos": "averbar",
    "averbando": "averbar",
    "averbara": "averbar",
    "averbaram": "averbar",
    "averbaras": "averbar",
    "averbarde": "averbar",
    "averbardes": "averbar",
    "averbare": "averbar",
    "averbarei": "averbar",
    "averbareis": "averbar",
    "averbarem": "averbar",
    "averbaremos": "averbar",
    "averbares": "averbar",
    "averbaria": "averbar",
    "averbariam": "averbar",
    "averbarias": "averbar",
    "averbarmo": "averbar",
    "averbarmos": "averbar",
    "averbará": "averbar",
    "averbarás": "averbar",
    "averbarão": "averbar",
    "averbaríamos": "averbar",
    "averbaríeis": "averbar",
    "averbas": "averbar",
    "averbasse": "averbar",
    "averbassem": "averbar",
    "averbasses": "averbar",
    "averbaste": "averbar",
    "averbastes": "averbar",
    "averbava": "averbar",
    "averbavam": "averbar",
    "averbavas": "averbar",
    "averbações": "averbação",
    "averbe": "averbar",
    "averbei": "averbar",
    "averbeis": "averbar",
    "averbem": "averbar",
    "averbemo": "averbar",
    "averbemos": "averbar",
    "averbes": "averbar",
    "averbo": "averbar",
    "averbou": "averbar",
    "averbá": "averbar",
    "averbámo": "averbar",
    "averbámos": "averbar",
    "averbáramo": "averbar",
    "averbáramos": "averbar",
    "averbárei": "averbar",
    "averbáreis": "averbar",
    "averbásseis": "averbar",
    "averbássemos": "averbar",
    "averbávamo": "averbar",
    "averbávamos": "averbar",
    "averbávei": "averbar",
    "averbáveis": "averbar",
    "averdengada": "averdengado",
    "averdengadas": "averdengado",
    "averdengados": "averdengado",
    "averge": "avergir",
    "avergem": "avergir",
    "averges": "avergir",
    "avergi": "avergir",
    "avergia": "avergir",
    "avergiam": "avergir",
    "avergias": "avergir",
    "avergida": "avergir",
    "avergidas": "avergir",
    "avergido": "avergir",
    "avergidos": "avergir",
    "avergimo": "avergir",
    "avergimos": "avergir",
    "avergindo": "avergir",
    "avergira": "avergir",
    "avergiram": "avergir",
    "avergiras": "avergir",
    "avergirde": "avergir",
    "avergirdes": "avergir",
    "avergire": "avergir",
    "avergirei": "avergir",
    "avergireis": "avergir",
    "avergirem": "avergir",
    "avergiremos": "avergir",
    "avergires": "avergir",
    "avergiria": "avergir",
    "avergiriam": "avergir",
    "avergirias": "avergir",
    "avergirmo": "avergir",
    "avergirmos": "avergir",
    "avergirá": "avergir",
    "avergirás": "avergir",
    "avergirão": "avergir",
    "avergiríamos": "avergir",
    "avergiríeis": "avergir",
    "avergis": "avergir",
    "avergisse": "avergir",
    "avergissem": "avergir",
    "avergisses": "avergir",
    "avergiste": "avergir",
    "avergistes": "avergir",
    "avergiu": "avergir",
    "avergíamo": "avergir",
    "avergíamos": "avergir",
    "avergíei": "avergir",
    "avergíeis": "avergir",
    "avergíramo": "avergir",
    "avergíramos": "avergir",
    "avergírei": "avergir",
    "avergíreis": "avergir",
    "avergísseis": "avergir",
    "avergíssemos": "avergir",
    "averigua": "averiguar",
    "averiguada": "averiguar",
    "averiguadas": "averiguar",
    "averiguado": "averiguar",
    "averiguadora": "averiguador",
    "averiguadoras": "averiguador",
    "averiguadores": "averiguador",
    "averiguados": "averiguar",
    "averiguai": "averiguar",
    "averiguais": "averiguar",
    "averiguam": "averiguar",
    "averiguamo": "averiguar",
    "averiguamos": "averiguar",
    "averiguando": "averiguar",
    "averiguara": "averiguar",
    "averiguaram": "averiguar",
    "averiguaras": "averiguar",
    "averiguarde": "averiguar",
    "averiguardes": "averiguar",
    "averiguare": "averiguar",
    "averiguarei": "averiguar",
    "averiguareis": "averiguar",
    "averiguarem": "averiguar",
    "averiguaremos": "averiguar",
    "averiguares": "averiguar",
    "averiguaria": "averiguar",
    "averiguariam": "averiguar",
    "averiguarias": "averiguar",
    "averiguarmo": "averiguar",
    "averiguarmos": "averiguar",
    "averiguará": "averiguar",
    "averiguarás": "averiguar",
    "averiguarão": "averiguar",
    "averiguaríamos": "averiguar",
    "averiguaríeis": "averiguar",
    "averiguas": "averiguar",
    "averiguasse": "averiguar",
    "averiguassem": "averiguar",
    "averiguasses": "averiguar",
    "averiguaste": "averiguar",
    "averiguastes": "averiguar",
    "averiguava": "averiguar",
    "averiguavam": "averiguar",
    "averiguavas": "averiguar",
    "averiguações": "averiguação",
    "averiguei": "averiguar",
    "averigueis": "averiguar",
    "averiguemo": "averiguar",
    "averiguemos": "averiguar",
    "averigues": "averiguar",
    "averiguo": "averiguar",
    "averiguou": "averiguar",
    "averiguá": "averiguar",
    "averiguámo": "averiguar",
    "averiguámos": "averiguar",
    "averiguáramo": "averiguar",
    "averiguáramos": "averiguar",
    "averiguárei": "averiguar",
    "averiguáreis": "averiguar",
    "averiguásseis": "averiguar",
    "averiguássemos": "averiguar",
    "averiguávamo": "averiguar",
    "averiguávamos": "averiguar",
    "averiguávei": "averiguar",
    "averiguáveis": "averiguável",
    "averigúe": "averiguar",
    "averigúem": "averiguar",
    "averigúes": "averiguar",
    "avermelha": "avermelhar",
    "avermelhada": "avermelhar",
    "avermelhadas": "avermelhar",
    "avermelhadinha": "avermelhado",
    "avermelhadinhas": "avermelhado",
    "avermelhadinho": "avermelhado",
    "avermelhadinhos": "avermelhado",
    "avermelhadita": "avermelhado",
    "avermelhaditas": "avermelhado",
    "avermelhadito": "avermelhado",
    "avermelhaditos": "avermelhado",
    "avermelhado": "avermelhar",
    "avermelhados": "avermelhar",
    "avermelhadíssima": "avermelhado",
    "avermelhadíssimas": "avermelhado",
    "avermelhadíssimo": "avermelhado",
    "avermelhadíssimos": "avermelhado",
    "avermelhai": "avermelhar",
    "avermelhais": "avermelhar",
    "avermelham": "avermelhar",
    "avermelhamo": "avermelhar",
    "avermelhamos": "avermelhar",
    "avermelhando": "avermelhar",
    "avermelhara": "avermelhar",
    "avermelharam": "avermelhar",
    "avermelharas": "avermelhar",
    "avermelharde": "avermelhar",
    "avermelhardes": "avermelhar",
    "avermelhare": "avermelhar",
    "avermelharei": "avermelhar",
    "avermelhareis": "avermelhar",
    "avermelharem": "avermelhar",
    "avermelharemos": "avermelhar",
    "avermelhares": "avermelhar",
    "avermelharia": "avermelhar",
    "avermelhariam": "avermelhar",
    "avermelharias": "avermelhar",
    "avermelharmo": "avermelhar",
    "avermelharmos": "avermelhar",
    "avermelhará": "avermelhar",
    "avermelharás": "avermelhar",
    "avermelharão": "avermelhar",
    "avermelharíamos": "avermelhar",
    "avermelharíeis": "avermelhar",
    "avermelhas": "avermelhar",
    "avermelhasse": "avermelhar",
    "avermelhassem": "avermelhar",
    "avermelhasses": "avermelhar",
    "avermelhaste": "avermelhar",
    "avermelhastes": "avermelhar",
    "avermelhava": "avermelhar",
    "avermelhavam": "avermelhar",
    "avermelhavas": "avermelhar",
    "avermelhe": "avermelhar",
    "avermelhei": "avermelhar",
    "avermelheis": "avermelhar",
    "avermelhem": "avermelhar",
    "avermelhemo": "avermelhar",
    "avermelhemos": "avermelhar",
    "avermelhes": "avermelhar",
    "avermelho": "avermelhar",
    "avermelhou": "avermelhar",
    "avermelhá": "avermelhar",
    "avermelhámo": "avermelhar",
    "avermelhámos": "avermelhar",
    "avermelháramo": "avermelhar",
    "avermelháramos": "avermelhar",
    "avermelhárei": "avermelhar",
    "avermelháreis": "avermelhar",
    "avermelhásseis": "avermelhar",
    "avermelhássemos": "avermelhar",
    "avermelhávamo": "avermelhar",
    "avermelhávamos": "avermelhar",
    "avermelhávei": "avermelhar",
    "avermelháveis": "avermelhar",
    "avernais": "avernal",
    "averroísmos": "averroísmo",
    "averroístas": "averroísta",
    "aversões": "aversão",
    "aves": "ave",
    "avessa": "avesso",
    "avessada": "avessado",
    "avessadas": "avessado",
    "avessados": "avessado",
    "avessas": "avesso",
    "avesseira": "avesseiro",
    "avesseiras": "avesseiro",
    "avesseiros": "avesseiro",
    "avessias": "avessia",
    "avessidades": "avessidade",
    "avessos": "avesso",
    "avestrueira": "avestrueiro",
    "avestrueiras": "avestrueiro",
    "avestrueiros": "avestrueiro",
    "avestruzeira": "avestruzeiro",
    "avestruzeiras": "avestruzeiro",
    "avestruzeiros": "avestruzeiro",
    "avestruzes": "avestruz",
    "avezada": "avezado",
    "avezadas": "avezado",
    "avezados": "avezado",
    "avezinha": "ave",
    "avezinhas": "ave",
    "avezita": "ave",
    "avezitas": "ave",
    "aveões": "aveão",
    "avia": "aviar",
    "aviada": "aviar",
    "aviadas": "aviar",
    "aviadinha": "aviado",
    "aviadinhas": "aviado",
    "aviadinho": "aviado",
    "aviadinhos": "aviado",
    "aviadita": "aviado",
    "aviaditas": "aviado",
    "aviadito": "aviado",
    "aviaditos": "aviado",
    "aviado": "aviar",
    "aviadora": "aviador",
    "aviadoras": "aviador",
    "aviadores": "aviador",
    "aviados": "aviar",
    "aviadíssima": "aviado",
    "aviadíssimas": "aviado",
    "aviadíssimo": "aviado",
    "aviadíssimos": "aviado",
    "aviai": "aviar",
    "aviais": "aviar",
    "aviajada": "aviajado",
    "aviajadas": "aviajado",
    "aviajados": "aviajado",
    "aviam": "aviar",
    "aviamentos": "aviamento",
    "aviamo": "aviar",
    "aviamos": "aviar",
    "aviando": "aviar",
    "aviara": "aviar",
    "aviaram": "aviar",
    "aviaras": "aviar",
    "aviarde": "aviar",
    "aviardes": "aviar",
    "aviare": "aviar",
    "aviarei": "aviar",
    "aviareis": "aviar",
    "aviarem": "aviar",
    "aviaremos": "aviar",
    "aviares": "aviar",
    "aviaria": "aviar",
    "aviariam": "aviar",
    "aviarias": "aviar",
    "aviarmo": "aviar",
    "aviarmos": "aviar",
    "aviará": "aviar",
    "aviarás": "aviar",
    "aviarão": "aviar",
    "aviaríamos": "aviar",
    "aviaríeis": "aviar",
    "avias": "aviar",
    "aviasse": "aviar",
    "aviassem": "aviar",
    "aviasses": "aviar",
    "aviaste": "aviar",
    "aviastes": "aviar",
    "aviava": "aviar",
    "aviavam": "aviar",
    "aviavas": "aviar",
    "aviações": "aviação",
    "aviceptologias": "aviceptologia",
    "avicidas": "avicida",
    "aviculares": "avicular",
    "aviculas": "avicula",
    "aviculinhas": "aviculinha",
    "avicultora": "avicultor",
    "avicultoras": "avicultor",
    "avicultores": "avicultor",
    "aviculturas": "avicultura",
    "aviculária": "aviculário",
    "aviculárias": "aviculário",
    "aviculários": "aviculário",
    "aviculídea": "aviculídeo",
    "aviculídeas": "aviculídeo",
    "aviculídeos": "aviculídeo",
    "avicénias": "avicénia",
    "avicúlidas": "avicúlida",
    "avidazinha": "ávido",
    "avidazinhas": "ávido",
    "avidazita": "ávido",
    "avidazitas": "ávido",
    "avidezes": "avidez",
    "avidozinho": "ávido",
    "avidozinhos": "ávido",
    "avidozito": "ávido",
    "avidozitos": "ávido",
    "avidíssima": "ávido",
    "avidíssimas": "ávido",
    "avidíssimo": "ávido",
    "avidíssimos": "ávido",
    "avie": "aviar",
    "aviei": "aviar",
    "avieirada": "avieirado",
    "avieiradas": "avieirado",
    "avieirados": "avieirado",
    "avieiros": "avieiro",
    "avieis": "aviar",
    "aviem": "aviar",
    "aviemo": "aviar",
    "aviemos": "aviar",
    "avies": "aviar",
    "aviguramentos": "aviguramento",
    "avilta": "aviltar",
    "aviltada": "aviltar",
    "aviltadas": "aviltar",
    "aviltado": "aviltar",
    "aviltadora": "aviltador",
    "aviltadoras": "aviltador",
    "aviltadores": "aviltador",
    "aviltados": "aviltar",
    "aviltadíssima": "aviltado",
    "aviltadíssimas": "aviltado",
    "aviltadíssimo": "aviltado",
    "aviltadíssimos": "aviltado",
    "aviltai": "aviltar",
    "aviltais": "aviltar",
    "aviltam": "aviltar",
    "aviltamentos": "aviltamento",
    "aviltamo": "aviltar",
    "aviltamos": "aviltar",
    "aviltando": "aviltar",
    "aviltantes": "aviltante",
    "aviltara": "aviltar",
    "aviltaram": "aviltar",
    "aviltaras": "aviltar",
    "aviltarde": "aviltar",
    "aviltardes": "aviltar",
    "aviltare": "aviltar",
    "aviltarei": "aviltar",
    "aviltareis": "aviltar",
    "aviltarem": "aviltar",
    "aviltaremos": "aviltar",
    "aviltares": "aviltar",
    "aviltaria": "aviltar",
    "aviltariam": "aviltar",
    "aviltarias": "aviltar",
    "aviltarmo": "aviltar",
    "aviltarmos": "aviltar",
    "aviltará": "aviltar",
    "aviltarás": "aviltar",
    "aviltarão": "aviltar",
    "aviltaríamos": "aviltar",
    "aviltaríeis": "aviltar",
    "aviltas": "aviltar",
    "aviltasse": "aviltar",
    "aviltassem": "aviltar",
    "aviltasses": "aviltar",
    "aviltaste": "aviltar",
    "aviltastes": "aviltar",
    "aviltava": "aviltar",
    "aviltavam": "aviltar",
    "aviltavas": "aviltar",
    "aviltações": "aviltação",
    "avilte": "aviltar",
    "aviltei": "aviltar",
    "avilteis": "aviltar",
    "aviltem": "aviltar",
    "aviltemo": "aviltar",
    "aviltemos": "aviltar",
    "aviltes": "aviltar",
    "avilto": "aviltar",
    "aviltou": "aviltar",
    "aviltá": "aviltar",
    "aviltámo": "aviltar",
    "aviltámos": "aviltar",
    "aviltáramo": "aviltar",
    "aviltáramos": "aviltar",
    "aviltárei": "aviltar",
    "aviltáreis": "aviltar",
    "aviltásseis": "aviltar",
    "aviltássemos": "aviltar",
    "aviltávamo": "aviltar",
    "aviltávamos": "aviltar",
    "aviltávei": "aviltar",
    "aviltáveis": "aviltar",
    "avinagra": "avinagrar",
    "avinagrada": "avinagrar",
    "avinagradas": "avinagrar",
    "avinagrado": "avinagrar",
    "avinagrados": "avinagrar",
    "avinagrai": "avinagrar",
    "avinagrais": "avinagrar",
    "avinagram": "avinagrar",
    "avinagramo": "avinagrar",
    "avinagramos": "avinagrar",
    "avinagrando": "avinagrar",
    "avinagrara": "avinagrar",
    "avinagraram": "avinagrar",
    "avinagraras": "avinagrar",
    "avinagrarde": "avinagrar",
    "avinagrardes": "avinagrar",
    "avinagrare": "avinagrar",
    "avinagrarei": "avinagrar",
    "avinagrareis": "avinagrar",
    "avinagrarem": "avinagrar",
    "avinagraremos": "avinagrar",
    "avinagrares": "avinagrar",
    "avinagraria": "avinagrar",
    "avinagrariam": "avinagrar",
    "avinagrarias": "avinagrar",
    "avinagrarmo": "avinagrar",
    "avinagrarmos": "avinagrar",
    "avinagrará": "avinagrar",
    "avinagrarás": "avinagrar",
    "avinagrarão": "avinagrar",
    "avinagraríamos": "avinagrar",
    "avinagraríeis": "avinagrar",
    "avinagras": "avinagrar",
    "avinagrasse": "avinagrar",
    "avinagrassem": "avinagrar",
    "avinagrasses": "avinagrar",
    "avinagraste": "avinagrar",
    "avinagrastes": "avinagrar",
    "avinagrava": "avinagrar",
    "avinagravam": "avinagrar",
    "avinagravas": "avinagrar",
    "avinagre": "avinagrar",
    "avinagrei": "avinagrar",
    "avinagreis": "avinagrar",
    "avinagrem": "avinagrar",
    "avinagremo": "avinagrar",
    "avinagremos": "avinagrar",
    "avinagres": "avinagrar",
    "avinagro": "avinagrar",
    "avinagrou": "avinagrar",
    "avinagrá": "avinagrar",
    "avinagrámo": "avinagrar",
    "avinagrámos": "avinagrar",
    "avinagráramo": "avinagrar",
    "avinagráramos": "avinagrar",
    "avinagrárei": "avinagrar",
    "avinagráreis": "avinagrar",
    "avinagrásseis": "avinagrar",
    "avinagrássemos": "avinagrar",
    "avinagrávamo": "avinagrar",
    "avinagrávamos": "avinagrar",
    "avinagrávei": "avinagrar",
    "avinagráveis": "avinagrar",
    "avinda": "avindo",
    "avindas": "avindo",
    "avindora": "avindor",
    "avindoras": "avindor",
    "avindores": "avindor",
    "avindos": "avindo",
    "avinhada": "avinhado",
    "avinhadas": "avinhado",
    "avinhados": "avinhado",
    "avintenses": "avintense",
    "avio": "aviar",
    "aviolada": "aviolado",
    "avioladas": "aviolado",
    "aviolados": "aviolado",
    "avioleta": "avioletar",
    "avioletada": "avioletar",
    "avioletadas": "avioletar",
    "avioletado": "avioletar",
    "avioletados": "avioletar",
    "avioletai": "avioletar",
    "avioletais": "avioletar",
    "avioletam": "avioletar",
    "avioletamo": "avioletar",
    "avioletamos": "avioletar",
    "avioletando": "avioletar",
    "avioletara": "avioletar",
    "avioletaram": "avioletar",
    "avioletaras": "avioletar",
    "avioletarde": "avioletar",
    "avioletardes": "avioletar",
    "avioletare": "avioletar",
    "avioletarei": "avioletar",
    "avioletareis": "avioletar",
    "avioletarem": "avioletar",
    "avioletaremos": "avioletar",
    "avioletares": "avioletar",
    "avioletaria": "avioletar",
    "avioletariam": "avioletar",
    "avioletarias": "avioletar",
    "avioletarmo": "avioletar",
    "avioletarmos": "avioletar",
    "avioletará": "avioletar",
    "avioletarás": "avioletar",
    "avioletarão": "avioletar",
    "avioletaríamos": "avioletar",
    "avioletaríeis": "avioletar",
    "avioletas": "avioletar",
    "avioletasse": "avioletar",
    "avioletassem": "avioletar",
    "avioletasses": "avioletar",
    "avioletaste": "avioletar",
    "avioletastes": "avioletar",
    "avioletava": "avioletar",
    "avioletavam": "avioletar",
    "avioletavas": "avioletar",
    "aviolete": "avioletar",
    "avioletei": "avioletar",
    "avioleteis": "avioletar",
    "avioletem": "avioletar",
    "avioletemo": "avioletar",
    "avioletemos": "avioletar",
    "avioletes": "avioletar",
    "avioleto": "avioletar",
    "avioletou": "avioletar",
    "avioletá": "avioletar",
    "avioletámo": "avioletar",
    "avioletámos": "avioletar",
    "avioletáramo": "avioletar",
    "avioletáramos": "avioletar",
    "avioletárei": "avioletar",
    "avioletáreis": "avioletar",
    "avioletásseis": "avioletar",
    "avioletássemos": "avioletar",
    "avioletávamo": "avioletar",
    "avioletávamos": "avioletar",
    "avioletávei": "avioletar",
    "avioletáveis": "avioletar",
    "aviominiaturas": "aviominiatura",
    "avionetas": "avioneta",
    "avios": "avio",
    "aviou": "aviar",
    "avirja": "avergir",
    "avirjais": "avergir",
    "avirjam": "avergir",
    "avirjamo": "avergir",
    "avirjamos": "avergir",
    "avirjas": "avergir",
    "avirjo": "avergir",
    "avisa": "avisar",
    "avisada": "avisar",
    "avisadas": "avisar",
    "avisado": "avisar",
    "avisadora": "avisador",
    "avisadoras": "avisador",
    "avisadores": "avisador",
    "avisados": "avisar",
    "avisadíssima": "avisado",
    "avisadíssimas": "avisado",
    "avisadíssimo": "avisado",
    "avisadíssimos": "avisado",
    "avisai": "avisar",
    "avisais": "avisar",
    "avisam": "avisar",
    "avisamo": "avisar",
    "avisamos": "avisar",
    "avisando": "avisar",
    "avisara": "avisar",
    "avisaram": "avisar",
    "avisaras": "avisar",
    "avisarde": "avisar",
    "avisardes": "avisar",
    "avisare": "avisar",
    "avisarei": "avisar",
    "avisareis": "avisar",
    "avisarem": "avisar",
    "avisaremos": "avisar",
    "avisares": "avisar",
    "avisaria": "avisar",
    "avisariam": "avisar",
    "avisarias": "avisar",
    "avisarmo": "avisar",
    "avisarmos": "avisar",
    "avisará": "avisar",
    "avisarás": "avisar",
    "avisarão": "avisar",
    "avisaríamos": "avisar",
    "avisaríeis": "avisar",
    "avisas": "avisar",
    "avisasse": "avisar",
    "avisassem": "avisar",
    "avisasses": "avisar",
    "avisaste": "avisar",
    "avisastes": "avisar",
    "avisava": "avisar",
    "avisavam": "avisar",
    "avisavas": "avisar",
    "avise": "avisar",
    "avisei": "avisar",
    "aviseis": "avisar",
    "avisem": "avisar",
    "avisemo": "avisar",
    "avisemos": "avisar",
    "avises": "avisar",
    "aviso": "avisar",
    "avisos": "aviso",
    "avisou": "avisar",
    "avissugas": "avissuga",
    "avista": "avistar",
    "avistada": "avistar",
    "avistadas": "avistar",
    "avistado": "avistar",
    "avistados": "avistar",
    "avistai": "avistar",
    "avistais": "avistar",
    "avistam": "avistar",
    "avistamo": "avistar",
    "avistamos": "avistar",
    "avistando": "avistar",
    "avistara": "avistar",
    "avistaram": "avistar",
    "avistaras": "avistar",
    "avistarde": "avistar",
    "avistardes": "avistar",
    "avistare": "avistar",
    "avistarei": "avistar",
    "avistareis": "avistar",
    "avistarem": "avistar",
    "avistaremos": "avistar",
    "avistares": "avistar",
    "avistaria": "avistar",
    "avistariam": "avistar",
    "avistarias": "avistar",
    "avistarmo": "avistar",
    "avistarmos": "avistar",
    "avistará": "avistar",
    "avistarás": "avistar",
    "avistarão": "avistar",
    "avistaríamos": "avistar",
    "avistaríeis": "avistar",
    "avistas": "avistar",
    "avistasse": "avistar",
    "avistassem": "avistar",
    "avistasses": "avistar",
    "avistaste": "avistar",
    "avistastes": "avistar",
    "avistava": "avistar",
    "avistavam": "avistar",
    "avistavas": "avistar",
    "aviste": "avistar",
    "avistei": "avistar",
    "avisteis": "avistar",
    "avistem": "avistar",
    "avistemo": "avistar",
    "avistemos": "avistar",
    "avistes": "avistar",
    "avisto": "avistar",
    "avistou": "avistar",
    "avistá": "avistar",
    "avistámo": "avistar",
    "avistámos": "avistar",
    "avistáramo": "avistar",
    "avistáramos": "avistar",
    "avistárei": "avistar",
    "avistáreis": "avistar",
    "avistásseis": "avistar",
    "avistássemos": "avistar",
    "avistávamo": "avistar",
    "avistávamos": "avistar",
    "avistávei": "avistar",
    "avistáveis": "avistável",
    "avisá": "avisar",
    "avisámo": "avisar",
    "avisámos": "avisar",
    "avisáramo": "avisar",
    "avisáramos": "avisar",
    "avisárei": "avisar",
    "avisáreis": "avisar",
    "avisásseis": "avisar",
    "avisássemos": "avisar",
    "avisávamo": "avisar",
    "avisávamos": "avisar",
    "avisávei": "avisar",
    "avisáveis": "avisar",
    "avita": "avito",
    "avitaminoses": "avitaminose",
    "avitas": "avito",
    "avitos": "avito",
    "aviva": "avivar",
    "avivada": "avivar",
    "avivadas": "avivar",
    "avivadinha": "avivado",
    "avivadinhas": "avivado",
    "avivadinho": "avivado",
    "avivadinhos": "avivado",
    "avivadita": "avivado",
    "avivaditas": "avivado",
    "avivadito": "avivado",
    "avivaditos": "avivado",
    "avivado": "avivar",
    "avivadora": "avivador",
    "avivadoras": "avivador",
    "avivadores": "avivador",
    "avivados": "avivar",
    "avivadíssima": "avivado",
    "avivadíssimas": "avivado",
    "avivadíssimo": "avivado",
    "avivadíssimos": "avivado",
    "avivai": "avivar",
    "avivais": "avivar",
    "avivam": "avivar",
    "avivamentos": "avivamento",
    "avivamo": "avivar",
    "avivamos": "avivar",
    "avivando": "avivar",
    "avivara": "avivar",
    "avivaram": "avivar",
    "avivaras": "avivar",
    "avivarde": "avivar",
    "avivardes": "avivar",
    "avivare": "avivar",
    "avivarei": "avivar",
    "avivareis": "avivar",
    "avivarem": "avivar",
    "avivaremos": "avivar",
    "avivares": "avivar",
    "avivaria": "avivar",
    "avivariam": "avivar",
    "avivarias": "avivar",
    "avivarmo": "avivar",
    "avivarmos": "avivar",
    "avivará": "avivar",
    "avivarás": "avivar",
    "avivarão": "avivar",
    "avivaríamos": "avivar",
    "avivaríeis": "avivar",
    "avivas": "avivar",
    "avivasse": "avivar",
    "avivassem": "avivar",
    "avivasses": "avivar",
    "avivaste": "avivar",
    "avivastes": "avivar",
    "avivava": "avivar",
    "avivavam": "avivar",
    "avivavas": "avivar",
    "avive": "avivar",
    "avivei": "avivar",
    "aviveis": "avivar",
    "avivem": "avivar",
    "avivemo": "avivar",
    "avivemos": "avivar",
    "aviventa": "aviventar",
    "aviventada": "aviventar",
    "aviventadas": "aviventar",
    "aviventado": "aviventar",
    "aviventadora": "aviventador",
    "aviventadoras": "aviventador",
    "aviventadores": "aviventador",
    "aviventados": "aviventar",
    "aviventai": "aviventar",
    "aviventais": "aviventar",
    "aviventam": "aviventar",
    "aviventamo": "aviventar",
    "aviventamos": "aviventar",
    "aviventando": "aviventar",
    "aviventara": "aviventar",
    "aviventaram": "aviventar",
    "aviventaras": "aviventar",
    "aviventarde": "aviventar",
    "aviventardes": "aviventar",
    "aviventare": "aviventar",
    "aviventarei": "aviventar",
    "aviventareis": "aviventar",
    "aviventarem": "aviventar",
    "aviventaremos": "aviventar",
    "aviventares": "aviventar",
    "aviventaria": "aviventar",
    "aviventariam": "aviventar",
    "aviventarias": "aviventar",
    "aviventarmo": "aviventar",
    "aviventarmos": "aviventar",
    "aviventará": "aviventar",
    "aviventarás": "aviventar",
    "aviventarão": "aviventar",
    "aviventaríamos": "aviventar",
    "aviventaríeis": "aviventar",
    "aviventas": "aviventar",
    "aviventasse": "aviventar",
    "aviventassem": "aviventar",
    "aviventasses": "aviventar",
    "aviventaste": "aviventar",
    "aviventastes": "aviventar",
    "aviventava": "aviventar",
    "aviventavam": "aviventar",
    "aviventavas": "aviventar",
    "avivente": "aviventar",
    "aviventei": "aviventar",
    "aviventeis": "aviventar",
    "aviventem": "aviventar",
    "aviventemo": "aviventar",
    "aviventemos": "aviventar",
    "aviventes": "aviventar",
    "avivento": "aviventar",
    "aviventou": "aviventar",
    "aviventá": "aviventar",
    "aviventámo": "aviventar",
    "aviventámos": "aviventar",
    "aviventáramo": "aviventar",
    "aviventáramos": "aviventar",
    "aviventárei": "aviventar",
    "aviventáreis": "aviventar",
    "aviventásseis": "aviventar",
    "aviventássemos": "aviventar",
    "aviventávamo": "aviventar",
    "aviventávamos": "aviventar",
    "aviventávei": "aviventar",
    "aviventáveis": "aviventar",
    "avives": "avivar",
    "avivo": "avivar",
    "avivou": "avivar",
    "avivá": "avivar",
    "avivámo": "avivar",
    "avivámos": "avivar",
    "aviváramo": "avivar",
    "aviváramos": "avivar",
    "avivárei": "avivar",
    "aviváreis": "avivar",
    "avivásseis": "avivar",
    "avivássemos": "avivar",
    "avivávamo": "avivar",
    "avivávamos": "avivar",
    "avivávei": "avivar",
    "aviváveis": "avivar",
    "avizinha": "avizinhar",
    "avizinhada": "avizinhar",
    "avizinhadas": "avizinhar",
    "avizinhado": "avizinhar",
    "avizinhados": "avizinhar",
    "avizinhai": "avizinhar",
    "avizinhais": "avizinhar",
    "avizinham": "avizinhar",
    "avizinhamo": "avizinhar",
    "avizinhamos": "avizinhar",
    "avizinhando": "avizinhar",
    "avizinhara": "avizinhar",
    "avizinharam": "avizinhar",
    "avizinharas": "avizinhar",
    "avizinharde": "avizinhar",
    "avizinhardes": "avizinhar",
    "avizinhare": "avizinhar",
    "avizinharei": "avizinhar",
    "avizinhareis": "avizinhar",
    "avizinharem": "avizinhar",
    "avizinharemos": "avizinhar",
    "avizinhares": "avizinhar",
    "avizinharia": "avizinhar",
    "avizinhariam": "avizinhar",
    "avizinharias": "avizinhar",
    "avizinharmo": "avizinhar",
    "avizinharmos": "avizinhar",
    "avizinhará": "avizinhar",
    "avizinharás": "avizinhar",
    "avizinharão": "avizinhar",
    "avizinharíamos": "avizinhar",
    "avizinharíeis": "avizinhar",
    "avizinhas": "avizinhar",
    "avizinhasse": "avizinhar",
    "avizinhassem": "avizinhar",
    "avizinhasses": "avizinhar",
    "avizinhaste": "avizinhar",
    "avizinhastes": "avizinhar",
    "avizinhava": "avizinhar",
    "avizinhavam": "avizinhar",
    "avizinhavas": "avizinhar",
    "avizinhações": "avizinhação",
    "avizinhe": "avizinhar",
    "avizinhei": "avizinhar",
    "avizinheis": "avizinhar",
    "avizinhem": "avizinhar",
    "avizinhemo": "avizinhar",
    "avizinhemos": "avizinhar",
    "avizinhes": "avizinhar",
    "avizinho": "avizinhar",
    "avizinhou": "avizinhar",
    "avizinhá": "avizinhar",
    "avizinhámo": "avizinhar",
    "avizinhámos": "avizinhar",
    "avizinháramo": "avizinhar",
    "avizinháramos": "avizinhar",
    "avizinhárei": "avizinhar",
    "avizinháreis": "avizinhar",
    "avizinhásseis": "avizinhar",
    "avizinhássemos": "avizinhar",
    "avizinhávamo": "avizinhar",
    "avizinhávamos": "avizinhar",
    "avizinhávei": "avizinhar",
    "avizinháveis": "avizinhar",
    "aviá": "aviar",
    "aviámo": "aviar",
    "aviámos": "aviar",
    "aviáramo": "aviar",
    "aviáramos": "aviar",
    "aviárei": "aviar",
    "aviáreis": "aviar",
    "aviária": "aviário",
    "aviárias": "aviário",
    "aviários": "aviário",
    "aviásseis": "aviar",
    "aviássemos": "aviar",
    "aviávamo": "aviar",
    "aviávamos": "aviar",
    "aviávei": "aviar",
    "aviáveis": "aviar",
    "aviãozinho": "avião",
    "aviãozito": "avião",
    "aviões": "avião",
    "aviõezinhos": "avião",
    "aviõezitos": "avião",
    "avoamentos": "avoamento",
    "avoca": "avocar",
    "avocada": "avocar",
    "avocadas": "avocar",
    "avocado": "avocar",
    "avocados": "avocar",
    "avocai": "avocar",
    "avocais": "avocar",
    "avocam": "avocar",
    "avocamo": "avocar",
    "avocamos": "avocar",
    "avocando": "avocar",
    "avocara": "avocar",
    "avocaram": "avocar",
    "avocaras": "avocar",
    "avocarde": "avocar",
    "avocardes": "avocar",
    "avocare": "avocar",
    "avocarei": "avocar",
    "avocareis": "avocar",
    "avocarem": "avocar",
    "avocaremos": "avocar",
    "avocares": "avocar",
    "avocaria": "avocar",
    "avocariam": "avocar",
    "avocarias": "avocar",
    "avocarmo": "avocar",
    "avocarmos": "avocar",
    "avocará": "avocar",
    "avocarás": "avocar",
    "avocarão": "avocar",
    "avocaríamos": "avocar",
    "avocaríeis": "avocar",
    "avocas": "avocar",
    "avocasse": "avocar",
    "avocassem": "avocar",
    "avocasses": "avocar",
    "avocaste": "avocar",
    "avocastes": "avocar",
    "avocaturas": "avocatura",
    "avocatória": "avocatório",
    "avocatórias": "avocatório",
    "avocatórios": "avocatório",
    "avocava": "avocar",
    "avocavam": "avocar",
    "avocavas": "avocar",
    "avocações": "avocação",
    "avocetas": "avoceta",
    "avoco": "avocar",
    "avocou": "avocar",
    "avocá": "avocar",
    "avocámo": "avocar",
    "avocámos": "avocar",
    "avocáramo": "avocar",
    "avocáramos": "avocar",
    "avocárei": "avocar",
    "avocáreis": "avocar",
    "avocásseis": "avocar",
    "avocássemos": "avocar",
    "avocávamo": "avocar",
    "avocávamos": "avocar",
    "avocávei": "avocar",
    "avocáveis": "avocável",
    "avoeiras": "avoeira",
    "avoejos": "avoejo",
    "avoenga": "avoengo",
    "avoengas": "avoengo",
    "avoengos": "avoengo",
    "avoengueira": "avoengueiro",
    "avoengueiras": "avoengueiro",
    "avoengueiros": "avoengueiro",
    "avoluma": "avolumar",
    "avolumada": "avolumar",
    "avolumadas": "avolumar",
    "avolumado": "avolumar",
    "avolumados": "avolumar",
    "avolumai": "avolumar",
    "avolumais": "avolumar",
    "avolumam": "avolumar",
    "avolumamo": "avolumar",
    "avolumamos": "avolumar",
    "avolumando": "avolumar",
    "avolumara": "avolumar",
    "avolumaram": "avolumar",
    "avolumaras": "avolumar",
    "avolumarde": "avolumar",
    "avolumardes": "avolumar",
    "avolumare": "avolumar",
    "avolumarei": "avolumar",
    "avolumareis": "avolumar",
    "avolumarem": "avolumar",
    "avolumaremos": "avolumar",
    "avolumares": "avolumar",
    "avolumaria": "avolumar",
    "avolumariam": "avolumar",
    "avolumarias": "avolumar",
    "avolumarmo": "avolumar",
    "avolumarmos": "avolumar",
    "avolumará": "avolumar",
    "avolumarás": "avolumar",
    "avolumarão": "avolumar",
    "avolumaríamos": "avolumar",
    "avolumaríeis": "avolumar",
    "avolumas": "avolumar",
    "avolumasse": "avolumar",
    "avolumassem": "avolumar",
    "avolumasses": "avolumar",
    "avolumaste": "avolumar",
    "avolumastes": "avolumar",
    "avolumava": "avolumar",
    "avolumavam": "avolumar",
    "avolumavas": "avolumar",
    "avolume": "avolumar",
    "avolumei": "avolumar",
    "avolumeis": "avolumar",
    "avolumem": "avolumar",
    "avolumemo": "avolumar",
    "avolumemos": "avolumar",
    "avolumes": "avolumar",
    "avolumo": "avolumar",
    "avolumou": "avolumar",
    "avolumá": "avolumar",
    "avolumámo": "avolumar",
    "avolumámos": "avolumar",
    "avolumáramo": "avolumar",
    "avolumáramos": "avolumar",
    "avolumárei": "avolumar",
    "avolumáreis": "avolumar",
    "avolumásseis": "avolumar",
    "avolumássemos": "avolumar",
    "avolumávamo": "avolumar",
    "avolumávamos": "avolumar",
    "avolumávei": "avolumar",
    "avolumáveis": "avolumar",
    "avoque": "avocar",
    "avoquei": "avocar",
    "avoqueis": "avocar",
    "avoquem": "avocar",
    "avoquemo": "avocar",
    "avoquemos": "avocar",
    "avoques": "avocar",
    "avos": "avo",
    "avozinha": "avô",
    "avozinhas": "avô",
    "avozinho": "avô",
    "avozinhos": "avô",
    "avozita": "avô",
    "avozitas": "avô",
    "avozito": "avô",
    "avozitos": "avô",
    "avoões": "avoão",
    "avras": "avra",
    "avulsa": "avulso",
    "avulsas": "avulso",
    "avulsiva": "avulsivo",
    "avulsivas": "avulsivo",
    "avulsivos": "avulsivo",
    "avulsos": "avulso",
    "avulsões": "avulsão",
    "avulta": "avultar",
    "avultada": "avultar",
    "avultadas": "avultar",
    "avultadinha": "avultado",
    "avultadinhas": "avultado",
    "avultadinho": "avultado",
    "avultadinhos": "avultado",
    "avultadita": "avultado",
    "avultaditas": "avultado",
    "avultadito": "avultado",
    "avultaditos": "avultado",
    "avultado": "avultar",
    "avultados": "avultar",
    "avultadíssima": "avultado",
    "avultadíssimas": "avultado",
    "avultadíssimo": "avultado",
    "avultadíssimos": "avultado",
    "avultai": "avultar",
    "avultais": "avultar",
    "avultam": "avultar",
    "avultamo": "avultar",
    "avultamos": "avultar",
    "avultando": "avultar",
    "avultara": "avultar",
    "avultaram": "avultar",
    "avultaras": "avultar",
    "avultarde": "avultar",
    "avultardes": "avultar",
    "avultare": "avultar",
    "avultarei": "avultar",
    "avultareis": "avultar",
    "avultarem": "avultar",
    "avultaremos": "avultar",
    "avultares": "avultar",
    "avultaria": "avultar",
    "avultariam": "avultar",
    "avultarias": "avultar",
    "avultarmo": "avultar",
    "avultarmos": "avultar",
    "avultará": "avultar",
    "avultarás": "avultar",
    "avultarão": "avultar",
    "avultaríamos": "avultar",
    "avultaríeis": "avultar",
    "avultas": "avultar",
    "avultasse": "avultar",
    "avultassem": "avultar",
    "avultasses": "avultar",
    "avultaste": "avultar",
    "avultastes": "avultar",
    "avultava": "avultar",
    "avultavam": "avultar",
    "avultavas": "avultar",
    "avultações": "avultação",
    "avulte": "avultar",
    "avultei": "avultar",
    "avulteis": "avultar",
    "avultem": "avultar",
    "avultemo": "avultar",
    "avultemos": "avultar",
    "avultes": "avultar",
    "avulto": "avultar",
    "avultosa": "avultoso",
    "avultosas": "avultoso",
    "avultosos": "avultoso",
    "avultou": "avultar",
    "avultá": "avultar",
    "avultámo": "avultar",
    "avultámos": "avultar",
    "avultáramo": "avultar",
    "avultáramos": "avultar",
    "avultárei": "avultar",
    "avultáreis": "avultar",
    "avultásseis": "avultar",
    "avultássemos": "avultar",
    "avultávamo": "avultar",
    "avultávamos": "avultar",
    "avultávei": "avultar",
    "avultáveis": "avultar",
    "avunculares": "avuncular",
    "avés": "avé",
    "avéstica": "avéstico",
    "avésticas": "avéstico",
    "avésticos": "avéstico",
    "avícolas": "avícola",
    "avó": "avô",
    "avós": "avô",
    "avôs": "avô",
    "axadrezada": "axadrezado",
    "axadrezadas": "axadrezado",
    "axadrezados": "axadrezado",
    "axelhos": "axelho",
    "axes": "axe",
    "axiais": "axial",
    "axiformes": "axiforme",
    "axilantes": "axilante",
    "axilares": "axilar",
    "axilas": "axila",
    "aximezes": "aximez",
    "axinitas": "axinita",
    "axinites": "axinite",
    "axinomancias": "axinomancia",
    "axinomantes": "axinomante",
    "axinomântica": "axinomântico",
    "axinomânticas": "axinomântico",
    "axinomânticos": "axinomântico",
    "axiologias": "axiologia",
    "axiomas": "axioma",
    "axiometrias": "axiometria",
    "axiomática": "axiomático",
    "axiomáticas": "axiomático",
    "axiomáticos": "axiomático",
    "axiométrica": "axiométrico",
    "axiométricas": "axiométrico",
    "axiométricos": "axiométrico",
    "axionímias": "axionímia",
    "axiómetros": "axiómetro",
    "axiónimos": "axiónimo",
    "axorcas": "axorca",
    "axículos": "axículo",
    "axífera": "axífero",
    "axíferas": "axífero",
    "axíferos": "axífero",
    "axífuga": "axífugo",
    "axífugas": "axífugo",
    "axífugos": "axífugo",
    "axípeta": "axípeto",
    "axípetas": "axípeto",
    "axípetos": "axípeto",
    "axóides": "axóide",
    "axónios": "axónio",
    "axúnguias": "axúnguia",
    "ayatollahs": "ayatollah",
    "azabumbada": "azabumbado",
    "azabumbadas": "azabumbado",
    "azabumbados": "azabumbado",
    "azabumbantes": "azabumbante",
    "azada": "azado",
    "azadas": "azado",
    "azados": "azado",
    "azafama": "azafamar",
    "azafamada": "azafamar",
    "azafamadas": "azafamar",
    "azafamado": "azafamar",
    "azafamados": "azafamar",
    "azafamai": "azafamar",
    "azafamais": "azafamar",
    "azafamam": "azafamar",
    "azafamamo": "azafamar",
    "azafamamos": "azafamar",
    "azafamando": "azafamar",
    "azafamara": "azafamar",
    "azafamaram": "azafamar",
    "azafamaras": "azafamar",
    "azafamarde": "azafamar",
    "azafamardes": "azafamar",
    "azafamare": "azafamar",
    "azafamarei": "azafamar",
    "azafamareis": "azafamar",
    "azafamarem": "azafamar",
    "azafamaremos": "azafamar",
    "azafamares": "azafamar",
    "azafamaria": "azafamar",
    "azafamariam": "azafamar",
    "azafamarias": "azafamar",
    "azafamarmo": "azafamar",
    "azafamarmos": "azafamar",
    "azafamará": "azafamar",
    "azafamarás": "azafamar",
    "azafamarão": "azafamar",
    "azafamaríamos": "azafamar",
    "azafamaríeis": "azafamar",
    "azafamas": "azafamar",
    "azafamasse": "azafamar",
    "azafamassem": "azafamar",
    "azafamasses": "azafamar",
    "azafamaste": "azafamar",
    "azafamastes": "azafamar",
    "azafamava": "azafamar",
    "azafamavam": "azafamar",
    "azafamavas": "azafamar",
    "azafame": "azafamar",
    "azafamei": "azafamar",
    "azafameis": "azafamar",
    "azafamem": "azafamar",
    "azafamemo": "azafamar",
    "azafamemos": "azafamar",
    "azafames": "azafamar",
    "azafamo": "azafamar",
    "azafamou": "azafamar",
    "azafamá": "azafamar",
    "azafamámo": "azafamar",
    "azafamámos": "azafamar",
    "azafamáramo": "azafamar",
    "azafamáramos": "azafamar",
    "azafamárei": "azafamar",
    "azafamáreis": "azafamar",
    "azafamásseis": "azafamar",
    "azafamássemos": "azafamar",
    "azafamávamo": "azafamar",
    "azafamávamos": "azafamar",
    "azafamávei": "azafamar",
    "azafamáveis": "azafamar",
    "azagaiadas": "azagaiada",
    "azagaias": "azagaia",
    "azagunchadas": "azagunchada",
    "azais": "azal",
    "azamboada": "azamboado",
    "azamboadas": "azamboado",
    "azamboados": "azamboado",
    "azamboamentos": "azamboamento",
    "azambrada": "azambrado",
    "azambradas": "azambrado",
    "azambrados": "azambrado",
    "azambujas": "azambuja",
    "azambujeiras": "azambujeira",
    "azambujeiros": "azambujeiro",
    "azambujenses": "azambujense",
    "azambujos": "azambujo",
    "azara": "azarar",
    "azarada": "azarar",
    "azaradas": "azarar",
    "azaradinha": "azarado",
    "azaradinhas": "azarado",
    "azaradinho": "azarado",
    "azaradinhos": "azarado",
    "azaradita": "azarado",
    "azaraditas": "azarado",
    "azaradito": "azarado",
    "azaraditos": "azarado",
    "azarado": "azarar",
    "azarados": "azarar",
    "azarai": "azarar",
    "azarais": "azarar",
    "azaram": "azarar",
    "azaramo": "azarar",
    "azaramos": "azarar",
    "azarando": "azarar",
    "azarara": "azarar",
    "azararam": "azarar",
    "azararas": "azarar",
    "azararde": "azarar",
    "azarardes": "azarar",
    "azarare": "azarar",
    "azararei": "azarar",
    "azarareis": "azarar",
    "azararem": "azarar",
    "azararemos": "azarar",
    "azarares": "azarar",
    "azararia": "azarar",
    "azarariam": "azarar",
    "azararias": "azarar",
    "azararmo": "azarar",
    "azararmos": "azarar",
    "azarará": "azarar",
    "azararás": "azarar",
    "azararão": "azarar",
    "azararíamos": "azarar",
    "azararíeis": "azarar",
    "azaras": "azarar",
    "azarasse": "azarar",
    "azarassem": "azarar",
    "azarasses": "azarar",
    "azaraste": "azarar",
    "azarastes": "azarar",
    "azarava": "azarar",
    "azaravam": "azarar",
    "azaravas": "azarar",
    "azare": "azarar",
    "azarei": "azarar",
    "azareis": "azarar",
    "azarem": "azarar",
    "azaremo": "azarar",
    "azaremos": "azarar",
    "azarenta": "azarento",
    "azarentas": "azarento",
    "azarentos": "azarento",
    "azares": "azarar",
    "azaro": "azarar",
    "azarolas": "azarola",
    "azaroleiras": "azaroleira",
    "azaroleiros": "azaroleiro",
    "azarolos": "azarolo",
    "azarou": "azarar",
    "azará": "azarar",
    "azarámo": "azarar",
    "azarámos": "azarar",
    "azaráramo": "azarar",
    "azaráramos": "azarar",
    "azarárei": "azarar",
    "azaráreis": "azarar",
    "azarásseis": "azarar",
    "azarássemos": "azarar",
    "azarávamo": "azarar",
    "azarávamos": "azarar",
    "azarávei": "azarar",
    "azaráveis": "azarar",
    "azebres": "azebre",
    "azebuada": "azebuado",
    "azebuadas": "azebuado",
    "azebuados": "azebuado",
    "azeda": "azedo",
    "azedada": "azedar",
    "azedadas": "azedar",
    "azedado": "azedar",
    "azedadora": "azedador",
    "azedadoras": "azedador",
    "azedadores": "azedador",
    "azedados": "azedar",
    "azedai": "azedar",
    "azedais": "azedar",
    "azedam": "azedar",
    "azedamentos": "azedamento",
    "azedamo": "azedar",
    "azedamos": "azedar",
    "azedando": "azedar",
    "azedara": "azedar",
    "azedaram": "azedar",
    "azedaras": "azedar",
    "azedarde": "azedar",
    "azedardes": "azedar",
    "azedare": "azedar",
    "azedarei": "azedar",
    "azedareis": "azedar",
    "azedarem": "azedar",
    "azedaremos": "azedar",
    "azedares": "azedar",
    "azedaria": "azedar",
    "azedariam": "azedar",
    "azedarias": "azedar",
    "azedarmo": "azedar",
    "azedarmos": "azedar",
    "azedará": "azedar",
    "azedarás": "azedar",
    "azedarão": "azedar",
    "azedaríamos": "azedar",
    "azedaríeis": "azedar",
    "azedas": "azedo",
    "azedasse": "azedar",
    "azedassem": "azedar",
    "azedasses": "azedar",
    "azedaste": "azedar",
    "azedastes": "azedar",
    "azedava": "azedar",
    "azedavam": "azedar",
    "azedavas": "azedar",
    "azede": "azedar",
    "azedei": "azedar",
    "azedeiras": "azedeira",
    "azedeis": "azedar",
    "azedem": "azedar",
    "azedemo": "azedar",
    "azedemos": "azedar",
    "azedes": "azedar",
    "azedias": "azedia",
    "azedinha": "azedo",
    "azedinhas": "azedo",
    "azedinho": "azedo",
    "azedinhos": "azedo",
    "azedita": "azedo",
    "azeditas": "azedo",
    "azedito": "azedo",
    "azeditos": "azedo",
    "azedo": "azedar",
    "azedos": "azedo",
    "azedosa": "azedoso",
    "azedosas": "azedoso",
    "azedosos": "azedoso",
    "azedou": "azedar",
    "azedumes": "azedume",
    "azeduns": "azedum",
    "azedá": "azedar",
    "azedámo": "azedar",
    "azedámos": "azedar",
    "azedáramo": "azedar",
    "azedáramos": "azedar",
    "azedárei": "azedar",
    "azedáreis": "azedar",
    "azedásseis": "azedar",
    "azedássemos": "azedar",
    "azedávamo": "azedar",
    "azedávamos": "azedar",
    "azedávei": "azedar",
    "azedáveis": "azedar",
    "azedíssima": "azedo",
    "azedíssimas": "azedo",
    "azedíssimo": "azedo",
    "azedíssimos": "azedo",
    "azedões": "azedão",
    "azegrinos": "azegrino",
    "azeita": "azeitar",
    "azeitada": "azeitar",
    "azeitadas": "azeitar",
    "azeitado": "azeitar",
    "azeitadora": "azeitador",
    "azeitadoras": "azeitador",
    "azeitadores": "azeitador",
    "azeitados": "azeitar",
    "azeitai": "azeitar",
    "azeitais": "azeitar",
    "azeitam": "azeitar",
    "azeitamo": "azeitar",
    "azeitamos": "azeitar",
    "azeitando": "azeitar",
    "azeitara": "azeitar",
    "azeitaram": "azeitar",
    "azeitaras": "azeitar",
    "azeitarde": "azeitar",
    "azeitardes": "azeitar",
    "azeitare": "azeitar",
    "azeitarei": "azeitar",
    "azeitareis": "azeitar",
    "azeitarem": "azeitar",
    "azeitaremos": "azeitar",
    "azeitares": "azeitar",
    "azeitaria": "azeitar",
    "azeitariam": "azeitar",
    "azeitarias": "azeitar",
    "azeitarmo": "azeitar",
    "azeitarmos": "azeitar",
    "azeitará": "azeitar",
    "azeitarás": "azeitar",
    "azeitarão": "azeitar",
    "azeitaríamos": "azeitar",
    "azeitaríeis": "azeitar",
    "azeitas": "azeitar",
    "azeitasse": "azeitar",
    "azeitassem": "azeitar",
    "azeitasses": "azeitar",
    "azeitaste": "azeitar",
    "azeitastes": "azeitar",
    "azeitava": "azeitar",
    "azeitavam": "azeitar",
    "azeitavas": "azeitar",
    "azeite": "azeitar",
    "azeitei": "azeitar",
    "azeiteira": "azeiteiro",
    "azeiteiras": "azeiteiro",
    "azeiteiros": "azeiteiro",
    "azeiteis": "azeitar",
    "azeitem": "azeitar",
    "azeitemo": "azeitar",
    "azeitemos": "azeitar",
    "azeites": "azeite",
    "azeitinhos": "azeitinho",
    "azeito": "azeitar",
    "azeitonada": "azeitonado",
    "azeitonadas": "azeitonado",
    "azeitonados": "azeitonado",
    "azeitonas": "azeitona",
    "azeitoneiras": "azeitoneira",
    "azeitoneiros": "azeitoneiro",
    "azeitoninha": "azeitona",
    "azeitoninhas": "azeitona",
    "azeitonita": "azeitona",
    "azeitonitas": "azeitona",
    "azeitou": "azeitar",
    "azeitá": "azeitar",
    "azeitámo": "azeitar",
    "azeitámos": "azeitar",
    "azeitáramo": "azeitar",
    "azeitáramos": "azeitar",
    "azeitárei": "azeitar",
    "azeitáreis": "azeitar",
    "azeitásseis": "azeitar",
    "azeitássemos": "azeitar",
    "azeitávamo": "azeitar",
    "azeitávamos": "azeitar",
    "azeitávei": "azeitar",
    "azeitáveis": "azeitar",
    "azeitões": "azeitão",
    "azelhas": "azelha",
    "azemeleiros": "azemeleiro",
    "azeméis": "azemel",
    "azenegues": "azenegue",
    "azenhas": "azenha",
    "azenheiros": "azenheiro",
    "azeotrópica": "azeotrópico",
    "azeotrópicas": "azeotrópico",
    "azeotrópicos": "azeotrópico",
    "azerada": "azerado",
    "azeradas": "azerado",
    "azerados": "azerado",
    "azeredos": "azeredo",
    "azereiros": "azereiro",
    "azeris": "azeri",
    "azes": "az",
    "azevias": "azevia",
    "azeviches": "azeviche",
    "azevieira": "azevieiro",
    "azevieiras": "azevieiro",
    "azevieiros": "azevieiro",
    "azevinheiros": "azevinheiro",
    "azevinhos": "azevinho",
    "azevéns": "azevém",
    "aziaga": "aziago",
    "aziagas": "aziago",
    "aziagos": "aziago",
    "azias": "azia",
    "azimias": "azimia",
    "azimutais": "azimutal",
    "azimutes": "azimute",
    "azinhagas": "azinhaga",
    "azinhais": "azinhal",
    "azinhas": "azinha",
    "azinhavres": "azinhavre",
    "azinheirais": "azinheiral",
    "azinheiras": "azinheira",
    "azinheiros": "azinheiro",
    "azinhos": "azinho",
    "azinhosa": "azinhoso",
    "azinhosas": "azinhoso",
    "azinhosos": "azinhoso",
    "azizitas": "azul",
    "azizitos": "azul",
    "aziúmes": "aziúme",
    "azlzita": "azul",
    "azlzito": "azul",
    "azoada": "azoado",
    "azoadas": "azoado",
    "azoados": "azoado",
    "azoamentos": "azoamento",
    "azoeirada": "azoeirado",
    "azoeiradas": "azoeirado",
    "azoeirados": "azoeirado",
    "azoinantes": "azoinante",
    "azoospermias": "azoospermia",
    "azoospérmica": "azoospérmico",
    "azoospérmicas": "azoospérmico",
    "azoospérmicos": "azoospérmico",
    "azoques": "azoque",
    "azoratada": "azoratado",
    "azoratadas": "azoratado",
    "azoratados": "azoratado",
    "azorragadas": "azorragada",
    "azorragues": "azorrague",
    "azos": "azo",
    "azota": "azotar",
    "azotada": "azotar",
    "azotadas": "azotar",
    "azotado": "azotar",
    "azotados": "azotar",
    "azotai": "azotar",
    "azotais": "azotar",
    "azotam": "azotar",
    "azotamo": "azotar",
    "azotamos": "azotar",
    "azotando": "azotar",
    "azotara": "azotar",
    "azotaram": "azotar",
    "azotaras": "azotar",
    "azotarde": "azotar",
    "azotardes": "azotar",
    "azotare": "azotar",
    "azotarei": "azotar",
    "azotareis": "azotar",
    "azotarem": "azotar",
    "azotaremos": "azotar",
    "azotares": "azotar",
    "azotaria": "azotar",
    "azotariam": "azotar",
    "azotarias": "azotar",
    "azotarmo": "azotar",
    "azotarmos": "azotar",
    "azotará": "azotar",
    "azotarás": "azotar",
    "azotarão": "azotar",
    "azotaríamos": "azotar",
    "azotaríeis": "azotar",
    "azotas": "azotar",
    "azotasse": "azotar",
    "azotassem": "azotar",
    "azotasses": "azotar",
    "azotaste": "azotar",
    "azotastes": "azotar",
    "azotatos": "azotato",
    "azotava": "azotar",
    "azotavam": "azotar",
    "azotavas": "azotar",
    "azote": "azotar",
    "azotei": "azotar",
    "azoteis": "azotar",
    "azotem": "azotar",
    "azotemias": "azotemia",
    "azotemo": "azotar",
    "azotemos": "azotar",
    "azotes": "azotar",
    "azotetos": "azoteto",
    "azotitos": "azotito",
    "azoto": "azotar",
    "azotos": "azoto",
    "azotosa": "azotoso",
    "azotosas": "azotoso",
    "azotosos": "azotoso",
    "azotou": "azotar",
    "azoturias": "azoturia",
    "azotá": "azotar",
    "azotámo": "azotar",
    "azotámos": "azotar",
    "azotáramo": "azotar",
    "azotáramos": "azotar",
    "azotárei": "azotar",
    "azotáreis": "azotar",
    "azotásseis": "azotar",
    "azotássemos": "azotar",
    "azotávamo": "azotar",
    "azotávamos": "azotar",
    "azotávei": "azotar",
    "azotáveis": "azotável",
    "azotídrica": "azotídrico",
    "azotídricas": "azotídrico",
    "azotídricos": "azotídrico",
    "azotúrias": "azotúria",
    "azougada": "azougado",
    "azougadas": "azougado",
    "azougados": "azougado",
    "azougamentos": "azougamento",
    "azougues": "azougue",
    "azourcões": "azourcão",
    "azuelas": "azuela",
    "azuis": "azul",
    "azuizinhas": "azul",
    "azuizinhos": "azul",
    "azula": "azular",
    "azulada": "azular",
    "azuladas": "azular",
    "azulado": "azular",
    "azuladora": "azulador",
    "azuladoras": "azulador",
    "azuladores": "azulador",
    "azulados": "azular",
    "azulai": "azular",
    "azulais": "azular",
    "azulam": "azular",
    "azulamentos": "azulamento",
    "azulamo": "azular",
    "azulamos": "azular",
    "azulando": "azular",
    "azulara": "azular",
    "azularam": "azular",
    "azularas": "azular",
    "azularde": "azular",
    "azulardes": "azular",
    "azulare": "azular",
    "azularei": "azular",
    "azulareis": "azular",
    "azularem": "azular",
    "azularemos": "azular",
    "azulares": "azular",
    "azularia": "azular",
    "azulariam": "azular",
    "azularias": "azular",
    "azularmo": "azular",
    "azularmos": "azular",
    "azulará": "azular",
    "azularás": "azular",
    "azularão": "azular",
    "azularíamos": "azular",
    "azularíeis": "azular",
    "azulas": "azular",
    "azulasse": "azular",
    "azulassem": "azular",
    "azulasses": "azular",
    "azulaste": "azular",
    "azulastes": "azular",
    "azulava": "azular",
    "azulavam": "azular",
    "azulavas": "azular",
    "azule": "azular",
    "azulei": "azular",
    "azuleis": "azular",
    "azulejadora": "azulejador",
    "azulejadoras": "azulejador",
    "azulejadores": "azulejador",
    "azulejarias": "azulejaria",
    "azulejos": "azulejo",
    "azulem": "azular",
    "azulemo": "azular",
    "azulemos": "azular",
    "azulenos": "azuleno",
    "azules": "azular",
    "azulina": "azulino",
    "azulinas": "azulino",
    "azulinha": "azul",
    "azulinhas": "azul",
    "azulinho": "azul",
    "azulinhos": "azul",
    "azulinos": "azulino",
    "azulita": "azul",
    "azulitas": "azul",
    "azulito": "azul",
    "azulitos": "azul",
    "azulo": "azular",
    "azulou": "azular",
    "azulzinha": "azul",
    "azulzinho": "azul",
    "azulá": "azular",
    "azulácea": "azuláceo",
    "azuláceas": "azuláceo",
    "azuláceos": "azuláceo",
    "azulámo": "azular",
    "azulámos": "azular",
    "azuláramo": "azular",
    "azuláramos": "azular",
    "azulárei": "azular",
    "azuláreis": "azular",
    "azulásseis": "azular",
    "azulássemos": "azular",
    "azulávamo": "azular",
    "azulávamos": "azular",
    "azulávei": "azular",
    "azuláveis": "azular",
    "azulíssima": "azul",
    "azulíssimas": "azul",
    "azulíssimo": "azul",
    "azulíssimos": "azul",
    "azulóia": "azulóio",
    "azulóias": "azulóio",
    "azulóios": "azulóio",
    "azulões": "azulão",
    "azuraques": "azuraque",
    "azurites": "azurite",
    "azurrachas": "azurracha",
    "azurus": "azuru",
    "azáfamas": "azáfama",
    "azálea": "azáleo",
    "azáleas": "azáleo",
    "azáleos": "azáleo",
    "azémolas": "azémola",
    "azóica": "azóico",
    "azóicas": "azóico",
    "azóicos": "azóico",
    "azótica": "azótico",
    "azóticas": "azótico",
    "azóticos": "azótico",
    "açacala": "acalar",
    "açacalada": "açacalar",
    "açacaladas": "açacalar",
    "açacalado": "açacalar",
    "açacaladora": "açacalador",
    "açacaladoras": "açacalador",
    "açacaladores": "açacalador",
    "açacalados": "açacalar",
    "açacaladuras": "açacaladura",
    "açacalai": "açacalar",
    "açacalais": "açacalar",
    "açacalam": "açacalar",
    "açacalamo": "açacalar",
    "açacalamos": "açacalar",
    "açacalando": "açacalar",
    "açacalar": "acalar",
    "açacalara": "acalar",
    "açacalaram": "acalar",
    "açacalaras": "açacalar",
    "açacalarde": "açacalar",
    "açacalardes": "açacalar",
    "açacalare": "açacalar",
    "açacalarei": "açacalar",
    "açacalareis": "açacalar",
    "açacalarem": "acalar",
    "açacalaremos": "açacalar",
    "açacalares": "açacalar",
    "açacalaria": "acalar",
    "açacalariam": "açacalar",
    "açacalarias": "açacalar",
    "açacalarmo": "açacalar",
    "açacalarmos": "açacalar",
    "açacalará": "açacalar",
    "açacalarás": "açacalar",
    "açacalarão": "açacalar",
    "açacalaríamos": "açacalar",
    "açacalaríeis": "açacalar",
    "açacalas": "açacalar",
    "açacalasse": "acalar",
    "açacalassem": "açacalar",
    "açacalasses": "açacalar",
    "açacalaste": "açacalar",
    "açacalastes": "açacalar",
    "açacalava": "acalar",
    "açacalavam": "açacalar",
    "açacalavas": "açacalar",
    "açacale": "acalar",
    "açacalei": "açacalar",
    "açacaleis": "açacalar",
    "açacalem": "acalar",
    "açacalemo": "açacalar",
    "açacalemos": "açacalar",
    "açacales": "açacalar",
    "açacalo": "açacalar",
    "açacalou": "açacalar",
    "açacalá": "acalar",
    "açacalámo": "açacalar",
    "açacalámos": "açacalar",
    "açacaláramo": "açacalar",
    "açacaláramos": "açacalar",
    "açacalárei": "açacalar",
    "açacaláreis": "açacalar",
    "açacalásseis": "açacalar",
    "açacalássemos": "açacalar",
    "açacalávamo": "açacalar",
    "açacalávamos": "açacalar",
    "açacalávei": "açacalar",
    "açacaláveis": "açacalar",
    "açafatas": "açafata",
    "açafateiros": "açafateiro",
    "açafates": "açafate",
    "açaflores": "açaflor",
    "açafroais": "açafroal",
    "açafroas": "açafroa",
    "açafroeiras": "açafroeira",
    "açafroeiros": "açafroeiro",
    "açafróis": "açafrol",
    "açafrões": "açafrão",
    "açaima": "aimar",
    "açaimada": "açaimar",
    "açaimadas": "açaimar",
    "açaimado": "açaimar",
    "açaimados": "açaimar",
    "açaimai": "açaimar",
    "açaimais": "açaimar",
    "açaimam": "açaimar",
    "açaimamo": "açaimar",
    "açaimamos": "açaimar",
    "açaimando": "açaimar",
    "açaimar": "aimar",
    "açaimara": "aimar",
    "açaimaram": "aimar",
    "açaimaras": "açaimar",
    "açaimarde": "açaimar",
    "açaimardes": "açaimar",
    "açaimare": "açaimar",
    "açaimarei": "açaimar",
    "açaimareis": "açaimar",
    "açaimarem": "aimar",
    "açaimaremos": "açaimar",
    "açaimares": "açaimar",
    "açaimaria": "aimar",
    "açaimariam": "açaimar",
    "açaimarias": "açaimar",
    "açaimarmo": "açaimar",
    "açaimarmos": "açaimar",
    "açaimará": "açaimar",
    "açaimarás": "açaimar",
    "açaimarão": "açaimar",
    "açaimaríamos": "açaimar",
    "açaimaríeis": "açaimar",
    "açaimas": "açaimar",
    "açaimasse": "aimar",
    "açaimassem": "açaimar",
    "açaimasses": "açaimar",
    "açaimaste": "açaimar",
    "açaimastes": "açaimar",
    "açaimava": "aimar",
    "açaimavam": "açaimar",
    "açaimavas": "açaimar",
    "açaime": "aimar",
    "açaimei": "açaimar",
    "açaimeis": "açaimar",
    "açaimem": "aimar",
    "açaimemo": "açaimar",
    "açaimemos": "açaimar",
    "açaimes": "açaime",
    "açaimo": "açaimar",
    "açaimos": "açaimo",
    "açaimou": "açaimar",
    "açaimá": "aimar",
    "açaimámo": "açaimar",
    "açaimámos": "açaimar",
    "açaimáramo": "açaimar",
    "açaimáramos": "açaimar",
    "açaimárei": "açaimar",
    "açaimáreis": "açaimar",
    "açaimásseis": "açaimar",
    "açaimássemos": "açaimar",
    "açaimávamo": "açaimar",
    "açaimávamos": "açaimar",
    "açaimávei": "açaimar",
    "açaimáveis": "açaimar",
    "açaizais": "açaizal",
    "açaizeiros": "açaizeiro",
    "açama": "amar",
    "açamada": "açamar",
    "açamadas": "açamar",
    "açamado": "açamar",
    "açamados": "açamar",
    "açamai": "açamar",
    "açamais": "açamar",
    "açamam": "açamar",
    "açamamo": "açamar",
    "açamamos": "açamar",
    "açamando": "açamar",
    "açamar": "amar",
    "açamara": "amar",
    "açamaram": "amar",
    "açamaras": "açamar",
    "açamarde": "açamar",
    "açamardes": "açamar",
    "açamare": "açamar",
    "açamarei": "açamar",
    "açamareis": "açamar",
    "açamarem": "amar",
    "açamaremos": "açamar",
    "açamares": "açamar",
    "açamaria": "amar",
    "açamariam": "açamar",
    "açamarias": "açamar",
    "açamarmo": "açamar",
    "açamarmos": "açamar",
    "açamará": "açamar",
    "açamarás": "açamar",
    "açamarão": "açamar",
    "açamaríamos": "açamar",
    "açamaríeis": "açamar",
    "açamas": "açamar",
    "açamasse": "amar",
    "açamassem": "açamar",
    "açamasses": "açamar",
    "açamaste": "açamar",
    "açamastes": "açamar",
    "açamava": "amar",
    "açamavam": "açamar",
    "açamavas": "açamar",
    "açambarca": "ambarcar",
    "açambarcada": "açambarcar",
    "açambarcadas": "açambarcar",
    "açambarcado": "açambarcar",
    "açambarcadora": "açambarcador",
    "açambarcadoras": "açambarcador",
    "açambarcadores": "açambarcador",
    "açambarcados": "açambarcar",
    "açambarcagens": "açambarcagem",
    "açambarcai": "açambarcar",
    "açambarcais": "açambarcar",
    "açambarcam": "açambarcar",
    "açambarcamentos": "açambarcamento",
    "açambarcamo": "açambarcar",
    "açambarcamos": "açambarcar",
    "açambarcando": "açambarcar",
    "açambarcar": "ambarcar",
    "açambarcara": "ambarcar",
    "açambarcaram": "ambarcar",
    "açambarcaras": "açambarcar",
    "açambarcarde": "açambarcar",
    "açambarcardes": "açambarcar",
    "açambarcare": "açambarcar",
    "açambarcarei": "açambarcar",
    "açambarcareis": "açambarcar",
    "açambarcarem": "ambarcar",
    "açambarcaremos": "açambarcar",
    "açambarcares": "açambarcar",
    "açambarcaria": "ambarcar",
    "açambarcariam": "açambarcar",
    "açambarcarias": "açambarcar",
    "açambarcarmo": "açambarcar",
    "açambarcarmos": "açambarcar",
    "açambarcará": "açambarcar",
    "açambarcarás": "açambarcar",
    "açambarcarão": "açambarcar",
    "açambarcaríamos": "açambarcar",
    "açambarcaríeis": "açambarcar",
    "açambarcas": "açambarcar",
    "açambarcasse": "ambarcar",
    "açambarcassem": "açambarcar",
    "açambarcasses": "açambarcar",
    "açambarcaste": "açambarcar",
    "açambarcastes": "açambarcar",
    "açambarcava": "ambarcar",
    "açambarcavam": "açambarcar",
    "açambarcavas": "açambarcar",
    "açambarco": "açambarcar",
    "açambarcou": "açambarcar",
    "açambarcá": "ambarcar",
    "açambarcámo": "açambarcar",
    "açambarcámos": "açambarcar",
    "açambarcáramo": "açambarcar",
    "açambarcáramos": "açambarcar",
    "açambarcárei": "açambarcar",
    "açambarcáreis": "açambarcar",
    "açambarcásseis": "açambarcar",
    "açambarcássemos": "açambarcar",
    "açambarcávamo": "açambarcar",
    "açambarcávamos": "açambarcar",
    "açambarcávei": "açambarcar",
    "açambarcáveis": "açambarcar",
    "açambarque": "ambarcar",
    "açambarquei": "açambarcar",
    "açambarqueis": "açambarcar",
    "açambarquem": "ambarcar",
    "açambarquemo": "açambarcar",
    "açambarquemos": "açambarcar",
    "açambarques": "açambarque",
    "açame": "amar",
    "açamei": "açamar",
    "açameis": "açamar",
    "açamem": "amar",
    "açamemo": "açamar",
    "açamemos": "açamar",
    "açames": "açame",
    "açamo": "açamar",
    "açamos": "açamo",
    "açamou": "açamar",
    "açamoucada": "açamoucado",
    "açamoucadas": "açamoucado",
    "açamoucados": "açamoucado",
    "açamá": "amar",
    "açamámo": "açamar",
    "açamámos": "açamar",
    "açamáramo": "açamar",
    "açamáramos": "açamar",
    "açamárei": "açamar",
    "açamáreis": "açamar",
    "açamásseis": "açamar",
    "açamássemos": "açamar",
    "açamávamo": "açamar",
    "açamávamos": "açamar",
    "açamávei": "açamar",
    "açamáveis": "açamar",
    "açariçobas": "açariçoba",
    "aças": "aça",
    "açaís": "açaí",
    "açoda": "odar",
    "açodada": "açodar",
    "açodadas": "açodar",
    "açodado": "açodar",
    "açodados": "açodar",
    "açodai": "açodar",
    "açodais": "açodar",
    "açodam": "açodar",
    "açodamentos": "açodamento",
    "açodamo": "açodar",
    "açodamos": "açodar",
    "açodando": "açodar",
    "açodar": "odar",
    "açodara": "odar",
    "açodaram": "odar",
    "açodaras": "açodar",
    "açodarde": "açodar",
    "açodardes": "açodar",
    "açodare": "açodar",
    "açodarei": "açodar",
    "açodareis": "açodar",
    "açodarem": "odar",
    "açodaremos": "açodar",
    "açodares": "açodar",
    "açodaria": "odar",
    "açodariam": "açodar",
    "açodarias": "açodar",
    "açodarmo": "açodar",
    "açodarmos": "açodar",
    "açodará": "açodar",
    "açodarás": "açodar",
    "açodarão": "açodar",
    "açodaríamos": "açodar",
    "açodaríeis": "açodar",
    "açodas": "açodar",
    "açodasse": "odar",
    "açodassem": "açodar",
    "açodasses": "açodar",
    "açodaste": "açodar",
    "açodastes": "açodar",
    "açodava": "odar",
    "açodavam": "açodar",
    "açodavas": "açodar",
    "açode": "odar",
    "açodei": "açodar",
    "açodeis": "açodar",
    "açodem": "odar",
    "açodemo": "açodar",
    "açodemos": "açodar",
    "açodes": "açodar",
    "açodo": "açodar",
    "açodou": "açodar",
    "açodá": "odar",
    "açodámo": "açodar",
    "açodámos": "açodar",
    "açodáramo": "açodar",
    "açodáramos": "açodar",
    "açodárei": "açodar",
    "açodáreis": "açodar",
    "açodásseis": "açodar",
    "açodássemos": "açodar",
    "açodávamo": "açodar",
    "açodávamos": "açodar",
    "açodávei": "açodar",
    "açodáveis": "açodar",
    "açofeifas": "açofeifa",
    "açofeifeiras": "açofeifeira",
    "açoiabas": "açoiaba",
    "açoita": "oitar",
    "açoitada": "açoitar",
    "açoitadas": "açoitar",
    "açoitado": "açoitar",
    "açoitadora": "açoitador",
    "açoitadoras": "açoitador",
    "açoitadores": "açoitador",
    "açoitados": "açoitar",
    "açoitai": "açoitar",
    "açoitais": "açoitar",
    "açoitam": "açoitar",
    "açoitamentos": "açoitamento",
    "açoitamo": "açoitar",
    "açoitamos": "açoitar",
    "açoitando": "açoitar",
    "açoitar": "oitar",
    "açoitara": "oitar",
    "açoitaram": "oitar",
    "açoitaras": "açoitar",
    "açoitarde": "açoitar",
    "açoitardes": "açoitar",
    "açoitare": "açoitar",
    "açoitarei": "açoitar",
    "açoitareis": "açoitar",
    "açoitarem": "oitar",
    "açoitaremos": "açoitar",
    "açoitares": "açoitar",
    "açoitaria": "oitar",
    "açoitariam": "açoitar",
    "açoitarias": "açoitar",
    "açoitarmo": "açoitar",
    "açoitarmos": "açoitar",
    "açoitará": "açoitar",
    "açoitarás": "açoitar",
    "açoitarão": "açoitar",
    "açoitaríamos": "açoitar",
    "açoitaríeis": "açoitar",
    "açoitas": "açoitar",
    "açoitasse": "oitar",
    "açoitassem": "açoitar",
    "açoitasses": "açoitar",
    "açoitaste": "açoitar",
    "açoitastes": "açoitar",
    "açoitava": "oitar",
    "açoitavam": "açoitar",
    "açoitavas": "açoitar",
    "açoite": "oitar",
    "açoitei": "açoitar",
    "açoiteiras": "açoiteira",
    "açoiteis": "açoitar",
    "açoitem": "oitar",
    "açoitemo": "açoitar",
    "açoitemos": "açoitar",
    "açoites": "açoite",
    "açoitezinho": "açoite",
    "açoitezinhos": "açoite",
    "açoitezito": "açoite",
    "açoitezitos": "açoite",
    "açoito": "açoitar",
    "açoitou": "açoitar",
    "açoitá": "oitar",
    "açoitámo": "açoitar",
    "açoitámos": "açoitar",
    "açoitáramo": "açoitar",
    "açoitáramos": "açoitar",
    "açoitárei": "açoitar",
    "açoitáreis": "açoitar",
    "açoitásseis": "açoitar",
    "açoitássemos": "açoitar",
    "açoitávamo": "açoitar",
    "açoitávamos": "açoitar",
    "açoitávei": "açoitar",
    "açoitáveis": "açoitar",
    "açora": "orar",
    "açorada": "açorar",
    "açoradas": "açorar",
    "açorado": "açorar",
    "açorados": "açorar",
    "açorai": "açorar",
    "açorais": "açorar",
    "açoram": "açorar",
    "açoramentos": "açoramento",
    "açoramo": "açorar",
    "açoramos": "açorar",
    "açorando": "açorar",
    "açorar": "orar",
    "açorara": "orar",
    "açoraram": "orar",
    "açoraras": "açorar",
    "açorarde": "açorar",
    "açorardes": "açorar",
    "açorare": "açorar",
    "açorarei": "açorar",
    "açorareis": "açorar",
    "açorarem": "orar",
    "açoraremos": "açorar",
    "açorares": "açorar",
    "açoraria": "orar",
    "açorariam": "açorar",
    "açorarias": "açorar",
    "açorarmo": "açorar",
    "açorarmos": "açorar",
    "açorará": "açorar",
    "açorarás": "açorar",
    "açorarão": "açorar",
    "açoraríamos": "açorar",
    "açoraríeis": "açorar",
    "açoras": "açorar",
    "açorasse": "orar",
    "açorassem": "açorar",
    "açorasses": "açorar",
    "açoraste": "açorar",
    "açorastes": "açorar",
    "açorava": "orar",
    "açoravam": "açorar",
    "açoravas": "açorar",
    "açordas": "açorda",
    "açore": "orar",
    "açorei": "açorar",
    "açoreis": "açorar",
    "açorem": "orar",
    "açoremo": "açorar",
    "açoremos": "açorar",
    "açorenha": "açorenho",
    "açorenhas": "açorenho",
    "açorenhos": "açorenho",
    "açores": "açorar",
    "açoriana": "açoriano",
    "açorianas": "açoriano",
    "açorianismos": "açorianismo",
    "açorianos": "açoriano",
    "açoro": "açorar",
    "açorou": "açorar",
    "açorá": "orar",
    "açorámo": "açorar",
    "açorámos": "açorar",
    "açoráramo": "açorar",
    "açoráramos": "açorar",
    "açorárei": "açorar",
    "açoráreis": "açorar",
    "açorásseis": "açorar",
    "açorássemos": "açorar",
    "açorávamo": "açorar",
    "açorávamos": "açorar",
    "açorávei": "açorar",
    "açoráveis": "açorar",
    "aços": "aço",
    "açoteada": "açoteado",
    "açoteadas": "açoteado",
    "açoteados": "açoteado",
    "açoteias": "açoteia",
    "açougadas": "açougada",
    "açougueiros": "açougueiro",
    "açougues": "açougue",
    "açouta": "outar",
    "açoutada": "açoutar",
    "açoutadas": "açoutar",
    "açoutado": "açoutar",
    "açoutadora": "açoutador",
    "açoutadoras": "açoutador",
    "açoutadores": "açoutador",
    "açoutados": "açoutar",
    "açoutai": "açoutar",
    "açoutais": "açoutar",
    "açoutam": "açoutar",
    "açoutamo": "açoutar",
    "açoutamos": "açoutar",
    "açoutando": "açoutar",
    "açoutar": "outar",
    "açoutara": "outar",
    "açoutaram": "outar",
    "açoutaras": "açoutar",
    "açoutarde": "açoutar",
    "açoutardes": "açoutar",
    "açoutare": "açoutar",
    "açoutarei": "açoutar",
    "açoutareis": "açoutar",
    "açoutarem": "outar",
    "açoutaremos": "açoutar",
    "açoutares": "açoutar",
    "açoutaria": "outar",
    "açoutariam": "açoutar",
    "açoutarias": "açoutar",
    "açoutarmo": "açoutar",
    "açoutarmos": "açoutar",
    "açoutará": "açoutar",
    "açoutarás": "açoutar",
    "açoutarão": "açoutar",
    "açoutaríamos": "açoutar",
    "açoutaríeis": "açoutar",
    "açoutas": "açoutar",
    "açoutasse": "outar",
    "açoutassem": "açoutar",
    "açoutasses": "açoutar",
    "açoutaste": "açoutar",
    "açoutastes": "açoutar",
    "açoutava": "outar",
    "açoutavam": "açoutar",
    "açoutavas": "açoutar",
    "açoute": "outar",
    "açoutei": "açoutar",
    "açouteiras": "açouteira",
    "açouteis": "açoutar",
    "açoutem": "outar",
    "açoutemo": "açoutar",
    "açoutemos": "açoutar",
    "açoutes": "açoute",
    "açouto": "açoutar",
    "açoutou": "açoutar",
    "açoutá": "outar",
    "açoutámo": "açoutar",
    "açoutámos": "açoutar",
    "açoutáramo": "açoutar",
    "açoutáramos": "açoutar",
    "açoutárei": "açoutar",
    "açoutáreis": "açoutar",
    "açoutásseis": "açoutar",
    "açoutássemos": "açoutar",
    "açoutávamo": "açoutar",
    "açoutávamos": "açoutar",
    "açoutávei": "açoutar",
    "açoutáveis": "açoutar",
    "açubás": "açubá",
    "açucara": "ucarar",
    "açucarada": "açucarar",
    "açucaradas": "açucarar",
    "açucarado": "açucarar",
    "açucarados": "açucarar",
    "açucarai": "açucarar",
    "açucarais": "açucarar",
    "açucaram": "açucarar",
    "açucaramo": "açucarar",
    "açucaramos": "açucarar",
    "açucarando": "açucarar",
    "açucarar": "ucarar",
    "açucarara": "ucarar",
    "açucararam": "ucarar",
    "açucararas": "açucarar",
    "açucararde": "açucarar",
    "açucarardes": "açucarar",
    "açucarare": "açucarar",
    "açucararei": "açucarar",
    "açucarareis": "açucarar",
    "açucararem": "ucarar",
    "açucararemos": "açucarar",
    "açucarares": "açucarar",
    "açucararia": "ucarar",
    "açucarariam": "açucarar",
    "açucararias": "açucarar",
    "açucararmo": "açucarar",
    "açucararmos": "açucarar",
    "açucarará": "açucarar",
    "açucararás": "açucarar",
    "açucararão": "açucarar",
    "açucararíamos": "açucarar",
    "açucararíeis": "açucarar",
    "açucaras": "açucarar",
    "açucarasse": "ucarar",
    "açucarassem": "açucarar",
    "açucarasses": "açucarar",
    "açucaraste": "açucarar",
    "açucarastes": "açucarar",
    "açucarava": "ucarar",
    "açucaravam": "açucarar",
    "açucaravas": "açucarar",
    "açucare": "ucarar",
    "açucarei": "açucarar",
    "açucareira": "açucareiro",
    "açucareiras": "açucareiro",
    "açucareiros": "açucareiro",
    "açucareis": "açucarar",
    "açucarem": "ucarar",
    "açucaremo": "açucarar",
    "açucaremos": "açucarar",
    "açucares": "açucarar",
    "açucaro": "açucarar",
    "açucarou": "açucarar",
    "açucará": "ucarar",
    "açucarámo": "açucarar",
    "açucarámos": "açucarar",
    "açucaráramo": "açucarar",
    "açucaráramos": "açucarar",
    "açucarárei": "açucarar",
    "açucaráreis": "açucarar",
    "açucarásseis": "açucarar",
    "açucarássemos": "açucarar",
    "açucarávamo": "açucarar",
    "açucarávamos": "açucarar",
    "açucarávei": "açucarar",
    "açucaráveis": "açucarar",
    "açucenais": "açucenal",
    "açucenas": "açucena",
    "açucenses": "açucense",
    "açuda": "udar",
    "açudada": "açudar",
    "açudadas": "açudar",
    "açudado": "açudar",
    "açudados": "açudar",
    "açudai": "açudar",
    "açudais": "açudar",
    "açudam": "açudar",
    "açudamo": "açudar",
    "açudamos": "açudar",
    "açudando": "açudar",
    "açudar": "udar",
    "açudara": "udar",
    "açudaram": "udar",
    "açudaras": "açudar",
    "açudarde": "açudar",
    "açudardes": "açudar",
    "açudare": "açudar",
    "açudarei": "açudar",
    "açudareis": "açudar",
    "açudarem": "udar",
    "açudaremos": "açudar",
    "açudares": "açudar",
    "açudaria": "udar",
    "açudariam": "açudar",
    "açudarias": "açudar",
    "açudarmo": "açudar",
    "açudarmos": "açudar",
    "açudará": "açudar",
    "açudarás": "açudar",
    "açudarão": "açudar",
    "açudaríamos": "açudar",
    "açudaríeis": "açudar",
    "açudas": "açudar",
    "açudasse": "udar",
    "açudassem": "açudar",
    "açudasses": "açudar",
    "açudaste": "açudar",
    "açudastes": "açudar",
    "açudava": "udar",
    "açudavam": "açudar",
    "açudavas": "açudar",
    "açude": "udar",
    "açudei": "açudar",
    "açudeis": "açudar",
    "açudem": "udar",
    "açudemo": "açudar",
    "açudemos": "açudar",
    "açudes": "açude",
    "açudo": "açudar",
    "açudou": "açudar",
    "açudá": "udar",
    "açudámo": "açudar",
    "açudámos": "açudar",
    "açudáramo": "açudar",
    "açudáramos": "açudar",
    "açudárei": "açudar",
    "açudáreis": "açudar",
    "açudásseis": "açudar",
    "açudássemos": "açudar",
    "açudávamo": "açudar",
    "açudávamos": "açudar",
    "açudávei": "açudar",
    "açudáveis": "açudar",
    "açula": "ular",
    "açulada": "açular",
    "açuladas": "açular",
    "açuladeira": "açulador",
    "açuladeiras": "açulador",
    "açulado": "açular",
    "açuladora": "açulador",
    "açuladoras": "açulador",
    "açuladores": "açulador",
    "açulados": "açular",
    "açulai": "açular",
    "açulais": "açular",
    "açulam": "açular",
    "açulamentos": "açulamento",
    "açulamo": "açular",
    "açulamos": "açular",
    "açulando": "açular",
    "açular": "ular",
    "açulara": "ular",
    "açularam": "ular",
    "açularas": "açular",
    "açularde": "açular",
    "açulardes": "açular",
    "açulare": "açular",
    "açularei": "açular",
    "açulareis": "açular",
    "açularem": "ular",
    "açularemos": "açular",
    "açulares": "açular",
    "açularia": "ular",
    "açulariam": "açular",
    "açularias": "açular",
    "açularmo": "açular",
    "açularmos": "açular",
    "açulará": "açular",
    "açularás": "açular",
    "açularão": "açular",
    "açularíamos": "açular",
    "açularíeis": "açular",
    "açulas": "açular",
    "açulasse": "ular",
    "açulassem": "açular",
    "açulasses": "açular",
    "açulaste": "açular",
    "açulastes": "açular",
    "açulava": "ular",
    "açulavam": "açular",
    "açulavas": "açular",
    "açule": "ular",
    "açulei": "açular",
    "açuleis": "açular",
    "açulem": "ular",
    "açulemo": "açular",
    "açulemos": "açular",
    "açules": "açular",
    "açulo": "açular",
    "açulou": "açular",
    "açulá": "ular",
    "açulámo": "açular",
    "açulámos": "açular",
    "açuláramo": "açular",
    "açuláramos": "açular",
    "açulárei": "açular",
    "açuláreis": "açular",
    "açulásseis": "açular",
    "açulássemos": "açular",
    "açulávamo": "açular",
    "açulávamos": "açular",
    "açulávei": "açular",
    "açuláveis": "açular",
    "açúcares": "açúcar",
    "aérea": "aéreo",
    "aéreas": "aéreo",
    "aéreos": "aéreo",
    "aónia": "aónio",
    "aónias": "aónio",
    "aónios": "aónio",
    "aórtica": "aórtico",
    "aórticas": "aórtico",
    "aórticos": "aórtico",
    "baalitas": "baalita",
    "baba": "babar",
    "babada": "babar",
    "babadas": "babar",
    "babadinha": "babado",
    "babadinhas": "babado",
    "babadinho": "babado",
    "babadinhos": "babado",
    "babadita": "babado",
    "babaditas": "babado",
    "babadito": "babado",
    "babaditos": "babado",
    "babado": "babar",
    "babadoiros": "babadoiro",
    "babados": "babar",
    "babadouros": "babadouro",
    "babaduras": "babadura",
    "babadíssima": "babado",
    "babadíssimas": "babado",
    "babadíssimo": "babado",
    "babadíssimos": "babado",
    "babai": "babar",
    "babais": "babar",
    "babam": "babar",
    "babamo": "babar",
    "babamos": "babar",
    "babancas": "babanca",
    "babando": "babar",
    "babara": "babar",
    "babaram": "babar",
    "babaras": "babar",
    "babarde": "babar",
    "babardes": "babar",
    "babare": "babar",
    "babarei": "babar",
    "babareis": "babar",
    "babarem": "babar",
    "babaremos": "babar",
    "babares": "babar",
    "babaria": "babar",
    "babariam": "babar",
    "babarias": "babar",
    "babarmo": "babar",
    "babarmos": "babar",
    "babará": "babar",
    "babarás": "babar",
    "babarão": "babar",
    "babarés": "babaré",
    "babaríamos": "babar",
    "babaríeis": "babar",
    "babas": "babar",
    "babasse": "babar",
    "babassem": "babar",
    "babasses": "babar",
    "babaste": "babar",
    "babastes": "babar",
    "babava": "babar",
    "babavam": "babar",
    "babavas": "babar",
    "babe": "babar",
    "babei": "babar",
    "babeiras": "babeira",
    "babeiros": "babeiro",
    "babeis": "babar",
    "babelesca": "babelesco",
    "babelescas": "babelesco",
    "babelescos": "babelesco",
    "babem": "babar",
    "babemo": "babar",
    "babemos": "babar",
    "babes": "babar",
    "babilónea": "babilóneo",
    "babilóneas": "babilóneo",
    "babilóneos": "babilóneo",
    "babilónia": "babilónio",
    "babilónias": "babilónio",
    "babilónica": "babilónico",
    "babilónicas": "babilónico",
    "babilónicos": "babilónico",
    "babilónios": "babilónio",
    "babiruças": "babiruça",
    "babo": "babar",
    "babocas": "baboca",
    "babona": "babão",
    "babonas": "babão",
    "babosa": "baboso",
    "babosas": "baboso",
    "baboseiras": "baboseira",
    "babosices": "babosice",
    "babosos": "baboso",
    "babou": "babar",
    "babuchas": "babucha",
    "babugens": "babugem",
    "babugenta": "babugento",
    "babugentas": "babugento",
    "babugentos": "babugento",
    "babuges": "babuge",
    "babuja": "babujar",
    "babujada": "babujar",
    "babujadas": "babujar",
    "babujado": "babujar",
    "babujados": "babujar",
    "babujai": "babujar",
    "babujais": "babujar",
    "babujam": "babujar",
    "babujamo": "babujar",
    "babujamos": "babujar",
    "babujando": "babujar",
    "babujara": "babujar",
    "babujaram": "babujar",
    "babujaras": "babujar",
    "babujarde": "babujar",
    "babujardes": "babujar",
    "babujare": "babujar",
    "babujarei": "babujar",
    "babujareis": "babujar",
    "babujarem": "babujar",
    "babujaremos": "babujar",
    "babujares": "babujar",
    "babujaria": "babujar",
    "babujariam": "babujar",
    "babujarias": "babujaria",
    "babujarmo": "babujar",
    "babujarmos": "babujar",
    "babujará": "babujar",
    "babujarás": "babujar",
    "babujarão": "babujar",
    "babujaríamos": "babujar",
    "babujaríeis": "babujar",
    "babujas": "babujar",
    "babujasse": "babujar",
    "babujassem": "babujar",
    "babujasses": "babujar",
    "babujaste": "babujar",
    "babujastes": "babujar",
    "babujava": "babujar",
    "babujavam": "babujar",
    "babujavas": "babujar",
    "babuje": "babujar",
    "babujei": "babujar",
    "babujeis": "babujar",
    "babujem": "babujar",
    "babujemo": "babujar",
    "babujemos": "babujar",
    "babujes": "babujar",
    "babujo": "babujar",
    "babujou": "babujar",
    "babujá": "babujar",
    "babujámo": "babujar",
    "babujámos": "babujar",
    "babujáramo": "babujar",
    "babujáramos": "babujar",
    "babujárei": "babujar",
    "babujáreis": "babujar",
    "babujásseis": "babujar",
    "babujássemos": "babujar",
    "babujávamo": "babujar",
    "babujávamos": "babujar",
    "babujávei": "babujar",
    "babujáveis": "babujar",
    "babuínos": "babuíno",
    "babá": "babar",
    "babámo": "babar",
    "babámos": "babar",
    "babáramo": "babar",
    "babáramos": "babar",
    "babárei": "babar",
    "babáreis": "babar",
    "babás": "babá",
    "babásseis": "babar",
    "babássemos": "babar",
    "babávamo": "babar",
    "babávamos": "babar",
    "babávei": "babar",
    "babáveis": "babar",
    "babéis": "babel",
    "babélica": "babélico",
    "babélicas": "babélico",
    "babélicos": "babélico",
    "babões": "babão",
    "bacabeiras": "bacabeira",
    "bacalhaus": "bacalhau",
    "bacalhoadas": "bacalhoada",
    "bacalhoeiros": "bacalhoeiro",
    "bacalhuços": "bacalhuço",
    "bacamartadas": "bacamartada",
    "bacamartes": "bacamarte",
    "bacanais": "bacanal",
    "bacanaliza": "bacanalizar",
    "bacanalizada": "bacanalizar",
    "bacanalizadas": "bacanalizar",
    "bacanalizado": "bacanalizar",
    "bacanalizados": "bacanalizar",
    "bacanalizai": "bacanalizar",
    "bacanalizais": "bacanalizar",
    "bacanalizam": "bacanalizar",
    "bacanalizamo": "bacanalizar",
    "bacanalizamos": "bacanalizar",
    "bacanalizando": "bacanalizar",
    "bacanalizara": "bacanalizar",
    "bacanalizaram": "bacanalizar",
    "bacanalizaras": "bacanalizar",
    "bacanalizarde": "bacanalizar",
    "bacanalizardes": "bacanalizar",
    "bacanalizare": "bacanalizar",
    "bacanalizarei": "bacanalizar",
    "bacanalizareis": "bacanalizar",
    "bacanalizarem": "bacanalizar",
    "bacanalizaremos": "bacanalizar",
    "bacanalizares": "bacanalizar",
    "bacanalizaria": "bacanalizar",
    "bacanalizariam": "bacanalizar",
    "bacanalizarias": "bacanalizar",
    "bacanalizarmo": "bacanalizar",
    "bacanalizarmos": "bacanalizar",
    "bacanalizará": "bacanalizar",
    "bacanalizarás": "bacanalizar",
    "bacanalizarão": "bacanalizar",
    "bacanalizaríamos": "bacanalizar",
    "bacanalizaríeis": "bacanalizar",
    "bacanalizas": "bacanalizar",
    "bacanalizasse": "bacanalizar",
    "bacanalizassem": "bacanalizar",
    "bacanalizasses": "bacanalizar",
    "bacanalizaste": "bacanalizar",
    "bacanalizastes": "bacanalizar",
    "bacanalizava": "bacanalizar",
    "bacanalizavam": "bacanalizar",
    "bacanalizavas": "bacanalizar",
    "bacanalize": "bacanalizar",
    "bacanalizei": "bacanalizar",
    "bacanalizeis": "bacanalizar",
    "bacanalizem": "bacanalizar",
    "bacanalizemo": "bacanalizar",
    "bacanalizemos": "bacanalizar",
    "bacanalizes": "bacanalizar",
    "bacanalizo": "bacanalizar",
    "bacanalizou": "bacanalizar",
    "bacanalizá": "bacanalizar",
    "bacanalizámo": "bacanalizar",
    "bacanalizámos": "bacanalizar",
    "bacanalizáramo": "bacanalizar",
    "bacanalizáramos": "bacanalizar",
    "bacanalizárei": "bacanalizar",
    "bacanalizáreis": "bacanalizar",
    "bacanalizásseis": "bacanalizar",
    "bacanalizássemos": "bacanalizar",
    "bacanalizávamo": "bacanalizar",
    "bacanalizávamos": "bacanalizar",
    "bacanalizávei": "bacanalizar",
    "bacanalizáveis": "bacanalizar",
    "bacanos": "bacano",
    "bacantes": "bacante",
    "bacarijas": "bacarija",
    "bacarás": "bacará",
    "baceira": "baceiro",
    "baceiras": "baceiro",
    "baceiros": "baceiro",
    "bacela": "bacelar",
    "bacelada": "bacelar",
    "baceladas": "bacelar",
    "bacelado": "bacelar",
    "baceladores": "bacelador",
    "bacelados": "bacelar",
    "bacelai": "bacelar",
    "bacelais": "bacelar",
    "bacelam": "bacelar",
    "bacelamo": "bacelar",
    "bacelamos": "bacelar",
    "bacelando": "bacelar",
    "bacelara": "bacelar",
    "bacelaram": "bacelar",
    "bacelaras": "bacelar",
    "bacelarde": "bacelar",
    "bacelardes": "bacelar",
    "bacelare": "bacelar",
    "bacelarei": "bacelar",
    "bacelareis": "bacelar",
    "bacelarem": "bacelar",
    "bacelaremos": "bacelar",
    "bacelares": "bacelar",
    "bacelaria": "bacelar",
    "bacelariam": "bacelar",
    "bacelarias": "bacelar",
    "bacelarmo": "bacelar",
    "bacelarmos": "bacelar",
    "bacelará": "bacelar",
    "bacelarás": "bacelar",
    "bacelarão": "bacelar",
    "bacelaríamos": "bacelar",
    "bacelaríeis": "bacelar",
    "bacelas": "bacelar",
    "bacelasse": "bacelar",
    "bacelassem": "bacelar",
    "bacelasses": "bacelar",
    "bacelaste": "bacelar",
    "bacelastes": "bacelar",
    "bacelava": "bacelar",
    "bacelavam": "bacelar",
    "bacelavas": "bacelar",
    "bacele": "bacelar",
    "bacelei": "bacelar",
    "baceleiros": "baceleiro",
    "baceleis": "bacelar",
    "bacelem": "bacelar",
    "bacelemo": "bacelar",
    "bacelemos": "bacelar",
    "baceles": "bacelar",
    "bacelo": "bacelar",
    "bacelos": "bacelo",
    "bacelou": "bacelar",
    "bacelá": "bacelar",
    "bacelámo": "bacelar",
    "bacelámos": "bacelar",
    "baceláramo": "bacelar",
    "baceláramos": "bacelar",
    "bacelárei": "bacelar",
    "baceláreis": "bacelar",
    "bacelásseis": "bacelar",
    "bacelássemos": "bacelar",
    "bacelávamo": "bacelar",
    "bacelávamos": "bacelar",
    "bacelávei": "bacelar",
    "baceláveis": "bacelar",
    "bacenta": "bacento",
    "bacentas": "bacento",
    "bacentos": "bacento",
    "bacharela": "bacharelar",
    "bacharelada": "bacharelar",
    "bachareladas": "bacharelar",
    "bacharelado": "bacharelar",
    "bacharelados": "bacharelar",
    "bacharelai": "bacharelar",
    "bacharelais": "bacharelar",
    "bacharelam": "bacharelar",
    "bacharelamo": "bacharelar",
    "bacharelamos": "bacharelar",
    "bacharelanda": "bacharelando",
    "bacharelandas": "bacharelando",
    "bacharelando": "bacharelar",
    "bacharelandos": "bacharelando",
    "bacharelara": "bacharelar",
    "bacharelaram": "bacharelar",
    "bacharelaras": "bacharelar",
    "bacharelarde": "bacharelar",
    "bacharelardes": "bacharelar",
    "bacharelare": "bacharelar",
    "bacharelarei": "bacharelar",
    "bacharelareis": "bacharelar",
    "bacharelarem": "bacharelar",
    "bacharelaremos": "bacharelar",
    "bacharelares": "bacharelar",
    "bacharelaria": "bacharelar",
    "bacharelariam": "bacharelar",
    "bacharelarias": "bacharelar",
    "bacharelarmo": "bacharelar",
    "bacharelarmos": "bacharelar",
    "bacharelará": "bacharelar",
    "bacharelarás": "bacharelar",
    "bacharelarão": "bacharelar",
    "bacharelaríamos": "bacharelar",
    "bacharelaríeis": "bacharelar",
    "bacharelas": "bacharelar",
    "bacharelasse": "bacharelar",
    "bacharelassem": "bacharelar",
    "bacharelasses": "bacharelar",
    "bacharelaste": "bacharelar",
    "bacharelastes": "bacharelar",
    "bacharelatos": "bacharelato",
    "bacharelava": "bacharelar",
    "bacharelavam": "bacharelar",
    "bacharelavas": "bacharelar",
    "bacharele": "bacharelar",
    "bacharelei": "bacharelar",
    "bachareleira": "bachareleiro",
    "bachareleiras": "bachareleiro",
    "bachareleiros": "bachareleiro",
    "bachareleis": "bacharelar",
    "bacharelem": "bacharelar",
    "bacharelemo": "bacharelar",
    "bacharelemos": "bacharelar",
    "bachareles": "bacharelar",
    "bacharelesca": "bacharelesco",
    "bacharelescas": "bacharelesco",
    "bacharelescos": "bacharelesco",
    "bacharelices": "bacharelice",
    "bacharelismos": "bacharelismo",
    "bacharelo": "bacharelar",
    "bacharelomanias": "bacharelomania",
    "bacharelou": "bacharelar",
    "bacharelá": "bacharelar",
    "bacharelámo": "bacharelar",
    "bacharelámos": "bacharelar",
    "bachareláramo": "bacharelar",
    "bachareláramos": "bacharelar",
    "bacharelárei": "bacharelar",
    "bachareláreis": "bacharelar",
    "bacharelásseis": "bacharelar",
    "bacharelássemos": "bacharelar",
    "bacharelávamo": "bacharelar",
    "bacharelávamos": "bacharelar",
    "bacharelávei": "bacharelar",
    "bachareláveis": "bacharelar",
    "bacharéis": "bacharel",
    "bachica": "bachicar",
    "bachicada": "bachicar",
    "bachicadas": "bachicar",
    "bachicado": "bachicar",
    "bachicados": "bachicar",
    "bachicais": "bachicar",
    "bachicam": "bachicar",
    "bachicamo": "bachicar",
    "bachicamos": "bachicar",
    "bachicando": "bachicar",
    "bachicara": "bachicar",
    "bachicaram": "bachicar",
    "bachicaras": "bachicar",
    "bachicardes": "bachicar",
    "bachicarei": "bachicar",
    "bachicareis": "bachicar",
    "bachicarem": "bachicar",
    "bachicaremos": "bachicar",
    "bachicares": "bachicar",
    "bachicaria": "bachicar",
    "bachicariam": "bachicar",
    "bachicarias": "bachicar",
    "bachicarmo": "bachicar",
    "bachicarmos": "bachicar",
    "bachicará": "bachicar",
    "bachicarás": "bachicar",
    "bachicarão": "bachicar",
    "bachicaríamos": "bachicar",
    "bachicaríeis": "bachicar",
    "bachicas": "bachicar",
    "bachicasse": "bachicar",
    "bachicassem": "bachicar",
    "bachicasses": "bachicar",
    "bachicaste": "bachicar",
    "bachicastes": "bachicar",
    "bachicava": "bachicar",
    "bachicavam": "bachicar",
    "bachicavas": "bachicar",
    "bachico": "bachicar",
    "bachicou": "bachicar",
    "bachicámo": "bachicar",
    "bachicámos": "bachicar",
    "bachicáramo": "bachicar",
    "bachicáramos": "bachicar",
    "bachicáreis": "bachicar",
    "bachicásseis": "bachicar",
    "bachicássemos": "bachicar",
    "bachicávamo": "bachicar",
    "bachicávamos": "bachicar",
    "bachicáveis": "bachicar",
    "bachique": "bachicar",
    "bachiquei": "bachicar",
    "bachiqueis": "bachicar",
    "bachiquem": "bachicar",
    "bachiquemos": "bachicar",
    "bachiques": "bachicar",
    "baciada": "baciado",
    "baciadas": "baciado",
    "baciados": "baciado",
    "baciais": "bacial",
    "baciana": "baciano",
    "bacianas": "baciano",
    "bacianos": "baciano",
    "bacias": "bacia",
    "bacidezes": "bacidez",
    "baciformes": "baciforme",
    "bacilares": "bacilar",
    "bacilariácea": "bacilariáceo",
    "bacilariáceas": "bacilariáceo",
    "bacilariáceos": "bacilariáceo",
    "bacilariófitas": "bacilariófita",
    "bacilariófitos": "bacilariófito",
    "bacilemias": "bacilemia",
    "baciliformes": "baciliforme",
    "baciliza": "bacilizar",
    "bacilizada": "bacilizar",
    "bacilizadas": "bacilizar",
    "bacilizado": "bacilizar",
    "bacilizados": "bacilizar",
    "bacilizai": "bacilizar",
    "bacilizais": "bacilizar",
    "bacilizam": "bacilizar",
    "bacilizamo": "bacilizar",
    "bacilizamos": "bacilizar",
    "bacilizando": "bacilizar",
    "bacilizara": "bacilizar",
    "bacilizaram": "bacilizar",
    "bacilizaras": "bacilizar",
    "bacilizarde": "bacilizar",
    "bacilizardes": "bacilizar",
    "bacilizare": "bacilizar",
    "bacilizarei": "bacilizar",
    "bacilizareis": "bacilizar",
    "bacilizarem": "bacilizar",
    "bacilizaremos": "bacilizar",
    "bacilizares": "bacilizar",
    "bacilizaria": "bacilizar",
    "bacilizariam": "bacilizar",
    "bacilizarias": "bacilizar",
    "bacilizarmo": "bacilizar",
    "bacilizarmos": "bacilizar",
    "bacilizará": "bacilizar",
    "bacilizarás": "bacilizar",
    "bacilizarão": "bacilizar",
    "bacilizaríamos": "bacilizar",
    "bacilizaríeis": "bacilizar",
    "bacilizas": "bacilizar",
    "bacilizasse": "bacilizar",
    "bacilizassem": "bacilizar",
    "bacilizasses": "bacilizar",
    "bacilizaste": "bacilizar",
    "bacilizastes": "bacilizar",
    "bacilizava": "bacilizar",
    "bacilizavam": "bacilizar",
    "bacilizavas": "bacilizar",
    "bacilizações": "bacilização",
    "bacilize": "bacilizar",
    "bacilizei": "bacilizar",
    "bacilizeis": "bacilizar",
    "bacilizem": "bacilizar",
    "bacilizemo": "bacilizar",
    "bacilizemos": "bacilizar",
    "bacilizes": "bacilizar",
    "bacilizo": "bacilizar",
    "bacilizou": "bacilizar",
    "bacilizá": "bacilizar",
    "bacilizámo": "bacilizar",
    "bacilizámos": "bacilizar",
    "bacilizáramo": "bacilizar",
    "bacilizáramos": "bacilizar",
    "bacilizárei": "bacilizar",
    "bacilizáreis": "bacilizar",
    "bacilizásseis": "bacilizar",
    "bacilizássemos": "bacilizar",
    "bacilizávamo": "bacilizar",
    "bacilizávamos": "bacilizar",
    "bacilizávei": "bacilizar",
    "bacilizáveis": "bacilizar",
    "bacilos": "bacilo",
    "bacilosa": "baciloso",
    "bacilosas": "baciloso",
    "baciloscopias": "baciloscopia",
    "baciloscópica": "baciloscópico",
    "baciloscópicas": "baciloscópico",
    "baciloscópicos": "baciloscópico",
    "baciloscópios": "baciloscópio",
    "baciloses": "bacilose",
    "bacilosos": "baciloso",
    "baciloterapias": "baciloterapia",
    "baciloterapêutica": "baciloterapêutico",
    "baciloterapêuticas": "baciloterapêutico",
    "baciloterapêuticos": "baciloterapêutico",
    "baciloterápica": "baciloterápico",
    "baciloterápicas": "baciloterápico",
    "baciloterápicos": "baciloterápico",
    "bacinetas": "bacineta",
    "bacinetes": "bacinete",
    "bacios": "bacio",
    "bacoca": "bacoco",
    "bacocas": "bacoco",
    "bacocazinha": "bacoco",
    "bacocazinhas": "bacoco",
    "bacocazita": "bacoco",
    "bacocazitas": "bacoco",
    "bacocos": "bacoco",
    "bacocozinho": "bacoco",
    "bacocozinhos": "bacoco",
    "bacocozito": "bacoco",
    "bacocozitos": "bacoco",
    "baconiana": "baconiano",
    "baconianas": "baconiano",
    "baconianos": "baconiano",
    "baconismos": "baconismo",
    "bacons": "bacon",
    "bacoquices": "bacoquice",
    "bacoquismos": "bacoquismo",
    "bacoradas": "bacorada",
    "bacoreja": "bacorejar",
    "bacorejada": "bacorejar",
    "bacorejadas": "bacorejar",
    "bacorejado": "bacorejar",
    "bacorejados": "bacorejar",
    "bacorejai": "bacorejar",
    "bacorejais": "bacorejar",
    "bacorejam": "bacorejar",
    "bacorejamo": "bacorejar",
    "bacorejamos": "bacorejar",
    "bacorejando": "bacorejar",
    "bacorejara": "bacorejar",
    "bacorejaram": "bacorejar",
    "bacorejaras": "bacorejar",
    "bacorejarde": "bacorejar",
    "bacorejardes": "bacorejar",
    "bacorejare": "bacorejar",
    "bacorejarei": "bacorejar",
    "bacorejareis": "bacorejar",
    "bacorejarem": "bacorejar",
    "bacorejaremos": "bacorejar",
    "bacorejares": "bacorejar",
    "bacorejaria": "bacorejar",
    "bacorejariam": "bacorejar",
    "bacorejarias": "bacorejar",
    "bacorejarmo": "bacorejar",
    "bacorejarmos": "bacorejar",
    "bacorejará": "bacorejar",
    "bacorejarás": "bacorejar",
    "bacorejarão": "bacorejar",
    "bacorejaríamos": "bacorejar",
    "bacorejaríeis": "bacorejar",
    "bacorejas": "bacorejar",
    "bacorejasse": "bacorejar",
    "bacorejassem": "bacorejar",
    "bacorejasses": "bacorejar",
    "bacorejaste": "bacorejar",
    "bacorejastes": "bacorejar",
    "bacorejava": "bacorejar",
    "bacorejavam": "bacorejar",
    "bacorejavas": "bacorejar",
    "bacoreje": "bacorejar",
    "bacorejei": "bacorejar",
    "bacorejeis": "bacorejar",
    "bacorejem": "bacorejar",
    "bacorejemo": "bacorejar",
    "bacorejemos": "bacorejar",
    "bacorejes": "bacorejar",
    "bacorejo": "bacorejar",
    "bacorejos": "bacorejo",
    "bacorejou": "bacorejar",
    "bacorejá": "bacorejar",
    "bacorejámo": "bacorejar",
    "bacorejámos": "bacorejar",
    "bacorejáramo": "bacorejar",
    "bacorejáramos": "bacorejar",
    "bacorejárei": "bacorejar",
    "bacorejáreis": "bacorejar",
    "bacorejásseis": "bacorejar",
    "bacorejássemos": "bacorejar",
    "bacorejávamo": "bacorejar",
    "bacorejávamos": "bacorejar",
    "bacorejávei": "bacorejar",
    "bacorejáveis": "bacorejar",
    "bacorices": "bacorice",
    "bacorinha": "bácoro",
    "bacorinhada": "bacorinhar",
    "bacorinhadas": "bacorinhar",
    "bacorinhado": "bacorinhar",
    "bacorinhados": "bacorinhar",
    "bacorinhai": "bacorinhar",
    "bacorinhais": "bacorinhar",
    "bacorinham": "bacorinhar",
    "bacorinhamo": "bacorinhar",
    "bacorinhamos": "bacorinhar",
    "bacorinhando": "bacorinhar",
    "bacorinhara": "bacorinhar",
    "bacorinharam": "bacorinhar",
    "bacorinharas": "bacorinhar",
    "bacorinhardes": "bacorinhar",
    "bacorinharei": "bacorinhar",
    "bacorinhareis": "bacorinhar",
    "bacorinharem": "bacorinhar",
    "bacorinharemos": "bacorinhar",
    "bacorinhares": "bacorinhar",
    "bacorinharia": "bacorinhar",
    "bacorinhariam": "bacorinhar",
    "bacorinharias": "bacorinhar",
    "bacorinharmo": "bacorinhar",
    "bacorinharmos": "bacorinhar",
    "bacorinhará": "bacorinhar",
    "bacorinharás": "bacorinhar",
    "bacorinharão": "bacorinhar",
    "bacorinharíamos": "bacorinhar",
    "bacorinharíeis": "bacorinhar",
    "bacorinhas": "bácoro",
    "bacorinhasse": "bacorinhar",
    "bacorinhassem": "bacorinhar",
    "bacorinhasses": "bacorinhar",
    "bacorinhaste": "bacorinhar",
    "bacorinhastes": "bacorinhar",
    "bacorinhava": "bacorinhar",
    "bacorinhavam": "bacorinhar",
    "bacorinhavas": "bacorinhar",
    "bacorinhe": "bacorinhar",
    "bacorinhei": "bacorinhar",
    "bacorinheis": "bacorinhar",
    "bacorinhem": "bacorinhar",
    "bacorinhemo": "bacorinhar",
    "bacorinhemos": "bacorinhar",
    "bacorinhes": "bacorinhar",
    "bacorinho": "bácoro",
    "bacorinhos": "bácoro",
    "bacorinhou": "bacorinhar",
    "bacorinhámo": "bacorinhar",
    "bacorinhámos": "bacorinhar",
    "bacorinháramo": "bacorinhar",
    "bacorinháramos": "bacorinhar",
    "bacorinháreis": "bacorinhar",
    "bacorinhásseis": "bacorinhar",
    "bacorinhássemos": "bacorinhar",
    "bacorinhávamo": "bacorinhar",
    "bacorinhávamos": "bacorinhar",
    "bacorinháveis": "bacorinhar",
    "bacorita": "bácoro",
    "bacoritas": "bácoro",
    "bacorito": "bácoro",
    "bacoritos": "bácoro",
    "bacorotes": "bacorote",
    "bacteriana": "bacteriano",
    "bacterianas": "bacteriano",
    "bacterianos": "bacteriano",
    "bactericidas": "bactericida",
    "bacteriemias": "bacteriemia",
    "bacteriologias": "bacteriologia",
    "bacteriologistas": "bacteriologista",
    "bacteriológica": "bacteriológico",
    "bacteriológicas": "bacteriológico",
    "bacteriológicos": "bacteriológico",
    "bacterioscopias": "bacterioscopia",
    "bacterioscópica": "bacterioscópico",
    "bacterioscópicas": "bacterioscópico",
    "bacterioscópicos": "bacterioscópico",
    "bacterioscópios": "bacterioscópio",
    "bacterioses": "bacteriose",
    "bacteriostática": "bacteriostático",
    "bacteriostáticas": "bacteriostático",
    "bacteriostáticos": "bacteriostático",
    "bacterioterapias": "bacterioterapia",
    "bacterioterapêutica": "bacterioterapêutico",
    "bacterioterapêuticas": "bacterioterapêutico",
    "bacterioterapêuticos": "bacterioterapêutico",
    "bacterioterápica": "bacterioterápico",
    "bacterioterápicas": "bacterioterápico",
    "bacterioterápicos": "bacterioterápico",
    "bacteriácea": "bacteriáceo",
    "bacteriáceas": "bacteriáceo",
    "bacteriáceos": "bacteriáceo",
    "bacteriófaga": "bacteriófago",
    "bacteriófagas": "bacteriófago",
    "bacteriófagos": "bacteriófago",
    "bacterióloga": "bacteriólogo",
    "bacteriólogas": "bacteriólogo",
    "bacteriólogos": "bacteriólogo",
    "bacteriúrias": "bacteriúria",
    "bactérias": "bactéria",
    "bactérica": "bactérico",
    "bactéricas": "bactérico",
    "bactéricos": "bactérico",
    "baculiformes": "baculiforme",
    "baculina": "baculino",
    "baculinas": "baculino",
    "baculinos": "baculino",
    "baculometrias": "baculometria",
    "baculométrica": "baculométrico",
    "baculométricas": "baculométrico",
    "baculométricos": "baculométrico",
    "baculífera": "baculífero",
    "baculíferas": "baculífero",
    "baculíferos": "baculífero",
    "baculómetros": "baculómetro",
    "bacácea": "bacáceo",
    "bacáceas": "bacáceo",
    "bacáceos": "bacáceo",
    "bacífera": "bacífero",
    "bacíferas": "bacífero",
    "bacíferos": "bacífero",
    "bacívora": "bacívoro",
    "bacívoras": "bacívoro",
    "bacívoros": "bacívoro",
    "badala": "badalar",
    "badalada": "badalar",
    "badaladas": "badalar",
    "badalado": "badalar",
    "badalados": "badalar",
    "badaladíssima": "badalado",
    "badaladíssimas": "badalado",
    "badaladíssimo": "badalado",
    "badaladíssimos": "badalado",
    "badalai": "badalar",
    "badalais": "badalar",
    "badalam": "badalar",
    "badalamo": "badalar",
    "badalamos": "badalar",
    "badalando": "badalar",
    "badalara": "badalar",
    "badalaram": "badalar",
    "badalaras": "badalar",
    "badalarde": "badalar",
    "badalardes": "badalar",
    "badalare": "badalar",
    "badalarei": "badalar",
    "badalareis": "badalar",
    "badalarem": "badalar",
    "badalaremos": "badalar",
    "badalares": "badalar",
    "badalaria": "badalar",
    "badalariam": "badalar",
    "badalarias": "badalar",
    "badalarmo": "badalar",
    "badalarmos": "badalar",
    "badalará": "badalar",
    "badalarás": "badalar",
    "badalarão": "badalar",
    "badalaríamos": "badalar",
    "badalaríeis": "badalar",
    "badalas": "badalar",
    "badalasse": "badalar",
    "badalassem": "badalar",
    "badalasses": "badalar",
    "badalaste": "badalar",
    "badalastes": "badalar",
    "badalava": "badalar",
    "badalavam": "badalar",
    "badalavas": "badalar",
    "badalações": "badalação",
    "badale": "badalar",
    "badalei": "badalar",
    "badaleiras": "badaleira",
    "badaleiros": "badaleiro",
    "badaleis": "badalar",
    "badaleja": "badalejar",
    "badalejada": "badalejar",
    "badalejadas": "badalejar",
    "badalejado": "badalejar",
    "badalejados": "badalejar",
    "badalejai": "badalejar",
    "badalejais": "badalejar",
    "badalejam": "badalejar",
    "badalejamo": "badalejar",
    "badalejamos": "badalejar",
    "badalejando": "badalejar",
    "badalejara": "badalejar",
    "badalejaram": "badalejar",
    "badalejaras": "badalejar",
    "badalejardes": "badalejar",
    "badalejarei": "badalejar",
    "badalejareis": "badalejar",
    "badalejarem": "badalejar",
    "badalejaremos": "badalejar",
    "badalejares": "badalejar",
    "badalejaria": "badalejar",
    "badalejariam": "badalejar",
    "badalejarias": "badalejar",
    "badalejarmo": "badalejar",
    "badalejarmos": "badalejar",
    "badalejará": "badalejar",
    "badalejarás": "badalejar",
    "badalejarão": "badalejar",
    "badalejaríamos": "badalejar",
    "badalejaríeis": "badalejar",
    "badalejas": "badalejar",
    "badalejasse": "badalejar",
    "badalejassem": "badalejar",
    "badalejasses": "badalejar",
    "badalejaste": "badalejar",
    "badalejastes": "badalejar",
    "badalejava": "badalejar",
    "badalejavam": "badalejar",
    "badalejavas": "badalejar",
    "badaleje": "badalejar",
    "badalejei": "badalejar",
    "badalejeis": "badalejar",
    "badalejem": "badalejar",
    "badalejemo": "badalejar",
    "badalejemos": "badalejar",
    "badalejes": "badalejar",
    "badalejo": "badalejar",
    "badalejou": "badalejar",
    "badalejámo": "badalejar",
    "badalejámos": "badalejar",
    "badalejáramo": "badalejar",
    "badalejáramos": "badalejar",
    "badalejáreis": "badalejar",
    "badalejásseis": "badalejar",
    "badalejássemos": "badalejar",
    "badalejávamo": "badalejar",
    "badalejávamos": "badalejar",
    "badalejáveis": "badalejar",
    "badalem": "badalar",
    "badalemo": "badalar",
    "badalemos": "badalar",
    "badales": "badalar",
    "badalhoca": "badalhoco",
    "badalhocas": "badalhoco",
    "badalhocos": "badalhoco",
    "badalo": "badalar",
    "badalos": "badalo",
    "badalou": "badalar",
    "badalá": "badalar",
    "badalámo": "badalar",
    "badalámos": "badalar",
    "badaláramo": "badalar",
    "badaláramos": "badalar",
    "badalárei": "badalar",
    "badaláreis": "badalar",
    "badalásseis": "badalar",
    "badalássemos": "badalar",
    "badalávamo": "badalar",
    "badalávamos": "badalar",
    "badalávei": "badalar",
    "badaláveis": "badalar",
    "badalões": "badalão",
    "badameca": "badameco",
    "badamecas": "badameco",
    "badamecos": "badameco",
    "badames": "badame",
    "badana": "badanar",
    "badanada": "badanar",
    "badanadas": "badanar",
    "badanado": "badanar",
    "badanados": "badanar",
    "badanagens": "badanagem",
    "badanai": "badanar",
    "badanais": "badanar",
    "badanam": "badanar",
    "badanamo": "badanar",
    "badanamos": "badanar",
    "badanando": "badanar",
    "badanara": "badanar",
    "badanaram": "badanar",
    "badanaras": "badanar",
    "badanardes": "badanar",
    "badanarei": "badanar",
    "badanareis": "badanar",
    "badanarem": "badanar",
    "badanaremos": "badanar",
    "badanares": "badanar",
    "badanaria": "badanar",
    "badanariam": "badanar",
    "badanarias": "badanar",
    "badanarmo": "badanar",
    "badanarmos": "badanar",
    "badanará": "badanar",
    "badanarás": "badanar",
    "badanarão": "badanar",
    "badanaríamos": "badanar",
    "badanaríeis": "badanar",
    "badanas": "badanar",
    "badanasse": "badanar",
    "badanassem": "badanar",
    "badanasses": "badanar",
    "badanaste": "badanar",
    "badanastes": "badanar",
    "badanava": "badanar",
    "badanavam": "badanar",
    "badanavas": "badanar",
    "badane": "badanar",
    "badanei": "badanar",
    "badaneis": "badanar",
    "badanem": "badanar",
    "badanemo": "badanar",
    "badanemos": "badanar",
    "badanes": "badanar",
    "badano": "badanar",
    "badanos": "badano",
    "badanou": "badanar",
    "badantes": "badante",
    "badanámo": "badanar",
    "badanámos": "badanar",
    "badanáramo": "badanar",
    "badanáramos": "badanar",
    "badanáreis": "badanar",
    "badanásseis": "badanar",
    "badanássemos": "badanar",
    "badanávamo": "badanar",
    "badanávamos": "badanar",
    "badanáveis": "badanar",
    "badejos": "badejo",
    "badernas": "baderna",
    "badianas": "badiana",
    "badiis": "badil",
    "badiões": "badião",
    "badoleiros": "badoleiro",
    "badora": "badorar",
    "badorada": "badorar",
    "badoradas": "badorar",
    "badorado": "badorar",
    "badorados": "badorar",
    "badorai": "badorar",
    "badorais": "badorar",
    "badoram": "badorar",
    "badoramo": "badorar",
    "badoramos": "badorar",
    "badorando": "badorar",
    "badorara": "badorar",
    "badoraram": "badorar",
    "badoraras": "badorar",
    "badorardes": "badorar",
    "badorarei": "badorar",
    "badorareis": "badorar",
    "badorarem": "badorar",
    "badoraremos": "badorar",
    "badorares": "badorar",
    "badoraria": "badorar",
    "badorariam": "badorar",
    "badorarias": "badorar",
    "badorarmo": "badorar",
    "badorarmos": "badorar",
    "badorará": "badorar",
    "badorarás": "badorar",
    "badorarão": "badorar",
    "badoraríamos": "badorar",
    "badoraríeis": "badorar",
    "badoras": "badorar",
    "badorasse": "badorar",
    "badorassem": "badorar",
    "badorasses": "badorar",
    "badoraste": "badorar",
    "badorastes": "badorar",
    "badorava": "badorar",
    "badoravam": "badorar",
    "badoravas": "badorar",
    "badore": "badorar",
    "badorei": "badorar",
    "badoreis": "badorar",
    "badorem": "badorar",
    "badoremo": "badorar",
    "badoremos": "badorar",
    "badores": "badorar",
    "badoro": "badorar",
    "badorou": "badorar",
    "badorámo": "badorar",
    "badorámos": "badorar",
    "badoráramo": "badorar",
    "badoráramos": "badorar",
    "badoráreis": "badorar",
    "badorásseis": "badorar",
    "badorássemos": "badorar",
    "badorávamo": "badorar",
    "badorávamos": "badorar",
    "badoráveis": "badorar",
    "badulaques": "badulaque",
    "baetais": "baetal",
    "baetas": "baeta",
    "baetilhas": "baetilha",
    "baetões": "baetão",
    "bafa": "bafar",
    "bafada": "bafar",
    "bafadas": "bafar",
    "bafado": "bafar",
    "bafados": "bafar",
    "bafagens": "bafagem",
    "bafai": "bafar",
    "bafais": "bafar",
    "bafam": "bafar",
    "bafamo": "bafar",
    "bafamos": "bafar",
    "bafando": "bafar",
    "bafara": "bafar",
    "bafaram": "bafar",
    "bafaras": "bafar",
    "bafardes": "bafar",
    "bafarei": "bafar",
    "bafareiras": "bafareira",
    "bafareis": "bafar",
    "bafarem": "bafar",
    "bafaremos": "bafar",
    "bafares": "bafar",
    "bafaria": "bafar",
    "bafariam": "bafar",
    "bafarias": "bafar",
    "bafaris": "bafari",
    "bafarmo": "bafar",
    "bafarmos": "bafar",
    "bafará": "bafar",
    "bafarás": "bafar",
    "bafarão": "bafar",
    "bafaríamos": "bafar",
    "bafaríeis": "bafar",
    "bafas": "bafar",
    "bafasse": "bafar",
    "bafassem": "bafar",
    "bafasses": "bafar",
    "bafaste": "bafar",
    "bafastes": "bafar",
    "bafava": "bafar",
    "bafavam": "bafar",
    "bafavas": "bafar",
    "bafe": "bafar",
    "bafei": "bafar",
    "bafeis": "bafar",
    "bafeja": "bafejar",
    "bafejada": "bafejar",
    "bafejadas": "bafejar",
    "bafejado": "bafejar",
    "bafejadora": "bafejador",
    "bafejadoras": "bafejador",
    "bafejadores": "bafejador",
    "bafejados": "bafejar",
    "bafejadíssima": "bafejado",
    "bafejadíssimas": "bafejado",
    "bafejadíssimo": "bafejado",
    "bafejadíssimos": "bafejado",
    "bafejai": "bafejar",
    "bafejais": "bafejar",
    "bafejam": "bafejar",
    "bafejamo": "bafejar",
    "bafejamos": "bafejar",
    "bafejando": "bafejar",
    "bafejantes": "bafejante",
    "bafejara": "bafejar",
    "bafejaram": "bafejar",
    "bafejaras": "bafejar",
    "bafejarde": "bafejar",
    "bafejardes": "bafejar",
    "bafejare": "bafejar",
    "bafejarei": "bafejar",
    "bafejareis": "bafejar",
    "bafejarem": "bafejar",
    "bafejaremos": "bafejar",
    "bafejares": "bafejar",
    "bafejaria": "bafejar",
    "bafejariam": "bafejar",
    "bafejarias": "bafejar",
    "bafejarmo": "bafejar",
    "bafejarmos": "bafejar",
    "bafejará": "bafejar",
    "bafejarás": "bafejar",
    "bafejarão": "bafejar",
    "bafejaríamos": "bafejar",
    "bafejaríeis": "bafejar",
    "bafejas": "bafejar",
    "bafejasse": "bafejar",
    "bafejassem": "bafejar",
    "bafejasses": "bafejar",
    "bafejaste": "bafejar",
    "bafejastes": "bafejar",
    "bafejava": "bafejar",
    "bafejavam": "bafejar",
    "bafejavas": "bafejar",
    "bafeje": "bafejar",
    "bafejei": "bafejar",
    "bafejeis": "bafejar",
    "bafejem": "bafejar",
    "bafejemo": "bafejar",
    "bafejemos": "bafejar",
    "bafejes": "bafejar",
    "bafejo": "bafejar",
    "bafejos": "bafejo",
    "bafejou": "bafejar",
    "bafejá": "bafejar",
    "bafejámo": "bafejar",
    "bafejámos": "bafejar",
    "bafejáramo": "bafejar",
    "bafejáramos": "bafejar",
    "bafejárei": "bafejar",
    "bafejáreis": "bafejar",
    "bafejásseis": "bafejar",
    "bafejássemos": "bafejar",
    "bafejávamo": "bafejar",
    "bafejávamos": "bafejar",
    "bafejávei": "bafejar",
    "bafejáveis": "bafejar",
    "bafem": "bafar",
    "bafemo": "bafar",
    "bafemos": "bafar",
    "bafes": "bafar",
    "bafienta": "bafiento",
    "bafientas": "bafiento",
    "bafientos": "bafiento",
    "bafios": "bafio",
    "bafo": "bafar",
    "bafora": "baforar",
    "baforada": "baforar",
    "baforadas": "baforar",
    "baforado": "baforar",
    "baforados": "baforar",
    "baforai": "baforar",
    "baforais": "baforar",
    "baforam": "baforar",
    "baforamo": "baforar",
    "baforamos": "baforar",
    "baforando": "baforar",
    "baforara": "baforar",
    "baforaram": "baforar",
    "baforaras": "baforar",
    "baforardes": "baforar",
    "baforarei": "baforar",
    "baforareis": "baforar",
    "baforarem": "baforar",
    "baforaremos": "baforar",
    "baforares": "baforar",
    "baforaria": "baforar",
    "baforariam": "baforar",
    "baforarias": "baforar",
    "baforarmo": "baforar",
    "baforarmos": "baforar",
    "baforará": "baforar",
    "baforarás": "baforar",
    "baforarão": "baforar",
    "baforaríamos": "baforar",
    "baforaríeis": "baforar",
    "baforas": "baforar",
    "baforasse": "baforar",
    "baforassem": "baforar",
    "baforasses": "baforar",
    "baforaste": "baforar",
    "baforastes": "baforar",
    "baforava": "baforar",
    "baforavam": "baforar",
    "baforavas": "baforar",
    "bafordos": "bafordo",
    "bafore": "baforar",
    "baforei": "baforar",
    "baforeiras": "baforeira",
    "baforeis": "baforar",
    "baforem": "baforar",
    "baforemo": "baforar",
    "baforemos": "baforar",
    "bafores": "baforar",
    "baforo": "baforar",
    "baforou": "baforar",
    "baforámo": "baforar",
    "baforámos": "baforar",
    "baforáramo": "baforar",
    "baforáramos": "baforar",
    "baforáreis": "baforar",
    "baforásseis": "baforar",
    "baforássemos": "baforar",
    "baforávamo": "baforar",
    "baforávamos": "baforar",
    "baforáveis": "baforar",
    "bafos": "bafo",
    "bafou": "bafar",
    "bafuns": "bafum",
    "bafurda": "bafurdar",
    "bafurdada": "bafurdar",
    "bafurdadas": "bafurdar",
    "bafurdado": "bafurdar",
    "bafurdados": "bafurdar",
    "bafurdai": "bafurdar",
    "bafurdais": "bafurdar",
    "bafurdam": "bafurdar",
    "bafurdamo": "bafurdar",
    "bafurdamos": "bafurdar",
    "bafurdando": "bafurdar",
    "bafurdara": "bafurdar",
    "bafurdaram": "bafurdar",
    "bafurdaras": "bafurdar",
    "bafurdardes": "bafurdar",
    "bafurdarei": "bafurdar",
    "bafurdareis": "bafurdar",
    "bafurdarem": "bafurdar",
    "bafurdaremos": "bafurdar",
    "bafurdares": "bafurdar",
    "bafurdaria": "bafurdar",
    "bafurdariam": "bafurdar",
    "bafurdarias": "bafurdar",
    "bafurdarmo": "bafurdar",
    "bafurdarmos": "bafurdar",
    "bafurdará": "bafurdar",
    "bafurdarás": "bafurdar",
    "bafurdarão": "bafurdar",
    "bafurdaríamos": "bafurdar",
    "bafurdaríeis": "bafurdar",
    "bafurdas": "bafurdar",
    "bafurdasse": "bafurdar",
    "bafurdassem": "bafurdar",
    "bafurdasses": "bafurdar",
    "bafurdaste": "bafurdar",
    "bafurdastes": "bafurdar",
    "bafurdava": "bafurdar",
    "bafurdavam": "bafurdar",
    "bafurdavas": "bafurdar",
    "bafurde": "bafurdar",
    "bafurdei": "bafurdar",
    "bafurdeis": "bafurdar",
    "bafurdem": "bafurdar",
    "bafurdemo": "bafurdar",
    "bafurdemos": "bafurdar",
    "bafurdes": "bafurdar",
    "bafurdo": "bafurdar",
    "bafurdou": "bafurdar",
    "bafurdámo": "bafurdar",
    "bafurdámos": "bafurdar",
    "bafurdáramo": "bafurdar",
    "bafurdáramos": "bafurdar",
    "bafurdáreis": "bafurdar",
    "bafurdásseis": "bafurdar",
    "bafurdássemos": "bafurdar",
    "bafurdávamo": "bafurdar",
    "bafurdávamos": "bafurdar",
    "bafurdáveis": "bafurdar",
    "bafureira": "bafureiro",
    "bafureiras": "bafureiro",
    "bafureiros": "bafureiro",
    "bafámo": "bafar",
    "bafámos": "bafar",
    "bafáramo": "bafar",
    "bafáramos": "bafar",
    "bafáreis": "bafar",
    "bafásseis": "bafar",
    "bafássemos": "bafar",
    "bafávamo": "bafar",
    "bafávamos": "bafar",
    "bafáveis": "bafar",
    "baga": "bagar",
    "bagaceira": "bagaceiro",
    "bagaceiras": "bagaceiro",
    "bagaceiros": "bagaceiro",
    "bagacinho": "bagaço",
    "bagacinhos": "bagaço",
    "bagacito": "bagaço",
    "bagacitos": "bagaço",
    "bagada": "bagar",
    "bagadas": "bagar",
    "bagado": "bagar",
    "bagados": "bagar",
    "bagageiras": "bagageira",
    "bagageiros": "bagageiro",
    "bagagens": "bagagem",
    "bagagistas": "bagagista",
    "bagagueira": "bagagueiro",
    "bagagueiras": "bagagueiro",
    "bagagueiros": "bagagueiro",
    "bagai": "bagar",
    "bagais": "bagar",
    "bagalhos": "bagalho",
    "bagalhoças": "bagalhoça",
    "bagalhuda": "bagalhudo",
    "bagalhudas": "bagalhudo",
    "bagalhudos": "bagalhudo",
    "bagalhões": "bagalhão",
    "bagam": "bagar",
    "bagamo": "bagar",
    "bagamos": "bagar",
    "bagandas": "baganda",
    "bagando": "bagar",
    "baganhas": "baganha",
    "baganhos": "baganho",
    "bagara": "bagar",
    "bagaram": "bagar",
    "bagaras": "bagar",
    "bagardes": "bagar",
    "bagarei": "bagar",
    "bagareis": "bagar",
    "bagarem": "bagar",
    "bagaremos": "bagar",
    "bagares": "bagar",
    "bagaria": "bagar",
    "bagariam": "bagar",
    "bagarias": "bagar",
    "bagarmo": "bagar",
    "bagarmos": "bagar",
    "bagará": "bagar",
    "bagarás": "bagar",
    "bagarão": "bagar",
    "bagaríamos": "bagar",
    "bagaríeis": "bagar",
    "bagas": "bagar",
    "bagasse": "bagar",
    "bagassem": "bagar",
    "bagasses": "bagar",
    "bagaste": "bagar",
    "bagastes": "bagar",
    "bagatelas": "bagatela",
    "bagateleira": "bagateleiro",
    "bagateleiras": "bagateleiro",
    "bagateleiros": "bagateleiro",
    "bagava": "bagar",
    "bagavam": "bagar",
    "bagavas": "bagar",
    "bagaxas": "bagaxa",
    "bagaçadas": "bagaçada",
    "bagaçais": "bagaçal",
    "bagaços": "bagaço",
    "bago": "bagar",
    "bagoada": "bagoado",
    "bagoadas": "bagoado",
    "bagoados": "bagoado",
    "bagochos": "bagocho",
    "bagoeiras": "bagoeira",
    "bagos": "bago",
    "bagou": "bagar",
    "baguda": "bagudo",
    "bagudas": "bagudo",
    "bagudos": "bagudo",
    "bague": "bagar",
    "baguei": "bagar",
    "bagueis": "bagar",
    "baguem": "bagar",
    "baguemo": "bagar",
    "baguemos": "bagar",
    "bagues": "bagar",
    "baguetes": "baguete",
    "baguinha": "baga",
    "baguinhas": "baga",
    "baguinho": "bago",
    "baguinhos": "bago",
    "baguins": "baguim",
    "baguita": "baga",
    "baguitas": "baga",
    "baguito": "bago",
    "baguitos": "bago",
    "bagulhada": "bagulhado",
    "bagulhadas": "bagulhado",
    "bagulhados": "bagulhado",
    "bagulhenta": "bagulhento",
    "bagulhentas": "bagulhento",
    "bagulhentos": "bagulhento",
    "bagulhos": "bagulho",
    "bagulhosa": "bagulhoso",
    "bagulhosas": "bagulhoso",
    "bagulhosos": "bagulhoso",
    "bagunçadas": "bagunçada",
    "bagunças": "bagunça",
    "bagámo": "bagar",
    "bagámos": "bagar",
    "bagáramo": "bagar",
    "bagáramos": "bagar",
    "bagáreis": "bagar",
    "bagásseis": "bagar",
    "bagássemos": "bagar",
    "bagávamo": "bagar",
    "bagávamos": "bagar",
    "bagáveis": "bagar",
    "baia": "baio",
    "baiada": "baiar",
    "baiadas": "baiar",
    "baiado": "baiar",
    "baiados": "baiar",
    "baiai": "baiar",
    "baiais": "baiar",
    "baiam": "baiar",
    "baiamo": "baiar",
    "baiamos": "baiar",
    "baiana": "baiano",
    "baianas": "baiano",
    "baiando": "baiar",
    "baianismos": "baianismo",
    "baianos": "baiano",
    "baiara": "baiar",
    "baiaram": "baiar",
    "baiaras": "baiar",
    "baiardes": "baiar",
    "baiardos": "baiardo",
    "baiarei": "baiar",
    "baiareis": "baiar",
    "baiarem": "baiar",
    "baiaremos": "baiar",
    "baiares": "baiar",
    "baiaria": "baiar",
    "baiariam": "baiar",
    "baiarias": "baiar",
    "baiarmo": "baiar",
    "baiarmos": "baiar",
    "baiará": "baiar",
    "baiarás": "baiar",
    "baiarão": "baiar",
    "baiaríamos": "baiar",
    "baiaríeis": "baiar",
    "baias": "baio",
    "baiasse": "baiar",
    "baiassem": "baiar",
    "baiasses": "baiar",
    "baiaste": "baiar",
    "baiastes": "baiar",
    "baiava": "baiar",
    "baiavam": "baiar",
    "baiavas": "baiar",
    "baie": "baiar",
    "baiei": "baiar",
    "baieis": "baiar",
    "baiem": "baiar",
    "baiemo": "baiar",
    "baiemos": "baiar",
    "baies": "baiar",
    "baila": "bailar",
    "bailada": "bailar",
    "bailadas": "bailar",
    "bailadeira": "bailador",
    "bailadeiras": "bailador",
    "bailado": "bailar",
    "bailadoiros": "bailadoiro",
    "bailadores": "bailador",
    "bailados": "bailar",
    "bailadouros": "bailadouro",
    "bailai": "bailar",
    "bailais": "bailar",
    "bailam": "bailar",
    "bailamo": "bailar",
    "bailamos": "bailar",
    "bailando": "bailar",
    "bailantes": "bailante",
    "bailara": "bailar",
    "bailaram": "bailar",
    "bailaras": "bailar",
    "bailardes": "bailar",
    "bailarecos": "bailareco",
    "bailarei": "bailar",
    "bailareis": "bailar",
    "bailarem": "bailar",
    "bailaremos": "bailar",
    "bailares": "bailar",
    "bailaria": "bailar",
    "bailariam": "bailar",
    "bailarias": "bailar",
    "bailaricos": "bailarico",
    "bailarina": "bailarino",
    "bailarinas": "bailarino",
    "bailarinos": "bailarino",
    "bailarins": "bailarim",
    "bailariqueiros": "bailariqueiro",
    "bailarmo": "bailar",
    "bailarmos": "bailar",
    "bailará": "bailar",
    "bailarás": "bailar",
    "bailarão": "bailar",
    "bailaríamos": "bailar",
    "bailaríeis": "bailar",
    "bailas": "bailar",
    "bailasse": "bailar",
    "bailassem": "bailar",
    "bailasses": "bailar",
    "bailaste": "bailar",
    "bailastes": "bailar",
    "bailatas": "bailata",
    "bailava": "bailar",
    "bailavam": "bailar",
    "bailavas": "bailar",
    "baile": "bailar",
    "bailei": "bailar",
    "baileis": "bailar",
    "bailem": "bailar",
    "bailemo": "bailar",
    "bailemos": "bailar",
    "bailes": "baile",
    "bailetes": "bailete",
    "bailiados": "bailiado",
    "bailinho": "baile",
    "bailinhos": "baile",
    "bailios": "bailio",
    "bailiques": "bailique",
    "bailito": "baile",
    "bailitos": "baile",
    "bailo": "bailar",
    "bailomanias": "bailomania",
    "bailomaníaca": "bailomaníaco",
    "bailomaníacas": "bailomaníaco",
    "bailomaníacos": "bailomaníaco",
    "bailona": "bailão",
    "bailonas": "bailão",
    "bailou": "bailar",
    "bailunda": "bailundo",
    "bailundas": "bailundo",
    "bailundos": "bailundo",
    "bailámo": "bailar",
    "bailámos": "bailar",
    "bailáramo": "bailar",
    "bailáramos": "bailar",
    "bailáreis": "bailar",
    "bailásseis": "bailar",
    "bailássemos": "bailar",
    "bailávamo": "bailar",
    "bailávamos": "bailar",
    "bailáveis": "bailar",
    "bailéus": "bailéu",
    "bailões": "bailão",
    "bainha": "bainhar",
    "bainhada": "bainhar",
    "bainhadas": "bainhar",
    "bainhado": "bainhar",
    "bainhados": "bainhar",
    "bainhai": "bainhar",
    "bainhais": "bainhar",
    "bainham": "bainhar",
    "bainhamo": "bainhar",
    "bainhamos": "bainhar",
    "bainhando": "bainhar",
    "bainhara": "bainhar",
    "bainharam": "bainhar",
    "bainharas": "bainhar",
    "bainharde": "bainhar",
    "bainhardes": "bainhar",
    "bainhare": "bainhar",
    "bainharei": "bainhar",
    "bainhareis": "bainhar",
    "bainharem": "bainhar",
    "bainharemos": "bainhar",
    "bainhares": "bainhar",
    "bainharia": "bainhar",
    "bainhariam": "bainhar",
    "bainharias": "bainharia",
    "bainharmo": "bainhar",
    "bainharmos": "bainhar",
    "bainhará": "bainhar",
    "bainharás": "bainhar",
    "bainharão": "bainhar",
    "bainharíamos": "bainhar",
    "bainharíeis": "bainhar",
    "bainhas": "bainhar",
    "bainhasse": "bainhar",
    "bainhassem": "bainhar",
    "bainhasses": "bainhar",
    "bainhaste": "bainhar",
    "bainhastes": "bainhar",
    "bainhava": "bainhar",
    "bainhavam": "bainhar",
    "bainhavas": "bainhar",
    "bainhe": "bainhar",
    "bainhei": "bainhar",
    "bainheiros": "bainheiro",
    "bainheis": "bainhar",
    "bainhem": "bainhar",
    "bainhemo": "bainhar",
    "bainhemos": "bainhar",
    "bainhes": "bainhar",
    "bainho": "bainhar",
    "bainhou": "bainhar",
    "bainhá": "bainhar",
    "bainhámo": "bainhar",
    "bainhámos": "bainhar",
    "bainháramo": "bainhar",
    "bainháramos": "bainhar",
    "bainhárei": "bainhar",
    "bainháreis": "bainhar",
    "bainhásseis": "bainhar",
    "bainhássemos": "bainhar",
    "bainhávamo": "bainhar",
    "bainhávamos": "bainhar",
    "bainhávei": "bainhar",
    "bainháveis": "bainhar",
    "baio": "baiar",
    "baiona": "baião",
    "baionas": "baião",
    "baionesa": "baionês",
    "baionesas": "baionês",
    "baioneses": "baionês",
    "baionetadas": "baionetada",
    "baionetas": "baioneta",
    "baionezas": "baioneza",
    "baios": "baio",
    "baiotes": "baiote",
    "baiou": "baiar",
    "bairradina": "bairradino",
    "bairradinas": "bairradino",
    "bairradinos": "bairradino",
    "bairrismos": "bairrismo",
    "bairristas": "bairrista",
    "bairros": "bairro",
    "baitacas": "baitaca",
    "baiucas": "baiuca",
    "baiuqueira": "baiuqueiro",
    "baiuqueiras": "baiuqueiro",
    "baiuqueiros": "baiuqueiro",
    "baixa": "baixo",
    "baixada": "baixar",
    "baixadas": "baixar",
    "baixado": "baixar",
    "baixados": "baixar",
    "baixai": "baixar",
    "baixais": "baixar",
    "baixam": "baixar",
    "baixamo": "baixar",
    "baixamos": "baixar",
    "baixando": "baixar",
    "baixantes": "baixante",
    "baixara": "baixar",
    "baixaram": "baixar",
    "baixaras": "baixar",
    "baixarde": "baixar",
    "baixardes": "baixar",
    "baixare": "baixar",
    "baixarei": "baixar",
    "baixareis": "baixar",
    "baixarem": "baixar",
    "baixaremos": "baixar",
    "baixares": "baixar",
    "baixaria": "baixar",
    "baixariam": "baixar",
    "baixarias": "baixar",
    "baixarmo": "baixar",
    "baixarmos": "baixar",
    "baixará": "baixar",
    "baixarás": "baixar",
    "baixarão": "baixar",
    "baixaríamos": "baixar",
    "baixaríeis": "baixar",
    "baixas": "baixo",
    "baixasse": "baixar",
    "baixassem": "baixar",
    "baixasses": "baixar",
    "baixaste": "baixar",
    "baixastes": "baixar",
    "baixava": "baixar",
    "baixavam": "baixar",
    "baixavas": "baixar",
    "baixe": "baixar",
    "baixei": "baixar",
    "baixeis": "baixar",
    "baixelas": "baixela",
    "baixem": "baixar",
    "baixemo": "baixar",
    "baixemos": "baixar",
    "baixes": "baixar",
    "baixetes": "baixete",
    "baixezas": "baixeza",
    "baixias": "baixia",
    "baixinha": "baixo",
    "baixinhas": "baixo",
    "baixinho": "baixo",
    "baixinhos": "baixo",
    "baixios": "baixio",
    "baixistas": "baixista",
    "baixita": "baixo",
    "baixitas": "baixo",
    "baixito": "baixo",
    "baixitos": "baixo",
    "baixo": "baixar",
    "baixos": "baixo",
    "baixota": "baixote",
    "baixotas": "baixote",
    "baixotes": "baixote",
    "baixou": "baixar",
    "baixuras": "baixura",
    "baixá": "baixar",
    "baixámo": "baixar",
    "baixámos": "baixar",
    "baixáramo": "baixar",
    "baixáramos": "baixar",
    "baixárei": "baixar",
    "baixáreis": "baixar",
    "baixásseis": "baixar",
    "baixássemos": "baixar",
    "baixávamo": "baixar",
    "baixávamos": "baixar",
    "baixávei": "baixar",
    "baixáveis": "baixável",
    "baixéis": "baixel",
    "baixíssima": "baixo",
    "baixíssimas": "baixo",
    "baixíssimo": "baixo",
    "baixíssimos": "baixo",
    "baixões": "baixão",
    "baiámo": "baiar",
    "baiámos": "baiar",
    "baiáramo": "baiar",
    "baiáramos": "baiar",
    "baiáreis": "baiar",
    "baiásseis": "baiar",
    "baiássemos": "baiar",
    "baiávamo": "baiar",
    "baiávamos": "baiar",
    "baiáveis": "baiar",
    "baiões": "baião",
    "bajouja": "bajoujo",
    "bajoujada": "bajoujar",
    "bajoujadas": "bajoujar",
    "bajoujado": "bajoujar",
    "bajoujados": "bajoujar",
    "bajoujai": "bajoujar",
    "bajoujais": "bajoujar",
    "bajoujam": "bajoujar",
    "bajoujamo": "bajoujar",
    "bajoujamos": "bajoujar",
    "bajoujando": "bajoujar",
    "bajoujara": "bajoujar",
    "bajoujaram": "bajoujar",
    "bajoujaras": "bajoujar",
    "bajoujarde": "bajoujar",
    "bajoujardes": "bajoujar",
    "bajoujare": "bajoujar",
    "bajoujarei": "bajoujar",
    "bajoujareis": "bajoujar",
    "bajoujarem": "bajoujar",
    "bajoujaremos": "bajoujar",
    "bajoujares": "bajoujar",
    "bajoujaria": "bajoujar",
    "bajoujariam": "bajoujar",
    "bajoujarias": "bajoujar",
    "bajoujarmo": "bajoujar",
    "bajoujarmos": "bajoujar",
    "bajoujará": "bajoujar",
    "bajoujarás": "bajoujar",
    "bajoujarão": "bajoujar",
    "bajoujaríamos": "bajoujar",
    "bajoujaríeis": "bajoujar",
    "bajoujas": "bajoujo",
    "bajoujasse": "bajoujar",
    "bajoujassem": "bajoujar",
    "bajoujasses": "bajoujar",
    "bajoujaste": "bajoujar",
    "bajoujastes": "bajoujar",
    "bajoujava": "bajoujar",
    "bajoujavam": "bajoujar",
    "bajoujavas": "bajoujar",
    "bajouje": "bajoujar",
    "bajoujei": "bajoujar",
    "bajoujeis": "bajoujar",
    "bajoujem": "bajoujar",
    "bajoujemo": "bajoujar",
    "bajoujemos": "bajoujar",
    "bajoujes": "bajoujar",
    "bajoujices": "bajoujice",
    "bajoujo": "bajoujar",
    "bajoujos": "bajoujo",
    "bajoujou": "bajoujar",
    "bajoujá": "bajoujar",
    "bajoujámo": "bajoujar",
    "bajoujámos": "bajoujar",
    "bajoujáramo": "bajoujar",
    "bajoujáramos": "bajoujar",
    "bajoujárei": "bajoujar",
    "bajoujáreis": "bajoujar",
    "bajoujásseis": "bajoujar",
    "bajoujássemos": "bajoujar",
    "bajoujávamo": "bajoujar",
    "bajoujávamos": "bajoujar",
    "bajoujávei": "bajoujar",
    "bajoujáveis": "bajoujar",
    "bajula": "bajular",
    "bajulada": "bajular",
    "bajuladas": "bajular",
    "bajulado": "bajular",
    "bajuladora": "bajulador",
    "bajuladoras": "bajulador",
    "bajuladores": "bajulador",
    "bajulados": "bajular",
    "bajulai": "bajular",
    "bajulais": "bajular",
    "bajulam": "bajular",
    "bajulamo": "bajular",
    "bajulamos": "bajular",
    "bajulando": "bajular",
    "bajulara": "bajular",
    "bajularam": "bajular",
    "bajularas": "bajular",
    "bajularde": "bajular",
    "bajulardes": "bajular",
    "bajulare": "bajular",
    "bajularei": "bajular",
    "bajulareis": "bajular",
    "bajularem": "bajular",
    "bajularemos": "bajular",
    "bajulares": "bajular",
    "bajularia": "bajular",
    "bajulariam": "bajular",
    "bajularias": "bajular",
    "bajularmo": "bajular",
    "bajularmos": "bajular",
    "bajulará": "bajular",
    "bajularás": "bajular",
    "bajularão": "bajular",
    "bajularíamos": "bajular",
    "bajularíeis": "bajular",
    "bajulas": "bajular",
    "bajulasse": "bajular",
    "bajulassem": "bajular",
    "bajulasses": "bajular",
    "bajulaste": "bajular",
    "bajulastes": "bajular",
    "bajulatória": "bajulatório",
    "bajulatórias": "bajulatório",
    "bajulatórios": "bajulatório",
    "bajulava": "bajular",
    "bajulavam": "bajular",
    "bajulavas": "bajular",
    "bajulações": "bajulação",
    "bajule": "bajular",
    "bajulei": "bajular",
    "bajuleis": "bajular",
    "bajulem": "bajular",
    "bajulemo": "bajular",
    "bajulemos": "bajular",
    "bajules": "bajular",
    "bajulices": "bajulice",
    "bajulismos": "bajulismo",
    "bajulo": "bajular",
    "bajulou": "bajular",
    "bajulá": "bajular",
    "bajulámo": "bajular",
    "bajulámos": "bajular",
    "bajuláramo": "bajular",
    "bajuláramos": "bajular",
    "bajulárei": "bajular",
    "bajuláreis": "bajular",
    "bajulásseis": "bajular",
    "bajulássemos": "bajular",
    "bajulávamo": "bajular",
    "bajulávamos": "bajular",
    "bajulávei": "bajular",
    "bajuláveis": "bajular",
    "bala": "balir",
    "balaches": "balache",
    "balada": "balar",
    "baladas": "balar",
    "baladeira": "baladeiro",
    "baladeiras": "baladeiro",
    "baladeiros": "baladeiro",
    "balado": "balar",
    "baladora": "balador",
    "baladoras": "balador",
    "baladores": "balador",
    "balados": "balar",
    "balai": "balar",
    "balaiadas": "balaiada",
    "balais": "balir",
    "balalaicas": "balalaica",
    "balam": "balir",
    "balamentos": "balamento",
    "balames": "balame",
    "balamo": "balir",
    "balamos": "balir",
    "balance": "balançar",
    "balanceada": "balancear",
    "balanceadas": "balancear",
    "balanceado": "balancear",
    "balanceados": "balancear",
    "balanceai": "balancear",
    "balanceais": "balancear",
    "balanceamentos": "balanceamento",
    "balanceamo": "balancear",
    "balanceamos": "balancear",
    "balanceando": "balancear",
    "balanceara": "balancear",
    "balancearam": "balancear",
    "balancearas": "balancear",
    "balancearde": "balancear",
    "balanceardes": "balancear",
    "balanceare": "balancear",
    "balancearei": "balancear",
    "balanceareis": "balancear",
    "balancearem": "balancear",
    "balancearemos": "balancear",
    "balanceares": "balancear",
    "balancearia": "balancear",
    "balanceariam": "balancear",
    "balancearias": "balancear",
    "balancearmo": "balancear",
    "balancearmos": "balancear",
    "balanceará": "balancear",
    "balancearás": "balancear",
    "balancearão": "balancear",
    "balancearíamos": "balancear",
    "balancearíeis": "balancear",
    "balanceasse": "balancear",
    "balanceassem": "balancear",
    "balanceasses": "balancear",
    "balanceaste": "balancear",
    "balanceastes": "balancear",
    "balanceava": "balancear",
    "balanceavam": "balancear",
    "balanceavas": "balancear",
    "balanceei": "balancear",
    "balanceeis": "balancear",
    "balanceemo": "balancear",
    "balanceemos": "balancear",
    "balancei": "balançar",
    "balanceia": "balancear",
    "balanceiam": "balancear",
    "balanceias": "balancear",
    "balanceie": "balancear",
    "balanceiem": "balancear",
    "balanceies": "balancear",
    "balanceio": "balancear",
    "balanceiros": "balanceiro",
    "balanceis": "balançar",
    "balancem": "balançar",
    "balancemo": "balançar",
    "balancemos": "balançar",
    "balanceou": "balancear",
    "balances": "balançar",
    "balancetes": "balancete",
    "balanceá": "balancear",
    "balanceámo": "balancear",
    "balanceámos": "balancear",
    "balanceáramo": "balancear",
    "balanceáramos": "balancear",
    "balanceárei": "balancear",
    "balanceáreis": "balancear",
    "balanceásseis": "balancear",
    "balanceássemos": "balancear",
    "balanceávamo": "balancear",
    "balanceávamos": "balancear",
    "balanceávei": "balancear",
    "balanceáveis": "balancear",
    "balancins": "balancim",
    "balancistas": "balancista",
    "balancos": "balanco",
    "balancés": "balancé",
    "balando": "balar",
    "balandras": "balandra",
    "balandraus": "balandrau",
    "balangandãs": "balangandã",
    "balanites": "balanite",
    "balanorragias": "balanorragia",
    "balanorréias": "balanorréia",
    "balanquinhos": "balanquinho",
    "balantas": "balanta",
    "balantes": "balante",
    "balantidiana": "balantidiano",
    "balantidianas": "balantidiano",
    "balantidianos": "balantidiano",
    "balantidioses": "balantidiose",
    "balantidíases": "balantidíase",
    "balantídea": "balantídeo",
    "balantídeas": "balantídeo",
    "balantídeos": "balantídeo",
    "balantídica": "balantídico",
    "balantídicas": "balantídico",
    "balantídicos": "balantídico",
    "balança": "balançar",
    "balançada": "balançar",
    "balançadas": "balançar",
    "balançado": "balançar",
    "balançados": "balançar",
    "balançai": "balançar",
    "balançais": "balançar",
    "balançam": "balançar",
    "balançamo": "balançar",
    "balançamos": "balançar",
    "balançando": "balançar",
    "balançara": "balançar",
    "balançaram": "balançar",
    "balançaras": "balançar",
    "balançarde": "balançar",
    "balançardes": "balançar",
    "balançare": "balançar",
    "balançarei": "balançar",
    "balançareis": "balançar",
    "balançarem": "balançar",
    "balançaremos": "balançar",
    "balançares": "balançar",
    "balançaria": "balançar",
    "balançariam": "balançar",
    "balançarias": "balançar",
    "balançarmo": "balançar",
    "balançarmos": "balançar",
    "balançará": "balançar",
    "balançarás": "balançar",
    "balançarão": "balançar",
    "balançaríamos": "balançar",
    "balançaríeis": "balançar",
    "balanças": "balançar",
    "balançasse": "balançar",
    "balançassem": "balançar",
    "balançasses": "balançar",
    "balançaste": "balançar",
    "balançastes": "balançar",
    "balançava": "balançar",
    "balançavam": "balançar",
    "balançavas": "balançar",
    "balanço": "balançar",
    "balanços": "balanço",
    "balançou": "balançar",
    "balançá": "balançar",
    "balançámo": "balançar",
    "balançámos": "balançar",
    "balançáramo": "balançar",
    "balançáramos": "balançar",
    "balançárei": "balançar",
    "balançáreis": "balançar",
    "balançásseis": "balançar",
    "balançássemos": "balançar",
    "balançávamo": "balançar",
    "balançávamos": "balançar",
    "balançávei": "balançar",
    "balançáveis": "balançar",
    "balanífera": "balanífero",
    "balaníferas": "balanífero",
    "balaníferos": "balanífero",
    "balanófaga": "balanófago",
    "balanófagas": "balanófago",
    "balanófagos": "balanófago",
    "balanófora": "balanóforo",
    "balanóforas": "balanóforo",
    "balanóforos": "balanóforo",
    "balanóides": "balanóide",
    "balara": "balar",
    "balaram": "balar",
    "balaras": "balar",
    "balardes": "balar",
    "balarei": "balar",
    "balareis": "balar",
    "balarem": "balar",
    "balaremos": "balar",
    "balares": "balar",
    "balaria": "balar",
    "balariam": "balar",
    "balarias": "balar",
    "balarmo": "balar",
    "balarmos": "balar",
    "balará": "balar",
    "balarás": "balar",
    "balarão": "balar",
    "balaríamos": "balar",
    "balaríeis": "balar",
    "balas": "balir",
    "balasse": "balar",
    "balassem": "balar",
    "balasses": "balar",
    "balaste": "balar",
    "balastes": "balar",
    "balastra": "balastrar",
    "balastrada": "balastrar",
    "balastradas": "balastrar",
    "balastrado": "balastrar",
    "balastrados": "balastrar",
    "balastragens": "balastragem",
    "balastrai": "balastrar",
    "balastrais": "balastrar",
    "balastram": "balastrar",
    "balastramo": "balastrar",
    "balastramos": "balastrar",
    "balastrando": "balastrar",
    "balastrara": "balastrar",
    "balastraram": "balastrar",
    "balastraras": "balastrar",
    "balastrarde": "balastrar",
    "balastrardes": "balastrar",
    "balastrare": "balastrar",
    "balastrarei": "balastrar",
    "balastrareis": "balastrar",
    "balastrarem": "balastrar",
    "balastraremos": "balastrar",
    "balastrares": "balastrar",
    "balastraria": "balastrar",
    "balastrariam": "balastrar",
    "balastrarias": "balastrar",
    "balastrarmo": "balastrar",
    "balastrarmos": "balastrar",
    "balastrará": "balastrar",
    "balastrarás": "balastrar",
    "balastrarão": "balastrar",
    "balastraríamos": "balastrar",
    "balastraríeis": "balastrar",
    "balastras": "balastrar",
    "balastrasse": "balastrar",
    "balastrassem": "balastrar",
    "balastrasses": "balastrar",
    "balastraste": "balastrar",
    "balastrastes": "balastrar",
    "balastrava": "balastrar",
    "balastravam": "balastrar",
    "balastravas": "balastrar",
    "balastre": "balastrar",
    "balastrei": "balastrar",
    "balastreiras": "balastreira",
    "balastreis": "balastrar",
    "balastrem": "balastrar",
    "balastremo": "balastrar",
    "balastremos": "balastrar",
    "balastres": "balastrar",
    "balastro": "balastrar",
    "balastros": "balastro",
    "balastrou": "balastrar",
    "balastrá": "balastrar",
    "balastrámo": "balastrar",
    "balastrámos": "balastrar",
    "balastráramo": "balastrar",
    "balastráramos": "balastrar",
    "balastrárei": "balastrar",
    "balastráreis": "balastrar",
    "balastrásseis": "balastrar",
    "balastrássemos": "balastrar",
    "balastrávamo": "balastrar",
    "balastrávamos": "balastrar",
    "balastrávei": "balastrar",
    "balastráveis": "balastrar",
    "balatais": "balatal",
    "balatas": "balata",
    "balateiros": "balateiro",
    "balaustra": "balaustrar",
    "balaustrada": "balaustrar",
    "balaustradas": "balaustrar",
    "balaustrado": "balaustrar",
    "balaustrados": "balaustrar",
    "balaustrai": "balaustrar",
    "balaustrais": "balaustrar",
    "balaustram": "balaustrar",
    "balaustramo": "balaustrar",
    "balaustramos": "balaustrar",
    "balaustrando": "balaustrar",
    "balaustrara": "balaustrar",
    "balaustraram": "balaustrar",
    "balaustraras": "balaustrar",
    "balaustrarde": "balaustrar",
    "balaustrardes": "balaustrar",
    "balaustrare": "balaustrar",
    "balaustrarei": "balaustrar",
    "balaustrareis": "balaustrar",
    "balaustrarem": "balaustrar",
    "balaustraremos": "balaustrar",
    "balaustrares": "balaustrar",
    "balaustraria": "balaustrar",
    "balaustrariam": "balaustrar",
    "balaustrarias": "balaustrar",
    "balaustrarmo": "balaustrar",
    "balaustrarmos": "balaustrar",
    "balaustrará": "balaustrar",
    "balaustrarás": "balaustrar",
    "balaustrarão": "balaustrar",
    "balaustraríamos": "balaustrar",
    "balaustraríeis": "balaustrar",
    "balaustras": "balaustrar",
    "balaustrasse": "balaustrar",
    "balaustrassem": "balaustrar",
    "balaustrasses": "balaustrar",
    "balaustraste": "balaustrar",
    "balaustrastes": "balaustrar",
    "balaustrava": "balaustrar",
    "balaustravam": "balaustrar",
    "balaustravas": "balaustrar",
    "balaustre": "balaustrar",
    "balaustrei": "balaustrar",
    "balaustreis": "balaustrar",
    "balaustrem": "balaustrar",
    "balaustremo": "balaustrar",
    "balaustremos": "balaustrar",
    "balaustres": "balaustrar",
    "balaustro": "balaustrar",
    "balaustrou": "balaustrar",
    "balaustrá": "balaustrar",
    "balaustrámo": "balaustrar",
    "balaustrámos": "balaustrar",
    "balaustráramo": "balaustrar",
    "balaustráramos": "balaustrar",
    "balaustrárei": "balaustrar",
    "balaustráreis": "balaustrar",
    "balaustrásseis": "balaustrar",
    "balaustrássemos": "balaustrar",
    "balaustrávamo": "balaustrar",
    "balaustrávamos": "balaustrar",
    "balaustrávei": "balaustrar",
    "balaustráveis": "balaustrar",
    "balava": "balar",
    "balavam": "balar",
    "balavas": "balar",
    "balazinha": "bala",
    "balazinhas": "bala",
    "balazita": "bala",
    "balazitas": "bala",
    "balaços": "balaço",
    "balaústas": "balaústa",
    "balaústes": "balaúste",
    "balaústos": "balaústo",
    "balaústres": "balaústre",
    "balba": "balbo",
    "balbas": "balbo",
    "balboas": "balboa",
    "balbordas": "balborda",
    "balbos": "balbo",
    "balbucia": "balbuciar",
    "balbuciada": "balbuciar",
    "balbuciadas": "balbuciar",
    "balbuciadeiras": "balbuciadeira",
    "balbuciado": "balbuciar",
    "balbuciados": "balbuciar",
    "balbuciai": "balbuciar",
    "balbuciais": "balbuciar",
    "balbuciam": "balbuciar",
    "balbuciamentos": "balbuciamento",
    "balbuciamo": "balbuciar",
    "balbuciamos": "balbuciar",
    "balbuciando": "balbuciar",
    "balbuciantes": "balbuciante",
    "balbuciara": "balbuciar",
    "balbuciaram": "balbuciar",
    "balbuciaras": "balbuciar",
    "balbuciarde": "balbuciar",
    "balbuciardes": "balbuciar",
    "balbuciare": "balbuciar",
    "balbuciarei": "balbuciar",
    "balbuciareis": "balbuciar",
    "balbuciarem": "balbuciar",
    "balbuciaremos": "balbuciar",
    "balbuciares": "balbuciar",
    "balbuciaria": "balbuciar",
    "balbuciariam": "balbuciar",
    "balbuciarias": "balbuciar",
    "balbuciarmo": "balbuciar",
    "balbuciarmos": "balbuciar",
    "balbuciará": "balbuciar",
    "balbuciarás": "balbuciar",
    "balbuciarão": "balbuciar",
    "balbuciaríamos": "balbuciar",
    "balbuciaríeis": "balbuciar",
    "balbucias": "balbuciar",
    "balbuciasse": "balbuciar",
    "balbuciassem": "balbuciar",
    "balbuciasses": "balbuciar",
    "balbuciaste": "balbuciar",
    "balbuciastes": "balbuciar",
    "balbuciava": "balbuciar",
    "balbuciavam": "balbuciar",
    "balbuciavas": "balbuciar",
    "balbuciações": "balbuciação",
    "balbucie": "balbuciar",
    "balbuciei": "balbuciar",
    "balbucieis": "balbuciar",
    "balbuciem": "balbuciar",
    "balbuciemo": "balbuciar",
    "balbuciemos": "balbuciar",
    "balbucientes": "balbuciente",
    "balbucies": "balbuciar",
    "balbucio": "balbuciar",
    "balbuciou": "balbuciar",
    "balbuciá": "balbuciar",
    "balbuciámo": "balbuciar",
    "balbuciámos": "balbuciar",
    "balbuciáramo": "balbuciar",
    "balbuciáramos": "balbuciar",
    "balbuciárei": "balbuciar",
    "balbuciáreis": "balbuciar",
    "balbuciásseis": "balbuciar",
    "balbuciássemos": "balbuciar",
    "balbuciávamo": "balbuciar",
    "balbuciávamos": "balbuciar",
    "balbuciávei": "balbuciar",
    "balbuciáveis": "balbuciável",
    "balbuciências": "balbuciência",
    "balburdia": "balburdiar",
    "balburdiada": "balburdiar",
    "balburdiadas": "balburdiar",
    "balburdiado": "balburdiar",
    "balburdiados": "balburdiar",
    "balburdiai": "balburdiar",
    "balburdiais": "balburdiar",
    "balburdiam": "balburdiar",
    "balburdiamo": "balburdiar",
    "balburdiamos": "balburdiar",
    "balburdiando": "balburdiar",
    "balburdiara": "balburdiar",
    "balburdiaram": "balburdiar",
    "balburdiaras": "balburdiar",
    "balburdiarde": "balburdiar",
    "balburdiardes": "balburdiar",
    "balburdiare": "balburdiar",
    "balburdiarei": "balburdiar",
    "balburdiareis": "balburdiar",
    "balburdiarem": "balburdiar",
    "balburdiaremos": "balburdiar",
    "balburdiares": "balburdiar",
    "balburdiaria": "balburdiar",
    "balburdiariam": "balburdiar",
    "balburdiarias": "balburdiar",
    "balburdiarmo": "balburdiar",
    "balburdiarmos": "balburdiar",
    "balburdiará": "balburdiar",
    "balburdiarás": "balburdiar",
    "balburdiarão": "balburdiar",
    "balburdiaríamos": "balburdiar",
    "balburdiaríeis": "balburdiar",
    "balburdias": "balburdiar",
    "balburdiasse": "balburdiar",
    "balburdiassem": "balburdiar",
    "balburdiasses": "balburdiar",
    "balburdiaste": "balburdiar",
    "balburdiastes": "balburdiar",
    "balburdiava": "balburdiar",
    "balburdiavam": "balburdiar",
    "balburdiavas": "balburdiar",
    "balburdie": "balburdiar",
    "balburdiei": "balburdiar",
    "balburdieis": "balburdiar",
    "balburdiem": "balburdiar",
    "balburdiemo": "balburdiar",
    "balburdiemos": "balburdiar",
    "balburdies": "balburdiar",
    "balburdio": "balburdiar",
    "balburdiou": "balburdiar",
    "balburdiá": "balburdiar",
    "balburdiámo": "balburdiar",
    "balburdiámos": "balburdiar",
    "balburdiáramo": "balburdiar",
    "balburdiáramos": "balburdiar",
    "balburdiárei": "balburdiar",
    "balburdiáreis": "balburdiar",
    "balburdiásseis": "balburdiar",
    "balburdiássemos": "balburdiar",
    "balburdiávamo": "balburdiar",
    "balburdiávamos": "balburdiar",
    "balburdiávei": "balburdiar",
    "balburdiáveis": "balburdiar",
    "balbúcies": "balbúcie",
    "balbúcios": "balbúcio",
    "balbúrdias": "balbúrdia",
    "balcanizações": "balcanização",
    "balceira": "balceiro",
    "balceiras": "balceiro",
    "balceiros": "balceiro",
    "balcânica": "balcânico",
    "balcânicas": "balcânico",
    "balcânicos": "balcânico",
    "balcões": "balcão",
    "balda": "baldo",
    "baldada": "baldar",
    "baldadas": "baldar",
    "baldado": "baldar",
    "baldados": "baldar",
    "baldai": "baldar",
    "baldais": "baldar",
    "baldam": "baldar",
    "baldamo": "baldar",
    "baldamos": "baldar",
    "baldando": "baldar",
    "baldaquinos": "baldaquino",
    "baldaquins": "baldaquim",
    "baldara": "baldar",
    "baldaram": "baldar",
    "baldaras": "baldar",
    "baldarde": "baldar",
    "baldardes": "baldar",
    "baldare": "baldar",
    "baldarei": "baldar",
    "baldareis": "baldar",
    "baldarem": "baldar",
    "baldaremos": "baldar",
    "baldares": "baldar",
    "baldaria": "baldar",
    "baldariam": "baldar",
    "baldarias": "baldar",
    "baldarmo": "baldar",
    "baldarmos": "baldar",
    "baldará": "baldar",
    "baldarás": "baldar",
    "baldarão": "baldar",
    "baldaríamos": "baldar",
    "baldaríeis": "baldar",
    "baldas": "baldo",
    "baldasse": "baldar",
    "baldassem": "baldar",
    "baldasses": "baldar",
    "baldaste": "baldar",
    "baldastes": "baldar",
    "baldava": "baldar",
    "baldavam": "baldar",
    "baldavas": "baldar",
    "balde": "baldar",
    "baldeada": "baldear",
    "baldeadas": "baldear",
    "baldeado": "baldear",
    "baldeadora": "baldeador",
    "baldeadoras": "baldeador",
    "baldeadores": "baldeador",
    "baldeados": "baldear",
    "baldeai": "baldear",
    "baldeais": "baldear",
    "baldeamentos": "baldeamento",
    "baldeamo": "baldear",
    "baldeamos": "baldear",
    "baldeando": "baldear",
    "baldeara": "baldear",
    "baldearam": "baldear",
    "baldearas": "baldear",
    "baldearde": "baldear",
    "baldeardes": "baldear",
    "baldeare": "baldear",
    "baldearei": "baldear",
    "baldeareis": "baldear",
    "baldearem": "baldear",
    "baldearemos": "baldear",
    "baldeares": "baldear",
    "baldearia": "baldear",
    "baldeariam": "baldear",
    "baldearias": "baldear",
    "baldearmo": "baldear",
    "baldearmos": "baldear",
    "baldeará": "baldear",
    "baldearás": "baldear",
    "baldearão": "baldear",
    "baldearíamos": "baldear",
    "baldearíeis": "baldear",
    "baldeasse": "baldear",
    "baldeassem": "baldear",
    "baldeasses": "baldear",
    "baldeaste": "baldear",
    "baldeastes": "baldear",
    "baldeava": "baldear",
    "baldeavam": "baldear",
    "baldeavas": "baldear",
    "baldeações": "baldeação",
    "baldeei": "baldear",
    "baldeeis": "baldear",
    "baldeemo": "baldear",
    "baldeemos": "baldear",
    "baldei": "baldar",
    "baldeia": "baldear",
    "baldeiam": "baldear",
    "baldeias": "baldear",
    "baldeie": "baldear",
    "baldeiem": "baldear",
    "baldeies": "baldear",
    "baldeio": "baldear",
    "baldeis": "baldar",
    "baldem": "baldar",
    "baldemo": "baldar",
    "baldemos": "baldar",
    "baldeonas": "baldeona",
    "baldeou": "baldear",
    "baldes": "balde",
    "baldeá": "baldear",
    "baldeámo": "baldear",
    "baldeámos": "baldear",
    "baldeáramo": "baldear",
    "baldeáramos": "baldear",
    "baldeárei": "baldear",
    "baldeáreis": "baldear",
    "baldeásseis": "baldear",
    "baldeássemos": "baldear",
    "baldeávamo": "baldear",
    "baldeávamos": "baldear",
    "baldeávei": "baldear",
    "baldeáveis": "baldear",
    "baldios": "baldio",
    "baldo": "baldar",
    "baldoa": "baldoar",
    "baldoada": "baldoar",
    "baldoadas": "baldoar",
    "baldoado": "baldoar",
    "baldoados": "baldoar",
    "baldoai": "baldoar",
    "baldoais": "baldoar",
    "baldoam": "baldoar",
    "baldoamo": "baldoar",
    "baldoamos": "baldoar",
    "baldoando": "baldoar",
    "baldoara": "baldoar",
    "baldoaram": "baldoar",
    "baldoaras": "baldoar",
    "baldoarde": "baldoar",
    "baldoardes": "baldoar",
    "baldoare": "baldoar",
    "baldoarei": "baldoar",
    "baldoareis": "baldoar",
    "baldoarem": "baldoar",
    "baldoaremos": "baldoar",
    "baldoares": "baldoar",
    "baldoaria": "baldoar",
    "baldoariam": "baldoar",
    "baldoarias": "baldoar",
    "baldoarmo": "baldoar",
    "baldoarmos": "baldoar",
    "baldoará": "baldoar",
    "baldoarás": "baldoar",
    "baldoarão": "baldoar",
    "baldoaríamos": "baldoar",
    "baldoaríeis": "baldoar",
    "baldoas": "baldoar",
    "baldoasse": "baldoar",
    "baldoassem": "baldoar",
    "baldoasses": "baldoar",
    "baldoaste": "baldoar",
    "baldoastes": "baldoar",
    "baldoava": "baldoar",
    "baldoavam": "baldoar",
    "baldoavas": "baldoar",
    "baldoe": "baldoar",
    "baldoei": "baldoar",
    "baldoeiras": "baldoeira",
    "baldoeiros": "baldoeiro",
    "baldoeis": "baldoar",
    "baldoem": "baldoar",
    "baldoemo": "baldoar",
    "baldoemos": "baldoar",
    "baldoes": "baldoar",
    "baldona": "baldão",
    "baldonas": "baldão",
    "baldoo": "baldoar",
    "baldoou": "baldoar",
    "baldos": "baldo",
    "baldosas": "baldosa",
    "baldou": "baldar",
    "baldoá": "baldoar",
    "baldoámo": "baldoar",
    "baldoámos": "baldoar",
    "baldoáramo": "baldoar",
    "baldoáramos": "baldoar",
    "baldoárei": "baldoar",
    "baldoáreis": "baldoar",
    "baldoásseis": "baldoar",
    "baldoássemos": "baldoar",
    "baldoávamo": "baldoar",
    "baldoávamos": "baldoar",
    "baldoávei": "baldoar",
    "baldoáveis": "baldoar",
    "baldroca": "baldrocar",
    "baldrocada": "baldrocar",
    "baldrocadas": "baldrocar",
    "baldrocado": "baldrocar",
    "baldrocados": "baldrocar",
    "baldrocai": "baldrocar",
    "baldrocais": "baldrocar",
    "baldrocam": "baldrocar",
    "baldrocamo": "baldrocar",
    "baldrocamos": "baldrocar",
    "baldrocando": "baldrocar",
    "baldrocara": "baldrocar",
    "baldrocaram": "baldrocar",
    "baldrocaras": "baldrocar",
    "baldrocarde": "baldrocar",
    "baldrocardes": "baldrocar",
    "baldrocare": "baldrocar",
    "baldrocarei": "baldrocar",
    "baldrocareis": "baldrocar",
    "baldrocarem": "baldrocar",
    "baldrocaremos": "baldrocar",
    "baldrocares": "baldrocar",
    "baldrocaria": "baldrocar",
    "baldrocariam": "baldrocar",
    "baldrocarias": "baldrocar",
    "baldrocarmo": "baldrocar",
    "baldrocarmos": "baldrocar",
    "baldrocará": "baldrocar",
    "baldrocarás": "baldrocar",
    "baldrocarão": "baldrocar",
    "baldrocaríamos": "baldrocar",
    "baldrocaríeis": "baldrocar",
    "baldrocas": "baldrocar",
    "baldrocasse": "baldrocar",
    "baldrocassem": "baldrocar",
    "baldrocasses": "baldrocar",
    "baldrocaste": "baldrocar",
    "baldrocastes": "baldrocar",
    "baldrocava": "baldrocar",
    "baldrocavam": "baldrocar",
    "baldrocavas": "baldrocar",
    "baldroco": "baldrocar",
    "baldrocou": "baldrocar",
    "baldrocá": "baldrocar",
    "baldrocámo": "baldrocar",
    "baldrocámos": "baldrocar",
    "baldrocáramo": "baldrocar",
    "baldrocáramos": "baldrocar",
    "baldrocárei": "baldrocar",
    "baldrocáreis": "baldrocar",
    "baldrocásseis": "baldrocar",
    "baldrocássemos": "baldrocar",
    "baldrocávamo": "baldrocar",
    "baldrocávamos": "baldrocar",
    "baldrocávei": "baldrocar",
    "baldrocáveis": "baldrocar",
    "baldrogueira": "baldrogueiro",
    "baldrogueiras": "baldrogueiro",
    "baldrogueiros": "baldrogueiro",
    "baldroque": "baldrocar",
    "baldroquei": "baldrocar",
    "baldroqueira": "baldroqueiro",
    "baldroqueiras": "baldroqueiro",
    "baldroqueiros": "baldroqueiro",
    "baldroqueis": "baldrocar",
    "baldroquem": "baldrocar",
    "baldroquemo": "baldrocar",
    "baldroquemos": "baldrocar",
    "baldroques": "baldrocar",
    "baldréus": "baldréu",
    "baldá": "baldar",
    "baldámo": "baldar",
    "baldámos": "baldar",
    "baldáramo": "baldar",
    "baldáramos": "baldar",
    "baldárei": "baldar",
    "baldáreis": "baldar",
    "baldásseis": "baldar",
    "baldássemos": "baldar",
    "baldávamo": "baldar",
    "baldávamos": "baldar",
    "baldávei": "baldar",
    "baldáveis": "baldar",
    "baldões": "baldão",
    "bale": "balir",
    "baleada": "balear",
    "baleadas": "balear",
    "baleado": "balear",
    "baleados": "balear",
    "baleai": "balear",
    "baleais": "balear",
    "baleamentos": "baleamento",
    "baleamo": "balear",
    "baleamos": "balear",
    "baleando": "balear",
    "baleara": "balear",
    "balearam": "balear",
    "balearas": "balear",
    "balearde": "balear",
    "baleardes": "balear",
    "baleare": "balear",
    "balearei": "balear",
    "baleareis": "balear",
    "balearem": "balear",
    "balearemos": "balear",
    "baleares": "balear",
    "balearia": "balear",
    "baleariam": "balear",
    "balearias": "balear",
    "balearmo": "balear",
    "balearmos": "balear",
    "baleará": "balear",
    "balearás": "balear",
    "balearão": "balear",
    "balearíamos": "balear",
    "balearíeis": "balear",
    "baleasse": "balear",
    "baleassem": "balear",
    "baleasses": "balear",
    "baleaste": "balear",
    "baleastes": "balear",
    "baleatos": "baleato",
    "baleava": "balear",
    "baleavam": "balear",
    "baleavas": "balear",
    "baleações": "baleação",
    "baleei": "balear",
    "baleeiras": "baleeira",
    "baleeiros": "baleeiro",
    "baleeis": "balear",
    "baleemo": "balear",
    "baleemos": "balear",
    "balei": "balar",
    "baleia": "balear",
    "baleiam": "balear",
    "baleias": "baleia",
    "baleie": "balear",
    "baleiem": "balear",
    "baleies": "balear",
    "baleio": "balear",
    "baleis": "balar",
    "balelas": "balela",
    "balem": "balir",
    "balemo": "balar",
    "balemos": "balar",
    "balenopterídea": "balenopterídeo",
    "balenopterídeas": "balenopterídeo",
    "balenopterídeos": "balenopterídeo",
    "balenoptéridas": "balenoptérida",
    "baleotas": "baleota",
    "baleotes": "baleote",
    "baleou": "balear",
    "bales": "balir",
    "balestilhas": "balestilha",
    "balestras": "balestra",
    "balestreiros": "balestreiro",
    "baleá": "balear",
    "baleámo": "balear",
    "baleámos": "balear",
    "baleáramo": "balear",
    "baleáramos": "balear",
    "baleárei": "balear",
    "baleáreis": "balear",
    "baleásseis": "balear",
    "baleássemos": "balear",
    "baleávamo": "balear",
    "baleávamos": "balear",
    "baleávei": "balear",
    "baleáveis": "balear",
    "balhadeiras": "balhadeira",
    "balhanas": "balhana",
    "balhas": "balha",
    "balhesteiras": "balhesteira",
    "bali": "balir",
    "balia": "balir",
    "baliados": "baliado",
    "baliam": "balir",
    "balias": "balir",
    "balida": "balir",
    "balidas": "balir",
    "balido": "balir",
    "balidos": "balir",
    "balimo": "balir",
    "balimos": "balir",
    "balindo": "balir",
    "balinha": "bala",
    "balinhas": "bala",
    "balins": "balim",
    "balios": "balio",
    "balipodos": "balipodo",
    "balira": "balir",
    "baliram": "balir",
    "baliras": "balir",
    "balirdes": "balir",
    "balirei": "balir",
    "balireis": "balir",
    "balirem": "balir",
    "baliremos": "balir",
    "balires": "balir",
    "baliria": "balir",
    "baliriam": "balir",
    "balirias": "balir",
    "balirmo": "balir",
    "balirmos": "balir",
    "balirá": "balir",
    "balirás": "balir",
    "balirão": "balir",
    "baliríamos": "balir",
    "baliríeis": "balir",
    "balis": "balir",
    "balisse": "balir",
    "balissem": "balir",
    "balisses": "balir",
    "balistas": "balista",
    "baliste": "balir",
    "balistes": "balir",
    "balistites": "balistite",
    "balita": "bala",
    "balitas": "bala",
    "baliu": "balir",
    "baliza": "balizar",
    "balizada": "balizar",
    "balizadas": "balizar",
    "balizado": "balizar",
    "balizadora": "balizador",
    "balizadoras": "balizador",
    "balizadores": "balizador",
    "balizados": "balizar",
    "balizagens": "balizagem",
    "balizai": "balizar",
    "balizais": "balizar",
    "balizam": "balizar",
    "balizamentos": "balizamento",
    "balizamo": "balizar",
    "balizamos": "balizar",
    "balizando": "balizar",
    "balizara": "balizar",
    "balizaram": "balizar",
    "balizaras": "balizar",
    "balizarde": "balizar",
    "balizardes": "balizar",
    "balizare": "balizar",
    "balizarei": "balizar",
    "balizareis": "balizar",
    "balizarem": "balizar",
    "balizaremos": "balizar",
    "balizares": "balizar",
    "balizaria": "balizar",
    "balizariam": "balizar",
    "balizarias": "balizar",
    "balizarmo": "balizar",
    "balizarmos": "balizar",
    "balizará": "balizar",
    "balizarás": "balizar",
    "balizarão": "balizar",
    "balizaríamos": "balizar",
    "balizaríeis": "balizar",
    "balizas": "balizar",
    "balizasse": "balizar",
    "balizassem": "balizar",
    "balizasses": "balizar",
    "balizaste": "balizar",
    "balizastes": "balizar",
    "balizava": "balizar",
    "balizavam": "balizar",
    "balizavas": "balizar",
    "balize": "balizar",
    "balizei": "balizar",
    "balizeis": "balizar",
    "balizem": "balizar",
    "balizemo": "balizar",
    "balizemos": "balizar",
    "balizes": "balizar",
    "balizo": "balizar",
    "balizou": "balizar",
    "balizá": "balizar",
    "balizámo": "balizar",
    "balizámos": "balizar",
    "balizáramo": "balizar",
    "balizáramos": "balizar",
    "balizárei": "balizar",
    "balizáreis": "balizar",
    "balizásseis": "balizar",
    "balizássemos": "balizar",
    "balizávamo": "balizar",
    "balizávamos": "balizar",
    "balizávei": "balizar",
    "balizáveis": "balizar",
    "ballets": "ballet",
    "balmazes": "balmaz",
    "balmázios": "balmázio",
    "balneada": "balnear",
    "balneadas": "balnear",
    "balneado": "balnear",
    "balneados": "balnear",
    "balneai": "balnear",
    "balneais": "balnear",
    "balneamo": "balnear",
    "balneamos": "balnear",
    "balneando": "balnear",
    "balneara": "balnear",
    "balnearam": "balnear",
    "balnearas": "balnear",
    "balnearde": "balnear",
    "balneardes": "balnear",
    "balneare": "balnear",
    "balnearei": "balnear",
    "balneareis": "balnear",
    "balnearem": "balnear",
    "balnearemos": "balnear",
    "balneares": "balnear",
    "balnearia": "balnear",
    "balneariam": "balnear",
    "balnearias": "balnear",
    "balnearmo": "balnear",
    "balnearmos": "balnear",
    "balneará": "balnear",
    "balnearás": "balnear",
    "balnearão": "balnear",
    "balnearíamos": "balnear",
    "balnearíeis": "balnear",
    "balneasse": "balnear",
    "balneassem": "balnear",
    "balneasses": "balnear",
    "balneaste": "balnear",
    "balneastes": "balnear",
    "balneatória": "balneatório",
    "balneatórias": "balneatório",
    "balneatórios": "balneatório",
    "balneava": "balnear",
    "balneavam": "balnear",
    "balneavas": "balnear",
    "balneações": "balneação",
    "balneei": "balnear",
    "balneeis": "balnear",
    "balneemo": "balnear",
    "balneemos": "balnear",
    "balneia": "balnear",
    "balneiam": "balnear",
    "balneias": "balnear",
    "balneie": "balnear",
    "balneiem": "balnear",
    "balneies": "balnear",
    "balneio": "balnear",
    "balneografias": "balneografia",
    "balneográfica": "balneográfico",
    "balneográficas": "balneográfico",
    "balneográficos": "balneográfico",
    "balneoterapias": "balneoterapia",
    "balneoterapêutica": "balneoterapêutico",
    "balneoterapêuticas": "balneoterapêutico",
    "balneoterapêuticos": "balneoterapêutico",
    "balneoterápica": "balneoterápico",
    "balneoterápicas": "balneoterápico",
    "balneoterápicos": "balneoterápico",
    "balneou": "balnear",
    "balneá": "balnear",
    "balneámo": "balnear",
    "balneámos": "balnear",
    "balneáramo": "balnear",
    "balneáramos": "balnear",
    "balneárei": "balnear",
    "balneáreis": "balnear",
    "balneários": "balneário",
    "balneásseis": "balnear",
    "balneássemos": "balnear",
    "balneávamo": "balnear",
    "balneávamos": "balnear",
    "balneávei": "balnear",
    "balneáveis": "balneável",
    "balo": "balir",
    "balofa": "balofo",
    "balofas": "balofo",
    "balofazinha": "balofo",
    "balofazinhas": "balofo",
    "balofazita": "balofo",
    "balofazitas": "balofo",
    "balofices": "balofice",
    "balofinha": "balofo",
    "balofinhas": "balofo",
    "balofinho": "balofo",
    "balofinhos": "balofo",
    "balofita": "balofo",
    "balofitas": "balofo",
    "balofito": "balofo",
    "balofitos": "balofo",
    "balofos": "balofo",
    "balofozinho": "balofo",
    "balofozinhos": "balofo",
    "balofozito": "balofo",
    "balofozitos": "balofo",
    "balofíssima": "balofo",
    "balofíssimas": "balofo",
    "balofíssimo": "balofo",
    "balofíssimos": "balofo",
    "baloice": "baloiçar",
    "baloicei": "baloiçar",
    "baloiceis": "baloiçar",
    "baloicem": "baloiçar",
    "baloicemo": "baloiçar",
    "baloicemos": "baloiçar",
    "baloices": "baloiçar",
    "baloiça": "baloiçar",
    "baloiçada": "baloiçar",
    "baloiçadas": "baloiçar",
    "baloiçado": "baloiçar",
    "baloiçadora": "baloiçador",
    "baloiçadoras": "baloiçador",
    "baloiçadores": "baloiçador",
    "baloiçados": "baloiçar",
    "baloiçai": "baloiçar",
    "baloiçais": "baloiçar",
    "baloiçam": "baloiçar",
    "baloiçamentos": "baloiçamento",
    "baloiçamo": "baloiçar",
    "baloiçamos": "baloiçar",
    "baloiçando": "baloiçar",
    "baloiçantes": "baloiçante",
    "baloiçara": "baloiçar",
    "baloiçaram": "baloiçar",
    "baloiçaras": "baloiçar",
    "baloiçarde": "baloiçar",
    "baloiçardes": "baloiçar",
    "baloiçare": "baloiçar",
    "baloiçarei": "baloiçar",
    "baloiçareis": "baloiçar",
    "baloiçarem": "baloiçar",
    "baloiçaremos": "baloiçar",
    "baloiçares": "baloiçar",
    "baloiçaria": "baloiçar",
    "baloiçariam": "baloiçar",
    "baloiçarias": "baloiçar",
    "baloiçarmo": "baloiçar",
    "baloiçarmos": "baloiçar",
    "baloiçará": "baloiçar",
    "baloiçarás": "baloiçar",
    "baloiçarão": "baloiçar",
    "baloiçaríamos": "baloiçar",
    "baloiçaríeis": "baloiçar",
    "baloiças": "baloiçar",
    "baloiçasse": "baloiçar",
    "baloiçassem": "baloiçar",
    "baloiçasses": "baloiçar",
    "baloiçaste": "baloiçar",
    "baloiçastes": "baloiçar",
    "baloiçava": "baloiçar",
    "baloiçavam": "baloiçar",
    "baloiçavas": "baloiçar",
    "baloiço": "baloiçar",
    "baloiços": "baloiço",
    "baloiçosa": "baloiçoso",
    "baloiçosas": "baloiçoso",
    "baloiçosos": "baloiçoso",
    "baloiçou": "baloiçar",
    "baloiçá": "baloiçar",
    "baloiçámo": "baloiçar",
    "baloiçámos": "baloiçar",
    "baloiçáramo": "baloiçar",
    "baloiçáramos": "baloiçar",
    "baloiçárei": "baloiçar",
    "baloiçáreis": "baloiçar",
    "baloiçásseis": "baloiçar",
    "baloiçássemos": "baloiçar",
    "baloiçávamo": "baloiçar",
    "baloiçávamos": "baloiçar",
    "baloiçávei": "baloiçar",
    "baloiçáveis": "baloiçar",
    "balonas": "balona",
    "balotas": "balota",
    "balotes": "balote",
    "balou": "balar",
    "balouce": "balouçar",
    "baloucei": "balouçar",
    "balouceis": "balouçar",
    "baloucem": "balouçar",
    "baloucemo": "balouçar",
    "baloucemos": "balouçar",
    "balouces": "balouçar",
    "balouça": "balouçar",
    "balouçada": "balouçar",
    "balouçadas": "balouçar",
    "balouçado": "balouçar",
    "balouçadora": "balouçador",
    "balouçadoras": "balouçador",
    "balouçadores": "balouçador",
    "balouçados": "balouçar",
    "balouçai": "balouçar",
    "balouçais": "balouçar",
    "balouçam": "balouçar",
    "balouçamentos": "balouçamento",
    "balouçamo": "balouçar",
    "balouçamos": "balouçar",
    "balouçando": "balouçar",
    "balouçantes": "balouçante",
    "balouçara": "balouçar",
    "balouçaram": "balouçar",
    "balouçaras": "balouçar",
    "balouçarde": "balouçar",
    "balouçardes": "balouçar",
    "balouçare": "balouçar",
    "balouçarei": "balouçar",
    "balouçareis": "balouçar",
    "balouçarem": "balouçar",
    "balouçaremos": "balouçar",
    "balouçares": "balouçar",
    "balouçaria": "balouçar",
    "balouçariam": "balouçar",
    "balouçarias": "balouçar",
    "balouçarmo": "balouçar",
    "balouçarmos": "balouçar",
    "balouçará": "balouçar",
    "balouçarás": "balouçar",
    "balouçarão": "balouçar",
    "balouçaríamos": "balouçar",
    "balouçaríeis": "balouçar",
    "balouças": "balouçar",
    "balouçasse": "balouçar",
    "balouçassem": "balouçar",
    "balouçasses": "balouçar",
    "balouçaste": "balouçar",
    "balouçastes": "balouçar",
    "balouçava": "balouçar",
    "balouçavam": "balouçar",
    "balouçavas": "balouçar",
    "balouço": "balouçar",
    "balouços": "balouço",
    "balouçosa": "balouçoso",
    "balouçosas": "balouçoso",
    "balouçosos": "balouçoso",
    "balouçou": "balouçar",
    "balouçá": "balouçar",
    "balouçámo": "balouçar",
    "balouçámos": "balouçar",
    "balouçáramo": "balouçar",
    "balouçáramos": "balouçar",
    "balouçárei": "balouçar",
    "balouçáreis": "balouçar",
    "balouçásseis": "balouçar",
    "balouçássemos": "balouçar",
    "balouçávamo": "balouçar",
    "balouçávamos": "balouçar",
    "balouçávei": "balouçar",
    "balouçáveis": "balouçar",
    "balroas": "balroa",
    "balsama": "balsamar",
    "balsamada": "balsamar",
    "balsamadas": "balsamar",
    "balsamado": "balsamar",
    "balsamados": "balsamar",
    "balsamai": "balsamar",
    "balsamais": "balsamar",
    "balsamam": "balsamar",
    "balsamamo": "balsamar",
    "balsamamos": "balsamar",
    "balsamando": "balsamar",
    "balsamara": "balsamar",
    "balsamaram": "balsamar",
    "balsamaras": "balsamar",
    "balsamarde": "balsamar",
    "balsamardes": "balsamar",
    "balsamare": "balsamar",
    "balsamarei": "balsamar",
    "balsamareis": "balsamar",
    "balsamarem": "balsamar",
    "balsamaremos": "balsamar",
    "balsamares": "balsamar",
    "balsamaria": "balsamar",
    "balsamariam": "balsamar",
    "balsamarias": "balsamar",
    "balsamarmo": "balsamar",
    "balsamarmos": "balsamar",
    "balsamará": "balsamar",
    "balsamarás": "balsamar",
    "balsamarão": "balsamar",
    "balsamaríamos": "balsamar",
    "balsamaríeis": "balsamar",
    "balsamas": "balsamar",
    "balsamasse": "balsamar",
    "balsamassem": "balsamar",
    "balsamasses": "balsamar",
    "balsamaste": "balsamar",
    "balsamastes": "balsamar",
    "balsamava": "balsamar",
    "balsamavam": "balsamar",
    "balsamavas": "balsamar",
    "balsame": "balsamar",
    "balsamei": "balsamar",
    "balsameias": "balsameia",
    "balsameiros": "balsameiro",
    "balsameis": "balsamar",
    "balsamem": "balsamar",
    "balsamemo": "balsamar",
    "balsamemos": "balsamar",
    "balsames": "balsame",
    "balsamifica": "balsamificar",
    "balsamificada": "balsamificar",
    "balsamificadas": "balsamificar",
    "balsamificado": "balsamificar",
    "balsamificados": "balsamificar",
    "balsamificai": "balsamificar",
    "balsamificais": "balsamificar",
    "balsamificam": "balsamificar",
    "balsamificamo": "balsamificar",
    "balsamificamos": "balsamificar",
    "balsamificando": "balsamificar",
    "balsamificara": "balsamificar",
    "balsamificaram": "balsamificar",
    "balsamificaras": "balsamificar",
    "balsamificarde": "balsamificar",
    "balsamificardes": "balsamificar",
    "balsamificare": "balsamificar",
    "balsamificarei": "balsamificar",
    "balsamificareis": "balsamificar",
    "balsamificarem": "balsamificar",
    "balsamificaremos": "balsamificar",
    "balsamificares": "balsamificar",
    "balsamificaria": "balsamificar",
    "balsamificariam": "balsamificar",
    "balsamificarias": "balsamificar",
    "balsamificarmo": "balsamificar",
    "balsamificarmos": "balsamificar",
    "balsamificará": "balsamificar",
    "balsamificarás": "balsamificar",
    "balsamificarão": "balsamificar",
    "balsamificaríamos": "balsamificar",
    "balsamificaríeis": "balsamificar",
    "balsamificas": "balsamificar",
    "balsamificasse": "balsamificar",
    "balsamificassem": "balsamificar",
    "balsamificasses": "balsamificar",
    "balsamificaste": "balsamificar",
    "balsamificastes": "balsamificar",
    "balsamificava": "balsamificar",
    "balsamificavam": "balsamificar",
    "balsamificavas": "balsamificar",
    "balsamifico": "balsamificar",
    "balsamificou": "balsamificar",
    "balsamificá": "balsamificar",
    "balsamificámo": "balsamificar",
    "balsamificámos": "balsamificar",
    "balsamificáramo": "balsamificar",
    "balsamificáramos": "balsamificar",
    "balsamificárei": "balsamificar",
    "balsamificáreis": "balsamificar",
    "balsamificásseis": "balsamificar",
    "balsamificássemos": "balsamificar",
    "balsamificávamo": "balsamificar",
    "balsamificávamos": "balsamificar",
    "balsamificávei": "balsamificar",
    "balsamificáveis": "balsamificar",
    "balsamifique": "balsamificar",
    "balsamifiquei": "balsamificar",
    "balsamifiqueis": "balsamificar",
    "balsamifiquem": "balsamificar",
    "balsamifiquemo": "balsamificar",
    "balsamifiquemos": "balsamificar",
    "balsamifiques": "balsamificar",
    "balsaminas": "balsamina",
    "balsaminácea": "balsamináceo",
    "balsamináceas": "balsamináceo",
    "balsamináceos": "balsamináceo",
    "balsamitas": "balsamita",
    "balsamiza": "balsamizar",
    "balsamizada": "balsamizar",
    "balsamizadas": "balsamizar",
    "balsamizado": "balsamizar",
    "balsamizados": "balsamizar",
    "balsamizai": "balsamizar",
    "balsamizais": "balsamizar",
    "balsamizam": "balsamizar",
    "balsamizamo": "balsamizar",
    "balsamizamos": "balsamizar",
    "balsamizando": "balsamizar",
    "balsamizara": "balsamizar",
    "balsamizaram": "balsamizar",
    "balsamizaras": "balsamizar",
    "balsamizarde": "balsamizar",
    "balsamizardes": "balsamizar",
    "balsamizare": "balsamizar",
    "balsamizarei": "balsamizar",
    "balsamizareis": "balsamizar",
    "balsamizarem": "balsamizar",
    "balsamizaremos": "balsamizar",
    "balsamizares": "balsamizar",
    "balsamizaria": "balsamizar",
    "balsamizariam": "balsamizar",
    "balsamizarias": "balsamizar",
    "balsamizarmo": "balsamizar",
    "balsamizarmos": "balsamizar",
    "balsamizará": "balsamizar",
    "balsamizarás": "balsamizar",
    "balsamizarão": "balsamizar",
    "balsamizaríamos": "balsamizar",
    "balsamizaríeis": "balsamizar",
    "balsamizas": "balsamizar",
    "balsamizasse": "balsamizar",
    "balsamizassem": "balsamizar",
    "balsamizasses": "balsamizar",
    "balsamizaste": "balsamizar",
    "balsamizastes": "balsamizar",
    "balsamizava": "balsamizar",
    "balsamizavam": "balsamizar",
    "balsamizavas": "balsamizar",
    "balsamizações": "balsamização",
    "balsamize": "balsamizar",
    "balsamizei": "balsamizar",
    "balsamizeis": "balsamizar",
    "balsamizem": "balsamizar",
    "balsamizemo": "balsamizar",
    "balsamizemos": "balsamizar",
    "balsamizes": "balsamizar",
    "balsamizo": "balsamizar",
    "balsamizou": "balsamizar",
    "balsamizá": "balsamizar",
    "balsamizámo": "balsamizar",
    "balsamizámos": "balsamizar",
    "balsamizáramo": "balsamizar",
    "balsamizáramos": "balsamizar",
    "balsamizárei": "balsamizar",
    "balsamizáreis": "balsamizar",
    "balsamizásseis": "balsamizar",
    "balsamizássemos": "balsamizar",
    "balsamizávamo": "balsamizar",
    "balsamizávamos": "balsamizar",
    "balsamizávei": "balsamizar",
    "balsamizáveis": "balsamizar",
    "balsamo": "balsamar",
    "balsamou": "balsamar",
    "balsamá": "balsamar",
    "balsamámo": "balsamar",
    "balsamámos": "balsamar",
    "balsamáramo": "balsamar",
    "balsamáramos": "balsamar",
    "balsamárei": "balsamar",
    "balsamáreis": "balsamar",
    "balsamários": "balsamário",
    "balsamásseis": "balsamar",
    "balsamássemos": "balsamar",
    "balsamávamo": "balsamar",
    "balsamávamos": "balsamar",
    "balsamávei": "balsamar",
    "balsamáveis": "balsamar",
    "balsamífera": "balsamífero",
    "balsamíferas": "balsamífero",
    "balsamíferos": "balsamífero",
    "balsamínea": "balsamíneo",
    "balsamíneas": "balsamíneo",
    "balsamíneos": "balsamíneo",
    "balsanas": "balsana",
    "balsas": "balsa",
    "balsedos": "balsedo",
    "balseiras": "balseira",
    "balseiros": "balseiro",
    "balsos": "balso",
    "balsáminas": "balsámina",
    "balsâmica": "balsâmico",
    "balsâmicas": "balsâmico",
    "balsâmicos": "balsâmico",
    "balsões": "balsão",
    "baltares": "baltar",
    "baltimores": "baltimore",
    "baluartes": "baluarte",
    "balumas": "baluma",
    "balurdos": "balurdo",
    "balámo": "balar",
    "balámos": "balar",
    "baláramo": "balar",
    "baláramos": "balar",
    "baláreis": "balar",
    "balárias": "balária",
    "balásseis": "balar",
    "balássemos": "balar",
    "baláustias": "baláustia",
    "baláustios": "baláustio",
    "balávamo": "balar",
    "balávamos": "balar",
    "baláveis": "balar",
    "balázios": "balázio",
    "balãozinho": "balão",
    "balãozito": "balão",
    "balças": "balça",
    "balções": "balção",
    "balés": "balé",
    "baléticas": "balética",
    "balíamo": "balir",
    "balíamos": "balir",
    "balíeis": "balir",
    "balíramo": "balir",
    "balíramos": "balir",
    "balíreis": "balir",
    "balísseis": "balir",
    "balíssemos": "balir",
    "balística": "balístico",
    "balísticas": "balístico",
    "balísticos": "balístico",
    "balóticas": "balótica",
    "balões": "balão",
    "balõezinhos": "balão",
    "balõezitos": "balão",
    "balúrdios": "balúrdio",
    "bamba": "bambo",
    "bambada": "bambar",
    "bambadas": "bambar",
    "bambado": "bambar",
    "bambados": "bambar",
    "bambai": "bambar",
    "bambais": "bambar",
    "bambaleada": "bambalear",
    "bambaleadas": "bambalear",
    "bambaleado": "bambalear",
    "bambaleados": "bambalear",
    "bambaleai": "bambalear",
    "bambaleais": "bambalear",
    "bambaleamo": "bambalear",
    "bambaleamos": "bambalear",
    "bambaleando": "bambalear",
    "bambaleara": "bambalear",
    "bambalearam": "bambalear",
    "bambalearas": "bambalear",
    "bambaleardes": "bambalear",
    "bambalearei": "bambalear",
    "bambaleareis": "bambalear",
    "bambalearem": "bambalear",
    "bambalearemos": "bambalear",
    "bambaleares": "bambalear",
    "bambalearia": "bambalear",
    "bambaleariam": "bambalear",
    "bambalearias": "bambalear",
    "bambalearmo": "bambalear",
    "bambalearmos": "bambalear",
    "bambaleará": "bambalear",
    "bambalearás": "bambalear",
    "bambalearão": "bambalear",
    "bambalearíamos": "bambalear",
    "bambalearíeis": "bambalear",
    "bambaleasse": "bambalear",
    "bambaleassem": "bambalear",
    "bambaleasses": "bambalear",
    "bambaleaste": "bambalear",
    "bambaleastes": "bambalear",
    "bambaleava": "bambalear",
    "bambaleavam": "bambalear",
    "bambaleavas": "bambalear",
    "bambaleei": "bambalear",
    "bambaleeis": "bambalear",
    "bambaleemo": "bambalear",
    "bambaleemos": "bambalear",
    "bambaleia": "bambalear",
    "bambaleiam": "bambalear",
    "bambaleias": "bambalear",
    "bambaleie": "bambalear",
    "bambaleiem": "bambalear",
    "bambaleies": "bambalear",
    "bambaleio": "bambalear",
    "bambaleios": "bambaleio",
    "bambaleou": "bambalear",
    "bambaleámo": "bambalear",
    "bambaleámos": "bambalear",
    "bambaleáramo": "bambalear",
    "bambaleáramos": "bambalear",
    "bambaleáreis": "bambalear",
    "bambaleásseis": "bambalear",
    "bambaleássemos": "bambalear",
    "bambaleávamo": "bambalear",
    "bambaleávamos": "bambalear",
    "bambaleáveis": "bambalear",
    "bambalhona": "bambalhão",
    "bambalhonas": "bambalhona",
    "bambalhões": "bambalhão",
    "bambaliaduras": "bambaliadura",
    "bambaliantes": "bambaliante",
    "bambam": "bambar",
    "bambamo": "bambar",
    "bambamos": "bambar",
    "bambando": "bambar",
    "bambara": "bambar",
    "bambaram": "bambar",
    "bambaras": "bambar",
    "bambarde": "bambar",
    "bambardes": "bambar",
    "bambare": "bambar",
    "bambarei": "bambar",
    "bambareis": "bambar",
    "bambarem": "bambar",
    "bambaremos": "bambar",
    "bambares": "bambar",
    "bambaria": "bambar",
    "bambariam": "bambar",
    "bambarias": "bambar",
    "bambarmo": "bambar",
    "bambarmos": "bambar",
    "bambará": "bambar",
    "bambarás": "bambar",
    "bambarão": "bambar",
    "bambaríamos": "bambar",
    "bambaríeis": "bambar",
    "bambas": "bambo",
    "bambasse": "bambar",
    "bambassem": "bambar",
    "bambasses": "bambar",
    "bambaste": "bambar",
    "bambastes": "bambar",
    "bambava": "bambar",
    "bambavam": "bambar",
    "bambavas": "bambar",
    "bambe": "bambar",
    "bambeada": "bambear",
    "bambeadas": "bambear",
    "bambeado": "bambear",
    "bambeados": "bambear",
    "bambeai": "bambear",
    "bambeais": "bambear",
    "bambeamo": "bambear",
    "bambeamos": "bambear",
    "bambeando": "bambear",
    "bambeara": "bambear",
    "bambearam": "bambear",
    "bambearas": "bambear",
    "bambearde": "bambear",
    "bambeardes": "bambear",
    "bambeare": "bambear",
    "bambearei": "bambear",
    "bambeareis": "bambear",
    "bambearem": "bambear",
    "bambearemos": "bambear",
    "bambeares": "bambear",
    "bambearia": "bambear",
    "bambeariam": "bambear",
    "bambearias": "bambear",
    "bambearmo": "bambear",
    "bambearmos": "bambear",
    "bambeará": "bambear",
    "bambearás": "bambear",
    "bambearão": "bambear",
    "bambearíamos": "bambear",
    "bambearíeis": "bambear",
    "bambeasse": "bambear",
    "bambeassem": "bambear",
    "bambeasses": "bambear",
    "bambeaste": "bambear",
    "bambeastes": "bambear",
    "bambeava": "bambear",
    "bambeavam": "bambear",
    "bambeavas": "bambear",
    "bambeei": "bambear",
    "bambeeis": "bambear",
    "bambeemo": "bambear",
    "bambeemos": "bambear",
    "bambei": "bambar",
    "bambeia": "bambear",
    "bambeiam": "bambear",
    "bambeias": "bambear",
    "bambeie": "bambear",
    "bambeiem": "bambear",
    "bambeies": "bambear",
    "bambeio": "bambear",
    "bambeis": "bambar",
    "bambem": "bambar",
    "bambemo": "bambar",
    "bambemos": "bambar",
    "bambeou": "bambear",
    "bambes": "bambar",
    "bambezas": "bambeza",
    "bambeá": "bambear",
    "bambeámo": "bambear",
    "bambeámos": "bambear",
    "bambeáramo": "bambear",
    "bambeáramos": "bambear",
    "bambeárei": "bambear",
    "bambeáreis": "bambear",
    "bambeásseis": "bambear",
    "bambeássemos": "bambear",
    "bambeávamo": "bambear",
    "bambeávamos": "bambear",
    "bambeávei": "bambear",
    "bambeáveis": "bambear",
    "bambina": "bambinar",
    "bambinada": "bambinar",
    "bambinadas": "bambinar",
    "bambinado": "bambinar",
    "bambinados": "bambinar",
    "bambinai": "bambinar",
    "bambinais": "bambinar",
    "bambinam": "bambinar",
    "bambinamo": "bambinar",
    "bambinamos": "bambinar",
    "bambinando": "bambinar",
    "bambinara": "bambinar",
    "bambinaram": "bambinar",
    "bambinaras": "bambinar",
    "bambinardes": "bambinar",
    "bambinarei": "bambinar",
    "bambinareis": "bambinar",
    "bambinarem": "bambinar",
    "bambinaremos": "bambinar",
    "bambinares": "bambinar",
    "bambinaria": "bambinar",
    "bambinariam": "bambinar",
    "bambinarias": "bambinar",
    "bambinarmo": "bambinar",
    "bambinarmos": "bambinar",
    "bambinará": "bambinar",
    "bambinarás": "bambinar",
    "bambinarão": "bambinar",
    "bambinaríamos": "bambinar",
    "bambinaríeis": "bambinar",
    "bambinas": "bambinar",
    "bambinasse": "bambinar",
    "bambinassem": "bambinar",
    "bambinasses": "bambinar",
    "bambinaste": "bambinar",
    "bambinastes": "bambinar",
    "bambinava": "bambinar",
    "bambinavam": "bambinar",
    "bambinavas": "bambinar",
    "bambine": "bambinar",
    "bambinei": "bambinar",
    "bambineis": "bambinar",
    "bambinelas": "bambinela",
    "bambinem": "bambinar",
    "bambinemo": "bambinar",
    "bambinemos": "bambinar",
    "bambines": "bambinar",
    "bambino": "bambinar",
    "bambinos": "bambino",
    "bambinou": "bambinar",
    "bambinámo": "bambinar",
    "bambinámos": "bambinar",
    "bambináramo": "bambinar",
    "bambináramos": "bambinar",
    "bambináreis": "bambinar",
    "bambinásseis": "bambinar",
    "bambinássemos": "bambinar",
    "bambinávamo": "bambinar",
    "bambinávamos": "bambinar",
    "bambináveis": "bambinar",
    "bambis": "bambi",
    "bambo": "bambar",
    "bamboa": "bamboar",
    "bamboada": "bamboar",
    "bamboadas": "bamboar",
    "bamboado": "bamboar",
    "bamboados": "bamboar",
    "bamboai": "bamboar",
    "bamboais": "bamboar",
    "bamboam": "bamboar",
    "bamboamo": "bamboar",
    "bamboamos": "bamboar",
    "bamboando": "bamboar",
    "bamboara": "bamboar",
    "bamboaram": "bamboar",
    "bamboaras": "bamboar",
    "bamboarde": "bamboar",
    "bamboardes": "bamboar",
    "bamboare": "bamboar",
    "bamboarei": "bamboar",
    "bamboareis": "bamboar",
    "bamboarem": "bamboar",
    "bamboaremos": "bamboar",
    "bamboares": "bamboar",
    "bamboaria": "bamboar",
    "bamboariam": "bamboar",
    "bamboarias": "bamboar",
    "bamboarmo": "bamboar",
    "bamboarmos": "bamboar",
    "bamboará": "bamboar",
    "bamboarás": "bamboar",
    "bamboarão": "bamboar",
    "bamboaríamos": "bamboar",
    "bamboaríeis": "bamboar",
    "bamboas": "bamboar",
    "bamboasse": "bamboar",
    "bamboassem": "bamboar",
    "bamboasses": "bamboar",
    "bamboaste": "bamboar",
    "bamboastes": "bamboar",
    "bamboava": "bamboar",
    "bamboavam": "bamboar",
    "bamboavas": "bamboar",
    "bambocha": "bambochar",
    "bambochada": "bambochar",
    "bambochadas": "bambochar",
    "bambochado": "bambochar",
    "bambochados": "bambochar",
    "bambochai": "bambochar",
    "bambochais": "bambochar",
    "bambocham": "bambochar",
    "bambochamo": "bambochar",
    "bambochamos": "bambochar",
    "bambochando": "bambochar",
    "bambochara": "bambochar",
    "bambocharam": "bambochar",
    "bambocharas": "bambochar",
    "bambochardes": "bambochar",
    "bambocharei": "bambochar",
    "bambochareis": "bambochar",
    "bambocharem": "bambochar",
    "bambocharemos": "bambochar",
    "bambochares": "bambochar",
    "bambocharia": "bambochar",
    "bambochariam": "bambochar",
    "bambocharias": "bambochar",
    "bambocharmo": "bambochar",
    "bambocharmos": "bambochar",
    "bambochará": "bambochar",
    "bambocharás": "bambochar",
    "bambocharão": "bambochar",
    "bambocharíamos": "bambochar",
    "bambocharíeis": "bambochar",
    "bambochas": "bambochar",
    "bambochasse": "bambochar",
    "bambochassem": "bambochar",
    "bambochasses": "bambochar",
    "bambochaste": "bambochar",
    "bambochastes": "bambochar",
    "bambochatas": "bambochata",
    "bambochava": "bambochar",
    "bambochavam": "bambochar",
    "bambochavas": "bambochar",
    "bamboche": "bambochar",
    "bambochei": "bambochar",
    "bambocheis": "bambochar",
    "bambochem": "bambochar",
    "bambochemo": "bambochar",
    "bambochemos": "bambochar",
    "bamboches": "bambochar",
    "bambocho": "bambochar",
    "bambochou": "bambochar",
    "bambochámo": "bambochar",
    "bambochámos": "bambochar",
    "bambocháramo": "bambochar",
    "bambocháramos": "bambochar",
    "bambocháreis": "bambochar",
    "bambochásseis": "bambochar",
    "bambochássemos": "bambochar",
    "bambochávamo": "bambochar",
    "bambochávamos": "bambochar",
    "bambocháveis": "bambochar",
    "bamboe": "bamboar",
    "bamboei": "bamboar",
    "bamboeis": "bamboar",
    "bamboem": "bamboar",
    "bamboemo": "bamboar",
    "bamboemos": "bamboar",
    "bamboes": "bamboar",
    "bamboleada": "bambolear",
    "bamboleadas": "bambolear",
    "bamboleado": "bambolear",
    "bamboleados": "bambolear",
    "bamboleai": "bambolear",
    "bamboleais": "bambolear",
    "bamboleamentos": "bamboleamento",
    "bamboleamo": "bambolear",
    "bamboleamos": "bambolear",
    "bamboleando": "bambolear",
    "bamboleantes": "bamboleante",
    "bamboleara": "bambolear",
    "bambolearam": "bambolear",
    "bambolearas": "bambolear",
    "bambolearde": "bambolear",
    "bamboleardes": "bambolear",
    "bamboleare": "bambolear",
    "bambolearei": "bambolear",
    "bamboleareis": "bambolear",
    "bambolearem": "bambolear",
    "bambolearemos": "bambolear",
    "bamboleares": "bambolear",
    "bambolearia": "bambolear",
    "bamboleariam": "bambolear",
    "bambolearias": "bambolear",
    "bambolearmo": "bambolear",
    "bambolearmos": "bambolear",
    "bamboleará": "bambolear",
    "bambolearás": "bambolear",
    "bambolearão": "bambolear",
    "bambolearíamos": "bambolear",
    "bambolearíeis": "bambolear",
    "bamboleasse": "bambolear",
    "bamboleassem": "bambolear",
    "bamboleasses": "bambolear",
    "bamboleaste": "bambolear",
    "bamboleastes": "bambolear",
    "bamboleava": "bambolear",
    "bamboleavam": "bambolear",
    "bamboleavas": "bambolear",
    "bamboleei": "bambolear",
    "bamboleeis": "bambolear",
    "bamboleemo": "bambolear",
    "bamboleemos": "bambolear",
    "bamboleia": "bambolear",
    "bamboleiam": "bambolear",
    "bamboleias": "bambolear",
    "bamboleie": "bambolear",
    "bamboleiem": "bambolear",
    "bamboleies": "bambolear",
    "bamboleio": "bambolear",
    "bamboleios": "bamboleio",
    "bamboleou": "bambolear",
    "bamboleá": "bambolear",
    "bamboleámo": "bambolear",
    "bamboleámos": "bambolear",
    "bamboleáramo": "bambolear",
    "bamboleáramos": "bambolear",
    "bamboleárei": "bambolear",
    "bamboleáreis": "bambolear",
    "bamboleásseis": "bambolear",
    "bamboleássemos": "bambolear",
    "bamboleávamo": "bambolear",
    "bamboleávamos": "bambolear",
    "bamboleávei": "bambolear",
    "bamboleáveis": "bambolear",
    "bambolinas": "bambolina",
    "bambolins": "bambolim",
    "bamboo": "bamboar",
    "bamboou": "bamboar",
    "bambos": "bambo",
    "bambou": "bambar",
    "bamboá": "bamboar",
    "bamboámo": "bamboar",
    "bamboámos": "bamboar",
    "bamboáramo": "bamboar",
    "bamboáramos": "bamboar",
    "bamboárei": "bamboar",
    "bamboáreis": "bamboar",
    "bamboásseis": "bamboar",
    "bamboássemos": "bamboar",
    "bamboávamo": "bamboar",
    "bamboávamos": "bamboar",
    "bamboávei": "bamboar",
    "bamboáveis": "bamboar",
    "bambuadas": "bambuada",
    "bambuais": "bambual",
    "bambuchatas": "bambuchata",
    "bambueiras": "bambueira",
    "bambuelas": "bambuela",
    "bamburas": "bambura",
    "bamburrados": "bamburrado",
    "bamburrais": "bamburral",
    "bamburristas": "bamburrista",
    "bamburros": "bamburro",
    "bambus": "bambu",
    "bambuzais": "bambuzal",
    "bambá": "bambar",
    "bambámo": "bambar",
    "bambámos": "bambar",
    "bambáramo": "bambar",
    "bambáramos": "bambar",
    "bambárei": "bambar",
    "bambáreis": "bambar",
    "bambásseis": "bambar",
    "bambássemos": "bambar",
    "bambávamo": "bambar",
    "bambávamos": "bambar",
    "bambávei": "bambar",
    "bambáveis": "bambar",
    "bambúrrios": "bambúrrio",
    "bana": "banir",
    "banabóias": "banabóia",
    "banais": "banir",
    "banaizinhas": "banal",
    "banaizinhos": "banal",
    "banaizitas": "banal",
    "banaizitos": "banal",
    "banalidades": "banalidade",
    "banaliza": "banalizar",
    "banalizada": "banalizar",
    "banalizadas": "banalizar",
    "banalizado": "banalizar",
    "banalizados": "banalizar",
    "banalizai": "banalizar",
    "banalizais": "banalizar",
    "banalizam": "banalizar",
    "banalizamo": "banalizar",
    "banalizamos": "banalizar",
    "banalizando": "banalizar",
    "banalizara": "banalizar",
    "banalizaram": "banalizar",
    "banalizaras": "banalizar",
    "banalizarde": "banalizar",
    "banalizardes": "banalizar",
    "banalizare": "banalizar",
    "banalizarei": "banalizar",
    "banalizareis": "banalizar",
    "banalizarem": "banalizar",
    "banalizaremos": "banalizar",
    "banalizares": "banalizar",
    "banalizaria": "banalizar",
    "banalizariam": "banalizar",
    "banalizarias": "banalizar",
    "banalizarmo": "banalizar",
    "banalizarmos": "banalizar",
    "banalizará": "banalizar",
    "banalizarás": "banalizar",
    "banalizarão": "banalizar",
    "banalizaríamos": "banalizar",
    "banalizaríeis": "banalizar",
    "banalizas": "banalizar",
    "banalizasse": "banalizar",
    "banalizassem": "banalizar",
    "banalizasses": "banalizar",
    "banalizaste": "banalizar",
    "banalizastes": "banalizar",
    "banalizava": "banalizar",
    "banalizavam": "banalizar",
    "banalizavas": "banalizar",
    "banalizações": "banalização",
    "banalize": "banalizar",
    "banalizei": "banalizar",
    "banalizeis": "banalizar",
    "banalizem": "banalizar",
    "banalizemo": "banalizar",
    "banalizemos": "banalizar",
    "banalizes": "banalizar",
    "banalizo": "banalizar",
    "banalizou": "banalizar",
    "banalizá": "banalizar",
    "banalizámo": "banalizar",
    "banalizámos": "banalizar",
    "banalizáramo": "banalizar",
    "banalizáramos": "banalizar",
    "banalizárei": "banalizar",
    "banalizáreis": "banalizar",
    "banalizásseis": "banalizar",
    "banalizássemos": "banalizar",
    "banalizávamo": "banalizar",
    "banalizávamos": "banalizar",
    "banalizávei": "banalizar",
    "banalizáveis": "banalizável",
    "banalzinha": "banal",
    "banalzinho": "banal",
    "banalzita": "banal",
    "banalzito": "banal",
    "banalíssima": "banal",
    "banalíssimas": "banal",
    "banalíssimo": "banal",
    "banalíssimos": "banal",
    "banam": "banir",
    "banamo": "banir",
    "banamos": "banir",
    "bananadas": "bananada",
    "bananais": "bananal",
    "bananas": "banana",
    "bananeira": "bananeiro",
    "bananeirais": "bananeiral",
    "bananeiras": "bananeiro",
    "bananeiros": "bananeiro",
    "bananices": "bananice",
    "bananinha": "banana",
    "bananinhas": "banana",
    "bananistas": "bananista",
    "bananita": "banana",
    "bananitas": "banana",
    "bananosas": "bananosa",
    "bananoses": "bananose",
    "bananívora": "bananívoro",
    "bananívoras": "bananívoro",
    "bananívoros": "bananívoro",
    "banas": "banir",
    "banazolas": "banazola",
    "bancadas": "bancada",
    "bancais": "bancal",
    "bancarias": "bancaria",
    "bancarrotas": "bancarrota",
    "bancarroteira": "bancarroteiro",
    "bancarroteiras": "bancarroteiro",
    "bancarroteiros": "bancarroteiro",
    "bancas": "banca",
    "bancocracias": "bancocracia",
    "bancos": "banco",
    "bancária": "bancário",
    "bancárias": "bancário",
    "bancários": "bancário",
    "banda": "bandar",
    "bandada": "bandar",
    "bandadas": "bandar",
    "bandadazinha": "bandado",
    "bandadazinhas": "bandado",
    "bandadazita": "bandado",
    "bandadazitas": "bandado",
    "bandadinha": "bandado",
    "bandadinhas": "bandado",
    "bandadinho": "bandado",
    "bandadinhos": "bandado",
    "bandadita": "bandado",
    "bandaditas": "bandado",
    "bandadito": "bandado",
    "bandaditos": "bandado",
    "bandado": "bandar",
    "bandados": "bandar",
    "bandadozinho": "bandado",
    "bandadozinhos": "bandado",
    "bandadozito": "bandado",
    "bandadozitos": "bandado",
    "bandai": "bandar",
    "bandais": "bandar",
    "bandalheiras": "bandalheira",
    "bandalhices": "bandalhice",
    "bandalhismos": "bandalhismo",
    "bandalhos": "bandalho",
    "bandam": "bandar",
    "bandamo": "bandar",
    "bandamos": "bandar",
    "bandando": "bandar",
    "bandara": "bandar",
    "bandaram": "bandar",
    "bandaras": "bandar",
    "bandarde": "bandar",
    "bandardes": "bandar",
    "bandare": "bandar",
    "bandarei": "bandar",
    "bandareis": "bandar",
    "bandarem": "bandar",
    "bandaremos": "bandar",
    "bandares": "bandar",
    "bandaria": "bandar",
    "bandariam": "bandar",
    "bandarias": "bandar",
    "bandarilha": "bandarilhar",
    "bandarilhada": "bandarilhar",
    "bandarilhadas": "bandarilhar",
    "bandarilhado": "bandarilhar",
    "bandarilhados": "bandarilhar",
    "bandarilhai": "bandarilhar",
    "bandarilhais": "bandarilhar",
    "bandarilham": "bandarilhar",
    "bandarilhamo": "bandarilhar",
    "bandarilhamos": "bandarilhar",
    "bandarilhando": "bandarilhar",
    "bandarilhara": "bandarilhar",
    "bandarilharam": "bandarilhar",
    "bandarilharas": "bandarilhar",
    "bandarilharde": "bandarilhar",
    "bandarilhardes": "bandarilhar",
    "bandarilhare": "bandarilhar",
    "bandarilharei": "bandarilhar",
    "bandarilhareis": "bandarilhar",
    "bandarilharem": "bandarilhar",
    "bandarilharemos": "bandarilhar",
    "bandarilhares": "bandarilhar",
    "bandarilharia": "bandarilhar",
    "bandarilhariam": "bandarilhar",
    "bandarilharias": "bandarilhar",
    "bandarilharmo": "bandarilhar",
    "bandarilharmos": "bandarilhar",
    "bandarilhará": "bandarilhar",
    "bandarilharás": "bandarilhar",
    "bandarilharão": "bandarilhar",
    "bandarilharíamos": "bandarilhar",
    "bandarilharíeis": "bandarilhar",
    "bandarilhas": "bandarilhar",
    "bandarilhasse": "bandarilhar",
    "bandarilhassem": "bandarilhar",
    "bandarilhasses": "bandarilhar",
    "bandarilhaste": "bandarilhar",
    "bandarilhastes": "bandarilhar",
    "bandarilhava": "bandarilhar",
    "bandarilhavam": "bandarilhar",
    "bandarilhavas": "bandarilhar",
    "bandarilhe": "bandarilhar",
    "bandarilhei": "bandarilhar",
    "bandarilheira": "bandarilheiro",
    "bandarilheiras": "bandarilheiro",
    "bandarilheiros": "bandarilheiro",
    "bandarilheis": "bandarilhar",
    "bandarilhem": "bandarilhar",
    "bandarilhemo": "bandarilhar",
    "bandarilhemos": "bandarilhar",
    "bandarilhes": "bandarilhar",
    "bandarilho": "bandarilhar",
    "bandarilhou": "bandarilhar",
    "bandarilhá": "bandarilhar",
    "bandarilhámo": "bandarilhar",
    "bandarilhámos": "bandarilhar",
    "bandarilháramo": "bandarilhar",
    "bandarilháramos": "bandarilhar",
    "bandarilhárei": "bandarilhar",
    "bandarilháreis": "bandarilhar",
    "bandarilhásseis": "bandarilhar",
    "bandarilhássemos": "bandarilhar",
    "bandarilhávamo": "bandarilhar",
    "bandarilhávamos": "bandarilhar",
    "bandarilhávei": "bandarilhar",
    "bandarilháveis": "bandarilhar",
    "bandarins": "bandarim",
    "bandarmo": "bandar",
    "bandarmos": "bandar",
    "bandarras": "bandarra",
    "bandarreada": "bandarrear",
    "bandarreadas": "bandarrear",
    "bandarreado": "bandarrear",
    "bandarreados": "bandarrear",
    "bandarreai": "bandarrear",
    "bandarreais": "bandarrear",
    "bandarreamo": "bandarrear",
    "bandarreamos": "bandarrear",
    "bandarreando": "bandarrear",
    "bandarreara": "bandarrear",
    "bandarrearam": "bandarrear",
    "bandarrearas": "bandarrear",
    "bandarreardes": "bandarrear",
    "bandarrearei": "bandarrear",
    "bandarreareis": "bandarrear",
    "bandarrearem": "bandarrear",
    "bandarrearemos": "bandarrear",
    "bandarreares": "bandarrear",
    "bandarrearia": "bandarrear",
    "bandarreariam": "bandarrear",
    "bandarrearias": "bandarrear",
    "bandarrearmo": "bandarrear",
    "bandarrearmos": "bandarrear",
    "bandarreará": "bandarrear",
    "bandarrearás": "bandarrear",
    "bandarrearão": "bandarrear",
    "bandarrearíamos": "bandarrear",
    "bandarrearíeis": "bandarrear",
    "bandarreasse": "bandarrear",
    "bandarreassem": "bandarrear",
    "bandarreasses": "bandarrear",
    "bandarreaste": "bandarrear",
    "bandarreastes": "bandarrear",
    "bandarreava": "bandarrear",
    "bandarreavam": "bandarrear",
    "bandarreavas": "bandarrear",
    "bandarreei": "bandarrear",
    "bandarreeis": "bandarrear",
    "bandarreemo": "bandarrear",
    "bandarreemos": "bandarrear",
    "bandarreia": "bandarrear",
    "bandarreiam": "bandarrear",
    "bandarreias": "bandarrear",
    "bandarreie": "bandarrear",
    "bandarreiem": "bandarrear",
    "bandarreies": "bandarrear",
    "bandarreio": "bandarrear",
    "bandarreou": "bandarrear",
    "bandarreámo": "bandarrear",
    "bandarreámos": "bandarrear",
    "bandarreáramo": "bandarrear",
    "bandarreáramos": "bandarrear",
    "bandarreáreis": "bandarrear",
    "bandarreásseis": "bandarrear",
    "bandarreássemos": "bandarrear",
    "bandarreávamo": "bandarrear",
    "bandarreávamos": "bandarrear",
    "bandarreáveis": "bandarrear",
    "bandarrices": "bandarrice",
    "bandarrismos": "bandarrismo",
    "bandarristas": "bandarrista",
    "bandará": "bandar",
    "bandarás": "bandar",
    "bandarão": "bandar",
    "bandaríamos": "bandar",
    "bandaríeis": "bandar",
    "bandas": "bandar",
    "bandasse": "bandar",
    "bandassem": "bandar",
    "bandasses": "bandar",
    "bandaste": "bandar",
    "bandastes": "bandar",
    "bandava": "bandar",
    "bandavam": "bandar",
    "bandavas": "bandar",
    "bande": "bandar",
    "bandeada": "bandear",
    "bandeadas": "bandear",
    "bandeado": "bandear",
    "bandeadores": "bandeador",
    "bandeados": "bandear",
    "bandeai": "bandear",
    "bandeais": "bandear",
    "bandeamentos": "bandeamento",
    "bandeamo": "bandear",
    "bandeamos": "bandear",
    "bandeando": "bandear",
    "bandeara": "bandear",
    "bandearam": "bandear",
    "bandearas": "bandear",
    "bandeardes": "bandear",
    "bandearei": "bandear",
    "bandeareis": "bandear",
    "bandearem": "bandear",
    "bandearemos": "bandear",
    "bandeares": "bandear",
    "bandearia": "bandear",
    "bandeariam": "bandear",
    "bandearias": "bandear",
    "bandearmo": "bandear",
    "bandearmos": "bandear",
    "bandeará": "bandear",
    "bandearás": "bandear",
    "bandearão": "bandear",
    "bandearíamos": "bandear",
    "bandearíeis": "bandear",
    "bandeasse": "bandear",
    "bandeassem": "bandear",
    "bandeasses": "bandear",
    "bandeaste": "bandear",
    "bandeastes": "bandear",
    "bandeava": "bandear",
    "bandeavam": "bandear",
    "bandeavas": "bandear",
    "bandeei": "bandear",
    "bandeeis": "bandear",
    "bandeemo": "bandear",
    "bandeemos": "bandear",
    "bandei": "bandar",
    "bandeia": "bandear",
    "bandeiam": "bandear",
    "bandeias": "bandear",
    "bandeie": "bandear",
    "bandeiem": "bandear",
    "bandeies": "bandear",
    "bandeio": "bandear",
    "bandeira": "bandeiro",
    "bandeirada": "bandeirar",
    "bandeiradas": "bandeirar",
    "bandeirado": "bandeirar",
    "bandeirados": "bandeirar",
    "bandeirai": "bandeirar",
    "bandeirais": "bandeirar",
    "bandeiram": "bandeirar",
    "bandeiramo": "bandeirar",
    "bandeiramos": "bandeirar",
    "bandeirando": "bandeirar",
    "bandeirantes": "bandeirante",
    "bandeirara": "bandeirar",
    "bandeiraram": "bandeirar",
    "bandeiraras": "bandeirar",
    "bandeirardes": "bandeirar",
    "bandeirarei": "bandeirar",
    "bandeirareis": "bandeirar",
    "bandeirarem": "bandeirar",
    "bandeiraremos": "bandeirar",
    "bandeirares": "bandeirar",
    "bandeiraria": "bandeirar",
    "bandeirariam": "bandeirar",
    "bandeirarias": "bandeirar",
    "bandeirarmo": "bandeirar",
    "bandeirarmos": "bandeirar",
    "bandeirará": "bandeirar",
    "bandeirarás": "bandeirar",
    "bandeirarão": "bandeirar",
    "bandeiraríamos": "bandeirar",
    "bandeiraríeis": "bandeirar",
    "bandeiras": "bandeiro",
    "bandeirasse": "bandeirar",
    "bandeirassem": "bandeirar",
    "bandeirasses": "bandeirar",
    "bandeiraste": "bandeirar",
    "bandeirastes": "bandeirar",
    "bandeirava": "bandeirar",
    "bandeiravam": "bandeirar",
    "bandeiravas": "bandeirar",
    "bandeire": "bandeirar",
    "bandeirei": "bandeirar",
    "bandeireis": "bandeirar",
    "bandeirem": "bandeirar",
    "bandeiremo": "bandeirar",
    "bandeiremos": "bandeirar",
    "bandeires": "bandeirar",
    "bandeirinha": "bandeira",
    "bandeirinhas": "bandeirinha",
    "bandeirismos": "bandeirismo",
    "bandeirita": "bandeira",
    "bandeiritas": "bandeira",
    "bandeiro": "bandeirar",
    "bandeirolas": "bandeirola",
    "bandeiros": "bandeiro",
    "bandeirou": "bandeirar",
    "bandeirámo": "bandeirar",
    "bandeirámos": "bandeirar",
    "bandeiráramo": "bandeirar",
    "bandeiráramos": "bandeirar",
    "bandeiráreis": "bandeirar",
    "bandeirásseis": "bandeirar",
    "bandeirássemos": "bandeirar",
    "bandeirávamo": "bandeirar",
    "bandeirávamos": "bandeirar",
    "bandeiráveis": "bandeirar",
    "bandeis": "bandar",
    "bandeja": "bandejar",
    "bandejada": "bandejar",
    "bandejadas": "bandejar",
    "bandejado": "bandejar",
    "bandejados": "bandejar",
    "bandejai": "bandejar",
    "bandejais": "bandejar",
    "bandejam": "bandejar",
    "bandejamo": "bandejar",
    "bandejamos": "bandejar",
    "bandejando": "bandejar",
    "bandejara": "bandejar",
    "bandejaram": "bandejar",
    "bandejaras": "bandejar",
    "bandejarde": "bandejar",
    "bandejardes": "bandejar",
    "bandejare": "bandejar",
    "bandejarei": "bandejar",
    "bandejareis": "bandejar",
    "bandejarem": "bandejar",
    "bandejaremos": "bandejar",
    "bandejares": "bandejar",
    "bandejaria": "bandejar",
    "bandejariam": "bandejar",
    "bandejarias": "bandejar",
    "bandejarmo": "bandejar",
    "bandejarmos": "bandejar",
    "bandejará": "bandejar",
    "bandejarás": "bandejar",
    "bandejarão": "bandejar",
    "bandejaríamos": "bandejar",
    "bandejaríeis": "bandejar",
    "bandejas": "bandejar",
    "bandejasse": "bandejar",
    "bandejassem": "bandejar",
    "bandejasses": "bandejar",
    "bandejaste": "bandejar",
    "bandejastes": "bandejar",
    "bandejava": "bandejar",
    "bandejavam": "bandejar",
    "bandejavas": "bandejar",
    "bandeje": "bandejar",
    "bandejei": "bandejar",
    "bandejeis": "bandejar",
    "bandejem": "bandejar",
    "bandejemo": "bandejar",
    "bandejemos": "bandejar",
    "bandejes": "bandejar",
    "bandejo": "bandejar",
    "bandejou": "bandejar",
    "bandejá": "bandejar",
    "bandejámo": "bandejar",
    "bandejámos": "bandejar",
    "bandejáramo": "bandejar",
    "bandejáramos": "bandejar",
    "bandejárei": "bandejar",
    "bandejáreis": "bandejar",
    "bandejásseis": "bandejar",
    "bandejássemos": "bandejar",
    "bandejávamo": "bandejar",
    "bandejávamos": "bandejar",
    "bandejávei": "bandejar",
    "bandejáveis": "bandejar",
    "bandem": "bandar",
    "bandemo": "bandar",
    "bandemos": "bandar",
    "bandeou": "bandear",
    "bandes": "bandar",
    "bandeámo": "bandear",
    "bandeámos": "bandear",
    "bandeáramo": "bandear",
    "bandeáramos": "bandear",
    "bandeáreis": "bandear",
    "bandeásseis": "bandear",
    "bandeássemos": "bandear",
    "bandeávamo": "bandear",
    "bandeávamos": "bandear",
    "bandeáveis": "bandear",
    "bandida": "bandido",
    "bandidas": "bandido",
    "bandidismos": "bandidismo",
    "bandidos": "bandido",
    "banditismos": "banditismo",
    "bando": "bandar",
    "bandolas": "bandola",
    "bandoleada": "bandolear",
    "bandoleadas": "bandolear",
    "bandoleado": "bandolear",
    "bandoleados": "bandolear",
    "bandoleai": "bandolear",
    "bandoleais": "bandolear",
    "bandoleamo": "bandolear",
    "bandoleamos": "bandolear",
    "bandoleando": "bandolear",
    "bandoleara": "bandolear",
    "bandolearam": "bandolear",
    "bandolearas": "bandolear",
    "bandoleardes": "bandolear",
    "bandolearei": "bandolear",
    "bandoleareis": "bandolear",
    "bandolearem": "bandolear",
    "bandolearemos": "bandolear",
    "bandoleares": "bandolear",
    "bandolearia": "bandolear",
    "bandoleariam": "bandolear",
    "bandolearias": "bandolear",
    "bandolearmo": "bandolear",
    "bandolearmos": "bandolear",
    "bandoleará": "bandolear",
    "bandolearás": "bandolear",
    "bandolearão": "bandolear",
    "bandolearíamos": "bandolear",
    "bandolearíeis": "bandolear",
    "bandoleasse": "bandolear",
    "bandoleassem": "bandolear",
    "bandoleasses": "bandolear",
    "bandoleaste": "bandolear",
    "bandoleastes": "bandolear",
    "bandoleava": "bandolear",
    "bandoleavam": "bandolear",
    "bandoleavas": "bandolear",
    "bandoleei": "bandolear",
    "bandoleeis": "bandolear",
    "bandoleemo": "bandolear",
    "bandoleemos": "bandolear",
    "bandoleia": "bandolear",
    "bandoleiam": "bandolear",
    "bandoleias": "bandolear",
    "bandoleie": "bandolear",
    "bandoleiem": "bandolear",
    "bandoleies": "bandolear",
    "bandoleio": "bandolear",
    "bandoleira": "bandoleiro",
    "bandoleiras": "bandoleiro",
    "bandoleirismos": "bandoleirismo",
    "bandoleiros": "bandoleiro",
    "bandoleou": "bandolear",
    "bandoletas": "bandoleta",
    "bandoleámo": "bandolear",
    "bandoleámos": "bandolear",
    "bandoleáramo": "bandolear",
    "bandoleáramos": "bandolear",
    "bandoleáreis": "bandolear",
    "bandoleásseis": "bandolear",
    "bandoleássemos": "bandolear",
    "bandoleávamo": "bandolear",
    "bandoleávamos": "bandolear",
    "bandoleáveis": "bandolear",
    "bandolinadas": "bandolinada",
    "bandolinas": "bandolina",
    "bandolinistas": "bandolinista",
    "bandolins": "bandolim",
    "bandorias": "bandoria",
    "bandorristas": "bandorrista",
    "bandos": "bando",
    "bandou": "bandar",
    "bandulhos": "bandulho",
    "bandurra": "bandurrar",
    "bandurrada": "bandurrar",
    "bandurradas": "bandurrar",
    "bandurrado": "bandurrar",
    "bandurrados": "bandurrar",
    "bandurrai": "bandurrar",
    "bandurrais": "bandurrar",
    "bandurram": "bandurrar",
    "bandurramo": "bandurrar",
    "bandurramos": "bandurrar",
    "bandurrando": "bandurrar",
    "bandurrara": "bandurrar",
    "bandurraram": "bandurrar",
    "bandurraras": "bandurrar",
    "bandurrardes": "bandurrar",
    "bandurrarei": "bandurrar",
    "bandurrareis": "bandurrar",
    "bandurrarem": "bandurrar",
    "bandurraremos": "bandurrar",
    "bandurrares": "bandurrar",
    "bandurraria": "bandurrar",
    "bandurrariam": "bandurrar",
    "bandurrarias": "bandurrar",
    "bandurrarmo": "bandurrar",
    "bandurrarmos": "bandurrar",
    "bandurrará": "bandurrar",
    "bandurrarás": "bandurrar",
    "bandurrarão": "bandurrar",
    "bandurraríamos": "bandurrar",
    "bandurraríeis": "bandurrar",
    "bandurras": "bandurrar",
    "bandurrasse": "bandurrar",
    "bandurrassem": "bandurrar",
    "bandurrasses": "bandurrar",
    "bandurraste": "bandurrar",
    "bandurrastes": "bandurrar",
    "bandurrava": "bandurrar",
    "bandurravam": "bandurrar",
    "bandurravas": "bandurrar",
    "bandurre": "bandurrar",
    "bandurreada": "bandurrear",
    "bandurreadas": "bandurrear",
    "bandurreado": "bandurrear",
    "bandurreados": "bandurrear",
    "bandurreai": "bandurrear",
    "bandurreais": "bandurrear",
    "bandurreamo": "bandurrear",
    "bandurreamos": "bandurrear",
    "bandurreando": "bandurrear",
    "bandurreara": "bandurrear",
    "bandurrearam": "bandurrear",
    "bandurrearas": "bandurrear",
    "bandurreardes": "bandurrear",
    "bandurrearei": "bandurrear",
    "bandurreareis": "bandurrear",
    "bandurrearem": "bandurrear",
    "bandurrearemos": "bandurrear",
    "bandurreares": "bandurrear",
    "bandurrearia": "bandurrear",
    "bandurreariam": "bandurrear",
    "bandurrearias": "bandurrear",
    "bandurrearmo": "bandurrear",
    "bandurrearmos": "bandurrear",
    "bandurreará": "bandurrear",
    "bandurrearás": "bandurrear",
    "bandurrearão": "bandurrear",
    "bandurrearíamos": "bandurrear",
    "bandurrearíeis": "bandurrear",
    "bandurreasse": "bandurrear",
    "bandurreassem": "bandurrear",
    "bandurreasses": "bandurrear",
    "bandurreaste": "bandurrear",
    "bandurreastes": "bandurrear",
    "bandurreava": "bandurrear",
    "bandurreavam": "bandurrear",
    "bandurreavas": "bandurrear",
    "bandurreei": "bandurrear",
    "bandurreeis": "bandurrear",
    "bandurreemo": "bandurrear",
    "bandurreemos": "bandurrear",
    "bandurrei": "bandurrar",
    "bandurreia": "bandurrear",
    "bandurreiam": "bandurrear",
    "bandurreias": "bandurrear",
    "bandurreie": "bandurrear",
    "bandurreiem": "bandurrear",
    "bandurreies": "bandurrear",
    "bandurreio": "bandurrear",
    "bandurreis": "bandurrar",
    "bandurrem": "bandurrar",
    "bandurremo": "bandurrar",
    "bandurremos": "bandurrar",
    "bandurreou": "bandurrear",
    "bandurres": "bandurrar",
    "bandurreámo": "bandurrear",
    "bandurreámos": "bandurrear",
    "bandurreáramo": "bandurrear",
    "bandurreáramos": "bandurrear",
    "bandurreáreis": "bandurrear",
    "bandurreásseis": "bandurrear",
    "bandurreássemos": "bandurrear",
    "bandurreávamo": "bandurrear",
    "bandurreávamos": "bandurrear",
    "bandurreáveis": "bandurrear",
    "bandurrilhas": "bandurrilha",
    "bandurro": "bandurrar",
    "bandurrou": "bandurrar",
    "bandurrámo": "bandurrar",
    "bandurrámos": "bandurrar",
    "bandurráramo": "bandurrar",
    "bandurráramos": "bandurrar",
    "bandurráreis": "bandurrar",
    "bandurrásseis": "bandurrar",
    "bandurrássemos": "bandurrar",
    "bandurrávamo": "bandurrar",
    "bandurrávamos": "bandurrar",
    "bandurráveis": "bandurrar",
    "bandá": "bandar",
    "bandámo": "bandar",
    "bandámos": "bandar",
    "bandáramo": "bandar",
    "bandáramos": "bandar",
    "bandárei": "bandar",
    "bandáreis": "bandar",
    "bandásseis": "bandar",
    "bandássemos": "bandar",
    "bandávamo": "bandar",
    "bandávamos": "bandar",
    "bandávei": "bandar",
    "bandáveis": "bandar",
    "bandónios": "bandónio",
    "bandós": "bandó",
    "bane": "banir",
    "baneanes": "baneane",
    "banem": "banir",
    "banes": "banir",
    "banesianismos": "banesianismo",
    "banga": "bango",
    "bangalas": "bangala",
    "bangalés": "bangalé",
    "bangalós": "bangaló",
    "bangalôs": "bangalô",
    "bangas": "bango",
    "bangos": "bango",
    "bangs": "bang",
    "bangueira": "bangueiro",
    "bangueiras": "bangueiro",
    "bangueiros": "bangueiro",
    "bangues": "bangue",
    "bangués": "bangué",
    "banha": "banhar",
    "banhada": "banhar",
    "banhadas": "banhar",
    "banhado": "banhar",
    "banhados": "banhar",
    "banhai": "banhar",
    "banhais": "banhar",
    "banham": "banhar",
    "banhamo": "banhar",
    "banhamos": "banhar",
    "banhando": "banhar",
    "banhara": "banhar",
    "banharam": "banhar",
    "banharas": "banhar",
    "banharde": "banhar",
    "banhardes": "banhar",
    "banhare": "banhar",
    "banharei": "banhar",
    "banhareis": "banhar",
    "banharem": "banhar",
    "banharemos": "banhar",
    "banhares": "banhar",
    "banharia": "banhar",
    "banhariam": "banhar",
    "banharias": "banhar",
    "banharmo": "banhar",
    "banharmos": "banhar",
    "banhará": "banhar",
    "banharás": "banhar",
    "banharão": "banhar",
    "banharíamos": "banhar",
    "banharíeis": "banhar",
    "banhas": "banhar",
    "banhasse": "banhar",
    "banhassem": "banhar",
    "banhasses": "banhar",
    "banhaste": "banhar",
    "banhastes": "banhar",
    "banhava": "banhar",
    "banhavam": "banhar",
    "banhavas": "banhar",
    "banhe": "banhar",
    "banhei": "banhar",
    "banheiras": "banheira",
    "banheiros": "banheiro",
    "banheis": "banhar",
    "banhem": "banhar",
    "banhemo": "banhar",
    "banhemos": "banhar",
    "banhes": "banhar",
    "banhinho": "banho",
    "banhinhos": "banho",
    "banhistas": "banhista",
    "banhito": "banho",
    "banhitos": "banho",
    "banho": "banhar",
    "banhocas": "banhoca",
    "banhos": "banho",
    "banhou": "banhar",
    "banhá": "banhar",
    "banhámo": "banhar",
    "banhámos": "banhar",
    "banháramo": "banhar",
    "banháramos": "banhar",
    "banhárei": "banhar",
    "banháreis": "banhar",
    "banhásseis": "banhar",
    "banhássemos": "banhar",
    "banhávamo": "banhar",
    "banhávamos": "banhar",
    "banhávei": "banhar",
    "banháveis": "banhar",
    "bani": "banir",
    "bania": "banir",
    "baniam": "banir",
    "banianos": "baniano",
    "banias": "banir",
    "banida": "banir",
    "banidas": "banir",
    "banido": "banir",
    "banidores": "banidor",
    "banidos": "banir",
    "banimentos": "banimento",
    "banimo": "banir",
    "banimos": "banir",
    "banindo": "banir",
    "banira": "banir",
    "baniram": "banir",
    "baniras": "banir",
    "banirde": "banir",
    "banirdes": "banir",
    "banire": "banir",
    "banirei": "banir",
    "banireis": "banir",
    "banirem": "banir",
    "baniremos": "banir",
    "banires": "banir",
    "baniria": "banir",
    "baniriam": "banir",
    "banirias": "banir",
    "banirmo": "banir",
    "banirmos": "banir",
    "banirá": "banir",
    "banirás": "banir",
    "banirão": "banir",
    "baniríamos": "banir",
    "baniríeis": "banir",
    "banis": "banir",
    "banisse": "banir",
    "banissem": "banir",
    "banisses": "banir",
    "baniste": "banir",
    "banistes": "banir",
    "baniu": "banir",
    "banjos": "banjo",
    "bano": "banir",
    "banqueira": "banqueiro",
    "banqueiras": "banqueiro",
    "banqueiros": "banqueiro",
    "banquetas": "banqueta",
    "banqueteada": "banquetear",
    "banqueteadas": "banquetear",
    "banqueteado": "banquetear",
    "banqueteadora": "banqueteador",
    "banqueteadoras": "banqueteador",
    "banqueteadores": "banqueteador",
    "banqueteados": "banquetear",
    "banqueteai": "banquetear",
    "banqueteais": "banquetear",
    "banqueteamo": "banquetear",
    "banqueteamos": "banquetear",
    "banqueteando": "banquetear",
    "banqueteara": "banquetear",
    "banquetearam": "banquetear",
    "banquetearas": "banquetear",
    "banqueteardes": "banquetear",
    "banquetearei": "banquetear",
    "banqueteareis": "banquetear",
    "banquetearem": "banquetear",
    "banquetearemos": "banquetear",
    "banqueteares": "banquetear",
    "banquetearia": "banquetear",
    "banqueteariam": "banquetear",
    "banquetearias": "banquetear",
    "banquetearmo": "banquetear",
    "banquetearmos": "banquetear",
    "banqueteará": "banquetear",
    "banquetearás": "banquetear",
    "banquetearão": "banquetear",
    "banquetearíamos": "banquetear",
    "banquetearíeis": "banquetear",
    "banqueteasse": "banquetear",
    "banqueteassem": "banquetear",
    "banqueteasses": "banquetear",
    "banqueteaste": "banquetear",
    "banqueteastes": "banquetear",
    "banqueteava": "banquetear",
    "banqueteavam": "banquetear",
    "banqueteavas": "banquetear",
    "banqueteei": "banquetear",
    "banqueteeis": "banquetear",
    "banqueteemo": "banquetear",
    "banqueteemos": "banquetear",
    "banqueteia": "banquetear",
    "banqueteiam": "banquetear",
    "banqueteias": "banquetear",
    "banqueteie": "banquetear",
    "banqueteiem": "banquetear",
    "banqueteies": "banquetear",
    "banqueteio": "banquetear",
    "banqueteou": "banquetear",
    "banquetes": "banquete",
    "banqueteámo": "banquetear",
    "banqueteámos": "banquetear",
    "banqueteáramo": "banquetear",
    "banqueteáramos": "banquetear",
    "banqueteáreis": "banquetear",
    "banqueteásseis": "banquetear",
    "banqueteássemos": "banquetear",
    "banqueteávamo": "banquetear",
    "banqueteávamos": "banquetear",
    "banqueteáveis": "banquetear",
    "banquinho": "banco",
    "banquinhos": "banco",
    "banquisas": "banquisa",
    "banquito": "banco",
    "banquitos": "banco",
    "banta": "banto",
    "bantas": "banto",
    "bantologias": "bantologia",
    "bantos": "banto",
    "bantus": "bantu",
    "bantustões": "bantustão",
    "bantóloga": "bantólogo",
    "bantólogas": "bantólogo",
    "bantólogos": "bantólogo",
    "banza": "banzar",
    "banzada": "banzar",
    "banzadas": "banzar",
    "banzado": "banzar",
    "banzados": "banzar",
    "banzai": "banzar",
    "banzais": "banzar",
    "banzam": "banzar",
    "banzamo": "banzar",
    "banzamos": "banzar",
    "banzando": "banzar",
    "banzara": "banzar",
    "banzaram": "banzar",
    "banzaras": "banzar",
    "banzarde": "banzar",
    "banzardes": "banzar",
    "banzare": "banzar",
    "banzarei": "banzar",
    "banzareis": "banzar",
    "banzarem": "banzar",
    "banzaremos": "banzar",
    "banzares": "banzar",
    "banzaria": "banzar",
    "banzariam": "banzar",
    "banzarias": "banzar",
    "banzarmo": "banzar",
    "banzarmos": "banzar",
    "banzará": "banzar",
    "banzarás": "banzar",
    "banzarão": "banzar",
    "banzaríamos": "banzar",
    "banzaríeis": "banzar",
    "banzas": "banzar",
    "banzasse": "banzar",
    "banzassem": "banzar",
    "banzasses": "banzar",
    "banzaste": "banzar",
    "banzastes": "banzar",
    "banzava": "banzar",
    "banzavam": "banzar",
    "banzavas": "banzar",
    "banze": "banzar",
    "banzei": "banzar",
    "banzeira": "banzeiro",
    "banzeiras": "banzeiro",
    "banzeiros": "banzeiro",
    "banzeis": "banzar",
    "banzem": "banzar",
    "banzemo": "banzar",
    "banzemos": "banzar",
    "banzes": "banzar",
    "banzo": "banzar",
    "banzos": "banzo",
    "banzou": "banzar",
    "banzá": "banzar",
    "banzámo": "banzar",
    "banzámos": "banzar",
    "banzáramo": "banzar",
    "banzáramos": "banzar",
    "banzárei": "banzar",
    "banzáreis": "banzar",
    "banzásseis": "banzar",
    "banzássemos": "banzar",
    "banzávamo": "banzar",
    "banzávamos": "banzar",
    "banzávei": "banzar",
    "banzáveis": "banzar",
    "banzés": "banzé",
    "baníamo": "banir",
    "baníamos": "banir",
    "baníei": "banir",
    "baníeis": "banir",
    "baníramo": "banir",
    "baníramos": "banir",
    "banírei": "banir",
    "baníreis": "banir",
    "banísseis": "banir",
    "baníssemos": "banir",
    "baníveis": "banível",
    "baobabes": "baobabe",
    "baobás": "baobá",
    "baptismais": "baptismal",
    "baptismos": "baptismo",
    "baptistas": "baptista",
    "baptistina": "baptistino",
    "baptistinas": "baptistino",
    "baptistinos": "baptistino",
    "baptistérios": "baptistério",
    "baptiza": "baptizar",
    "baptizada": "baptizar",
    "baptizadas": "baptizar",
    "baptizado": "baptizar",
    "baptizados": "baptizar",
    "baptizai": "baptizar",
    "baptizais": "baptizar",
    "baptizam": "baptizar",
    "baptizamo": "baptizar",
    "baptizamos": "baptizar",
    "baptizando": "baptizar",
    "baptizandos": "baptizando",
    "baptizantes": "baptizante",
    "baptizara": "baptizar",
    "baptizaram": "baptizar",
    "baptizaras": "baptizar",
    "baptizarde": "baptizar",
    "baptizardes": "baptizar",
    "baptizare": "baptizar",
    "baptizarei": "baptizar",
    "baptizareis": "baptizar",
    "baptizarem": "baptizar",
    "baptizaremos": "baptizar",
    "baptizares": "baptizar",
    "baptizaria": "baptizar",
    "baptizariam": "baptizar",
    "baptizarias": "baptizar",
    "baptizarmo": "baptizar",
    "baptizarmos": "baptizar",
    "baptizará": "baptizar",
    "baptizarás": "baptizar",
    "baptizarão": "baptizar",
    "baptizaríamos": "baptizar",
    "baptizaríeis": "baptizar",
    "baptizas": "baptizar",
    "baptizasse": "baptizar",
    "baptizassem": "baptizar",
    "baptizasses": "baptizar",
    "baptizaste": "baptizar",
    "baptizastes": "baptizar",
    "baptizava": "baptizar",
    "baptizavam": "baptizar",
    "baptizavas": "baptizar",
    "baptize": "baptizar",
    "baptizei": "baptizar",
    "baptizeis": "baptizar",
    "baptizem": "baptizar",
    "baptizemo": "baptizar",
    "baptizemos": "baptizar",
    "baptizes": "baptizar",
    "baptizo": "baptizar",
    "baptizos": "baptizo",
    "baptizou": "baptizar",
    "baptizá": "baptizar",
    "baptizámo": "baptizar",
    "baptizámos": "baptizar",
    "baptizáramo": "baptizar",
    "baptizáramos": "baptizar",
    "baptizárei": "baptizar",
    "baptizáreis": "baptizar",
    "baptizásseis": "baptizar",
    "baptizássemos": "baptizar",
    "baptizávamo": "baptizar",
    "baptizávamos": "baptizar",
    "baptizávei": "baptizar",
    "baptizáveis": "baptizar",
    "baqueada": "baquear",
    "baqueadas": "baquear",
    "baqueado": "baquear",
    "baqueados": "baquear",
    "baqueai": "baquear",
    "baqueais": "baquear",
    "baqueamo": "baquear",
    "baqueamos": "baquear",
    "baqueando": "baquear",
    "baqueara": "baquear",
    "baquearam": "baquear",
    "baquearas": "baquear",
    "baqueardes": "baquear",
    "baquearei": "baquear",
    "baqueareis": "baquear",
    "baquearem": "baquear",
    "baquearemos": "baquear",
    "baqueares": "baquear",
    "baquearia": "baquear",
    "baqueariam": "baquear",
    "baquearias": "baquear",
    "baquearmo": "baquear",
    "baquearmos": "baquear",
    "baqueará": "baquear",
    "baquearás": "baquear",
    "baquearão": "baquear",
    "baquearíamos": "baquear",
    "baquearíeis": "baquear",
    "baqueasse": "baquear",
    "baqueassem": "baquear",
    "baqueasses": "baquear",
    "baqueaste": "baquear",
    "baqueastes": "baquear",
    "baqueava": "baquear",
    "baqueavam": "baquear",
    "baqueavas": "baquear",
    "baqueei": "baquear",
    "baqueeis": "baquear",
    "baqueemo": "baquear",
    "baqueemos": "baquear",
    "baqueia": "baquear",
    "baqueiam": "baquear",
    "baqueias": "baquear",
    "baqueie": "baquear",
    "baqueiem": "baquear",
    "baqueies": "baquear",
    "baqueio": "baquear",
    "baquelitas": "baquelita",
    "baquelites": "baquelite",
    "baqueou": "baquear",
    "baques": "baque",
    "baqueta": "baquetar",
    "baquetada": "baquetar",
    "baquetadas": "baquetar",
    "baquetado": "baquetar",
    "baquetados": "baquetar",
    "baquetai": "baquetar",
    "baquetais": "baquetar",
    "baquetam": "baquetar",
    "baquetamo": "baquetar",
    "baquetamos": "baquetar",
    "baquetando": "baquetar",
    "baquetara": "baquetar",
    "baquetaram": "baquetar",
    "baquetaras": "baquetar",
    "baquetardes": "baquetar",
    "baquetarei": "baquetar",
    "baquetareis": "baquetar",
    "baquetarem": "baquetar",
    "baquetaremos": "baquetar",
    "baquetares": "baquetar",
    "baquetaria": "baquetar",
    "baquetariam": "baquetar",
    "baquetarias": "baquetar",
    "baquetarmo": "baquetar",
    "baquetarmos": "baquetar",
    "baquetará": "baquetar",
    "baquetarás": "baquetar",
    "baquetarão": "baquetar",
    "baquetaríamos": "baquetar",
    "baquetaríeis": "baquetar",
    "baquetas": "baquetar",
    "baquetasse": "baquetar",
    "baquetassem": "baquetar",
    "baquetasses": "baquetar",
    "baquetaste": "baquetar",
    "baquetastes": "baquetar",
    "baquetava": "baquetar",
    "baquetavam": "baquetar",
    "baquetavas": "baquetar",
    "baquete": "baquetar",
    "baqueteada": "baquetear",
    "baqueteadas": "baquetear",
    "baqueteado": "baquetear",
    "baqueteados": "baquetear",
    "baqueteai": "baquetear",
    "baqueteais": "baquetear",
    "baqueteamo": "baquetear",
    "baqueteamos": "baquetear",
    "baqueteando": "baquetear",
    "baqueteara": "baquetear",
    "baquetearam": "baquetear",
    "baquetearas": "baquetear",
    "baqueteardes": "baquetear",
    "baquetearei": "baquetear",
    "baqueteareis": "baquetear",
    "baquetearem": "baquetear",
    "baquetearemos": "baquetear",
    "baqueteares": "baquetear",
    "baquetearia": "baquetear",
    "baqueteariam": "baquetear",
    "baquetearias": "baquetear",
    "baquetearmo": "baquetear",
    "baquetearmos": "baquetear",
    "baqueteará": "baquetear",
    "baquetearás": "baquetear",
    "baquetearão": "baquetear",
    "baquetearíamos": "baquetear",
    "baquetearíeis": "baquetear",
    "baqueteasse": "baquetear",
    "baqueteassem": "baquetear",
    "baqueteasses": "baquetear",
    "baqueteaste": "baquetear",
    "baqueteastes": "baquetear",
    "baqueteava": "baquetear",
    "baqueteavam": "baquetear",
    "baqueteavas": "baquetear",
    "baqueteei": "baquetear",
    "baqueteeis": "baquetear",
    "baqueteemo": "baquetear",
    "baqueteemos": "baquetear",
    "baquetei": "baquetar",
    "baqueteia": "baquetear",
    "baqueteiam": "baquetear",
    "baqueteias": "baquetear",
    "baqueteie": "baquetear",
    "baqueteiem": "baquetear",
    "baqueteies": "baquetear",
    "baqueteio": "baquetear",
    "baqueteis": "baquetar",
    "baquetem": "baquetar",
    "baquetemo": "baquetar",
    "baquetemos": "baquetar",
    "baqueteou": "baquetear",
    "baquetes": "baquetar",
    "baqueteámo": "baquetear",
    "baqueteámos": "baquetear",
    "baqueteáramo": "baquetear",
    "baqueteáramos": "baquetear",
    "baqueteáreis": "baquetear",
    "baqueteásseis": "baquetear",
    "baqueteássemos": "baquetear",
    "baqueteávamo": "baquetear",
    "baqueteávamos": "baquetear",
    "baqueteáveis": "baquetear",
    "baqueto": "baquetar",
    "baquetou": "baquetar",
    "baquetámo": "baquetar",
    "baquetámos": "baquetar",
    "baquetáramo": "baquetar",
    "baquetáramos": "baquetar",
    "baquetáreis": "baquetar",
    "baquetásseis": "baquetar",
    "baquetássemos": "baquetar",
    "baquetávamo": "baquetar",
    "baquetávamos": "baquetar",
    "baquetáveis": "baquetar",
    "baqueámo": "baquear",
    "baqueámos": "baquear",
    "baqueáramo": "baquear",
    "baqueáramos": "baquear",
    "baqueáreis": "baquear",
    "baqueásseis": "baquear",
    "baqueássemos": "baquear",
    "baqueávamo": "baquear",
    "baqueávamos": "baquear",
    "baqueáveis": "baquear",
    "baquistas": "baquista",
    "baracha": "barachar",
    "barachada": "barachar",
    "barachadas": "barachar",
    "barachado": "barachar",
    "barachados": "barachar",
    "barachai": "barachar",
    "barachais": "barachar",
    "baracham": "barachar",
    "barachamo": "barachar",
    "barachamos": "barachar",
    "barachando": "barachar",
    "barachara": "barachar",
    "baracharam": "barachar",
    "baracharas": "barachar",
    "barachardes": "barachar",
    "baracharei": "barachar",
    "barachareis": "barachar",
    "baracharem": "barachar",
    "baracharemos": "barachar",
    "barachares": "barachar",
    "baracharia": "barachar",
    "barachariam": "barachar",
    "baracharias": "barachar",
    "baracharmo": "barachar",
    "baracharmos": "barachar",
    "barachará": "barachar",
    "baracharás": "barachar",
    "baracharão": "barachar",
    "baracharíamos": "barachar",
    "baracharíeis": "barachar",
    "barachas": "barachar",
    "barachasse": "barachar",
    "barachassem": "barachar",
    "barachasses": "barachar",
    "barachaste": "barachar",
    "barachastes": "barachar",
    "barachava": "barachar",
    "barachavam": "barachar",
    "barachavas": "barachar",
    "barache": "barachar",
    "barachei": "barachar",
    "baracheis": "barachar",
    "barachem": "barachar",
    "barachemo": "barachar",
    "barachemos": "barachar",
    "baraches": "barachar",
    "baracho": "barachar",
    "barachou": "barachar",
    "barachámo": "barachar",
    "barachámos": "barachar",
    "baracháramo": "barachar",
    "baracháramos": "barachar",
    "baracháreis": "barachar",
    "barachásseis": "barachar",
    "barachássemos": "barachar",
    "barachávamo": "barachar",
    "barachávamos": "barachar",
    "baracháveis": "barachar",
    "barafundas": "barafunda",
    "barafusta": "barafustar",
    "barafustada": "barafustar",
    "barafustadas": "barafustar",
    "barafustado": "barafustar",
    "barafustados": "barafustar",
    "barafustai": "barafustar",
    "barafustais": "barafustar",
    "barafustam": "barafustar",
    "barafustamo": "barafustar",
    "barafustamos": "barafustar",
    "barafustando": "barafustar",
    "barafustara": "barafustar",
    "barafustaram": "barafustar",
    "barafustaras": "barafustar",
    "barafustardes": "barafustar",
    "barafustarei": "barafustar",
    "barafustareis": "barafustar",
    "barafustarem": "barafustar",
    "barafustaremos": "barafustar",
    "barafustares": "barafustar",
    "barafustaria": "barafustar",
    "barafustariam": "barafustar",
    "barafustarias": "barafustar",
    "barafustarmo": "barafustar",
    "barafustarmos": "barafustar",
    "barafustará": "barafustar",
    "barafustarás": "barafustar",
    "barafustarão": "barafustar",
    "barafustaríamos": "barafustar",
    "barafustaríeis": "barafustar",
    "barafustas": "barafustar",
    "barafustasse": "barafustar",
    "barafustassem": "barafustar",
    "barafustasses": "barafustar",
    "barafustaste": "barafustar",
    "barafustastes": "barafustar",
    "barafustava": "barafustar",
    "barafustavam": "barafustar",
    "barafustavas": "barafustar",
    "barafuste": "barafustar",
    "barafustei": "barafustar",
    "barafusteis": "barafustar",
    "barafustem": "barafustar",
    "barafustemo": "barafustar",
    "barafustemos": "barafustar",
    "barafustes": "barafustar",
    "barafusto": "barafustar",
    "barafustou": "barafustar",
    "barafustámo": "barafustar",
    "barafustámos": "barafustar",
    "barafustáramo": "barafustar",
    "barafustáramos": "barafustar",
    "barafustáreis": "barafustar",
    "barafustásseis": "barafustar",
    "barafustássemos": "barafustar",
    "barafustávamo": "barafustar",
    "barafustávamos": "barafustar",
    "barafustáveis": "barafustar",
    "baralha": "baralhar",
    "baralhada": "baralhar",
    "baralhadas": "baralhar",
    "baralhado": "baralhar",
    "baralhadora": "baralhador",
    "baralhadoras": "baralhador",
    "baralhadores": "baralhador",
    "baralhados": "baralhar",
    "baralhadíssima": "baralhado",
    "baralhadíssimas": "baralhado",
    "baralhadíssimo": "baralhado",
    "baralhadíssimos": "baralhado",
    "baralhai": "baralhar",
    "baralhais": "baralhar",
    "baralham": "baralhar",
    "baralhamentos": "baralhamento",
    "baralhamo": "baralhar",
    "baralhamos": "baralhar",
    "baralhando": "baralhar",
    "baralhara": "baralhar",
    "baralharam": "baralhar",
    "baralharas": "baralhar",
    "baralharde": "baralhar",
    "baralhardes": "baralhar",
    "baralhare": "baralhar",
    "baralharei": "baralhar",
    "baralhareis": "baralhar",
    "baralharem": "baralhar",
    "baralharemos": "baralhar",
    "baralhares": "baralhar",
    "baralharia": "baralhar",
    "baralhariam": "baralhar",
    "baralharias": "baralhar",
    "baralharmo": "baralhar",
    "baralharmos": "baralhar",
    "baralhará": "baralhar",
    "baralharás": "baralhar",
    "baralharão": "baralhar",
    "baralharíamos": "baralhar",
    "baralharíeis": "baralhar",
    "baralhas": "baralhar",
    "baralhasse": "baralhar",
    "baralhassem": "baralhar",
    "baralhasses": "baralhar",
    "baralhaste": "baralhar",
    "baralhastes": "baralhar",
    "baralhava": "baralhar",
    "baralhavam": "baralhar",
    "baralhavas": "baralhar",
    "baralhações": "baralhação",
    "baralhe": "baralhar",
    "baralhei": "baralhar",
    "baralheis": "baralhar",
    "baralhem": "baralhar",
    "baralhemo": "baralhar",
    "baralhemos": "baralhar",
    "baralhes": "baralhar",
    "baralho": "baralhar",
    "baralhos": "baralho",
    "baralhou": "baralhar",
    "baralhá": "baralhar",
    "baralhámo": "baralhar",
    "baralhámos": "baralhar",
    "baralháramo": "baralhar",
    "baralháramos": "baralhar",
    "baralhárei": "baralhar",
    "baralháreis": "baralhar",
    "baralhásseis": "baralhar",
    "baralhássemos": "baralhar",
    "baralhávamo": "baralhar",
    "baralhávamos": "baralhar",
    "baralhávei": "baralhar",
    "baralháveis": "baralhável",
    "barambazes": "barambaz",
    "baranhos": "baranho",
    "barata": "barato",
    "baratada": "baratar",
    "baratadas": "baratar",
    "baratado": "baratar",
    "baratados": "baratar",
    "baratai": "baratar",
    "baratais": "baratar",
    "baratam": "baratar",
    "baratamo": "baratar",
    "baratamos": "baratar",
    "baratando": "baratar",
    "baratara": "baratar",
    "barataram": "baratar",
    "barataras": "baratar",
    "baratarde": "baratar",
    "baratardes": "baratar",
    "baratare": "baratar",
    "baratarei": "baratar",
    "baratareis": "baratar",
    "baratarem": "baratar",
    "barataremos": "baratar",
    "baratares": "baratar",
    "barataria": "baratar",
    "baratariam": "baratar",
    "baratarias": "barataria",
    "baratarmo": "baratar",
    "baratarmos": "baratar",
    "baratará": "baratar",
    "baratarás": "baratar",
    "baratarão": "baratar",
    "barataríamos": "baratar",
    "barataríeis": "baratar",
    "baratas": "barato",
    "baratasse": "baratar",
    "baratassem": "baratar",
    "baratasses": "baratar",
    "barataste": "baratar",
    "baratastes": "baratar",
    "baratava": "baratar",
    "baratavam": "baratar",
    "baratavas": "baratar",
    "baratazinha": "barato",
    "baratazinhas": "barato",
    "baratazita": "barato",
    "baratazitas": "barato",
    "barate": "baratar",
    "barateada": "baratear",
    "barateadas": "baratear",
    "barateado": "baratear",
    "barateadora": "barateador",
    "barateadoras": "barateador",
    "barateadores": "barateador",
    "barateados": "baratear",
    "barateai": "baratear",
    "barateais": "baratear",
    "barateamentos": "barateamento",
    "barateamo": "baratear",
    "barateamos": "baratear",
    "barateando": "baratear",
    "barateara": "baratear",
    "baratearam": "baratear",
    "baratearas": "baratear",
    "baratearde": "baratear",
    "barateardes": "baratear",
    "barateare": "baratear",
    "baratearei": "baratear",
    "barateareis": "baratear",
    "baratearem": "baratear",
    "baratearemos": "baratear",
    "barateares": "baratear",
    "baratearia": "baratear",
    "barateariam": "baratear",
    "baratearias": "baratear",
    "baratearmo": "baratear",
    "baratearmos": "baratear",
    "barateará": "baratear",
    "baratearás": "baratear",
    "baratearão": "baratear",
    "baratearíamos": "baratear",
    "baratearíeis": "baratear",
    "barateasse": "baratear",
    "barateassem": "baratear",
    "barateasses": "baratear",
    "barateaste": "baratear",
    "barateastes": "baratear",
    "barateava": "baratear",
    "barateavam": "baratear",
    "barateavas": "baratear",
    "barateei": "baratear",
    "barateeis": "baratear",
    "barateemo": "baratear",
    "barateemos": "baratear",
    "baratei": "baratar",
    "barateia": "baratear",
    "barateiam": "baratear",
    "barateias": "baratear",
    "barateie": "baratear",
    "barateiem": "baratear",
    "barateies": "baratear",
    "barateio": "baratear",
    "barateios": "barateio",
    "barateira": "barateiro",
    "barateiras": "barateiro",
    "barateiros": "barateiro",
    "barateis": "baratar",
    "baratem": "baratar",
    "baratemo": "baratar",
    "baratemos": "baratar",
    "barateou": "baratear",
    "barates": "baratar",
    "baratezas": "barateza",
    "barateá": "baratear",
    "barateámo": "baratear",
    "barateámos": "baratear",
    "barateáramo": "baratear",
    "barateáramos": "baratear",
    "barateárei": "baratear",
    "barateáreis": "baratear",
    "barateásseis": "baratear",
    "barateássemos": "baratear",
    "barateávamo": "baratear",
    "barateávamos": "baratear",
    "barateávei": "baratear",
    "barateáveis": "baratear",
    "baraticidas": "baraticida",
    "baratinada": "baratinado",
    "baratinadas": "baratinado",
    "baratinados": "baratinado",
    "baratinha": "barato",
    "baratinhas": "barato",
    "baratinho": "barato",
    "baratinhos": "barato",
    "baratita": "barato",
    "baratitas": "barato",
    "baratito": "barato",
    "baratitos": "barato",
    "barato": "baratar",
    "baratométrica": "baratométrico",
    "baratométricas": "baratométrico",
    "baratométricos": "baratométrico",
    "baratos": "barato",
    "baratou": "baratar",
    "baratozinho": "barato",
    "baratozinhos": "barato",
    "baratozito": "barato",
    "baratozitos": "barato",
    "baratá": "baratar",
    "baratámo": "baratar",
    "baratámos": "baratar",
    "baratáramo": "baratar",
    "baratáramos": "baratar",
    "baratárei": "baratar",
    "baratáreis": "baratar",
    "baratásseis": "baratar",
    "baratássemos": "baratar",
    "baratávamo": "baratar",
    "baratávamos": "baratar",
    "baratávei": "baratar",
    "baratáveis": "baratar",
    "baratíssima": "barato",
    "baratíssimas": "barato",
    "baratíssimo": "barato",
    "baratíssimos": "barato",
    "baratómetros": "baratómetro",
    "baraças": "baraça",
    "baraçejos": "baraçejo",
    "baraços": "baraço",
    "barba": "barbar",
    "barbacãs": "barbacã",
    "barbada": "barbar",
    "barbadas": "barbar",
    "barbadinhos": "barbadinho",
    "barbado": "barbar",
    "barbados": "barbar",
    "barbai": "barbar",
    "barbais": "barbar",
    "barbalhos": "barbalho",
    "barbalhostes": "barbalhoste",
    "barbam": "barbar",
    "barbamo": "barbar",
    "barbamos": "barbar",
    "barbando": "barbar",
    "barbantes": "barbante",
    "barbara": "barbar",
    "barbaram": "barbar",
    "barbaras": "barbara",
    "barbarazinha": "bárbaro",
    "barbarazinhas": "bárbaro",
    "barbarazita": "bárbaro",
    "barbarazitas": "bárbaro",
    "barbarde": "barbar",
    "barbardes": "barbar",
    "barbare": "barbar",
    "barbarei": "barbar",
    "barbareis": "barbar",
    "barbarem": "barbar",
    "barbaremos": "barbar",
    "barbares": "barbar",
    "barbaresca": "barbaresco",
    "barbarescas": "barbaresco",
    "barbarescos": "barbaresco",
    "barbaria": "barbar",
    "barbariam": "barbar",
    "barbarias": "barbaria",
    "barbarices": "barbarice",
    "barbaridades": "barbaridade",
    "barbariloquias": "barbariloquia",
    "barbarinha": "bárbaro",
    "barbarinhas": "bárbaro",
    "barbarinho": "bárbaro",
    "barbarinhos": "bárbaro",
    "barbarisca": "barbarisco",
    "barbariscas": "barbarisco",
    "barbariscos": "barbarisco",
    "barbarismos": "barbarismo",
    "barbarita": "bárbaro",
    "barbaritas": "bárbaro",
    "barbarito": "bárbaro",
    "barbaritos": "bárbaro",
    "barbariza": "barbarizar",
    "barbarizada": "barbarizar",
    "barbarizadas": "barbarizar",
    "barbarizado": "barbarizar",
    "barbarizados": "barbarizar",
    "barbarizai": "barbarizar",
    "barbarizais": "barbarizar",
    "barbarizam": "barbarizar",
    "barbarizamo": "barbarizar",
    "barbarizamos": "barbarizar",
    "barbarizando": "barbarizar",
    "barbarizara": "barbarizar",
    "barbarizaram": "barbarizar",
    "barbarizaras": "barbarizar",
    "barbarizarde": "barbarizar",
    "barbarizardes": "barbarizar",
    "barbarizare": "barbarizar",
    "barbarizarei": "barbarizar",
    "barbarizareis": "barbarizar",
    "barbarizarem": "barbarizar",
    "barbarizaremos": "barbarizar",
    "barbarizares": "barbarizar",
    "barbarizaria": "barbarizar",
    "barbarizariam": "barbarizar",
    "barbarizarias": "barbarizar",
    "barbarizarmo": "barbarizar",
    "barbarizarmos": "barbarizar",
    "barbarizará": "barbarizar",
    "barbarizarás": "barbarizar",
    "barbarizarão": "barbarizar",
    "barbarizaríamos": "barbarizar",
    "barbarizaríeis": "barbarizar",
    "barbarizas": "barbarizar",
    "barbarizasse": "barbarizar",
    "barbarizassem": "barbarizar",
    "barbarizasses": "barbarizar",
    "barbarizaste": "barbarizar",
    "barbarizastes": "barbarizar",
    "barbarizava": "barbarizar",
    "barbarizavam": "barbarizar",
    "barbarizavas": "barbarizar",
    "barbarizações": "barbarização",
    "barbarize": "barbarizar",
    "barbarizei": "barbarizar",
    "barbarizeis": "barbarizar",
    "barbarizem": "barbarizar",
    "barbarizemo": "barbarizar",
    "barbarizemos": "barbarizar",
    "barbarizes": "barbarizar",
    "barbarizo": "barbarizar",
    "barbarizou": "barbarizar",
    "barbarizá": "barbarizar",
    "barbarizámo": "barbarizar",
    "barbarizámos": "barbarizar",
    "barbarizáramo": "barbarizar",
    "barbarizáramos": "barbarizar",
    "barbarizárei": "barbarizar",
    "barbarizáreis": "barbarizar",
    "barbarizásseis": "barbarizar",
    "barbarizássemos": "barbarizar",
    "barbarizávamo": "barbarizar",
    "barbarizávamos": "barbarizar",
    "barbarizávei": "barbarizar",
    "barbarizáveis": "barbarizar",
    "barbarmo": "barbar",
    "barbarmos": "barbar",
    "barbarolexias": "barbarolexia",
    "barbarozinho": "bárbaro",
    "barbarozinhos": "bárbaro",
    "barbarozito": "bárbaro",
    "barbarozitos": "bárbaro",
    "barbará": "barbar",
    "barbarás": "barbar",
    "barbarão": "barbar",
    "barbaríamos": "barbar",
    "barbaríeis": "barbar",
    "barbaríssima": "bárbaro",
    "barbaríssimas": "bárbaro",
    "barbaríssimo": "bárbaro",
    "barbaríssimos": "bárbaro",
    "barbas": "barbar",
    "barbascos": "barbasco",
    "barbasse": "barbar",
    "barbassem": "barbar",
    "barbasses": "barbar",
    "barbaste": "barbar",
    "barbastes": "barbar",
    "barbata": "barbato",
    "barbatanas": "barbatana",
    "barbatas": "barbato",
    "barbatos": "barbato",
    "barbava": "barbar",
    "barbavam": "barbar",
    "barbavas": "barbar",
    "barbaçanas": "barbaçana",
    "barbaças": "barbaça",
    "barbaçuda": "barbaçudo",
    "barbaçudas": "barbaçudo",
    "barbaçudos": "barbaçudo",
    "barbaíscos": "barbaísco",
    "barbe": "barbar",
    "barbeada": "barbear",
    "barbeadas": "barbear",
    "barbeado": "barbear",
    "barbeadora": "barbeador",
    "barbeadoras": "barbeador",
    "barbeadores": "barbeador",
    "barbeados": "barbear",
    "barbeai": "barbear",
    "barbeais": "barbear",
    "barbealçada": "barbealçado",
    "barbealçadas": "barbealçado",
    "barbealçados": "barbealçado",
    "barbeamo": "barbear",
    "barbeamos": "barbear",
    "barbeando": "barbear",
    "barbeara": "barbear",
    "barbearam": "barbear",
    "barbearas": "barbear",
    "barbearde": "barbear",
    "barbeardes": "barbear",
    "barbeare": "barbear",
    "barbearei": "barbear",
    "barbeareis": "barbear",
    "barbearem": "barbear",
    "barbearemos": "barbear",
    "barbeares": "barbear",
    "barbearia": "barbear",
    "barbeariam": "barbear",
    "barbearias": "barbearia",
    "barbearmo": "barbear",
    "barbearmos": "barbear",
    "barbeará": "barbear",
    "barbearás": "barbear",
    "barbearão": "barbear",
    "barbearíamos": "barbear",
    "barbearíeis": "barbear",
    "barbeasse": "barbear",
    "barbeassem": "barbear",
    "barbeasses": "barbear",
    "barbeaste": "barbear",
    "barbeastes": "barbear",
    "barbeava": "barbear",
    "barbeavam": "barbear",
    "barbeavas": "barbear",
    "barbeações": "barbeação",
    "barbecha": "barbechar",
    "barbechada": "barbechar",
    "barbechadas": "barbechar",
    "barbechado": "barbechar",
    "barbechados": "barbechar",
    "barbechai": "barbechar",
    "barbechais": "barbechar",
    "barbecham": "barbechar",
    "barbechamo": "barbechar",
    "barbechamos": "barbechar",
    "barbechando": "barbechar",
    "barbechara": "barbechar",
    "barbecharam": "barbechar",
    "barbecharas": "barbechar",
    "barbecharde": "barbechar",
    "barbechardes": "barbechar",
    "barbechare": "barbechar",
    "barbecharei": "barbechar",
    "barbechareis": "barbechar",
    "barbecharem": "barbechar",
    "barbecharemos": "barbechar",
    "barbechares": "barbechar",
    "barbecharia": "barbechar",
    "barbechariam": "barbechar",
    "barbecharias": "barbechar",
    "barbecharmo": "barbechar",
    "barbecharmos": "barbechar",
    "barbechará": "barbechar",
    "barbecharás": "barbechar",
    "barbecharão": "barbechar",
    "barbecharíamos": "barbechar",
    "barbecharíeis": "barbechar",
    "barbechas": "barbechar",
    "barbechasse": "barbechar",
    "barbechassem": "barbechar",
    "barbechasses": "barbechar",
    "barbechaste": "barbechar",
    "barbechastes": "barbechar",
    "barbechava": "barbechar",
    "barbechavam": "barbechar",
    "barbechavas": "barbechar",
    "barbeche": "barbechar",
    "barbechei": "barbechar",
    "barbecheis": "barbechar",
    "barbechem": "barbechar",
    "barbechemo": "barbechar",
    "barbechemos": "barbechar",
    "barbeches": "barbechar",
    "barbecho": "barbechar",
    "barbechos": "barbecho",
    "barbechou": "barbechar",
    "barbechá": "barbechar",
    "barbechámo": "barbechar",
    "barbechámos": "barbechar",
    "barbecháramo": "barbechar",
    "barbecháramos": "barbechar",
    "barbechárei": "barbechar",
    "barbecháreis": "barbechar",
    "barbechásseis": "barbechar",
    "barbechássemos": "barbechar",
    "barbechávamo": "barbechar",
    "barbechávamos": "barbechar",
    "barbechávei": "barbechar",
    "barbecháveis": "barbechar",
    "barbecues": "barbecue",
    "barbeei": "barbear",
    "barbeeis": "barbear",
    "barbeemo": "barbear",
    "barbeemos": "barbear",
    "barbei": "barbar",
    "barbeia": "barbear",
    "barbeiam": "barbear",
    "barbeias": "barbear",
    "barbeie": "barbear",
    "barbeiem": "barbear",
    "barbeies": "barbear",
    "barbeio": "barbear",
    "barbeirices": "barbeirice",
    "barbeirolas": "barbeirola",
    "barbeiros": "barbeiro",
    "barbeis": "barbar",
    "barbeitos": "barbeito",
    "barbela": "barbelar",
    "barbelada": "barbelar",
    "barbeladas": "barbelar",
    "barbelado": "barbelar",
    "barbelados": "barbelar",
    "barbelai": "barbelar",
    "barbelais": "barbelar",
    "barbelam": "barbelar",
    "barbelamo": "barbelar",
    "barbelamos": "barbelar",
    "barbelando": "barbelar",
    "barbelara": "barbelar",
    "barbelaram": "barbelar",
    "barbelaras": "barbelar",
    "barbelarde": "barbelar",
    "barbelardes": "barbelar",
    "barbelare": "barbelar",
    "barbelarei": "barbelar",
    "barbelareis": "barbelar",
    "barbelarem": "barbelar",
    "barbelaremos": "barbelar",
    "barbelares": "barbelar",
    "barbelaria": "barbelar",
    "barbelariam": "barbelar",
    "barbelarias": "barbelar",
    "barbelarmo": "barbelar",
    "barbelarmos": "barbelar",
    "barbelará": "barbelar",
    "barbelarás": "barbelar",
    "barbelarão": "barbelar",
    "barbelaríamos": "barbelar",
    "barbelaríeis": "barbelar",
    "barbelas": "barbelar",
    "barbelasse": "barbelar",
    "barbelassem": "barbelar",
    "barbelasses": "barbelar",
    "barbelaste": "barbelar",
    "barbelastes": "barbelar",
    "barbelava": "barbelar",
    "barbelavam": "barbelar",
    "barbelavas": "barbelar",
    "barbele": "barbelar",
    "barbelei": "barbelar",
    "barbeleis": "barbelar",
    "barbelem": "barbelar",
    "barbelemo": "barbelar",
    "barbelemos": "barbelar",
    "barbeles": "barbelar",
    "barbelo": "barbelar",
    "barbelou": "barbelar",
    "barbelá": "barbelar",
    "barbelámo": "barbelar",
    "barbelámos": "barbelar",
    "barbeláramo": "barbelar",
    "barbeláramos": "barbelar",
    "barbelárei": "barbelar",
    "barbeláreis": "barbelar",
    "barbelásseis": "barbelar",
    "barbelássemos": "barbelar",
    "barbelávamo": "barbelar",
    "barbelávamos": "barbelar",
    "barbelávei": "barbelar",
    "barbeláveis": "barbelar",
    "barbelões": "barbelão",
    "barbem": "barbar",
    "barbemo": "barbar",
    "barbemos": "barbar",
    "barbeou": "barbear",
    "barbes": "barbar",
    "barbetas": "barbeta",
    "barbeá": "barbear",
    "barbeámo": "barbear",
    "barbeámos": "barbear",
    "barbeáramo": "barbear",
    "barbeáramos": "barbear",
    "barbeárei": "barbear",
    "barbeáreis": "barbear",
    "barbeásseis": "barbear",
    "barbeássemos": "barbear",
    "barbeávamo": "barbear",
    "barbeávamos": "barbear",
    "barbeávei": "barbear",
    "barbeáveis": "barbear",
    "barbicachos": "barbicacho",
    "barbicas": "barbica",
    "barbichas": "barbicha",
    "barbiformes": "barbiforme",
    "barbilhas": "barbilha",
    "barbilhos": "barbilho",
    "barbilhões": "barbilhão",
    "barbiloira": "barbiloiro",
    "barbiloiras": "barbiloiro",
    "barbiloiros": "barbiloiro",
    "barbilonga": "barbilongo",
    "barbilongas": "barbilongo",
    "barbilongos": "barbilongo",
    "barbiloura": "barbilouro",
    "barbilouras": "barbilouro",
    "barbilouros": "barbilouro",
    "barbinegra": "barbinegro",
    "barbinegras": "barbinegro",
    "barbinegros": "barbinegro",
    "barbinha": "barba",
    "barbinhas": "barba",
    "barbipoentes": "barbipoente",
    "barbiponentes": "barbiponente",
    "barbirrostra": "barbirrostro",
    "barbirrostras": "barbirrostro",
    "barbirrostros": "barbirrostro",
    "barbirruiva": "barbirruivo",
    "barbirruivas": "barbirruivo",
    "barbirruivos": "barbirruivo",
    "barbita": "barba",
    "barbitais": "barbital",
    "barbitas": "barba",
    "barbitesa": "barbiteso",
    "barbitesas": "barbiteso",
    "barbitesos": "barbiteso",
    "barbituratos": "barbiturato",
    "barbiturismos": "barbiturismo",
    "barbitúrica": "barbitúrico",
    "barbitúricas": "barbitúrico",
    "barbitúricos": "barbitúrico",
    "barbo": "barbar",
    "barbos": "barbo",
    "barbosanos": "barbosano",
    "barbosinhos": "barbosinho",
    "barbotes": "barbote",
    "barbou": "barbar",
    "barbuda": "barbudo",
    "barbudas": "barbudo",
    "barbudinhos": "barbudinho",
    "barbudos": "barbudo",
    "barbá": "barbar",
    "barbámo": "barbar",
    "barbámos": "barbar",
    "barbáramo": "barbar",
    "barbáramos": "barbar",
    "barbárei": "barbar",
    "barbáreis": "barbar",
    "barbárica": "barbárico",
    "barbáricas": "barbárico",
    "barbáricos": "barbárico",
    "barbáries": "barbárie",
    "barbásseis": "barbar",
    "barbássemos": "barbar",
    "barbávamo": "barbar",
    "barbávamos": "barbar",
    "barbávei": "barbar",
    "barbáveis": "barbar",
    "barbífera": "barbífero",
    "barbíferas": "barbífero",
    "barbíferos": "barbífero",
    "barbípedes": "barbípede",
    "barcadas": "barcada",
    "barcagens": "barcagem",
    "barcarolas": "barcarola",
    "barcas": "barca",
    "barcavolantes": "barcavolante",
    "barcaças": "barcaça",
    "barceiros": "barceiro",
    "barceladas": "barcelada",
    "barcelenses": "barcelense",
    "barcelonesa": "barcelonês",
    "barcelonesas": "barcelonês",
    "barceloneses": "barcelonês",
    "barcolas": "barcola",
    "barcos": "barco",
    "barda": "bardar",
    "bardada": "bardar",
    "bardadas": "bardar",
    "bardado": "bardar",
    "bardados": "bardar",
    "bardai": "bardar",
    "bardais": "bardar",
    "bardam": "bardar",
    "bardamo": "bardar",
    "bardamos": "bardar",
    "bardanas": "bardana",
    "bardando": "bardar",
    "bardara": "bardar",
    "bardaram": "bardar",
    "bardaras": "bardar",
    "bardarde": "bardar",
    "bardardes": "bardar",
    "bardare": "bardar",
    "bardarei": "bardar",
    "bardareis": "bardar",
    "bardarem": "bardar",
    "bardaremos": "bardar",
    "bardares": "bardar",
    "bardaria": "bardar",
    "bardariam": "bardar",
    "bardarias": "bardar",
    "bardarmo": "bardar",
    "bardarmos": "bardar",
    "bardará": "bardar",
    "bardarás": "bardar",
    "bardarão": "bardar",
    "bardaríamos": "bardar",
    "bardaríeis": "bardar",
    "bardas": "bardar",
    "bardasse": "bardar",
    "bardassem": "bardar",
    "bardasses": "bardar",
    "bardaste": "bardar",
    "bardastes": "bardar",
    "bardava": "bardar",
    "bardavam": "bardar",
    "bardavas": "bardar",
    "barde": "bardar",
    "bardei": "bardar",
    "bardeis": "bardar",
    "bardem": "bardar",
    "bardemo": "bardar",
    "bardemos": "bardar",
    "bardes": "bardar",
    "bardina": "bardino",
    "bardinas": "bardino",
    "bardinos": "bardino",
    "bardo": "bardar",
    "bardos": "bardo",
    "bardou": "bardar",
    "bardá": "bardar",
    "bardámo": "bardar",
    "bardámos": "bardar",
    "bardáramo": "bardar",
    "bardáramos": "bardar",
    "bardárei": "bardar",
    "bardáreis": "bardar",
    "bardásseis": "bardar",
    "bardássemos": "bardar",
    "bardávamo": "bardar",
    "bardávamos": "bardar",
    "bardávei": "bardar",
    "bardáveis": "bardar",
    "bareges": "barege",
    "bareginas": "baregina",
    "bares": "bar",
    "barganha": "barganhar",
    "barganhada": "barganhar",
    "barganhadas": "barganhar",
    "barganhado": "barganhar",
    "barganhados": "barganhar",
    "barganhai": "barganhar",
    "barganhais": "barganhar",
    "barganham": "barganhar",
    "barganhamo": "barganhar",
    "barganhamos": "barganhar",
    "barganhando": "barganhar",
    "barganhara": "barganhar",
    "barganharam": "barganhar",
    "barganharas": "barganhar",
    "barganharde": "barganhar",
    "barganhardes": "barganhar",
    "barganhare": "barganhar",
    "barganharei": "barganhar",
    "barganhareis": "barganhar",
    "barganharem": "barganhar",
    "barganharemos": "barganhar",
    "barganhares": "barganhar",
    "barganharia": "barganhar",
    "barganhariam": "barganhar",
    "barganharias": "barganhar",
    "barganharmo": "barganhar",
    "barganharmos": "barganhar",
    "barganhará": "barganhar",
    "barganharás": "barganhar",
    "barganharão": "barganhar",
    "barganharíamos": "barganhar",
    "barganharíeis": "barganhar",
    "barganhas": "barganhar",
    "barganhasse": "barganhar",
    "barganhassem": "barganhar",
    "barganhasses": "barganhar",
    "barganhaste": "barganhar",
    "barganhastes": "barganhar",
    "barganhava": "barganhar",
    "barganhavam": "barganhar",
    "barganhavas": "barganhar",
    "barganhe": "barganhar",
    "barganhei": "barganhar",
    "barganheis": "barganhar",
    "barganhem": "barganhar",
    "barganhemo": "barganhar",
    "barganhemos": "barganhar",
    "barganhes": "barganhar",
    "barganhistas": "barganhista",
    "barganho": "barganhar",
    "barganhou": "barganhar",
    "barganhá": "barganhar",
    "barganhámo": "barganhar",
    "barganhámos": "barganhar",
    "barganháramo": "barganhar",
    "barganháramos": "barganhar",
    "barganhárei": "barganhar",
    "barganháreis": "barganhar",
    "barganhásseis": "barganhar",
    "barganhássemos": "barganhar",
    "barganhávamo": "barganhar",
    "barganhávamos": "barganhar",
    "barganhávei": "barganhar",
    "barganháveis": "barganhar",
    "bargantarias": "bargantaria",
    "barganteada": "bargantear",
    "barganteadas": "bargantear",
    "barganteado": "bargantear",
    "barganteados": "bargantear",
    "barganteai": "bargantear",
    "barganteais": "bargantear",
    "barganteamo": "bargantear",
    "barganteamos": "bargantear",
    "barganteando": "bargantear",
    "barganteara": "bargantear",
    "bargantearam": "bargantear",
    "bargantearas": "bargantear",
    "barganteardes": "bargantear",
    "bargantearei": "bargantear",
    "barganteareis": "bargantear",
    "bargantearem": "bargantear",
    "bargantearemos": "bargantear",
    "barganteares": "bargantear",
    "bargantearia": "bargantear",
    "barganteariam": "bargantear",
    "bargantearias": "bargantear",
    "bargantearmo": "bargantear",
    "bargantearmos": "bargantear",
    "barganteará": "bargantear",
    "bargantearás": "bargantear",
    "bargantearão": "bargantear",
    "bargantearíamos": "bargantear",
    "bargantearíeis": "bargantear",
    "barganteasse": "bargantear",
    "barganteassem": "bargantear",
    "barganteasses": "bargantear",
    "barganteaste": "bargantear",
    "barganteastes": "bargantear",
    "barganteava": "bargantear",
    "barganteavam": "bargantear",
    "barganteavas": "bargantear",
    "barganteei": "bargantear",
    "barganteeis": "bargantear",
    "barganteemo": "bargantear",
    "barganteemos": "bargantear",
    "barganteia": "bargantear",
    "barganteiam": "bargantear",
    "barganteias": "bargantear",
    "barganteie": "bargantear",
    "barganteiem": "bargantear",
    "barganteies": "bargantear",
    "barganteio": "bargantear",
    "barganteou": "bargantear",
    "bargantes": "bargante",
    "barganteámo": "bargantear",
    "barganteámos": "bargantear",
    "barganteáramo": "bargantear",
    "barganteáramos": "bargantear",
    "barganteáreis": "bargantear",
    "barganteásseis": "bargantear",
    "barganteássemos": "bargantear",
    "barganteávamo": "bargantear",
    "barganteávamos": "bargantear",
    "barganteáveis": "bargantear",
    "bargas": "barga",
    "bargelas": "bargela",
    "bargueiros": "bargueiro",
    "baricentros": "baricentro",
    "barifonias": "barifonia",
    "bariglossias": "bariglossia",
    "barimetrias": "barimetria",
    "barinéis": "barinel",
    "barisferas": "barisfera",
    "baritas": "barita",
    "barites": "barite",
    "baritinas": "baritina",
    "baritites": "baritite",
    "bariões": "barião",
    "barjoletas": "barjoleta",
    "barlaventeada": "barlaventear",
    "barlaventeadas": "barlaventear",
    "barlaventeado": "barlaventear",
    "barlaventeados": "barlaventear",
    "barlaventeai": "barlaventear",
    "barlaventeais": "barlaventear",
    "barlaventeamo": "barlaventear",
    "barlaventeamos": "barlaventear",
    "barlaventeando": "barlaventear",
    "barlaventeara": "barlaventear",
    "barlaventearam": "barlaventear",
    "barlaventearas": "barlaventear",
    "barlaventeardes": "barlaventear",
    "barlaventearei": "barlaventear",
    "barlaventeareis": "barlaventear",
    "barlaventearem": "barlaventear",
    "barlaventearemos": "barlaventear",
    "barlaventeares": "barlaventear",
    "barlaventearia": "barlaventear",
    "barlaventeariam": "barlaventear",
    "barlaventearias": "barlaventear",
    "barlaventearmo": "barlaventear",
    "barlaventearmos": "barlaventear",
    "barlaventeará": "barlaventear",
    "barlaventearás": "barlaventear",
    "barlaventearão": "barlaventear",
    "barlaventearíamos": "barlaventear",
    "barlaventearíeis": "barlaventear",
    "barlaventeasse": "barlaventear",
    "barlaventeassem": "barlaventear",
    "barlaventeasses": "barlaventear",
    "barlaventeaste": "barlaventear",
    "barlaventeastes": "barlaventear",
    "barlaventeava": "barlaventear",
    "barlaventeavam": "barlaventear",
    "barlaventeavas": "barlaventear",
    "barlaventeei": "barlaventear",
    "barlaventeeis": "barlaventear",
    "barlaventeemo": "barlaventear",
    "barlaventeemos": "barlaventear",
    "barlaventeia": "barlaventear",
    "barlaventeiam": "barlaventear",
    "barlaventeias": "barlaventear",
    "barlaventeie": "barlaventear",
    "barlaventeiem": "barlaventear",
    "barlaventeies": "barlaventear",
    "barlaventeio": "barlaventear",
    "barlaventeja": "barlaventejar",
    "barlaventejada": "barlaventejar",
    "barlaventejadas": "barlaventejar",
    "barlaventejado": "barlaventejar",
    "barlaventejados": "barlaventejar",
    "barlaventejai": "barlaventejar",
    "barlaventejais": "barlaventejar",
    "barlaventejam": "barlaventejar",
    "barlaventejamo": "barlaventejar",
    "barlaventejamos": "barlaventejar",
    "barlaventejando": "barlaventejar",
    "barlaventejara": "barlaventejar",
    "barlaventejaram": "barlaventejar",
    "barlaventejaras": "barlaventejar",
    "barlaventejardes": "barlaventejar",
    "barlaventejarei": "barlaventejar",
    "barlaventejareis": "barlaventejar",
    "barlaventejarem": "barlaventejar",
    "barlaventejaremos": "barlaventejar",
    "barlaventejares": "barlaventejar",
    "barlaventejaria": "barlaventejar",
    "barlaventejariam": "barlaventejar",
    "barlaventejarias": "barlaventejar",
    "barlaventejarmo": "barlaventejar",
    "barlaventejarmos": "barlaventejar",
    "barlaventejará": "barlaventejar",
    "barlaventejarás": "barlaventejar",
    "barlaventejarão": "barlaventejar",
    "barlaventejaríamos": "barlaventejar",
    "barlaventejaríeis": "barlaventejar",
    "barlaventejas": "barlaventejar",
    "barlaventejasse": "barlaventejar",
    "barlaventejassem": "barlaventejar",
    "barlaventejasses": "barlaventejar",
    "barlaventejaste": "barlaventejar",
    "barlaventejastes": "barlaventejar",
    "barlaventejava": "barlaventejar",
    "barlaventejavam": "barlaventejar",
    "barlaventejavas": "barlaventejar",
    "barlaventeje": "barlaventejar",
    "barlaventejei": "barlaventejar",
    "barlaventejeis": "barlaventejar",
    "barlaventejem": "barlaventejar",
    "barlaventejemo": "barlaventejar",
    "barlaventejemos": "barlaventejar",
    "barlaventejes": "barlaventejar",
    "barlaventejo": "barlaventejar",
    "barlaventejou": "barlaventejar",
    "barlaventejámo": "barlaventejar",
    "barlaventejámos": "barlaventejar",
    "barlaventejáramo": "barlaventejar",
    "barlaventejáramos": "barlaventejar",
    "barlaventejáreis": "barlaventejar",
    "barlaventejásseis": "barlaventejar",
    "barlaventejássemos": "barlaventejar",
    "barlaventejávamo": "barlaventejar",
    "barlaventejávamos": "barlaventejar",
    "barlaventejáveis": "barlaventejar",
    "barlaventeou": "barlaventear",
    "barlaventeámo": "barlaventear",
    "barlaventeámos": "barlaventear",
    "barlaventeáramo": "barlaventear",
    "barlaventeáramos": "barlaventear",
    "barlaventeáreis": "barlaventear",
    "barlaventeásseis": "barlaventear",
    "barlaventeássemos": "barlaventear",
    "barlaventeávamo": "barlaventear",
    "barlaventeávamos": "barlaventear",
    "barlaventeáveis": "barlaventear",
    "barlaventos": "barlavento",
    "barmans": "barman",
    "barnabitas": "barnabita",
    "barns": "barn",
    "baroados": "baroado",
    "baroclínica": "baroclínico",
    "baroclínicas": "baroclínico",
    "baroclínicos": "baroclínico",
    "barocos": "baroco",
    "barogramas": "barograma",
    "barográfica": "barográfico",
    "barográficas": "barográfico",
    "barográficos": "barográfico",
    "barometrias": "barometria",
    "barométrica": "barométrico",
    "barométricas": "barométrico",
    "barométricos": "barométrico",
    "baronatos": "baronato",
    "baronesa": "barão",
    "baronesas": "barão",
    "baronesazinha": "barão",
    "baronesazinhas": "barão",
    "baronesazita": "barão",
    "baronesazitas": "barão",
    "baronetes": "baronete",
    "baroniais": "baronial",
    "baronias": "baronia",
    "baroniza": "baronizar",
    "baronizada": "baronizar",
    "baronizadas": "baronizar",
    "baronizado": "baronizar",
    "baronizados": "baronizar",
    "baronizai": "baronizar",
    "baronizais": "baronizar",
    "baronizam": "baronizar",
    "baronizamo": "baronizar",
    "baronizamos": "baronizar",
    "baronizando": "baronizar",
    "baronizara": "baronizar",
    "baronizaram": "baronizar",
    "baronizaras": "baronizar",
    "baronizarde": "baronizar",
    "baronizardes": "baronizar",
    "baronizare": "baronizar",
    "baronizarei": "baronizar",
    "baronizareis": "baronizar",
    "baronizarem": "baronizar",
    "baronizaremos": "baronizar",
    "baronizares": "baronizar",
    "baronizaria": "baronizar",
    "baronizariam": "baronizar",
    "baronizarias": "baronizar",
    "baronizarmo": "baronizar",
    "baronizarmos": "baronizar",
    "baronizará": "baronizar",
    "baronizarás": "baronizar",
    "baronizarão": "baronizar",
    "baronizaríamos": "baronizar",
    "baronizaríeis": "baronizar",
    "baronizas": "baronizar",
    "baronizasse": "baronizar",
    "baronizassem": "baronizar",
    "baronizasses": "baronizar",
    "baronizaste": "baronizar",
    "baronizastes": "baronizar",
    "baronizava": "baronizar",
    "baronizavam": "baronizar",
    "baronizavas": "baronizar",
    "baronize": "baronizar",
    "baronizei": "baronizar",
    "baronizeis": "baronizar",
    "baronizem": "baronizar",
    "baronizemo": "baronizar",
    "baronizemos": "baronizar",
    "baronizes": "baronizar",
    "baronizo": "baronizar",
    "baronizou": "baronizar",
    "baronizá": "baronizar",
    "baronizámo": "baronizar",
    "baronizámos": "baronizar",
    "baronizáramo": "baronizar",
    "baronizáramos": "baronizar",
    "baronizárei": "baronizar",
    "baronizáreis": "baronizar",
    "baronizásseis": "baronizar",
    "baronizássemos": "baronizar",
    "baronizávamo": "baronizar",
    "baronizávamos": "baronizar",
    "baronizávei": "baronizar",
    "baronizáveis": "baronizar",
    "baroscópica": "baroscópico",
    "baroscópicas": "baroscópico",
    "baroscópicos": "baroscópico",
    "baroscópios": "baroscópio",
    "barossânemos": "barossânemo",
    "barostática": "barostático",
    "barostáticas": "barostático",
    "barostáticos": "barostático",
    "barotaxias": "barotaxia",
    "barotermógrafos": "barotermógrafo",
    "barotermómetros": "barotermómetro",
    "barotropismos": "barotropismo",
    "barotrópica": "barotrópico",
    "barotrópicas": "barotrópico",
    "barotrópicos": "barotrópico",
    "barotáxica": "barotáxico",
    "barotáxicas": "barotáxico",
    "barotáxicos": "barotáxico",
    "barqueada": "barquear",
    "barqueadas": "barquear",
    "barqueado": "barquear",
    "barqueados": "barquear",
    "barqueai": "barquear",
    "barqueais": "barquear",
    "barqueamo": "barquear",
    "barqueamos": "barquear",
    "barqueando": "barquear",
    "barqueara": "barquear",
    "barquearam": "barquear",
    "barquearas": "barquear",
    "barqueardes": "barquear",
    "barquearei": "barquear",
    "barqueareis": "barquear",
    "barquearem": "barquear",
    "barquearemos": "barquear",
    "barqueares": "barquear",
    "barquearia": "barquear",
    "barqueariam": "barquear",
    "barquearias": "barquear",
    "barquearmo": "barquear",
    "barquearmos": "barquear",
    "barqueará": "barquear",
    "barquearás": "barquear",
    "barquearão": "barquear",
    "barquearíamos": "barquear",
    "barquearíeis": "barquear",
    "barqueasse": "barquear",
    "barqueassem": "barquear",
    "barqueasses": "barquear",
    "barqueaste": "barquear",
    "barqueastes": "barquear",
    "barqueava": "barquear",
    "barqueavam": "barquear",
    "barqueavas": "barquear",
    "barqueei": "barquear",
    "barqueeis": "barquear",
    "barqueemo": "barquear",
    "barqueemos": "barquear",
    "barqueia": "barquear",
    "barqueiam": "barquear",
    "barqueias": "barquear",
    "barqueie": "barquear",
    "barqueiem": "barquear",
    "barqueies": "barquear",
    "barqueio": "barquear",
    "barqueira": "barqueiro",
    "barqueiras": "barqueiro",
    "barqueiros": "barqueiro",
    "barqueja": "barquejar",
    "barquejada": "barquejar",
    "barquejadas": "barquejar",
    "barquejado": "barquejar",
    "barquejados": "barquejar",
    "barquejai": "barquejar",
    "barquejais": "barquejar",
    "barquejam": "barquejar",
    "barquejamo": "barquejar",
    "barquejamos": "barquejar",
    "barquejando": "barquejar",
    "barquejara": "barquejar",
    "barquejaram": "barquejar",
    "barquejaras": "barquejar",
    "barquejardes": "barquejar",
    "barquejarei": "barquejar",
    "barquejareis": "barquejar",
    "barquejarem": "barquejar",
    "barquejaremos": "barquejar",
    "barquejares": "barquejar",
    "barquejaria": "barquejar",
    "barquejariam": "barquejar",
    "barquejarias": "barquejar",
    "barquejarmo": "barquejar",
    "barquejarmos": "barquejar",
    "barquejará": "barquejar",
    "barquejarás": "barquejar",
    "barquejarão": "barquejar",
    "barquejaríamos": "barquejar",
    "barquejaríeis": "barquejar",
    "barquejas": "barquejar",
    "barquejasse": "barquejar",
    "barquejassem": "barquejar",
    "barquejasses": "barquejar",
    "barquejaste": "barquejar",
    "barquejastes": "barquejar",
    "barquejava": "barquejar",
    "barquejavam": "barquejar",
    "barquejavas": "barquejar",
    "barqueje": "barquejar",
    "barquejei": "barquejar",
    "barquejeis": "barquejar",
    "barquejem": "barquejar",
    "barquejemo": "barquejar",
    "barquejemos": "barquejar",
    "barquejes": "barquejar",
    "barquejo": "barquejar",
    "barquejou": "barquejar",
    "barquejámo": "barquejar",
    "barquejámos": "barquejar",
    "barquejáramo": "barquejar",
    "barquejáramos": "barquejar",
    "barquejáreis": "barquejar",
    "barquejásseis": "barquejar",
    "barquejássemos": "barquejar",
    "barquejávamo": "barquejar",
    "barquejávamos": "barquejar",
    "barquejáveis": "barquejar",
    "barquenses": "barquense",
    "barqueou": "barquear",
    "barquetas": "barqueta",
    "barqueámo": "barquear",
    "barqueámos": "barquear",
    "barqueáramo": "barquear",
    "barqueáramos": "barquear",
    "barqueáreis": "barquear",
    "barqueásseis": "barquear",
    "barqueássemos": "barquear",
    "barqueávamo": "barquear",
    "barqueávamos": "barquear",
    "barqueáveis": "barquear",
    "barquilhas": "barquilha",
    "barquilheiros": "barquilheiro",
    "barquilhos": "barquilho",
    "barquinha": "barca",
    "barquinhas": "barquinha",
    "barquinho": "barco",
    "barquinhos": "barco",
    "barquita": "barca",
    "barquitas": "barca",
    "barquito": "barco",
    "barquitos": "barco",
    "barra": "barrir",
    "barracadas": "barracada",
    "barracas": "barraca",
    "barracenta": "barracento",
    "barracentas": "barracento",
    "barracentos": "barracento",
    "barracos": "barraco",
    "barracudas": "barracuda",
    "barracórios": "barracório",
    "barracões": "barracão",
    "barrada": "barrar",
    "barradas": "barrar",
    "barradazinha": "barrado",
    "barradazinhas": "barrado",
    "barradazita": "barrado",
    "barradazitas": "barrado",
    "barradelas": "barradela",
    "barradinha": "barrado",
    "barradinhas": "barrado",
    "barradinho": "barrado",
    "barradinhos": "barrado",
    "barradita": "barrado",
    "barraditas": "barrado",
    "barradito": "barrado",
    "barraditos": "barrado",
    "barrado": "barrar",
    "barrados": "barrar",
    "barradozinho": "barrado",
    "barradozinhos": "barrado",
    "barradozito": "barrado",
    "barradozitos": "barrado",
    "barraduras": "barradura",
    "barragens": "barragem",
    "barrai": "barrar",
    "barrais": "barrir",
    "barram": "barrir",
    "barramaques": "barramaque",
    "barramentos": "barramento",
    "barramo": "barrir",
    "barramos": "barrir",
    "barrancais": "barrancal",
    "barrancas": "barranca",
    "barrancos": "barranco",
    "barrancosa": "barrancoso",
    "barrancosas": "barrancoso",
    "barrancosos": "barrancoso",
    "barrando": "barrar",
    "barranhas": "barranha",
    "barranhões": "barranhão",
    "barranqueira": "barranqueiro",
    "barranqueiras": "barranqueiro",
    "barranqueiros": "barranqueiro",
    "barranquenha": "barranquenho",
    "barranquenhas": "barranquenho",
    "barranquenhos": "barranquenho",
    "barraqueira": "barraqueiro",
    "barraqueiras": "barraqueiro",
    "barraqueiros": "barraqueiro",
    "barraquinha": "barraca",
    "barraquinhas": "barraca",
    "barraquins": "barraquim",
    "barraquita": "barraca",
    "barraquitas": "barraca",
    "barrara": "barrar",
    "barraram": "barrar",
    "barraras": "barrar",
    "barrarde": "barrar",
    "barrardes": "barrar",
    "barrare": "barrar",
    "barrarei": "barrar",
    "barrareis": "barrar",
    "barrarem": "barrar",
    "barraremos": "barrar",
    "barrares": "barrar",
    "barraria": "barrar",
    "barrariam": "barrar",
    "barrarias": "barrar",
    "barrarmo": "barrar",
    "barrarmos": "barrar",
    "barrará": "barrar",
    "barrarás": "barrar",
    "barrarão": "barrar",
    "barraríamos": "barrar",
    "barraríeis": "barrar",
    "barras": "barrir",
    "barrascos": "barrasco",
    "barrasse": "barrar",
    "barrassem": "barrar",
    "barrasses": "barrar",
    "barraste": "barrar",
    "barrastes": "barrar",
    "barrava": "barrar",
    "barravam": "barrar",
    "barravas": "barrar",
    "barre": "barrir",
    "barredos": "barredo",
    "barrega": "barregar",
    "barregada": "barregar",
    "barregadas": "barregar",
    "barregado": "barregar",
    "barregados": "barregar",
    "barregai": "barregar",
    "barregais": "barregar",
    "barregam": "barregar",
    "barregamo": "barregar",
    "barregamos": "barregar",
    "barreganas": "barregana",
    "barregando": "barregar",
    "barregara": "barregar",
    "barregaram": "barregar",
    "barregaras": "barregar",
    "barregardes": "barregar",
    "barregarei": "barregar",
    "barregareis": "barregar",
    "barregarem": "barregar",
    "barregaremos": "barregar",
    "barregares": "barregar",
    "barregaria": "barregar",
    "barregariam": "barregar",
    "barregarias": "barregar",
    "barregarmo": "barregar",
    "barregarmos": "barregar",
    "barregará": "barregar",
    "barregarás": "barregar",
    "barregarão": "barregar",
    "barregaríamos": "barregar",
    "barregaríeis": "barregar",
    "barregas": "barregar",
    "barregasse": "barregar",
    "barregassem": "barregar",
    "barregasses": "barregar",
    "barregaste": "barregar",
    "barregastes": "barregar",
    "barregava": "barregar",
    "barregavam": "barregar",
    "barregavas": "barregar",
    "barrego": "barregar",
    "barregou": "barregar",
    "barregue": "barregar",
    "barreguei": "barregar",
    "barregueira": "barregueiro",
    "barregueiras": "barregueiro",
    "barregueiros": "barregueiro",
    "barregueis": "barregar",
    "barreguem": "barregar",
    "barreguemo": "barregar",
    "barreguemos": "barregar",
    "barregues": "barregar",
    "barregámo": "barregar",
    "barregámos": "barregar",
    "barregáramo": "barregar",
    "barregáramos": "barregar",
    "barregáreis": "barregar",
    "barregásseis": "barregar",
    "barregássemos": "barregar",
    "barregávamo": "barregar",
    "barregávamos": "barregar",
    "barregáveis": "barregar",
    "barregã": "barregão",
    "barregãos": "barregão",
    "barregãs": "barregão",
    "barrei": "barrar",
    "barreira": "barreirar",
    "barreirada": "barreirar",
    "barreiradas": "barreirar",
    "barreirado": "barreirar",
    "barreirados": "barreirar",
    "barreirai": "barreirar",
    "barreirais": "barreirar",
    "barreiram": "barreirar",
    "barreiramo": "barreirar",
    "barreiramos": "barreirar",
    "barreirando": "barreirar",
    "barreirara": "barreirar",
    "barreiraram": "barreirar",
    "barreiraras": "barreirar",
    "barreirardes": "barreirar",
    "barreirarei": "barreirar",
    "barreirareis": "barreirar",
    "barreirarem": "barreirar",
    "barreiraremos": "barreirar",
    "barreirares": "barreirar",
    "barreiraria": "barreirar",
    "barreirariam": "barreirar",
    "barreirarias": "barreirar",
    "barreirarmo": "barreirar",
    "barreirarmos": "barreirar",
    "barreirará": "barreirar",
    "barreirarás": "barreirar",
    "barreirarão": "barreirar",
    "barreiraríamos": "barreirar",
    "barreiraríeis": "barreirar",
    "barreiras": "barreirar",
    "barreirasse": "barreirar",
    "barreirassem": "barreirar",
    "barreirasses": "barreirar",
    "barreiraste": "barreirar",
    "barreirastes": "barreirar",
    "barreirava": "barreirar",
    "barreiravam": "barreirar",
    "barreiravas": "barreirar",
    "barreire": "barreirar",
    "barreirei": "barreirar",
    "barreireis": "barreirar",
    "barreirem": "barreirar",
    "barreiremo": "barreirar",
    "barreiremos": "barreirar",
    "barreirenses": "barreirense",
    "barreirenta": "barreirento",
    "barreirentas": "barreirento",
    "barreirentos": "barreirento",
    "barreires": "barreirar",
    "barreiristas": "barreirista",
    "barreiro": "barreirar",
    "barreiros": "barreiro",
    "barreirou": "barreirar",
    "barreirámo": "barreirar",
    "barreirámos": "barreirar",
    "barreiráramo": "barreirar",
    "barreiráramos": "barreirar",
    "barreiráreis": "barreirar",
    "barreirásseis": "barreirar",
    "barreirássemos": "barreirar",
    "barreirávamo": "barreirar",
    "barreirávamos": "barreirar",
    "barreiráveis": "barreirar",
    "barreis": "barrar",
    "barrelas": "barrela",
    "barreleiras": "barreleira",
    "barreleiros": "barreleiro",
    "barrelonas": "barrelona",
    "barrelos": "barrelo",
    "barrelões": "barrelão",
    "barrem": "barrir",
    "barremo": "barrar",
    "barremos": "barrar",
    "barrena": "barrenar",
    "barrenada": "barrenar",
    "barrenadas": "barrenar",
    "barrenado": "barrenar",
    "barrenados": "barrenar",
    "barrenai": "barrenar",
    "barrenais": "barrenar",
    "barrenam": "barrenar",
    "barrenamo": "barrenar",
    "barrenamos": "barrenar",
    "barrenando": "barrenar",
    "barrenara": "barrenar",
    "barrenaram": "barrenar",
    "barrenaras": "barrenar",
    "barrenardes": "barrenar",
    "barrenarei": "barrenar",
    "barrenareis": "barrenar",
    "barrenarem": "barrenar",
    "barrenaremos": "barrenar",
    "barrenares": "barrenar",
    "barrenaria": "barrenar",
    "barrenariam": "barrenar",
    "barrenarias": "barrenar",
    "barrenarmo": "barrenar",
    "barrenarmos": "barrenar",
    "barrenará": "barrenar",
    "barrenarás": "barrenar",
    "barrenarão": "barrenar",
    "barrenaríamos": "barrenar",
    "barrenaríeis": "barrenar",
    "barrenas": "barrenar",
    "barrenasse": "barrenar",
    "barrenassem": "barrenar",
    "barrenasses": "barrenar",
    "barrenaste": "barrenar",
    "barrenastes": "barrenar",
    "barrenava": "barrenar",
    "barrenavam": "barrenar",
    "barrenavas": "barrenar",
    "barrene": "barrenar",
    "barrenei": "barrenar",
    "barreneira": "barreneiro",
    "barreneiras": "barreneiro",
    "barreneiros": "barreneiro",
    "barreneis": "barrenar",
    "barrenem": "barrenar",
    "barrenemo": "barrenar",
    "barrenemos": "barrenar",
    "barrenes": "barrenar",
    "barrenhas": "barrenha",
    "barrenhões": "barrenhão",
    "barreno": "barrenar",
    "barrenos": "barreno",
    "barrenou": "barrenar",
    "barrenta": "barrento",
    "barrentas": "barrento",
    "barrentos": "barrento",
    "barrenámo": "barrenar",
    "barrenámos": "barrenar",
    "barrenáramo": "barrenar",
    "barrenáramos": "barrenar",
    "barrenáreis": "barrenar",
    "barrenásseis": "barrenar",
    "barrenássemos": "barrenar",
    "barrenávamo": "barrenar",
    "barrenávamos": "barrenar",
    "barrenáveis": "barrenar",
    "barres": "barrir",
    "barretadas": "barretada",
    "barretas": "barreta",
    "barreteiros": "barreteiro",
    "barretes": "barrete",
    "barretezinho": "barrete",
    "barretezinhos": "barrete",
    "barretezito": "barrete",
    "barretezitos": "barrete",
    "barretinas": "barretina",
    "barretinho": "barrete",
    "barretinhos": "barrete",
    "barretito": "barrete",
    "barretitos": "barrete",
    "barri": "barrir",
    "barria": "barrir",
    "barriam": "barrir",
    "barrias": "barrir",
    "barrica": "barricar",
    "barricada": "barricar",
    "barricadas": "barricar",
    "barricado": "barricar",
    "barricados": "barricar",
    "barricai": "barricar",
    "barricais": "barricar",
    "barricam": "barricar",
    "barricamo": "barricar",
    "barricamos": "barricar",
    "barricando": "barricar",
    "barricara": "barricar",
    "barricaram": "barricar",
    "barricaras": "barricar",
    "barricarde": "barricar",
    "barricardes": "barricar",
    "barricare": "barricar",
    "barricarei": "barricar",
    "barricareis": "barricar",
    "barricarem": "barricar",
    "barricaremos": "barricar",
    "barricares": "barricar",
    "barricaria": "barricar",
    "barricariam": "barricar",
    "barricarias": "barricar",
    "barricarmo": "barricar",
    "barricarmos": "barricar",
    "barricará": "barricar",
    "barricarás": "barricar",
    "barricarão": "barricar",
    "barricaríamos": "barricar",
    "barricaríeis": "barricar",
    "barricas": "barricar",
    "barricasse": "barricar",
    "barricassem": "barricar",
    "barricasses": "barricar",
    "barricaste": "barricar",
    "barricastes": "barricar",
    "barricava": "barricar",
    "barricavam": "barricar",
    "barricavas": "barricar",
    "barrico": "barricar",
    "barricou": "barricar",
    "barricá": "barricar",
    "barricámo": "barricar",
    "barricámos": "barricar",
    "barricáramo": "barricar",
    "barricáramos": "barricar",
    "barricárei": "barricar",
    "barricáreis": "barricar",
    "barricásseis": "barricar",
    "barricássemos": "barricar",
    "barricávamo": "barricar",
    "barricávamos": "barricar",
    "barricávei": "barricar",
    "barricáveis": "barricável",
    "barricões": "barricão",
    "barrida": "barrir",
    "barridas": "barrir",
    "barrido": "barrir",
    "barridos": "barrir",
    "barrigadas": "barrigada",
    "barrigais": "barrigal",
    "barriganas": "barrigana",
    "barrigas": "barriga",
    "barriguda": "barrigudo",
    "barrigudas": "barrigudo",
    "barrigudos": "barrigudo",
    "barrigueiras": "barrigueira",
    "barriguinha": "barriga",
    "barriguinhas": "barriga",
    "barriguismos": "barriguismo",
    "barriguistas": "barriguista",
    "barriguita": "barriga",
    "barriguitas": "barriga",
    "barriladas": "barrilada",
    "barrileiras": "barrileira",
    "barrileiros": "barrileiro",
    "barriletes": "barrilete",
    "barrilhas": "barrilha",
    "barrilheiras": "barrilheira",
    "barrilinho": "barril",
    "barrilinhos": "barril",
    "barrilito": "barril",
    "barrilitos": "barril",
    "barrimo": "barrir",
    "barrimos": "barrir",
    "barrindo": "barrir",
    "barrinhas": "barrinha",
    "barrique": "barricar",
    "barriquei": "barricar",
    "barriqueira": "barriqueiro",
    "barriqueiras": "barriqueiro",
    "barriqueiros": "barriqueiro",
    "barriqueis": "barricar",
    "barriquem": "barricar",
    "barriquemo": "barricar",
    "barriquemos": "barricar",
    "barriques": "barricar",
    "barriquinha": "barrica",
    "barriquinhas": "barrica",
    "barriquita": "barrica",
    "barriquitas": "barrica",
    "barrira": "barrir",
    "barriram": "barrir",
    "barriras": "barrir",
    "barrirdes": "barrir",
    "barrirei": "barrir",
    "barrireis": "barrir",
    "barrirem": "barrir",
    "barriremos": "barrir",
    "barrires": "barrir",
    "barriria": "barrir",
    "barririam": "barrir",
    "barririas": "barrir",
    "barrirmo": "barrir",
    "barrirmos": "barrir",
    "barrirá": "barrir",
    "barrirás": "barrir",
    "barrirão": "barrir",
    "barriríamos": "barrir",
    "barriríeis": "barrir",
    "barris": "barrir",
    "barriscos": "barrisco",
    "barrisse": "barrir",
    "barrissem": "barrir",
    "barrisses": "barrir",
    "barristas": "barrista",
    "barriste": "barrir",
    "barristes": "barrir",
    "barritos": "barrito",
    "barriu": "barrir",
    "barro": "barrir",
    "barroca": "barroco",
    "barrocais": "barrocal",
    "barrocas": "barroco",
    "barrocos": "barroco",
    "barrocosa": "barrocoso",
    "barrocosas": "barrocoso",
    "barrocosos": "barrocoso",
    "barrocões": "barrocão",
    "barroqueiras": "barroqueira",
    "barroquismos": "barroquismo",
    "barros": "barro",
    "barrosa": "barroso",
    "barrosas": "barroso",
    "barrosinha": "barrosinho",
    "barrosinhas": "barrosinho",
    "barrosinhos": "barrosinho",
    "barrosona": "barrosão",
    "barrosonas": "barrosão",
    "barrosos": "barroso",
    "barrosã": "barrosão",
    "barrosãos": "barrosão",
    "barrosãs": "barrosão",
    "barrosões": "barrosão",
    "barrota": "barrotar",
    "barrotada": "barrotar",
    "barrotadas": "barrotar",
    "barrotado": "barrotar",
    "barrotados": "barrotar",
    "barrotai": "barrotar",
    "barrotais": "barrotar",
    "barrotam": "barrotar",
    "barrotamo": "barrotar",
    "barrotamos": "barrotar",
    "barrotando": "barrotar",
    "barrotara": "barrotar",
    "barrotaram": "barrotar",
    "barrotaras": "barrotar",
    "barrotarde": "barrotar",
    "barrotardes": "barrotar",
    "barrotare": "barrotar",
    "barrotarei": "barrotar",
    "barrotareis": "barrotar",
    "barrotarem": "barrotar",
    "barrotaremos": "barrotar",
    "barrotares": "barrotar",
    "barrotaria": "barrotar",
    "barrotariam": "barrotar",
    "barrotarias": "barrotar",
    "barrotarmo": "barrotar",
    "barrotarmos": "barrotar",
    "barrotará": "barrotar",
    "barrotarás": "barrotar",
    "barrotarão": "barrotar",
    "barrotaríamos": "barrotar",
    "barrotaríeis": "barrotar",
    "barrotas": "barrotar",
    "barrotasse": "barrotar",
    "barrotassem": "barrotar",
    "barrotasses": "barrotar",
    "barrotaste": "barrotar",
    "barrotastes": "barrotar",
    "barrotava": "barrotar",
    "barrotavam": "barrotar",
    "barrotavas": "barrotar",
    "barrote": "barrotar",
    "barroteada": "barrotear",
    "barroteadas": "barrotear",
    "barroteado": "barrotear",
    "barroteados": "barrotear",
    "barroteai": "barrotear",
    "barroteais": "barrotear",
    "barroteamo": "barrotear",
    "barroteamos": "barrotear",
    "barroteando": "barrotear",
    "barroteara": "barrotear",
    "barrotearam": "barrotear",
    "barrotearas": "barrotear",
    "barrotearde": "barrotear",
    "barroteardes": "barrotear",
    "barroteare": "barrotear",
    "barrotearei": "barrotear",
    "barroteareis": "barrotear",
    "barrotearem": "barrotear",
    "barrotearemos": "barrotear",
    "barroteares": "barrotear",
    "barrotearia": "barrotear",
    "barroteariam": "barrotear",
    "barrotearias": "barrotear",
    "barrotearmo": "barrotear",
    "barrotearmos": "barrotear",
    "barroteará": "barrotear",
    "barrotearás": "barrotear",
    "barrotearão": "barrotear",
    "barrotearíamos": "barrotear",
    "barrotearíeis": "barrotear",
    "barroteasse": "barrotear",
    "barroteassem": "barrotear",
    "barroteasses": "barrotear",
    "barroteaste": "barrotear",
    "barroteastes": "barrotear",
    "barroteava": "barrotear",
    "barroteavam": "barrotear",
    "barroteavas": "barrotear",
    "barroteei": "barrotear",
    "barroteeis": "barrotear",
    "barroteemo": "barrotear",
    "barroteemos": "barrotear",
    "barrotei": "barrotar",
    "barroteia": "barrotear",
    "barroteiam": "barrotear",
    "barroteias": "barrotear",
    "barroteie": "barrotear",
    "barroteiem": "barrotear",
    "barroteies": "barrotear",
    "barroteio": "barrotear",
    "barroteis": "barrotar",
    "barrotem": "barrotar",
    "barrotemo": "barrotar",
    "barrotemos": "barrotar",
    "barroteou": "barrotear",
    "barrotes": "barrote",
    "barroteá": "barrotear",
    "barroteámo": "barrotear",
    "barroteámos": "barrotear",
    "barroteáramo": "barrotear",
    "barroteáramos": "barrotear",
    "barroteárei": "barrotear",
    "barroteáreis": "barrotear",
    "barroteásseis": "barrotear",
    "barroteássemos": "barrotear",
    "barroteávamo": "barrotear",
    "barroteávamos": "barrotear",
    "barroteávei": "barrotear",
    "barroteáveis": "barrotear",
    "barroto": "barrotar",
    "barrotou": "barrotar",
    "barrotá": "barrotar",
    "barrotámo": "barrotar",
    "barrotámos": "barrotar",
    "barrotáramo": "barrotar",
    "barrotáramos": "barrotar",
    "barrotárei": "barrotar",
    "barrotáreis": "barrotar",
    "barrotásseis": "barrotar",
    "barrotássemos": "barrotar",
    "barrotávamo": "barrotar",
    "barrotávamos": "barrotar",
    "barrotávei": "barrotar",
    "barrotáveis": "barrotar",
    "barrou": "barrar",
    "barrufa": "barrufar",
    "barrufada": "barrufar",
    "barrufadas": "barrufar",
    "barrufado": "barrufar",
    "barrufados": "barrufar",
    "barrufai": "barrufar",
    "barrufais": "barrufar",
    "barrufam": "barrufar",
    "barrufamo": "barrufar",
    "barrufamos": "barrufar",
    "barrufando": "barrufar",
    "barrufara": "barrufar",
    "barrufaram": "barrufar",
    "barrufaras": "barrufar",
    "barrufarde": "barrufar",
    "barrufardes": "barrufar",
    "barrufare": "barrufar",
    "barrufarei": "barrufar",
    "barrufareis": "barrufar",
    "barrufarem": "barrufar",
    "barrufaremos": "barrufar",
    "barrufares": "barrufar",
    "barrufaria": "barrufar",
    "barrufariam": "barrufar",
    "barrufarias": "barrufar",
    "barrufarmo": "barrufar",
    "barrufarmos": "barrufar",
    "barrufará": "barrufar",
    "barrufarás": "barrufar",
    "barrufarão": "barrufar",
    "barrufaríamos": "barrufar",
    "barrufaríeis": "barrufar",
    "barrufas": "barrufar",
    "barrufasse": "barrufar",
    "barrufassem": "barrufar",
    "barrufasses": "barrufar",
    "barrufaste": "barrufar",
    "barrufastes": "barrufar",
    "barrufava": "barrufar",
    "barrufavam": "barrufar",
    "barrufavas": "barrufar",
    "barrufe": "barrufar",
    "barrufei": "barrufar",
    "barrufeis": "barrufar",
    "barrufem": "barrufar",
    "barrufemo": "barrufar",
    "barrufemos": "barrufar",
    "barrufes": "barrufar",
    "barrufo": "barrufar",
    "barrufos": "barrufo",
    "barrufou": "barrufar",
    "barrufá": "barrufar",
    "barrufámo": "barrufar",
    "barrufámos": "barrufar",
    "barrufáramo": "barrufar",
    "barrufáramos": "barrufar",
    "barrufárei": "barrufar",
    "barrufáreis": "barrufar",
    "barrufásseis": "barrufar",
    "barrufássemos": "barrufar",
    "barrufávamo": "barrufar",
    "barrufávamos": "barrufar",
    "barrufávei": "barrufar",
    "barrufáveis": "barrufar",
    "barrunta": "barruntar",
    "barruntada": "barruntar",
    "barruntadas": "barruntar",
    "barruntado": "barruntar",
    "barruntados": "barruntar",
    "barruntai": "barruntar",
    "barruntais": "barruntar",
    "barruntam": "barruntar",
    "barruntamo": "barruntar",
    "barruntamos": "barruntar",
    "barruntando": "barruntar",
    "barruntara": "barruntar",
    "barruntaram": "barruntar",
    "barruntaras": "barruntar",
    "barruntarde": "barruntar",
    "barruntardes": "barruntar",
    "barruntare": "barruntar",
    "barruntarei": "barruntar",
    "barruntareis": "barruntar",
    "barruntarem": "barruntar",
    "barruntaremos": "barruntar",
    "barruntares": "barruntar",
    "barruntaria": "barruntar",
    "barruntariam": "barruntar",
    "barruntarias": "barruntar",
    "barruntarmo": "barruntar",
    "barruntarmos": "barruntar",
    "barruntará": "barruntar",
    "barruntarás": "barruntar",
    "barruntarão": "barruntar",
    "barruntaríamos": "barruntar",
    "barruntaríeis": "barruntar",
    "barruntas": "barruntar",
    "barruntasse": "barruntar",
    "barruntassem": "barruntar",
    "barruntasses": "barruntar",
    "barruntaste": "barruntar",
    "barruntastes": "barruntar",
    "barruntava": "barruntar",
    "barruntavam": "barruntar",
    "barruntavas": "barruntar",
    "barrunte": "barruntar",
    "barruntei": "barruntar",
    "barrunteis": "barruntar",
    "barruntem": "barruntar",
    "barruntemo": "barruntar",
    "barruntemos": "barruntar",
    "barruntes": "barruntar",
    "barrunto": "barruntar",
    "barruntos": "barrunto",
    "barruntou": "barruntar",
    "barruntá": "barruntar",
    "barruntámo": "barruntar",
    "barruntámos": "barruntar",
    "barruntáramo": "barruntar",
    "barruntáramos": "barruntar",
    "barruntárei": "barruntar",
    "barruntáreis": "barruntar",
    "barruntásseis": "barruntar",
    "barruntássemos": "barruntar",
    "barruntávamo": "barruntar",
    "barruntávamos": "barruntar",
    "barruntávei": "barruntar",
    "barruntáveis": "barruntar",
    "barrá": "barrar",
    "barrámo": "barrar",
    "barrámos": "barrar",
    "barráramo": "barrar",
    "barráramos": "barrar",
    "barrárei": "barrar",
    "barráreis": "barrar",
    "barrásseis": "barrar",
    "barrássemos": "barrar",
    "barrávamo": "barrar",
    "barrávamos": "barrar",
    "barrávei": "barrar",
    "barráveis": "barrar",
    "barríamo": "barrir",
    "barríamos": "barrir",
    "barríeis": "barrir",
    "barríramo": "barrir",
    "barríramos": "barrir",
    "barríreis": "barrir",
    "barrísseis": "barrir",
    "barríssemos": "barrir",
    "barrões": "barrão",
    "bartolomeus": "bartolomeu",
    "barulha": "barulhar",
    "barulhada": "barulhar",
    "barulhadas": "barulhar",
    "barulhado": "barulhar",
    "barulhados": "barulhar",
    "barulhai": "barulhar",
    "barulhais": "barulhar",
    "barulham": "barulhar",
    "barulhamo": "barulhar",
    "barulhamos": "barulhar",
    "barulhando": "barulhar",
    "barulhara": "barulhar",
    "barulharam": "barulhar",
    "barulharas": "barulhar",
    "barulharde": "barulhar",
    "barulhardes": "barulhar",
    "barulhare": "barulhar",
    "barulharei": "barulhar",
    "barulhareis": "barulhar",
    "barulharem": "barulhar",
    "barulharemos": "barulhar",
    "barulhares": "barulhar",
    "barulharia": "barulhar",
    "barulhariam": "barulhar",
    "barulharias": "barulhar",
    "barulharmo": "barulhar",
    "barulharmos": "barulhar",
    "barulhará": "barulhar",
    "barulharás": "barulhar",
    "barulharão": "barulhar",
    "barulharíamos": "barulhar",
    "barulharíeis": "barulhar",
    "barulhas": "barulhar",
    "barulhasse": "barulhar",
    "barulhassem": "barulhar",
    "barulhasses": "barulhar",
    "barulhaste": "barulhar",
    "barulhastes": "barulhar",
    "barulhava": "barulhar",
    "barulhavam": "barulhar",
    "barulhavas": "barulhar",
    "barulhe": "barulhar",
    "barulhei": "barulhar",
    "barulheira": "barulheiro",
    "barulheiras": "barulheiro",
    "barulheiros": "barulheiro",
    "barulheis": "barulhar",
    "barulhem": "barulhar",
    "barulhemo": "barulhar",
    "barulhemos": "barulhar",
    "barulhenta": "barulhento",
    "barulhentas": "barulhento",
    "barulhentos": "barulhento",
    "barulhes": "barulhar",
    "barulhinho": "barulho",
    "barulhinhos": "barulho",
    "barulhito": "barulho",
    "barulhitos": "barulho",
    "barulho": "barulhar",
    "barulhos": "barulho",
    "barulhosa": "barulhoso",
    "barulhosas": "barulhoso",
    "barulhosos": "barulhoso",
    "barulhou": "barulhar",
    "barulhá": "barulhar",
    "barulhámo": "barulhar",
    "barulhámos": "barulhar",
    "barulháramo": "barulhar",
    "barulháramos": "barulhar",
    "barulhárei": "barulhar",
    "barulháreis": "barulhar",
    "barulhásseis": "barulhar",
    "barulhássemos": "barulhar",
    "barulhávamo": "barulhar",
    "barulhávamos": "barulhar",
    "barulhávei": "barulhar",
    "barulháveis": "barulhar",
    "barzinho": "bar",
    "barzinhos": "bar",
    "barzito": "bar",
    "barzitos": "bar",
    "barãozinho": "barão",
    "barãozito": "barão",
    "barças": "barça",
    "barítonos": "barítono",
    "barógrafos": "barógrafo",
    "barómetros": "barómetro",
    "baróstatos": "baróstato",
    "barões": "barão",
    "barõezinhos": "barão",
    "barõezitos": "barão",
    "basais": "basal",
    "basaltiformes": "basaltiforme",
    "basaltos": "basalto",
    "basbacarias": "basbacaria",
    "basbaqueiras": "basbaqueira",
    "basbaques": "basbaque",
    "basbaquices": "basbaquice",
    "basca": "basco",
    "bascas": "basco",
    "bascos": "basco",
    "basculantes": "basculante",
    "basculha": "basculhar",
    "basculhada": "basculhar",
    "basculhadas": "basculhar",
    "basculhado": "basculhar",
    "basculhados": "basculhar",
    "basculhai": "basculhar",
    "basculhais": "basculhar",
    "basculham": "basculhar",
    "basculhamo": "basculhar",
    "basculhamos": "basculhar",
    "basculhando": "basculhar",
    "basculhara": "basculhar",
    "basculharam": "basculhar",
    "basculharas": "basculhar",
    "basculharde": "basculhar",
    "basculhardes": "basculhar",
    "basculhare": "basculhar",
    "basculharei": "basculhar",
    "basculhareis": "basculhar",
    "basculharem": "basculhar",
    "basculharemos": "basculhar",
    "basculhares": "basculhar",
    "basculharia": "basculhar",
    "basculhariam": "basculhar",
    "basculharias": "basculhar",
    "basculharmo": "basculhar",
    "basculharmos": "basculhar",
    "basculhará": "basculhar",
    "basculharás": "basculhar",
    "basculharão": "basculhar",
    "basculharíamos": "basculhar",
    "basculharíeis": "basculhar",
    "basculhas": "basculhar",
    "basculhasse": "basculhar",
    "basculhassem": "basculhar",
    "basculhasses": "basculhar",
    "basculhaste": "basculhar",
    "basculhastes": "basculhar",
    "basculhava": "basculhar",
    "basculhavam": "basculhar",
    "basculhavas": "basculhar",
    "basculhe": "basculhar",
    "basculhei": "basculhar",
    "basculheis": "basculhar",
    "basculhem": "basculhar",
    "basculhemo": "basculhar",
    "basculhemos": "basculhar",
    "basculhes": "basculhar",
    "basculho": "basculhar",
    "basculhos": "basculho",
    "basculhou": "basculhar",
    "basculhá": "basculhar",
    "basculhámo": "basculhar",
    "basculhámos": "basculhar",
    "basculháramo": "basculhar",
    "basculháramos": "basculhar",
    "basculhárei": "basculhar",
    "basculháreis": "basculhar",
    "basculhásseis": "basculhar",
    "basculhássemos": "basculhar",
    "basculhávamo": "basculhar",
    "basculhávamos": "basculhar",
    "basculhávei": "basculhar",
    "basculháveis": "basculhar",
    "baseada": "basear",
    "baseadas": "basear",
    "baseado": "basear",
    "baseados": "basear",
    "baseai": "basear",
    "baseais": "basear",
    "baseamentos": "baseamento",
    "baseamo": "basear",
    "baseamos": "basear",
    "baseando": "basear",
    "baseara": "basear",
    "basearam": "basear",
    "basearas": "basear",
    "basearde": "basear",
    "baseardes": "basear",
    "baseare": "basear",
    "basearei": "basear",
    "baseareis": "basear",
    "basearem": "basear",
    "basearemos": "basear",
    "baseares": "basear",
    "basearia": "basear",
    "baseariam": "basear",
    "basearias": "basear",
    "basearmo": "basear",
    "basearmos": "basear",
    "baseará": "basear",
    "basearás": "basear",
    "basearão": "basear",
    "basearíamos": "basear",
    "basearíeis": "basear",
    "baseasse": "basear",
    "baseassem": "basear",
    "baseasses": "basear",
    "baseaste": "basear",
    "baseastes": "basear",
    "baseava": "basear",
    "baseavam": "basear",
    "baseavas": "basear",
    "basebóis": "basebol",
    "baseei": "basear",
    "baseeis": "basear",
    "baseemo": "basear",
    "baseemos": "basear",
    "baseia": "basear",
    "baseiam": "basear",
    "baseias": "basear",
    "baseie": "basear",
    "baseiem": "basear",
    "baseies": "basear",
    "baseio": "basear",
    "baselgas": "baselga",
    "baseofobias": "baseofobia",
    "baseou": "basear",
    "bases": "base",
    "basezinha": "base",
    "basezinhas": "base",
    "basezita": "base",
    "basezitas": "base",
    "baseá": "basear",
    "baseámo": "basear",
    "baseámos": "basear",
    "baseáramo": "basear",
    "baseáramos": "basear",
    "baseárei": "basear",
    "baseáreis": "basear",
    "baseásseis": "basear",
    "baseássemos": "basear",
    "baseávamo": "basear",
    "baseávamos": "basear",
    "baseávei": "basear",
    "baseáveis": "basear",
    "basicidades": "basicidade",
    "basicromatinas": "basicromatina",
    "basidiósporos": "basidiósporo",
    "basifica": "basificar",
    "basificada": "basificar",
    "basificadas": "basificar",
    "basificado": "basificar",
    "basificados": "basificar",
    "basificai": "basificar",
    "basificais": "basificar",
    "basificam": "basificar",
    "basificamo": "basificar",
    "basificamos": "basificar",
    "basificando": "basificar",
    "basificara": "basificar",
    "basificaram": "basificar",
    "basificaras": "basificar",
    "basificarde": "basificar",
    "basificardes": "basificar",
    "basificare": "basificar",
    "basificarei": "basificar",
    "basificareis": "basificar",
    "basificarem": "basificar",
    "basificaremos": "basificar",
    "basificares": "basificar",
    "basificaria": "basificar",
    "basificariam": "basificar",
    "basificarias": "basificar",
    "basificarmo": "basificar",
    "basificarmos": "basificar",
    "basificará": "basificar",
    "basificarás": "basificar",
    "basificarão": "basificar",
    "basificaríamos": "basificar",
    "basificaríeis": "basificar",
    "basificas": "basificar",
    "basificasse": "basificar",
    "basificassem": "basificar",
    "basificasses": "basificar",
    "basificaste": "basificar",
    "basificastes": "basificar",
    "basificava": "basificar",
    "basificavam": "basificar",
    "basificavas": "basificar",
    "basificações": "basificação",
    "basifico": "basificar",
    "basificou": "basificar",
    "basificá": "basificar",
    "basificámo": "basificar",
    "basificámos": "basificar",
    "basificáramo": "basificar",
    "basificáramos": "basificar",
    "basificárei": "basificar",
    "basificáreis": "basificar",
    "basificásseis": "basificar",
    "basificássemos": "basificar",
    "basificávamo": "basificar",
    "basificávamos": "basificar",
    "basificávei": "basificar",
    "basificáveis": "basificar",
    "basifique": "basificar",
    "basifiquei": "basificar",
    "basifiqueis": "basificar",
    "basifiquem": "basificar",
    "basifiquemo": "basificar",
    "basifiquemos": "basificar",
    "basifiques": "basificar",
    "basifixa": "basifixo",
    "basifixas": "basifixo",
    "basifixos": "basifixo",
    "basigénia": "basigénio",
    "basigénias": "basigénio",
    "basigénios": "basigénio",
    "basilares": "basilar",
    "basilicais": "basilical",
    "basilicões": "basilicão",
    "basiliscos": "basilisco",
    "basinérvea": "basinérveo",
    "basinérveas": "basinérveo",
    "basinérveos": "basinérveo",
    "basipinacóides": "basipinacóide",
    "basofobias": "basofobia",
    "basquetebolistas": "basquetebolista",
    "basquetebolística": "basquetebolístico",
    "basquetebolísticas": "basquetebolístico",
    "basquetebolísticos": "basquetebolístico",
    "basquetebóis": "basquetebol",
    "bassês": "bassê",
    "basta": "basto",
    "bastada": "bastar",
    "bastadas": "bastar",
    "bastado": "bastar",
    "bastados": "bastar",
    "bastai": "bastar",
    "bastais": "bastir",
    "bastam": "bastir",
    "bastamo": "bastir",
    "bastamos": "bastir",
    "bastando": "bastar",
    "bastantes": "bastante",
    "bastara": "bastar",
    "bastaram": "bastar",
    "bastaras": "bastar",
    "bastarda": "bastardo",
    "bastardas": "bastardo",
    "bastardazinha": "bastardo",
    "bastardazinhas": "bastardo",
    "bastardazita": "bastardo",
    "bastardazitas": "bastardo",
    "bastardeada": "bastardear",
    "bastardeadas": "bastardear",
    "bastardeado": "bastardear",
    "bastardeados": "bastardear",
    "bastardeai": "bastardear",
    "bastardeais": "bastardear",
    "bastardeamo": "bastardear",
    "bastardeamos": "bastardear",
    "bastardeando": "bastardear",
    "bastardeara": "bastardear",
    "bastardearam": "bastardear",
    "bastardearas": "bastardear",
    "bastardeardes": "bastardear",
    "bastardearei": "bastardear",
    "bastardeareis": "bastardear",
    "bastardearem": "bastardear",
    "bastardearemos": "bastardear",
    "bastardeares": "bastardear",
    "bastardearia": "bastardear",
    "bastardeariam": "bastardear",
    "bastardearias": "bastardear",
    "bastardearmo": "bastardear",
    "bastardearmos": "bastardear",
    "bastardeará": "bastardear",
    "bastardearás": "bastardear",
    "bastardearão": "bastardear",
    "bastardearíamos": "bastardear",
    "bastardearíeis": "bastardear",
    "bastardeasse": "bastardear",
    "bastardeassem": "bastardear",
    "bastardeasses": "bastardear",
    "bastardeaste": "bastardear",
    "bastardeastes": "bastardear",
    "bastardeava": "bastardear",
    "bastardeavam": "bastardear",
    "bastardeavas": "bastardear",
    "bastardeei": "bastardear",
    "bastardeeis": "bastardear",
    "bastardeemo": "bastardear",
    "bastardeemos": "bastardear",
    "bastardeia": "bastardear",
    "bastardeiam": "bastardear",
    "bastardeias": "bastardear",
    "bastardeie": "bastardear",
    "bastardeiem": "bastardear",
    "bastardeies": "bastardear",
    "bastardeio": "bastardear",
    "bastardeira": "bastardeiro",
    "bastardeiras": "bastardeiro",
    "bastardeiros": "bastardeiro",
    "bastardeou": "bastardear",
    "bastardes": "bastar",
    "bastardeámo": "bastardear",
    "bastardeámos": "bastardear",
    "bastardeáramo": "bastardear",
    "bastardeáramos": "bastardear",
    "bastardeáreis": "bastardear",
    "bastardeásseis": "bastardear",
    "bastardeássemos": "bastardear",
    "bastardeávamo": "bastardear",
    "bastardeávamos": "bastardear",
    "bastardeáveis": "bastardear",
    "bastardias": "bastardia",
    "bastardinhas": "bastardinha",
    "bastardinhos": "bastardinho",
    "bastardos": "bastardo",
    "bastardozinho": "bastardo",
    "bastardozinhos": "bastardo",
    "bastardozito": "bastardo",
    "bastardozitos": "bastardo",
    "bastardões": "bastardão",
    "bastarei": "bastar",
    "bastareis": "bastar",
    "bastarem": "bastar",
    "bastaremos": "bastar",
    "bastares": "bastar",
    "bastaria": "bastar",
    "bastariam": "bastar",
    "bastarias": "bastar",
    "bastarmo": "bastar",
    "bastarmos": "bastar",
    "bastará": "bastar",
    "bastarás": "bastar",
    "bastarão": "bastar",
    "bastaríamos": "bastar",
    "bastaríeis": "bastar",
    "bastas": "basto",
    "bastasse": "bastar",
    "bastassem": "bastar",
    "bastasses": "bastar",
    "bastaste": "bastar",
    "bastastes": "bastar",
    "bastava": "bastar",
    "bastavam": "bastar",
    "bastavas": "bastar",
    "baste": "bastir",
    "basteada": "bastear",
    "basteadas": "bastear",
    "basteado": "bastear",
    "basteados": "bastear",
    "basteai": "bastear",
    "basteais": "bastear",
    "basteamo": "bastear",
    "basteamos": "bastear",
    "basteando": "bastear",
    "basteara": "bastear",
    "bastearam": "bastear",
    "bastearas": "bastear",
    "bastearde": "bastear",
    "basteardeiras": "basteardeira",
    "basteardes": "bastear",
    "basteare": "bastear",
    "bastearei": "bastear",
    "basteareis": "bastear",
    "bastearem": "bastear",
    "bastearemos": "bastear",
    "basteares": "bastear",
    "bastearia": "bastear",
    "basteariam": "bastear",
    "bastearias": "bastear",
    "bastearmo": "bastear",
    "bastearmos": "bastear",
    "basteará": "bastear",
    "bastearás": "bastear",
    "bastearão": "bastear",
    "bastearíamos": "bastear",
    "bastearíeis": "bastear",
    "basteasse": "bastear",
    "basteassem": "bastear",
    "basteasses": "bastear",
    "basteaste": "bastear",
    "basteastes": "bastear",
    "basteava": "bastear",
    "basteavam": "bastear",
    "basteavas": "bastear",
    "basteei": "bastear",
    "basteeis": "bastear",
    "basteemo": "bastear",
    "basteemos": "bastear",
    "bastei": "bastar",
    "basteia": "bastear",
    "basteiam": "bastear",
    "basteias": "bastear",
    "basteie": "bastear",
    "basteiem": "bastear",
    "basteies": "bastear",
    "basteio": "bastear",
    "basteis": "bastar",
    "bastem": "bastir",
    "bastemo": "bastar",
    "bastemos": "bastar",
    "basteou": "bastear",
    "bastes": "bastir",
    "basteá": "bastear",
    "basteámo": "bastear",
    "basteámos": "bastear",
    "basteáramo": "bastear",
    "basteáramos": "bastear",
    "basteárei": "bastear",
    "basteáreis": "bastear",
    "basteásseis": "bastear",
    "basteássemos": "bastear",
    "basteávamo": "bastear",
    "basteávamos": "bastear",
    "basteávei": "bastear",
    "basteáveis": "bastear",
    "basti": "bastir",
    "bastia": "bastir",
    "bastiam": "bastir",
    "bastias": "bastir",
    "bastida": "bastir",
    "bastidas": "bastir",
    "bastido": "bastir",
    "bastidores": "bastidor",
    "bastidos": "bastir",
    "bastidões": "bastidão",
    "bastilhas": "bastilha",
    "bastimentos": "bastimento",
    "bastimo": "bastir",
    "bastimos": "bastir",
    "bastindo": "bastir",
    "bastios": "bastio",
    "bastira": "bastir",
    "bastiram": "bastir",
    "bastiras": "bastir",
    "bastirde": "bastir",
    "bastirdes": "bastir",
    "bastire": "bastir",
    "bastirei": "bastir",
    "bastireis": "bastir",
    "bastirem": "bastir",
    "bastiremos": "bastir",
    "bastires": "bastir",
    "bastiria": "bastir",
    "bastiriam": "bastir",
    "bastirias": "bastir",
    "bastirmo": "bastir",
    "bastirmos": "bastir",
    "bastirá": "bastir",
    "bastirás": "bastir",
    "bastirão": "bastir",
    "bastiríamos": "bastir",
    "bastiríeis": "bastir",
    "bastis": "bastir",
    "bastisse": "bastir",
    "bastissem": "bastir",
    "bastisses": "bastir",
    "bastiste": "bastir",
    "bastistes": "bastir",
    "bastiu": "bastir",
    "bastiçagens": "bastiçagem",
    "bastições": "bastição",
    "bastiões": "bastião",
    "basto": "bastir",
    "bastonadas": "bastonada",
    "bastonetes": "bastonete",
    "bastonária": "bastonário",
    "bastonárias": "bastonário",
    "bastonários": "bastonário",
    "bastos": "basto",
    "bastou": "bastar",
    "basturas": "bastura",
    "bastámo": "bastar",
    "bastámos": "bastar",
    "bastáramo": "bastar",
    "bastáramos": "bastar",
    "bastáreis": "bastar",
    "bastásseis": "bastar",
    "bastássemos": "bastar",
    "bastávamo": "bastar",
    "bastávamos": "bastar",
    "bastáveis": "bastar",
    "bastíamo": "bastir",
    "bastíamos": "bastir",
    "bastíei": "bastir",
    "bastíeis": "bastir",
    "bastíramo": "bastir",
    "bastíramos": "bastir",
    "bastírei": "bastir",
    "bastíreis": "bastir",
    "bastísseis": "bastir",
    "bastíssemos": "bastir",
    "bastíssima": "basto",
    "bastíssimas": "basto",
    "bastíssimo": "basto",
    "bastíssimos": "basto",
    "bastões": "bastão",
    "basáltica": "basáltico",
    "basálticas": "basáltico",
    "basálticos": "basáltico",
    "basídiomicites": "basídiomicite",
    "basídiomicitos": "basídiomicito",
    "basídios": "basídio",
    "basífuga": "basífugo",
    "basífugas": "basífugo",
    "basífugos": "basífugo",
    "basílicas": "basílica",
    "basílicos": "basílico",
    "basípeta": "basípeto",
    "basípetas": "basípeto",
    "basípetos": "basípeto",
    "basófila": "basófilo",
    "basófilas": "basófilo",
    "basófilos": "basófilo",
    "bata": "bater",
    "batachins": "batachim",
    "batagens": "batagem",
    "batages": "batage",
    "batais": "bater",
    "batalha": "batalhar",
    "batalhada": "batalhar",
    "batalhadas": "batalhar",
    "batalhadeira": "batalhador",
    "batalhadeiras": "batalhador",
    "batalhado": "batalhar",
    "batalhadora": "batalhador",
    "batalhadoras": "batalhador",
    "batalhadores": "batalhador",
    "batalhados": "batalhar",
    "batalhai": "batalhar",
    "batalhais": "batalhar",
    "batalham": "batalhar",
    "batalhamo": "batalhar",
    "batalhamos": "batalhar",
    "batalhando": "batalhar",
    "batalhantes": "batalhante",
    "batalhara": "batalhar",
    "batalharam": "batalhar",
    "batalharas": "batalhar",
    "batalhardes": "batalhar",
    "batalharei": "batalhar",
    "batalhareis": "batalhar",
    "batalharem": "batalhar",
    "batalharemos": "batalhar",
    "batalhares": "batalhar",
    "batalharia": "batalhar",
    "batalhariam": "batalhar",
    "batalharias": "batalhar",
    "batalharmo": "batalhar",
    "batalharmos": "batalhar",
    "batalhará": "batalhar",
    "batalharás": "batalhar",
    "batalharão": "batalhar",
    "batalharíamos": "batalhar",
    "batalharíeis": "batalhar",
    "batalhas": "batalhar",
    "batalhasse": "batalhar",
    "batalhassem": "batalhar",
    "batalhasses": "batalhar",
    "batalhaste": "batalhar",
    "batalhastes": "batalhar",
    "batalhava": "batalhar",
    "batalhavam": "batalhar",
    "batalhavas": "batalhar",
    "batalhe": "batalhar",
    "batalhei": "batalhar",
    "batalheiras": "batalheira",
    "batalheis": "batalhar",
    "batalhem": "batalhar",
    "batalhemo": "batalhar",
    "batalhemos": "batalhar",
    "batalhes": "batalhar",
    "batalho": "batalhar",
    "batalhou": "batalhar",
    "batalhámo": "batalhar",
    "batalhámos": "batalhar",
    "batalháramo": "batalhar",
    "batalháramos": "batalhar",
    "batalháreis": "batalhar",
    "batalhásseis": "batalhar",
    "batalhássemos": "batalhar",
    "batalhávamo": "batalhar",
    "batalhávamos": "batalhar",
    "batalháveis": "batalhar",
    "batalhões": "batalhão",
    "batam": "bater",
    "batamo": "bater",
    "batamos": "bater",
    "batardas": "batarda",
    "batardões": "batardão",
    "batarias": "bataria",
    "batas": "bater",
    "batatadas": "batatada",
    "batatais": "batatal",
    "batatas": "batata",
    "batateira": "batateiro",
    "batateirais": "batateiral",
    "batateiras": "batateiro",
    "batateiros": "batateiro",
    "batatinha": "batata",
    "batatinhas": "batata",
    "batatita": "batata",
    "batatitas": "batata",
    "batatuda": "batatudo",
    "batatudas": "batatudo",
    "batatudinha": "batatudo",
    "batatudinhas": "batatudo",
    "batatudinho": "batatudo",
    "batatudinhos": "batatudo",
    "batatudita": "batatudo",
    "batatuditas": "batatudo",
    "batatudito": "batatudo",
    "batatuditos": "batatudo",
    "batatudos": "batatudo",
    "bate": "bater",
    "bateada": "batear",
    "bateadas": "batear",
    "bateado": "batear",
    "bateados": "batear",
    "bateai": "batear",
    "bateais": "batear",
    "bateamo": "batear",
    "bateamos": "batear",
    "bateando": "batear",
    "bateara": "batear",
    "batearam": "batear",
    "batearas": "batear",
    "batearde": "batear",
    "bateardes": "batear",
    "bateare": "batear",
    "batearei": "batear",
    "bateareis": "batear",
    "batearem": "batear",
    "batearemos": "batear",
    "bateares": "batear",
    "batearia": "batear",
    "bateariam": "batear",
    "batearias": "batear",
    "batearmo": "batear",
    "batearmos": "batear",
    "bateará": "batear",
    "batearás": "batear",
    "batearão": "batear",
    "batearíamos": "batear",
    "batearíeis": "batear",
    "bateasse": "batear",
    "bateassem": "batear",
    "bateasses": "batear",
    "bateaste": "batear",
    "bateastes": "batear",
    "bateava": "batear",
    "bateavam": "batear",
    "bateavas": "batear",
    "batedeira": "batedor",
    "batedeiras": "batedor",
    "batedelas": "batedela",
    "batedoiros": "batedoiro",
    "batedora": "batedor",
    "batedoras": "batedora",
    "batedores": "batedor",
    "batedouros": "batedouro",
    "bateduras": "batedura",
    "bateei": "batear",
    "bateeis": "batear",
    "bateemo": "batear",
    "bateemos": "batear",
    "bategadas": "bategada",
    "batei": "bater",
    "bateia": "batear",
    "bateiam": "batear",
    "bateias": "bateia",
    "bateie": "batear",
    "bateiem": "batear",
    "bateies": "batear",
    "bateio": "batear",
    "bateira": "bateiro",
    "bateiras": "bateiro",
    "bateiros": "bateiro",
    "bateis": "bater",
    "bateladas": "batelada",
    "batelas": "batela",
    "bateleiros": "bateleiro",
    "batelos": "batelo",
    "batelões": "batelão",
    "batem": "bater",
    "batemo": "bater",
    "batemos": "bater",
    "batendo": "bater",
    "batentes": "batente",
    "bateou": "batear",
    "batera": "bater",
    "bateram": "bater",
    "bateras": "bater",
    "baterde": "bater",
    "baterdes": "bater",
    "batere": "bater",
    "baterei": "bater",
    "batereis": "bater",
    "baterem": "bater",
    "bateremos": "bater",
    "bateres": "bater",
    "bateria": "bater",
    "bateriam": "bater",
    "baterias": "bateria",
    "bateristas": "baterista",
    "batermo": "bater",
    "batermos": "bater",
    "baterá": "bater",
    "baterás": "bater",
    "baterão": "bater",
    "bateríamos": "bater",
    "bateríeis": "bater",
    "bates": "bater",
    "batesse": "bater",
    "batessem": "bater",
    "batesses": "bater",
    "bateste": "bater",
    "batestes": "bater",
    "bateu": "bater",
    "bateá": "batear",
    "bateámo": "batear",
    "bateámos": "batear",
    "bateáramo": "batear",
    "bateáramos": "batear",
    "bateárei": "batear",
    "bateáreis": "batear",
    "bateásseis": "batear",
    "bateássemos": "batear",
    "bateávamo": "batear",
    "bateávamos": "batear",
    "bateávei": "batear",
    "bateáveis": "batear",
    "bati": "bater",
    "batia": "bater",
    "batiam": "bater",
    "batias": "bater",
    "batibarbas": "batibarba",
    "batida": "batido",
    "batidas": "batido",
    "batido": "bater",
    "batidos": "batido",
    "batidíssima": "batido",
    "batidíssimas": "batido",
    "batidíssimo": "batido",
    "batidíssimos": "batido",
    "batigrafias": "batigrafia",
    "batilha": "batilhar",
    "batilhada": "batilhar",
    "batilhadas": "batilhar",
    "batilhado": "batilhar",
    "batilhados": "batilhar",
    "batilhai": "batilhar",
    "batilhais": "batilhar",
    "batilham": "batilhar",
    "batilhamo": "batilhar",
    "batilhamos": "batilhar",
    "batilhando": "batilhar",
    "batilhara": "batilhar",
    "batilharam": "batilhar",
    "batilharas": "batilhar",
    "batilhardes": "batilhar",
    "batilharei": "batilhar",
    "batilhareis": "batilhar",
    "batilharem": "batilhar",
    "batilharemos": "batilhar",
    "batilhares": "batilhar",
    "batilharia": "batilhar",
    "batilhariam": "batilhar",
    "batilharias": "batilhar",
    "batilharmo": "batilhar",
    "batilharmos": "batilhar",
    "batilhará": "batilhar",
    "batilharás": "batilhar",
    "batilharão": "batilhar",
    "batilharíamos": "batilhar",
    "batilharíeis": "batilhar",
    "batilhas": "batilhar",
    "batilhasse": "batilhar",
    "batilhassem": "batilhar",
    "batilhasses": "batilhar",
    "batilhaste": "batilhar",
    "batilhastes": "batilhar",
    "batilhava": "batilhar",
    "batilhavam": "batilhar",
    "batilhavas": "batilhar",
    "batilhe": "batilhar",
    "batilhei": "batilhar",
    "batilheis": "batilhar",
    "batilhem": "batilhar",
    "batilhemo": "batilhar",
    "batilhemos": "batilhar",
    "batilhes": "batilhar",
    "batilho": "batilhar",
    "batilhou": "batilhar",
    "batilhámo": "batilhar",
    "batilhámos": "batilhar",
    "batilháramo": "batilhar",
    "batilháramos": "batilhar",
    "batilháreis": "batilhar",
    "batilhásseis": "batilhar",
    "batilhássemos": "batilhar",
    "batilhávamo": "batilhar",
    "batilhávamos": "batilhar",
    "batilháveis": "batilhar",
    "batimentos": "batimento",
    "batimetrias": "batimetria",
    "batimétrica": "batimétrico",
    "batimétricas": "batimétrico",
    "batimétricos": "batimétrico",
    "batinas": "batina",
    "batinha": "bata",
    "batinhas": "bata",
    "batipelágica": "batipelágico",
    "batipelágicas": "batipelágico",
    "batipelágicos": "batipelágico",
    "batiques": "batique",
    "batiscafos": "batiscafo",
    "batisferas": "batisfera",
    "batita": "bata",
    "batitas": "bata",
    "bato": "bater",
    "batoca": "batocar",
    "batocada": "batocar",
    "batocadas": "batocar",
    "batocado": "batocar",
    "batocados": "batocar",
    "batocaduras": "batocadura",
    "batocai": "batocar",
    "batocais": "batocar",
    "batocam": "batocar",
    "batocamo": "batocar",
    "batocamos": "batocar",
    "batocando": "batocar",
    "batocara": "batocar",
    "batocaram": "batocar",
    "batocaras": "batocar",
    "batocarde": "batocar",
    "batocardes": "batocar",
    "batocare": "batocar",
    "batocarei": "batocar",
    "batocareis": "batocar",
    "batocarem": "batocar",
    "batocaremos": "batocar",
    "batocares": "batocar",
    "batocaria": "batocar",
    "batocariam": "batocar",
    "batocarias": "batocar",
    "batocarmo": "batocar",
    "batocarmos": "batocar",
    "batocará": "batocar",
    "batocarás": "batocar",
    "batocarão": "batocar",
    "batocaríamos": "batocar",
    "batocaríeis": "batocar",
    "batocas": "batocar",
    "batocasse": "batocar",
    "batocassem": "batocar",
    "batocasses": "batocar",
    "batocaste": "batocar",
    "batocastes": "batocar",
    "batocava": "batocar",
    "batocavam": "batocar",
    "batocavas": "batocar",
    "batoco": "batocar",
    "batocos": "batoco",
    "batocou": "batocar",
    "batocá": "batocar",
    "batocámo": "batocar",
    "batocámos": "batocar",
    "batocáramo": "batocar",
    "batocáramos": "batocar",
    "batocárei": "batocar",
    "batocáreis": "batocar",
    "batocásseis": "batocar",
    "batocássemos": "batocar",
    "batocávamo": "batocar",
    "batocávamos": "batocar",
    "batocávei": "batocar",
    "batocáveis": "batocar",
    "batografias": "batografia",
    "batográfica": "batográfico",
    "batográficas": "batográfico",
    "batográficos": "batográfico",
    "batologias": "batologia",
    "batológica": "batológico",
    "batológicas": "batológico",
    "batológicos": "batológico",
    "batometrias": "batometria",
    "batométrica": "batométrico",
    "batométricas": "batométrico",
    "batométricos": "batométrico",
    "batons": "baton",
    "batoque": "batocar",
    "batoquei": "batocar",
    "batoqueiras": "batoqueira",
    "batoqueis": "batocar",
    "batoquem": "batocar",
    "batoquemo": "batocar",
    "batoquemos": "batocar",
    "batoques": "batoque",
    "batos": "bato",
    "batota": "batotar",
    "batotada": "batotar",
    "batotadas": "batotar",
    "batotado": "batotar",
    "batotados": "batotar",
    "batotai": "batotar",
    "batotais": "batotar",
    "batotam": "batotar",
    "batotamo": "batotar",
    "batotamos": "batotar",
    "batotando": "batotar",
    "batotara": "batotar",
    "batotaram": "batotar",
    "batotaras": "batotar",
    "batotardes": "batotar",
    "batotarei": "batotar",
    "batotareis": "batotar",
    "batotarem": "batotar",
    "batotaremos": "batotar",
    "batotares": "batotar",
    "batotaria": "batotar",
    "batotariam": "batotar",
    "batotarias": "batotar",
    "batotarmo": "batotar",
    "batotarmos": "batotar",
    "batotará": "batotar",
    "batotarás": "batotar",
    "batotarão": "batotar",
    "batotaríamos": "batotar",
    "batotaríeis": "batotar",
    "batotas": "batotar",
    "batotasse": "batotar",
    "batotassem": "batotar",
    "batotasses": "batotar",
    "batotaste": "batotar",
    "batotastes": "batotar",
    "batotava": "batotar",
    "batotavam": "batotar",
    "batotavas": "batotar",
    "batotazinha": "batota",
    "batotazinhas": "batota",
    "batotazita": "batota",
    "batotazitas": "batota",
    "batote": "batotar",
    "batoteada": "batotear",
    "batoteadas": "batotear",
    "batoteado": "batotear",
    "batoteados": "batotear",
    "batoteai": "batotear",
    "batoteais": "batotear",
    "batoteamo": "batotear",
    "batoteamos": "batotear",
    "batoteando": "batotear",
    "batoteara": "batotear",
    "batotearam": "batotear",
    "batotearas": "batotear",
    "batoteardes": "batotear",
    "batotearei": "batotear",
    "batoteareis": "batotear",
    "batotearem": "batotear",
    "batotearemos": "batotear",
    "batoteares": "batotear",
    "batotearia": "batotear",
    "batoteariam": "batotear",
    "batotearias": "batotear",
    "batotearmo": "batotear",
    "batotearmos": "batotear",
    "batoteará": "batotear",
    "batotearás": "batotear",
    "batotearão": "batotear",
    "batotearíamos": "batotear",
    "batotearíeis": "batotear",
    "batoteasse": "batotear",
    "batoteassem": "batotear",
    "batoteasses": "batotear",
    "batoteaste": "batotear",
    "batoteastes": "batotear",
    "batoteava": "batotear",
    "batoteavam": "batotear",
    "batoteavas": "batotear",
    "batoteei": "batotear",
    "batoteeis": "batotear",
    "batoteemo": "batotear",
    "batoteemos": "batotear",
    "batotei": "batotar",
    "batoteia": "batotear",
    "batoteiam": "batotear",
    "batoteias": "batotear",
    "batoteie": "batotear",
    "batoteiem": "batotear",
    "batoteies": "batotear",
    "batoteio": "batotear",
    "batoteira": "batoteiro",
    "batoteiras": "batoteiro",
    "batoteirazinha": "batoteiro",
    "batoteirazinhas": "batoteiro",
    "batoteirazita": "batoteiro",
    "batoteirazitas": "batoteiro",
    "batoteirinha": "batoteiro",
    "batoteirinhas": "batoteiro",
    "batoteirinho": "batoteiro",
    "batoteirinhos": "batoteiro",
    "batoteirita": "batoteiro",
    "batoteiritas": "batoteiro",
    "batoteirito": "batoteiro",
    "batoteiritos": "batoteiro",
    "batoteiros": "batoteiro",
    "batoteirozinho": "batoteiro",
    "batoteirozinhos": "batoteiro",
    "batoteirozito": "batoteiro",
    "batoteirozitos": "batoteiro",
    "batoteis": "batotar",
    "batotem": "batotar",
    "batotemo": "batotar",
    "batotemos": "batotar",
    "batoteou": "batotear",
    "batotes": "batotar",
    "batoteámo": "batotear",
    "batoteámos": "batotear",
    "batoteáramo": "batotear",
    "batoteáramos": "batotear",
    "batoteáreis": "batotear",
    "batoteásseis": "batotear",
    "batoteássemos": "batotear",
    "batoteávamo": "batotear",
    "batoteávamos": "batotear",
    "batoteáveis": "batotear",
    "batotinha": "batota",
    "batotinhas": "batota",
    "batotita": "batota",
    "batotitas": "batota",
    "batoto": "batotar",
    "batotou": "batotar",
    "batotámo": "batotar",
    "batotámos": "batotar",
    "batotáramo": "batotar",
    "batotáramos": "batotar",
    "batotáreis": "batotar",
    "batotásseis": "batotar",
    "batotássemos": "batotar",
    "batotávamo": "batotar",
    "batotávamos": "batotar",
    "batotáveis": "batotar",
    "batracófaga": "batracófago",
    "batracófagas": "batracófago",
    "batracófagos": "batracófago",
    "batracóides": "batracóide",
    "batraquídea": "batraquídeo",
    "batraquídeas": "batraquídeo",
    "batraquídeos": "batraquídeo",
    "batráquia": "batráquio",
    "batráquias": "batráquio",
    "batráquidas": "batráquida",
    "batráquios": "batráquio",
    "batuca": "batucar",
    "batucada": "batucar",
    "batucadas": "batucar",
    "batucado": "batucar",
    "batucadors": "batucador",
    "batucados": "batucar",
    "batucais": "batucar",
    "batucam": "batucar",
    "batucamo": "batucar",
    "batucamos": "batucar",
    "batucando": "batucar",
    "batucara": "batucar",
    "batucaram": "batucar",
    "batucaras": "batucar",
    "batucardes": "batucar",
    "batucarei": "batucar",
    "batucareis": "batucar",
    "batucarem": "batucar",
    "batucaremos": "batucar",
    "batucares": "batucar",
    "batucaria": "batucar",
    "batucariam": "batucar",
    "batucarias": "batucar",
    "batucarmo": "batucar",
    "batucarmos": "batucar",
    "batucará": "batucar",
    "batucarás": "batucar",
    "batucarão": "batucar",
    "batucaríamos": "batucar",
    "batucaríeis": "batucar",
    "batucas": "batucar",
    "batucasse": "batucar",
    "batucassem": "batucar",
    "batucasses": "batucar",
    "batucaste": "batucar",
    "batucastes": "batucar",
    "batucava": "batucar",
    "batucavam": "batucar",
    "batucavas": "batucar",
    "batuco": "batucar",
    "batucou": "batucar",
    "batucámo": "batucar",
    "batucámos": "batucar",
    "batucáramo": "batucar",
    "batucáramos": "batucar",
    "batucáreis": "batucar",
    "batucásseis": "batucar",
    "batucássemos": "batucar",
    "batucávamo": "batucar",
    "batucávamos": "batucar",
    "batucáveis": "batucar",
    "batudas": "batuda",
    "batuque": "batucar",
    "batuquei": "batucar",
    "batuqueira": "batuqueiro",
    "batuqueiras": "batuqueiro",
    "batuqueiros": "batuqueiro",
    "batuqueis": "batucar",
    "batuquem": "batucar",
    "batuquemos": "batucar",
    "batuques": "batuque",
    "batuquiras": "batuquira",
    "batutas": "batuta",
    "batávia": "batávio",
    "batávias": "batávio",
    "batávica": "batávico",
    "batávicas": "batávico",
    "batávicos": "batávico",
    "batávios": "batávio",
    "batéis": "batel",
    "batê": "bater",
    "batêramo": "bater",
    "batêramos": "bater",
    "batêrei": "bater",
    "batêreis": "bater",
    "batêsseis": "bater",
    "batêssemos": "bater",
    "batíamo": "bater",
    "batíamos": "bater",
    "batíei": "bater",
    "batíeis": "bater",
    "batílitos": "batílito",
    "batímetros": "batímetro",
    "batíveis": "batível",
    "batógrafos": "batógrafo",
    "batólitos": "batólito",
    "batómetros": "batómetro",
    "bauchites": "bauchite",
    "bauleiros": "bauleiro",
    "baunilhas": "baunilha",
    "baunilhazinha": "baunilha",
    "baunilhazinhas": "baunilha",
    "baunilhazita": "baunilha",
    "baunilhazitas": "baunilha",
    "baus": "bau",
    "bauxitas": "bauxita",
    "bauxites": "bauxite",
    "bauzinho": "baú",
    "bauzinhos": "baú",
    "bauzito": "baú",
    "bauzitos": "baú",
    "bazanadas": "bazanada",
    "bazares": "bazar",
    "bazofia": "bazofiar",
    "bazofiada": "bazofiar",
    "bazofiadas": "bazofiar",
    "bazofiadeira": "bazofiador",
    "bazofiadeiras": "bazofiador",
    "bazofiado": "bazofiar",
    "bazofiadora": "bazofiador",
    "bazofiadoras": "bazofiador",
    "bazofiadores": "bazofiador",
    "bazofiados": "bazofiar",
    "bazofiai": "bazofiar",
    "bazofiais": "bazofiar",
    "bazofiam": "bazofiar",
    "bazofiamentos": "bazofiamento",
    "bazofiamo": "bazofiar",
    "bazofiamos": "bazofiar",
    "bazofiando": "bazofiar",
    "bazofiara": "bazofiar",
    "bazofiaram": "bazofiar",
    "bazofiaras": "bazofiar",
    "bazofiardes": "bazofiar",
    "bazofiarei": "bazofiar",
    "bazofiareis": "bazofiar",
    "bazofiarem": "bazofiar",
    "bazofiaremos": "bazofiar",
    "bazofiares": "bazofiar",
    "bazofiaria": "bazofiar",
    "bazofiariam": "bazofiar",
    "bazofiarias": "bazofiar",
    "bazofiarmo": "bazofiar",
    "bazofiarmos": "bazofiar",
    "bazofiará": "bazofiar",
    "bazofiarás": "bazofiar",
    "bazofiarão": "bazofiar",
    "bazofiaríamos": "bazofiar",
    "bazofiaríeis": "bazofiar",
    "bazofias": "bazofiar",
    "bazofiasse": "bazofiar",
    "bazofiassem": "bazofiar",
    "bazofiasses": "bazofiar",
    "bazofiaste": "bazofiar",
    "bazofiastes": "bazofiar",
    "bazofiava": "bazofiar",
    "bazofiavam": "bazofiar",
    "bazofiavas": "bazofiar",
    "bazofie": "bazofiar",
    "bazofiei": "bazofiar",
    "bazofieis": "bazofiar",
    "bazofiem": "bazofiar",
    "bazofiemo": "bazofiar",
    "bazofiemos": "bazofiar",
    "bazofies": "bazofiar",
    "bazofio": "bazofiar",
    "bazofiou": "bazofiar",
    "bazofiámo": "bazofiar",
    "bazofiámos": "bazofiar",
    "bazofiáramo": "bazofiar",
    "bazofiáramos": "bazofiar",
    "bazofiáreis": "bazofiar",
    "bazofiásseis": "bazofiar",
    "bazofiássemos": "bazofiar",
    "bazofiávamo": "bazofiar",
    "bazofiávamos": "bazofiar",
    "bazofiáveis": "bazofiar",
    "bazucas": "bazuca",
    "bazulaques": "bazulaque",
    "bazófia": "bazófio",
    "bazófias": "bazófio",
    "bazófios": "bazófio",
    "baça": "baço",
    "baças": "baço",
    "baçorinas": "baçorina",
    "baços": "baço",
    "baías": "baía",
    "baús": "baú",
    "bb": "b",
    "bdélios": "bdélio",
    "beata": "beato",
    "beatarias": "beataria",
    "beatas": "beato",
    "beateira": "beateiro",
    "beateiras": "beateiro",
    "beateiros": "beateiro",
    "beatices": "beatice",
    "beatifica": "beatificar",
    "beatificada": "beatificar",
    "beatificadas": "beatificar",
    "beatificado": "beatificar",
    "beatificadora": "beatificador",
    "beatificadoras": "beatificador",
    "beatificadores": "beatificador",
    "beatificados": "beatificar",
    "beatificai": "beatificar",
    "beatificais": "beatificar",
    "beatificam": "beatificar",
    "beatificamo": "beatificar",
    "beatificamos": "beatificar",
    "beatificando": "beatificar",
    "beatificantes": "beatificante",
    "beatificara": "beatificar",
    "beatificaram": "beatificar",
    "beatificaras": "beatificar",
    "beatificarde": "beatificar",
    "beatificardes": "beatificar",
    "beatificare": "beatificar",
    "beatificarei": "beatificar",
    "beatificareis": "beatificar",
    "beatificarem": "beatificar",
    "beatificaremos": "beatificar",
    "beatificares": "beatificar",
    "beatificaria": "beatificar",
    "beatificariam": "beatificar",
    "beatificarias": "beatificar",
    "beatificarmo": "beatificar",
    "beatificarmos": "beatificar",
    "beatificará": "beatificar",
    "beatificarás": "beatificar",
    "beatificarão": "beatificar",
    "beatificaríamos": "beatificar",
    "beatificaríeis": "beatificar",
    "beatificas": "beatificar",
    "beatificasse": "beatificar",
    "beatificassem": "beatificar",
    "beatificasses": "beatificar",
    "beatificaste": "beatificar",
    "beatificastes": "beatificar",
    "beatificatória": "beatificatório",
    "beatificatórias": "beatificatório",
    "beatificatórios": "beatificatório",
    "beatificava": "beatificar",
    "beatificavam": "beatificar",
    "beatificavas": "beatificar",
    "beatificações": "beatificação",
    "beatifico": "beatificar",
    "beatificou": "beatificar",
    "beatificá": "beatificar",
    "beatificámo": "beatificar",
    "beatificámos": "beatificar",
    "beatificáramo": "beatificar",
    "beatificáramos": "beatificar",
    "beatificárei": "beatificar",
    "beatificáreis": "beatificar",
    "beatificásseis": "beatificar",
    "beatificássemos": "beatificar",
    "beatificávamo": "beatificar",
    "beatificávamos": "beatificar",
    "beatificávei": "beatificar",
    "beatificáveis": "beatificar",
    "beatifique": "beatificar",
    "beatifiquei": "beatificar",
    "beatifiqueis": "beatificar",
    "beatifiquem": "beatificar",
    "beatifiquemo": "beatificar",
    "beatifiquemos": "beatificar",
    "beatifiques": "beatificar",
    "beatilhas": "beatilha",
    "beatismos": "beatismo",
    "beatitudes": "beatitude",
    "beatona": "beatão",
    "beatonas": "beatão",
    "beatorra": "beatorro",
    "beatorras": "beatorro",
    "beatorros": "beatorro",
    "beatos": "beato",
    "beatérios": "beatério",
    "beatífica": "beatífico",
    "beatíficas": "beatífico",
    "beatíficos": "beatífico",
    "beatões": "beatão",
    "beba": "beber",
    "bebais": "beber",
    "bebam": "beber",
    "bebamo": "beber",
    "bebamos": "beber",
    "bebas": "beber",
    "bebe": "beber",
    "bebedeiras": "bebedeira",
    "bebedices": "bebedice",
    "bebedoiros": "bebedoiro",
    "bebedora": "bebedor",
    "bebedoras": "bebedor",
    "bebedores": "bebedor",
    "bebedouros": "bebedouro",
    "bebeduras": "bebedura",
    "bebei": "beber",
    "bebeis": "beber",
    "bebem": "beber",
    "bebemo": "beber",
    "bebemos": "beber",
    "bebendo": "beber",
    "bebera": "beberar",
    "beberada": "beberar",
    "beberadas": "beberar",
    "beberado": "beberar",
    "beberados": "beberar",
    "beberagens": "beberagem",
    "beberai": "beberar",
    "beberais": "beberar",
    "beberam": "beberar",
    "beberamo": "beberar",
    "beberamos": "beberar",
    "beberando": "beberar",
    "beberara": "beberar",
    "beberaram": "beberar",
    "beberaras": "beberar",
    "beberarde": "beberar",
    "beberardes": "beberar",
    "beberare": "beberar",
    "beberarei": "beberar",
    "beberareis": "beberar",
    "beberarem": "beberar",
    "beberaremos": "beberar",
    "beberares": "beberar",
    "beberaria": "beberar",
    "beberariam": "beberar",
    "beberarias": "beberar",
    "beberarmo": "beberar",
    "beberarmos": "beberar",
    "beberará": "beberar",
    "beberarás": "beberar",
    "beberarão": "beberar",
    "beberaríamos": "beberar",
    "beberaríeis": "beberar",
    "beberas": "beberar",
    "beberasse": "beberar",
    "beberassem": "beberar",
    "beberasses": "beberar",
    "beberaste": "beberar",
    "beberastes": "beberar",
    "beberava": "beberar",
    "beberavam": "beberar",
    "beberavas": "beberar",
    "beberde": "beber",
    "beberdes": "beber",
    "bebere": "beberar",
    "beberei": "beberar",
    "bebereiras": "bebereira",
    "bebereis": "beberar",
    "beberem": "beberar",
    "beberemo": "beberar",
    "beberemos": "beberar",
    "beberes": "beberar",
    "beberetes": "beberete",
    "beberia": "beber",
    "beberiam": "beber",
    "beberias": "beber",
    "beberica": "bebericar",
    "bebericada": "bebericar",
    "bebericadas": "bebericar",
    "bebericado": "bebericar",
    "bebericados": "bebericar",
    "bebericai": "bebericar",
    "bebericais": "bebericar",
    "bebericam": "bebericar",
    "bebericamo": "bebericar",
    "bebericamos": "bebericar",
    "bebericando": "bebericar",
    "bebericara": "bebericar",
    "bebericaram": "bebericar",
    "bebericaras": "bebericar",
    "bebericarde": "bebericar",
    "bebericardes": "bebericar",
    "bebericare": "bebericar",
    "bebericarei": "bebericar",
    "bebericareis": "bebericar",
    "bebericarem": "bebericar",
    "bebericaremos": "bebericar",
    "bebericares": "bebericar",
    "bebericaria": "bebericar",
    "bebericariam": "bebericar",
    "bebericarias": "bebericar",
    "bebericarmo": "bebericar",
    "bebericarmos": "bebericar",
    "bebericará": "bebericar",
    "bebericarás": "bebericar",
    "bebericarão": "bebericar",
    "bebericaríamos": "bebericar",
    "bebericaríeis": "bebericar",
    "bebericas": "bebericar",
    "bebericasse": "bebericar",
    "bebericassem": "bebericar",
    "bebericasses": "bebericar",
    "bebericaste": "bebericar",
    "bebericastes": "bebericar",
    "bebericava": "bebericar",
    "bebericavam": "bebericar",
    "bebericavas": "bebericar",
    "beberico": "bebericar",
    "bebericou": "bebericar",
    "bebericá": "bebericar",
    "bebericámo": "bebericar",
    "bebericámos": "bebericar",
    "bebericáramo": "bebericar",
    "bebericáramos": "bebericar",
    "bebericárei": "bebericar",
    "bebericáreis": "bebericar",
    "bebericásseis": "bebericar",
    "bebericássemos": "bebericar",
    "bebericávamo": "bebericar",
    "bebericávamos": "bebericar",
    "bebericávei": "bebericar",
    "bebericáveis": "bebericar",
    "beberique": "bebericar",
    "beberiquei": "bebericar",
    "beberiqueis": "bebericar",
    "beberiquem": "bebericar",
    "beberiquemo": "bebericar",
    "beberiquemos": "bebericar",
    "beberiques": "bebericar",
    "bebermo": "beber",
    "bebermos": "beber",
    "bebero": "beberar",
    "beberou": "beberar",
    "beberrazes": "beberraz",
    "beberrica": "beberricar",
    "beberricada": "beberricar",
    "beberricadas": "beberricar",
    "beberricado": "beberricar",
    "beberricadora": "beberricador",
    "beberricadoras": "beberricador",
    "beberricadores": "beberricador",
    "beberricados": "beberricar",
    "beberricai": "beberricar",
    "beberricais": "beberricar",
    "beberricam": "beberricar",
    "beberricamo": "beberricar",
    "beberricamos": "beberricar",
    "beberricando": "beberricar",
    "beberricara": "beberricar",
    "beberricaram": "beberricar",
    "beberricaras": "beberricar",
    "beberricarde": "beberricar",
    "beberricardes": "beberricar",
    "beberricare": "beberricar",
    "beberricarei": "beberricar",
    "beberricareis": "beberricar",
    "beberricarem": "beberricar",
    "beberricaremos": "beberricar",
    "beberricares": "beberricar",
    "beberricaria": "beberricar",
    "beberricariam": "beberricar",
    "beberricarias": "beberricar",
    "beberricarmo": "beberricar",
    "beberricarmos": "beberricar",
    "beberricará": "beberricar",
    "beberricarás": "beberricar",
    "beberricarão": "beberricar",
    "beberricaríamos": "beberricar",
    "beberricaríeis": "beberricar",
    "beberricas": "beberricar",
    "beberricasse": "beberricar",
    "beberricassem": "beberricar",
    "beberricasses": "beberricar",
    "beberricaste": "beberricar",
    "beberricastes": "beberricar",
    "beberricava": "beberricar",
    "beberricavam": "beberricar",
    "beberricavas": "beberricar",
    "beberricações": "beberricação",
    "beberrico": "beberricar",
    "beberricou": "beberricar",
    "beberricá": "beberricar",
    "beberricámo": "beberricar",
    "beberricámos": "beberricar",
    "beberricáramo": "beberricar",
    "beberricáramos": "beberricar",
    "beberricárei": "beberricar",
    "beberricáreis": "beberricar",
    "beberricásseis": "beberricar",
    "beberricássemos": "beberricar",
    "beberricávamo": "beberricar",
    "beberricávamos": "beberricar",
    "beberricávei": "beberricar",
    "beberricáveis": "beberricar",
    "beberrique": "beberricar",
    "beberriquei": "beberricar",
    "beberriqueis": "beberricar",
    "beberriquem": "beberricar",
    "beberriquemo": "beberricar",
    "beberriquemos": "beberricar",
    "beberriques": "beberricar",
    "beberrona": "beberrão",
    "beberronas": "beberrão",
    "beberronias": "beberronia",
    "beberrões": "beberrão",
    "beberá": "beberar",
    "beberámo": "beberar",
    "beberámos": "beberar",
    "beberáramo": "beberar",
    "beberáramos": "beberar",
    "beberárei": "beberar",
    "beberáreis": "beberar",
    "beberás": "beber",
    "beberásseis": "beberar",
    "beberássemos": "beberar",
    "beberávamo": "beberar",
    "beberávamos": "beberar",
    "beberávei": "beberar",
    "beberáveis": "beberar",
    "beberão": "beber",
    "beberíamos": "beber",
    "beberíeis": "beber",
    "bebes": "beber",
    "bebesse": "beber",
    "bebessem": "beber",
    "bebesses": "beber",
    "bebeste": "beber",
    "bebestes": "beber",
    "bebeu": "beber",
    "bebezinha": "bebé",
    "bebezinhas": "bebé",
    "bebezinho": "bebé",
    "bebezinhos": "bebé",
    "bebezita": "bebé",
    "bebezitas": "bebé",
    "bebezito": "bebé",
    "bebezitos": "bebé",
    "bebi": "beber",
    "bebia": "beber",
    "bebiam": "beber",
    "bebias": "beber",
    "bebida": "bebido",
    "bebidas": "bebido",
    "bebidinha": "bebida",
    "bebidinhas": "bebida",
    "bebidita": "bebida",
    "bebiditas": "bebida",
    "bebido": "beber",
    "bebidos": "bebido",
    "bebo": "beber",
    "bebés": "bebé",
    "bebê": "beber",
    "bebêramo": "beber",
    "bebêramos": "beber",
    "bebêrei": "beber",
    "bebêreis": "beber",
    "bebêsseis": "beber",
    "bebêssemos": "beber",
    "bebíamo": "beber",
    "bebíamos": "beber",
    "bebíei": "beber",
    "bebíeis": "beber",
    "bebíveis": "bebível",
    "becabungas": "becabunga",
    "becas": "beca",
    "becazinha": "beca",
    "becazinhas": "beca",
    "becazita": "beca",
    "becazitas": "beca",
    "bechaméis": "bechamel",
    "becos": "beco",
    "becozinho": "beco",
    "becozinhos": "beco",
    "becozito": "beco",
    "becozitos": "beco",
    "becuadros": "becuadro",
    "becuinhas": "becuinha",
    "bedames": "bedame",
    "bedegares": "bedegar",
    "bedelha": "bedelhar",
    "bedelhada": "bedelhar",
    "bedelhadas": "bedelhar",
    "bedelhado": "bedelhar",
    "bedelhados": "bedelhar",
    "bedelhai": "bedelhar",
    "bedelhais": "bedelhar",
    "bedelham": "bedelhar",
    "bedelhamo": "bedelhar",
    "bedelhamos": "bedelhar",
    "bedelhando": "bedelhar",
    "bedelhara": "bedelhar",
    "bedelharam": "bedelhar",
    "bedelharas": "bedelhar",
    "bedelhardes": "bedelhar",
    "bedelharei": "bedelhar",
    "bedelhareis": "bedelhar",
    "bedelharem": "bedelhar",
    "bedelharemos": "bedelhar",
    "bedelhares": "bedelhar",
    "bedelharia": "bedelhar",
    "bedelhariam": "bedelhar",
    "bedelharias": "bedelhar",
    "bedelharmo": "bedelhar",
    "bedelharmos": "bedelhar",
    "bedelhará": "bedelhar",
    "bedelharás": "bedelhar",
    "bedelharão": "bedelhar",
    "bedelharíamos": "bedelhar",
    "bedelharíeis": "bedelhar",
    "bedelhas": "bedelhar",
    "bedelhasse": "bedelhar",
    "bedelhassem": "bedelhar",
    "bedelhasses": "bedelhar",
    "bedelhaste": "bedelhar",
    "bedelhastes": "bedelhar",
    "bedelhava": "bedelhar",
    "bedelhavam": "bedelhar",
    "bedelhavas": "bedelhar",
    "bedelhe": "bedelhar",
    "bedelhei": "bedelhar",
    "bedelheira": "bedelheiro",
    "bedelheiras": "bedelheiro",
    "bedelheiros": "bedelheiro",
    "bedelheis": "bedelhar",
    "bedelhem": "bedelhar",
    "bedelhemo": "bedelhar",
    "bedelhemos": "bedelhar",
    "bedelhes": "bedelhar",
    "bedelho": "bedelhar",
    "bedelhos": "bedelho",
    "bedelhou": "bedelhar",
    "bedelhámo": "bedelhar",
    "bedelhámos": "bedelhar",
    "bedelháramo": "bedelhar",
    "bedelháramos": "bedelhar",
    "bedelháreis": "bedelhar",
    "bedelhásseis": "bedelhar",
    "bedelhássemos": "bedelhar",
    "bedelhávamo": "bedelhar",
    "bedelhávamos": "bedelhar",
    "bedelháveis": "bedelhar",
    "bedelias": "bedelia",
    "bedetecas": "bedeteca",
    "bedros": "bedro",
    "beduins": "beduim",
    "beduns": "bedum",
    "beduína": "beduíno",
    "beduínas": "beduíno",
    "beduínos": "beduíno",
    "bedéis": "bedel",
    "bedéns": "bedém",
    "beerites": "beerite",
    "beetovénica": "beetovénico",
    "beetovénicas": "beetovénico",
    "beetovénicos": "beetovénico",
    "beetrias": "beetria",
    "beges": "bege",
    "begezinho": "bege",
    "begezinhos": "bege",
    "begezito": "bege",
    "begezitos": "bege",
    "begoniácea": "begoniáceo",
    "begoniáceas": "begoniáceo",
    "begoniáceos": "begoniáceo",
    "beguinarias": "beguinaria",
    "beguína": "beguíno",
    "beguínas": "beguíno",
    "beguínos": "beguíno",
    "begónias": "begónia",
    "behaviorismos": "behaviorismo",
    "behavioristas": "behaviorista",
    "beicinha": "beiça",
    "beicinhas": "beiça",
    "beicinho": "beiço",
    "beicinhos": "beiço",
    "beicita": "beiça",
    "beicitas": "beiça",
    "beicito": "beiço",
    "beicitos": "beiço",
    "beija": "beijar",
    "beijada": "beijar",
    "beijadas": "beijar",
    "beijadelas": "beijadela",
    "beijado": "beijar",
    "beijadora": "beijador",
    "beijadoras": "beijador",
    "beijadores": "beijador",
    "beijados": "beijar",
    "beijai": "beijar",
    "beijais": "beijar",
    "beijam": "beijar",
    "beijamo": "beijar",
    "beijamos": "beijar",
    "beijando": "beijar",
    "beijara": "beijar",
    "beijaram": "beijar",
    "beijaras": "beijar",
    "beijarde": "beijar",
    "beijardes": "beijar",
    "beijare": "beijar",
    "beijarei": "beijar",
    "beijareis": "beijar",
    "beijarem": "beijar",
    "beijaremos": "beijar",
    "beijares": "beijar",
    "beijaria": "beijar",
    "beijariam": "beijar",
    "beijarias": "beijar",
    "beijarmo": "beijar",
    "beijarmos": "beijar",
    "beijará": "beijar",
    "beijarás": "beijar",
    "beijarão": "beijar",
    "beijaríamos": "beijar",
    "beijaríeis": "beijar",
    "beijas": "beijar",
    "beijasse": "beijar",
    "beijassem": "beijar",
    "beijasses": "beijar",
    "beijaste": "beijar",
    "beijastes": "beijar",
    "beijava": "beijar",
    "beijavam": "beijar",
    "beijavas": "beijar",
    "beije": "beijar",
    "beijei": "beijar",
    "beijeis": "beijar",
    "beijem": "beijar",
    "beijemo": "beijar",
    "beijemos": "beijar",
    "beijes": "beijar",
    "beijinho": "beijo",
    "beijinhos": "beijo",
    "beijito": "beijo",
    "beijitos": "beijo",
    "beijo": "beijar",
    "beijoca": "beijocar",
    "beijocada": "beijocar",
    "beijocadas": "beijocar",
    "beijocadelas": "beijocadela",
    "beijocado": "beijocar",
    "beijocadora": "beijocador",
    "beijocadoras": "beijocador",
    "beijocadores": "beijocador",
    "beijocados": "beijocar",
    "beijocai": "beijocar",
    "beijocais": "beijocar",
    "beijocam": "beijocar",
    "beijocamo": "beijocar",
    "beijocamos": "beijocar",
    "beijocando": "beijocar",
    "beijocara": "beijocar",
    "beijocaram": "beijocar",
    "beijocaras": "beijocar",
    "beijocarde": "beijocar",
    "beijocardes": "beijocar",
    "beijocare": "beijocar",
    "beijocarei": "beijocar",
    "beijocareis": "beijocar",
    "beijocarem": "beijocar",
    "beijocaremos": "beijocar",
    "beijocares": "beijocar",
    "beijocaria": "beijocar",
    "beijocariam": "beijocar",
    "beijocarias": "beijocar",
    "beijocarmo": "beijocar",
    "beijocarmos": "beijocar",
    "beijocará": "beijocar",
    "beijocarás": "beijocar",
    "beijocarão": "beijocar",
    "beijocaríamos": "beijocar",
    "beijocaríeis": "beijocar",
    "beijocas": "beijocar",
    "beijocasse": "beijocar",
    "beijocassem": "beijocar",
    "beijocasses": "beijocar",
    "beijocaste": "beijocar",
    "beijocastes": "beijocar",
    "beijocava": "beijocar",
    "beijocavam": "beijocar",
    "beijocavas": "beijocar",
    "beijocazinha": "beijoca",
    "beijocazinhas": "beijoca",
    "beijocazita": "beijoca",
    "beijocazitas": "beijoca",
    "beijoco": "beijocar",
    "beijocou": "beijocar",
    "beijocá": "beijocar",
    "beijocámo": "beijocar",
    "beijocámos": "beijocar",
    "beijocáramo": "beijocar",
    "beijocáramos": "beijocar",
    "beijocárei": "beijocar",
    "beijocáreis": "beijocar",
    "beijocásseis": "beijocar",
    "beijocássemos": "beijocar",
    "beijocávamo": "beijocar",
    "beijocávamos": "beijocar",
    "beijocávei": "beijocar",
    "beijocáveis": "beijocar",
    "beijoque": "beijocar",
    "beijoquei": "beijocar",
    "beijoqueira": "beijoqueiro",
    "beijoqueiras": "beijoqueiro",
    "beijoqueiros": "beijoqueiro",
    "beijoqueis": "beijocar",
    "beijoquem": "beijocar",
    "beijoquemo": "beijocar",
    "beijoquemos": "beijocar",
    "beijoques": "beijocar",
    "beijoquinha": "beijoca",
    "beijoquinhas": "beijoca",
    "beijoquita": "beijoca",
    "beijoquitas": "beijoca",
    "beijos": "beijo",
    "beijou": "beijar",
    "beijoíns": "beijoím",
    "beijus": "beiju",
    "beijá": "beijar",
    "beijámo": "beijar",
    "beijámos": "beijar",
    "beijáramo": "beijar",
    "beijáramos": "beijar",
    "beijárei": "beijar",
    "beijáreis": "beijar",
    "beijásseis": "beijar",
    "beijássemos": "beijar",
    "beijávamo": "beijar",
    "beijávamos": "beijar",
    "beijávei": "beijar",
    "beijáveis": "beijar",
    "beilhiques": "beilhique",
    "beilhós": "beilhó",
    "beira": "beirar",
    "beirada": "beirar",
    "beiradas": "beirar",
    "beirado": "beirar",
    "beirados": "beirar",
    "beirai": "beirar",
    "beirais": "beirar",
    "beiram": "beirar",
    "beirames": "beirame",
    "beiramo": "beirar",
    "beiramos": "beirar",
    "beirando": "beirar",
    "beirara": "beirar",
    "beiraram": "beirar",
    "beiraras": "beirar",
    "beirarde": "beirar",
    "beirardes": "beirar",
    "beirare": "beirar",
    "beirarei": "beirar",
    "beirareis": "beirar",
    "beirarem": "beirar",
    "beiraremos": "beirar",
    "beirares": "beirar",
    "beiraria": "beirar",
    "beirariam": "beirar",
    "beirarias": "beirar",
    "beirarmo": "beirar",
    "beirarmos": "beirar",
    "beirará": "beirar",
    "beirarás": "beirar",
    "beirarão": "beirar",
    "beiraríamos": "beirar",
    "beiraríeis": "beirar",
    "beiras": "beirar",
    "beirasse": "beirar",
    "beirassem": "beirar",
    "beirasses": "beirar",
    "beiraste": "beirar",
    "beirastes": "beirar",
    "beirava": "beirar",
    "beiravam": "beirar",
    "beiravas": "beirar",
    "beire": "beirar",
    "beirei": "beirar",
    "beireis": "beirar",
    "beirem": "beirar",
    "beiremo": "beirar",
    "beiremos": "beirar",
    "beirenses": "beirense",
    "beires": "beirar",
    "beirinha": "beira",
    "beirinhas": "beira",
    "beirita": "beira",
    "beiritas": "beira",
    "beiro": "beirar",
    "beiroa": "beirão",
    "beiroas": "beirão",
    "beirou": "beirar",
    "beirá": "beirar",
    "beirámo": "beirar",
    "beirámos": "beirar",
    "beiráramo": "beirar",
    "beiráramos": "beirar",
    "beirárei": "beirar",
    "beiráreis": "beirar",
    "beirásseis": "beirar",
    "beirássemos": "beirar",
    "beirávamo": "beirar",
    "beirávamos": "beirar",
    "beirávei": "beirar",
    "beiráveis": "beirar",
    "beirã": "beirão",
    "beirãs": "beirão",
    "beirões": "beirão",
    "beis": "bei",
    "beisebóis": "beisebol",
    "beiçadas": "beiçada",
    "beiçanas": "beiçana",
    "beiças": "beiça",
    "beiçolas": "beiçola",
    "beiçorras": "beiçorra",
    "beiços": "beiço",
    "beiçuda": "beiçudo",
    "beiçudas": "beiçudo",
    "beiçudos": "beiçudo",
    "bejenses": "bejense",
    "bejoegas": "bejoega",
    "bejogas": "bejoga",
    "bela": "belo",
    "beladonada": "beladonado",
    "beladonadas": "beladonado",
    "beladonados": "beladonado",
    "beladonas": "beladona",
    "beladónea": "beladóneo",
    "beladóneas": "beladóneo",
    "beladóneos": "beladóneo",
    "belas": "belo",
    "belatrizes": "belatriz",
    "belbutinas": "belbutina",
    "belcantos": "belcanto",
    "beldades": "beldade",
    "beldroegas": "beldroega",
    "beldros": "beldro",
    "beleguins": "beleguim",
    "belemitas": "belemita",
    "belenenses": "belenense",
    "beletristas": "beletrista",
    "beletrísticas": "beletrística",
    "belezas": "beleza",
    "belezinha": "beleza",
    "belezinhas": "beleza",
    "belezita": "beleza",
    "belezitas": "beleza",
    "belfa": "belfo",
    "belfas": "belfo",
    "belfos": "belfo",
    "belfuda": "belfudo",
    "belfudas": "belfudo",
    "belfudos": "belfudo",
    "belgas": "belga",
    "belgatas": "belgata",
    "belhos": "belho",
    "belhós": "belhó",
    "beliches": "beliche",
    "belicismos": "belicismo",
    "belicistas": "belicista",
    "belicosa": "belicoso",
    "belicosas": "belicoso",
    "belicosidades": "belicosidade",
    "belicosos": "belicoso",
    "belidas": "belida",
    "beligerantes": "beligerante",
    "beligerâncias": "beligerância",
    "belindres": "belindre",
    "belindros": "belindro",
    "belinogramas": "belinograma",
    "belinográfica": "belinográfico",
    "belinográficas": "belinográfico",
    "belinográficos": "belinográfico",
    "belinógrafos": "belinógrafo",
    "belipotentes": "belipotente",
    "belipotências": "belipotência",
    "belisca": "beliscar",
    "beliscada": "beliscar",
    "beliscadas": "beliscar",
    "beliscadelas": "beliscadela",
    "beliscado": "beliscar",
    "beliscados": "beliscar",
    "beliscaduras": "beliscadura",
    "beliscai": "beliscar",
    "beliscais": "beliscar",
    "beliscam": "beliscar",
    "beliscamo": "beliscar",
    "beliscamos": "beliscar",
    "beliscando": "beliscar",
    "beliscara": "beliscar",
    "beliscaram": "beliscar",
    "beliscaras": "beliscar",
    "beliscarde": "beliscar",
    "beliscardes": "beliscar",
    "beliscare": "beliscar",
    "beliscarei": "beliscar",
    "beliscareis": "beliscar",
    "beliscarem": "beliscar",
    "beliscaremos": "beliscar",
    "beliscares": "beliscar",
    "beliscaria": "beliscar",
    "beliscariam": "beliscar",
    "beliscarias": "beliscar",
    "beliscarmo": "beliscar",
    "beliscarmos": "beliscar",
    "beliscará": "beliscar",
    "beliscarás": "beliscar",
    "beliscarão": "beliscar",
    "beliscaríamos": "beliscar",
    "beliscaríeis": "beliscar",
    "beliscas": "beliscar",
    "beliscasse": "beliscar",
    "beliscassem": "beliscar",
    "beliscasses": "beliscar",
    "beliscaste": "beliscar",
    "beliscastes": "beliscar",
    "beliscava": "beliscar",
    "beliscavam": "beliscar",
    "beliscavas": "beliscar",
    "belisco": "beliscar",
    "beliscos": "belisco",
    "beliscou": "beliscar",
    "beliscozinho": "belisco",
    "beliscozinhos": "belisco",
    "beliscozito": "belisco",
    "beliscozitos": "belisco",
    "beliscá": "beliscar",
    "beliscámo": "beliscar",
    "beliscámos": "beliscar",
    "beliscáramo": "beliscar",
    "beliscáramos": "beliscar",
    "beliscárei": "beliscar",
    "beliscáreis": "beliscar",
    "beliscásseis": "beliscar",
    "beliscássemos": "beliscar",
    "beliscávamo": "beliscar",
    "beliscávamos": "beliscar",
    "beliscávei": "beliscar",
    "beliscáveis": "beliscar",
    "beliscões": "beliscão",
    "belisque": "beliscar",
    "belisquei": "beliscar",
    "belisqueis": "beliscar",
    "belisquem": "beliscar",
    "belisquemo": "beliscar",
    "belisquemos": "beliscar",
    "belisques": "beliscar",
    "belisária": "belisário",
    "belisárias": "belisário",
    "belisários": "belisário",
    "belomancias": "belomancia",
    "belomantes": "belomante",
    "belomântica": "belomântico",
    "belomânticas": "belomântico",
    "belomânticos": "belomântico",
    "belonas": "belona",
    "belonofobias": "belonofobia",
    "belos": "belo",
    "beloárias": "beloária",
    "beloários": "beloário",
    "bels": "bel",
    "beltrana": "beltrano",
    "beltranas": "beltrano",
    "beltranos": "beltrano",
    "beltrona": "beltrão",
    "beltronas": "beltrão",
    "beltrões": "beltrão",
    "belucas": "beluca",
    "belugas": "beluga",
    "beluína": "beluíno",
    "beluínas": "beluíno",
    "beluínos": "beluíno",
    "belvederes": "belvedere",
    "belverdes": "belverde",
    "belveres": "belver",
    "belzebus": "belzebu",
    "belzebútica": "belzebútico",
    "belzebúticas": "belzebútico",
    "belzebúticos": "belzebútico",
    "beléns": "belém",
    "belígera": "belígero",
    "belígeras": "belígero",
    "belígeros": "belígero",
    "belíssima": "belo",
    "belíssimas": "belo",
    "belíssimo": "belo",
    "belíssimos": "belo",
    "belíssona": "belíssono",
    "belíssonas": "belíssono",
    "belíssonos": "belíssono",
    "bemola": "bemolar",
    "bemolada": "bemolar",
    "bemoladas": "bemolar",
    "bemolado": "bemolar",
    "bemolados": "bemolar",
    "bemolai": "bemolar",
    "bemolais": "bemolar",
    "bemolam": "bemolar",
    "bemolamo": "bemolar",
    "bemolamos": "bemolar",
    "bemolando": "bemolar",
    "bemolara": "bemolar",
    "bemolaram": "bemolar",
    "bemolaras": "bemolar",
    "bemolarde": "bemolar",
    "bemolardes": "bemolar",
    "bemolare": "bemolar",
    "bemolarei": "bemolar",
    "bemolareis": "bemolar",
    "bemolarem": "bemolar",
    "bemolaremos": "bemolar",
    "bemolares": "bemolar",
    "bemolaria": "bemolar",
    "bemolariam": "bemolar",
    "bemolarias": "bemolar",
    "bemolarmo": "bemolar",
    "bemolarmos": "bemolar",
    "bemolará": "bemolar",
    "bemolarás": "bemolar",
    "bemolarão": "bemolar",
    "bemolaríamos": "bemolar",
    "bemolaríeis": "bemolar",
    "bemolas": "bemolar",
    "bemolasse": "bemolar",
    "bemolassem": "bemolar",
    "bemolasses": "bemolar",
    "bemolaste": "bemolar",
    "bemolastes": "bemolar",
    "bemolava": "bemolar",
    "bemolavam": "bemolar",
    "bemolavas": "bemolar",
    "bemole": "bemolar",
    "bemolei": "bemolar",
    "bemoleis": "bemolar",
    "bemolem": "bemolar",
    "bemolemo": "bemolar",
    "bemolemos": "bemolar",
    "bemoles": "bemolar",
    "bemoliza": "bemolizar",
    "bemolizada": "bemolizar",
    "bemolizadas": "bemolizar",
    "bemolizado": "bemolizar",
    "bemolizados": "bemolizar",
    "bemolizai": "bemolizar",
    "bemolizais": "bemolizar",
    "bemolizam": "bemolizar",
    "bemolizamo": "bemolizar",
    "bemolizamos": "bemolizar",
    "bemolizando": "bemolizar",
    "bemolizara": "bemolizar",
    "bemolizaram": "bemolizar",
    "bemolizaras": "bemolizar",
    "bemolizarde": "bemolizar",
    "bemolizardes": "bemolizar",
    "bemolizare": "bemolizar",
    "bemolizarei": "bemolizar",
    "bemolizareis": "bemolizar",
    "bemolizarem": "bemolizar",
    "bemolizaremos": "bemolizar",
    "bemolizares": "bemolizar",
    "bemolizaria": "bemolizar",
    "bemolizariam": "bemolizar",
    "bemolizarias": "bemolizar",
    "bemolizarmo": "bemolizar",
    "bemolizarmos": "bemolizar",
    "bemolizará": "bemolizar",
    "bemolizarás": "bemolizar",
    "bemolizarão": "bemolizar",
    "bemolizaríamos": "bemolizar",
    "bemolizaríeis": "bemolizar",
    "bemolizas": "bemolizar",
    "bemolizasse": "bemolizar",
    "bemolizassem": "bemolizar",
    "bemolizasses": "bemolizar",
    "bemolizaste": "bemolizar",
    "bemolizastes": "bemolizar",
    "bemolizava": "bemolizar",
    "bemolizavam": "bemolizar",
    "bemolizavas": "bemolizar",
    "bemolize": "bemolizar",
    "bemolizei": "bemolizar",
    "bemolizeis": "bemolizar",
    "bemolizem": "bemolizar",
    "bemolizemo": "bemolizar",
    "bemolizemos": "bemolizar",
    "bemolizes": "bemolizar",
    "bemolizo": "bemolizar",
    "bemolizou": "bemolizar",
    "bemolizá": "bemolizar",
    "bemolizámo": "bemolizar",
    "bemolizámos": "bemolizar",
    "bemolizáramo": "bemolizar",
    "bemolizáramos": "bemolizar",
    "bemolizárei": "bemolizar",
    "bemolizáreis": "bemolizar",
    "bemolizásseis": "bemolizar",
    "bemolizássemos": "bemolizar",
    "bemolizávamo": "bemolizar",
    "bemolizávamos": "bemolizar",
    "bemolizávei": "bemolizar",
    "bemolizáveis": "bemolizar",
    "bemolo": "bemolar",
    "bemolou": "bemolar",
    "bemolá": "bemolar",
    "bemolámo": "bemolar",
    "bemolámos": "bemolar",
    "bemoláramo": "bemolar",
    "bemoláramos": "bemolar",
    "bemolárei": "bemolar",
    "bemoláreis": "bemolar",
    "bemolásseis": "bemolar",
    "bemolássemos": "bemolar",
    "bemolávamo": "bemolar",
    "bemolávamos": "bemolar",
    "bemolávei": "bemolar",
    "bemoláveis": "bemolar",
    "bemóis": "bemol",
    "bendiga": "bendizer",
    "bendigais": "bendizer",
    "bendigam": "bendizer",
    "bendigamo": "bendizer",
    "bendigamos": "bendizer",
    "bendigas": "bendizer",
    "bendigo": "bendizer",
    "bendirei": "bendizer",
    "bendireis": "bendizer",
    "bendiremos": "bendizer",
    "bendiria": "bendizer",
    "bendiriam": "bendizer",
    "bendirias": "bendizer",
    "bendirá": "bendizer",
    "bendirás": "bendizer",
    "bendirão": "bendizer",
    "bendiríamos": "bendizer",
    "bendiríeis": "bendizer",
    "bendisse": "bendizer",
    "bendissemo": "bendizer",
    "bendissemos": "bendizer",
    "bendisser": "bendizer",
    "bendissera": "bendizer",
    "bendisseram": "bendizer",
    "bendisseras": "bendizer",
    "bendisserdes": "bendizer",
    "bendisserem": "bendizer",
    "bendisseres": "bendizer",
    "bendissermos": "bendizer",
    "bendissesse": "bendizer",
    "bendissessem": "bendizer",
    "bendissesses": "bendizer",
    "bendisseste": "bendizer",
    "bendissestes": "bendizer",
    "bendisséramo": "bendizer",
    "bendisséramos": "bendizer",
    "bendissérei": "bendizer",
    "bendisséreis": "bendizer",
    "bendissésseis": "bendizer",
    "bendisséssemos": "bendizer",
    "bendita": "bendizer",
    "benditas": "bendizer",
    "bendito": "bendizer",
    "benditos": "bendizer",
    "bendiz": "bendizer",
    "bendize": "bendizer",
    "bendizei": "bendizer",
    "bendizeis": "bendizer",
    "bendizem": "bendizer",
    "bendizemo": "bendizer",
    "bendizemos": "bendizer",
    "bendizendo": "bendizer",
    "bendizerde": "bendizer",
    "bendizerdes": "bendizer",
    "bendizere": "bendizer",
    "bendizerem": "bendizer",
    "bendizeres": "bendizer",
    "bendizermo": "bendizer",
    "bendizermos": "bendizer",
    "bendizes": "bendizer",
    "bendizia": "bendizer",
    "bendiziam": "bendizer",
    "bendizias": "bendizer",
    "bendizê": "bendizer",
    "bendizíamo": "bendizer",
    "bendizíamos": "bendizer",
    "bendizíei": "bendizer",
    "bendizíeis": "bendizer",
    "beneditina": "beneditino",
    "beneditinas": "beneditino",
    "beneditinos": "beneditino",
    "beneditos": "benedito",
    "benefes": "benefe",
    "beneficentes": "beneficente",
    "beneficia": "beneficiar",
    "beneficiada": "beneficiar",
    "beneficiadas": "beneficiar",
    "beneficiado": "beneficiar",
    "beneficiadora": "beneficiador",
    "beneficiadoras": "beneficiador",
    "beneficiadores": "beneficiador",
    "beneficiados": "beneficiar",
    "beneficiadíssima": "beneficiado",
    "beneficiadíssimas": "beneficiado",
    "beneficiadíssimo": "beneficiado",
    "beneficiadíssimos": "beneficiado",
    "beneficiai": "beneficiar",
    "beneficiais": "beneficiar",
    "beneficiam": "beneficiar",
    "beneficiamentos": "beneficiamento",
    "beneficiamo": "beneficiar",
    "beneficiamos": "beneficiar",
    "beneficiando": "beneficiar",
    "beneficiara": "beneficiar",
    "beneficiaram": "beneficiar",
    "beneficiaras": "beneficiar",
    "beneficiarde": "beneficiar",
    "beneficiardes": "beneficiar",
    "beneficiare": "beneficiar",
    "beneficiarei": "beneficiar",
    "beneficiareis": "beneficiar",
    "beneficiarem": "beneficiar",
    "beneficiaremos": "beneficiar",
    "beneficiares": "beneficiar",
    "beneficiaria": "beneficiar",
    "beneficiariam": "beneficiar",
    "beneficiarias": "beneficiar",
    "beneficiarmo": "beneficiar",
    "beneficiarmos": "beneficiar",
    "beneficiará": "beneficiar",
    "beneficiarás": "beneficiar",
    "beneficiarão": "beneficiar",
    "beneficiaríamos": "beneficiar",
    "beneficiaríeis": "beneficiar",
    "beneficias": "beneficiar",
    "beneficiasse": "beneficiar",
    "beneficiassem": "beneficiar",
    "beneficiasses": "beneficiar",
    "beneficiaste": "beneficiar",
    "beneficiastes": "beneficiar",
    "beneficiava": "beneficiar",
    "beneficiavam": "beneficiar",
    "beneficiavas": "beneficiar",
    "beneficiações": "beneficiação",
    "beneficie": "beneficiar",
    "beneficiei": "beneficiar",
    "beneficieis": "beneficiar",
    "beneficiem": "beneficiar",
    "beneficiemo": "beneficiar",
    "beneficiemos": "beneficiar",
    "beneficies": "beneficiar",
    "beneficio": "beneficiar",
    "beneficiou": "beneficiar",
    "beneficiá": "beneficiar",
    "beneficiámo": "beneficiar",
    "beneficiámos": "beneficiar",
    "beneficiáramo": "beneficiar",
    "beneficiáramos": "beneficiar",
    "beneficiárei": "beneficiar",
    "beneficiáreis": "beneficiar",
    "beneficiária": "beneficiário",
    "beneficiárias": "beneficiário",
    "beneficiários": "beneficiário",
    "beneficiásseis": "beneficiar",
    "beneficiássemos": "beneficiar",
    "beneficiávamo": "beneficiar",
    "beneficiávamos": "beneficiar",
    "beneficiávei": "beneficiar",
    "beneficiáveis": "beneficiável",
    "beneficências": "beneficência",
    "benefícios": "benefício",
    "benemerentes": "benemerente",
    "benemerências": "benemerência",
    "benemérita": "benemérito",
    "beneméritas": "benemérito",
    "beneméritos": "benemérito",
    "beneplácitos": "beneplácito",
    "benesses": "benesse",
    "benevolentes": "benevolente",
    "benevolências": "benevolência",
    "benfazeja": "benfazejo",
    "benfazejas": "benfazejo",
    "benfazejos": "benfazejo",
    "benfeitora": "benfeitor",
    "benfeitoras": "benfeitor",
    "benfeitores": "benfeitor",
    "benfeitorias": "benfeitoria",
    "benfeitoriza": "benfeitorizar",
    "benfeitorizada": "benfeitorizar",
    "benfeitorizadas": "benfeitorizar",
    "benfeitorizado": "benfeitorizar",
    "benfeitorizados": "benfeitorizar",
    "benfeitorizai": "benfeitorizar",
    "benfeitorizais": "benfeitorizar",
    "benfeitorizam": "benfeitorizar",
    "benfeitorizamo": "benfeitorizar",
    "benfeitorizamos": "benfeitorizar",
    "benfeitorizando": "benfeitorizar",
    "benfeitorizara": "benfeitorizar",
    "benfeitorizaram": "benfeitorizar",
    "benfeitorizaras": "benfeitorizar",
    "benfeitorizarde": "benfeitorizar",
    "benfeitorizardes": "benfeitorizar",
    "benfeitorizare": "benfeitorizar",
    "benfeitorizarei": "benfeitorizar",
    "benfeitorizareis": "benfeitorizar",
    "benfeitorizarem": "benfeitorizar",
    "benfeitorizaremos": "benfeitorizar",
    "benfeitorizares": "benfeitorizar",
    "benfeitorizaria": "benfeitorizar",
    "benfeitorizariam": "benfeitorizar",
    "benfeitorizarias": "benfeitorizar",
    "benfeitorizarmo": "benfeitorizar",
    "benfeitorizarmos": "benfeitorizar",
    "benfeitorizará": "benfeitorizar",
    "benfeitorizarás": "benfeitorizar",
    "benfeitorizarão": "benfeitorizar",
    "benfeitorizaríamos": "benfeitorizar",
    "benfeitorizaríeis": "benfeitorizar",
    "benfeitorizas": "benfeitorizar",
    "benfeitorizasse": "benfeitorizar",
    "benfeitorizassem": "benfeitorizar",
    "benfeitorizasses": "benfeitorizar",
    "benfeitorizaste": "benfeitorizar",
    "benfeitorizastes": "benfeitorizar",
    "benfeitorizava": "benfeitorizar",
    "benfeitorizavam": "benfeitorizar",
    "benfeitorizavas": "benfeitorizar",
    "benfeitorize": "benfeitorizar",
    "benfeitorizei": "benfeitorizar",
    "benfeitorizeis": "benfeitorizar",
    "benfeitorizem": "benfeitorizar",
    "benfeitorizemo": "benfeitorizar",
    "benfeitorizemos": "benfeitorizar",
    "benfeitorizes": "benfeitorizar",
    "benfeitorizo": "benfeitorizar",
    "benfeitorizou": "benfeitorizar",
    "benfeitorizá": "benfeitorizar",
    "benfeitorizámo": "benfeitorizar",
    "benfeitorizámos": "benfeitorizar",
    "benfeitorizáramo": "benfeitorizar",
    "benfeitorizáramos": "benfeitorizar",
    "benfeitorizárei": "benfeitorizar",
    "benfeitorizáreis": "benfeitorizar",
    "benfeitorizásseis": "benfeitorizar",
    "benfeitorizássemos": "benfeitorizar",
    "benfeitorizávamo": "benfeitorizar",
    "benfeitorizávamos": "benfeitorizar",
    "benfeitorizávei": "benfeitorizar",
    "benfeitorizáveis": "benfeitorizar",
    "benfiquismos": "benfiquismo",
    "benfiquistas": "benfiquista",
    "bengaladas": "bengalada",
    "bengalas": "bengala",
    "bengaleiros": "bengaleiro",
    "bengalesa": "bengalês",
    "bengalesas": "bengalês",
    "bengaleses": "bengalês",
    "bengalinha": "bengala",
    "bengalinhas": "bengalinha",
    "bengalita": "bengala",
    "bengalitas": "bengala",
    "bengalões": "bengalão",
    "bengos": "bengo",
    "benguelas": "benguela",
    "benguelenses": "benguelense",
    "benigna": "benigno",
    "benignas": "benigno",
    "benignidades": "benignidade",
    "benignos": "benigno",
    "benjamins": "benjamim",
    "benjoíns": "benjoím",
    "benodáctila": "benodáctilo",
    "benodáctilas": "benodáctilo",
    "benodáctilos": "benodáctilo",
    "benquerenças": "benquerença",
    "benquista": "benquisto",
    "benquistada": "benquistar",
    "benquistadas": "benquistar",
    "benquistado": "benquistar",
    "benquistados": "benquistar",
    "benquistai": "benquistar",
    "benquistais": "benquistar",
    "benquistam": "benquistar",
    "benquistamo": "benquistar",
    "benquistamos": "benquistar",
    "benquistando": "benquistar",
    "benquistara": "benquistar",
    "benquistaram": "benquistar",
    "benquistaras": "benquistar",
    "benquistarde": "benquistar",
    "benquistardes": "benquistar",
    "benquistare": "benquistar",
    "benquistarei": "benquistar",
    "benquistareis": "benquistar",
    "benquistarem": "benquistar",
    "benquistaremos": "benquistar",
    "benquistares": "benquistar",
    "benquistaria": "benquistar",
    "benquistariam": "benquistar",
    "benquistarias": "benquistar",
    "benquistarmo": "benquistar",
    "benquistarmos": "benquistar",
    "benquistará": "benquistar",
    "benquistarás": "benquistar",
    "benquistarão": "benquistar",
    "benquistaríamos": "benquistar",
    "benquistaríeis": "benquistar",
    "benquistas": "benquisto",
    "benquistasse": "benquistar",
    "benquistassem": "benquistar",
    "benquistasses": "benquistar",
    "benquistaste": "benquistar",
    "benquistastes": "benquistar",
    "benquistava": "benquistar",
    "benquistavam": "benquistar",
    "benquistavas": "benquistar",
    "benquiste": "benquistar",
    "benquistei": "benquistar",
    "benquisteis": "benquistar",
    "benquistem": "benquistar",
    "benquistemo": "benquistar",
    "benquistemos": "benquistar",
    "benquistes": "benquistar",
    "benquisto": "benquistar",
    "benquistos": "benquisto",
    "benquistou": "benquistar",
    "benquistá": "benquistar",
    "benquistámo": "benquistar",
    "benquistámos": "benquistar",
    "benquistáramo": "benquistar",
    "benquistáramos": "benquistar",
    "benquistárei": "benquistar",
    "benquistáreis": "benquistar",
    "benquistásseis": "benquistar",
    "benquistássemos": "benquistar",
    "benquistávamo": "benquistar",
    "benquistávamos": "benquistar",
    "benquistávei": "benquistar",
    "benquistáveis": "benquistar",
    "bens": "bem",
    "benta": "bento",
    "bentas": "bento",
    "bentos": "bento",
    "bentoínhas": "bentoínha",
    "benza": "benzer",
    "benzais": "benzer",
    "benzam": "benzer",
    "benzamo": "benzer",
    "benzamos": "benzer",
    "benzas": "benzer",
    "benze": "benzer",
    "benzedeira": "benzedeiro",
    "benzedeiras": "benzedeiro",
    "benzedeiros": "benzedeiro",
    "benzedelas": "benzedela",
    "benzedora": "benzedor",
    "benzedoras": "benzedor",
    "benzedores": "benzedor",
    "benzeduras": "benzedura",
    "benzei": "benzer",
    "benzeis": "benzer",
    "benzem": "benzer",
    "benzemo": "benzer",
    "benzemos": "benzer",
    "benzendo": "benzer",
    "benzenos": "benzeno",
    "benzenossulfónica": "benzenossulfónico",
    "benzenossulfónicas": "benzenossulfónico",
    "benzenossulfónicos": "benzenossulfónico",
    "benzera": "benzer",
    "benzeram": "benzer",
    "benzeras": "benzer",
    "benzerde": "benzer",
    "benzerdes": "benzer",
    "benzere": "benzer",
    "benzerei": "benzer",
    "benzereis": "benzer",
    "benzerem": "benzer",
    "benzeremos": "benzer",
    "benzeres": "benzer",
    "benzeria": "benzer",
    "benzeriam": "benzer",
    "benzerias": "benzer",
    "benzermo": "benzer",
    "benzermos": "benzer",
    "benzerá": "benzer",
    "benzerás": "benzer",
    "benzerão": "benzer",
    "benzeríamos": "benzer",
    "benzeríeis": "benzer",
    "benzes": "benzer",
    "benzesse": "benzer",
    "benzessem": "benzer",
    "benzesses": "benzer",
    "benzeste": "benzer",
    "benzestes": "benzer",
    "benzeu": "benzer",
    "benzi": "benzer",
    "benzia": "benzer",
    "benziam": "benzer",
    "benzias": "benzer",
    "benzida": "benzido",
    "benzidas": "benzido",
    "benzidinas": "benzidina",
    "benzido": "benzer",
    "benzidos": "benzido",
    "benzilhões": "benzilhão",
    "benzilos": "benzilo",
    "benzimentos": "benzimento",
    "benzinas": "benzina",
    "benzis": "benzil",
    "benzitas": "benzita",
    "benzo": "benzer",
    "benzoatos": "benzoato",
    "benzodiazepinas": "benzodiazepina",
    "benzonafetóis": "benzonafetol",
    "benzossulfónica": "benzossulfónico",
    "benzossulfónicas": "benzossulfónico",
    "benzossulfónicos": "benzossulfónico",
    "benzénica": "benzénico",
    "benzénicas": "benzénico",
    "benzénicos": "benzénico",
    "benzê": "benzer",
    "benzêramo": "benzer",
    "benzêramos": "benzer",
    "benzêrei": "benzer",
    "benzêreis": "benzer",
    "benzêsseis": "benzer",
    "benzêssemos": "benzer",
    "benzíamo": "benzer",
    "benzíamos": "benzer",
    "benzíei": "benzer",
    "benzíeis": "benzer",
    "benzílica": "benzílico",
    "benzílicas": "benzílico",
    "benzílicos": "benzílico",
    "benzóica": "benzóico",
    "benzóicas": "benzóico",
    "benzóicos": "benzóico",
    "benzóis": "benzol",
    "benéfica": "benéfico",
    "benéficas": "benéfico",
    "benéficos": "benéfico",
    "benévola": "benévolo",
    "benévolas": "benévolo",
    "benévolos": "benévolo",
    "beques": "beque",
    "bequilhas": "bequilha",
    "bequinha": "beca",
    "bequinhas": "beca",
    "bequita": "beca",
    "bequitas": "beca",
    "beras": "bera",
    "berbequins": "berbequim",
    "berberes": "berbere",
    "berberesca": "berberesco",
    "berberescas": "berberesco",
    "berberescos": "berberesco",
    "berberinas": "berberina",
    "berbicachos": "berbicacho",
    "berbigoeiras": "berbigoeira",
    "berbigões": "berbigão",
    "berbérica": "berbérico",
    "berbéricas": "berbérico",
    "berbéricos": "berbérico",
    "bercinho": "berço",
    "bercinhos": "berço",
    "bercito": "berço",
    "bercitos": "berço",
    "berdamerdas": "berdamerda",
    "bergadinhas": "bergadinha",
    "bergamotas": "bergamota",
    "bergantins": "bergantim",
    "bergelas": "bergela",
    "bergsoniana": "bergsoniano",
    "bergsonianas": "bergsoniano",
    "bergsonianos": "bergsoniano",
    "bergsonismos": "bergsonismo",
    "beriberiza": "beriberizar",
    "beriberizada": "beriberizar",
    "beriberizadas": "beriberizar",
    "beriberizado": "beriberizar",
    "beriberizados": "beriberizar",
    "beriberizai": "beriberizar",
    "beriberizais": "beriberizar",
    "beriberizam": "beriberizar",
    "beriberizamo": "beriberizar",
    "beriberizamos": "beriberizar",
    "beriberizando": "beriberizar",
    "beriberizara": "beriberizar",
    "beriberizaram": "beriberizar",
    "beriberizaras": "beriberizar",
    "beriberizarde": "beriberizar",
    "beriberizardes": "beriberizar",
    "beriberizare": "beriberizar",
    "beriberizarei": "beriberizar",
    "beriberizareis": "beriberizar",
    "beriberizarem": "beriberizar",
    "beriberizaremos": "beriberizar",
    "beriberizares": "beriberizar",
    "beriberizaria": "beriberizar",
    "beriberizariam": "beriberizar",
    "beriberizarias": "beriberizar",
    "beriberizarmo": "beriberizar",
    "beriberizarmos": "beriberizar",
    "beriberizará": "beriberizar",
    "beriberizarás": "beriberizar",
    "beriberizarão": "beriberizar",
    "beriberizaríamos": "beriberizar",
    "beriberizaríeis": "beriberizar",
    "beriberizas": "beriberizar",
    "beriberizasse": "beriberizar",
    "beriberizassem": "beriberizar",
    "beriberizasses": "beriberizar",
    "beriberizaste": "beriberizar",
    "beriberizastes": "beriberizar",
    "beriberizava": "beriberizar",
    "beriberizavam": "beriberizar",
    "beriberizavas": "beriberizar",
    "beriberize": "beriberizar",
    "beriberizei": "beriberizar",
    "beriberizeis": "beriberizar",
    "beriberizem": "beriberizar",
    "beriberizemo": "beriberizar",
    "beriberizemos": "beriberizar",
    "beriberizes": "beriberizar",
    "beriberizo": "beriberizar",
    "beriberizou": "beriberizar",
    "beriberizá": "beriberizar",
    "beriberizámo": "beriberizar",
    "beriberizámos": "beriberizar",
    "beriberizáramo": "beriberizar",
    "beriberizáramos": "beriberizar",
    "beriberizárei": "beriberizar",
    "beriberizáreis": "beriberizar",
    "beriberizásseis": "beriberizar",
    "beriberizássemos": "beriberizar",
    "beriberizávamo": "beriberizar",
    "beriberizávamos": "beriberizar",
    "beriberizávei": "beriberizar",
    "beriberizáveis": "beriberizar",
    "beribérica": "beribérico",
    "beribéricas": "beribérico",
    "beribéricos": "beribérico",
    "bericídea": "bericídeo",
    "bericídeas": "bericídeo",
    "bericídeos": "bericídeo",
    "berilos": "berilo",
    "berimbaus": "berimbau",
    "beringelas": "beringela",
    "berkeleyanismos": "berkeleyanismo",
    "berkeleyniana": "berkeleyniano",
    "berkeleynianas": "berkeleyniano",
    "berkeleynianos": "berkeleyniano",
    "berlindas": "berlinda",
    "berlindes": "berlinde",
    "berlinenses": "berlinense",
    "berlinesa": "berlinês",
    "berlinesas": "berlinês",
    "berlineses": "berlinês",
    "berloques": "berloque",
    "bermas": "berma",
    "bermudas": "bermuda",
    "bernacas": "bernaca",
    "bernachos": "bernacho",
    "bernarda": "bernardo",
    "bernardas": "bernardo",
    "bernardesca": "bernardesco",
    "bernardescas": "bernardesco",
    "bernardescos": "bernardesco",
    "bernardices": "bernardice",
    "bernardos": "bernardo",
    "bernazes": "bernaz",
    "bernenses": "bernense",
    "bernes": "berne",
    "bernesa": "bernês",
    "bernesas": "bernês",
    "berneses": "bernês",
    "beroídea": "beroídeo",
    "beroídeas": "beroídeo",
    "beroídeos": "beroídeo",
    "berquélios": "berquélio",
    "berra": "berrar",
    "berrada": "berrar",
    "berradas": "berrar",
    "berrado": "berrar",
    "berradora": "berrador",
    "berradoras": "berrador",
    "berradores": "berrador",
    "berrados": "berrar",
    "berrai": "berrar",
    "berrais": "berrar",
    "berram": "berrar",
    "berramo": "berrar",
    "berramos": "berrar",
    "berrando": "berrar",
    "berrantes": "berrante",
    "berrara": "berrar",
    "berraram": "berrar",
    "berraras": "berrar",
    "berrardes": "berrar",
    "berrarei": "berrar",
    "berrareis": "berrar",
    "berrarem": "berrar",
    "berraremos": "berrar",
    "berrares": "berrar",
    "berraria": "berrar",
    "berrariam": "berrar",
    "berrarias": "berraria",
    "berrarmo": "berrar",
    "berrarmos": "berrar",
    "berrará": "berrar",
    "berrarás": "berrar",
    "berrarão": "berrar",
    "berraríamos": "berrar",
    "berraríeis": "berrar",
    "berras": "berrar",
    "berrasse": "berrar",
    "berrassem": "berrar",
    "berrasses": "berrar",
    "berraste": "berrar",
    "berrastes": "berrar",
    "berratórios": "berratório",
    "berrava": "berrar",
    "berravam": "berrar",
    "berravas": "berrar",
    "berrações": "berração",
    "berre": "berrar",
    "berrega": "berregar",
    "berregada": "berregar",
    "berregadas": "berregar",
    "berregado": "berregar",
    "berregados": "berregar",
    "berregai": "berregar",
    "berregais": "berregar",
    "berregam": "berregar",
    "berregamo": "berregar",
    "berregamos": "berregar",
    "berregando": "berregar",
    "berregara": "berregar",
    "berregaram": "berregar",
    "berregaras": "berregar",
    "berregardes": "berregar",
    "berregarei": "berregar",
    "berregareis": "berregar",
    "berregarem": "berregar",
    "berregaremos": "berregar",
    "berregares": "berregar",
    "berregaria": "berregar",
    "berregariam": "berregar",
    "berregarias": "berregar",
    "berregarmo": "berregar",
    "berregarmos": "berregar",
    "berregará": "berregar",
    "berregarás": "berregar",
    "berregarão": "berregar",
    "berregaríamos": "berregar",
    "berregaríeis": "berregar",
    "berregas": "berregar",
    "berregasse": "berregar",
    "berregassem": "berregar",
    "berregasses": "berregar",
    "berregaste": "berregar",
    "berregastes": "berregar",
    "berregava": "berregar",
    "berregavam": "berregar",
    "berregavas": "berregar",
    "berrego": "berregar",
    "berregou": "berregar",
    "berregue": "berregar",
    "berreguei": "berregar",
    "berregueis": "berregar",
    "berreguem": "berregar",
    "berreguemo": "berregar",
    "berreguemos": "berregar",
    "berregues": "berregar",
    "berregámo": "berregar",
    "berregámos": "berregar",
    "berregáramo": "berregar",
    "berregáramos": "berregar",
    "berregáreis": "berregar",
    "berregásseis": "berregar",
    "berregássemos": "berregar",
    "berregávamo": "berregar",
    "berregávamos": "berregar",
    "berregáveis": "berregar",
    "berrei": "berrar",
    "berreiros": "berreiro",
    "berreis": "berrar",
    "berrem": "berrar",
    "berremo": "berrar",
    "berremos": "berrar",
    "berres": "berrar",
    "berrinho": "berro",
    "berrinhos": "berro",
    "berrito": "berro",
    "berritos": "berro",
    "berro": "berrar",
    "berroas": "berroa",
    "berronas": "berrona",
    "berros": "berro",
    "berrou": "berrar",
    "berrámo": "berrar",
    "berrámos": "berrar",
    "berráramo": "berrar",
    "berráramos": "berrar",
    "berráreis": "berrar",
    "berrásseis": "berrar",
    "berrássemos": "berrar",
    "berrávamo": "berrar",
    "berrávamos": "berrar",
    "berráveis": "berrar",
    "berrões": "berrão",
    "bertangiis": "bertangil",
    "bertoldices": "bertoldice",
    "bertoldos": "bertoldo",
    "berzabuns": "berzabum",
    "berzundas": "berzunda",
    "berzundelas": "berzundela",
    "berças": "berça",
    "berços": "berço",
    "berçozinho": "berço",
    "berçozinhos": "berço",
    "berçozito": "berço",
    "berçozitos": "berço",
    "berçuda": "berçudo",
    "berçudas": "berçudo",
    "berçudos": "berçudo",
    "berçários": "berçário",
    "berícidas": "berícida",
    "berílios": "berílio",
    "beróides": "beróide",
    "besanta": "besantar",
    "besantada": "besantar",
    "besantadas": "besantar",
    "besantado": "besantar",
    "besantados": "besantar",
    "besantai": "besantar",
    "besantais": "besantar",
    "besantam": "besantar",
    "besantamo": "besantar",
    "besantamos": "besantar",
    "besantando": "besantar",
    "besantara": "besantar",
    "besantaram": "besantar",
    "besantaras": "besantar",
    "besantarde": "besantar",
    "besantardes": "besantar",
    "besantare": "besantar",
    "besantarei": "besantar",
    "besantareis": "besantar",
    "besantarem": "besantar",
    "besantaremos": "besantar",
    "besantares": "besantar",
    "besantaria": "besantar",
    "besantariam": "besantar",
    "besantarias": "besantar",
    "besantarmo": "besantar",
    "besantarmos": "besantar",
    "besantará": "besantar",
    "besantarás": "besantar",
    "besantarão": "besantar",
    "besantaríamos": "besantar",
    "besantaríeis": "besantar",
    "besantas": "besantar",
    "besantasse": "besantar",
    "besantassem": "besantar",
    "besantasses": "besantar",
    "besantaste": "besantar",
    "besantastes": "besantar",
    "besantava": "besantar",
    "besantavam": "besantar",
    "besantavas": "besantar",
    "besante": "besantar",
    "besantei": "besantar",
    "besanteis": "besantar",
    "besantem": "besantar",
    "besantemo": "besantar",
    "besantemos": "besantar",
    "besantes": "besante",
    "besanto": "besantar",
    "besantou": "besantar",
    "besantá": "besantar",
    "besantámo": "besantar",
    "besantámos": "besantar",
    "besantáramo": "besantar",
    "besantáramos": "besantar",
    "besantárei": "besantar",
    "besantáreis": "besantar",
    "besantásseis": "besantar",
    "besantássemos": "besantar",
    "besantávamo": "besantar",
    "besantávamos": "besantar",
    "besantávei": "besantar",
    "besantáveis": "besantar",
    "besigues": "besigue",
    "besoira": "besoirar",
    "besoirada": "besoirar",
    "besoiradas": "besoirar",
    "besoirado": "besoirar",
    "besoirados": "besoirar",
    "besoirai": "besoirar",
    "besoirais": "besoirar",
    "besoiram": "besoirar",
    "besoiramo": "besoirar",
    "besoiramos": "besoirar",
    "besoirando": "besoirar",
    "besoirara": "besoirar",
    "besoiraram": "besoirar",
    "besoiraras": "besoirar",
    "besoirardes": "besoirar",
    "besoirarei": "besoirar",
    "besoirareis": "besoirar",
    "besoirarem": "besoirar",
    "besoiraremos": "besoirar",
    "besoirares": "besoirar",
    "besoiraria": "besoirar",
    "besoirariam": "besoirar",
    "besoirarias": "besoirar",
    "besoirarmo": "besoirar",
    "besoirarmos": "besoirar",
    "besoirará": "besoirar",
    "besoirarás": "besoirar",
    "besoirarão": "besoirar",
    "besoiraríamos": "besoirar",
    "besoiraríeis": "besoirar",
    "besoiras": "besoirar",
    "besoirasse": "besoirar",
    "besoirassem": "besoirar",
    "besoirasses": "besoirar",
    "besoiraste": "besoirar",
    "besoirastes": "besoirar",
    "besoirava": "besoirar",
    "besoiravam": "besoirar",
    "besoiravas": "besoirar",
    "besoire": "besoirar",
    "besoirei": "besoirar",
    "besoireis": "besoirar",
    "besoirem": "besoirar",
    "besoiremo": "besoirar",
    "besoiremos": "besoirar",
    "besoires": "besoirar",
    "besoirinho": "besoiro",
    "besoirinhos": "besoiro",
    "besoirito": "besoiro",
    "besoiritos": "besoiro",
    "besoiro": "besoirar",
    "besoiros": "besoiro",
    "besoirou": "besoirar",
    "besoirámo": "besoirar",
    "besoirámos": "besoirar",
    "besoiráramo": "besoirar",
    "besoiráramos": "besoirar",
    "besoiráreis": "besoirar",
    "besoirásseis": "besoirar",
    "besoirássemos": "besoirar",
    "besoirávamo": "besoirar",
    "besoirávamos": "besoirar",
    "besoiráveis": "besoirar",
    "besoura": "besourar",
    "besourada": "besourar",
    "besouradas": "besourar",
    "besourado": "besourar",
    "besourados": "besourar",
    "besourai": "besourar",
    "besourais": "besourar",
    "besouram": "besourar",
    "besouramo": "besourar",
    "besouramos": "besourar",
    "besourando": "besourar",
    "besourara": "besourar",
    "besouraram": "besourar",
    "besouraras": "besourar",
    "besourardes": "besourar",
    "besourarei": "besourar",
    "besourareis": "besourar",
    "besourarem": "besourar",
    "besouraremos": "besourar",
    "besourares": "besourar",
    "besouraria": "besourar",
    "besourariam": "besourar",
    "besourarias": "besourar",
    "besourarmo": "besourar",
    "besourarmos": "besourar",
    "besourará": "besourar",
    "besourarás": "besourar",
    "besourarão": "besourar",
    "besouraríamos": "besourar",
    "besouraríeis": "besourar",
    "besouras": "besourar",
    "besourasse": "besourar",
    "besourassem": "besourar",
    "besourasses": "besourar",
    "besouraste": "besourar",
    "besourastes": "besourar",
    "besourava": "besourar",
    "besouravam": "besourar",
    "besouravas": "besourar",
    "besoure": "besourar",
    "besourei": "besourar",
    "besoureis": "besourar",
    "besourem": "besourar",
    "besouremo": "besourar",
    "besouremos": "besourar",
    "besoures": "besourar",
    "besourinho": "besouro",
    "besourinhos": "besouro",
    "besourito": "besouro",
    "besouritos": "besouro",
    "besouro": "besourar",
    "besouros": "besouro",
    "besourou": "besourar",
    "besourámo": "besourar",
    "besourámos": "besourar",
    "besouráramo": "besourar",
    "besouráramos": "besourar",
    "besouráreis": "besourar",
    "besourásseis": "besourar",
    "besourássemos": "besourar",
    "besourávamo": "besourar",
    "besourávamos": "besourar",
    "besouráveis": "besourar",
    "bestalhona": "bestalhão",
    "bestalhonas": "bestalhão",
    "bestalhões": "bestalhão",
    "bestarias": "bestaria",
    "bestas": "besta",
    "bestearias": "bestearia",
    "besteiras": "besteira",
    "besteiros": "besteiro",
    "bestiagas": "bestiaga",
    "bestiagens": "bestiagem",
    "bestiais": "bestial",
    "bestialidades": "bestialidade",
    "bestializa": "bestializar",
    "bestializada": "bestializar",
    "bestializadas": "bestializar",
    "bestializado": "bestializar",
    "bestializadora": "bestializador",
    "bestializadoras": "bestializador",
    "bestializadores": "bestializador",
    "bestializados": "bestializar",
    "bestializai": "bestializar",
    "bestializais": "bestializar",
    "bestializam": "bestializar",
    "bestializamo": "bestializar",
    "bestializamos": "bestializar",
    "bestializando": "bestializar",
    "bestializara": "bestializar",
    "bestializaram": "bestializar",
    "bestializaras": "bestializar",
    "bestializarde": "bestializar",
    "bestializardes": "bestializar",
    "bestializare": "bestializar",
    "bestializarei": "bestializar",
    "bestializareis": "bestializar",
    "bestializarem": "bestializar",
    "bestializaremos": "bestializar",
    "bestializares": "bestializar",
    "bestializaria": "bestializar",
    "bestializariam": "bestializar",
    "bestializarias": "bestializar",
    "bestializarmo": "bestializar",
    "bestializarmos": "bestializar",
    "bestializará": "bestializar",
    "bestializarás": "bestializar",
    "bestializarão": "bestializar",
    "bestializaríamos": "bestializar",
    "bestializaríeis": "bestializar",
    "bestializas": "bestializar",
    "bestializasse": "bestializar",
    "bestializassem": "bestializar",
    "bestializasses": "bestializar",
    "bestializaste": "bestializar",
    "bestializastes": "bestializar",
    "bestializava": "bestializar",
    "bestializavam": "bestializar",
    "bestializavas": "bestializar",
    "bestializações": "bestialização",
    "bestialize": "bestializar",
    "bestializei": "bestializar",
    "bestializeis": "bestializar",
    "bestializem": "bestializar",
    "bestializemo": "bestializar",
    "bestializemos": "bestializar",
    "bestializes": "bestializar",
    "bestializo": "bestializar",
    "bestializou": "bestializar",
    "bestializá": "bestializar",
    "bestializámo": "bestializar",
    "bestializámos": "bestializar",
    "bestializáramo": "bestializar",
    "bestializáramos": "bestializar",
    "bestializárei": "bestializar",
    "bestializáreis": "bestializar",
    "bestializásseis": "bestializar",
    "bestializássemos": "bestializar",
    "bestializávamo": "bestializar",
    "bestializávamos": "bestializar",
    "bestializávei": "bestializar",
    "bestializáveis": "bestializar",
    "bestiames": "bestiame",
    "bestices": "bestice",
    "bestidades": "bestidade",
    "bestifica": "bestificar",
    "bestificada": "bestificar",
    "bestificadas": "bestificar",
    "bestificado": "bestificar",
    "bestificadora": "bestificador",
    "bestificadoras": "bestificador",
    "bestificadores": "bestificador",
    "bestificados": "bestificar",
    "bestificai": "bestificar",
    "bestificais": "bestificar",
    "bestificam": "bestificar",
    "bestificamo": "bestificar",
    "bestificamos": "bestificar",
    "bestificando": "bestificar",
    "bestificantes": "bestificante",
    "bestificara": "bestificar",
    "bestificaram": "bestificar",
    "bestificaras": "bestificar",
    "bestificarde": "bestificar",
    "bestificardes": "bestificar",
    "bestificare": "bestificar",
    "bestificarei": "bestificar",
    "bestificareis": "bestificar",
    "bestificarem": "bestificar",
    "bestificaremos": "bestificar",
    "bestificares": "bestificar",
    "bestificaria": "bestificar",
    "bestificariam": "bestificar",
    "bestificarias": "bestificar",
    "bestificarmo": "bestificar",
    "bestificarmos": "bestificar",
    "bestificará": "bestificar",
    "bestificarás": "bestificar",
    "bestificarão": "bestificar",
    "bestificaríamos": "bestificar",
    "bestificaríeis": "bestificar",
    "bestificas": "bestificar",
    "bestificasse": "bestificar",
    "bestificassem": "bestificar",
    "bestificasses": "bestificar",
    "bestificaste": "bestificar",
    "bestificastes": "bestificar",
    "bestificava": "bestificar",
    "bestificavam": "bestificar",
    "bestificavas": "bestificar",
    "bestificações": "bestificação",
    "bestifico": "bestificar",
    "bestificou": "bestificar",
    "bestificá": "bestificar",
    "bestificámo": "bestificar",
    "bestificámos": "bestificar",
    "bestificáramo": "bestificar",
    "bestificáramos": "bestificar",
    "bestificárei": "bestificar",
    "bestificáreis": "bestificar",
    "bestificásseis": "bestificar",
    "bestificássemos": "bestificar",
    "bestificávamo": "bestificar",
    "bestificávamos": "bestificar",
    "bestificávei": "bestificar",
    "bestificáveis": "bestificar",
    "bestifique": "bestificar",
    "bestifiquei": "bestificar",
    "bestifiqueis": "bestificar",
    "bestifiquem": "bestificar",
    "bestifiquemo": "bestificar",
    "bestifiquemos": "bestificar",
    "bestifiques": "bestificar",
    "bestinha": "besta",
    "bestinhas": "besta",
    "bestiolas": "bestiola",
    "bestita": "besta",
    "bestitas": "besta",
    "bestiária": "bestiário",
    "bestiárias": "bestiário",
    "bestiários": "bestiário",
    "bestunta": "bestuntar",
    "bestuntada": "bestuntar",
    "bestuntadas": "bestuntar",
    "bestuntado": "bestuntar",
    "bestuntados": "bestuntar",
    "bestuntai": "bestuntar",
    "bestuntais": "bestuntar",
    "bestuntam": "bestuntar",
    "bestuntamo": "bestuntar",
    "bestuntamos": "bestuntar",
    "bestuntando": "bestuntar",
    "bestuntara": "bestuntar",
    "bestuntaram": "bestuntar",
    "bestuntaras": "bestuntar",
    "bestuntarde": "bestuntar",
    "bestuntardes": "bestuntar",
    "bestuntare": "bestuntar",
    "bestuntarei": "bestuntar",
    "bestuntareis": "bestuntar",
    "bestuntarem": "bestuntar",
    "bestuntaremos": "bestuntar",
    "bestuntares": "bestuntar",
    "bestuntaria": "bestuntar",
    "bestuntariam": "bestuntar",
    "bestuntarias": "bestuntar",
    "bestuntarmo": "bestuntar",
    "bestuntarmos": "bestuntar",
    "bestuntará": "bestuntar",
    "bestuntarás": "bestuntar",
    "bestuntarão": "bestuntar",
    "bestuntaríamos": "bestuntar",
    "bestuntaríeis": "bestuntar",
    "bestuntas": "bestuntar",
    "bestuntasse": "bestuntar",
    "bestuntassem": "bestuntar",
    "bestuntasses": "bestuntar",
    "bestuntaste": "bestuntar",
    "bestuntastes": "bestuntar",
    "bestuntava": "bestuntar",
    "bestuntavam": "bestuntar",
    "bestuntavas": "bestuntar",
    "bestunte": "bestuntar",
    "bestuntei": "bestuntar",
    "bestunteis": "bestuntar",
    "bestuntem": "bestuntar",
    "bestuntemo": "bestuntar",
    "bestuntemos": "bestuntar",
    "bestuntes": "bestuntar",
    "bestunto": "bestuntar",
    "bestuntos": "bestunto",
    "bestuntou": "bestuntar",
    "bestuntá": "bestuntar",
    "bestuntámo": "bestuntar",
    "bestuntámos": "bestuntar",
    "bestuntáramo": "bestuntar",
    "bestuntáramos": "bestuntar",
    "bestuntárei": "bestuntar",
    "bestuntáreis": "bestuntar",
    "bestuntásseis": "bestuntar",
    "bestuntássemos": "bestuntar",
    "bestuntávamo": "bestuntar",
    "bestuntávamos": "bestuntar",
    "bestuntávei": "bestuntar",
    "bestuntáveis": "bestuntar",
    "besugos": "besugo",
    "besunta": "besuntar",
    "besuntada": "besuntar",
    "besuntadas": "besuntar",
    "besuntadelas": "besuntadela",
    "besuntado": "besuntar",
    "besuntados": "besuntar",
    "besuntai": "besuntar",
    "besuntais": "besuntar",
    "besuntam": "besuntar",
    "besuntamo": "besuntar",
    "besuntamos": "besuntar",
    "besuntando": "besuntar",
    "besuntara": "besuntar",
    "besuntaram": "besuntar",
    "besuntaras": "besuntar",
    "besuntarde": "besuntar",
    "besuntardes": "besuntar",
    "besuntare": "besuntar",
    "besuntarei": "besuntar",
    "besuntareis": "besuntar",
    "besuntarem": "besuntar",
    "besuntaremos": "besuntar",
    "besuntares": "besuntar",
    "besuntaria": "besuntar",
    "besuntariam": "besuntar",
    "besuntarias": "besuntar",
    "besuntarmo": "besuntar",
    "besuntarmos": "besuntar",
    "besuntará": "besuntar",
    "besuntarás": "besuntar",
    "besuntarão": "besuntar",
    "besuntaríamos": "besuntar",
    "besuntaríeis": "besuntar",
    "besuntas": "besuntar",
    "besuntasse": "besuntar",
    "besuntassem": "besuntar",
    "besuntasses": "besuntar",
    "besuntaste": "besuntar",
    "besuntastes": "besuntar",
    "besuntava": "besuntar",
    "besuntavam": "besuntar",
    "besuntavas": "besuntar",
    "besunte": "besuntar",
    "besuntei": "besuntar",
    "besunteis": "besuntar",
    "besuntem": "besuntar",
    "besuntemo": "besuntar",
    "besuntemos": "besuntar",
    "besuntes": "besuntar",
    "besunto": "besuntar",
    "besuntou": "besuntar",
    "besuntá": "besuntar",
    "besuntámo": "besuntar",
    "besuntámos": "besuntar",
    "besuntáramo": "besuntar",
    "besuntáramos": "besuntar",
    "besuntárei": "besuntar",
    "besuntáreis": "besuntar",
    "besuntásseis": "besuntar",
    "besuntássemos": "besuntar",
    "besuntávamo": "besuntar",
    "besuntávamos": "besuntar",
    "besuntávei": "besuntar",
    "besuntáveis": "besuntar",
    "besuntões": "besuntão",
    "beta": "beto",
    "betacismos": "betacismo",
    "betada": "betar",
    "betadas": "betar",
    "betado": "betar",
    "betados": "betar",
    "betai": "betar",
    "betais": "betar",
    "betam": "betar",
    "betamo": "betar",
    "betamos": "betar",
    "betando": "betar",
    "betara": "betar",
    "betaram": "betar",
    "betaras": "betar",
    "betardas": "betarda",
    "betarde": "betar",
    "betardes": "betar",
    "betare": "betar",
    "betarei": "betar",
    "betareis": "betar",
    "betarem": "betar",
    "betaremos": "betar",
    "betares": "betar",
    "betaria": "betar",
    "betariam": "betar",
    "betarias": "betar",
    "betarmo": "betar",
    "betarmos": "betar",
    "betará": "betar",
    "betarás": "betar",
    "betarão": "betar",
    "betaríamos": "betar",
    "betaríeis": "betar",
    "betas": "beto",
    "betasse": "betar",
    "betassem": "betar",
    "betasses": "betar",
    "betaste": "betar",
    "betastes": "betar",
    "betatrões": "betatrão",
    "betava": "betar",
    "betavam": "betar",
    "betavas": "betar",
    "bete": "betar",
    "betei": "betar",
    "beteis": "betar",
    "betem": "betar",
    "betemo": "betar",
    "betemos": "betar",
    "beterrabais": "beterrabal",
    "beterrabas": "beterraba",
    "betes": "betar",
    "betesgas": "betesga",
    "betilhos": "betilho",
    "betinha": "beto",
    "betinhas": "beto",
    "betinho": "beto",
    "betinhos": "beto",
    "betita": "beto",
    "betitas": "beto",
    "betito": "beto",
    "betitos": "beto",
    "betlemitas": "betlemita",
    "betles": "betle",
    "beto": "betar",
    "betoiras": "betoira",
    "betolácea": "betoláceo",
    "betoláceas": "betoláceo",
    "betoláceos": "betoláceo",
    "betolínea": "betolíneo",
    "betolíneas": "betolíneo",
    "betolíneos": "betolíneo",
    "betona": "betonar",
    "betonada": "betonar",
    "betonadas": "betonar",
    "betonado": "betonar",
    "betonados": "betonar",
    "betonagens": "betonagem",
    "betonai": "betonar",
    "betonais": "betonar",
    "betonam": "betonar",
    "betonamo": "betonar",
    "betonamos": "betonar",
    "betonando": "betonar",
    "betonara": "betonar",
    "betonaram": "betonar",
    "betonaras": "betonar",
    "betonarde": "betonar",
    "betonardes": "betonar",
    "betonare": "betonar",
    "betonarei": "betonar",
    "betonareis": "betonar",
    "betonarem": "betonar",
    "betonaremos": "betonar",
    "betonares": "betonar",
    "betonaria": "betonar",
    "betonariam": "betonar",
    "betonarias": "betonar",
    "betonarmo": "betonar",
    "betonarmos": "betonar",
    "betonará": "betonar",
    "betonarás": "betonar",
    "betonarão": "betonar",
    "betonaríamos": "betonar",
    "betonaríeis": "betonar",
    "betonas": "betonar",
    "betonasse": "betonar",
    "betonassem": "betonar",
    "betonasses": "betonar",
    "betonaste": "betonar",
    "betonastes": "betonar",
    "betonava": "betonar",
    "betonavam": "betonar",
    "betonavas": "betonar",
    "betone": "betonar",
    "betonei": "betonar",
    "betoneiras": "betoneira",
    "betoneis": "betonar",
    "betonem": "betonar",
    "betonemo": "betonar",
    "betonemos": "betonar",
    "betones": "betonar",
    "betonicinas": "betonicina",
    "betonilhas": "betonilha",
    "betono": "betonar",
    "betonou": "betonar",
    "betoná": "betonar",
    "betonámo": "betonar",
    "betonámos": "betonar",
    "betonáramo": "betonar",
    "betonáramos": "betonar",
    "betonárei": "betonar",
    "betonáreis": "betonar",
    "betonásseis": "betonar",
    "betonássemos": "betonar",
    "betonávamo": "betonar",
    "betonávamos": "betonar",
    "betonávei": "betonar",
    "betonáveis": "betonar",
    "betos": "beto",
    "betou": "betar",
    "betouras": "betoura",
    "betouros": "betouro",
    "betuma": "betumar",
    "betumada": "betumar",
    "betumadas": "betumar",
    "betumadeiras": "betumadeira",
    "betumado": "betumar",
    "betumados": "betumar",
    "betumai": "betumar",
    "betumais": "betumar",
    "betumam": "betumar",
    "betumamo": "betumar",
    "betumamos": "betumar",
    "betumando": "betumar",
    "betumara": "betumar",
    "betumaram": "betumar",
    "betumaras": "betumar",
    "betumarde": "betumar",
    "betumardes": "betumar",
    "betumare": "betumar",
    "betumarei": "betumar",
    "betumareis": "betumar",
    "betumarem": "betumar",
    "betumaremos": "betumar",
    "betumares": "betumar",
    "betumaria": "betumar",
    "betumariam": "betumar",
    "betumarias": "betumar",
    "betumarmo": "betumar",
    "betumarmos": "betumar",
    "betumará": "betumar",
    "betumarás": "betumar",
    "betumarão": "betumar",
    "betumaríamos": "betumar",
    "betumaríeis": "betumar",
    "betumas": "betumar",
    "betumasse": "betumar",
    "betumassem": "betumar",
    "betumasses": "betumar",
    "betumaste": "betumar",
    "betumastes": "betumar",
    "betumava": "betumar",
    "betumavam": "betumar",
    "betumavas": "betumar",
    "betume": "betumar",
    "betumei": "betumar",
    "betumeis": "betumar",
    "betumem": "betumar",
    "betumemo": "betumar",
    "betumemos": "betumar",
    "betumes": "betume",
    "betuminosa": "betuminoso",
    "betuminosas": "betuminoso",
    "betuminosos": "betuminoso",
    "betumo": "betumar",
    "betumou": "betumar",
    "betumá": "betumar",
    "betumámo": "betumar",
    "betumámos": "betumar",
    "betumáramo": "betumar",
    "betumáramos": "betumar",
    "betumárei": "betumar",
    "betumáreis": "betumar",
    "betumásseis": "betumar",
    "betumássemos": "betumar",
    "betumávamo": "betumar",
    "betumávamos": "betumar",
    "betumávei": "betumar",
    "betumáveis": "betumar",
    "betá": "betar",
    "betámo": "betar",
    "betámos": "betar",
    "betáramo": "betar",
    "betáramos": "betar",
    "betárei": "betar",
    "betáreis": "betar",
    "betásseis": "betar",
    "betássemos": "betar",
    "betávamo": "betar",
    "betávamos": "betar",
    "betávei": "betar",
    "betáveis": "betar",
    "betónicas": "betónica",
    "betões": "betão",
    "bexiga": "bexigar",
    "bexigada": "bexigar",
    "bexigadas": "bexigar",
    "bexigado": "bexigar",
    "bexigados": "bexigar",
    "bexigai": "bexigar",
    "bexigais": "bexigar",
    "bexigam": "bexigar",
    "bexigamo": "bexigar",
    "bexigamos": "bexigar",
    "bexigando": "bexigar",
    "bexigara": "bexigar",
    "bexigaram": "bexigar",
    "bexigaras": "bexigar",
    "bexigardes": "bexigar",
    "bexigarei": "bexigar",
    "bexigareis": "bexigar",
    "bexigarem": "bexigar",
    "bexigaremos": "bexigar",
    "bexigares": "bexigar",
    "bexigaria": "bexigar",
    "bexigariam": "bexigar",
    "bexigarias": "bexigar",
    "bexigarmo": "bexigar",
    "bexigarmos": "bexigar",
    "bexigará": "bexigar",
    "bexigarás": "bexigar",
    "bexigarão": "bexigar",
    "bexigaríamos": "bexigar",
    "bexigaríeis": "bexigar",
    "bexigas": "bexigar",
    "bexigasse": "bexigar",
    "bexigassem": "bexigar",
    "bexigasses": "bexigar",
    "bexigaste": "bexigar",
    "bexigastes": "bexigar",
    "bexigava": "bexigar",
    "bexigavam": "bexigar",
    "bexigavas": "bexigar",
    "bexigo": "bexigar",
    "bexigosa": "bexigoso",
    "bexigosas": "bexigoso",
    "bexigosos": "bexigoso",
    "bexigou": "bexigar",
    "bexigue": "bexigar",
    "bexiguei": "bexigar",
    "bexigueira": "bexigueiro",
    "bexigueiras": "bexigueiro",
    "bexigueiros": "bexigueiro",
    "bexigueis": "bexigar",
    "bexiguem": "bexigar",
    "bexiguemo": "bexigar",
    "bexiguemos": "bexigar",
    "bexiguenta": "bexiguento",
    "bexiguentas": "bexiguento",
    "bexiguentos": "bexiguento",
    "bexigues": "bexigar",
    "bexiguinha": "bexiga",
    "bexiguinhas": "bexiga",
    "bexiguita": "bexiga",
    "bexiguitas": "bexiga",
    "bexigámo": "bexigar",
    "bexigámos": "bexigar",
    "bexigáramo": "bexigar",
    "bexigáramos": "bexigar",
    "bexigáreis": "bexigar",
    "bexigásseis": "bexigar",
    "bexigássemos": "bexigar",
    "bexigávamo": "bexigar",
    "bexigávamos": "bexigar",
    "bexigáveis": "bexigar",
    "bexigões": "bexigão",
    "bezedores": "bezedor",
    "bezerra": "bezerro",
    "bezerradas": "bezerrada",
    "bezerras": "bezerro",
    "bezerrinha": "bezerro",
    "bezerrinhas": "bezerro",
    "bezerrinho": "bezerro",
    "bezerrinhos": "bezerro",
    "bezerrita": "bezerro",
    "bezerritas": "bezerro",
    "bezerrito": "bezerro",
    "bezerritos": "bezerro",
    "bezerros": "bezerro",
    "bezoantes": "bezoante",
    "bezoares": "bezoar",
    "beática": "beático",
    "beáticas": "beático",
    "beáticos": "beático",
    "beócios": "beócio",
    "biaculeada": "biaculeado",
    "biaculeadas": "biaculeado",
    "biaculeados": "biaculeado",
    "biafadas": "biafada",
    "bialada": "bialado",
    "bialadas": "bialado",
    "bialados": "bialado",
    "bianeja": "bianejo",
    "bianejas": "bianejo",
    "bianejos": "bianejo",
    "biangulada": "biangulado",
    "bianguladas": "biangulado",
    "biangulados": "biangulado",
    "biangulares": "biangular",
    "bianuais": "bianual",
    "biaristada": "biaristado",
    "biaristadas": "biaristado",
    "biaristados": "biaristado",
    "biarticulada": "biarticulado",
    "biarticuladas": "biarticulado",
    "biarticulados": "biarticulado",
    "biatómica": "biatómico",
    "biatómicas": "biatómico",
    "biatómicos": "biatómico",
    "biauriculada": "biauriculado",
    "biauriculadas": "biauriculado",
    "biauriculados": "biauriculado",
    "biauriculares": "biauricular",
    "biaxiais": "biaxial",
    "biaxilares": "biaxilar",
    "biaxífera": "biaxífero",
    "biaxíferas": "biaxífero",
    "biaxíferos": "biaxífero",
    "bibelotistas": "bibelotista",
    "bibelôs": "bibelô",
    "biberetes": "biberete",
    "biberões": "biberão",
    "bibes": "bibe",
    "bibichinhos": "bibichinho",
    "bibis": "bibi",
    "biblicismos": "biblicismo",
    "biblicistas": "biblicista",
    "biblioclastas": "biblioclasta",
    "bibliocleptas": "biblioclepta",
    "bibliofagias": "bibliofagia",
    "bibliofilias": "bibliofilia",
    "bibliofobias": "bibliofobia",
    "bibliografa": "bibliografar",
    "bibliografada": "bibliografar",
    "bibliografadas": "bibliografar",
    "bibliografado": "bibliografar",
    "bibliografados": "bibliografar",
    "bibliografai": "bibliografar",
    "bibliografais": "bibliografar",
    "bibliografam": "bibliografar",
    "bibliografamo": "bibliografar",
    "bibliografamos": "bibliografar",
    "bibliografando": "bibliografar",
    "bibliografara": "bibliografar",
    "bibliografaram": "bibliografar",
    "bibliografaras": "bibliografar",
    "bibliografarde": "bibliografar",
    "bibliografardes": "bibliografar",
    "bibliografare": "bibliografar",
    "bibliografarei": "bibliografar",
    "bibliografareis": "bibliografar",
    "bibliografarem": "bibliografar",
    "bibliografaremos": "bibliografar",
    "bibliografares": "bibliografar",
    "bibliografaria": "bibliografar",
    "bibliografariam": "bibliografar",
    "bibliografarias": "bibliografar",
    "bibliografarmo": "bibliografar",
    "bibliografarmos": "bibliografar",
    "bibliografará": "bibliografar",
    "bibliografarás": "bibliografar",
    "bibliografarão": "bibliografar",
    "bibliografaríamos": "bibliografar",
    "bibliografaríeis": "bibliografar",
    "bibliografas": "bibliografar",
    "bibliografasse": "bibliografar",
    "bibliografassem": "bibliografar",
    "bibliografasses": "bibliografar",
    "bibliografaste": "bibliografar",
    "bibliografastes": "bibliografar",
    "bibliografava": "bibliografar",
    "bibliografavam": "bibliografar",
    "bibliografavas": "bibliografar",
    "bibliografe": "bibliografar",
    "bibliografei": "bibliografar",
    "bibliografeis": "bibliografar",
    "bibliografem": "bibliografar",
    "bibliografemo": "bibliografar",
    "bibliografemos": "bibliografar",
    "bibliografes": "bibliografar",
    "bibliografias": "bibliografia",
    "bibliografo": "bibliografar",
    "bibliografou": "bibliografar",
    "bibliografá": "bibliografar",
    "bibliografámo": "bibliografar",
    "bibliografámos": "bibliografar",
    "bibliografáramo": "bibliografar",
    "bibliografáramos": "bibliografar",
    "bibliografárei": "bibliografar",
    "bibliografáreis": "bibliografar",
    "bibliografásseis": "bibliografar",
    "bibliografássemos": "bibliografar",
    "bibliografávamo": "bibliografar",
    "bibliografávamos": "bibliografar",
    "bibliografávei": "bibliografar",
    "bibliografáveis": "bibliografar",
    "bibliográfica": "bibliográfico",
    "bibliográficas": "bibliográfico",
    "bibliográficos": "bibliográfico",
    "bibliologias": "bibliologia",
    "bibliomancias": "bibliomancia",
    "bibliomanias": "bibliomania",
    "bibliomantes": "bibliomante",
    "bibliomaníaca": "bibliomaníaco",
    "bibliomaníacas": "bibliomaníaco",
    "bibliomaníacos": "bibliomaníaco",
    "bibliomântica": "bibliomântico",
    "bibliomânticas": "bibliomântico",
    "bibliomânticos": "bibliomântico",
    "biblionímias": "biblionímia",
    "biblionímica": "biblionímico",
    "biblionímicas": "biblionímico",
    "biblionímicos": "biblionímico",
    "bibliopiratarias": "bibliopirataria",
    "bibliopiratas": "bibliopirata",
    "bibliopolas": "bibliopola",
    "bibliorreias": "bibliorreia",
    "bibliotecas": "biblioteca",
    "bibliotecnias": "bibliotecnia",
    "biblioteconomias": "biblioteconomia",
    "bibliotecária": "bibliotecário",
    "bibliotecárias": "bibliotecário",
    "bibliotecários": "bibliotecário",
    "bibliotecónoma": "bibliotecónomo",
    "bibliotecónomas": "bibliotecónomo",
    "bibliotecónomos": "bibliotecónomo",
    "bibliotáfios": "bibliotáfio",
    "bibliotécnica": "bibliotécnico",
    "bibliotécnicas": "bibliotécnico",
    "bibliotécnicos": "bibliotécnico",
    "biblistas": "biblista",
    "bibliátricas": "bibliátrica",
    "bibliófaga": "bibliófago",
    "bibliófagas": "bibliófago",
    "bibliófagos": "bibliófago",
    "bibliófila": "bibliófilo",
    "bibliófilas": "bibliófilo",
    "bibliófilos": "bibliófilo",
    "bibliófoba": "bibliófobo",
    "bibliófobas": "bibliófobo",
    "bibliófobos": "bibliófobo",
    "bibliógrafa": "bibliógrafo",
    "bibliógrafas": "bibliógrafo",
    "bibliógrafos": "bibliógrafo",
    "biblióloga": "bibliólogo",
    "bibliólogas": "bibliólogo",
    "bibliólogos": "bibliólogo",
    "bibliómana": "bibliómano",
    "bibliómanas": "bibliómano",
    "bibliómanos": "bibliómano",
    "bibliónimos": "bibliónimo",
    "biblíaca": "biblíaco",
    "biblíacas": "biblíaco",
    "biblíacos": "biblíaco",
    "biblísticas": "biblística",
    "bibos": "bibo",
    "bibras": "bibra",
    "bibóis": "bibói",
    "bibós": "bibó",
    "bica": "bicar",
    "bicada": "bicar",
    "bicadas": "bicar",
    "bicado": "bicar",
    "bicados": "bicar",
    "bicai": "bicar",
    "bicais": "bicar",
    "bicam": "bicar",
    "bicamo": "bicar",
    "bicamos": "bicar",
    "bicampeã": "bicampeão",
    "bicampeãs": "bicampeão",
    "bicampeões": "bicampeão",
    "bicancas": "bicanca",
    "bicancras": "bicancra",
    "bicancuda": "bicancudo",
    "bicancudas": "bicancudo",
    "bicancudos": "bicancudo",
    "bicando": "bicar",
    "bicanços": "bicanço",
    "bicapsulada": "bicapsulado",
    "bicapsuladas": "bicapsulado",
    "bicapsulados": "bicapsulado",
    "bicapsulares": "bicapsular",
    "bicara": "bicar",
    "bicaram": "bicar",
    "bicaras": "bicar",
    "bicarbonatos": "bicarbonato",
    "bicarde": "bicar",
    "bicardes": "bicar",
    "bicare": "bicar",
    "bicarei": "bicar",
    "bicareis": "bicar",
    "bicarem": "bicar",
    "bicaremos": "bicar",
    "bicares": "bicar",
    "bicaria": "bicar",
    "bicariam": "bicar",
    "bicarias": "bicar",
    "bicarmo": "bicar",
    "bicarmos": "bicar",
    "bicarpelada": "bicarpelado",
    "bicarpeladas": "bicarpelado",
    "bicarpelados": "bicarpelado",
    "bicará": "bicar",
    "bicarás": "bicar",
    "bicarão": "bicar",
    "bicaríamos": "bicar",
    "bicaríeis": "bicar",
    "bicas": "bicar",
    "bicasse": "bicar",
    "bicassem": "bicar",
    "bicasses": "bicar",
    "bicaste": "bicar",
    "bicastes": "bicar",
    "bicaudada": "bicaudado",
    "bicaudadas": "bicaudado",
    "bicaudados": "bicaudado",
    "bicava": "bicar",
    "bicavam": "bicar",
    "bicavas": "bicar",
    "bicazinha": "bica",
    "bicazinhas": "bica",
    "bicazita": "bica",
    "bicazitas": "bica",
    "bicelulares": "bicelular",
    "bicentenária": "bicentenário",
    "bicentenárias": "bicentenário",
    "bicentenários": "bicentenário",
    "bicha": "bicho",
    "bichada": "bichar",
    "bichadas": "bichar",
    "bichado": "bichar",
    "bichados": "bichar",
    "bichai": "bichar",
    "bichais": "bichar",
    "bicham": "bichar",
    "bichamo": "bichar",
    "bichamos": "bichar",
    "bichana": "bichano",
    "bichanada": "bichanar",
    "bichanadas": "bichanar",
    "bichanado": "bichanar",
    "bichanados": "bichanar",
    "bichanai": "bichanar",
    "bichanais": "bichanar",
    "bichanam": "bichanar",
    "bichanamo": "bichanar",
    "bichanamos": "bichanar",
    "bichanando": "bichanar",
    "bichanara": "bichanar",
    "bichanaram": "bichanar",
    "bichanaras": "bichanar",
    "bichanardes": "bichanar",
    "bichanarei": "bichanar",
    "bichanareis": "bichanar",
    "bichanarem": "bichanar",
    "bichanaremos": "bichanar",
    "bichanares": "bichanar",
    "bichanaria": "bichanar",
    "bichanariam": "bichanar",
    "bichanarias": "bichanar",
    "bichanarmo": "bichanar",
    "bichanarmos": "bichanar",
    "bichanará": "bichanar",
    "bichanarás": "bichanar",
    "bichanarão": "bichanar",
    "bichanaríamos": "bichanar",
    "bichanaríeis": "bichanar",
    "bichanas": "bichano",
    "bichanasse": "bichanar",
    "bichanassem": "bichanar",
    "bichanasses": "bichanar",
    "bichanaste": "bichanar",
    "bichanastes": "bichanar",
    "bichanava": "bichanar",
    "bichanavam": "bichanar",
    "bichanavas": "bichanar",
    "bichando": "bichar",
    "bichane": "bichanar",
    "bichanei": "bichanar",
    "bichaneira": "bichaneiro",
    "bichaneiras": "bichaneiro",
    "bichaneiros": "bichaneiro",
    "bichaneis": "bichanar",
    "bichanem": "bichanar",
    "bichanemo": "bichanar",
    "bichanemos": "bichanar",
    "bichanes": "bichanar",
    "bichanices": "bichanice",
    "bichaninha": "bichano",
    "bichaninhas": "bichano",
    "bichaninho": "bichano",
    "bichaninhos": "bichano",
    "bichanita": "bichano",
    "bichanitas": "bichano",
    "bichanito": "bichano",
    "bichanitos": "bichano",
    "bichano": "bichanar",
    "bichanos": "bichano",
    "bichanou": "bichanar",
    "bichanámo": "bichanar",
    "bichanámos": "bichanar",
    "bichanáramo": "bichanar",
    "bichanáramos": "bichanar",
    "bichanáreis": "bichanar",
    "bichanásseis": "bichanar",
    "bichanássemos": "bichanar",
    "bichanávamo": "bichanar",
    "bichanávamos": "bichanar",
    "bichanáveis": "bichanar",
    "bichara": "bichar",
    "bicharadas": "bicharada",
    "bicharam": "bichar",
    "bicharas": "bichar",
    "bichardes": "bichar",
    "bicharedos": "bicharedo",
    "bicharei": "bichar",
    "bichareis": "bichar",
    "bicharem": "bichar",
    "bicharemos": "bichar",
    "bicharengos": "bicharengo",
    "bichares": "bichar",
    "bicharia": "bichar",
    "bichariam": "bichar",
    "bicharias": "bicharia",
    "bicharmo": "bichar",
    "bicharmos": "bichar",
    "bicharocas": "bicharoca",
    "bicharocos": "bicharoco",
    "bicharrona": "bicharrão",
    "bicharronas": "bicharrão",
    "bicharrões": "bicharrão",
    "bichará": "bichar",
    "bicharás": "bichar",
    "bicharão": "bichar",
    "bicharíamos": "bichar",
    "bicharíeis": "bichar",
    "bichas": "bicho",
    "bichasse": "bichar",
    "bichassem": "bichar",
    "bichasses": "bichar",
    "bichaste": "bichar",
    "bichastes": "bichar",
    "bichava": "bichar",
    "bichavam": "bichar",
    "bichavas": "bichar",
    "biche": "bichar",
    "bichei": "bichar",
    "bicheiras": "bicheira",
    "bicheiros": "bicheiro",
    "bicheis": "bichar",
    "bichem": "bichar",
    "bichemo": "bichar",
    "bichemos": "bichar",
    "bichenta": "bichento",
    "bichentas": "bichento",
    "bichentos": "bichento",
    "biches": "bichar",
    "bichezas": "bicheza",
    "bichices": "bichice",
    "bichinha": "bicho",
    "bichinhas": "bicho",
    "bichinho": "bicho",
    "bichinhos": "bicho",
    "bichita": "bicho",
    "bichitas": "bicho",
    "bichito": "bicho",
    "bichitos": "bicho",
    "bicho": "bichar",
    "bichoca": "bichoco",
    "bichocas": "bichoco",
    "bichocos": "bichoco",
    "bichoiros": "bichoiro",
    "bichona": "bichão",
    "bichonas": "bichona",
    "bichos": "bicho",
    "bichosa": "bichoso",
    "bichosas": "bichoso",
    "bichosos": "bichoso",
    "bichou": "bichar",
    "bichouros": "bichouro",
    "bichámo": "bichar",
    "bichámos": "bichar",
    "bicháramo": "bichar",
    "bicháramos": "bichar",
    "bicháreis": "bichar",
    "bichásseis": "bichar",
    "bichássemos": "bichar",
    "bichávamo": "bichar",
    "bichávamos": "bichar",
    "bicháveis": "bichar",
    "bichões": "bichão",
    "bicicletas": "bicicleta",
    "biciclete": "bicicleta",
    "bicicletes": "bicicleta",
    "biciclistas": "biciclista",
    "bicipitais": "bicipital",
    "bicloretos": "bicloreto",
    "bico": "bicar",
    "bicolors": "bicolor",
    "biconjugada": "biconjugado",
    "biconjugadas": "biconjugado",
    "biconjugados": "biconjugado",
    "biconvexa": "biconvexo",
    "biconvexas": "biconvexo",
    "biconvexos": "biconvexo",
    "bicornes": "bicorne",
    "bicornígera": "bicornígero",
    "bicornígeras": "bicornígero",
    "bicornígeros": "bicornígero",
    "bicos": "bico",
    "bicou": "bicar",
    "bicromada": "bicromado",
    "bicromadas": "bicromado",
    "bicromados": "bicromado",
    "bicromias": "bicromia",
    "bicuda": "bicudo",
    "bicudas": "bicudo",
    "bicudos": "bicudo",
    "bicá": "bicar",
    "bicámo": "bicar",
    "bicámos": "bicar",
    "bicáramo": "bicar",
    "bicáramos": "bicar",
    "bicárei": "bicar",
    "bicáreis": "bicar",
    "bicásseis": "bicar",
    "bicássemos": "bicar",
    "bicávamo": "bicar",
    "bicávamos": "bicar",
    "bicávei": "bicar",
    "bicáveis": "bicar",
    "bicéfala": "bicéfalo",
    "bicéfalas": "bicéfalo",
    "bicéfalos": "bicéfalo",
    "bicípites": "bicípite",
    "bicórnea": "bicórneo",
    "bicórneas": "bicórneo",
    "bicórneos": "bicórneo",
    "bicôncava": "bicôncavo",
    "bicôncavas": "bicôncavo",
    "bicôncavos": "bicôncavo",
    "bicúspides": "bicúspide",
    "bidentada": "bidentado",
    "bidentadas": "bidentado",
    "bidentados": "bidentado",
    "bidentes": "bidente",
    "bidestilada": "bidestilado",
    "bidestiladas": "bidestilado",
    "bidestilados": "bidestilado",
    "bidigitada": "bidigitado",
    "bidigitadas": "bidigitado",
    "bidigitados": "bidigitado",
    "bidimensionais": "bidimensional",
    "bidireccionais": "bidireccional",
    "bidoeiros": "bidoeiro",
    "bidés": "bidé",
    "bidões": "bidão",
    "biebdomadária": "biebdomadário",
    "biebdomadárias": "biebdomadário",
    "biebdomadários": "biebdomadário",
    "bielas": "biela",
    "bielorrussa": "bielorrusso",
    "bielorrussas": "bielorrusso",
    "bielorrussos": "bielorrusso",
    "biena": "bieno",
    "bienais": "bienal",
    "bienas": "bieno",
    "bienos": "bieno",
    "bifa": "bifar",
    "bifaciais": "bifacial",
    "bifada": "bifar",
    "bifadas": "bifar",
    "bifado": "bifar",
    "bifados": "bifar",
    "bifai": "bifar",
    "bifais": "bifar",
    "bifalhadas": "bifalhada",
    "bifam": "bifar",
    "bifamo": "bifar",
    "bifamos": "bifar",
    "bifanas": "bifana",
    "bifando": "bifar",
    "bifara": "bifar",
    "bifaram": "bifar",
    "bifaras": "bifar",
    "bifarde": "bifar",
    "bifardes": "bifar",
    "bifare": "bifar",
    "bifarei": "bifar",
    "bifareis": "bifar",
    "bifarem": "bifar",
    "bifaremos": "bifar",
    "bifares": "bifar",
    "bifaria": "bifar",
    "bifariam": "bifar",
    "bifarias": "bifar",
    "bifarmo": "bifar",
    "bifarmos": "bifar",
    "bifarpada": "bifarpado",
    "bifarpadas": "bifarpado",
    "bifarpados": "bifarpado",
    "bifará": "bifar",
    "bifarás": "bifar",
    "bifarão": "bifar",
    "bifaríamos": "bifar",
    "bifaríeis": "bifar",
    "bifas": "bifar",
    "bifasse": "bifar",
    "bifassem": "bifar",
    "bifasses": "bifar",
    "bifaste": "bifar",
    "bifastes": "bifar",
    "bifava": "bifar",
    "bifavam": "bifar",
    "bifavas": "bifar",
    "bife": "bifar",
    "bifei": "bifar",
    "bifeiras": "bifeira",
    "bifeis": "bifar",
    "bifem": "bifar",
    "bifemo": "bifar",
    "bifemos": "bifar",
    "bifendida": "bifendido",
    "bifendidas": "bifendido",
    "bifendidos": "bifendido",
    "bifes": "bife",
    "bifesteques": "bifesteque",
    "bifinho": "bife",
    "bifinhos": "bife",
    "bifito": "bife",
    "bifitos": "bife",
    "biflexa": "biflexo",
    "biflexas": "biflexo",
    "biflexos": "biflexo",
    "biflora": "bifloro",
    "bifloras": "bifloro",
    "bifloros": "bifloro",
    "bifo": "bifar",
    "bifocais": "bifocal",
    "bifoliada": "bifoliado",
    "bifoliadas": "bifoliado",
    "bifoliados": "bifoliado",
    "bifonias": "bifonia",
    "biformes": "biforme",
    "bifou": "bifar",
    "bifrontes": "bifronte",
    "bifurca": "bifurcar",
    "bifurcada": "bifurcar",
    "bifurcadas": "bifurcar",
    "bifurcado": "bifurcar",
    "bifurcados": "bifurcar",
    "bifurcai": "bifurcar",
    "bifurcais": "bifurcar",
    "bifurcam": "bifurcar",
    "bifurcamo": "bifurcar",
    "bifurcamos": "bifurcar",
    "bifurcando": "bifurcar",
    "bifurcara": "bifurcar",
    "bifurcaram": "bifurcar",
    "bifurcaras": "bifurcar",
    "bifurcarde": "bifurcar",
    "bifurcardes": "bifurcar",
    "bifurcare": "bifurcar",
    "bifurcarei": "bifurcar",
    "bifurcareis": "bifurcar",
    "bifurcarem": "bifurcar",
    "bifurcaremos": "bifurcar",
    "bifurcares": "bifurcar",
    "bifurcaria": "bifurcar",
    "bifurcariam": "bifurcar",
    "bifurcarias": "bifurcar",
    "bifurcarmo": "bifurcar",
    "bifurcarmos": "bifurcar",
    "bifurcará": "bifurcar",
    "bifurcarás": "bifurcar",
    "bifurcarão": "bifurcar",
    "bifurcaríamos": "bifurcar",
    "bifurcaríeis": "bifurcar",
    "bifurcas": "bifurcar",
    "bifurcasse": "bifurcar",
    "bifurcassem": "bifurcar",
    "bifurcasses": "bifurcar",
    "bifurcaste": "bifurcar",
    "bifurcastes": "bifurcar",
    "bifurcava": "bifurcar",
    "bifurcavam": "bifurcar",
    "bifurcavas": "bifurcar",
    "bifurcações": "bifurcação",
    "bifurco": "bifurcar",
    "bifurcou": "bifurcar",
    "bifurcá": "bifurcar",
    "bifurcámo": "bifurcar",
    "bifurcámos": "bifurcar",
    "bifurcáramo": "bifurcar",
    "bifurcáramos": "bifurcar",
    "bifurcárei": "bifurcar",
    "bifurcáreis": "bifurcar",
    "bifurcásseis": "bifurcar",
    "bifurcássemos": "bifurcar",
    "bifurcávamo": "bifurcar",
    "bifurcávamos": "bifurcar",
    "bifurcávei": "bifurcar",
    "bifurcáveis": "bifurcar",
    "bifurque": "bifurcar",
    "bifurquei": "bifurcar",
    "bifurqueis": "bifurcar",
    "bifurquem": "bifurcar",
    "bifurquemo": "bifurcar",
    "bifurquemos": "bifurcar",
    "bifurques": "bifurcar",
    "bifá": "bifar",
    "bifámo": "bifar",
    "bifámos": "bifar",
    "bifáramo": "bifar",
    "bifáramos": "bifar",
    "bifárei": "bifar",
    "bifáreis": "bifar",
    "bifásseis": "bifar",
    "bifássemos": "bifar",
    "bifávamo": "bifar",
    "bifávamos": "bifar",
    "bifávei": "bifar",
    "bifáveis": "bifar",
    "bifólia": "bifólio",
    "bifólias": "bifólio",
    "bifólios": "bifólio",
    "bifónica": "bifónico",
    "bifónicas": "bifónico",
    "bifónicos": "bifónico",
    "bigamias": "bigamia",
    "bigamiza": "bigamizar",
    "bigamizada": "bigamizar",
    "bigamizadas": "bigamizar",
    "bigamizado": "bigamizar",
    "bigamizados": "bigamizar",
    "bigamizai": "bigamizar",
    "bigamizais": "bigamizar",
    "bigamizam": "bigamizar",
    "bigamizamo": "bigamizar",
    "bigamizamos": "bigamizar",
    "bigamizando": "bigamizar",
    "bigamizara": "bigamizar",
    "bigamizaram": "bigamizar",
    "bigamizaras": "bigamizar",
    "bigamizardes": "bigamizar",
    "bigamizarei": "bigamizar",
    "bigamizareis": "bigamizar",
    "bigamizarem": "bigamizar",
    "bigamizaremos": "bigamizar",
    "bigamizares": "bigamizar",
    "bigamizaria": "bigamizar",
    "bigamizariam": "bigamizar",
    "bigamizarias": "bigamizar",
    "bigamizarmo": "bigamizar",
    "bigamizarmos": "bigamizar",
    "bigamizará": "bigamizar",
    "bigamizarás": "bigamizar",
    "bigamizarão": "bigamizar",
    "bigamizaríamos": "bigamizar",
    "bigamizaríeis": "bigamizar",
    "bigamizas": "bigamizar",
    "bigamizasse": "bigamizar",
    "bigamizassem": "bigamizar",
    "bigamizasses": "bigamizar",
    "bigamizaste": "bigamizar",
    "bigamizastes": "bigamizar",
    "bigamizava": "bigamizar",
    "bigamizavam": "bigamizar",
    "bigamizavas": "bigamizar",
    "bigamize": "bigamizar",
    "bigamizei": "bigamizar",
    "bigamizeis": "bigamizar",
    "bigamizem": "bigamizar",
    "bigamizemo": "bigamizar",
    "bigamizemos": "bigamizar",
    "bigamizes": "bigamizar",
    "bigamizo": "bigamizar",
    "bigamizou": "bigamizar",
    "bigamizámo": "bigamizar",
    "bigamizámos": "bigamizar",
    "bigamizáramo": "bigamizar",
    "bigamizáramos": "bigamizar",
    "bigamizáreis": "bigamizar",
    "bigamizásseis": "bigamizar",
    "bigamizássemos": "bigamizar",
    "bigamizávamo": "bigamizar",
    "bigamizávamos": "bigamizar",
    "bigamizáveis": "bigamizar",
    "bigas": "biga",
    "bigeminada": "bigeminado",
    "bigeminadas": "bigeminado",
    "bigeminados": "bigeminado",
    "bigeminismos": "bigeminismo",
    "biglandulares": "biglandular",
    "biglandulosa": "biglanduloso",
    "biglandulosas": "biglanduloso",
    "biglandulosos": "biglanduloso",
    "biglas": "bigla",
    "bigles": "bigle",
    "biglobulares": "biglobular",
    "bignoniácea": "bignoniáceo",
    "bignoniáceas": "bignoniáceo",
    "bignoniáceos": "bignoniáceo",
    "bignónias": "bignónia",
    "bigodada": "bigodado",
    "bigodadas": "bigodado",
    "bigodados": "bigodado",
    "bigodeada": "bigodear",
    "bigodeadas": "bigodear",
    "bigodeado": "bigodear",
    "bigodeados": "bigodear",
    "bigodeai": "bigodear",
    "bigodeais": "bigodear",
    "bigodeamo": "bigodear",
    "bigodeamos": "bigodear",
    "bigodeando": "bigodear",
    "bigodeara": "bigodear",
    "bigodearam": "bigodear",
    "bigodearas": "bigodear",
    "bigodearde": "bigodear",
    "bigodeardes": "bigodear",
    "bigodeare": "bigodear",
    "bigodearei": "bigodear",
    "bigodeareis": "bigodear",
    "bigodearem": "bigodear",
    "bigodearemos": "bigodear",
    "bigodeares": "bigodear",
    "bigodearia": "bigodear",
    "bigodeariam": "bigodear",
    "bigodearias": "bigodear",
    "bigodearmo": "bigodear",
    "bigodearmos": "bigodear",
    "bigodeará": "bigodear",
    "bigodearás": "bigodear",
    "bigodearão": "bigodear",
    "bigodearíamos": "bigodear",
    "bigodearíeis": "bigodear",
    "bigodeasse": "bigodear",
    "bigodeassem": "bigodear",
    "bigodeasses": "bigodear",
    "bigodeaste": "bigodear",
    "bigodeastes": "bigodear",
    "bigodeava": "bigodear",
    "bigodeavam": "bigodear",
    "bigodeavas": "bigodear",
    "bigodeei": "bigodear",
    "bigodeeis": "bigodear",
    "bigodeemo": "bigodear",
    "bigodeemos": "bigodear",
    "bigodeia": "bigodear",
    "bigodeiam": "bigodear",
    "bigodeias": "bigodear",
    "bigodeie": "bigodear",
    "bigodeiem": "bigodear",
    "bigodeies": "bigodear",
    "bigodeio": "bigodear",
    "bigodeiras": "bigodeira",
    "bigodeou": "bigodear",
    "bigodes": "bigode",
    "bigodeá": "bigodear",
    "bigodeámo": "bigodear",
    "bigodeámos": "bigodear",
    "bigodeáramo": "bigodear",
    "bigodeáramos": "bigodear",
    "bigodeárei": "bigodear",
    "bigodeáreis": "bigodear",
    "bigodeásseis": "bigodear",
    "bigodeássemos": "bigodear",
    "bigodeávamo": "bigodear",
    "bigodeávamos": "bigodear",
    "bigodeávei": "bigodear",
    "bigodeáveis": "bigodear",
    "bigodinho": "bigode",
    "bigodinhos": "bigodinho",
    "bigodis": "bigodi",
    "bigodito": "bigode",
    "bigoditos": "bigode",
    "bigornas": "bigorna",
    "bigorrilhas": "bigorrilha",
    "bigotas": "bigota",
    "bigotismos": "bigotismo",
    "bigs": "big",
    "bigémea": "bigémeo",
    "bigémeas": "bigémeo",
    "bigémeos": "bigémeo",
    "bigénita": "bigénito",
    "bigénitas": "bigénito",
    "bigénitos": "bigénito",
    "bigúmia": "bigúmio",
    "bigúmias": "bigúmio",
    "bigúmios": "bigúmio",
    "bijagós": "bijagó",
    "bijecções": "bijecção",
    "bijuterias": "bijuteria",
    "bilabiada": "bilabiado",
    "bilabiadas": "bilabiado",
    "bilabiados": "bilabiado",
    "bilabiais": "bilabial",
    "bilaminada": "bilaminado",
    "bilaminadas": "bilaminado",
    "bilaminados": "bilaminado",
    "bilaterada": "bilaterado",
    "bilateradas": "bilaterado",
    "bilaterados": "bilaterado",
    "bilaterais": "bilateral",
    "bilbainha": "bilbainho",
    "bilbainhas": "bilbainho",
    "bilbainhos": "bilbainho",
    "bilbodes": "bilbode",
    "bilbuqués": "bilbuqué",
    "biles": "bile",
    "bilharda": "bilhardar",
    "bilhardada": "bilhardar",
    "bilhardadas": "bilhardar",
    "bilhardado": "bilhardar",
    "bilhardados": "bilhardar",
    "bilhardai": "bilhardar",
    "bilhardais": "bilhardar",
    "bilhardam": "bilhardar",
    "bilhardamo": "bilhardar",
    "bilhardamos": "bilhardar",
    "bilhardando": "bilhardar",
    "bilhardara": "bilhardar",
    "bilhardaram": "bilhardar",
    "bilhardaras": "bilhardar",
    "bilhardarde": "bilhardar",
    "bilhardardes": "bilhardar",
    "bilhardare": "bilhardar",
    "bilhardarei": "bilhardar",
    "bilhardareis": "bilhardar",
    "bilhardarem": "bilhardar",
    "bilhardaremos": "bilhardar",
    "bilhardares": "bilhardar",
    "bilhardaria": "bilhardar",
    "bilhardariam": "bilhardar",
    "bilhardarias": "bilhardar",
    "bilhardarmo": "bilhardar",
    "bilhardarmos": "bilhardar",
    "bilhardará": "bilhardar",
    "bilhardarás": "bilhardar",
    "bilhardarão": "bilhardar",
    "bilhardaríamos": "bilhardar",
    "bilhardaríeis": "bilhardar",
    "bilhardas": "bilhardar",
    "bilhardasse": "bilhardar",
    "bilhardassem": "bilhardar",
    "bilhardasses": "bilhardar",
    "bilhardaste": "bilhardar",
    "bilhardastes": "bilhardar",
    "bilhardava": "bilhardar",
    "bilhardavam": "bilhardar",
    "bilhardavas": "bilhardar",
    "bilharde": "bilhardar",
    "bilhardei": "bilhardar",
    "bilhardeira": "bilhardeiro",
    "bilhardeiras": "bilhardeiro",
    "bilhardeiros": "bilhardeiro",
    "bilhardeis": "bilhardar",
    "bilhardem": "bilhardar",
    "bilhardemo": "bilhardar",
    "bilhardemos": "bilhardar",
    "bilhardes": "bilhardar",
    "bilhardo": "bilhardar",
    "bilhardou": "bilhardar",
    "bilhardá": "bilhardar",
    "bilhardámo": "bilhardar",
    "bilhardámos": "bilhardar",
    "bilhardáramo": "bilhardar",
    "bilhardáramos": "bilhardar",
    "bilhardárei": "bilhardar",
    "bilhardáreis": "bilhardar",
    "bilhardásseis": "bilhardar",
    "bilhardássemos": "bilhardar",
    "bilhardávamo": "bilhardar",
    "bilhardávamos": "bilhardar",
    "bilhardávei": "bilhardar",
    "bilhardáveis": "bilhardar",
    "bilhares": "bilhar",
    "bilharistas": "bilharista",
    "bilharzioses": "bilharziose",
    "bilharzíases": "bilharzíase",
    "bilhas": "bilha",
    "bilhetadas": "bilhetada",
    "bilheteiras": "bilheteira",
    "bilheteiros": "bilheteiro",
    "bilhetes": "bilhete",
    "bilhetezinho": "bilhete",
    "bilhetezinhos": "bilhete",
    "bilhetezito": "bilhete",
    "bilhetezitos": "bilhete",
    "bilhetinho": "bilhete",
    "bilhetinhos": "bilhete",
    "bilhetito": "bilhete",
    "bilhetitos": "bilhete",
    "bilhinha": "bilha",
    "bilhinhas": "bilha",
    "bilhita": "bilha",
    "bilhitas": "bilha",
    "bilhostres": "bilhostre",
    "bilhárzias": "bilhárzia",
    "bilhão": "bilião",
    "bilhós": "bilhó",
    "bilhões": "bilião",
    "biliares": "biliar",
    "bilifulvinas": "bilifulvina",
    "bilifuscinas": "bilifuscina",
    "biligulada": "biligulado",
    "biliguladas": "biligulado",
    "biligulados": "biligulado",
    "bilimbis": "bilimbi",
    "bilingues": "bilingue",
    "bilinguismos": "bilinguismo",
    "bilionária": "bilionário",
    "bilionárias": "bilionário",
    "bilionários": "bilionário",
    "bilionésima": "bilionésimo",
    "bilionésimas": "bilionésimo",
    "bilionésimos": "bilionésimo",
    "biliosa": "bilioso",
    "biliosas": "bilioso",
    "biliosos": "bilioso",
    "bilirrubinas": "bilirrubina",
    "biliterais": "biliteral",
    "biliverdinas": "biliverdina",
    "biliária": "biliário",
    "biliárias": "biliário",
    "biliários": "biliário",
    "biliões": "bilião",
    "bilobada": "bilobado",
    "bilobadas": "bilobado",
    "bilobados": "bilobado",
    "bilocações": "bilocação",
    "biloculares": "bilocular",
    "bilogias": "bilogia",
    "bilontra": "bilontro",
    "bilontrada": "bilontrar",
    "bilontradas": "bilontrar",
    "bilontrado": "bilontrar",
    "bilontrados": "bilontrar",
    "bilontragens": "bilontragem",
    "bilontrai": "bilontrar",
    "bilontrais": "bilontrar",
    "bilontram": "bilontrar",
    "bilontramo": "bilontrar",
    "bilontramos": "bilontrar",
    "bilontrando": "bilontrar",
    "bilontrara": "bilontrar",
    "bilontraram": "bilontrar",
    "bilontraras": "bilontrar",
    "bilontrardes": "bilontrar",
    "bilontrarei": "bilontrar",
    "bilontrareis": "bilontrar",
    "bilontrarem": "bilontrar",
    "bilontraremos": "bilontrar",
    "bilontrares": "bilontrar",
    "bilontraria": "bilontrar",
    "bilontrariam": "bilontrar",
    "bilontrarias": "bilontrar",
    "bilontrarmo": "bilontrar",
    "bilontrarmos": "bilontrar",
    "bilontrará": "bilontrar",
    "bilontrarás": "bilontrar",
    "bilontrarão": "bilontrar",
    "bilontraríamos": "bilontrar",
    "bilontraríeis": "bilontrar",
    "bilontras": "bilontro",
    "bilontrasse": "bilontrar",
    "bilontrassem": "bilontrar",
    "bilontrasses": "bilontrar",
    "bilontraste": "bilontrar",
    "bilontrastes": "bilontrar",
    "bilontrava": "bilontrar",
    "bilontravam": "bilontrar",
    "bilontravas": "bilontrar",
    "bilontre": "bilontrar",
    "bilontrei": "bilontrar",
    "bilontreis": "bilontrar",
    "bilontrem": "bilontrar",
    "bilontremo": "bilontrar",
    "bilontremos": "bilontrar",
    "bilontres": "bilontrar",
    "bilontro": "bilontrar",
    "bilontros": "bilontro",
    "bilontrou": "bilontrar",
    "bilontrámo": "bilontrar",
    "bilontrámos": "bilontrar",
    "bilontráramo": "bilontrar",
    "bilontráramos": "bilontrar",
    "bilontráreis": "bilontrar",
    "bilontrásseis": "bilontrar",
    "bilontrássemos": "bilontrar",
    "bilontrávamo": "bilontrar",
    "bilontrávamos": "bilontrar",
    "bilontráveis": "bilontrar",
    "bilra": "bilrar",
    "bilrada": "bilrar",
    "bilradas": "bilrar",
    "bilrado": "bilrar",
    "bilrados": "bilrar",
    "bilrai": "bilrar",
    "bilrais": "bilrar",
    "bilram": "bilrar",
    "bilramo": "bilrar",
    "bilramos": "bilrar",
    "bilrando": "bilrar",
    "bilrara": "bilrar",
    "bilraram": "bilrar",
    "bilraras": "bilrar",
    "bilrardes": "bilrar",
    "bilrarei": "bilrar",
    "bilrareis": "bilrar",
    "bilrarem": "bilrar",
    "bilraremos": "bilrar",
    "bilrares": "bilrar",
    "bilraria": "bilrar",
    "bilrariam": "bilrar",
    "bilrarias": "bilrar",
    "bilrarmo": "bilrar",
    "bilrarmos": "bilrar",
    "bilrará": "bilrar",
    "bilrarás": "bilrar",
    "bilrarão": "bilrar",
    "bilraríamos": "bilrar",
    "bilraríeis": "bilrar",
    "bilras": "bilrar",
    "bilrasse": "bilrar",
    "bilrassem": "bilrar",
    "bilrasses": "bilrar",
    "bilraste": "bilrar",
    "bilrastes": "bilrar",
    "bilrava": "bilrar",
    "bilravam": "bilrar",
    "bilravas": "bilrar",
    "bilre": "bilrar",
    "bilrei": "bilrar",
    "bilreiras": "bilreira",
    "bilreiros": "bilreiro",
    "bilreis": "bilrar",
    "bilrem": "bilrar",
    "bilremo": "bilrar",
    "bilremos": "bilrar",
    "bilres": "bilrar",
    "bilro": "bilrar",
    "bilros": "bilro",
    "bilrou": "bilrar",
    "bilrámo": "bilrar",
    "bilrámos": "bilrar",
    "bilráramo": "bilrar",
    "bilráramos": "bilrar",
    "bilráreis": "bilrar",
    "bilrásseis": "bilrar",
    "bilrássemos": "bilrar",
    "bilrávamo": "bilrar",
    "bilrávamos": "bilrar",
    "bilráveis": "bilrar",
    "biltra": "biltre",
    "biltragens": "biltragem",
    "biltrarias": "biltraria",
    "biltras": "biltre",
    "biltres": "biltre",
    "bilénia": "bilénio",
    "bilénias": "bilénio",
    "bilénios": "bilénio",
    "bilítera": "bilítero",
    "bilíteras": "bilítero",
    "bilíteros": "bilítero",
    "bima": "bimo",
    "bimaculada": "bimaculado",
    "bimaculadas": "bimaculado",
    "bimaculados": "bimaculado",
    "bimares": "bimare",
    "bimarginada": "bimarginado",
    "bimarginadas": "bimarginado",
    "bimarginados": "bimarginado",
    "bimas": "bimo",
    "bimba": "bimbo",
    "bimbada": "bimbar",
    "bimbadas": "bimbar",
    "bimbado": "bimbar",
    "bimbados": "bimbar",
    "bimbaduras": "bimbadura",
    "bimbai": "bimbar",
    "bimbais": "bimbar",
    "bimbalha": "bimbalhar",
    "bimbalhada": "bimbalhar",
    "bimbalhadas": "bimbalhar",
    "bimbalhado": "bimbalhar",
    "bimbalhados": "bimbalhar",
    "bimbalhai": "bimbalhar",
    "bimbalhais": "bimbalhar",
    "bimbalham": "bimbalhar",
    "bimbalhamo": "bimbalhar",
    "bimbalhamos": "bimbalhar",
    "bimbalhando": "bimbalhar",
    "bimbalhara": "bimbalhar",
    "bimbalharam": "bimbalhar",
    "bimbalharas": "bimbalhar",
    "bimbalhardes": "bimbalhar",
    "bimbalharei": "bimbalhar",
    "bimbalhareis": "bimbalhar",
    "bimbalharem": "bimbalhar",
    "bimbalharemos": "bimbalhar",
    "bimbalhares": "bimbalhar",
    "bimbalharia": "bimbalhar",
    "bimbalhariam": "bimbalhar",
    "bimbalharias": "bimbalhar",
    "bimbalharmo": "bimbalhar",
    "bimbalharmos": "bimbalhar",
    "bimbalhará": "bimbalhar",
    "bimbalharás": "bimbalhar",
    "bimbalharão": "bimbalhar",
    "bimbalharíamos": "bimbalhar",
    "bimbalharíeis": "bimbalhar",
    "bimbalhas": "bimbalhar",
    "bimbalhasse": "bimbalhar",
    "bimbalhassem": "bimbalhar",
    "bimbalhasses": "bimbalhar",
    "bimbalhaste": "bimbalhar",
    "bimbalhastes": "bimbalhar",
    "bimbalhava": "bimbalhar",
    "bimbalhavam": "bimbalhar",
    "bimbalhavas": "bimbalhar",
    "bimbalhe": "bimbalhar",
    "bimbalhei": "bimbalhar",
    "bimbalheis": "bimbalhar",
    "bimbalhem": "bimbalhar",
    "bimbalhemo": "bimbalhar",
    "bimbalhemos": "bimbalhar",
    "bimbalhes": "bimbalhar",
    "bimbalho": "bimbalhar",
    "bimbalhou": "bimbalhar",
    "bimbalhámo": "bimbalhar",
    "bimbalhámos": "bimbalhar",
    "bimbalháramo": "bimbalhar",
    "bimbalháramos": "bimbalhar",
    "bimbalháreis": "bimbalhar",
    "bimbalhásseis": "bimbalhar",
    "bimbalhássemos": "bimbalhar",
    "bimbalhávamo": "bimbalhar",
    "bimbalhávamos": "bimbalhar",
    "bimbalháveis": "bimbalhar",
    "bimbam": "bimbar",
    "bimbamo": "bimbar",
    "bimbamos": "bimbar",
    "bimbando": "bimbar",
    "bimbara": "bimbar",
    "bimbaram": "bimbar",
    "bimbaras": "bimbar",
    "bimbardes": "bimbar",
    "bimbarei": "bimbar",
    "bimbareis": "bimbar",
    "bimbarem": "bimbar",
    "bimbaremos": "bimbar",
    "bimbares": "bimbar",
    "bimbaria": "bimbar",
    "bimbariam": "bimbar",
    "bimbarias": "bimbar",
    "bimbarmo": "bimbar",
    "bimbarmos": "bimbar",
    "bimbarras": "bimbarra",
    "bimbarretas": "bimbarreta",
    "bimbará": "bimbar",
    "bimbarás": "bimbar",
    "bimbarão": "bimbar",
    "bimbaríamos": "bimbar",
    "bimbaríeis": "bimbar",
    "bimbas": "bimbo",
    "bimbasse": "bimbar",
    "bimbassem": "bimbar",
    "bimbasses": "bimbar",
    "bimbaste": "bimbar",
    "bimbastes": "bimbar",
    "bimbava": "bimbar",
    "bimbavam": "bimbar",
    "bimbavas": "bimbar",
    "bimbe": "bimbar",
    "bimbei": "bimbar",
    "bimbeis": "bimbar",
    "bimbem": "bimbar",
    "bimbemo": "bimbar",
    "bimbemos": "bimbar",
    "bimbes": "bimbar",
    "bimbo": "bimbar",
    "bimbos": "bimbo",
    "bimbou": "bimbar",
    "bimbámo": "bimbar",
    "bimbámos": "bimbar",
    "bimbáramo": "bimbar",
    "bimbáramos": "bimbar",
    "bimbáreis": "bimbar",
    "bimbásseis": "bimbar",
    "bimbássemos": "bimbar",
    "bimbávamo": "bimbar",
    "bimbávamos": "bimbar",
    "bimbáveis": "bimbar",
    "bimembres": "bimembre",
    "bimensais": "bimensal",
    "bimestrais": "bimestral",
    "bimestres": "bimestre",
    "bimetais": "bimetal",
    "bimetalismos": "bimetalismo",
    "bimetalistas": "bimetalista",
    "bimodais": "bimodal",
    "bimos": "bimo",
    "bimotores": "bimotor",
    "bina": "binar",
    "binada": "binar",
    "binadas": "binar",
    "binado": "binar",
    "binados": "binar",
    "binagens": "binagem",
    "binai": "binar",
    "binais": "binar",
    "binam": "binar",
    "binamo": "binar",
    "binamos": "binar",
    "binando": "binar",
    "binara": "binar",
    "binaram": "binar",
    "binaras": "binar",
    "binardes": "binar",
    "binarei": "binar",
    "binareis": "binar",
    "binarem": "binar",
    "binaremos": "binar",
    "binares": "binar",
    "binaria": "binar",
    "binariam": "binar",
    "binarias": "binar",
    "binarmo": "binar",
    "binarmos": "binar",
    "binará": "binar",
    "binarás": "binar",
    "binarão": "binar",
    "binaríamos": "binar",
    "binaríeis": "binar",
    "binas": "binar",
    "binascida": "binascido",
    "binascidas": "binascido",
    "binascidos": "binascido",
    "binasse": "binar",
    "binassem": "binar",
    "binasses": "binar",
    "binaste": "binar",
    "binastes": "binar",
    "binauriculares": "binauricular",
    "binava": "binar",
    "binavam": "binar",
    "binavas": "binar",
    "binações": "binação",
    "bindas": "binda",
    "bine": "binar",
    "binei": "binar",
    "bineis": "binar",
    "binem": "binar",
    "binemo": "binar",
    "binemos": "binar",
    "binervada": "binervado",
    "binervadas": "binervado",
    "binervados": "binervado",
    "bines": "binar",
    "bingos": "bingo",
    "bino": "binar",
    "binoculada": "binoculado",
    "binoculadas": "binoculado",
    "binoculados": "binoculado",
    "binoculares": "binocular",
    "binoculiza": "binoculizar",
    "binoculizada": "binoculizar",
    "binoculizadas": "binoculizar",
    "binoculizado": "binoculizar",
    "binoculizados": "binoculizar",
    "binoculizai": "binoculizar",
    "binoculizais": "binoculizar",
    "binoculizam": "binoculizar",
    "binoculizamo": "binoculizar",
    "binoculizamos": "binoculizar",
    "binoculizando": "binoculizar",
    "binoculizara": "binoculizar",
    "binoculizaram": "binoculizar",
    "binoculizaras": "binoculizar",
    "binoculizarde": "binoculizar",
    "binoculizardes": "binoculizar",
    "binoculizare": "binoculizar",
    "binoculizarei": "binoculizar",
    "binoculizareis": "binoculizar",
    "binoculizarem": "binoculizar",
    "binoculizaremos": "binoculizar",
    "binoculizares": "binoculizar",
    "binoculizaria": "binoculizar",
    "binoculizariam": "binoculizar",
    "binoculizarias": "binoculizar",
    "binoculizarmo": "binoculizar",
    "binoculizarmos": "binoculizar",
    "binoculizará": "binoculizar",
    "binoculizarás": "binoculizar",
    "binoculizarão": "binoculizar",
    "binoculizaríamos": "binoculizar",
    "binoculizaríeis": "binoculizar",
    "binoculizas": "binoculizar",
    "binoculizasse": "binoculizar",
    "binoculizassem": "binoculizar",
    "binoculizasses": "binoculizar",
    "binoculizaste": "binoculizar",
    "binoculizastes": "binoculizar",
    "binoculizava": "binoculizar",
    "binoculizavam": "binoculizar",
    "binoculizavas": "binoculizar",
    "binoculize": "binoculizar",
    "binoculizei": "binoculizar",
    "binoculizeis": "binoculizar",
    "binoculizem": "binoculizar",
    "binoculizemo": "binoculizar",
    "binoculizemos": "binoculizar",
    "binoculizes": "binoculizar",
    "binoculizo": "binoculizar",
    "binoculizou": "binoculizar",
    "binoculizá": "binoculizar",
    "binoculizámo": "binoculizar",
    "binoculizámos": "binoculizar",
    "binoculizáramo": "binoculizar",
    "binoculizáramos": "binoculizar",
    "binoculizárei": "binoculizar",
    "binoculizáreis": "binoculizar",
    "binoculizásseis": "binoculizar",
    "binoculizássemos": "binoculizar",
    "binoculizávamo": "binoculizar",
    "binoculizávamos": "binoculizar",
    "binoculizávei": "binoculizar",
    "binoculizáveis": "binoculizar",
    "binomiais": "binomial",
    "binominais": "binominal",
    "binou": "binar",
    "binucleada": "binucleado",
    "binucleadas": "binucleado",
    "binucleados": "binucleado",
    "binucleares": "binuclear",
    "binágios": "binágio",
    "binámo": "binar",
    "binámos": "binar",
    "bináramo": "binar",
    "bináramos": "binar",
    "bináreis": "binar",
    "binária": "binário",
    "binárias": "binário",
    "binários": "binário",
    "binásseis": "binar",
    "binássemos": "binar",
    "binávamo": "binar",
    "binávamos": "binar",
    "bináveis": "binar",
    "binérvea": "binérveo",
    "binérveas": "binérveo",
    "binérveos": "binérveo",
    "binóculos": "binóculo",
    "binómica": "binómico",
    "binómicas": "binómico",
    "binómicos": "binómico",
    "binómines": "binómine",
    "binómios": "binómio",
    "biobibliografias": "biobibliografia",
    "biobibliográfica": "biobibliográfico",
    "biobibliográficas": "biobibliográfico",
    "biobibliográficos": "biobibliográfico",
    "biocatalizadores": "biocatalizador",
    "biocolóides": "biocolóide",
    "biocombustíveis": "biocombustível",
    "biocompatibilidades": "biocompatibilidade",
    "biocos": "bioco",
    "biocrática": "biocrático",
    "biocráticas": "biocrático",
    "biocráticos": "biocrático",
    "biodegradabilidades": "biodegradabilidade",
    "biodegradáveis": "biodegradável",
    "biodinâmica": "biodinâmico",
    "biodinâmicas": "biodinâmico",
    "biodinâmicos": "biodinâmico",
    "biodiversidades": "biodiversidade",
    "bioelectricidades": "bioelectricidade",
    "bioenergias": "bioenergia",
    "bioenergéticas": "bioenergética",
    "bioesferas": "bioesfera",
    "bioestatísticas": "bioestatística",
    "biofobias": "biofobia",
    "biofísica": "biofísico",
    "biofísicas": "biofísico",
    "biofísicos": "biofísico",
    "biogases": "biogás",
    "biogenias": "biogenia",
    "biogenésica": "biogenésico",
    "biogenésicas": "biogenésico",
    "biogenésicos": "biogenésico",
    "biogenética": "biogenético",
    "biogenéticas": "biogenético",
    "biogenéticos": "biogenético",
    "biogeografias": "biogeografia",
    "biogeógrafa": "biogeógrafo",
    "biogeógrafas": "biogeógrafo",
    "biogeógrafos": "biogeógrafo",
    "biografa": "biografar",
    "biografada": "biografar",
    "biografadas": "biografar",
    "biografado": "biografar",
    "biografados": "biografar",
    "biografai": "biografar",
    "biografais": "biografar",
    "biografam": "biografar",
    "biografamo": "biografar",
    "biografamos": "biografar",
    "biografando": "biografar",
    "biografara": "biografar",
    "biografaram": "biografar",
    "biografaras": "biografar",
    "biografarde": "biografar",
    "biografardes": "biografar",
    "biografare": "biografar",
    "biografarei": "biografar",
    "biografareis": "biografar",
    "biografarem": "biografar",
    "biografaremos": "biografar",
    "biografares": "biografar",
    "biografaria": "biografar",
    "biografariam": "biografar",
    "biografarias": "biografar",
    "biografarmo": "biografar",
    "biografarmos": "biografar",
    "biografará": "biografar",
    "biografarás": "biografar",
    "biografarão": "biografar",
    "biografaríamos": "biografar",
    "biografaríeis": "biografar",
    "biografas": "biografar",
    "biografasse": "biografar",
    "biografassem": "biografar",
    "biografasses": "biografar",
    "biografaste": "biografar",
    "biografastes": "biografar",
    "biografava": "biografar",
    "biografavam": "biografar",
    "biografavas": "biografar",
    "biografe": "biografar",
    "biografei": "biografar",
    "biografeis": "biografar",
    "biografem": "biografar",
    "biografemo": "biografar",
    "biografemos": "biografar",
    "biografes": "biografar",
    "biografias": "biografia",
    "biografistas": "biografista",
    "biografo": "biografar",
    "biografou": "biografar",
    "biografá": "biografar",
    "biografámo": "biografar",
    "biografámos": "biografar",
    "biografáramo": "biografar",
    "biografáramos": "biografar",
    "biografárei": "biografar",
    "biografáreis": "biografar",
    "biografásseis": "biografar",
    "biografássemos": "biografar",
    "biografávamo": "biografar",
    "biografávamos": "biografar",
    "biografávei": "biografar",
    "biografáveis": "biografar",
    "biográfica": "biográfico",
    "biográficas": "biográfico",
    "biográficos": "biográfico",
    "biogéneses": "biogénese",
    "biologias": "biologia",
    "biologismos": "biologismo",
    "biologistas": "biologista",
    "bioluminescências": "bioluminescência",
    "biológica": "biológico",
    "biológicas": "biológico",
    "biológicos": "biológico",
    "biomagnetismos": "biomagnetismo",
    "biomassas": "biomassa",
    "biombos": "biombo",
    "biomecânicas": "biomecânica",
    "biometrias": "biometria",
    "biomédica": "biomédico",
    "biomédicas": "biomédico",
    "biomédicos": "biomédico",
    "biométrica": "biométrico",
    "biométricas": "biométrico",
    "biométricos": "biométrico",
    "bionoses": "bionose",
    "biopses": "biopse",
    "biopsias": "biopsia",
    "bioquices": "bioquice",
    "bioquímica": "bioquímico",
    "bioquímicas": "bioquímico",
    "bioquímicos": "bioquímico",
    "bioritmos": "bioritmo",
    "biosferas": "biosfera",
    "biostratigrafias": "biostratigrafia",
    "biostratigráfica": "biostratigráfico",
    "biostratigráficas": "biostratigráfico",
    "biostratigráficos": "biostratigráfico",
    "biostratígrafa": "biostratígrafo",
    "biostratígrafas": "biostratígrafo",
    "biostratígrafos": "biostratígrafo",
    "biotaxias": "biotaxia",
    "biotecnologias": "biotecnologia",
    "biotitas": "biotita",
    "biotites": "biotite",
    "biotopologias": "biotopologia",
    "biotopos": "biotopo",
    "biotérios": "biotério",
    "bioéticas": "bioética",
    "biparietais": "biparietal",
    "biparta": "bipartir",
    "bipartais": "bipartir",
    "bipartam": "bipartir",
    "bipartamo": "bipartir",
    "bipartamos": "bipartir",
    "bipartas": "bipartir",
    "biparte": "bipartir",
    "bipartem": "bipartir",
    "bipartes": "bipartir",
    "biparti": "bipartir",
    "bipartia": "bipartir",
    "bipartiam": "bipartir",
    "bipartias": "bipartir",
    "bipartida": "bipartir",
    "bipartidarismos": "bipartidarismo",
    "bipartidaristas": "bipartidarista",
    "bipartidas": "bipartir",
    "bipartido": "bipartir",
    "bipartidos": "bipartir",
    "bipartidária": "bipartidário",
    "bipartidárias": "bipartidário",
    "bipartidários": "bipartidário",
    "bipartimo": "bipartir",
    "bipartimos": "bipartir",
    "bipartindo": "bipartir",
    "bipartira": "bipartir",
    "bipartiram": "bipartir",
    "bipartiras": "bipartir",
    "bipartirde": "bipartir",
    "bipartirdes": "bipartir",
    "bipartire": "bipartir",
    "bipartirei": "bipartir",
    "bipartireis": "bipartir",
    "bipartirem": "bipartir",
    "bipartiremos": "bipartir",
    "bipartires": "bipartir",
    "bipartiria": "bipartir",
    "bipartiriam": "bipartir",
    "bipartirias": "bipartir",
    "bipartirmo": "bipartir",
    "bipartirmos": "bipartir",
    "bipartirá": "bipartir",
    "bipartirás": "bipartir",
    "bipartirão": "bipartir",
    "bipartiríamos": "bipartir",
    "bipartiríeis": "bipartir",
    "bipartis": "bipartir",
    "bipartisse": "bipartir",
    "bipartissem": "bipartir",
    "bipartisses": "bipartir",
    "bipartiste": "bipartir",
    "bipartistes": "bipartir",
    "bipartiu": "bipartir",
    "bipartições": "bipartição",
    "biparto": "bipartir",
    "bipartíamo": "bipartir",
    "bipartíamos": "bipartir",
    "bipartíei": "bipartir",
    "bipartíeis": "bipartir",
    "bipartíramo": "bipartir",
    "bipartíramos": "bipartir",
    "bipartírei": "bipartir",
    "bipartíreis": "bipartir",
    "bipartísseis": "bipartir",
    "bipartíssemos": "bipartir",
    "bipartíveis": "bipartível",
    "bipatentes": "bipatente",
    "bipenes": "bipene",
    "biperfurada": "biperfurado",
    "biperfuradas": "biperfurado",
    "biperfurados": "biperfurado",
    "bipes": "bip",
    "bipetais": "bipetal",
    "bipiramidais": "bipiramidal",
    "bipirâmides": "bipirâmide",
    "biplana": "biplano",
    "biplanas": "biplano",
    "biplanos": "biplano",
    "biplumes": "biplume",
    "bipolares": "bipolar",
    "bipolaridades": "bipolaridade",
    "bipolarizada": "bipolarizado",
    "bipolarizadas": "bipolarizado",
    "bipolarizados": "bipolarizado",
    "bipolarizações": "bipolarização",
    "biprismas": "biprisma",
    "bipés": "bipé",
    "bipétala": "bipétalo",
    "bipétalas": "bipétalo",
    "bipétalos": "bipétalo",
    "biquadrada": "biquadrado",
    "biquadradas": "biquadrado",
    "biquadrados": "biquadrado",
    "bique": "bicar",
    "biquei": "bicar",
    "biqueira": "biqueiro",
    "biqueiradas": "biqueirada",
    "biqueiras": "biqueiro",
    "biqueiros": "biqueiro",
    "biqueirões": "biqueirão",
    "biqueis": "bicar",
    "biquem": "bicar",
    "biquemo": "bicar",
    "biquemos": "bicar",
    "biques": "bicar",
    "biquinha": "bica",
    "biquinhas": "bica",
    "biquinho": "bico",
    "biquinhos": "bico",
    "biquinis": "biquini",
    "biquita": "bica",
    "biquitas": "bica",
    "biquito": "bico",
    "biquitos": "bico",
    "biquotidiana": "biquotidiano",
    "biquotidianas": "biquotidiano",
    "biquotidianos": "biquotidiano",
    "birbantes": "birbante",
    "biribíris": "biribíri",
    "birmanes": "birmane",
    "birmanesa": "birmanês",
    "birmanesas": "birmanês",
    "birmaneses": "birmanês",
    "birmãs": "birmã",
    "birra": "birrar",
    "birrada": "birrar",
    "birradas": "birrar",
    "birrado": "birrar",
    "birrados": "birrar",
    "birrai": "birrar",
    "birrais": "birrar",
    "birram": "birrar",
    "birramo": "birrar",
    "birramos": "birrar",
    "birrando": "birrar",
    "birrara": "birrar",
    "birraram": "birrar",
    "birraras": "birrar",
    "birrardes": "birrar",
    "birrarei": "birrar",
    "birrareis": "birrar",
    "birrarem": "birrar",
    "birraremos": "birrar",
    "birrares": "birrar",
    "birraria": "birrar",
    "birrariam": "birrar",
    "birrarias": "birrar",
    "birrarmo": "birrar",
    "birrarmos": "birrar",
    "birrará": "birrar",
    "birrarás": "birrar",
    "birrarão": "birrar",
    "birraríamos": "birrar",
    "birraríeis": "birrar",
    "birras": "birrar",
    "birrasse": "birrar",
    "birrassem": "birrar",
    "birrasses": "birrar",
    "birraste": "birrar",
    "birrastes": "birrar",
    "birrava": "birrar",
    "birravam": "birrar",
    "birravas": "birrar",
    "birre": "birrar",
    "birrefracções": "birrefracção",
    "birrefrangentes": "birrefrangente",
    "birrefrangências": "birrefrangência",
    "birrefringentes": "birrefringente",
    "birrefringências": "birrefringência",
    "birrei": "birrar",
    "birreis": "birrar",
    "birrem": "birrar",
    "birremes": "birreme",
    "birremo": "birrar",
    "birremos": "birrar",
    "birrenta": "birrento",
    "birrentas": "birrento",
    "birrentos": "birrento",
    "birres": "birre",
    "birro": "birrar",
    "birrostrada": "birrostrado",
    "birrostradas": "birrostrado",
    "birrostrados": "birrostrado",
    "birrou": "birrar",
    "birrámo": "birrar",
    "birrámos": "birrar",
    "birráramo": "birrar",
    "birráramos": "birrar",
    "birráreis": "birrar",
    "birrásseis": "birrar",
    "birrássemos": "birrar",
    "birrávamo": "birrar",
    "birrávamos": "birrar",
    "birráveis": "birrar",
    "birutas": "biruta",
    "birutices": "birutice",
    "bisa": "bisar",
    "bisada": "bisar",
    "bisadas": "bisar",
    "bisado": "bisar",
    "bisados": "bisar",
    "bisagras": "bisagra",
    "bisai": "bisar",
    "bisais": "bisar",
    "bisalhada": "bisalhado",
    "bisalhadas": "bisalhado",
    "bisalhados": "bisalhado",
    "bisalhos": "bisalho",
    "bisam": "bisar",
    "bisamo": "bisar",
    "bisamos": "bisar",
    "bisando": "bisar",
    "bisanuais": "bisanual",
    "bisara": "bisar",
    "bisaram": "bisar",
    "bisaras": "bisar",
    "bisarde": "bisar",
    "bisardes": "bisar",
    "bisare": "bisar",
    "bisarei": "bisar",
    "bisareis": "bisar",
    "bisarem": "bisar",
    "bisaremos": "bisar",
    "bisares": "bisar",
    "bisaria": "bisar",
    "bisariam": "bisar",
    "bisarias": "bisar",
    "bisarmas": "bisarma",
    "bisarmo": "bisar",
    "bisarmos": "bisar",
    "bisará": "bisar",
    "bisarás": "bisar",
    "bisarão": "bisar",
    "bisaríamos": "bisar",
    "bisaríeis": "bisar",
    "bisas": "bisar",
    "bisasse": "bisar",
    "bisassem": "bisar",
    "bisasses": "bisar",
    "bisaste": "bisar",
    "bisastes": "bisar",
    "bisava": "bisar",
    "bisavam": "bisar",
    "bisavas": "bisar",
    "bisavozinha": "bisavô",
    "bisavozinhas": "bisavô",
    "bisavozinho": "bisavô",
    "bisavozinhos": "bisavô",
    "bisavozita": "bisavô",
    "bisavozitas": "bisavô",
    "bisavozito": "bisavô",
    "bisavozitos": "bisavô",
    "bisavó": "bisavô",
    "bisavós": "bisavô",
    "bisavôs": "bisavô",
    "bisbilhota": "bisbilhotar",
    "bisbilhotada": "bisbilhotar",
    "bisbilhotadas": "bisbilhotar",
    "bisbilhotado": "bisbilhotar",
    "bisbilhotados": "bisbilhotar",
    "bisbilhotai": "bisbilhotar",
    "bisbilhotais": "bisbilhotar",
    "bisbilhotam": "bisbilhotar",
    "bisbilhotamo": "bisbilhotar",
    "bisbilhotamos": "bisbilhotar",
    "bisbilhotando": "bisbilhotar",
    "bisbilhotara": "bisbilhotar",
    "bisbilhotaram": "bisbilhotar",
    "bisbilhotaras": "bisbilhotar",
    "bisbilhotarde": "bisbilhotar",
    "bisbilhotardes": "bisbilhotar",
    "bisbilhotare": "bisbilhotar",
    "bisbilhotarei": "bisbilhotar",
    "bisbilhotareis": "bisbilhotar",
    "bisbilhotarem": "bisbilhotar",
    "bisbilhotaremos": "bisbilhotar",
    "bisbilhotares": "bisbilhotar",
    "bisbilhotaria": "bisbilhotar",
    "bisbilhotariam": "bisbilhotar",
    "bisbilhotarias": "bisbilhotar",
    "bisbilhotarmo": "bisbilhotar",
    "bisbilhotarmos": "bisbilhotar",
    "bisbilhotará": "bisbilhotar",
    "bisbilhotarás": "bisbilhotar",
    "bisbilhotarão": "bisbilhotar",
    "bisbilhotaríamos": "bisbilhotar",
    "bisbilhotaríeis": "bisbilhotar",
    "bisbilhotas": "bisbilhotar",
    "bisbilhotasse": "bisbilhotar",
    "bisbilhotassem": "bisbilhotar",
    "bisbilhotasses": "bisbilhotar",
    "bisbilhotaste": "bisbilhotar",
    "bisbilhotastes": "bisbilhotar",
    "bisbilhotava": "bisbilhotar",
    "bisbilhotavam": "bisbilhotar",
    "bisbilhotavas": "bisbilhotar",
    "bisbilhote": "bisbilhotar",
    "bisbilhotei": "bisbilhotar",
    "bisbilhoteira": "bisbilhoteiro",
    "bisbilhoteiras": "bisbilhoteiro",
    "bisbilhoteiros": "bisbilhoteiro",
    "bisbilhoteis": "bisbilhotar",
    "bisbilhotem": "bisbilhotar",
    "bisbilhotemo": "bisbilhotar",
    "bisbilhotemos": "bisbilhotar",
    "bisbilhotes": "bisbilhotar",
    "bisbilhotices": "bisbilhotice",
    "bisbilhoto": "bisbilhotar",
    "bisbilhotou": "bisbilhotar",
    "bisbilhotá": "bisbilhotar",
    "bisbilhotámo": "bisbilhotar",
    "bisbilhotámos": "bisbilhotar",
    "bisbilhotáramo": "bisbilhotar",
    "bisbilhotáramos": "bisbilhotar",
    "bisbilhotárei": "bisbilhotar",
    "bisbilhotáreis": "bisbilhotar",
    "bisbilhotásseis": "bisbilhotar",
    "bisbilhotássemos": "bisbilhotar",
    "bisbilhotávamo": "bisbilhotar",
    "bisbilhotávamos": "bisbilhotar",
    "bisbilhotávei": "bisbilhotar",
    "bisbilhotáveis": "bisbilhotar",
    "bisbórrias": "bisbórria",
    "bisca": "bisco",
    "biscada": "biscar",
    "biscadas": "biscar",
    "biscado": "biscar",
    "biscados": "biscar",
    "biscaia": "biscaio",
    "biscaias": "biscaio",
    "biscainha": "biscainho",
    "biscainhas": "biscainho",
    "biscainhos": "biscainho",
    "biscaios": "biscaio",
    "biscais": "biscar",
    "biscalheiras": "biscalheira",
    "biscalhos": "biscalho",
    "biscalongos": "biscalongo",
    "biscam": "biscar",
    "biscamo": "biscar",
    "biscamos": "biscar",
    "biscando": "biscar",
    "biscara": "biscar",
    "biscaram": "biscar",
    "biscaras": "biscar",
    "biscardes": "biscar",
    "biscarei": "biscar",
    "biscareis": "biscar",
    "biscarem": "biscar",
    "biscaremos": "biscar",
    "biscares": "biscar",
    "biscaria": "biscar",
    "biscariam": "biscar",
    "biscarias": "biscar",
    "biscarmo": "biscar",
    "biscarmos": "biscar",
    "biscará": "biscar",
    "biscarás": "biscar",
    "biscarão": "biscar",
    "biscaríamos": "biscar",
    "biscaríeis": "biscar",
    "biscas": "bisco",
    "biscasse": "biscar",
    "biscassem": "biscar",
    "biscasses": "biscar",
    "biscaste": "biscar",
    "biscastes": "biscar",
    "biscateada": "biscatear",
    "biscateadas": "biscatear",
    "biscateado": "biscatear",
    "biscateados": "biscatear",
    "biscateai": "biscatear",
    "biscateais": "biscatear",
    "biscateamo": "biscatear",
    "biscateamos": "biscatear",
    "biscateando": "biscatear",
    "biscateara": "biscatear",
    "biscatearam": "biscatear",
    "biscatearas": "biscatear",
    "biscateardes": "biscatear",
    "biscatearei": "biscatear",
    "biscateareis": "biscatear",
    "biscatearem": "biscatear",
    "biscatearemos": "biscatear",
    "biscateares": "biscatear",
    "biscatearia": "biscatear",
    "biscateariam": "biscatear",
    "biscatearias": "biscatear",
    "biscatearmo": "biscatear",
    "biscatearmos": "biscatear",
    "biscateará": "biscatear",
    "biscatearás": "biscatear",
    "biscatearão": "biscatear",
    "biscatearíamos": "biscatear",
    "biscatearíeis": "biscatear",
    "biscateasse": "biscatear",
    "biscateassem": "biscatear",
    "biscateasses": "biscatear",
    "biscateaste": "biscatear",
    "biscateastes": "biscatear",
    "biscateava": "biscatear",
    "biscateavam": "biscatear",
    "biscateavas": "biscatear",
    "biscateei": "biscatear",
    "biscateeis": "biscatear",
    "biscateemo": "biscatear",
    "biscateemos": "biscatear",
    "biscateia": "biscatear",
    "biscateiam": "biscatear",
    "biscateias": "biscatear",
    "biscateie": "biscatear",
    "biscateiem": "biscatear",
    "biscateies": "biscatear",
    "biscateio": "biscatear",
    "biscateira": "biscateiro",
    "biscateiras": "biscateiro",
    "biscateiros": "biscateiro",
    "biscateou": "biscatear",
    "biscates": "biscate",
    "biscateámo": "biscatear",
    "biscateámos": "biscatear",
    "biscateáramo": "biscatear",
    "biscateáramos": "biscatear",
    "biscateáreis": "biscatear",
    "biscateásseis": "biscatear",
    "biscateássemos": "biscatear",
    "biscateávamo": "biscatear",
    "biscateávamos": "biscatear",
    "biscateáveis": "biscatear",
    "biscatos": "biscato",
    "biscava": "biscar",
    "biscavam": "biscar",
    "biscavas": "biscar",
    "biscazinha": "bisca",
    "biscazinhas": "bisca",
    "biscazita": "bisca",
    "biscazitas": "bisca",
    "bisco": "biscar",
    "biscoita": "biscoitar",
    "biscoitada": "biscoitar",
    "biscoitadas": "biscoitar",
    "biscoitado": "biscoitar",
    "biscoitados": "biscoitar",
    "biscoitai": "biscoitar",
    "biscoitais": "biscoitar",
    "biscoitam": "biscoitar",
    "biscoitamo": "biscoitar",
    "biscoitamos": "biscoitar",
    "biscoitando": "biscoitar",
    "biscoitara": "biscoitar",
    "biscoitaram": "biscoitar",
    "biscoitaras": "biscoitar",
    "biscoitarde": "biscoitar",
    "biscoitardes": "biscoitar",
    "biscoitare": "biscoitar",
    "biscoitarei": "biscoitar",
    "biscoitareis": "biscoitar",
    "biscoitarem": "biscoitar",
    "biscoitaremos": "biscoitar",
    "biscoitares": "biscoitar",
    "biscoitaria": "biscoitar",
    "biscoitariam": "biscoitar",
    "biscoitarias": "biscoitaria",
    "biscoitarmo": "biscoitar",
    "biscoitarmos": "biscoitar",
    "biscoitará": "biscoitar",
    "biscoitarás": "biscoitar",
    "biscoitarão": "biscoitar",
    "biscoitaríamos": "biscoitar",
    "biscoitaríeis": "biscoitar",
    "biscoitas": "biscoitar",
    "biscoitasse": "biscoitar",
    "biscoitassem": "biscoitar",
    "biscoitasses": "biscoitar",
    "biscoitaste": "biscoitar",
    "biscoitastes": "biscoitar",
    "biscoitava": "biscoitar",
    "biscoitavam": "biscoitar",
    "biscoitavas": "biscoitar",
    "biscoite": "biscoitar",
    "biscoitei": "biscoitar",
    "biscoiteiras": "biscoiteira",
    "biscoiteiros": "biscoiteiro",
    "biscoiteis": "biscoitar",
    "biscoitem": "biscoitar",
    "biscoitemo": "biscoitar",
    "biscoitemos": "biscoitar",
    "biscoites": "biscoitar",
    "biscoitinho": "biscoito",
    "biscoitinhos": "biscoito",
    "biscoitito": "biscoito",
    "biscoititos": "biscoito",
    "biscoito": "biscoitar",
    "biscoitos": "biscoito",
    "biscoitou": "biscoitar",
    "biscoitá": "biscoitar",
    "biscoitámo": "biscoitar",
    "biscoitámos": "biscoitar",
    "biscoitáramo": "biscoitar",
    "biscoitáramos": "biscoitar",
    "biscoitárei": "biscoitar",
    "biscoitáreis": "biscoitar",
    "biscoitásseis": "biscoitar",
    "biscoitássemos": "biscoitar",
    "biscoitávamo": "biscoitar",
    "biscoitávamos": "biscoitar",
    "biscoitávei": "biscoitar",
    "biscoitáveis": "biscoitar",
    "biscos": "bisco",
    "biscou": "biscar",
    "biscouta": "biscoutar",
    "biscoutada": "biscoutar",
    "biscoutadas": "biscoutar",
    "biscoutado": "biscoutar",
    "biscoutados": "biscoutar",
    "biscoutai": "biscoutar",
    "biscoutais": "biscoutar",
    "biscoutam": "biscoutar",
    "biscoutamo": "biscoutar",
    "biscoutamos": "biscoutar",
    "biscoutando": "biscoutar",
    "biscoutara": "biscoutar",
    "biscoutaram": "biscoutar",
    "biscoutaras": "biscoutar",
    "biscoutarde": "biscoutar",
    "biscoutardes": "biscoutar",
    "biscoutare": "biscoutar",
    "biscoutarei": "biscoutar",
    "biscoutareis": "biscoutar",
    "biscoutarem": "biscoutar",
    "biscoutaremos": "biscoutar",
    "biscoutares": "biscoutar",
    "biscoutaria": "biscoutar",
    "biscoutariam": "biscoutar",
    "biscoutarias": "biscoutaria",
    "biscoutarmo": "biscoutar",
    "biscoutarmos": "biscoutar",
    "biscoutará": "biscoutar",
    "biscoutarás": "biscoutar",
    "biscoutarão": "biscoutar",
    "biscoutaríamos": "biscoutar",
    "biscoutaríeis": "biscoutar",
    "biscoutas": "biscoutar",
    "biscoutasse": "biscoutar",
    "biscoutassem": "biscoutar",
    "biscoutasses": "biscoutar",
    "biscoutaste": "biscoutar",
    "biscoutastes": "biscoutar",
    "biscoutava": "biscoutar",
    "biscoutavam": "biscoutar",
    "biscoutavas": "biscoutar",
    "biscoute": "biscoutar",
    "biscoutei": "biscoutar",
    "biscouteira": "biscouteiro",
    "biscouteiras": "biscouteiro",
    "biscouteiros": "biscouteiro",
    "biscouteis": "biscoutar",
    "biscoutem": "biscoutar",
    "biscoutemo": "biscoutar",
    "biscoutemos": "biscoutar",
    "biscoutes": "biscoutar",
    "biscoutinho": "biscouto",
    "biscoutinhos": "biscouto",
    "biscoutito": "biscouto",
    "biscoutitos": "biscouto",
    "biscouto": "biscoutar",
    "biscoutos": "biscouto",
    "biscoutou": "biscoutar",
    "biscoutá": "biscoutar",
    "biscoutámo": "biscoutar",
    "biscoutámos": "biscoutar",
    "biscoutáramo": "biscoutar",
    "biscoutáramos": "biscoutar",
    "biscoutárei": "biscoutar",
    "biscoutáreis": "biscoutar",
    "biscoutásseis": "biscoutar",
    "biscoutássemos": "biscoutar",
    "biscoutávamo": "biscoutar",
    "biscoutávamos": "biscoutar",
    "biscoutávei": "biscoutar",
    "biscoutáveis": "biscoutar",
    "biscámo": "biscar",
    "biscámos": "biscar",
    "biscáramo": "biscar",
    "biscáramos": "biscar",
    "biscáreis": "biscar",
    "biscásseis": "biscar",
    "biscássemos": "biscar",
    "biscávamo": "biscar",
    "biscávamos": "biscar",
    "biscáveis": "biscar",
    "bise": "bisar",
    "bisegres": "bisegre",
    "bisei": "bisar",
    "biseis": "bisar",
    "bisela": "biselar",
    "biselada": "biselar",
    "biseladas": "biselar",
    "biselado": "biselar",
    "biselados": "biselar",
    "biselai": "biselar",
    "biselais": "biselar",
    "biselam": "biselar",
    "biselamo": "biselar",
    "biselamos": "biselar",
    "biselando": "biselar",
    "biselara": "biselar",
    "biselaram": "biselar",
    "biselaras": "biselar",
    "biselarde": "biselar",
    "biselardes": "biselar",
    "biselare": "biselar",
    "biselarei": "biselar",
    "biselareis": "biselar",
    "biselarem": "biselar",
    "biselaremos": "biselar",
    "biselares": "biselar",
    "biselaria": "biselar",
    "biselariam": "biselar",
    "biselarias": "biselar",
    "biselarmo": "biselar",
    "biselarmos": "biselar",
    "biselará": "biselar",
    "biselarás": "biselar",
    "biselarão": "biselar",
    "biselaríamos": "biselar",
    "biselaríeis": "biselar",
    "biselas": "biselar",
    "biselasse": "biselar",
    "biselassem": "biselar",
    "biselasses": "biselar",
    "biselaste": "biselar",
    "biselastes": "biselar",
    "biselava": "biselar",
    "biselavam": "biselar",
    "biselavas": "biselar",
    "bisele": "biselar",
    "biselei": "biselar",
    "biseleis": "biselar",
    "biselem": "biselar",
    "biselemo": "biselar",
    "biselemos": "biselar",
    "biseles": "biselar",
    "biselo": "biselar",
    "biselou": "biselar",
    "biselá": "biselar",
    "biselámo": "biselar",
    "biselámos": "biselar",
    "biseláramo": "biselar",
    "biseláramos": "biselar",
    "biselárei": "biselar",
    "biseláreis": "biselar",
    "biselásseis": "biselar",
    "biselássemos": "biselar",
    "biselávamo": "biselar",
    "biselávamos": "biselar",
    "biselávei": "biselar",
    "biseláveis": "biselar",
    "bisem": "bisar",
    "bisemo": "bisar",
    "bisemos": "bisar",
    "bises": "bisar",
    "bisesdrúxula": "bisesdrúxulo",
    "bisesdrúxulas": "bisesdrúxulo",
    "bisesdrúxulos": "bisesdrúxulo",
    "bismas": "bisma",
    "bismelas": "bismela",
    "bismotatos": "bismotato",
    "bismutinites": "bismutinite",
    "bismutos": "bismuto",
    "bismóteos": "bismóteo",
    "bismútica": "bismútico",
    "bismúticas": "bismútico",
    "bismúticos": "bismútico",
    "bisnaga": "bisnagar",
    "bisnagada": "bisnagar",
    "bisnagadas": "bisnagar",
    "bisnagado": "bisnagar",
    "bisnagados": "bisnagar",
    "bisnagai": "bisnagar",
    "bisnagais": "bisnagar",
    "bisnagam": "bisnagar",
    "bisnagamo": "bisnagar",
    "bisnagamos": "bisnagar",
    "bisnagando": "bisnagar",
    "bisnagara": "bisnagar",
    "bisnagaram": "bisnagar",
    "bisnagaras": "bisnagar",
    "bisnagarde": "bisnagar",
    "bisnagardes": "bisnagar",
    "bisnagare": "bisnagar",
    "bisnagarei": "bisnagar",
    "bisnagareis": "bisnagar",
    "bisnagarem": "bisnagar",
    "bisnagaremos": "bisnagar",
    "bisnagares": "bisnagar",
    "bisnagaria": "bisnagar",
    "bisnagariam": "bisnagar",
    "bisnagarias": "bisnagar",
    "bisnagarmo": "bisnagar",
    "bisnagarmos": "bisnagar",
    "bisnagará": "bisnagar",
    "bisnagarás": "bisnagar",
    "bisnagarão": "bisnagar",
    "bisnagaríamos": "bisnagar",
    "bisnagaríeis": "bisnagar",
    "bisnagas": "bisnagar",
    "bisnagasse": "bisnagar",
    "bisnagassem": "bisnagar",
    "bisnagasses": "bisnagar",
    "bisnagaste": "bisnagar",
    "bisnagastes": "bisnagar",
    "bisnagava": "bisnagar",
    "bisnagavam": "bisnagar",
    "bisnagavas": "bisnagar",
    "bisnago": "bisnagar",
    "bisnagou": "bisnagar",
    "bisnague": "bisnagar",
    "bisnaguei": "bisnagar",
    "bisnagueis": "bisnagar",
    "bisnaguem": "bisnagar",
    "bisnaguemo": "bisnagar",
    "bisnaguemos": "bisnagar",
    "bisnagues": "bisnagar",
    "bisnaguinha": "bisnaga",
    "bisnaguinhas": "bisnaga",
    "bisnaguita": "bisnaga",
    "bisnaguitas": "bisnaga",
    "bisnagá": "bisnagar",
    "bisnagámo": "bisnagar",
    "bisnagámos": "bisnagar",
    "bisnagáramo": "bisnagar",
    "bisnagáramos": "bisnagar",
    "bisnagárei": "bisnagar",
    "bisnagáreis": "bisnagar",
    "bisnagásseis": "bisnagar",
    "bisnagássemos": "bisnagar",
    "bisnagávamo": "bisnagar",
    "bisnagávamos": "bisnagar",
    "bisnagávei": "bisnagar",
    "bisnagáveis": "bisnagar",
    "bisnaus": "bisnau",
    "bisneta": "bisneto",
    "bisnetas": "bisneto",
    "bisnetos": "bisneto",
    "biso": "bisar",
    "bisonha": "bisonho",
    "bisonharias": "bisonharia",
    "bisonhas": "bisonho",
    "bisonhices": "bisonhice",
    "bisonhos": "bisonho",
    "bisontes": "bisonte",
    "bisou": "bisar",
    "bispa": "bispar",
    "bispada": "bispar",
    "bispadas": "bispar",
    "bispado": "bispar",
    "bispados": "bispar",
    "bispai": "bispar",
    "bispais": "bispar",
    "bispam": "bispar",
    "bispamo": "bispar",
    "bispamos": "bispar",
    "bispando": "bispar",
    "bispara": "bispar",
    "bisparam": "bispar",
    "bisparas": "bispar",
    "bisparde": "bispar",
    "bispardes": "bispar",
    "bispare": "bispar",
    "bisparei": "bispar",
    "bispareis": "bispar",
    "bisparem": "bispar",
    "bisparemos": "bispar",
    "bispares": "bispar",
    "bisparia": "bispar",
    "bispariam": "bispar",
    "bisparias": "bispar",
    "bisparmo": "bispar",
    "bisparmos": "bispar",
    "bispará": "bispar",
    "bisparás": "bispar",
    "bisparão": "bispar",
    "bisparíamos": "bispar",
    "bisparíeis": "bispar",
    "bispas": "bispar",
    "bispasse": "bispar",
    "bispassem": "bispar",
    "bispasses": "bispar",
    "bispaste": "bispar",
    "bispastes": "bispar",
    "bispava": "bispar",
    "bispavam": "bispar",
    "bispavas": "bispar",
    "bispe": "bispar",
    "bispei": "bispar",
    "bispeis": "bispar",
    "bispem": "bispar",
    "bispemo": "bispar",
    "bispemos": "bispar",
    "bispes": "bispar",
    "bispo": "bispar",
    "bispos": "bispo",
    "bispoteada": "bispotear",
    "bispoteadas": "bispotear",
    "bispoteado": "bispotear",
    "bispoteados": "bispotear",
    "bispoteai": "bispotear",
    "bispoteais": "bispotear",
    "bispoteamo": "bispotear",
    "bispoteamos": "bispotear",
    "bispoteando": "bispotear",
    "bispoteara": "bispotear",
    "bispotearam": "bispotear",
    "bispotearas": "bispotear",
    "bispotearde": "bispotear",
    "bispoteardes": "bispotear",
    "bispoteare": "bispotear",
    "bispotearei": "bispotear",
    "bispoteareis": "bispotear",
    "bispotearem": "bispotear",
    "bispotearemos": "bispotear",
    "bispoteares": "bispotear",
    "bispotearia": "bispotear",
    "bispoteariam": "bispotear",
    "bispotearias": "bispotear",
    "bispotearmo": "bispotear",
    "bispotearmos": "bispotear",
    "bispoteará": "bispotear",
    "bispotearás": "bispotear",
    "bispotearão": "bispotear",
    "bispotearíamos": "bispotear",
    "bispotearíeis": "bispotear",
    "bispoteasse": "bispotear",
    "bispoteassem": "bispotear",
    "bispoteasses": "bispotear",
    "bispoteaste": "bispotear",
    "bispoteastes": "bispotear",
    "bispoteava": "bispotear",
    "bispoteavam": "bispotear",
    "bispoteavas": "bispotear",
    "bispoteei": "bispotear",
    "bispoteeis": "bispotear",
    "bispoteemo": "bispotear",
    "bispoteemos": "bispotear",
    "bispoteia": "bispotear",
    "bispoteiam": "bispotear",
    "bispoteias": "bispotear",
    "bispoteie": "bispotear",
    "bispoteiem": "bispotear",
    "bispoteies": "bispotear",
    "bispoteio": "bispotear",
    "bispoteou": "bispotear",
    "bispotes": "bispote",
    "bispoteá": "bispotear",
    "bispoteámo": "bispotear",
    "bispoteámos": "bispotear",
    "bispoteáramo": "bispotear",
    "bispoteáramos": "bispotear",
    "bispoteárei": "bispotear",
    "bispoteáreis": "bispotear",
    "bispoteásseis": "bispotear",
    "bispoteássemos": "bispotear",
    "bispoteávamo": "bispotear",
    "bispoteávamos": "bispotear",
    "bispoteávei": "bispotear",
    "bispoteáveis": "bispotear",
    "bispou": "bispar",
    "bispá": "bispar",
    "bispámo": "bispar",
    "bispámos": "bispar",
    "bispáramo": "bispar",
    "bispáramos": "bispar",
    "bispárei": "bispar",
    "bispáreis": "bispar",
    "bispásseis": "bispar",
    "bispássemos": "bispar",
    "bispávamo": "bispar",
    "bispávamos": "bispar",
    "bispávei": "bispar",
    "bispáveis": "bispável",
    "bisque": "biscar",
    "bisquei": "biscar",
    "bisqueira": "bisqueiro",
    "bisqueiras": "bisqueiro",
    "bisqueiros": "bisqueiro",
    "bisqueis": "biscar",
    "bisquem": "biscar",
    "bisquemos": "biscar",
    "bisques": "biscar",
    "bisquinha": "bisca",
    "bisquinhas": "bisca",
    "bisquita": "bisca",
    "bisquitas": "bisca",
    "bissecta": "bissectar",
    "bissectada": "bissectar",
    "bissectadas": "bissectar",
    "bissectado": "bissectar",
    "bissectados": "bissectar",
    "bissectai": "bissectar",
    "bissectais": "bissectar",
    "bissectam": "bissectar",
    "bissectamo": "bissectar",
    "bissectamos": "bissectar",
    "bissectando": "bissectar",
    "bissectara": "bissectar",
    "bissectaram": "bissectar",
    "bissectaras": "bissectar",
    "bissectarde": "bissectar",
    "bissectardes": "bissectar",
    "bissectare": "bissectar",
    "bissectarei": "bissectar",
    "bissectareis": "bissectar",
    "bissectarem": "bissectar",
    "bissectaremos": "bissectar",
    "bissectares": "bissectar",
    "bissectaria": "bissectar",
    "bissectariam": "bissectar",
    "bissectarias": "bissectar",
    "bissectarmo": "bissectar",
    "bissectarmos": "bissectar",
    "bissectará": "bissectar",
    "bissectarás": "bissectar",
    "bissectarão": "bissectar",
    "bissectaríamos": "bissectar",
    "bissectaríeis": "bissectar",
    "bissectas": "bissectar",
    "bissectasse": "bissectar",
    "bissectassem": "bissectar",
    "bissectasses": "bissectar",
    "bissectaste": "bissectar",
    "bissectastes": "bissectar",
    "bissectava": "bissectar",
    "bissectavam": "bissectar",
    "bissectavas": "bissectar",
    "bissecte": "bissectar",
    "bissectei": "bissectar",
    "bissecteis": "bissectar",
    "bissectem": "bissectar",
    "bissectemo": "bissectar",
    "bissectemos": "bissectar",
    "bissectes": "bissectar",
    "bissecto": "bissectar",
    "bissectores": "bissector",
    "bissectou": "bissectar",
    "bissectriz": "bissector",
    "bissectrizes": "bissectriz",
    "bissectá": "bissectar",
    "bissectámo": "bissectar",
    "bissectámos": "bissectar",
    "bissectáramo": "bissectar",
    "bissectáramos": "bissectar",
    "bissectárei": "bissectar",
    "bissectáreis": "bissectar",
    "bissectásseis": "bissectar",
    "bissectássemos": "bissectar",
    "bissectávamo": "bissectar",
    "bissectávamos": "bissectar",
    "bissectávei": "bissectar",
    "bissectáveis": "bissectável",
    "bisseculares": "bissecular",
    "bissecções": "bissecção",
    "bissemanais": "bissemanal",
    "bissemanária": "bissemanário",
    "bissemanárias": "bissemanário",
    "bissemanários": "bissemanário",
    "bisseriada": "bisseriado",
    "bisseriadas": "bisseriado",
    "bisseriados": "bisseriado",
    "bissexta": "bissexto",
    "bissextas": "bissexto",
    "bissextis": "bissextil",
    "bissextos": "bissexto",
    "bissexuada": "bissexuado",
    "bissexuadas": "bissexuado",
    "bissexuados": "bissexuado",
    "bissexuais": "bissexual",
    "bissexualidades": "bissexualidade",
    "bissexualismos": "bissexualismo",
    "bissilábica": "bissilábico",
    "bissilábicas": "bissilábico",
    "bissilábicos": "bissilábico",
    "bissulcada": "bissulcado",
    "bissulcadas": "bissulcado",
    "bissulcados": "bissulcado",
    "bissulfatos": "bissulfato",
    "bissulfitos": "bissulfito",
    "bissulfuretos": "bissulfureto",
    "bissílabos": "bissílabo",
    "bissílada": "bissílado",
    "bissíladas": "bissílado",
    "bissílados": "bissílado",
    "bistortas": "bistorta",
    "bistres": "bistre",
    "bisturis": "bisturi",
    "bisá": "bisar",
    "bisámo": "bisar",
    "bisámos": "bisar",
    "bisáramo": "bisar",
    "bisáramos": "bisar",
    "bisárei": "bisar",
    "bisáreis": "bisar",
    "bisásseis": "bisar",
    "bisássemos": "bisar",
    "bisávamo": "bisar",
    "bisávamos": "bisar",
    "bisávei": "bisar",
    "bisáveis": "bisar",
    "biséis": "bisel",
    "bisões": "bisão",
    "bites": "bite",
    "bitióis": "bitiol",
    "bitles": "bitle",
    "bitola": "bitolar",
    "bitolada": "bitolar",
    "bitoladas": "bitolar",
    "bitolado": "bitolar",
    "bitolados": "bitolar",
    "bitolai": "bitolar",
    "bitolais": "bitolar",
    "bitolam": "bitolar",
    "bitolamo": "bitolar",
    "bitolamos": "bitolar",
    "bitolando": "bitolar",
    "bitolara": "bitolar",
    "bitolaram": "bitolar",
    "bitolaras": "bitolar",
    "bitolarde": "bitolar",
    "bitolardes": "bitolar",
    "bitolare": "bitolar",
    "bitolarei": "bitolar",
    "bitolareis": "bitolar",
    "bitolarem": "bitolar",
    "bitolaremos": "bitolar",
    "bitolares": "bitolar",
    "bitolaria": "bitolar",
    "bitolariam": "bitolar",
    "bitolarias": "bitolar",
    "bitolarmo": "bitolar",
    "bitolarmos": "bitolar",
    "bitolará": "bitolar",
    "bitolarás": "bitolar",
    "bitolarão": "bitolar",
    "bitolaríamos": "bitolar",
    "bitolaríeis": "bitolar",
    "bitolas": "bitolar",
    "bitolasse": "bitolar",
    "bitolassem": "bitolar",
    "bitolasses": "bitolar",
    "bitolaste": "bitolar",
    "bitolastes": "bitolar",
    "bitolava": "bitolar",
    "bitolavam": "bitolar",
    "bitolavas": "bitolar",
    "bitole": "bitolar",
    "bitolei": "bitolar",
    "bitoleis": "bitolar",
    "bitolem": "bitolar",
    "bitolemo": "bitolar",
    "bitolemos": "bitolar",
    "bitoles": "bitolar",
    "bitolo": "bitolar",
    "bitolou": "bitolar",
    "bitolá": "bitolar",
    "bitolámo": "bitolar",
    "bitolámos": "bitolar",
    "bitoláramo": "bitolar",
    "bitoláramos": "bitolar",
    "bitolárei": "bitolar",
    "bitoláreis": "bitolar",
    "bitolásseis": "bitolar",
    "bitolássemos": "bitolar",
    "bitolávamo": "bitolar",
    "bitolávamos": "bitolar",
    "bitolávei": "bitolar",
    "bitoláveis": "bitolar",
    "bitonalidades": "bitonalidade",
    "bitongas": "bitonga",
    "bitos": "bito",
    "bitáculas": "bitácula",
    "biunívoca": "biunívoco",
    "biunívocas": "biunívoco",
    "biunívocos": "biunívoco",
    "biuretos": "biureto",
    "bivaca": "bivacar",
    "bivacada": "bivacar",
    "bivacadas": "bivacar",
    "bivacado": "bivacar",
    "bivacados": "bivacar",
    "bivacais": "bivacar",
    "bivacam": "bivacar",
    "bivacamo": "bivacar",
    "bivacamos": "bivacar",
    "bivacando": "bivacar",
    "bivacara": "bivacar",
    "bivacaram": "bivacar",
    "bivacaras": "bivacar",
    "bivacardes": "bivacar",
    "bivacarei": "bivacar",
    "bivacareis": "bivacar",
    "bivacarem": "bivacar",
    "bivacaremos": "bivacar",
    "bivacares": "bivacar",
    "bivacaria": "bivacar",
    "bivacariam": "bivacar",
    "bivacarias": "bivacar",
    "bivacarmo": "bivacar",
    "bivacarmos": "bivacar",
    "bivacará": "bivacar",
    "bivacarás": "bivacar",
    "bivacarão": "bivacar",
    "bivacaríamos": "bivacar",
    "bivacaríeis": "bivacar",
    "bivacas": "bivacar",
    "bivacasse": "bivacar",
    "bivacassem": "bivacar",
    "bivacasses": "bivacar",
    "bivacaste": "bivacar",
    "bivacastes": "bivacar",
    "bivacava": "bivacar",
    "bivacavam": "bivacar",
    "bivacavas": "bivacar",
    "bivaco": "bivacar",
    "bivacou": "bivacar",
    "bivacámo": "bivacar",
    "bivacámos": "bivacar",
    "bivacáramo": "bivacar",
    "bivacáramos": "bivacar",
    "bivacáreis": "bivacar",
    "bivacásseis": "bivacar",
    "bivacássemos": "bivacar",
    "bivacávamo": "bivacar",
    "bivacávamos": "bivacar",
    "bivacáveis": "bivacar",
    "bivalentes": "bivalente",
    "bivalves": "bivalve",
    "bivalências": "bivalência",
    "bivaque": "bivacar",
    "bivaquei": "bivacar",
    "bivaqueis": "bivacar",
    "bivaquem": "bivacar",
    "bivaquemos": "bivacar",
    "bivaques": "bivaque",
    "bivas": "biva",
    "bivitelina": "bivitelino",
    "bivitelinas": "bivitelino",
    "bivitelinos": "bivitelino",
    "biviária": "biviário",
    "biviárias": "biviário",
    "biviários": "biviário",
    "bixeira": "bixeiro",
    "bixeiras": "bixeiro",
    "bixeiros": "bixeiro",
    "bixinas": "bixina",
    "bizantina": "bizantino",
    "bizantinas": "bizantino",
    "bizantinices": "bizantinice",
    "bizantinismos": "bizantinismo",
    "bizantinos": "bizantino",
    "bizarra": "bizarro",
    "bizarras": "bizarro",
    "bizarraça": "bizarraço",
    "bizarraças": "bizarraço",
    "bizarraços": "bizarraço",
    "bizarreada": "bizarrear",
    "bizarreadas": "bizarrear",
    "bizarreado": "bizarrear",
    "bizarreados": "bizarrear",
    "bizarreai": "bizarrear",
    "bizarreais": "bizarrear",
    "bizarreamo": "bizarrear",
    "bizarreamos": "bizarrear",
    "bizarreando": "bizarrear",
    "bizarreara": "bizarrear",
    "bizarrearam": "bizarrear",
    "bizarrearas": "bizarrear",
    "bizarreardes": "bizarrear",
    "bizarrearei": "bizarrear",
    "bizarreareis": "bizarrear",
    "bizarrearem": "bizarrear",
    "bizarrearemos": "bizarrear",
    "bizarreares": "bizarrear",
    "bizarrearia": "bizarrear",
    "bizarreariam": "bizarrear",
    "bizarrearias": "bizarrear",
    "bizarrearmo": "bizarrear",
    "bizarrearmos": "bizarrear",
    "bizarreará": "bizarrear",
    "bizarrearás": "bizarrear",
    "bizarrearão": "bizarrear",
    "bizarrearíamos": "bizarrear",
    "bizarrearíeis": "bizarrear",
    "bizarreasse": "bizarrear",
    "bizarreassem": "bizarrear",
    "bizarreasses": "bizarrear",
    "bizarreaste": "bizarrear",
    "bizarreastes": "bizarrear",
    "bizarreava": "bizarrear",
    "bizarreavam": "bizarrear",
    "bizarreavas": "bizarrear",
    "bizarreei": "bizarrear",
    "bizarreeis": "bizarrear",
    "bizarreemo": "bizarrear",
    "bizarreemos": "bizarrear",
    "bizarreia": "bizarrear",
    "bizarreiam": "bizarrear",
    "bizarreias": "bizarrear",
    "bizarreie": "bizarrear",
    "bizarreiem": "bizarrear",
    "bizarreies": "bizarrear",
    "bizarreio": "bizarrear",
    "bizarreou": "bizarrear",
    "bizarreámo": "bizarrear",
    "bizarreámos": "bizarrear",
    "bizarreáramo": "bizarrear",
    "bizarreáramos": "bizarrear",
    "bizarreáreis": "bizarrear",
    "bizarreásseis": "bizarrear",
    "bizarreássemos": "bizarrear",
    "bizarreávamo": "bizarrear",
    "bizarreávamos": "bizarrear",
    "bizarreáveis": "bizarrear",
    "bizarrias": "bizarria",
    "bizarrices": "bizarrice",
    "bizarros": "bizarro",
    "bizâncios": "bizâncio",
    "biácea": "biáceo",
    "biáceas": "biáceo",
    "biáceos": "biáceo",
    "biácida": "biácido",
    "biácidas": "biácido",
    "biácidos": "biácido",
    "biças": "biça",
    "biénios": "biénio",
    "biófoba": "biófobo",
    "biófobas": "biófobo",
    "biófobos": "biófobo",
    "biógrafa": "biógrafo",
    "biógrafas": "biógrafo",
    "biógrafos": "biógrafo",
    "bióloga": "biólogo",
    "biólogas": "biólogo",
    "biólogos": "biólogo",
    "biónicas": "biónica",
    "biópsias": "biópsia",
    "bióstromas": "bióstroma",
    "biótica": "biótico",
    "bióticas": "biótico",
    "bióticos": "biótico",
    "biótipos": "biótipo",
    "bióxidos": "bióxido",
    "blablablás": "blablablá",
    "blackouts": "blackout",
    "blagues": "blague",
    "blandicia": "blandiciar",
    "blandiciada": "blandiciar",
    "blandiciadas": "blandiciar",
    "blandiciado": "blandiciar",
    "blandiciados": "blandiciar",
    "blandiciai": "blandiciar",
    "blandiciais": "blandiciar",
    "blandiciam": "blandiciar",
    "blandiciamo": "blandiciar",
    "blandiciamos": "blandiciar",
    "blandiciando": "blandiciar",
    "blandiciara": "blandiciar",
    "blandiciaram": "blandiciar",
    "blandiciaras": "blandiciar",
    "blandiciarde": "blandiciar",
    "blandiciardes": "blandiciar",
    "blandiciare": "blandiciar",
    "blandiciarei": "blandiciar",
    "blandiciareis": "blandiciar",
    "blandiciarem": "blandiciar",
    "blandiciaremos": "blandiciar",
    "blandiciares": "blandiciar",
    "blandiciaria": "blandiciar",
    "blandiciariam": "blandiciar",
    "blandiciarias": "blandiciar",
    "blandiciarmo": "blandiciar",
    "blandiciarmos": "blandiciar",
    "blandiciará": "blandiciar",
    "blandiciarás": "blandiciar",
    "blandiciarão": "blandiciar",
    "blandiciaríamos": "blandiciar",
    "blandiciaríeis": "blandiciar",
    "blandicias": "blandiciar",
    "blandiciasse": "blandiciar",
    "blandiciassem": "blandiciar",
    "blandiciasses": "blandiciar",
    "blandiciaste": "blandiciar",
    "blandiciastes": "blandiciar",
    "blandiciava": "blandiciar",
    "blandiciavam": "blandiciar",
    "blandiciavas": "blandiciar",
    "blandicie": "blandiciar",
    "blandiciei": "blandiciar",
    "blandicieis": "blandiciar",
    "blandiciem": "blandiciar",
    "blandiciemo": "blandiciar",
    "blandiciemos": "blandiciar",
    "blandicies": "blandiciar",
    "blandicio": "blandiciar",
    "blandiciosa": "blandicioso",
    "blandiciosas": "blandicioso",
    "blandiciosos": "blandicioso",
    "blandiciou": "blandiciar",
    "blandiciá": "blandiciar",
    "blandiciámo": "blandiciar",
    "blandiciámos": "blandiciar",
    "blandiciáramo": "blandiciar",
    "blandiciáramos": "blandiciar",
    "blandiciárei": "blandiciar",
    "blandiciáreis": "blandiciar",
    "blandiciásseis": "blandiciar",
    "blandiciássemos": "blandiciar",
    "blandiciávamo": "blandiciar",
    "blandiciávamos": "blandiciar",
    "blandiciávei": "blandiciar",
    "blandiciáveis": "blandiciar",
    "blandícias": "blandícia",
    "blandíflua": "blandífluo",
    "blandífluas": "blandífluo",
    "blandífluos": "blandífluo",
    "blandíloqua": "blandíloquo",
    "blandíloquas": "blandíloquo",
    "blandíloquos": "blandíloquo",
    "blas": "bla",
    "blasfema": "blasfemo",
    "blasfemada": "blasfemar",
    "blasfemadas": "blasfemar",
    "blasfemado": "blasfemar",
    "blasfemadora": "blasfemador",
    "blasfemadoras": "blasfemador",
    "blasfemadores": "blasfemador",
    "blasfemados": "blasfemar",
    "blasfemai": "blasfemar",
    "blasfemais": "blasfemar",
    "blasfemam": "blasfemar",
    "blasfemamo": "blasfemar",
    "blasfemamos": "blasfemar",
    "blasfemando": "blasfemar",
    "blasfemara": "blasfemar",
    "blasfemaram": "blasfemar",
    "blasfemaras": "blasfemar",
    "blasfemarde": "blasfemar",
    "blasfemardes": "blasfemar",
    "blasfemare": "blasfemar",
    "blasfemarei": "blasfemar",
    "blasfemareis": "blasfemar",
    "blasfemarem": "blasfemar",
    "blasfemaremos": "blasfemar",
    "blasfemares": "blasfemar",
    "blasfemaria": "blasfemar",
    "blasfemariam": "blasfemar",
    "blasfemarias": "blasfemar",
    "blasfemarmo": "blasfemar",
    "blasfemarmos": "blasfemar",
    "blasfemará": "blasfemar",
    "blasfemarás": "blasfemar",
    "blasfemarão": "blasfemar",
    "blasfemaríamos": "blasfemar",
    "blasfemaríeis": "blasfemar",
    "blasfemas": "blasfemo",
    "blasfemasse": "blasfemar",
    "blasfemassem": "blasfemar",
    "blasfemasses": "blasfemar",
    "blasfemaste": "blasfemar",
    "blasfemastes": "blasfemar",
    "blasfematória": "blasfematório",
    "blasfematórias": "blasfematório",
    "blasfematórios": "blasfematório",
    "blasfemava": "blasfemar",
    "blasfemavam": "blasfemar",
    "blasfemavas": "blasfemar",
    "blasfemações": "blasfemação",
    "blasfeme": "blasfemar",
    "blasfemei": "blasfemar",
    "blasfemeis": "blasfemar",
    "blasfemem": "blasfemar",
    "blasfememo": "blasfemar",
    "blasfememos": "blasfemar",
    "blasfemes": "blasfemar",
    "blasfemo": "blasfemar",
    "blasfemos": "blasfemo",
    "blasfemou": "blasfemar",
    "blasfemá": "blasfemar",
    "blasfemámo": "blasfemar",
    "blasfemámos": "blasfemar",
    "blasfemáramo": "blasfemar",
    "blasfemáramos": "blasfemar",
    "blasfemárei": "blasfemar",
    "blasfemáreis": "blasfemar",
    "blasfemásseis": "blasfemar",
    "blasfemássemos": "blasfemar",
    "blasfemávamo": "blasfemar",
    "blasfemávamos": "blasfemar",
    "blasfemávei": "blasfemar",
    "blasfemáveis": "blasfemar",
    "blasfémias": "blasfémia",
    "blasona": "blasonar",
    "blasonada": "blasonar",
    "blasonadas": "blasonar",
    "blasonado": "blasonar",
    "blasonadora": "blasonador",
    "blasonadoras": "blasonador",
    "blasonadores": "blasonador",
    "blasonados": "blasonar",
    "blasonai": "blasonar",
    "blasonais": "blasonar",
    "blasonam": "blasonar",
    "blasonamo": "blasonar",
    "blasonamos": "blasonar",
    "blasonando": "blasonar",
    "blasonara": "blasonar",
    "blasonaram": "blasonar",
    "blasonaras": "blasonar",
    "blasonarde": "blasonar",
    "blasonardes": "blasonar",
    "blasonare": "blasonar",
    "blasonarei": "blasonar",
    "blasonareis": "blasonar",
    "blasonarem": "blasonar",
    "blasonaremos": "blasonar",
    "blasonares": "blasonar",
    "blasonaria": "blasonar",
    "blasonariam": "blasonar",
    "blasonarias": "blasonaria",
    "blasonarmo": "blasonar",
    "blasonarmos": "blasonar",
    "blasonará": "blasonar",
    "blasonarás": "blasonar",
    "blasonarão": "blasonar",
    "blasonaríamos": "blasonar",
    "blasonaríeis": "blasonar",
    "blasonas": "blasonar",
    "blasonasse": "blasonar",
    "blasonassem": "blasonar",
    "blasonasses": "blasonar",
    "blasonaste": "blasonar",
    "blasonastes": "blasonar",
    "blasonava": "blasonar",
    "blasonavam": "blasonar",
    "blasonavas": "blasonar",
    "blasone": "blasonar",
    "blasonei": "blasonar",
    "blasoneis": "blasonar",
    "blasonem": "blasonar",
    "blasonemo": "blasonar",
    "blasonemos": "blasonar",
    "blasones": "blasonar",
    "blasono": "blasonar",
    "blasonou": "blasonar",
    "blasoná": "blasonar",
    "blasonámo": "blasonar",
    "blasonámos": "blasonar",
    "blasonáramo": "blasonar",
    "blasonáramos": "blasonar",
    "blasonárei": "blasonar",
    "blasonáreis": "blasonar",
    "blasonásseis": "blasonar",
    "blasonássemos": "blasonar",
    "blasonávamo": "blasonar",
    "blasonávamos": "blasonar",
    "blasonávei": "blasonar",
    "blasonáveis": "blasonar",
    "blastemas": "blastema",
    "blastocélios": "blastocélio",
    "blastodermas": "blastoderma",
    "blastodermes": "blastoderme",
    "blastos": "blasto",
    "blastóides": "blastóide",
    "blastómeros": "blastómero",
    "blastósporos": "blastósporo",
    "blasês": "blasê",
    "blatera": "blaterar",
    "blaterada": "blaterar",
    "blateradas": "blaterar",
    "blaterado": "blaterar",
    "blaterados": "blaterar",
    "blaterai": "blaterar",
    "blaterais": "blaterar",
    "blateram": "blaterar",
    "blateramo": "blaterar",
    "blateramos": "blaterar",
    "blaterando": "blaterar",
    "blaterara": "blaterar",
    "blateraram": "blaterar",
    "blateraras": "blaterar",
    "blaterardes": "blaterar",
    "blaterarei": "blaterar",
    "blaterareis": "blaterar",
    "blaterarem": "blaterar",
    "blateraremos": "blaterar",
    "blaterares": "blaterar",
    "blateraria": "blaterar",
    "blaterariam": "blaterar",
    "blaterarias": "blaterar",
    "blaterarmo": "blaterar",
    "blaterarmos": "blaterar",
    "blaterará": "blaterar",
    "blaterarás": "blaterar",
    "blaterarão": "blaterar",
    "blateraríamos": "blaterar",
    "blateraríeis": "blaterar",
    "blateras": "blaterar",
    "blaterasse": "blaterar",
    "blaterassem": "blaterar",
    "blaterasses": "blaterar",
    "blateraste": "blaterar",
    "blaterastes": "blaterar",
    "blaterava": "blaterar",
    "blateravam": "blaterar",
    "blateravas": "blaterar",
    "blatere": "blaterar",
    "blaterei": "blaterar",
    "blatereis": "blaterar",
    "blaterem": "blaterar",
    "blateremo": "blaterar",
    "blateremos": "blaterar",
    "blateres": "blaterar",
    "blatero": "blaterar",
    "blaterou": "blaterar",
    "blaterámo": "blaterar",
    "blaterámos": "blaterar",
    "blateráramo": "blaterar",
    "blateráramos": "blaterar",
    "blateráreis": "blaterar",
    "blaterásseis": "blaterar",
    "blaterássemos": "blaterar",
    "blaterávamo": "blaterar",
    "blaterávamos": "blaterar",
    "blateráveis": "blaterar",
    "blatários": "blatário",
    "blatídea": "blatídeo",
    "blatídeas": "blatídeo",
    "blatídeos": "blatídeo",
    "blaus": "blau",
    "blazeres": "blazer",
    "blefarites": "blefarite",
    "blefaroplastas": "blefaroplasta",
    "blefaroplastos": "blefaroplasto",
    "blemométrica": "blemométrico",
    "blemométricas": "blemométrico",
    "blemométricos": "blemométrico",
    "blemómetros": "blemómetro",
    "blendas": "blenda",
    "bleniídea": "bleniídeo",
    "bleniídeas": "bleniídeo",
    "bleniídeos": "bleniídeo",
    "bleniídios": "bleniídio",
    "blenorragias": "blenorragia",
    "blenorreias": "blenorreia",
    "blenorrágica": "blenorrágico",
    "blenorrágicas": "blenorrágico",
    "blenorrágicos": "blenorrágico",
    "bleníidas": "bleníida",
    "blesa": "bleso",
    "blesas": "bleso",
    "blesidades": "blesidade",
    "blesos": "bleso",
    "blinda": "blindar",
    "blindada": "blindar",
    "blindadas": "blindar",
    "blindado": "blindar",
    "blindados": "blindar",
    "blindagens": "blindagem",
    "blindai": "blindar",
    "blindais": "blindar",
    "blindam": "blindar",
    "blindamo": "blindar",
    "blindamos": "blindar",
    "blindando": "blindar",
    "blindara": "blindar",
    "blindaram": "blindar",
    "blindaras": "blindar",
    "blindarde": "blindar",
    "blindardes": "blindar",
    "blindare": "blindar",
    "blindarei": "blindar",
    "blindareis": "blindar",
    "blindarem": "blindar",
    "blindaremos": "blindar",
    "blindares": "blindar",
    "blindaria": "blindar",
    "blindariam": "blindar",
    "blindarias": "blindar",
    "blindarmo": "blindar",
    "blindarmos": "blindar",
    "blindará": "blindar",
    "blindarás": "blindar",
    "blindarão": "blindar",
    "blindaríamos": "blindar",
    "blindaríeis": "blindar",
    "blindas": "blindar",
    "blindasse": "blindar",
    "blindassem": "blindar",
    "blindasses": "blindar",
    "blindaste": "blindar",
    "blindastes": "blindar",
    "blindava": "blindar",
    "blindavam": "blindar",
    "blindavas": "blindar",
    "blinde": "blindar",
    "blindei": "blindar",
    "blindeis": "blindar",
    "blindem": "blindar",
    "blindemo": "blindar",
    "blindemos": "blindar",
    "blindes": "blindar",
    "blindo": "blindar",
    "blindou": "blindar",
    "blindá": "blindar",
    "blindámo": "blindar",
    "blindámos": "blindar",
    "blindáramo": "blindar",
    "blindáramos": "blindar",
    "blindárei": "blindar",
    "blindáreis": "blindar",
    "blindásseis": "blindar",
    "blindássemos": "blindar",
    "blindávamo": "blindar",
    "blindávamos": "blindar",
    "blindávei": "blindar",
    "blindáveis": "blindar",
    "blocagens": "blocagem",
    "blocos": "bloco",
    "blocozinho": "bloco",
    "blocozinhos": "bloco",
    "blocozito": "bloco",
    "blocozitos": "bloco",
    "bloqueada": "bloquear",
    "bloqueadas": "bloquear",
    "bloqueado": "bloquear",
    "bloqueadora": "bloqueador",
    "bloqueadoras": "bloqueador",
    "bloqueadores": "bloqueador",
    "bloqueados": "bloquear",
    "bloqueai": "bloquear",
    "bloqueais": "bloquear",
    "bloqueamentos": "bloqueamento",
    "bloqueamo": "bloquear",
    "bloqueamos": "bloquear",
    "bloqueando": "bloquear",
    "bloqueantes": "bloqueante",
    "bloqueara": "bloquear",
    "bloquearam": "bloquear",
    "bloquearas": "bloquear",
    "bloquearde": "bloquear",
    "bloqueardes": "bloquear",
    "bloqueare": "bloquear",
    "bloquearei": "bloquear",
    "bloqueareis": "bloquear",
    "bloquearem": "bloquear",
    "bloquearemos": "bloquear",
    "bloqueares": "bloquear",
    "bloquearia": "bloquear",
    "bloqueariam": "bloquear",
    "bloquearias": "bloquear",
    "bloquearmo": "bloquear",
    "bloquearmos": "bloquear",
    "bloqueará": "bloquear",
    "bloquearás": "bloquear",
    "bloquearão": "bloquear",
    "bloquearíamos": "bloquear",
    "bloquearíeis": "bloquear",
    "bloqueasse": "bloquear",
    "bloqueassem": "bloquear",
    "bloqueasses": "bloquear",
    "bloqueaste": "bloquear",
    "bloqueastes": "bloquear",
    "bloqueava": "bloquear",
    "bloqueavam": "bloquear",
    "bloqueavas": "bloquear",
    "bloqueei": "bloquear",
    "bloqueeis": "bloquear",
    "bloqueemo": "bloquear",
    "bloqueemos": "bloquear",
    "bloqueia": "bloquear",
    "bloqueiam": "bloquear",
    "bloqueias": "bloquear",
    "bloqueie": "bloquear",
    "bloqueiem": "bloquear",
    "bloqueies": "bloquear",
    "bloqueio": "bloquear",
    "bloqueios": "bloqueio",
    "bloqueou": "bloquear",
    "bloqueá": "bloquear",
    "bloqueámo": "bloquear",
    "bloqueámos": "bloquear",
    "bloqueáramo": "bloquear",
    "bloqueáramos": "bloquear",
    "bloqueárei": "bloquear",
    "bloqueáreis": "bloquear",
    "bloqueásseis": "bloquear",
    "bloqueássemos": "bloquear",
    "bloqueávamo": "bloquear",
    "bloqueávamos": "bloquear",
    "bloqueávei": "bloquear",
    "bloqueáveis": "bloqueável",
    "bloquinho": "bloco",
    "bloquinhos": "bloco",
    "bloquistas": "bloquista",
    "bloquito": "bloco",
    "bloquitos": "bloco",
    "blusas": "blusa",
    "blusinha": "blusa",
    "blusinhas": "blusa",
    "blusita": "blusa",
    "blusitas": "blusa",
    "blusões": "blusão",
    "blástulas": "blástula",
    "blátidas": "blátida",
    "boa": "bom",
    "boabás": "boabá",
    "boais": "boal",
    "boanas": "boana",
    "boas": "bom",
    "boata": "boatar",
    "boatada": "boatar",
    "boatadas": "boatar",
    "boatado": "boatar",
    "boatados": "boatar",
    "boatai": "boatar",
    "boatais": "boatar",
    "boatam": "boatar",
    "boatamo": "boatar",
    "boatamos": "boatar",
    "boatando": "boatar",
    "boatara": "boatar",
    "boataram": "boatar",
    "boataras": "boatar",
    "boatardes": "boatar",
    "boatarei": "boatar",
    "boatareis": "boatar",
    "boatarem": "boatar",
    "boataremos": "boatar",
    "boatares": "boatar",
    "boataria": "boatar",
    "boatariam": "boatar",
    "boatarias": "boataria",
    "boatarmo": "boatar",
    "boatarmos": "boatar",
    "boatará": "boatar",
    "boatarás": "boatar",
    "boatarão": "boatar",
    "boataríamos": "boatar",
    "boataríeis": "boatar",
    "boatas": "boatar",
    "boatasse": "boatar",
    "boatassem": "boatar",
    "boatasses": "boatar",
    "boataste": "boatar",
    "boatastes": "boatar",
    "boatava": "boatar",
    "boatavam": "boatar",
    "boatavas": "boatar",
    "boate": "boatar",
    "boatei": "boatar",
    "boateira": "boateiro",
    "boateiras": "boateiro",
    "boateiros": "boateiro",
    "boateis": "boatar",
    "boatem": "boatar",
    "boatemo": "boatar",
    "boatemos": "boatar",
    "boates": "boatar",
    "boatinho": "boato",
    "boatinhos": "boato",
    "boatito": "boato",
    "boatitos": "boato",
    "boato": "boatar",
    "boatos": "boato",
    "boatou": "boatar",
    "boatámo": "boatar",
    "boatámos": "boatar",
    "boatáramo": "boatar",
    "boatáramos": "boatar",
    "boatáreis": "boatar",
    "boatásseis": "boatar",
    "boatássemos": "boatar",
    "boatávamo": "boatar",
    "boatávamos": "boatar",
    "boatáveis": "boatar",
    "boavisteira": "boavisteiro",
    "boavisteiras": "boavisteiro",
    "boavisteiros": "boavisteiro",
    "boazinha": "bom",
    "boazinhas": "bom",
    "boazita": "bom",
    "boazitas": "bom",
    "boba": "bobo",
    "bobagens": "bobagem",
    "bobas": "bobo",
    "bobeada": "bobear",
    "bobeadas": "bobear",
    "bobeado": "bobear",
    "bobeados": "bobear",
    "bobeai": "bobear",
    "bobeais": "bobear",
    "bobeamo": "bobear",
    "bobeamos": "bobear",
    "bobeando": "bobear",
    "bobeara": "bobear",
    "bobearam": "bobear",
    "bobearas": "bobear",
    "bobeardes": "bobear",
    "bobearei": "bobear",
    "bobeareis": "bobear",
    "bobearem": "bobear",
    "bobearemos": "bobear",
    "bobeares": "bobear",
    "bobearia": "bobear",
    "bobeariam": "bobear",
    "bobearias": "bobear",
    "bobearmo": "bobear",
    "bobearmos": "bobear",
    "bobeará": "bobear",
    "bobearás": "bobear",
    "bobearão": "bobear",
    "bobearíamos": "bobear",
    "bobearíeis": "bobear",
    "bobeasse": "bobear",
    "bobeassem": "bobear",
    "bobeasses": "bobear",
    "bobeaste": "bobear",
    "bobeastes": "bobear",
    "bobeava": "bobear",
    "bobeavam": "bobear",
    "bobeavas": "bobear",
    "bobeches": "bobeche",
    "bobeei": "bobear",
    "bobeeis": "bobear",
    "bobeemo": "bobear",
    "bobeemos": "bobear",
    "bobeia": "bobear",
    "bobeiam": "bobear",
    "bobeias": "bobear",
    "bobeie": "bobear",
    "bobeiem": "bobear",
    "bobeies": "bobear",
    "bobeio": "bobear",
    "bobeou": "bobear",
    "bobeámo": "bobear",
    "bobeámos": "bobear",
    "bobeáramo": "bobear",
    "bobeáramos": "bobear",
    "bobeáreis": "bobear",
    "bobeásseis": "bobear",
    "bobeássemos": "bobear",
    "bobeávamo": "bobear",
    "bobeávamos": "bobear",
    "bobeáveis": "bobear",
    "bobices": "bobice",
    "bobina": "bobinar",
    "bobinada": "bobinar",
    "bobinadas": "bobinar",
    "bobinado": "bobinar",
    "bobinadores": "bobinador",
    "bobinados": "bobinar",
    "bobinagens": "bobinagem",
    "bobinai": "bobinar",
    "bobinais": "bobinar",
    "bobinam": "bobinar",
    "bobinamo": "bobinar",
    "bobinamos": "bobinar",
    "bobinando": "bobinar",
    "bobinara": "bobinar",
    "bobinaram": "bobinar",
    "bobinaras": "bobinar",
    "bobinarde": "bobinar",
    "bobinardes": "bobinar",
    "bobinare": "bobinar",
    "bobinarei": "bobinar",
    "bobinareis": "bobinar",
    "bobinarem": "bobinar",
    "bobinaremos": "bobinar",
    "bobinares": "bobinar",
    "bobinaria": "bobinar",
    "bobinariam": "bobinar",
    "bobinarias": "bobinar",
    "bobinarmo": "bobinar",
    "bobinarmos": "bobinar",
    "bobinará": "bobinar",
    "bobinarás": "bobinar",
    "bobinarão": "bobinar",
    "bobinaríamos": "bobinar",
    "bobinaríeis": "bobinar",
    "bobinas": "bobinar",
    "bobinasse": "bobinar",
    "bobinassem": "bobinar",
    "bobinasses": "bobinar",
    "bobinaste": "bobinar",
    "bobinastes": "bobinar",
    "bobinava": "bobinar",
    "bobinavam": "bobinar",
    "bobinavas": "bobinar",
    "bobine": "bobinar",
    "bobinei": "bobinar",
    "bobineis": "bobinar",
    "bobinem": "bobinar",
    "bobinemo": "bobinar",
    "bobinemos": "bobinar",
    "bobines": "bobinar",
    "bobinetes": "bobinete",
    "bobinho": "bobo",
    "bobinhos": "bobo",
    "bobino": "bobinar",
    "bobinou": "bobinar",
    "bobiná": "bobinar",
    "bobinámo": "bobinar",
    "bobinámos": "bobinar",
    "bobináramo": "bobinar",
    "bobináramos": "bobinar",
    "bobinárei": "bobinar",
    "bobináreis": "bobinar",
    "bobinásseis": "bobinar",
    "bobinássemos": "bobinar",
    "bobinávamo": "bobinar",
    "bobinávamos": "bobinar",
    "bobinávei": "bobinar",
    "bobináveis": "bobinar",
    "bobito": "bobo",
    "bobitos": "bobo",
    "bobos": "bobo",
    "bobão": "bobo",
    "bobões": "bobo",
    "boca": "bocar",
    "bocada": "bocar",
    "bocadas": "bocar",
    "bocadeco": "bocado",
    "bocadecos": "bocado",
    "bocadinho": "bocado",
    "bocadinhos": "bocado",
    "bocadito": "bocado",
    "bocaditos": "bocado",
    "bocado": "bocar",
    "bocados": "bocar",
    "bocadões": "bocadão",
    "bocai": "bocar",
    "bocais": "bocar",
    "bocalva": "bocalvo",
    "bocalvas": "bocalvo",
    "bocalvos": "bocalvo",
    "bocam": "bocar",
    "bocamo": "bocar",
    "bocamos": "bocar",
    "bocando": "bocar",
    "bocanhas": "bocanha",
    "bocanhos": "bocanho",
    "bocara": "bocar",
    "bocaram": "bocar",
    "bocaras": "bocar",
    "bocarde": "bocar",
    "bocardes": "bocar",
    "bocare": "bocar",
    "bocarei": "bocar",
    "bocareis": "bocar",
    "bocarem": "bocar",
    "bocaremos": "bocar",
    "bocares": "bocar",
    "bocaria": "bocar",
    "bocariam": "bocar",
    "bocarias": "bocar",
    "bocarmo": "bocar",
    "bocarmos": "bocar",
    "bocarras": "bocarra",
    "bocará": "bocar",
    "bocarás": "bocar",
    "bocarão": "bocar",
    "bocaríamos": "bocar",
    "bocaríeis": "bocar",
    "bocas": "bocar",
    "bocasse": "bocar",
    "bocassem": "bocar",
    "bocasses": "bocar",
    "bocaste": "bocar",
    "bocastes": "bocar",
    "bocava": "bocar",
    "bocavam": "bocar",
    "bocavas": "bocar",
    "bocazinha": "boca",
    "bocazinhas": "boca",
    "bocazita": "boca",
    "bocazitas": "boca",
    "bocaças": "bocaça",
    "boce": "boçar",
    "bocei": "boçar",
    "boceis": "boçar",
    "boceja": "bocejar",
    "bocejada": "bocejar",
    "bocejadas": "bocejar",
    "bocejado": "bocejar",
    "bocejados": "bocejar",
    "bocejai": "bocejar",
    "bocejais": "bocejar",
    "bocejam": "bocejar",
    "bocejamo": "bocejar",
    "bocejamos": "bocejar",
    "bocejando": "bocejar",
    "bocejara": "bocejar",
    "bocejaram": "bocejar",
    "bocejaras": "bocejar",
    "bocejardes": "bocejar",
    "bocejarei": "bocejar",
    "bocejareis": "bocejar",
    "bocejarem": "bocejar",
    "bocejaremos": "bocejar",
    "bocejares": "bocejar",
    "bocejaria": "bocejar",
    "bocejariam": "bocejar",
    "bocejarias": "bocejar",
    "bocejarmo": "bocejar",
    "bocejarmos": "bocejar",
    "bocejará": "bocejar",
    "bocejarás": "bocejar",
    "bocejarão": "bocejar",
    "bocejaríamos": "bocejar",
    "bocejaríeis": "bocejar",
    "bocejas": "bocejar",
    "bocejasse": "bocejar",
    "bocejassem": "bocejar",
    "bocejasses": "bocejar",
    "bocejaste": "bocejar",
    "bocejastes": "bocejar",
    "bocejava": "bocejar",
    "bocejavam": "bocejar",
    "bocejavas": "bocejar",
    "boceje": "bocejar",
    "bocejei": "bocejar",
    "bocejeis": "bocejar",
    "bocejem": "bocejar",
    "bocejemo": "bocejar",
    "bocejemos": "bocejar",
    "bocejes": "bocejar",
    "bocejo": "bocejar",
    "bocejos": "bocejo",
    "bocejou": "bocejar",
    "bocejámo": "bocejar",
    "bocejámos": "bocejar",
    "bocejáramo": "bocejar",
    "bocejáramos": "bocejar",
    "bocejáreis": "bocejar",
    "bocejásseis": "bocejar",
    "bocejássemos": "bocejar",
    "bocejávamo": "bocejar",
    "bocejávamos": "bocejar",
    "bocejáveis": "bocejar",
    "bocela": "bocelar",
    "bocelada": "bocelar",
    "boceladas": "bocelar",
    "bocelado": "bocelar",
    "bocelados": "bocelar",
    "bocelai": "bocelar",
    "bocelais": "bocelar",
    "bocelam": "bocelar",
    "bocelamo": "bocelar",
    "bocelamos": "bocelar",
    "bocelando": "bocelar",
    "bocelara": "bocelar",
    "bocelaram": "bocelar",
    "bocelaras": "bocelar",
    "bocelarde": "bocelar",
    "bocelardes": "bocelar",
    "bocelare": "bocelar",
    "bocelarei": "bocelar",
    "bocelareis": "bocelar",
    "bocelarem": "bocelar",
    "bocelaremos": "bocelar",
    "bocelares": "bocelar",
    "bocelaria": "bocelar",
    "bocelariam": "bocelar",
    "bocelarias": "bocelar",
    "bocelarmo": "bocelar",
    "bocelarmos": "bocelar",
    "bocelará": "bocelar",
    "bocelarás": "bocelar",
    "bocelarão": "bocelar",
    "bocelaríamos": "bocelar",
    "bocelaríeis": "bocelar",
    "bocelas": "bocelar",
    "bocelasse": "bocelar",
    "bocelassem": "bocelar",
    "bocelasses": "bocelar",
    "bocelaste": "bocelar",
    "bocelastes": "bocelar",
    "bocelava": "bocelar",
    "bocelavam": "bocelar",
    "bocelavas": "bocelar",
    "bocele": "bocelar",
    "bocelei": "bocelar",
    "boceleis": "bocelar",
    "bocelem": "bocelar",
    "bocelemo": "bocelar",
    "bocelemos": "bocelar",
    "boceles": "bocelar",
    "bocelinhos": "bocelinho",
    "bocelinos": "bocelino",
    "bocelo": "bocelar",
    "bocelou": "bocelar",
    "bocelá": "bocelar",
    "bocelámo": "bocelar",
    "bocelámos": "bocelar",
    "boceláramo": "bocelar",
    "boceláramos": "bocelar",
    "bocelárei": "bocelar",
    "boceláreis": "bocelar",
    "bocelásseis": "bocelar",
    "bocelássemos": "bocelar",
    "bocelávamo": "bocelar",
    "bocelávamos": "bocelar",
    "bocelávei": "bocelar",
    "boceláveis": "bocelar",
    "bocem": "boçar",
    "bocemo": "boçar",
    "bocemos": "boçar",
    "boces": "boçar",
    "bocetas": "boceta",
    "boceteiros": "boceteiro",
    "bocetes": "bocete",
    "bochecha": "bochechar",
    "bochechada": "bochechar",
    "bochechadas": "bochechar",
    "bochechado": "bochechar",
    "bochechados": "bochechar",
    "bochechai": "bochechar",
    "bochechais": "bochechar",
    "bochecham": "bochechar",
    "bochechamo": "bochechar",
    "bochechamos": "bochechar",
    "bochechando": "bochechar",
    "bochechara": "bochechar",
    "bochecharam": "bochechar",
    "bochecharas": "bochechar",
    "bochecharde": "bochechar",
    "bochechardes": "bochechar",
    "bochechare": "bochechar",
    "bochecharei": "bochechar",
    "bochechareis": "bochechar",
    "bochecharem": "bochechar",
    "bochecharemos": "bochechar",
    "bochechares": "bochechar",
    "bochecharia": "bochechar",
    "bochechariam": "bochechar",
    "bochecharias": "bochechar",
    "bochecharmo": "bochechar",
    "bochecharmos": "bochechar",
    "bochechará": "bochechar",
    "bochecharás": "bochechar",
    "bochecharão": "bochechar",
    "bochecharíamos": "bochechar",
    "bochecharíeis": "bochechar",
    "bochechas": "bochechar",
    "bochechasse": "bochechar",
    "bochechassem": "bochechar",
    "bochechasses": "bochechar",
    "bochechaste": "bochechar",
    "bochechastes": "bochechar",
    "bochechava": "bochechar",
    "bochechavam": "bochechar",
    "bochechavas": "bochechar",
    "bocheche": "bochechar",
    "bochechei": "bochechar",
    "bochecheis": "bochechar",
    "bochechem": "bochechar",
    "bochechemo": "bochechar",
    "bochechemos": "bochechar",
    "bocheches": "bochechar",
    "bochechinha": "bochecha",
    "bochechinhas": "bochecha",
    "bochechita": "bochecha",
    "bochechitas": "bochecha",
    "bochecho": "bochechar",
    "bochechos": "bochecho",
    "bochechou": "bochechar",
    "bochechuda": "bochechudo",
    "bochechudas": "bochechudo",
    "bochechudos": "bochechudo",
    "bochechá": "bochechar",
    "bochechámo": "bochechar",
    "bochechámos": "bochechar",
    "bochecháramo": "bochechar",
    "bochecháramos": "bochechar",
    "bochechárei": "bochechar",
    "bochecháreis": "bochechar",
    "bochechásseis": "bochechar",
    "bochechássemos": "bochechar",
    "bochechávamo": "bochechar",
    "bochechávamos": "bochechar",
    "bochechávei": "bochechar",
    "bochecháveis": "bochechar",
    "bochechões": "bochechão",
    "boches": "boche",
    "bochornais": "bochornal",
    "bochornos": "bochorno",
    "bochornosa": "bochornoso",
    "bochornosas": "bochornoso",
    "bochornosos": "bochornoso",
    "boco": "bocar",
    "bocou": "bocar",
    "bocuda": "bocudo",
    "bocudas": "bocudo",
    "bocudos": "bocudo",
    "bocá": "bocar",
    "bocámo": "bocar",
    "bocámos": "bocar",
    "bocáramo": "bocar",
    "bocáramos": "bocar",
    "bocárei": "bocar",
    "bocáreis": "bocar",
    "bocásseis": "bocar",
    "bocássemos": "bocar",
    "bocávamo": "bocar",
    "bocávamos": "bocar",
    "bocávei": "bocar",
    "bocáveis": "bocar",
    "bocéis": "bocel",
    "bodalhas": "bodalha",
    "bodalhices": "bodalhice",
    "bodalhos": "bodalho",
    "bodalhões": "bodalhão",
    "bodanas": "bodana",
    "bodas": "boda",
    "bodegadas": "bodegada",
    "bodegas": "bodega",
    "bodegona": "bodegão",
    "bodegonas": "bodegão",
    "bodegueira": "bodegueiro",
    "bodegueiras": "bodegueiro",
    "bodegueiros": "bodegueiro",
    "bodeguices": "bodeguice",
    "bodeguinha": "bodega",
    "bodeguinhas": "bodega",
    "bodeguita": "bodega",
    "bodeguitas": "bodega",
    "bodegões": "bodegão",
    "bodeja": "bodejar",
    "bodejada": "bodejar",
    "bodejadas": "bodejar",
    "bodejado": "bodejar",
    "bodejados": "bodejar",
    "bodejai": "bodejar",
    "bodejais": "bodejar",
    "bodejam": "bodejar",
    "bodejamo": "bodejar",
    "bodejamos": "bodejar",
    "bodejando": "bodejar",
    "bodejara": "bodejar",
    "bodejaram": "bodejar",
    "bodejaras": "bodejar",
    "bodejardes": "bodejar",
    "bodejarei": "bodejar",
    "bodejareis": "bodejar",
    "bodejarem": "bodejar",
    "bodejaremos": "bodejar",
    "bodejares": "bodejar",
    "bodejaria": "bodejar",
    "bodejariam": "bodejar",
    "bodejarias": "bodejar",
    "bodejarmo": "bodejar",
    "bodejarmos": "bodejar",
    "bodejará": "bodejar",
    "bodejarás": "bodejar",
    "bodejarão": "bodejar",
    "bodejaríamos": "bodejar",
    "bodejaríeis": "bodejar",
    "bodejas": "bodejar",
    "bodejasse": "bodejar",
    "bodejassem": "bodejar",
    "bodejasses": "bodejar",
    "bodejaste": "bodejar",
    "bodejastes": "bodejar",
    "bodejava": "bodejar",
    "bodejavam": "bodejar",
    "bodejavas": "bodejar",
    "bodeje": "bodejar",
    "bodejei": "bodejar",
    "bodejeis": "bodejar",
    "bodejem": "bodejar",
    "bodejemo": "bodejar",
    "bodejemos": "bodejar",
    "bodejes": "bodejar",
    "bodejo": "bodejar",
    "bodejou": "bodejar",
    "bodejámo": "bodejar",
    "bodejámos": "bodejar",
    "bodejáramo": "bodejar",
    "bodejáramos": "bodejar",
    "bodejáreis": "bodejar",
    "bodejásseis": "bodejar",
    "bodejássemos": "bodejar",
    "bodejávamo": "bodejar",
    "bodejávamos": "bodejar",
    "bodejáveis": "bodejar",
    "bodelhas": "bodelha",
    "bodes": "bode",
    "bodezinho": "bode",
    "bodezinhos": "bode",
    "bodezito": "bode",
    "bodezitos": "bode",
    "bodiões": "bodião",
    "bodoques": "bodoque",
    "bodos": "bodo",
    "boduns": "bodum",
    "boeiras": "boeira",
    "boeirinhas": "boeirinha",
    "boemiazinha": "boémio",
    "boemiazinhas": "boémio",
    "boemiazita": "boémio",
    "boemiazitas": "boémio",
    "boemiozinho": "boémio",
    "boemiozinhos": "boémio",
    "boemiozito": "boémio",
    "boemiozitos": "boémio",
    "boeres": "boer",
    "boers": "boer",
    "bofa": "bofar",
    "bofada": "bofar",
    "bofadas": "bofar",
    "bofado": "bofar",
    "bofados": "bofar",
    "bofai": "bofar",
    "bofais": "bofar",
    "bofam": "bofar",
    "bofamo": "bofar",
    "bofamos": "bofar",
    "bofando": "bofar",
    "bofara": "bofar",
    "bofaram": "bofar",
    "bofaras": "bofar",
    "bofarde": "bofar",
    "bofardes": "bofar",
    "bofare": "bofar",
    "bofarei": "bofar",
    "bofareis": "bofar",
    "bofarem": "bofar",
    "bofaremos": "bofar",
    "bofares": "bofar",
    "bofaria": "bofar",
    "bofariam": "bofar",
    "bofarias": "bofar",
    "bofarmo": "bofar",
    "bofarmos": "bofar",
    "bofará": "bofar",
    "bofarás": "bofar",
    "bofarão": "bofar",
    "bofaríamos": "bofar",
    "bofaríeis": "bofar",
    "bofas": "bofar",
    "bofasse": "bofar",
    "bofassem": "bofar",
    "bofasses": "bofar",
    "bofaste": "bofar",
    "bofastes": "bofar",
    "bofava": "bofar",
    "bofavam": "bofar",
    "bofavas": "bofar",
    "bofe": "bofar",
    "bofei": "bofar",
    "bofeiras": "bofeira",
    "bofeis": "bofar",
    "bofem": "bofar",
    "bofemo": "bofar",
    "bofemos": "bofar",
    "bofes": "bofe",
    "bofetadas": "bofetada",
    "bofetadinha": "bofetada",
    "bofetadinhas": "bofetada",
    "bofetadita": "bofetada",
    "bofetaditas": "bofetada",
    "bofeteada": "bofetear",
    "bofeteadas": "bofetear",
    "bofeteado": "bofetear",
    "bofeteados": "bofetear",
    "bofeteai": "bofetear",
    "bofeteais": "bofetear",
    "bofeteamo": "bofetear",
    "bofeteamos": "bofetear",
    "bofeteando": "bofetear",
    "bofeteara": "bofetear",
    "bofetearam": "bofetear",
    "bofetearas": "bofetear",
    "bofetearde": "bofetear",
    "bofeteardes": "bofetear",
    "bofeteare": "bofetear",
    "bofetearei": "bofetear",
    "bofeteareis": "bofetear",
    "bofetearem": "bofetear",
    "bofetearemos": "bofetear",
    "bofeteares": "bofetear",
    "bofetearia": "bofetear",
    "bofeteariam": "bofetear",
    "bofetearias": "bofetear",
    "bofetearmo": "bofetear",
    "bofetearmos": "bofetear",
    "bofeteará": "bofetear",
    "bofetearás": "bofetear",
    "bofetearão": "bofetear",
    "bofetearíamos": "bofetear",
    "bofetearíeis": "bofetear",
    "bofeteasse": "bofetear",
    "bofeteassem": "bofetear",
    "bofeteasses": "bofetear",
    "bofeteaste": "bofetear",
    "bofeteastes": "bofetear",
    "bofeteava": "bofetear",
    "bofeteavam": "bofetear",
    "bofeteavas": "bofetear",
    "bofeteei": "bofetear",
    "bofeteeis": "bofetear",
    "bofeteemo": "bofetear",
    "bofeteemos": "bofetear",
    "bofeteia": "bofetear",
    "bofeteiam": "bofetear",
    "bofeteias": "bofetear",
    "bofeteie": "bofetear",
    "bofeteiem": "bofetear",
    "bofeteies": "bofetear",
    "bofeteio": "bofetear",
    "bofeteou": "bofetear",
    "bofetes": "bofete",
    "bofeteá": "bofetear",
    "bofeteámo": "bofetear",
    "bofeteámos": "bofetear",
    "bofeteáramo": "bofetear",
    "bofeteáramos": "bofetear",
    "bofeteárei": "bofetear",
    "bofeteáreis": "bofetear",
    "bofeteásseis": "bofetear",
    "bofeteássemos": "bofetear",
    "bofeteávamo": "bofetear",
    "bofeteávamos": "bofetear",
    "bofeteávei": "bofetear",
    "bofeteáveis": "bofetear",
    "bofetões": "bofetão",
    "bofo": "bofar",
    "bofou": "bofar",
    "bofá": "bofar",
    "bofámo": "bofar",
    "bofámos": "bofar",
    "bofáramo": "bofar",
    "bofáramos": "bofar",
    "bofárei": "bofar",
    "bofáreis": "bofar",
    "bofásseis": "bofar",
    "bofássemos": "bofar",
    "bofávamo": "bofar",
    "bofávamos": "bofar",
    "bofávei": "bofar",
    "bofáveis": "bofar",
    "boga": "bogar",
    "bogada": "bogar",
    "bogadas": "bogar",
    "bogado": "bogar",
    "bogados": "bogar",
    "bogai": "bogar",
    "bogais": "bogar",
    "bogam": "bogar",
    "bogamo": "bogar",
    "bogamos": "bogar",
    "bogando": "bogar",
    "bogara": "bogar",
    "bogaram": "bogar",
    "bogaras": "bogar",
    "bogardes": "bogar",
    "bogarei": "bogar",
    "bogareis": "bogar",
    "bogarem": "bogar",
    "bogaremos": "bogar",
    "bogares": "bogar",
    "bogaria": "bogar",
    "bogariam": "bogar",
    "bogarias": "bogar",
    "bogarins": "bogarim",
    "bogaris": "bogari",
    "bogarmo": "bogar",
    "bogarmos": "bogar",
    "bogará": "bogar",
    "bogarás": "bogar",
    "bogarão": "bogar",
    "bogaríamos": "bogar",
    "bogaríeis": "bogar",
    "bogas": "bogar",
    "bogasse": "bogar",
    "bogassem": "bogar",
    "bogasses": "bogar",
    "bogaste": "bogar",
    "bogastes": "bogar",
    "bogava": "bogar",
    "bogavam": "bogar",
    "bogavas": "bogar",
    "bogo": "bogar",
    "bogomila": "bogomilo",
    "bogomilas": "bogomilo",
    "bogomilos": "bogomilo",
    "bogotana": "bogotano",
    "bogotanas": "bogotano",
    "bogotanos": "bogotano",
    "bogou": "bogar",
    "bogue": "bogar",
    "boguei": "bogar",
    "bogueiras": "bogueira",
    "bogueiros": "bogueiro",
    "bogueis": "bogar",
    "boguem": "bogar",
    "boguemo": "bogar",
    "boguemos": "bogar",
    "bogues": "bogar",
    "bogámo": "bogar",
    "bogámos": "bogar",
    "bogáramo": "bogar",
    "bogáramos": "bogar",
    "bogáreis": "bogar",
    "bogásseis": "bogar",
    "bogássemos": "bogar",
    "bogávamo": "bogar",
    "bogávamos": "bogar",
    "bogáveis": "bogar",
    "boiada": "boiar",
    "boiadas": "boiar",
    "boiado": "boiar",
    "boiados": "boiar",
    "boiai": "boiar",
    "boiais": "boiar",
    "boiamo": "boiar",
    "boiamos": "boiar",
    "boiando": "boiar",
    "boiantes": "boiante",
    "boiara": "boiar",
    "boiaram": "boiar",
    "boiaras": "boiar",
    "boiarde": "boiar",
    "boiardes": "boiar",
    "boiardos": "boiardo",
    "boiare": "boiar",
    "boiarei": "boiar",
    "boiareis": "boiar",
    "boiarem": "boiar",
    "boiaremos": "boiar",
    "boiares": "boiar",
    "boiaria": "boiar",
    "boiariam": "boiar",
    "boiarias": "boiar",
    "boiarmo": "boiar",
    "boiarmos": "boiar",
    "boiará": "boiar",
    "boiarás": "boiar",
    "boiarão": "boiar",
    "boiaríamos": "boiar",
    "boiaríeis": "boiar",
    "boiasse": "boiar",
    "boiassem": "boiar",
    "boiasses": "boiar",
    "boiaste": "boiar",
    "boiastes": "boiar",
    "boiava": "boiar",
    "boiavam": "boiar",
    "boiavas": "boiar",
    "boice": "boiçar",
    "boicei": "boiçar",
    "boiceiras": "boiceira",
    "boiceis": "boiçar",
    "boicem": "boiçar",
    "boicemo": "boiçar",
    "boicemos": "boiçar",
    "boices": "boiçar",
    "boicoatiaras": "boicoatiara",
    "boicota": "boicotar",
    "boicotada": "boicotar",
    "boicotadas": "boicotar",
    "boicotado": "boicotar",
    "boicotados": "boicotar",
    "boicotagens": "boicotagem",
    "boicotai": "boicotar",
    "boicotais": "boicotar",
    "boicotam": "boicotar",
    "boicotamo": "boicotar",
    "boicotamos": "boicotar",
    "boicotando": "boicotar",
    "boicotara": "boicotar",
    "boicotaram": "boicotar",
    "boicotaras": "boicotar",
    "boicotarde": "boicotar",
    "boicotardes": "boicotar",
    "boicotare": "boicotar",
    "boicotarei": "boicotar",
    "boicotareis": "boicotar",
    "boicotarem": "boicotar",
    "boicotaremos": "boicotar",
    "boicotares": "boicotar",
    "boicotaria": "boicotar",
    "boicotariam": "boicotar",
    "boicotarias": "boicotar",
    "boicotarmo": "boicotar",
    "boicotarmos": "boicotar",
    "boicotará": "boicotar",
    "boicotarás": "boicotar",
    "boicotarão": "boicotar",
    "boicotaríamos": "boicotar",
    "boicotaríeis": "boicotar",
    "boicotas": "boicotar",
    "boicotasse": "boicotar",
    "boicotassem": "boicotar",
    "boicotasses": "boicotar",
    "boicotaste": "boicotar",
    "boicotastes": "boicotar",
    "boicotava": "boicotar",
    "boicotavam": "boicotar",
    "boicotavas": "boicotar",
    "boicote": "boicotar",
    "boicoteada": "boicotear",
    "boicoteadas": "boicotear",
    "boicoteado": "boicotear",
    "boicoteados": "boicotear",
    "boicoteai": "boicotear",
    "boicoteais": "boicotear",
    "boicoteamo": "boicotear",
    "boicoteamos": "boicotear",
    "boicoteando": "boicotear",
    "boicoteara": "boicotear",
    "boicotearam": "boicotear",
    "boicotearas": "boicotear",
    "boicotearde": "boicotear",
    "boicoteardes": "boicotear",
    "boicoteare": "boicotear",
    "boicotearei": "boicotear",
    "boicoteareis": "boicotear",
    "boicotearem": "boicotear",
    "boicotearemos": "boicotear",
    "boicoteares": "boicotear",
    "boicotearia": "boicotear",
    "boicoteariam": "boicotear",
    "boicotearias": "boicotear",
    "boicotearmo": "boicotear",
    "boicotearmos": "boicotear",
    "boicoteará": "boicotear",
    "boicotearás": "boicotear",
    "boicotearão": "boicotear",
    "boicotearíamos": "boicotear",
    "boicotearíeis": "boicotear",
    "boicoteasse": "boicotear",
    "boicoteassem": "boicotear",
    "boicoteasses": "boicotear",
    "boicoteaste": "boicotear",
    "boicoteastes": "boicotear",
    "boicoteava": "boicotear",
    "boicoteavam": "boicotear",
    "boicoteavas": "boicotear",
    "boicoteei": "boicotear",
    "boicoteeis": "boicotear",
    "boicoteemo": "boicotear",
    "boicoteemos": "boicotear",
    "boicotei": "boicotar",
    "boicoteia": "boicotear",
    "boicoteiam": "boicotear",
    "boicoteias": "boicotear",
    "boicoteie": "boicotear",
    "boicoteiem": "boicotear",
    "boicoteies": "boicotear",
    "boicoteio": "boicotear",
    "boicoteis": "boicotar",
    "boicotem": "boicotar",
    "boicotemo": "boicotar",
    "boicotemos": "boicotar",
    "boicoteou": "boicotear",
    "boicotes": "boicote",
    "boicoteá": "boicotear",
    "boicoteámo": "boicotear",
    "boicoteámos": "boicotear",
    "boicoteáramo": "boicotear",
    "boicoteáramos": "boicotear",
    "boicoteárei": "boicotear",
    "boicoteáreis": "boicotear",
    "boicoteásseis": "boicotear",
    "boicoteássemos": "boicotear",
    "boicoteávamo": "boicotear",
    "boicoteávamos": "boicotear",
    "boicoteávei": "boicotear",
    "boicoteáveis": "boicotear",
    "boicoto": "boicotar",
    "boicotou": "boicotar",
    "boicotá": "boicotar",
    "boicotámo": "boicotar",
    "boicotámos": "boicotar",
    "boicotáramo": "boicotar",
    "boicotáramos": "boicotar",
    "boicotárei": "boicotar",
    "boicotáreis": "boicotar",
    "boicotásseis": "boicotar",
    "boicotássemos": "boicotar",
    "boicotávamo": "boicotar",
    "boicotávamos": "boicotar",
    "boicotávei": "boicotar",
    "boicotáveis": "boicotável",
    "boiei": "boiar",
    "boieira": "boieiro",
    "boieiras": "boieiro",
    "boieiros": "boieiro",
    "boieis": "boiar",
    "boiemo": "boiar",
    "boiemos": "boiar",
    "boinas": "boina",
    "boininha": "boina",
    "boininhas": "boina",
    "boinita": "boina",
    "boinitas": "boina",
    "boiou": "boiar",
    "boiréis": "boirel",
    "bois": "boi",
    "boitas": "boita",
    "boites": "boite",
    "boiuna": "boiuno",
    "boiunas": "boiuno",
    "boiunos": "boiuno",
    "boizes": "boiz",
    "boizinho": "boi",
    "boizinhos": "boi",
    "boizito": "boi",
    "boizitos": "boi",
    "boiá": "boiar",
    "boiámo": "boiar",
    "boiámos": "boiar",
    "boiáramo": "boiar",
    "boiáramos": "boiar",
    "boiárei": "boiar",
    "boiáreis": "boiar",
    "boiásseis": "boiar",
    "boiássemos": "boiar",
    "boiávamo": "boiar",
    "boiávamos": "boiar",
    "boiávei": "boiar",
    "boiáveis": "boiar",
    "boiça": "boiçar",
    "boiçada": "boiçar",
    "boiçadas": "boiçar",
    "boiçado": "boiçar",
    "boiçados": "boiçar",
    "boiçai": "boiçar",
    "boiçais": "boiçar",
    "boiçam": "boiçar",
    "boiçamo": "boiçar",
    "boiçamos": "boiçar",
    "boiçando": "boiçar",
    "boiçara": "boiçar",
    "boiçaram": "boiçar",
    "boiçaras": "boiçar",
    "boiçarde": "boiçar",
    "boiçardes": "boiçar",
    "boiçare": "boiçar",
    "boiçarei": "boiçar",
    "boiçareis": "boiçar",
    "boiçarem": "boiçar",
    "boiçaremos": "boiçar",
    "boiçares": "boiçar",
    "boiçaria": "boiçar",
    "boiçariam": "boiçar",
    "boiçarias": "boiçar",
    "boiçarmo": "boiçar",
    "boiçarmos": "boiçar",
    "boiçará": "boiçar",
    "boiçarás": "boiçar",
    "boiçarão": "boiçar",
    "boiçaríamos": "boiçar",
    "boiçaríeis": "boiçar",
    "boiças": "boiçar",
    "boiçasse": "boiçar",
    "boiçassem": "boiçar",
    "boiçasses": "boiçar",
    "boiçaste": "boiçar",
    "boiçastes": "boiçar",
    "boiçava": "boiçar",
    "boiçavam": "boiçar",
    "boiçavas": "boiçar",
    "boiço": "boiçar",
    "boiçou": "boiçar",
    "boiçá": "boiçar",
    "boiçámo": "boiçar",
    "boiçámos": "boiçar",
    "boiçáramo": "boiçar",
    "boiçáramos": "boiçar",
    "boiçárei": "boiçar",
    "boiçáreis": "boiçar",
    "boiçásseis": "boiçar",
    "boiçássemos": "boiçar",
    "boiçávamo": "boiçar",
    "boiçávamos": "boiçar",
    "boiçávei": "boiçar",
    "boiçáveis": "boiçar",
    "boiões": "boião",
    "boja": "bojar",
    "bojada": "bojar",
    "bojadas": "bojar",
    "bojado": "bojar",
    "bojadora": "bojador",
    "bojadoras": "bojador",
    "bojadores": "bojador",
    "bojados": "bojar",
    "bojaduras": "bojadura",
    "bojai": "bojar",
    "bojais": "bojar",
    "bojam": "bojar",
    "bojamo": "bojar",
    "bojamos": "bojar",
    "bojando": "bojar",
    "bojantes": "bojante",
    "bojanças": "bojança",
    "bojara": "bojar",
    "bojaram": "bojar",
    "bojaras": "bojar",
    "bojardas": "bojarda",
    "bojarde": "bojar",
    "bojardes": "bojar",
    "bojare": "bojar",
    "bojarei": "bojar",
    "bojareis": "bojar",
    "bojarem": "bojar",
    "bojaremos": "bojar",
    "bojares": "bojar",
    "bojaria": "bojar",
    "bojariam": "bojar",
    "bojarias": "bojar",
    "bojarmo": "bojar",
    "bojarmos": "bojar",
    "bojará": "bojar",
    "bojarás": "bojar",
    "bojarão": "bojar",
    "bojaríamos": "bojar",
    "bojaríeis": "bojar",
    "bojas": "bojar",
    "bojasse": "bojar",
    "bojassem": "bojar",
    "bojasses": "bojar",
    "bojaste": "bojar",
    "bojastes": "bojar",
    "bojava": "bojar",
    "bojavam": "bojar",
    "bojavas": "bojar",
    "boje": "bojar",
    "bojegas": "bojega",
    "bojegos": "bojego",
    "bojei": "bojar",
    "bojeis": "bojar",
    "bojem": "bojar",
    "bojemo": "bojar",
    "bojemos": "bojar",
    "bojes": "bojar",
    "bojo": "bojar",
    "bojos": "bojo",
    "bojou": "bojar",
    "bojuda": "bojudo",
    "bojudas": "bojudo",
    "bojudos": "bojudo",
    "bojá": "bojar",
    "bojámo": "bojar",
    "bojámos": "bojar",
    "bojáramo": "bojar",
    "bojáramos": "bojar",
    "bojárei": "bojar",
    "bojáreis": "bojar",
    "bojásseis": "bojar",
    "bojássemos": "bojar",
    "bojávamo": "bojar",
    "bojávamos": "bojar",
    "bojávei": "bojar",
    "bojáveis": "bojar",
    "bola": "bolar",
    "bolachadas": "bolachada",
    "bolachas": "bolacha",
    "bolacheira": "bolacheiro",
    "bolacheiras": "bolacheiro",
    "bolacheirona": "bolacheirão",
    "bolacheironas": "bolacheirão",
    "bolacheiros": "bolacheiro",
    "bolacheirões": "bolacheirão",
    "bolachinha": "bolacha",
    "bolachinhas": "bolacha",
    "bolachita": "bolacha",
    "bolachitas": "bolacha",
    "bolachuda": "bolachudo",
    "bolachudas": "bolachudo",
    "bolachudos": "bolachudo",
    "bolada": "bolar",
    "boladas": "bolar",
    "bolado": "bolar",
    "bolados": "bolar",
    "bolai": "bolar",
    "bolais": "bolar",
    "bolam": "bolar",
    "bolamo": "bolar",
    "bolamos": "bolar",
    "bolando": "bolar",
    "bolanhas": "bolanha",
    "bolara": "bolar",
    "bolaram": "bolar",
    "bolaras": "bolar",
    "bolarde": "bolar",
    "bolardes": "bolar",
    "bolare": "bolar",
    "bolarei": "bolar",
    "bolareis": "bolar",
    "bolarem": "bolar",
    "bolaremos": "bolar",
    "bolares": "bolar",
    "bolaria": "bolar",
    "bolariam": "bolar",
    "bolarias": "bolar",
    "bolarmo": "bolar",
    "bolarmos": "bolar",
    "bolará": "bolar",
    "bolarás": "bolar",
    "bolarão": "bolar",
    "bolaríamos": "bolar",
    "bolaríeis": "bolar",
    "bolas": "bolar",
    "bolasse": "bolar",
    "bolassem": "bolar",
    "bolasses": "bolar",
    "bolaste": "bolar",
    "bolastes": "bolar",
    "bolava": "bolar",
    "bolavam": "bolar",
    "bolavas": "bolar",
    "bolbos": "bolbo",
    "bolbosa": "bolboso",
    "bolbosas": "bolboso",
    "bolbosos": "bolboso",
    "bolbuda": "bolbudo",
    "bolbudas": "bolbudo",
    "bolbudos": "bolbudo",
    "bolce": "bolçar",
    "bolcei": "bolçar",
    "bolceis": "bolçar",
    "bolcem": "bolçar",
    "bolcemo": "bolçar",
    "bolcemos": "bolçar",
    "bolces": "bolçar",
    "bolcheviques": "bolchevique",
    "bolchevismos": "bolchevismo",
    "bolchevistas": "bolchevista",
    "bolcheviza": "bolchevizar",
    "bolchevizada": "bolchevizar",
    "bolchevizadas": "bolchevizar",
    "bolchevizado": "bolchevizar",
    "bolchevizados": "bolchevizar",
    "bolchevizai": "bolchevizar",
    "bolchevizais": "bolchevizar",
    "bolchevizam": "bolchevizar",
    "bolchevizamo": "bolchevizar",
    "bolchevizamos": "bolchevizar",
    "bolchevizando": "bolchevizar",
    "bolchevizantes": "bolchevizante",
    "bolchevizara": "bolchevizar",
    "bolchevizaram": "bolchevizar",
    "bolchevizaras": "bolchevizar",
    "bolchevizarde": "bolchevizar",
    "bolchevizardes": "bolchevizar",
    "bolchevizare": "bolchevizar",
    "bolchevizarei": "bolchevizar",
    "bolchevizareis": "bolchevizar",
    "bolchevizarem": "bolchevizar",
    "bolchevizaremos": "bolchevizar",
    "bolchevizares": "bolchevizar",
    "bolchevizaria": "bolchevizar",
    "bolchevizariam": "bolchevizar",
    "bolchevizarias": "bolchevizar",
    "bolchevizarmo": "bolchevizar",
    "bolchevizarmos": "bolchevizar",
    "bolchevizará": "bolchevizar",
    "bolchevizarás": "bolchevizar",
    "bolchevizarão": "bolchevizar",
    "bolchevizaríamos": "bolchevizar",
    "bolchevizaríeis": "bolchevizar",
    "bolchevizas": "bolchevizar",
    "bolchevizasse": "bolchevizar",
    "bolchevizassem": "bolchevizar",
    "bolchevizasses": "bolchevizar",
    "bolchevizaste": "bolchevizar",
    "bolchevizastes": "bolchevizar",
    "bolchevizava": "bolchevizar",
    "bolchevizavam": "bolchevizar",
    "bolchevizavas": "bolchevizar",
    "bolchevizações": "bolchevização",
    "bolchevize": "bolchevizar",
    "bolchevizei": "bolchevizar",
    "bolchevizeis": "bolchevizar",
    "bolchevizem": "bolchevizar",
    "bolchevizemo": "bolchevizar",
    "bolchevizemos": "bolchevizar",
    "bolchevizes": "bolchevizar",
    "bolchevizo": "bolchevizar",
    "bolchevizou": "bolchevizar",
    "bolchevizá": "bolchevizar",
    "bolchevizámo": "bolchevizar",
    "bolchevizámos": "bolchevizar",
    "bolchevizáramo": "bolchevizar",
    "bolchevizáramos": "bolchevizar",
    "bolchevizárei": "bolchevizar",
    "bolchevizáreis": "bolchevizar",
    "bolchevizásseis": "bolchevizar",
    "bolchevizássemos": "bolchevizar",
    "bolchevizávamo": "bolchevizar",
    "bolchevizávamos": "bolchevizar",
    "bolchevizávei": "bolchevizar",
    "bolchevizáveis": "bolchevizar",
    "boldos": "boldo",
    "boldriés": "boldrié",
    "bole": "bolar",
    "boleada": "bolear",
    "boleadas": "bolear",
    "boleado": "bolear",
    "boleados": "bolear",
    "boleai": "bolear",
    "boleais": "bolear",
    "boleamentos": "boleamento",
    "boleamo": "bolear",
    "boleamos": "bolear",
    "boleando": "bolear",
    "boleara": "bolear",
    "bolearam": "bolear",
    "bolearas": "bolear",
    "bolearde": "bolear",
    "boleardes": "bolear",
    "boleare": "bolear",
    "bolearei": "bolear",
    "boleareis": "bolear",
    "bolearem": "bolear",
    "bolearemos": "bolear",
    "boleares": "bolear",
    "bolearia": "bolear",
    "boleariam": "bolear",
    "bolearias": "bolear",
    "bolearmo": "bolear",
    "bolearmos": "bolear",
    "boleará": "bolear",
    "bolearás": "bolear",
    "bolearão": "bolear",
    "bolearíamos": "bolear",
    "bolearíeis": "bolear",
    "boleasse": "bolear",
    "boleassem": "bolear",
    "boleasses": "bolear",
    "boleaste": "bolear",
    "boleastes": "bolear",
    "boleava": "bolear",
    "boleavam": "bolear",
    "boleavas": "bolear",
    "boleei": "bolear",
    "boleeira": "boleeiro",
    "boleeiras": "boleeiro",
    "boleeiros": "boleeiro",
    "boleeis": "bolear",
    "boleemo": "bolear",
    "boleemos": "bolear",
    "bolei": "bolar",
    "boleia": "bolear",
    "boleiam": "bolear",
    "boleias": "boleia",
    "boleie": "bolear",
    "boleiem": "bolear",
    "boleies": "bolear",
    "boleimas": "boleima",
    "boleio": "bolear",
    "boleios": "boleio",
    "boleira": "boleiro",
    "boleiras": "boleiro",
    "boleiros": "boleiro",
    "boleis": "bolar",
    "bolem": "bolar",
    "bolemo": "bolar",
    "bolemos": "bolar",
    "boleou": "bolear",
    "boleros": "bolero",
    "boles": "bolar",
    "boleta": "boleto",
    "boletada": "boletar",
    "boletadas": "boletar",
    "boletado": "boletar",
    "boletados": "boletar",
    "boletai": "boletar",
    "boletais": "boletar",
    "boletam": "boletar",
    "boletamo": "boletar",
    "boletamos": "boletar",
    "boletando": "boletar",
    "boletara": "boletar",
    "boletaram": "boletar",
    "boletaras": "boletar",
    "boletarde": "boletar",
    "boletardes": "boletar",
    "boletare": "boletar",
    "boletarei": "boletar",
    "boletareis": "boletar",
    "boletarem": "boletar",
    "boletaremos": "boletar",
    "boletares": "boletar",
    "boletaria": "boletar",
    "boletariam": "boletar",
    "boletarias": "boletar",
    "boletarmo": "boletar",
    "boletarmos": "boletar",
    "boletará": "boletar",
    "boletarás": "boletar",
    "boletarão": "boletar",
    "boletaríamos": "boletar",
    "boletaríeis": "boletar",
    "boletas": "boleto",
    "boletasse": "boletar",
    "boletassem": "boletar",
    "boletasses": "boletar",
    "boletaste": "boletar",
    "boletastes": "boletar",
    "boletava": "boletar",
    "boletavam": "boletar",
    "boletavas": "boletar",
    "bolete": "boletar",
    "boletei": "boletar",
    "boleteis": "boletar",
    "boletem": "boletar",
    "boletemo": "boletar",
    "boletemos": "boletar",
    "boletes": "bolete",
    "boletineira": "boletineiro",
    "boletineiras": "boletineiro",
    "boletineiros": "boletineiro",
    "boletinistas": "boletinista",
    "boletins": "boletim",
    "boletinzinho": "boletim",
    "boletinzinhos": "boletim",
    "boletinzito": "boletim",
    "boletinzitos": "boletim",
    "boleto": "boletar",
    "boletos": "boleto",
    "boletou": "boletar",
    "boletá": "boletar",
    "boletámo": "boletar",
    "boletámos": "boletar",
    "boletáramo": "boletar",
    "boletáramos": "boletar",
    "boletárei": "boletar",
    "boletáreis": "boletar",
    "boletásseis": "boletar",
    "boletássemos": "boletar",
    "boletávamo": "boletar",
    "boletávamos": "boletar",
    "boletávei": "boletar",
    "boletáveis": "boletar",
    "boleá": "bolear",
    "boleámo": "bolear",
    "boleámos": "bolear",
    "boleáramo": "bolear",
    "boleáramos": "bolear",
    "boleárei": "bolear",
    "boleáreis": "bolear",
    "boleásseis": "bolear",
    "boleássemos": "bolear",
    "boleávamo": "bolear",
    "boleávamos": "bolear",
    "boleávei": "bolear",
    "boleáveis": "bolear",
    "bolha": "bolhar",
    "bolhada": "bolhar",
    "bolhadas": "bolhar",
    "bolhado": "bolhar",
    "bolhados": "bolhar",
    "bolhai": "bolhar",
    "bolhais": "bolhar",
    "bolham": "bolhar",
    "bolhamo": "bolhar",
    "bolhamos": "bolhar",
    "bolhando": "bolhar",
    "bolhantes": "bolhante",
    "bolhara": "bolhar",
    "bolharam": "bolhar",
    "bolharas": "bolhar",
    "bolharde": "bolhar",
    "bolhardes": "bolhar",
    "bolhare": "bolhar",
    "bolharei": "bolhar",
    "bolhareis": "bolhar",
    "bolharem": "bolhar",
    "bolharemos": "bolhar",
    "bolhares": "bolhar",
    "bolharia": "bolhar",
    "bolhariam": "bolhar",
    "bolharias": "bolhar",
    "bolharmo": "bolhar",
    "bolharmos": "bolhar",
    "bolhará": "bolhar",
    "bolharás": "bolhar",
    "bolharão": "bolhar",
    "bolharíamos": "bolhar",
    "bolharíeis": "bolhar",
    "bolhas": "bolhar",
    "bolhasse": "bolhar",
    "bolhassem": "bolhar",
    "bolhasses": "bolhar",
    "bolhaste": "bolhar",
    "bolhastes": "bolhar",
    "bolhava": "bolhar",
    "bolhavam": "bolhar",
    "bolhavas": "bolhar",
    "bolhe": "bolhar",
    "bolhei": "bolhar",
    "bolheis": "bolhar",
    "bolhelha": "bolhelho",
    "bolhelhas": "bolhelho",
    "bolhelhos": "bolhelho",
    "bolhem": "bolhar",
    "bolhemo": "bolhar",
    "bolhemos": "bolhar",
    "bolhenta": "bolhento",
    "bolhentas": "bolhento",
    "bolhentos": "bolhento",
    "bolhes": "bolhar",
    "bolhinha": "bolha",
    "bolhinhas": "bolha",
    "bolhita": "bolha",
    "bolhitas": "bolha",
    "bolho": "bolhar",
    "bolhosa": "bolhoso",
    "bolhosas": "bolhoso",
    "bolhosos": "bolhoso",
    "bolhou": "bolhar",
    "bolhuda": "bolhudo",
    "bolhudas": "bolhudo",
    "bolhudos": "bolhudo",
    "bolhá": "bolhar",
    "bolhámo": "bolhar",
    "bolhámos": "bolhar",
    "bolháramo": "bolhar",
    "bolháramos": "bolhar",
    "bolhárei": "bolhar",
    "bolháreis": "bolhar",
    "bolhásseis": "bolhar",
    "bolhássemos": "bolhar",
    "bolhávamo": "bolhar",
    "bolhávamos": "bolhar",
    "bolhávei": "bolhar",
    "bolháveis": "bolhar",
    "bolhões": "bolhão",
    "bolina": "bolinar",
    "bolinada": "bolinar",
    "bolinadas": "bolinar",
    "bolinado": "bolinar",
    "bolinados": "bolinar",
    "bolinagens": "bolinagem",
    "bolinai": "bolinar",
    "bolinais": "bolinar",
    "bolinam": "bolinar",
    "bolinamo": "bolinar",
    "bolinamos": "bolinar",
    "bolinando": "bolinar",
    "bolinara": "bolinar",
    "bolinaram": "bolinar",
    "bolinaras": "bolinar",
    "bolinardes": "bolinar",
    "bolinarei": "bolinar",
    "bolinareis": "bolinar",
    "bolinarem": "bolinar",
    "bolinaremos": "bolinar",
    "bolinares": "bolinar",
    "bolinaria": "bolinar",
    "bolinariam": "bolinar",
    "bolinarias": "bolinar",
    "bolinarmo": "bolinar",
    "bolinarmos": "bolinar",
    "bolinará": "bolinar",
    "bolinarás": "bolinar",
    "bolinarão": "bolinar",
    "bolinaríamos": "bolinar",
    "bolinaríeis": "bolinar",
    "bolinas": "bolinar",
    "bolinasse": "bolinar",
    "bolinassem": "bolinar",
    "bolinasses": "bolinar",
    "bolinaste": "bolinar",
    "bolinastes": "bolinar",
    "bolinava": "bolinar",
    "bolinavam": "bolinar",
    "bolinavas": "bolinar",
    "boline": "bolinar",
    "bolinei": "bolinar",
    "bolineira": "bolineiro",
    "bolineiras": "bolineiro",
    "bolineiros": "bolineiro",
    "bolineis": "bolinar",
    "bolinem": "bolinar",
    "bolinemo": "bolinar",
    "bolinemos": "bolinar",
    "bolines": "bolinar",
    "bolinetes": "bolinete",
    "bolinha": "bola",
    "bolinhas": "bola",
    "bolinho": "bolo",
    "bolinhos": "bolo",
    "bolinhós": "bolinhó",
    "bolino": "bolinar",
    "bolinou": "bolinar",
    "bolins": "bolim",
    "bolinámo": "bolinar",
    "bolinámos": "bolinar",
    "bolináramo": "bolinar",
    "bolináramos": "bolinar",
    "bolináreis": "bolinar",
    "bolinásseis": "bolinar",
    "bolinássemos": "bolinar",
    "bolinávamo": "bolinar",
    "bolinávamos": "bolinar",
    "bolináveis": "bolinar",
    "bolita": "bola",
    "bolitas": "bola",
    "bolito": "bolo",
    "bolitos": "bolo",
    "boliviana": "boliviano",
    "bolivianas": "boliviano",
    "bolivianos": "boliviano",
    "bolo": "bolar",
    "bolometrias": "bolometria",
    "bolométrica": "bolométrico",
    "bolométricas": "bolométrico",
    "bolométricos": "bolométrico",
    "bolonhesa": "bolonhês",
    "bolonhesas": "bolonhês",
    "bolonheses": "bolonhês",
    "bolorece": "bolorecer",
    "bolorecei": "bolorecer",
    "boloreceis": "bolorecer",
    "bolorecem": "bolorecer",
    "bolorecemo": "bolorecer",
    "bolorecemos": "bolorecer",
    "bolorecendo": "bolorecer",
    "bolorecera": "bolorecer",
    "boloreceram": "bolorecer",
    "boloreceras": "bolorecer",
    "bolorecerdes": "bolorecer",
    "bolorecerei": "bolorecer",
    "bolorecereis": "bolorecer",
    "bolorecerem": "bolorecer",
    "boloreceremos": "bolorecer",
    "boloreceres": "bolorecer",
    "boloreceria": "bolorecer",
    "boloreceriam": "bolorecer",
    "bolorecerias": "bolorecer",
    "bolorecermo": "bolorecer",
    "bolorecermos": "bolorecer",
    "bolorecerá": "bolorecer",
    "bolorecerás": "bolorecer",
    "bolorecerão": "bolorecer",
    "boloreceríamos": "bolorecer",
    "boloreceríeis": "bolorecer",
    "boloreces": "bolorecer",
    "bolorecesse": "bolorecer",
    "bolorecessem": "bolorecer",
    "bolorecesses": "bolorecer",
    "boloreceste": "bolorecer",
    "bolorecestes": "bolorecer",
    "boloreceu": "bolorecer",
    "boloreci": "bolorecer",
    "bolorecia": "bolorecer",
    "boloreciam": "bolorecer",
    "bolorecias": "bolorecer",
    "bolorecida": "bolorecer",
    "bolorecidas": "bolorecer",
    "bolorecido": "bolorecer",
    "bolorecidos": "bolorecer",
    "bolorecêramo": "bolorecer",
    "bolorecêramos": "bolorecer",
    "bolorecêreis": "bolorecer",
    "bolorecêsseis": "bolorecer",
    "bolorecêssemos": "bolorecer",
    "bolorecíamo": "bolorecer",
    "bolorecíamos": "bolorecer",
    "bolorecíeis": "bolorecer",
    "bolorenta": "bolorento",
    "bolorentas": "bolorento",
    "bolorentos": "bolorento",
    "bolores": "bolor",
    "bolorescências": "bolorescência",
    "boloreça": "bolorecer",
    "boloreçais": "bolorecer",
    "boloreçam": "bolorecer",
    "boloreçamo": "bolorecer",
    "boloreçamos": "bolorecer",
    "boloreças": "bolorecer",
    "boloreço": "bolorecer",
    "bolorzinho": "bolor",
    "bolorzinhos": "bolor",
    "bolorzito": "bolor",
    "bolorzitos": "bolor",
    "bolorências": "bolorência",
    "bolos": "bolo",
    "bolotada": "bolotado",
    "bolotadas": "bolotado",
    "bolotados": "bolotado",
    "bolotais": "bolotal",
    "bolotas": "bolota",
    "bolou": "bolar",
    "bolozinho": "bolo",
    "bolozinhos": "bolo",
    "bolozito": "bolo",
    "bolozitos": "bolo",
    "bolsa": "bolsar",
    "bolsada": "bolsar",
    "bolsadas": "bolsar",
    "bolsado": "bolsar",
    "bolsados": "bolsar",
    "bolsai": "bolsar",
    "bolsais": "bolsar",
    "bolsam": "bolsar",
    "bolsamo": "bolsar",
    "bolsamos": "bolsar",
    "bolsando": "bolsar",
    "bolsara": "bolsar",
    "bolsaram": "bolsar",
    "bolsaras": "bolsar",
    "bolsarde": "bolsar",
    "bolsardes": "bolsar",
    "bolsare": "bolsar",
    "bolsarei": "bolsar",
    "bolsareis": "bolsar",
    "bolsarem": "bolsar",
    "bolsaremos": "bolsar",
    "bolsares": "bolsar",
    "bolsaria": "bolsar",
    "bolsariam": "bolsar",
    "bolsarias": "bolsar",
    "bolsarmo": "bolsar",
    "bolsarmos": "bolsar",
    "bolsará": "bolsar",
    "bolsarás": "bolsar",
    "bolsarão": "bolsar",
    "bolsaríamos": "bolsar",
    "bolsaríeis": "bolsar",
    "bolsas": "bolsar",
    "bolsasse": "bolsar",
    "bolsassem": "bolsar",
    "bolsasses": "bolsar",
    "bolsaste": "bolsar",
    "bolsastes": "bolsar",
    "bolsava": "bolsar",
    "bolsavam": "bolsar",
    "bolsavas": "bolsar",
    "bolse": "bolsar",
    "bolsei": "bolsar",
    "bolseira": "bolseiro",
    "bolseiras": "bolseiro",
    "bolseiros": "bolseiro",
    "bolseis": "bolsar",
    "bolselos": "bolselo",
    "bolsem": "bolsar",
    "bolsemo": "bolsar",
    "bolsemos": "bolsar",
    "bolses": "bolsar",
    "bolsinha": "bolsa",
    "bolsinhas": "bolsa",
    "bolsinho": "bolso",
    "bolsinhos": "bolso",
    "bolsistas": "bolsista",
    "bolsita": "bolsa",
    "bolsitas": "bolsa",
    "bolsito": "bolso",
    "bolsitos": "bolso",
    "bolso": "bolsar",
    "bolsos": "bolso",
    "bolsou": "bolsar",
    "bolsá": "bolsar",
    "bolsámo": "bolsar",
    "bolsámos": "bolsar",
    "bolsáramo": "bolsar",
    "bolsáramos": "bolsar",
    "bolsárei": "bolsar",
    "bolsáreis": "bolsar",
    "bolsásseis": "bolsar",
    "bolsássemos": "bolsar",
    "bolsávamo": "bolsar",
    "bolsávamos": "bolsar",
    "bolsávei": "bolsar",
    "bolsáveis": "bolsar",
    "bolsões": "bolsão",
    "bolá": "bolar",
    "bolámo": "bolar",
    "bolámos": "bolar",
    "boláramo": "bolar",
    "boláramos": "bolar",
    "bolárei": "bolar",
    "boláreis": "bolar",
    "bolásseis": "bolar",
    "bolássemos": "bolar",
    "bolávamo": "bolar",
    "bolávamos": "bolar",
    "bolávei": "bolar",
    "boláveis": "bolar",
    "bolça": "bolçar",
    "bolçada": "bolçar",
    "bolçadas": "bolçar",
    "bolçado": "bolçar",
    "bolçados": "bolçar",
    "bolçai": "bolçar",
    "bolçais": "bolçar",
    "bolçam": "bolçar",
    "bolçamo": "bolçar",
    "bolçamos": "bolçar",
    "bolçando": "bolçar",
    "bolçara": "bolçar",
    "bolçaram": "bolçar",
    "bolçaras": "bolçar",
    "bolçarde": "bolçar",
    "bolçardes": "bolçar",
    "bolçare": "bolçar",
    "bolçarei": "bolçar",
    "bolçareis": "bolçar",
    "bolçarem": "bolçar",
    "bolçaremos": "bolçar",
    "bolçares": "bolçar",
    "bolçaria": "bolçar",
    "bolçariam": "bolçar",
    "bolçarias": "bolçar",
    "bolçarmo": "bolçar",
    "bolçarmos": "bolçar",
    "bolçará": "bolçar",
    "bolçarás": "bolçar",
    "bolçarão": "bolçar",
    "bolçaríamos": "bolçar",
    "bolçaríeis": "bolçar",
    "bolças": "bolçar",
    "bolçasse": "bolçar",
    "bolçassem": "bolçar",
    "bolçasses": "bolçar",
    "bolçaste": "bolçar",
    "bolçastes": "bolçar",
    "bolçava": "bolçar",
    "bolçavam": "bolçar",
    "bolçavas": "bolçar",
    "bolço": "bolçar",
    "bolçou": "bolçar",
    "bolçá": "bolçar",
    "bolçámo": "bolçar",
    "bolçámos": "bolçar",
    "bolçáramo": "bolçar",
    "bolçáramos": "bolçar",
    "bolçárei": "bolçar",
    "bolçáreis": "bolçar",
    "bolçásseis": "bolçar",
    "bolçássemos": "bolçar",
    "bolçávamo": "bolçar",
    "bolçávamos": "bolçar",
    "bolçávei": "bolçar",
    "bolçáveis": "bolçar",
    "boléus": "boléu",
    "bolêias": "bolêia",
    "bolívares": "bolívar",
    "bolómetros": "bolómetro",
    "bolónia": "bolónio",
    "bolónias": "bolónio",
    "bolónios": "bolónio",
    "bolões": "bolão",
    "bombachos": "bombacho",
    "bombacácea": "bombacáceo",
    "bombacáceas": "bombacáceo",
    "bombacáceos": "bombacáceo",
    "bombadas": "bombada",
    "bombagens": "bombagem",
    "bombaratos": "bombarato",
    "bombardadas": "bombardada",
    "bombardas": "bombarda",
    "bombardeada": "bombardear",
    "bombardeadas": "bombardear",
    "bombardeado": "bombardear",
    "bombardeadora": "bombardeador",
    "bombardeadoras": "bombardeador",
    "bombardeadores": "bombardeador",
    "bombardeados": "bombardear",
    "bombardeai": "bombardear",
    "bombardeais": "bombardear",
    "bombardeamentos": "bombardeamento",
    "bombardeamo": "bombardear",
    "bombardeamos": "bombardear",
    "bombardeando": "bombardear",
    "bombardeara": "bombardear",
    "bombardearam": "bombardear",
    "bombardearas": "bombardear",
    "bombardearde": "bombardear",
    "bombardeardes": "bombardear",
    "bombardeare": "bombardear",
    "bombardearei": "bombardear",
    "bombardeareis": "bombardear",
    "bombardearem": "bombardear",
    "bombardearemos": "bombardear",
    "bombardeares": "bombardear",
    "bombardearia": "bombardear",
    "bombardeariam": "bombardear",
    "bombardearias": "bombardear",
    "bombardearmo": "bombardear",
    "bombardearmos": "bombardear",
    "bombardeará": "bombardear",
    "bombardearás": "bombardear",
    "bombardearão": "bombardear",
    "bombardearíamos": "bombardear",
    "bombardearíeis": "bombardear",
    "bombardeasse": "bombardear",
    "bombardeassem": "bombardear",
    "bombardeasses": "bombardear",
    "bombardeaste": "bombardear",
    "bombardeastes": "bombardear",
    "bombardeava": "bombardear",
    "bombardeavam": "bombardear",
    "bombardeavas": "bombardear",
    "bombardeei": "bombardear",
    "bombardeeis": "bombardear",
    "bombardeemo": "bombardear",
    "bombardeemos": "bombardear",
    "bombardeia": "bombardear",
    "bombardeiam": "bombardear",
    "bombardeias": "bombardear",
    "bombardeie": "bombardear",
    "bombardeiem": "bombardear",
    "bombardeies": "bombardear",
    "bombardeio": "bombardear",
    "bombardeira": "bombardeiro",
    "bombardeiras": "bombardeiro",
    "bombardeiros": "bombardeiro",
    "bombardeou": "bombardear",
    "bombardeá": "bombardear",
    "bombardeámo": "bombardear",
    "bombardeámos": "bombardear",
    "bombardeáramo": "bombardear",
    "bombardeáramos": "bombardear",
    "bombardeárei": "bombardear",
    "bombardeáreis": "bombardear",
    "bombardeásseis": "bombardear",
    "bombardeássemos": "bombardear",
    "bombardeávamo": "bombardear",
    "bombardeávamos": "bombardear",
    "bombardeávei": "bombardear",
    "bombardeáveis": "bombardeável",
    "bombardinos": "bombardino",
    "bombas": "bomba",
    "bombazinas": "bombazina",
    "bombazines": "bombazine",
    "bombeada": "bombear",
    "bombeadas": "bombear",
    "bombeado": "bombear",
    "bombeadora": "bombeador",
    "bombeadoras": "bombeador",
    "bombeadores": "bombeador",
    "bombeados": "bombear",
    "bombeai": "bombear",
    "bombeais": "bombear",
    "bombeamentos": "bombeamento",
    "bombeamo": "bombear",
    "bombeamos": "bombear",
    "bombeando": "bombear",
    "bombeara": "bombear",
    "bombearam": "bombear",
    "bombearas": "bombear",
    "bombearde": "bombear",
    "bombeardes": "bombear",
    "bombeare": "bombear",
    "bombearei": "bombear",
    "bombeareis": "bombear",
    "bombearem": "bombear",
    "bombearemos": "bombear",
    "bombeares": "bombear",
    "bombearia": "bombear",
    "bombeariam": "bombear",
    "bombearias": "bombear",
    "bombearmo": "bombear",
    "bombearmos": "bombear",
    "bombeará": "bombear",
    "bombearás": "bombear",
    "bombearão": "bombear",
    "bombearíamos": "bombear",
    "bombearíeis": "bombear",
    "bombeasse": "bombear",
    "bombeassem": "bombear",
    "bombeasses": "bombear",
    "bombeaste": "bombear",
    "bombeastes": "bombear",
    "bombeava": "bombear",
    "bombeavam": "bombear",
    "bombeavas": "bombear",
    "bombeei": "bombear",
    "bombeeis": "bombear",
    "bombeemo": "bombear",
    "bombeemos": "bombear",
    "bombeia": "bombear",
    "bombeiam": "bombear",
    "bombeias": "bombear",
    "bombeie": "bombear",
    "bombeiem": "bombear",
    "bombeies": "bombear",
    "bombeio": "bombear",
    "bombeira": "bombeiro",
    "bombeiras": "bombeiro",
    "bombeiros": "bombeiro",
    "bombeou": "bombear",
    "bombeá": "bombear",
    "bombeámo": "bombear",
    "bombeámos": "bombear",
    "bombeáramo": "bombear",
    "bombeáramos": "bombear",
    "bombeárei": "bombear",
    "bombeáreis": "bombear",
    "bombeásseis": "bombear",
    "bombeássemos": "bombear",
    "bombeávamo": "bombear",
    "bombeávamos": "bombear",
    "bombeávei": "bombear",
    "bombeáveis": "bombeável",
    "bombices": "bombice",
    "bombicilídea": "bombicilídeo",
    "bombicilídeas": "bombicilídeo",
    "bombicilídeos": "bombicilídeo",
    "bombiculturas": "bombicultura",
    "bombicídea": "bombicídeo",
    "bombicídeas": "bombicídeo",
    "bombicídeos": "bombicídeo",
    "bombicílidas": "bombicílida",
    "bombinha": "bomba",
    "bombinhas": "bomba",
    "bombistas": "bombista",
    "bombita": "bomba",
    "bombitas": "bomba",
    "bomboneiras": "bomboneira",
    "bombons": "bombom",
    "bombonzinho": "bombom",
    "bombonzinhos": "bombom",
    "bombonzito": "bombom",
    "bombonzitos": "bombom",
    "bombordos": "bombordo",
    "bombos": "bombo",
    "bomboteira": "bomboteiro",
    "bomboteiras": "bomboteiro",
    "bomboteiros": "bomboteiro",
    "bombástica": "bombástico",
    "bombásticas": "bombástico",
    "bombásticos": "bombástico",
    "bombícidas": "bombícida",
    "bombós": "bombó",
    "bonacha": "bonacho",
    "bonachas": "bonacho",
    "bonacheira": "bonacheiro",
    "bonacheiras": "bonacheiro",
    "bonacheirices": "bonacheirice",
    "bonacheirona": "bonacheirão",
    "bonacheironas": "bonacheirão",
    "bonacheiros": "bonacheiro",
    "bonacheirões": "bonacheirão",
    "bonachona": "bonachão",
    "bonachonas": "bonachão",
    "bonachos": "bonacho",
    "bonachões": "bonachão",
    "bonance": "bonançar",
    "bonancei": "bonançar",
    "bonanceis": "bonançar",
    "bonancem": "bonançar",
    "bonancemo": "bonançar",
    "bonancemos": "bonançar",
    "bonances": "bonançar",
    "bonança": "bonançar",
    "bonançada": "bonançar",
    "bonançadas": "bonançar",
    "bonançado": "bonançar",
    "bonançados": "bonançar",
    "bonançai": "bonançar",
    "bonançais": "bonançar",
    "bonançam": "bonançar",
    "bonançamo": "bonançar",
    "bonançamos": "bonançar",
    "bonançando": "bonançar",
    "bonançara": "bonançar",
    "bonançaram": "bonançar",
    "bonançaras": "bonançar",
    "bonançardes": "bonançar",
    "bonançarei": "bonançar",
    "bonançareis": "bonançar",
    "bonançarem": "bonançar",
    "bonançaremos": "bonançar",
    "bonançares": "bonançar",
    "bonançaria": "bonançar",
    "bonançariam": "bonançar",
    "bonançarias": "bonançar",
    "bonançarmo": "bonançar",
    "bonançarmos": "bonançar",
    "bonançará": "bonançar",
    "bonançarás": "bonançar",
    "bonançarão": "bonançar",
    "bonançaríamos": "bonançar",
    "bonançaríeis": "bonançar",
    "bonanças": "bonançar",
    "bonançasse": "bonançar",
    "bonançassem": "bonançar",
    "bonançasses": "bonançar",
    "bonançaste": "bonançar",
    "bonançastes": "bonançar",
    "bonançava": "bonançar",
    "bonançavam": "bonançar",
    "bonançavas": "bonançar",
    "bonanço": "bonançar",
    "bonançosa": "bonançoso",
    "bonançosas": "bonançoso",
    "bonançosos": "bonançoso",
    "bonançou": "bonançar",
    "bonançámo": "bonançar",
    "bonançámos": "bonançar",
    "bonançáramo": "bonançar",
    "bonançáramos": "bonançar",
    "bonançáreis": "bonançar",
    "bonançásseis": "bonançar",
    "bonançássemos": "bonançar",
    "bonançávamo": "bonançar",
    "bonançávamos": "bonançar",
    "bonançáveis": "bonançar",
    "bonapartismos": "bonapartismo",
    "bonapartistas": "bonapartista",
    "bonda": "bondar",
    "bondada": "bondar",
    "bondadas": "bondar",
    "bondades": "bondade",
    "bondado": "bondar",
    "bondados": "bondar",
    "bondai": "bondar",
    "bondais": "bondar",
    "bondam": "bondar",
    "bondamo": "bondar",
    "bondamos": "bondar",
    "bondando": "bondar",
    "bondara": "bondar",
    "bondaram": "bondar",
    "bondaras": "bondar",
    "bondardes": "bondar",
    "bondarei": "bondar",
    "bondareis": "bondar",
    "bondarem": "bondar",
    "bondaremos": "bondar",
    "bondares": "bondar",
    "bondaria": "bondar",
    "bondariam": "bondar",
    "bondarias": "bondar",
    "bondarmo": "bondar",
    "bondarmos": "bondar",
    "bondará": "bondar",
    "bondarás": "bondar",
    "bondarão": "bondar",
    "bondaríamos": "bondar",
    "bondaríeis": "bondar",
    "bondas": "bondar",
    "bondasse": "bondar",
    "bondassem": "bondar",
    "bondasses": "bondar",
    "bondaste": "bondar",
    "bondastes": "bondar",
    "bondava": "bondar",
    "bondavam": "bondar",
    "bondavas": "bondar",
    "bonde": "bondar",
    "bondei": "bondar",
    "bondeis": "bondar",
    "bondem": "bondar",
    "bondemo": "bondar",
    "bondemos": "bondar",
    "bondes": "bondar",
    "bondo": "bondar",
    "bondocinas": "bondocina",
    "bondosa": "bondoso",
    "bondosas": "bondoso",
    "bondosos": "bondoso",
    "bondou": "bondar",
    "bonduques": "bonduque",
    "bondámo": "bondar",
    "bondámos": "bondar",
    "bondáramo": "bondar",
    "bondáramos": "bondar",
    "bondáreis": "bondar",
    "bondásseis": "bondar",
    "bondássemos": "bondar",
    "bondávamo": "bondar",
    "bondávamos": "bondar",
    "bondáveis": "bondar",
    "bonecadas": "bonecada",
    "bonecagens": "bonecagem",
    "bonecas": "boneca",
    "bonecazinha": "boneca",
    "bonecazinhas": "boneca",
    "bonecazita": "boneca",
    "bonecazitas": "boneca",
    "bonecos": "boneco",
    "bonecozinho": "boneco",
    "bonecozinhos": "boneco",
    "bonecozito": "boneco",
    "bonecozitos": "boneco",
    "bonecradas": "bonecrada",
    "bonecragens": "bonecragem",
    "bonecras": "bonecra",
    "bonecreira": "bonecreiro",
    "bonecreiras": "bonecreiro",
    "bonecreiros": "bonecreiro",
    "bonequeira": "bonequeiro",
    "bonequeiras": "bonequeiro",
    "bonequeiros": "bonequeiro",
    "bonequinha": "boneca",
    "bonequinhas": "boneca",
    "bonequinho": "boneco",
    "bonequinhos": "boneco",
    "bonequita": "boneca",
    "bonequitas": "boneca",
    "bonequito": "boneco",
    "bonequitos": "boneco",
    "bonetes": "bonete",
    "bonezinho": "boné",
    "bonezinhos": "boné",
    "bonezito": "boné",
    "bonezitos": "boné",
    "bonicos": "bonico",
    "bonifica": "bonificar",
    "bonificada": "bonificar",
    "bonificadas": "bonificar",
    "bonificado": "bonificar",
    "bonificados": "bonificar",
    "bonificai": "bonificar",
    "bonificais": "bonificar",
    "bonificam": "bonificar",
    "bonificamo": "bonificar",
    "bonificamos": "bonificar",
    "bonificando": "bonificar",
    "bonificara": "bonificar",
    "bonificaram": "bonificar",
    "bonificaras": "bonificar",
    "bonificarde": "bonificar",
    "bonificardes": "bonificar",
    "bonificare": "bonificar",
    "bonificarei": "bonificar",
    "bonificareis": "bonificar",
    "bonificarem": "bonificar",
    "bonificaremos": "bonificar",
    "bonificares": "bonificar",
    "bonificaria": "bonificar",
    "bonificariam": "bonificar",
    "bonificarias": "bonificar",
    "bonificarmo": "bonificar",
    "bonificarmos": "bonificar",
    "bonificará": "bonificar",
    "bonificarás": "bonificar",
    "bonificarão": "bonificar",
    "bonificaríamos": "bonificar",
    "bonificaríeis": "bonificar",
    "bonificas": "bonificar",
    "bonificasse": "bonificar",
    "bonificassem": "bonificar",
    "bonificasses": "bonificar",
    "bonificaste": "bonificar",
    "bonificastes": "bonificar",
    "bonificava": "bonificar",
    "bonificavam": "bonificar",
    "bonificavas": "bonificar",
    "bonificações": "bonificação",
    "bonifico": "bonificar",
    "bonificou": "bonificar",
    "bonificá": "bonificar",
    "bonificámo": "bonificar",
    "bonificámos": "bonificar",
    "bonificáramo": "bonificar",
    "bonificáramos": "bonificar",
    "bonificárei": "bonificar",
    "bonificáreis": "bonificar",
    "bonificásseis": "bonificar",
    "bonificássemos": "bonificar",
    "bonificávamo": "bonificar",
    "bonificávamos": "bonificar",
    "bonificávei": "bonificar",
    "bonificáveis": "bonificar",
    "bonifique": "bonificar",
    "bonifiquei": "bonificar",
    "bonifiqueis": "bonificar",
    "bonifiquem": "bonificar",
    "bonifiquemo": "bonificar",
    "bonifiquemos": "bonificar",
    "bonifiques": "bonificar",
    "bonifrates": "bonifrate",
    "boninais": "boninal",
    "boninas": "bonina",
    "bonita": "bonito",
    "bonitas": "bonito",
    "bonitezas": "boniteza",
    "bonitinha": "bonito",
    "bonitinhas": "bonito",
    "bonitinho": "bonito",
    "bonitinhos": "bonito",
    "bonitita": "bonito",
    "bonititas": "bonito",
    "bonitito": "bonito",
    "bonititos": "bonito",
    "bonitona": "bonitão",
    "bonitonas": "bonitão",
    "bonitos": "bonito",
    "bonitotes": "bonitote",
    "bonitões": "bonitão",
    "bonomias": "bonomia",
    "bons": "bom",
    "bonsais": "bonsai",
    "bonzinho": "bom",
    "bonzinhos": "bom",
    "bonzito": "bom",
    "bonzitos": "bom",
    "bonzos": "bonzo",
    "bonés": "boné",
    "bootas": "boota",
    "boque": "bocar",
    "boqueaberta": "boqueaberto",
    "boqueabertas": "boqueaberto",
    "boqueabertos": "boqueaberto",
    "boqueada": "boquear",
    "boqueadas": "boquear",
    "boqueado": "boquear",
    "boqueados": "boquear",
    "boqueai": "boquear",
    "boqueais": "boquear",
    "boqueamo": "boquear",
    "boqueamos": "boquear",
    "boqueando": "boquear",
    "boqueara": "boquear",
    "boquearam": "boquear",
    "boquearas": "boquear",
    "boqueardentes": "boqueardente",
    "boqueardes": "boquear",
    "boquearei": "boquear",
    "boqueareis": "boquear",
    "boquearem": "boquear",
    "boquearemos": "boquear",
    "boqueares": "boquear",
    "boquearia": "boquear",
    "boqueariam": "boquear",
    "boquearias": "boquear",
    "boquearmo": "boquear",
    "boquearmos": "boquear",
    "boqueará": "boquear",
    "boquearás": "boquear",
    "boquearão": "boquear",
    "boquearíamos": "boquear",
    "boquearíeis": "boquear",
    "boqueasse": "boquear",
    "boqueassem": "boquear",
    "boqueasses": "boquear",
    "boqueaste": "boquear",
    "boqueastes": "boquear",
    "boqueava": "boquear",
    "boqueavam": "boquear",
    "boqueavas": "boquear",
    "boqueei": "boquear",
    "boqueeis": "boquear",
    "boqueemo": "boquear",
    "boqueemos": "boquear",
    "boquei": "bocar",
    "boqueia": "boquear",
    "boqueiam": "boquear",
    "boqueias": "boquear",
    "boqueie": "boquear",
    "boqueiem": "boquear",
    "boqueies": "boquear",
    "boqueio": "boquear",
    "boqueiras": "boqueira",
    "boqueiros": "boqueiro",
    "boqueirões": "boqueirão",
    "boqueis": "bocar",
    "boqueja": "boquejar",
    "boquejada": "boquejar",
    "boquejadas": "boquejar",
    "boquejado": "boquejar",
    "boquejados": "boquejar",
    "boquejaduras": "boquejadura",
    "boquejai": "boquejar",
    "boquejais": "boquejar",
    "boquejam": "boquejar",
    "boquejamentos": "boquejamento",
    "boquejamo": "boquejar",
    "boquejamos": "boquejar",
    "boquejando": "boquejar",
    "boquejara": "boquejar",
    "boquejaram": "boquejar",
    "boquejaras": "boquejar",
    "boquejarde": "boquejar",
    "boquejardes": "boquejar",
    "boquejare": "boquejar",
    "boquejarei": "boquejar",
    "boquejareis": "boquejar",
    "boquejarem": "boquejar",
    "boquejaremos": "boquejar",
    "boquejares": "boquejar",
    "boquejaria": "boquejar",
    "boquejariam": "boquejar",
    "boquejarias": "boquejar",
    "boquejarmo": "boquejar",
    "boquejarmos": "boquejar",
    "boquejará": "boquejar",
    "boquejarás": "boquejar",
    "boquejarão": "boquejar",
    "boquejaríamos": "boquejar",
    "boquejaríeis": "boquejar",
    "boquejas": "boquejar",
    "boquejasse": "boquejar",
    "boquejassem": "boquejar",
    "boquejasses": "boquejar",
    "boquejaste": "boquejar",
    "boquejastes": "boquejar",
    "boquejava": "boquejar",
    "boquejavam": "boquejar",
    "boquejavas": "boquejar",
    "boqueje": "boquejar",
    "boquejei": "boquejar",
    "boquejeis": "boquejar",
    "boquejem": "boquejar",
    "boquejemo": "boquejar",
    "boquejemos": "boquejar",
    "boquejes": "boquejar",
    "boquejo": "boquejar",
    "boquejos": "boquejo",
    "boquejou": "boquejar",
    "boquejá": "boquejar",
    "boquejámo": "boquejar",
    "boquejámos": "boquejar",
    "boquejáramo": "boquejar",
    "boquejáramos": "boquejar",
    "boquejárei": "boquejar",
    "boquejáreis": "boquejar",
    "boquejásseis": "boquejar",
    "boquejássemos": "boquejar",
    "boquejávamo": "boquejar",
    "boquejávamos": "boquejar",
    "boquejávei": "boquejar",
    "boquejáveis": "boquejar",
    "boquelhos": "boquelho",
    "boquem": "bocar",
    "boquemo": "bocar",
    "boquemos": "bocar",
    "boqueou": "boquear",
    "boques": "bocar",
    "boqueámo": "boquear",
    "boqueámos": "boquear",
    "boqueáramo": "boquear",
    "boqueáramos": "boquear",
    "boqueáreis": "boquear",
    "boqueásseis": "boquear",
    "boqueássemos": "boquear",
    "boqueávamo": "boquear",
    "boqueávamos": "boquear",
    "boqueáveis": "boquear",
    "boquiaberta": "boquiaberto",
    "boquiabertas": "boquiaberto",
    "boquiabertos": "boquiaberto",
    "boquidura": "boquiduro",
    "boquiduras": "boquiduro",
    "boquiduros": "boquiduro",
    "boquifendida": "boquifendido",
    "boquifendidas": "boquifendido",
    "boquifendidos": "boquifendido",
    "boquilarga": "boquilargo",
    "boquilargas": "boquilargo",
    "boquilargos": "boquilargo",
    "boquilhas": "boquilha",
    "boquinha": "boca",
    "boquinhas": "boca",
    "boquins": "boquim",
    "boquirrota": "boquirroto",
    "boquirrotas": "boquirroto",
    "boquirrotos": "boquirroto",
    "boquisseca": "boquisseco",
    "boquissecas": "boquisseco",
    "boquissecos": "boquisseco",
    "boquita": "boca",
    "boquitas": "boca",
    "boracites": "boracite",
    "boraginácea": "boragináceo",
    "boragináceas": "boragináceo",
    "boragináceos": "boragináceo",
    "boragínea": "boragíneo",
    "boragíneas": "boragíneo",
    "boragíneos": "boragíneo",
    "boratada": "boratado",
    "boratadas": "boratado",
    "boratados": "boratado",
    "boratos": "borato",
    "borboletas": "borboleta",
    "borboleteada": "borboletear",
    "borboleteadas": "borboletear",
    "borboleteado": "borboletear",
    "borboleteados": "borboletear",
    "borboleteai": "borboletear",
    "borboleteais": "borboletear",
    "borboleteamo": "borboletear",
    "borboleteamos": "borboletear",
    "borboleteando": "borboletear",
    "borboleteara": "borboletear",
    "borboletearam": "borboletear",
    "borboletearas": "borboletear",
    "borboleteardes": "borboletear",
    "borboletearei": "borboletear",
    "borboleteareis": "borboletear",
    "borboletearem": "borboletear",
    "borboletearemos": "borboletear",
    "borboleteares": "borboletear",
    "borboletearia": "borboletear",
    "borboleteariam": "borboletear",
    "borboletearias": "borboletear",
    "borboletearmo": "borboletear",
    "borboletearmos": "borboletear",
    "borboleteará": "borboletear",
    "borboletearás": "borboletear",
    "borboletearão": "borboletear",
    "borboletearíamos": "borboletear",
    "borboletearíeis": "borboletear",
    "borboleteasse": "borboletear",
    "borboleteassem": "borboletear",
    "borboleteasses": "borboletear",
    "borboleteaste": "borboletear",
    "borboleteastes": "borboletear",
    "borboleteava": "borboletear",
    "borboleteavam": "borboletear",
    "borboleteavas": "borboletear",
    "borboleteei": "borboletear",
    "borboleteeis": "borboletear",
    "borboleteemo": "borboletear",
    "borboleteemos": "borboletear",
    "borboleteia": "borboletear",
    "borboleteiam": "borboletear",
    "borboleteias": "borboletear",
    "borboleteie": "borboletear",
    "borboleteiem": "borboletear",
    "borboleteies": "borboletear",
    "borboleteio": "borboletear",
    "borboleteou": "borboletear",
    "borboleteámo": "borboletear",
    "borboleteámos": "borboletear",
    "borboleteáramo": "borboletear",
    "borboleteáramos": "borboletear",
    "borboleteáreis": "borboletear",
    "borboleteásseis": "borboletear",
    "borboleteássemos": "borboletear",
    "borboleteávamo": "borboletear",
    "borboleteávamos": "borboletear",
    "borboleteáveis": "borboletear",
    "borbolotos": "borboloto",
    "borboniana": "borboniano",
    "borbonianas": "borboniano",
    "borbonianos": "borboniano",
    "borboreja": "borborejar",
    "borborejada": "borborejar",
    "borborejadas": "borborejar",
    "borborejado": "borborejar",
    "borborejados": "borborejar",
    "borborejai": "borborejar",
    "borborejais": "borborejar",
    "borborejam": "borborejar",
    "borborejamo": "borborejar",
    "borborejamos": "borborejar",
    "borborejando": "borborejar",
    "borborejara": "borborejar",
    "borborejaram": "borborejar",
    "borborejaras": "borborejar",
    "borborejardes": "borborejar",
    "borborejarei": "borborejar",
    "borborejareis": "borborejar",
    "borborejarem": "borborejar",
    "borborejaremos": "borborejar",
    "borborejares": "borborejar",
    "borborejaria": "borborejar",
    "borborejariam": "borborejar",
    "borborejarias": "borborejar",
    "borborejarmo": "borborejar",
    "borborejarmos": "borborejar",
    "borborejará": "borborejar",
    "borborejarás": "borborejar",
    "borborejarão": "borborejar",
    "borborejaríamos": "borborejar",
    "borborejaríeis": "borborejar",
    "borborejas": "borborejar",
    "borborejasse": "borborejar",
    "borborejassem": "borborejar",
    "borborejasses": "borborejar",
    "borborejaste": "borborejar",
    "borborejastes": "borborejar",
    "borborejava": "borborejar",
    "borborejavam": "borborejar",
    "borborejavas": "borborejar",
    "borboreje": "borborejar",
    "borborejei": "borborejar",
    "borborejeis": "borborejar",
    "borborejem": "borborejar",
    "borborejemo": "borborejar",
    "borborejemos": "borborejar",
    "borborejes": "borborejar",
    "borborejo": "borborejar",
    "borborejou": "borborejar",
    "borborejámo": "borborejar",
    "borborejámos": "borborejar",
    "borborejáramo": "borborejar",
    "borborejáramos": "borborejar",
    "borborejáreis": "borborejar",
    "borborejásseis": "borborejar",
    "borborejássemos": "borborejar",
    "borborejávamo": "borborejar",
    "borborejávamos": "borborejar",
    "borborejáveis": "borborejar",
    "borborigmos": "borborigmo",
    "borborismos": "borborismo",
    "borbota": "borbotar",
    "borbotada": "borbotar",
    "borbotadas": "borbotar",
    "borbotado": "borbotar",
    "borbotados": "borbotar",
    "borbotai": "borbotar",
    "borbotais": "borbotar",
    "borbotam": "borbotar",
    "borbotamo": "borbotar",
    "borbotamos": "borbotar",
    "borbotando": "borbotar",
    "borbotara": "borbotar",
    "borbotaram": "borbotar",
    "borbotaras": "borbotar",
    "borbotardes": "borbotar",
    "borbotarei": "borbotar",
    "borbotareis": "borbotar",
    "borbotarem": "borbotar",
    "borbotaremos": "borbotar",
    "borbotares": "borbotar",
    "borbotaria": "borbotar",
    "borbotariam": "borbotar",
    "borbotarias": "borbotar",
    "borbotarmo": "borbotar",
    "borbotarmos": "borbotar",
    "borbotará": "borbotar",
    "borbotarás": "borbotar",
    "borbotarão": "borbotar",
    "borbotaríamos": "borbotar",
    "borbotaríeis": "borbotar",
    "borbotas": "borbotar",
    "borbotasse": "borbotar",
    "borbotassem": "borbotar",
    "borbotasses": "borbotar",
    "borbotaste": "borbotar",
    "borbotastes": "borbotar",
    "borbotava": "borbotar",
    "borbotavam": "borbotar",
    "borbotavas": "borbotar",
    "borbote": "borbotar",
    "borbotei": "borbotar",
    "borboteis": "borbotar",
    "borbotem": "borbotar",
    "borbotemo": "borbotar",
    "borbotemos": "borbotar",
    "borbotes": "borbotar",
    "borbotinho": "borboto",
    "borbotinhos": "borboto",
    "borbotito": "borboto",
    "borbotitos": "borboto",
    "borboto": "borbotar",
    "borbotos": "borboto",
    "borbotou": "borbotar",
    "borbotozinho": "borboto",
    "borbotozinhos": "borboto",
    "borbotozito": "borboto",
    "borbotozitos": "borboto",
    "borbotámo": "borbotar",
    "borbotámos": "borbotar",
    "borbotáramo": "borbotar",
    "borbotáramos": "borbotar",
    "borbotáreis": "borbotar",
    "borbotásseis": "borbotar",
    "borbotássemos": "borbotar",
    "borbotávamo": "borbotar",
    "borbotávamos": "borbotar",
    "borbotáveis": "borbotar",
    "borbotões": "borbotão",
    "borbulha": "borbulhar",
    "borbulhada": "borbulhar",
    "borbulhadas": "borbulhar",
    "borbulhado": "borbulhar",
    "borbulhados": "borbulhar",
    "borbulhagens": "borbulhagem",
    "borbulhai": "borbulhar",
    "borbulhais": "borbulhar",
    "borbulham": "borbulhar",
    "borbulhamo": "borbulhar",
    "borbulhamos": "borbulhar",
    "borbulhando": "borbulhar",
    "borbulhantes": "borbulhante",
    "borbulhara": "borbulhar",
    "borbulharam": "borbulhar",
    "borbulharas": "borbulhar",
    "borbulhardes": "borbulhar",
    "borbulharei": "borbulhar",
    "borbulhareis": "borbulhar",
    "borbulharem": "borbulhar",
    "borbulharemos": "borbulhar",
    "borbulhares": "borbulhar",
    "borbulharia": "borbulhar",
    "borbulhariam": "borbulhar",
    "borbulharias": "borbulhar",
    "borbulharmo": "borbulhar",
    "borbulharmos": "borbulhar",
    "borbulhará": "borbulhar",
    "borbulharás": "borbulhar",
    "borbulharão": "borbulhar",
    "borbulharíamos": "borbulhar",
    "borbulharíeis": "borbulhar",
    "borbulhas": "borbulhar",
    "borbulhasse": "borbulhar",
    "borbulhassem": "borbulhar",
    "borbulhasses": "borbulhar",
    "borbulhaste": "borbulhar",
    "borbulhastes": "borbulhar",
    "borbulhava": "borbulhar",
    "borbulhavam": "borbulhar",
    "borbulhavas": "borbulhar",
    "borbulhaços": "borbulhaço",
    "borbulhe": "borbulhar",
    "borbulhei": "borbulhar",
    "borbulheis": "borbulhar",
    "borbulhem": "borbulhar",
    "borbulhemo": "borbulhar",
    "borbulhemos": "borbulhar",
    "borbulhenta": "borbulhento",
    "borbulhentas": "borbulhento",
    "borbulhentos": "borbulhento",
    "borbulhes": "borbulhar",
    "borbulhinha": "borbulha",
    "borbulhinhas": "borbulha",
    "borbulhita": "borbulha",
    "borbulhitas": "borbulha",
    "borbulho": "borbulhar",
    "borbulhona": "borbulhão",
    "borbulhonas": "borbulhão",
    "borbulhosa": "borbulhoso",
    "borbulhosas": "borbulhoso",
    "borbulhosos": "borbulhoso",
    "borbulhou": "borbulhar",
    "borbulhámo": "borbulhar",
    "borbulhámos": "borbulhar",
    "borbulháramo": "borbulhar",
    "borbulháramos": "borbulhar",
    "borbulháreis": "borbulhar",
    "borbulhásseis": "borbulhar",
    "borbulhássemos": "borbulhar",
    "borbulhávamo": "borbulhar",
    "borbulhávamos": "borbulhar",
    "borbulháveis": "borbulhar",
    "borbulhões": "borbulhão",
    "borbónica": "borbónico",
    "borbónicas": "borbónico",
    "borbónicos": "borbónico",
    "borca": "borcar",
    "borcada": "borcar",
    "borcadas": "borcar",
    "borcado": "borcar",
    "borcados": "borcar",
    "borcai": "borcar",
    "borcais": "borcar",
    "borcam": "borcar",
    "borcamo": "borcar",
    "borcamos": "borcar",
    "borcando": "borcar",
    "borcara": "borcar",
    "borcaram": "borcar",
    "borcaras": "borcar",
    "borcarde": "borcar",
    "borcardes": "borcar",
    "borcare": "borcar",
    "borcarei": "borcar",
    "borcareis": "borcar",
    "borcarem": "borcar",
    "borcaremos": "borcar",
    "borcares": "borcar",
    "borcaria": "borcar",
    "borcariam": "borcar",
    "borcarias": "borcar",
    "borcarmo": "borcar",
    "borcarmos": "borcar",
    "borcará": "borcar",
    "borcarás": "borcar",
    "borcarão": "borcar",
    "borcaríamos": "borcar",
    "borcaríeis": "borcar",
    "borcas": "borcar",
    "borcasse": "borcar",
    "borcassem": "borcar",
    "borcasses": "borcar",
    "borcaste": "borcar",
    "borcastes": "borcar",
    "borcava": "borcar",
    "borcavam": "borcar",
    "borcavas": "borcar",
    "borco": "borcar",
    "borcos": "borco",
    "borcou": "borcar",
    "borcá": "borcar",
    "borcámo": "borcar",
    "borcámos": "borcar",
    "borcáramo": "borcar",
    "borcáramos": "borcar",
    "borcárei": "borcar",
    "borcáreis": "borcar",
    "borcásseis": "borcar",
    "borcássemos": "borcar",
    "borcávamo": "borcar",
    "borcávamos": "borcar",
    "borcávei": "borcar",
    "borcáveis": "borcar",
    "borda": "bordar",
    "bordada": "bordar",
    "bordadas": "bordar",
    "bordadeira": "bordador",
    "bordadeiras": "bordador",
    "bordadinho": "bordado",
    "bordadinhos": "bordado",
    "bordadito": "bordado",
    "bordaditos": "bordado",
    "bordado": "bordar",
    "bordadores": "bordador",
    "bordados": "bordar",
    "bordaduras": "bordadura",
    "bordagens": "bordagem",
    "bordai": "bordar",
    "bordais": "bordar",
    "bordaleira": "bordaleiro",
    "bordaleiras": "bordaleiro",
    "bordaleiros": "bordaleiro",
    "bordalenga": "bordalengo",
    "bordalengas": "bordalengo",
    "bordalengos": "bordalengo",
    "bordalenses": "bordalense",
    "bordalesa": "bordalês",
    "bordalesas": "bordalês",
    "bordaleses": "bordalês",
    "bordalos": "bordalo",
    "bordam": "bordar",
    "bordamo": "bordar",
    "bordamos": "bordar",
    "bordando": "bordar",
    "bordara": "bordar",
    "bordaram": "bordar",
    "bordaras": "bordar",
    "bordarde": "bordar",
    "bordardes": "bordar",
    "bordare": "bordar",
    "bordarei": "bordar",
    "bordareis": "bordar",
    "bordarem": "bordar",
    "bordaremos": "bordar",
    "bordares": "bordar",
    "bordaria": "bordar",
    "bordariam": "bordar",
    "bordarias": "bordar",
    "bordarmo": "bordar",
    "bordarmos": "bordar",
    "bordará": "bordar",
    "bordarás": "bordar",
    "bordarão": "bordar",
    "bordaríamos": "bordar",
    "bordaríeis": "bordar",
    "bordas": "bordar",
    "bordasse": "bordar",
    "bordassem": "bordar",
    "bordasses": "bordar",
    "bordaste": "bordar",
    "bordastes": "bordar",
    "bordava": "bordar",
    "bordavam": "bordar",
    "bordavas": "bordar",
    "bordações": "bordação",
    "borde": "bordar",
    "bordeada": "bordear",
    "bordeadas": "bordear",
    "bordeado": "bordear",
    "bordeados": "bordear",
    "bordeai": "bordear",
    "bordeais": "bordear",
    "bordeamo": "bordear",
    "bordeamos": "bordear",
    "bordeando": "bordear",
    "bordeara": "bordear",
    "bordearam": "bordear",
    "bordearas": "bordear",
    "bordearde": "bordear",
    "bordeardes": "bordear",
    "bordeare": "bordear",
    "bordearei": "bordear",
    "bordeareis": "bordear",
    "bordearem": "bordear",
    "bordearemos": "bordear",
    "bordeares": "bordear",
    "bordearia": "bordear",
    "bordeariam": "bordear",
    "bordearias": "bordear",
    "bordearmo": "bordear",
    "bordearmos": "bordear",
    "bordeará": "bordear",
    "bordearás": "bordear",
    "bordearão": "bordear",
    "bordearíamos": "bordear",
    "bordearíeis": "bordear",
    "bordeasse": "bordear",
    "bordeassem": "bordear",
    "bordeasses": "bordear",
    "bordeaste": "bordear",
    "bordeastes": "bordear",
    "bordeava": "bordear",
    "bordeavam": "bordear",
    "bordeavas": "bordear",
    "bordeei": "bordear",
    "bordeeis": "bordear",
    "bordeemo": "bordear",
    "bordeemos": "bordear",
    "bordegona": "bordegão",
    "bordegonas": "bordegão",
    "bordegões": "bordegão",
    "bordei": "bordar",
    "bordeia": "bordear",
    "bordeiam": "bordear",
    "bordeias": "bordear",
    "bordeie": "bordear",
    "bordeiem": "bordear",
    "bordeies": "bordear",
    "bordeio": "bordear",
    "bordeis": "bordar",
    "bordeja": "bordejar",
    "bordejada": "bordejar",
    "bordejadas": "bordejar",
    "bordejado": "bordejar",
    "bordejados": "bordejar",
    "bordejai": "bordejar",
    "bordejais": "bordejar",
    "bordejam": "bordejar",
    "bordejamo": "bordejar",
    "bordejamos": "bordejar",
    "bordejando": "bordejar",
    "bordejara": "bordejar",
    "bordejaram": "bordejar",
    "bordejaras": "bordejar",
    "bordejarde": "bordejar",
    "bordejardes": "bordejar",
    "bordejare": "bordejar",
    "bordejarei": "bordejar",
    "bordejareis": "bordejar",
    "bordejarem": "bordejar",
    "bordejaremos": "bordejar",
    "bordejares": "bordejar",
    "bordejaria": "bordejar",
    "bordejariam": "bordejar",
    "bordejarias": "bordejar",
    "bordejarmo": "bordejar",
    "bordejarmos": "bordejar",
    "bordejará": "bordejar",
    "bordejarás": "bordejar",
    "bordejarão": "bordejar",
    "bordejaríamos": "bordejar",
    "bordejaríeis": "bordejar",
    "bordejas": "bordejar",
    "bordejasse": "bordejar",
    "bordejassem": "bordejar",
    "bordejasses": "bordejar",
    "bordejaste": "bordejar",
    "bordejastes": "bordejar",
    "bordejava": "bordejar",
    "bordejavam": "bordejar",
    "bordejavas": "bordejar",
    "bordeje": "bordejar",
    "bordejei": "bordejar",
    "bordejeis": "bordejar",
    "bordejem": "bordejar",
    "bordejemo": "bordejar",
    "bordejemos": "bordejar",
    "bordejes": "bordejar",
    "bordejo": "bordejar",
    "bordejou": "bordejar",
    "bordejá": "bordejar",
    "bordejámo": "bordejar",
    "bordejámos": "bordejar",
    "bordejáramo": "bordejar",
    "bordejáramos": "bordejar",
    "bordejárei": "bordejar",
    "bordejáreis": "bordejar",
    "bordejásseis": "bordejar",
    "bordejássemos": "bordejar",
    "bordejávamo": "bordejar",
    "bordejávamos": "bordejar",
    "bordejávei": "bordejar",
    "bordejáveis": "bordejar",
    "bordeleira": "bordeleiro",
    "bordeleiras": "bordeleiro",
    "bordeleiros": "bordeleiro",
    "bordelesa": "bordelês",
    "bordelesas": "bordelês",
    "bordeleses": "bordelês",
    "bordem": "bordar",
    "bordemo": "bordar",
    "bordemos": "bordar",
    "bordeou": "bordear",
    "bordes": "bordar",
    "bordeá": "bordear",
    "bordeámo": "bordear",
    "bordeámos": "bordear",
    "bordeáramo": "bordear",
    "bordeáramos": "bordear",
    "bordeárei": "bordear",
    "bordeáreis": "bordear",
    "bordeásseis": "bordear",
    "bordeássemos": "bordear",
    "bordeávamo": "bordear",
    "bordeávamos": "bordear",
    "bordeávei": "bordear",
    "bordeáveis": "bordear",
    "bordinha": "borda",
    "bordinhas": "borda",
    "bordita": "borda",
    "borditas": "borda",
    "bordo": "bordar",
    "bordoadas": "bordoada",
    "bordoeiras": "bordoeira",
    "bordos": "bordo",
    "bordou": "bordar",
    "bordá": "bordar",
    "bordámo": "bordar",
    "bordámos": "bordar",
    "bordáramo": "bordar",
    "bordáramos": "bordar",
    "bordárei": "bordar",
    "bordáreis": "bordar",
    "bordásseis": "bordar",
    "bordássemos": "bordar",
    "bordávamo": "bordar",
    "bordávamos": "bordar",
    "bordávei": "bordar",
    "bordáveis": "bordar",
    "bordéis": "bordel",
    "bordões": "bordão",
    "boreais": "boreal",
    "borgas": "borga",
    "borgonhas": "borgonha",
    "borgonhesa": "borgonhês",
    "borgonhesas": "borgonhês",
    "borgonheses": "borgonhês",
    "borguinhona": "borguinhão",
    "borguinhonas": "borguinhão",
    "borguinhões": "borguinhão",
    "borguistas": "borguista",
    "boris": "bori",
    "borlada": "borlado",
    "borladas": "borlado",
    "borlados": "borlado",
    "borlas": "borla",
    "borleada": "borleado",
    "borleadas": "borleado",
    "borleados": "borleado",
    "borlinha": "borla",
    "borlinhas": "borla",
    "borlistas": "borlista",
    "borlita": "borla",
    "borlitas": "borla",
    "borna": "borno",
    "bornais": "bornal",
    "bornas": "borno",
    "borneios": "borneio",
    "borneira": "borneiro",
    "borneiras": "borneiro",
    "borneiros": "borneiro",
    "bornes": "borne",
    "borneóis": "borneol",
    "bornitas": "bornita",
    "bornites": "bornite",
    "bornos": "borno",
    "boroas": "boroa",
    "boros": "boro",
    "borque": "borcar",
    "borquei": "borcar",
    "borqueis": "borcar",
    "borquem": "borcar",
    "borquemo": "borcar",
    "borquemos": "borcar",
    "borques": "borcar",
    "borra": "borrar",
    "borrace": "borraçar",
    "borracei": "borraçar",
    "borraceira": "borraceiro",
    "borraceiras": "borraceiro",
    "borraceiros": "borraceiro",
    "borraceis": "borraçar",
    "borracem": "borraçar",
    "borracemo": "borraçar",
    "borracemos": "borraçar",
    "borraces": "borraçar",
    "borracha": "borracho",
    "borrachadas": "borrachada",
    "borrachas": "borracho",
    "borracheira": "borracheiro",
    "borracheiras": "borracheiro",
    "borracheiros": "borracheiro",
    "borrachices": "borrachice",
    "borrachinha": "borracho",
    "borrachinhas": "borracho",
    "borrachinho": "borracho",
    "borrachinhos": "borracho",
    "borrachita": "borracho",
    "borrachitas": "borracho",
    "borrachito": "borracho",
    "borrachitos": "borracho",
    "borrachona": "borrachão",
    "borrachonas": "borrachão",
    "borrachos": "borracho",
    "borrachuda": "borrachudo",
    "borrachudas": "borrachudo",
    "borrachudos": "borrachudo",
    "borrachões": "borrachão",
    "borrada": "borrar",
    "borradas": "borrar",
    "borradelas": "borradela",
    "borrado": "borrar",
    "borradors": "borrador",
    "borrados": "borrar",
    "borraduras": "borradura",
    "borragens": "borragem",
    "borraginácea": "borragináceo",
    "borragináceas": "borragináceo",
    "borragináceos": "borragináceo",
    "borrai": "borrar",
    "borrainas": "borraina",
    "borrais": "borrar",
    "borralhas": "borralha",
    "borralheira": "borralheiro",
    "borralheiras": "borralheiro",
    "borralheiros": "borralheiro",
    "borralhenta": "borralhento",
    "borralhentas": "borralhento",
    "borralhentos": "borralhento",
    "borralhos": "borralho",
    "borram": "borrar",
    "borramo": "borrar",
    "borramos": "borrar",
    "borrando": "borrar",
    "borrara": "borrar",
    "borraram": "borrar",
    "borraras": "borrar",
    "borrarde": "borrar",
    "borrardes": "borrar",
    "borrare": "borrar",
    "borrarei": "borrar",
    "borrareis": "borrar",
    "borrarem": "borrar",
    "borraremos": "borrar",
    "borrares": "borrar",
    "borraria": "borrar",
    "borrariam": "borrar",
    "borrarias": "borrar",
    "borrarmo": "borrar",
    "borrarmos": "borrar",
    "borrará": "borrar",
    "borrarás": "borrar",
    "borrarão": "borrar",
    "borraríamos": "borrar",
    "borraríeis": "borrar",
    "borras": "borrar",
    "borrascas": "borrasca",
    "borrascosa": "borrascoso",
    "borrascosas": "borrascoso",
    "borrascosos": "borrascoso",
    "borrasqueira": "borrasqueiro",
    "borrasqueiras": "borrasqueiro",
    "borrasqueiros": "borrasqueiro",
    "borrasse": "borrar",
    "borrassem": "borrar",
    "borrasses": "borrar",
    "borraste": "borrar",
    "borrastes": "borrar",
    "borrata": "borratar",
    "borratada": "borratar",
    "borratadas": "borratar",
    "borratado": "borratar",
    "borratados": "borratar",
    "borratai": "borratar",
    "borratais": "borratar",
    "borratam": "borratar",
    "borratamo": "borratar",
    "borratamos": "borratar",
    "borratando": "borratar",
    "borratara": "borratar",
    "borrataram": "borratar",
    "borrataras": "borratar",
    "borratarde": "borratar",
    "borratardes": "borratar",
    "borratare": "borratar",
    "borratarei": "borratar",
    "borratareis": "borratar",
    "borratarem": "borratar",
    "borrataremos": "borratar",
    "borratares": "borratar",
    "borrataria": "borratar",
    "borratariam": "borratar",
    "borratarias": "borratar",
    "borratarmo": "borratar",
    "borratarmos": "borratar",
    "borratará": "borratar",
    "borratarás": "borratar",
    "borratarão": "borratar",
    "borrataríamos": "borratar",
    "borrataríeis": "borratar",
    "borratas": "borratar",
    "borratasse": "borratar",
    "borratassem": "borratar",
    "borratasses": "borratar",
    "borrataste": "borratar",
    "borratastes": "borratar",
    "borratava": "borratar",
    "borratavam": "borratar",
    "borratavas": "borratar",
    "borrate": "borratar",
    "borratei": "borratar",
    "borrateis": "borratar",
    "borratem": "borratar",
    "borratemo": "borratar",
    "borratemos": "borratar",
    "borrates": "borratar",
    "borrato": "borratar",
    "borratou": "borratar",
    "borratá": "borratar",
    "borratámo": "borratar",
    "borratámos": "borratar",
    "borratáramo": "borratar",
    "borratáramos": "borratar",
    "borratárei": "borratar",
    "borratáreis": "borratar",
    "borratásseis": "borratar",
    "borratássemos": "borratar",
    "borratávamo": "borratar",
    "borratávamos": "borratar",
    "borratávei": "borratar",
    "borratáveis": "borratar",
    "borratões": "borratão",
    "borrava": "borrar",
    "borravam": "borrar",
    "borravas": "borrar",
    "borrazeiras": "borrazeira",
    "borraça": "borraçar",
    "borraçada": "borraçar",
    "borraçadas": "borraçar",
    "borraçado": "borraçar",
    "borraçados": "borraçar",
    "borraçai": "borraçar",
    "borraçais": "borraçar",
    "borraçam": "borraçar",
    "borraçamo": "borraçar",
    "borraçamos": "borraçar",
    "borraçando": "borraçar",
    "borraçara": "borraçar",
    "borraçaram": "borraçar",
    "borraçaras": "borraçar",
    "borraçardes": "borraçar",
    "borraçarei": "borraçar",
    "borraçareis": "borraçar",
    "borraçarem": "borraçar",
    "borraçaremos": "borraçar",
    "borraçares": "borraçar",
    "borraçaria": "borraçar",
    "borraçariam": "borraçar",
    "borraçarias": "borraçar",
    "borraçarmo": "borraçar",
    "borraçarmos": "borraçar",
    "borraçará": "borraçar",
    "borraçarás": "borraçar",
    "borraçarão": "borraçar",
    "borraçaríamos": "borraçar",
    "borraçaríeis": "borraçar",
    "borraças": "borraçar",
    "borraçasse": "borraçar",
    "borraçassem": "borraçar",
    "borraçasses": "borraçar",
    "borraçaste": "borraçar",
    "borraçastes": "borraçar",
    "borraçava": "borraçar",
    "borraçavam": "borraçar",
    "borraçavas": "borraçar",
    "borraço": "borraçar",
    "borraçou": "borraçar",
    "borraçámo": "borraçar",
    "borraçámos": "borraçar",
    "borraçáramo": "borraçar",
    "borraçáramos": "borraçar",
    "borraçáreis": "borraçar",
    "borraçásseis": "borraçar",
    "borraçássemos": "borraçar",
    "borraçávamo": "borraçar",
    "borraçávamos": "borraçar",
    "borraçáveis": "borraçar",
    "borre": "borrar",
    "borrega": "borrego",
    "borregada": "borregar",
    "borregadas": "borregar",
    "borregado": "borregar",
    "borregados": "borregar",
    "borregai": "borregar",
    "borregais": "borregar",
    "borregam": "borregar",
    "borregamo": "borregar",
    "borregamos": "borregar",
    "borregando": "borregar",
    "borregara": "borregar",
    "borregaram": "borregar",
    "borregaras": "borregar",
    "borregardes": "borregar",
    "borregarei": "borregar",
    "borregareis": "borregar",
    "borregarem": "borregar",
    "borregaremos": "borregar",
    "borregares": "borregar",
    "borregaria": "borregar",
    "borregariam": "borregar",
    "borregarias": "borregar",
    "borregarmo": "borregar",
    "borregarmos": "borregar",
    "borregará": "borregar",
    "borregarás": "borregar",
    "borregarão": "borregar",
    "borregaríamos": "borregar",
    "borregaríeis": "borregar",
    "borregas": "borrego",
    "borregasse": "borregar",
    "borregassem": "borregar",
    "borregasses": "borregar",
    "borregaste": "borregar",
    "borregastes": "borregar",
    "borregava": "borregar",
    "borregavam": "borregar",
    "borregavas": "borregar",
    "borrego": "borregar",
    "borregos": "borrego",
    "borregou": "borregar",
    "borregue": "borregar",
    "borreguei": "borregar",
    "borregueiros": "borregueiro",
    "borregueis": "borregar",
    "borreguem": "borregar",
    "borreguemo": "borregar",
    "borreguemos": "borregar",
    "borregues": "borregar",
    "borreguices": "borreguice",
    "borreguinha": "borrego",
    "borreguinhas": "borrego",
    "borreguinho": "borrego",
    "borreguinhos": "borrego",
    "borreguita": "borrego",
    "borreguitas": "borrego",
    "borreguito": "borrego",
    "borreguitos": "borrego",
    "borregámo": "borregar",
    "borregámos": "borregar",
    "borregáramo": "borregar",
    "borregáramos": "borregar",
    "borregáreis": "borregar",
    "borregásseis": "borregar",
    "borregássemos": "borregar",
    "borregávamo": "borregar",
    "borregávamos": "borregar",
    "borregáveis": "borregar",
    "borrei": "borrar",
    "borreis": "borrar",
    "borrelhos": "borrelho",
    "borrem": "borrar",
    "borremo": "borrar",
    "borremos": "borrar",
    "borrenta": "borrento",
    "borrentas": "borrento",
    "borrentos": "borrento",
    "borres": "borrar",
    "borrice": "borriçar",
    "borricei": "borriçar",
    "borriceiros": "borriceiro",
    "borriceis": "borriçar",
    "borricem": "borriçar",
    "borricemo": "borriçar",
    "borricemos": "borriçar",
    "borrices": "borriçar",
    "borrifa": "borrifar",
    "borrifada": "borrifar",
    "borrifadas": "borrifar",
    "borrifadelas": "borrifadela",
    "borrifado": "borrifar",
    "borrifadores": "borrifador",
    "borrifados": "borrifar",
    "borrifai": "borrifar",
    "borrifais": "borrifar",
    "borrifam": "borrifar",
    "borrifamo": "borrifar",
    "borrifamos": "borrifar",
    "borrifando": "borrifar",
    "borrifara": "borrifar",
    "borrifaram": "borrifar",
    "borrifaras": "borrifar",
    "borrifarde": "borrifar",
    "borrifardes": "borrifar",
    "borrifare": "borrifar",
    "borrifarei": "borrifar",
    "borrifareis": "borrifar",
    "borrifarem": "borrifar",
    "borrifaremos": "borrifar",
    "borrifares": "borrifar",
    "borrifaria": "borrifar",
    "borrifariam": "borrifar",
    "borrifarias": "borrifar",
    "borrifarmo": "borrifar",
    "borrifarmos": "borrifar",
    "borrifará": "borrifar",
    "borrifarás": "borrifar",
    "borrifarão": "borrifar",
    "borrifaríamos": "borrifar",
    "borrifaríeis": "borrifar",
    "borrifas": "borrifar",
    "borrifasse": "borrifar",
    "borrifassem": "borrifar",
    "borrifasses": "borrifar",
    "borrifaste": "borrifar",
    "borrifastes": "borrifar",
    "borrifava": "borrifar",
    "borrifavam": "borrifar",
    "borrifavas": "borrifar",
    "borrife": "borrifar",
    "borrifei": "borrifar",
    "borrifeis": "borrifar",
    "borrifem": "borrifar",
    "borrifemo": "borrifar",
    "borrifemos": "borrifar",
    "borrifes": "borrifar",
    "borrifinho": "borrifo",
    "borrifinhos": "borrifo",
    "borrifito": "borrifo",
    "borrifitos": "borrifo",
    "borrifo": "borrifar",
    "borrifos": "borrifo",
    "borrifou": "borrifar",
    "borrifá": "borrifar",
    "borrifámo": "borrifar",
    "borrifámos": "borrifar",
    "borrifáramo": "borrifar",
    "borrifáramos": "borrifar",
    "borrifárei": "borrifar",
    "borrifáreis": "borrifar",
    "borrifásseis": "borrifar",
    "borrifássemos": "borrifar",
    "borrifávamo": "borrifar",
    "borrifávamos": "borrifar",
    "borrifávei": "borrifar",
    "borrifáveis": "borrifar",
    "borrisca": "borriscar",
    "borriscada": "borriscar",
    "borriscadas": "borriscar",
    "borriscado": "borriscar",
    "borriscados": "borriscar",
    "borriscais": "borriscar",
    "borriscam": "borriscar",
    "borriscamo": "borriscar",
    "borriscamos": "borriscar",
    "borriscando": "borriscar",
    "borriscara": "borriscar",
    "borriscaram": "borriscar",
    "borriscaras": "borriscar",
    "borriscardes": "borriscar",
    "borriscarei": "borriscar",
    "borriscareis": "borriscar",
    "borriscarem": "borriscar",
    "borriscaremos": "borriscar",
    "borriscares": "borriscar",
    "borriscaria": "borriscar",
    "borriscariam": "borriscar",
    "borriscarias": "borriscar",
    "borriscarmo": "borriscar",
    "borriscarmos": "borriscar",
    "borriscará": "borriscar",
    "borriscarás": "borriscar",
    "borriscarão": "borriscar",
    "borriscaríamos": "borriscar",
    "borriscaríeis": "borriscar",
    "borriscas": "borriscar",
    "borriscasse": "borriscar",
    "borriscassem": "borriscar",
    "borriscasses": "borriscar",
    "borriscaste": "borriscar",
    "borriscastes": "borriscar",
    "borriscava": "borriscar",
    "borriscavam": "borriscar",
    "borriscavas": "borriscar",
    "borrisco": "borriscar",
    "borriscos": "borrisco",
    "borriscou": "borriscar",
    "borriscámo": "borriscar",
    "borriscámos": "borriscar",
    "borriscáramo": "borriscar",
    "borriscáramos": "borriscar",
    "borriscáreis": "borriscar",
    "borriscásseis": "borriscar",
    "borriscássemos": "borriscar",
    "borriscávamo": "borriscar",
    "borriscávamos": "borriscar",
    "borriscáveis": "borriscar",
    "borrisque": "borriscar",
    "borrisquei": "borriscar",
    "borrisqueis": "borriscar",
    "borrisquem": "borriscar",
    "borrisquemos": "borriscar",
    "borrisques": "borriscar",
    "borriça": "borriçar",
    "borriçada": "borriçar",
    "borriçadas": "borriçar",
    "borriçado": "borriçar",
    "borriçados": "borriçar",
    "borriçai": "borriçar",
    "borriçais": "borriçar",
    "borriçam": "borriçar",
    "borriçamo": "borriçar",
    "borriçamos": "borriçar",
    "borriçando": "borriçar",
    "borriçara": "borriçar",
    "borriçaram": "borriçar",
    "borriçaras": "borriçar",
    "borriçardes": "borriçar",
    "borriçarei": "borriçar",
    "borriçareis": "borriçar",
    "borriçarem": "borriçar",
    "borriçaremos": "borriçar",
    "borriçares": "borriçar",
    "borriçaria": "borriçar",
    "borriçariam": "borriçar",
    "borriçarias": "borriçar",
    "borriçarmo": "borriçar",
    "borriçarmos": "borriçar",
    "borriçará": "borriçar",
    "borriçarás": "borriçar",
    "borriçarão": "borriçar",
    "borriçaríamos": "borriçar",
    "borriçaríeis": "borriçar",
    "borriças": "borriçar",
    "borriçasse": "borriçar",
    "borriçassem": "borriçar",
    "borriçasses": "borriçar",
    "borriçaste": "borriçar",
    "borriçastes": "borriçar",
    "borriçava": "borriçar",
    "borriçavam": "borriçar",
    "borriçavas": "borriçar",
    "borriço": "borriçar",
    "borriços": "borriço",
    "borriçou": "borriçar",
    "borriçámo": "borriçar",
    "borriçámos": "borriçar",
    "borriçáramo": "borriçar",
    "borriçáramos": "borriçar",
    "borriçáreis": "borriçar",
    "borriçásseis": "borriçar",
    "borriçássemos": "borriçar",
    "borriçávamo": "borriçar",
    "borriçávamos": "borriçar",
    "borriçáveis": "borriçar",
    "borro": "borrar",
    "borros": "borro",
    "borrosa": "borroso",
    "borrosas": "borroso",
    "borrosos": "borroso",
    "borrou": "borrar",
    "borrá": "borrar",
    "borrámo": "borrar",
    "borrámos": "borrar",
    "borráramo": "borrar",
    "borráramos": "borrar",
    "borrárei": "borrar",
    "borráreis": "borrar",
    "borrásseis": "borrar",
    "borrássemos": "borrar",
    "borrávamo": "borrar",
    "borrávamos": "borrar",
    "borrávei": "borrar",
    "borráveis": "borrar",
    "borrões": "borrão",
    "borts": "bort",
    "borzeguieira": "borzeguieiro",
    "borzeguieiras": "borzeguieiro",
    "borzeguieiros": "borzeguieiro",
    "borzeguineira": "borzeguineiro",
    "borzeguineiras": "borzeguineiro",
    "borzeguineiros": "borzeguineiro",
    "borzeguins": "borzeguim",
    "borés": "boré",
    "bosboques": "bosboque",
    "boscagens": "boscagem",
    "boscareja": "boscarejo",
    "boscarejas": "boscarejo",
    "boscarejos": "boscarejo",
    "boscas": "bosca",
    "bosniana": "bosniano",
    "bosnianas": "bosniano",
    "bosnianos": "bosniano",
    "bosqueja": "bosquejar",
    "bosquejada": "bosquejar",
    "bosquejadas": "bosquejar",
    "bosquejado": "bosquejar",
    "bosquejados": "bosquejar",
    "bosquejai": "bosquejar",
    "bosquejais": "bosquejar",
    "bosquejam": "bosquejar",
    "bosquejamo": "bosquejar",
    "bosquejamos": "bosquejar",
    "bosquejando": "bosquejar",
    "bosquejara": "bosquejar",
    "bosquejaram": "bosquejar",
    "bosquejaras": "bosquejar",
    "bosquejarde": "bosquejar",
    "bosquejardes": "bosquejar",
    "bosquejare": "bosquejar",
    "bosquejarei": "bosquejar",
    "bosquejareis": "bosquejar",
    "bosquejarem": "bosquejar",
    "bosquejaremos": "bosquejar",
    "bosquejares": "bosquejar",
    "bosquejaria": "bosquejar",
    "bosquejariam": "bosquejar",
    "bosquejarias": "bosquejar",
    "bosquejarmo": "bosquejar",
    "bosquejarmos": "bosquejar",
    "bosquejará": "bosquejar",
    "bosquejarás": "bosquejar",
    "bosquejarão": "bosquejar",
    "bosquejaríamos": "bosquejar",
    "bosquejaríeis": "bosquejar",
    "bosquejas": "bosquejar",
    "bosquejasse": "bosquejar",
    "bosquejassem": "bosquejar",
    "bosquejasses": "bosquejar",
    "bosquejaste": "bosquejar",
    "bosquejastes": "bosquejar",
    "bosquejava": "bosquejar",
    "bosquejavam": "bosquejar",
    "bosquejavas": "bosquejar",
    "bosqueje": "bosquejar",
    "bosquejei": "bosquejar",
    "bosquejeis": "bosquejar",
    "bosquejem": "bosquejar",
    "bosquejemo": "bosquejar",
    "bosquejemos": "bosquejar",
    "bosquejes": "bosquejar",
    "bosquejo": "bosquejar",
    "bosquejos": "bosquejo",
    "bosquejou": "bosquejar",
    "bosquejá": "bosquejar",
    "bosquejámo": "bosquejar",
    "bosquejámos": "bosquejar",
    "bosquejáramo": "bosquejar",
    "bosquejáramos": "bosquejar",
    "bosquejárei": "bosquejar",
    "bosquejáreis": "bosquejar",
    "bosquejásseis": "bosquejar",
    "bosquejássemos": "bosquejar",
    "bosquejávamo": "bosquejar",
    "bosquejávamos": "bosquejar",
    "bosquejávei": "bosquejar",
    "bosquejáveis": "bosquejar",
    "bosques": "bosque",
    "bosquezinho": "bosque",
    "bosquezinhos": "bosque",
    "bosquezito": "bosque",
    "bosquezitos": "bosque",
    "bosquímanos": "bosquímano",
    "bossagens": "bossagem",
    "bossas": "bossa",
    "bosta": "bostar",
    "bostada": "bostar",
    "bostadas": "bostar",
    "bostado": "bostar",
    "bostados": "bostar",
    "bostai": "bostar",
    "bostais": "bostar",
    "bostam": "bostar",
    "bostamo": "bostar",
    "bostamos": "bostar",
    "bostando": "bostar",
    "bostara": "bostar",
    "bostaram": "bostar",
    "bostaras": "bostar",
    "bostarde": "bostar",
    "bostardes": "bostar",
    "bostare": "bostar",
    "bostarei": "bostar",
    "bostareis": "bostar",
    "bostarem": "bostar",
    "bostaremos": "bostar",
    "bostares": "bostar",
    "bostaria": "bostar",
    "bostariam": "bostar",
    "bostarias": "bostar",
    "bostarmo": "bostar",
    "bostarmos": "bostar",
    "bostará": "bostar",
    "bostarás": "bostar",
    "bostarão": "bostar",
    "bostaríamos": "bostar",
    "bostaríeis": "bostar",
    "bostas": "bostar",
    "bostasse": "bostar",
    "bostassem": "bostar",
    "bostasses": "bostar",
    "bostaste": "bostar",
    "bostastes": "bostar",
    "bostava": "bostar",
    "bostavam": "bostar",
    "bostavas": "bostar",
    "boste": "bostar",
    "bosteada": "bostear",
    "bosteadas": "bostear",
    "bosteado": "bostear",
    "bosteados": "bostear",
    "bosteai": "bostear",
    "bosteais": "bostear",
    "bosteamo": "bostear",
    "bosteamos": "bostear",
    "bosteando": "bostear",
    "bosteara": "bostear",
    "bostearam": "bostear",
    "bostearas": "bostear",
    "bostearde": "bostear",
    "bosteardes": "bostear",
    "bosteare": "bostear",
    "bostearei": "bostear",
    "bosteareis": "bostear",
    "bostearem": "bostear",
    "bostearemos": "bostear",
    "bosteares": "bostear",
    "bostearia": "bostear",
    "bosteariam": "bostear",
    "bostearias": "bostear",
    "bostearmo": "bostear",
    "bostearmos": "bostear",
    "bosteará": "bostear",
    "bostearás": "bostear",
    "bostearão": "bostear",
    "bostearíamos": "bostear",
    "bostearíeis": "bostear",
    "bosteasse": "bostear",
    "bosteassem": "bostear",
    "bosteasses": "bostear",
    "bosteaste": "bostear",
    "bosteastes": "bostear",
    "bosteava": "bostear",
    "bosteavam": "bostear",
    "bosteavas": "bostear",
    "bosteei": "bostear",
    "bosteeis": "bostear",
    "bosteemo": "bostear",
    "bosteemos": "bostear",
    "bostei": "bostar",
    "bosteia": "bostear",
    "bosteiam": "bostear",
    "bosteias": "bostear",
    "bosteie": "bostear",
    "bosteiem": "bostear",
    "bosteies": "bostear",
    "bosteio": "bostear",
    "bosteiras": "bosteira",
    "bosteiros": "bosteiro",
    "bosteis": "bostar",
    "bostelas": "bostela",
    "bostelenta": "bostelento",
    "bostelentas": "bostelento",
    "bostelentos": "bostelento",
    "bostelos": "bostelo",
    "bostem": "bostar",
    "bostemo": "bostar",
    "bostemos": "bostar",
    "bosteou": "bostear",
    "bostes": "bostar",
    "bosteá": "bostear",
    "bosteámo": "bostear",
    "bosteámos": "bostear",
    "bosteáramo": "bostear",
    "bosteáramos": "bostear",
    "bosteárei": "bostear",
    "bosteáreis": "bostear",
    "bosteásseis": "bostear",
    "bosteássemos": "bostear",
    "bosteávamo": "bostear",
    "bosteávamos": "bostear",
    "bosteávei": "bostear",
    "bosteáveis": "bostear",
    "bosto": "bostar",
    "bostolosa": "bostoloso",
    "bostolosas": "bostoloso",
    "bostolosos": "bostoloso",
    "bostou": "bostar",
    "bostá": "bostar",
    "bostámo": "bostar",
    "bostámos": "bostar",
    "bostáramo": "bostar",
    "bostáramos": "bostar",
    "bostárei": "bostar",
    "bostáreis": "bostar",
    "bostásseis": "bostar",
    "bostássemos": "bostar",
    "bostávamo": "bostar",
    "bostávamos": "bostar",
    "bostávei": "bostar",
    "bostáveis": "bostar",
    "bosões": "bosão",
    "bota": "boto",
    "botada": "botar",
    "botadas": "botar",
    "botado": "botar",
    "botados": "botar",
    "botai": "botar",
    "botais": "botar",
    "botalós": "botaló",
    "botam": "botar",
    "botamo": "botar",
    "botamos": "botar",
    "botando": "botar",
    "botantes": "botante",
    "botara": "botar",
    "botaram": "botar",
    "botaras": "botar",
    "botarde": "botar",
    "botardes": "botar",
    "botare": "botar",
    "botarei": "botar",
    "botareis": "botar",
    "botarem": "botar",
    "botaremos": "botar",
    "botares": "botar",
    "botaria": "botar",
    "botariam": "botar",
    "botarias": "botar",
    "botarmo": "botar",
    "botarmos": "botar",
    "botará": "botar",
    "botarás": "botar",
    "botarão": "botar",
    "botaréus": "botaréu",
    "botaríamos": "botar",
    "botaríeis": "botar",
    "botas": "boto",
    "botasse": "botar",
    "botassem": "botar",
    "botasses": "botar",
    "botaste": "botar",
    "botastes": "botar",
    "botava": "botar",
    "botavam": "botar",
    "botavas": "botar",
    "bote": "botar",
    "botei": "botar",
    "boteiros": "boteiro",
    "boteis": "botar",
    "botelharias": "botelharia",
    "botelhas": "botelha",
    "botelheiros": "botelheiro",
    "botem": "botar",
    "botemo": "botar",
    "botemos": "botar",
    "botequineira": "botequineiro",
    "botequineiras": "botequineiro",
    "botequineiros": "botequineiro",
    "botequins": "botequim",
    "botes": "bote",
    "botezinho": "bote",
    "botezinhos": "bote",
    "botezito": "bote",
    "botezitos": "bote",
    "boticas": "botica",
    "boticária": "boticário",
    "boticárias": "boticário",
    "boticários": "boticário",
    "boticões": "boticão",
    "botifarras": "botifarra",
    "botijas": "botija",
    "botilhões": "botilhão",
    "botinas": "botina",
    "botineira": "botineiro",
    "botineiras": "botineiro",
    "botineiros": "botineiro",
    "botinha": "bota",
    "botinhas": "bota",
    "botins": "botim",
    "botiques": "botique",
    "botirões": "botirão",
    "botita": "bota",
    "botitas": "bota",
    "boto": "botar",
    "botoarias": "botoaria",
    "botoca": "botocar",
    "botocada": "botocar",
    "botocadas": "botocar",
    "botocado": "botocar",
    "botocados": "botocar",
    "botocais": "botocar",
    "botocam": "botocar",
    "botocamo": "botocar",
    "botocamos": "botocar",
    "botocando": "botocar",
    "botocara": "botocar",
    "botocaram": "botocar",
    "botocaras": "botocar",
    "botocardes": "botocar",
    "botocarei": "botocar",
    "botocareis": "botocar",
    "botocarem": "botocar",
    "botocaremos": "botocar",
    "botocares": "botocar",
    "botocaria": "botocar",
    "botocariam": "botocar",
    "botocarias": "botocar",
    "botocarmo": "botocar",
    "botocarmos": "botocar",
    "botocará": "botocar",
    "botocarás": "botocar",
    "botocarão": "botocar",
    "botocaríamos": "botocar",
    "botocaríeis": "botocar",
    "botocas": "botocar",
    "botocasse": "botocar",
    "botocassem": "botocar",
    "botocasses": "botocar",
    "botocaste": "botocar",
    "botocastes": "botocar",
    "botocava": "botocar",
    "botocavam": "botocar",
    "botocavas": "botocar",
    "botoco": "botocar",
    "botocou": "botocar",
    "botocámo": "botocar",
    "botocámos": "botocar",
    "botocáramo": "botocar",
    "botocáramos": "botocar",
    "botocáreis": "botocar",
    "botocásseis": "botocar",
    "botocássemos": "botocar",
    "botocávamo": "botocar",
    "botocávamos": "botocar",
    "botocáveis": "botocar",
    "botoeira": "botoeiro",
    "botoeiras": "botoeiro",
    "botoeiros": "botoeiro",
    "botolismos": "botolismo",
    "botoque": "botocar",
    "botoquei": "botocar",
    "botoqueis": "botocar",
    "botoquem": "botocar",
    "botoquemos": "botocar",
    "botoques": "botoque",
    "botos": "boto",
    "botou": "botar",
    "botriocéfala": "botriocéfalo",
    "botriocéfalas": "botriocéfalo",
    "botriocéfalos": "botriocéfalo",
    "botrioidais": "botrioidal",
    "botrióides": "botrióide",
    "botriões": "botrião",
    "botá": "botar",
    "botámo": "botar",
    "botámos": "botar",
    "botáramo": "botar",
    "botáramos": "botar",
    "botárei": "botar",
    "botáreis": "botar",
    "botásseis": "botar",
    "botássemos": "botar",
    "botávamo": "botar",
    "botávamos": "botar",
    "botávei": "botar",
    "botáveis": "botar",
    "botânica": "botânico",
    "botânicas": "botânico",
    "botânicos": "botânico",
    "botãozinho": "botão",
    "botãozito": "botão",
    "botões": "botão",
    "botõezinhos": "botão",
    "botõezitos": "botão",
    "boubas": "bouba",
    "boubenta": "boubento",
    "boubentas": "boubento",
    "boubentos": "boubento",
    "bouce": "bouçar",
    "boucei": "bouçar",
    "bouceis": "bouçar",
    "boucem": "bouçar",
    "boucemo": "bouçar",
    "boucemos": "bouçar",
    "bouces": "bouçar",
    "bouchas": "boucha",
    "boutiques": "boutique",
    "bouverismos": "bouverismo",
    "bouça": "bouçar",
    "bouçada": "bouçar",
    "bouçadas": "bouçar",
    "bouçado": "bouçar",
    "bouçados": "bouçar",
    "bouçai": "bouçar",
    "bouçais": "bouçar",
    "bouçam": "bouçar",
    "bouçamo": "bouçar",
    "bouçamos": "bouçar",
    "bouçando": "bouçar",
    "bouçara": "bouçar",
    "bouçaram": "bouçar",
    "bouçaras": "bouçar",
    "bouçarde": "bouçar",
    "bouçardes": "bouçar",
    "bouçare": "bouçar",
    "bouçarei": "bouçar",
    "bouçareis": "bouçar",
    "bouçarem": "bouçar",
    "bouçaremos": "bouçar",
    "bouçares": "bouçar",
    "bouçaria": "bouçar",
    "bouçariam": "bouçar",
    "bouçarias": "bouçar",
    "bouçarmo": "bouçar",
    "bouçarmos": "bouçar",
    "bouçará": "bouçar",
    "bouçarás": "bouçar",
    "bouçarão": "bouçar",
    "bouçaríamos": "bouçar",
    "bouçaríeis": "bouçar",
    "bouças": "bouçar",
    "bouçasse": "bouçar",
    "bouçassem": "bouçar",
    "bouçasses": "bouçar",
    "bouçaste": "bouçar",
    "bouçastes": "bouçar",
    "bouçava": "bouçar",
    "bouçavam": "bouçar",
    "bouçavas": "bouçar",
    "bouço": "bouçar",
    "bouçou": "bouçar",
    "bouçá": "bouçar",
    "bouçámo": "bouçar",
    "bouçámos": "bouçar",
    "bouçáramo": "bouçar",
    "bouçáramos": "bouçar",
    "bouçárei": "bouçar",
    "bouçáreis": "bouçar",
    "bouçásseis": "bouçar",
    "bouçássemos": "bouçar",
    "bouçávamo": "bouçar",
    "bouçávamos": "bouçar",
    "bouçávei": "bouçar",
    "bouçáveis": "bouçar",
    "bovina": "bovino",
    "bovinas": "bovino",
    "bovinocultora": "bovinocultor",
    "bovinocultoras": "bovinocultor",
    "bovinocultores": "bovinocultor",
    "bovinoculturas": "bovinocultura",
    "bovinos": "bovino",
    "bovídea": "bovídeo",
    "bovídeas": "bovídeo",
    "bovídeos": "bovídeo",
    "boxa": "boxar",
    "boxada": "boxar",
    "boxadas": "boxar",
    "boxado": "boxar",
    "boxadores": "boxador",
    "boxados": "boxar",
    "boxai": "boxar",
    "boxais": "boxar",
    "boxam": "boxar",
    "boxamo": "boxar",
    "boxamos": "boxar",
    "boxando": "boxar",
    "boxara": "boxar",
    "boxaram": "boxar",
    "boxaras": "boxar",
    "boxarde": "boxar",
    "boxardes": "boxar",
    "boxare": "boxar",
    "boxarei": "boxar",
    "boxareis": "boxar",
    "boxarem": "boxar",
    "boxaremos": "boxar",
    "boxares": "boxar",
    "boxaria": "boxar",
    "boxariam": "boxar",
    "boxarias": "boxar",
    "boxarmo": "boxar",
    "boxarmos": "boxar",
    "boxará": "boxar",
    "boxarás": "boxar",
    "boxarão": "boxar",
    "boxaríamos": "boxar",
    "boxaríeis": "boxar",
    "boxas": "boxar",
    "boxasse": "boxar",
    "boxassem": "boxar",
    "boxasses": "boxar",
    "boxaste": "boxar",
    "boxastes": "boxar",
    "boxava": "boxar",
    "boxavam": "boxar",
    "boxavas": "boxar",
    "boxe": "boxar",
    "boxeadora": "boxeador",
    "boxeadoras": "boxeador",
    "boxeadores": "boxeador",
    "boxei": "boxar",
    "boxeis": "boxar",
    "boxem": "boxar",
    "boxemo": "boxar",
    "boxemos": "boxar",
    "boxes": "boxe",
    "boximanes": "boximane",
    "boxistas": "boxista",
    "boxo": "boxar",
    "boxou": "boxar",
    "boxá": "boxar",
    "boxámo": "boxar",
    "boxámos": "boxar",
    "boxáramo": "boxar",
    "boxáramos": "boxar",
    "boxárei": "boxar",
    "boxáreis": "boxar",
    "boxásseis": "boxar",
    "boxássemos": "boxar",
    "boxávamo": "boxar",
    "boxávamos": "boxar",
    "boxávei": "boxar",
    "boxáveis": "boxar",
    "boxímanes": "boxímane",
    "bozuns": "bozum",
    "bozós": "bozó",
    "boça": "boçar",
    "boçada": "boçar",
    "boçadas": "boçar",
    "boçado": "boçar",
    "boçados": "boçar",
    "boçai": "boçar",
    "boçais": "boçar",
    "boçalidades": "boçalidade",
    "boçam": "boçar",
    "boçamo": "boçar",
    "boçamos": "boçar",
    "boçando": "boçar",
    "boçara": "boçar",
    "boçaram": "boçar",
    "boçaras": "boçar",
    "boçardas": "boçarda",
    "boçarde": "boçar",
    "boçardes": "boçar",
    "boçare": "boçar",
    "boçarei": "boçar",
    "boçareis": "boçar",
    "boçarem": "boçar",
    "boçaremos": "boçar",
    "boçares": "boçar",
    "boçaria": "boçar",
    "boçariam": "boçar",
    "boçarias": "boçar",
    "boçarmo": "boçar",
    "boçarmos": "boçar",
    "boçará": "boçar",
    "boçarás": "boçar",
    "boçarão": "boçar",
    "boçaríamos": "boçar",
    "boçaríeis": "boçar",
    "boças": "boçar",
    "boçasse": "boçar",
    "boçassem": "boçar",
    "boçasses": "boçar",
    "boçaste": "boçar",
    "boçastes": "boçar",
    "boçava": "boçar",
    "boçavam": "boçar",
    "boçavas": "boçar",
    "boçejadora": "boçejador",
    "boçejadoras": "boçejador",
    "boçejadores": "boçejador",
    "boço": "boçar",
    "boçou": "boçar",
    "boçuda": "boçudo",
    "boçudas": "boçudo",
    "boçudos": "boçudo",
    "boçá": "boçar",
    "boçámo": "boçar",
    "boçámos": "boçar",
    "boçáramo": "boçar",
    "boçáramos": "boçar",
    "boçárei": "boçar",
    "boçáreis": "boçar",
    "boçásseis": "boçar",
    "boçássemos": "boçar",
    "boçávamo": "boçar",
    "boçávamos": "boçar",
    "boçávei": "boçar",
    "boçáveis": "boçar",
    "boémia": "boémio",
    "boémias": "boémio",
    "boémios": "boémio",
    "boîtes": "boîte",
    "bracamartes": "bracamarte",
    "bracarenses": "bracarense",
    "braceada": "bracear",
    "braceadas": "bracear",
    "braceado": "bracear",
    "braceados": "bracear",
    "braceai": "bracear",
    "braceais": "bracear",
    "braceamo": "bracear",
    "braceamos": "bracear",
    "braceando": "bracear",
    "braceara": "bracear",
    "bracearam": "bracear",
    "bracearas": "bracear",
    "braceardes": "bracear",
    "bracearei": "bracear",
    "braceareis": "bracear",
    "bracearem": "bracear",
    "bracearemos": "bracear",
    "braceares": "bracear",
    "bracearia": "bracear",
    "braceariam": "bracear",
    "bracearias": "bracear",
    "bracearmo": "bracear",
    "bracearmos": "bracear",
    "braceará": "bracear",
    "bracearás": "bracear",
    "bracearão": "bracear",
    "bracearíamos": "bracear",
    "bracearíeis": "bracear",
    "braceasse": "bracear",
    "braceassem": "bracear",
    "braceasses": "bracear",
    "braceaste": "bracear",
    "braceastes": "bracear",
    "braceava": "bracear",
    "braceavam": "bracear",
    "braceavas": "bracear",
    "braceei": "bracear",
    "braceeis": "bracear",
    "braceemo": "bracear",
    "braceemos": "bracear",
    "braceia": "bracear",
    "braceiam": "bracear",
    "braceias": "bracear",
    "braceie": "bracear",
    "braceiem": "bracear",
    "braceies": "bracear",
    "braceio": "bracear",
    "braceira": "braceiro",
    "braceiras": "braceiro",
    "braceiros": "braceiro",
    "braceja": "bracejar",
    "bracejada": "bracejar",
    "bracejadas": "bracejar",
    "bracejado": "bracejar",
    "bracejadora": "bracejador",
    "bracejadoras": "bracejador",
    "bracejadores": "bracejador",
    "bracejados": "bracejar",
    "bracejai": "bracejar",
    "bracejais": "bracejar",
    "bracejam": "bracejar",
    "bracejamentos": "bracejamento",
    "bracejamo": "bracejar",
    "bracejamos": "bracejar",
    "bracejando": "bracejar",
    "bracejara": "bracejar",
    "bracejaram": "bracejar",
    "bracejaras": "bracejar",
    "bracejardes": "bracejar",
    "bracejarei": "bracejar",
    "bracejareis": "bracejar",
    "bracejarem": "bracejar",
    "bracejaremos": "bracejar",
    "bracejares": "bracejar",
    "bracejaria": "bracejar",
    "bracejariam": "bracejar",
    "bracejarias": "bracejar",
    "bracejarmo": "bracejar",
    "bracejarmos": "bracejar",
    "bracejará": "bracejar",
    "bracejarás": "bracejar",
    "bracejarão": "bracejar",
    "bracejaríamos": "bracejar",
    "bracejaríeis": "bracejar",
    "bracejas": "bracejar",
    "bracejasse": "bracejar",
    "bracejassem": "bracejar",
    "bracejasses": "bracejar",
    "bracejaste": "bracejar",
    "bracejastes": "bracejar",
    "bracejava": "bracejar",
    "bracejavam": "bracejar",
    "bracejavas": "bracejar",
    "braceje": "bracejar",
    "bracejei": "bracejar",
    "bracejeis": "bracejar",
    "bracejem": "bracejar",
    "bracejemo": "bracejar",
    "bracejemos": "bracejar",
    "bracejes": "bracejar",
    "bracejo": "bracejar",
    "bracejos": "bracejo",
    "bracejou": "bracejar",
    "bracejámo": "bracejar",
    "bracejámos": "bracejar",
    "bracejáramo": "bracejar",
    "bracejáramos": "bracejar",
    "bracejáreis": "bracejar",
    "bracejásseis": "bracejar",
    "bracejássemos": "bracejar",
    "bracejávamo": "bracejar",
    "bracejávamos": "bracejar",
    "bracejáveis": "bracejar",
    "braceleiras": "braceleira",
    "braceletes": "bracelete",
    "braceou": "bracear",
    "braceámo": "bracear",
    "braceámos": "bracear",
    "braceáramo": "bracear",
    "braceáramos": "bracear",
    "braceáreis": "bracear",
    "braceásseis": "bracear",
    "braceássemos": "bracear",
    "braceávamo": "bracear",
    "braceávamos": "bracear",
    "braceáveis": "bracear",
    "braciagens": "braciagem",
    "bracinho": "braço",
    "bracinhos": "braço",
    "bracito": "braço",
    "bracitos": "braço",
    "bracos": "braco",
    "bracteada": "bracteado",
    "bracteadas": "bracteado",
    "bracteados": "bracteado",
    "bracteais": "bracteal",
    "bracteiformes": "bracteiforme",
    "bracteolada": "bracteolado",
    "bracteoladas": "bracteolado",
    "bracteolados": "bracteolado",
    "bracteolares": "bracteolar",
    "bractéolas": "bractéola",
    "brada": "bradar",
    "bradada": "bradar",
    "bradadas": "bradar",
    "bradado": "bradar",
    "bradados": "bradar",
    "bradai": "bradar",
    "bradais": "bradar",
    "bradam": "bradar",
    "bradamo": "bradar",
    "bradamos": "bradar",
    "bradando": "bradar",
    "bradara": "bradar",
    "bradaram": "bradar",
    "bradaras": "bradar",
    "bradardes": "bradar",
    "bradarei": "bradar",
    "bradareis": "bradar",
    "bradarem": "bradar",
    "bradaremos": "bradar",
    "bradares": "bradar",
    "bradaria": "bradar",
    "bradariam": "bradar",
    "bradarias": "bradar",
    "bradarmo": "bradar",
    "bradarmos": "bradar",
    "bradará": "bradar",
    "bradarás": "bradar",
    "bradarão": "bradar",
    "bradaríamos": "bradar",
    "bradaríeis": "bradar",
    "bradas": "bradar",
    "bradasse": "bradar",
    "bradassem": "bradar",
    "bradasses": "bradar",
    "bradaste": "bradar",
    "bradastes": "bradar",
    "bradava": "bradar",
    "bradavam": "bradar",
    "bradavas": "bradar",
    "brade": "bradar",
    "bradei": "bradar",
    "bradeis": "bradar",
    "bradeja": "bradejar",
    "bradejada": "bradejar",
    "bradejadas": "bradejar",
    "bradejado": "bradejar",
    "bradejados": "bradejar",
    "bradejai": "bradejar",
    "bradejais": "bradejar",
    "bradejam": "bradejar",
    "bradejamo": "bradejar",
    "bradejamos": "bradejar",
    "bradejando": "bradejar",
    "bradejara": "bradejar",
    "bradejaram": "bradejar",
    "bradejaras": "bradejar",
    "bradejardes": "bradejar",
    "bradejarei": "bradejar",
    "bradejareis": "bradejar",
    "bradejarem": "bradejar",
    "bradejaremos": "bradejar",
    "bradejares": "bradejar",
    "bradejaria": "bradejar",
    "bradejariam": "bradejar",
    "bradejarias": "bradejar",
    "bradejarmo": "bradejar",
    "bradejarmos": "bradejar",
    "bradejará": "bradejar",
    "bradejarás": "bradejar",
    "bradejarão": "bradejar",
    "bradejaríamos": "bradejar",
    "bradejaríeis": "bradejar",
    "bradejas": "bradejar",
    "bradejasse": "bradejar",
    "bradejassem": "bradejar",
    "bradejasses": "bradejar",
    "bradejaste": "bradejar",
    "bradejastes": "bradejar",
    "bradejava": "bradejar",
    "bradejavam": "bradejar",
    "bradejavas": "bradejar",
    "bradeje": "bradejar",
    "bradejei": "bradejar",
    "bradejeis": "bradejar",
    "bradejem": "bradejar",
    "bradejemo": "bradejar",
    "bradejemos": "bradejar",
    "bradejes": "bradejar",
    "bradejo": "bradejar",
    "bradejou": "bradejar",
    "bradejámo": "bradejar",
    "bradejámos": "bradejar",
    "bradejáramo": "bradejar",
    "bradejáramos": "bradejar",
    "bradejáreis": "bradejar",
    "bradejásseis": "bradejar",
    "bradejássemos": "bradejar",
    "bradejávamo": "bradejar",
    "bradejávamos": "bradejar",
    "bradejáveis": "bradejar",
    "bradem": "bradar",
    "brademo": "bradar",
    "brademos": "bradar",
    "brades": "bradar",
    "bradicardias": "bradicardia",
    "bradifasias": "bradifasia",
    "bradiglossias": "bradiglossia",
    "bradipepsias": "bradipepsia",
    "bradipneias": "bradipneia",
    "bradissismos": "bradissismo",
    "brado": "bradar",
    "brados": "brado",
    "bradou": "bradar",
    "bradozinho": "brado",
    "bradozinhos": "brado",
    "bradozito": "brado",
    "bradozitos": "brado",
    "bradámo": "bradar",
    "bradámos": "bradar",
    "bradáramo": "bradar",
    "bradáramos": "bradar",
    "bradáreis": "bradar",
    "bradásseis": "bradar",
    "bradássemos": "bradar",
    "bradávamo": "bradar",
    "bradávamos": "bradar",
    "bradáveis": "bradar",
    "bradípodes": "bradípode",
    "bradões": "bradão",
    "bragada": "bragado",
    "bragadas": "bragado",
    "bragados": "bragado",
    "bragaduras": "bragadura",
    "bragais": "bragal",
    "bragana": "bragano",
    "braganas": "bragano",
    "bragancesa": "bragancês",
    "bragancesas": "bragancês",
    "braganceses": "bragancês",
    "braganos": "bragano",
    "bragantes": "bragante",
    "bragantina": "bragantino",
    "bragantinas": "bragantino",
    "bragantinos": "bragantino",
    "bragançana": "bragançano",
    "bragançanas": "bragançano",
    "bragançanos": "bragançano",
    "bragançona": "braganção",
    "bragançonas": "braganção",
    "braganções": "braganção",
    "bragas": "braga",
    "bragueiros": "bragueiro",
    "braguesa": "braguês",
    "braguesas": "braguês",
    "bragueses": "braguês",
    "braguilhas": "braguilha",
    "brainstormings": "brainstorming",
    "brama": "bramir",
    "bramada": "bramar",
    "bramadas": "bramar",
    "bramadeiros": "bramadeiro",
    "bramado": "bramar",
    "bramadora": "bramador",
    "bramadoras": "bramador",
    "bramadores": "bramador",
    "bramados": "bramar",
    "bramai": "bramar",
    "bramais": "bramir",
    "bramam": "bramir",
    "bramamo": "bramir",
    "bramamos": "bramir",
    "bramando": "bramar",
    "bramanismos": "bramanismo",
    "bramanistas": "bramanista",
    "bramantes": "bramante",
    "bramara": "bramar",
    "bramaram": "bramar",
    "bramaras": "bramar",
    "bramardes": "bramar",
    "bramarei": "bramar",
    "bramareis": "bramar",
    "bramarem": "bramar",
    "bramaremos": "bramar",
    "bramares": "bramar",
    "bramaria": "bramar",
    "bramariam": "bramar",
    "bramarias": "bramar",
    "bramarmo": "bramar",
    "bramarmos": "bramar",
    "bramará": "bramar",
    "bramarás": "bramar",
    "bramarão": "bramar",
    "bramaríamos": "bramar",
    "bramaríeis": "bramar",
    "bramas": "bramir",
    "bramasse": "bramar",
    "bramassem": "bramar",
    "bramasses": "bramar",
    "bramaste": "bramar",
    "bramastes": "bramar",
    "bramava": "bramar",
    "bramavam": "bramar",
    "bramavas": "bramar",
    "brame": "bramir",
    "bramei": "bramar",
    "brameis": "bramar",
    "bramem": "bramir",
    "bramemo": "bramar",
    "bramemos": "bramar",
    "brames": "bramir",
    "brami": "bramir",
    "bramia": "bramir",
    "bramiam": "bramir",
    "bramias": "bramir",
    "bramida": "bramir",
    "bramidas": "bramir",
    "bramido": "bramir",
    "bramidora": "bramidor",
    "bramidoras": "bramidor",
    "bramidores": "bramidor",
    "bramidos": "bramir",
    "bramimo": "bramir",
    "bramimos": "bramir",
    "bramindo": "bramir",
    "bramira": "bramir",
    "bramiram": "bramir",
    "bramiras": "bramir",
    "bramirdes": "bramir",
    "bramirei": "bramir",
    "bramireis": "bramir",
    "bramirem": "bramir",
    "bramiremos": "bramir",
    "bramires": "bramir",
    "bramiria": "bramir",
    "bramiriam": "bramir",
    "bramirias": "bramir",
    "bramirmo": "bramir",
    "bramirmos": "bramir",
    "bramirá": "bramir",
    "bramirás": "bramir",
    "bramirão": "bramir",
    "bramiríamos": "bramir",
    "bramiríeis": "bramir",
    "bramis": "bramir",
    "bramismos": "bramismo",
    "bramisse": "bramir",
    "bramissem": "bramir",
    "bramisses": "bramir",
    "bramistas": "bramista",
    "bramiste": "bramir",
    "bramistes": "bramir",
    "bramiu": "bramir",
    "bramo": "bramir",
    "bramou": "bramar",
    "bramámo": "bramar",
    "bramámos": "bramar",
    "bramáramo": "bramar",
    "bramáramos": "bramar",
    "bramáreis": "bramar",
    "bramásseis": "bramar",
    "bramássemos": "bramar",
    "bramávamo": "bramar",
    "bramávamos": "bramar",
    "bramáveis": "bramar",
    "bramânica": "bramânico",
    "bramânicas": "bramânico",
    "bramânicos": "bramânico",
    "bramãs": "bramã",
    "bramíamo": "bramir",
    "bramíamos": "bramir",
    "bramíeis": "bramir",
    "bramíramo": "bramir",
    "bramíramos": "bramir",
    "bramíreis": "bramir",
    "bramísseis": "bramir",
    "bramíssemos": "bramir",
    "branca": "branco",
    "brancacenta": "brancacento",
    "brancacentas": "brancacento",
    "brancacentos": "brancacento",
    "brancagens": "brancagem",
    "brancais": "brancal",
    "brancarona": "brancarão",
    "brancaronas": "brancarão",
    "brancarões": "brancarão",
    "brancas": "branco",
    "brancores": "brancor",
    "brancos": "branco",
    "brancuras": "brancura",
    "branda": "brando",
    "brandais": "brandir",
    "brandam": "brandir",
    "brandamo": "brandir",
    "brandamos": "brandir",
    "brandas": "brando",
    "brande": "brandir",
    "brandeiras": "brandeira",
    "brandem": "brandir",
    "brandes": "brandir",
    "brandezas": "brandeza",
    "brandi": "brandir",
    "brandia": "brandir",
    "brandiam": "brandir",
    "brandias": "brandir",
    "brandida": "brandir",
    "brandidas": "brandir",
    "brandido": "brandir",
    "brandidos": "brandir",
    "brandies": "brandy",
    "brandimentos": "brandimento",
    "brandimo": "brandir",
    "brandimos": "brandir",
    "brandindo": "brandir",
    "brandira": "brandir",
    "brandiram": "brandir",
    "brandiras": "brandir",
    "brandirde": "brandir",
    "brandirdes": "brandir",
    "brandire": "brandir",
    "brandirei": "brandir",
    "brandireis": "brandir",
    "brandirem": "brandir",
    "brandiremos": "brandir",
    "brandires": "brandir",
    "brandiria": "brandir",
    "brandiriam": "brandir",
    "brandirias": "brandir",
    "brandirmo": "brandir",
    "brandirmos": "brandir",
    "brandirá": "brandir",
    "brandirás": "brandir",
    "brandirão": "brandir",
    "brandiríamos": "brandir",
    "brandiríeis": "brandir",
    "brandis": "brandir",
    "brandisse": "brandir",
    "brandissem": "brandir",
    "brandisses": "brandir",
    "brandiste": "brandir",
    "brandistes": "brandir",
    "brandiu": "brandir",
    "brando": "brandir",
    "brandos": "brando",
    "branduras": "brandura",
    "brandíamo": "brandir",
    "brandíamos": "brandir",
    "brandíei": "brandir",
    "brandíeis": "brandir",
    "brandíloqua": "brandíloquo",
    "brandíloquas": "brandíloquo",
    "brandíloquos": "brandíloquo",
    "brandíramo": "brandir",
    "brandíramos": "brandir",
    "brandírei": "brandir",
    "brandíreis": "brandir",
    "brandísseis": "brandir",
    "brandíssemos": "brandir",
    "brandíssima": "brando",
    "brandíssimas": "brando",
    "brandíssimo": "brando",
    "brandíssimos": "brando",
    "brandíveis": "brandível",
    "brandões": "brandão",
    "branqua": "branquir",
    "branquais": "branquir",
    "branquam": "branquir",
    "branquamo": "branquir",
    "branquamos": "branquir",
    "branquas": "branquir",
    "branqueada": "branquear",
    "branqueadas": "branquear",
    "branqueado": "branquear",
    "branqueadora": "branqueador",
    "branqueadoras": "branqueador",
    "branqueadores": "branqueador",
    "branqueados": "branquear",
    "branqueaduras": "branqueadura",
    "branqueai": "branquear",
    "branqueais": "branquear",
    "branqueamentos": "branqueamento",
    "branqueamo": "branquear",
    "branqueamos": "branquear",
    "branqueando": "branquear",
    "branqueara": "branquear",
    "branquearam": "branquear",
    "branquearas": "branquear",
    "branquearde": "branquear",
    "branqueardes": "branquear",
    "branqueare": "branquear",
    "branquearei": "branquear",
    "branqueareis": "branquear",
    "branquearem": "branquear",
    "branquearemos": "branquear",
    "branqueares": "branquear",
    "branquearia": "branquear",
    "branqueariam": "branquear",
    "branquearias": "branquearia",
    "branquearmo": "branquear",
    "branquearmos": "branquear",
    "branqueará": "branquear",
    "branquearás": "branquear",
    "branquearão": "branquear",
    "branquearíamos": "branquear",
    "branquearíeis": "branquear",
    "branqueasse": "branquear",
    "branqueassem": "branquear",
    "branqueasses": "branquear",
    "branqueaste": "branquear",
    "branqueastes": "branquear",
    "branqueava": "branquear",
    "branqueavam": "branquear",
    "branqueavas": "branquear",
    "branqueações": "branqueação",
    "branqueei": "branquear",
    "branqueeis": "branquear",
    "branqueemo": "branquear",
    "branqueemos": "branquear",
    "branqueia": "branquear",
    "branqueiam": "branquear",
    "branqueias": "branquear",
    "branqueie": "branquear",
    "branqueiem": "branquear",
    "branqueies": "branquear",
    "branqueio": "branquear",
    "branqueios": "branqueio",
    "branqueja": "branquejar",
    "branquejada": "branquejar",
    "branquejadas": "branquejar",
    "branquejado": "branquejar",
    "branquejados": "branquejar",
    "branquejai": "branquejar",
    "branquejais": "branquejar",
    "branquejam": "branquejar",
    "branquejamo": "branquejar",
    "branquejamos": "branquejar",
    "branquejando": "branquejar",
    "branquejantes": "branquejante",
    "branquejara": "branquejar",
    "branquejaram": "branquejar",
    "branquejaras": "branquejar",
    "branquejardes": "branquejar",
    "branquejarei": "branquejar",
    "branquejareis": "branquejar",
    "branquejarem": "branquejar",
    "branquejaremos": "branquejar",
    "branquejares": "branquejar",
    "branquejaria": "branquejar",
    "branquejariam": "branquejar",
    "branquejarias": "branquejar",
    "branquejarmo": "branquejar",
    "branquejarmos": "branquejar",
    "branquejará": "branquejar",
    "branquejarás": "branquejar",
    "branquejarão": "branquejar",
    "branquejaríamos": "branquejar",
    "branquejaríeis": "branquejar",
    "branquejas": "branquejar",
    "branquejasse": "branquejar",
    "branquejassem": "branquejar",
    "branquejasses": "branquejar",
    "branquejaste": "branquejar",
    "branquejastes": "branquejar",
    "branquejava": "branquejar",
    "branquejavam": "branquejar",
    "branquejavas": "branquejar",
    "branqueje": "branquejar",
    "branquejei": "branquejar",
    "branquejeis": "branquejar",
    "branquejem": "branquejar",
    "branquejemo": "branquejar",
    "branquejemos": "branquejar",
    "branquejes": "branquejar",
    "branquejo": "branquejar",
    "branquejou": "branquejar",
    "branquejámo": "branquejar",
    "branquejámos": "branquejar",
    "branquejáramo": "branquejar",
    "branquejáramos": "branquejar",
    "branquejáreis": "branquejar",
    "branquejásseis": "branquejar",
    "branquejássemos": "branquejar",
    "branquejávamo": "branquejar",
    "branquejávamos": "branquejar",
    "branquejáveis": "branquejar",
    "branquem": "branquir",
    "branqueou": "branquear",
    "branquetas": "branqueta",
    "branqueá": "branquear",
    "branqueámo": "branquear",
    "branqueámos": "branquear",
    "branqueáramo": "branquear",
    "branqueáramos": "branquear",
    "branqueárei": "branquear",
    "branqueáreis": "branquear",
    "branqueásseis": "branquear",
    "branqueássemos": "branquear",
    "branqueávamo": "branquear",
    "branqueávamos": "branquear",
    "branqueávei": "branquear",
    "branqueáveis": "branqueável",
    "branqui": "branquir",
    "branquiada": "branquiado",
    "branquiadas": "branquiado",
    "branquiados": "branquiado",
    "branquiais": "branquial",
    "branquidões": "branquidão",
    "branquindo": "branquir",
    "branquinha": "branco",
    "branquinhas": "branco",
    "branquinho": "branco",
    "branquinhos": "branco",
    "branquiostégios": "branquiostégio",
    "branquirde": "branquir",
    "branquirdes": "branquir",
    "branquirei": "branquir",
    "branquireis": "branquir",
    "branquiremos": "branquir",
    "branquiria": "branquir",
    "branquiriam": "branquir",
    "branquirias": "branquir",
    "branquirmo": "branquir",
    "branquirmos": "branquir",
    "branquirá": "branquir",
    "branquirás": "branquir",
    "branquirão": "branquir",
    "branquiríamos": "branquir",
    "branquiríeis": "branquir",
    "branquis": "branquir",
    "branquita": "branco",
    "branquitas": "branco",
    "branquito": "branco",
    "branquitos": "branco",
    "branquiu": "branquir",
    "branquiópodes": "branquiópode",
    "branquo": "branquir",
    "branquí": "branquir",
    "branquía": "branquir",
    "branquíam": "branquir",
    "branquíamo": "branquir",
    "branquíamos": "branquir",
    "branquías": "branquir",
    "branquída": "branquir",
    "branquídas": "branquir",
    "branquído": "branquir",
    "branquídos": "branquir",
    "branquíei": "branquir",
    "branquíeis": "branquir",
    "branquímo": "branquir",
    "branquímos": "branquir",
    "branquíra": "branquir",
    "branquíram": "branquir",
    "branquíramo": "branquir",
    "branquíramos": "branquir",
    "branquíras": "branquir",
    "branquíre": "branquir",
    "branquírei": "branquir",
    "branquíreis": "branquir",
    "branquírem": "branquir",
    "branquíres": "branquir",
    "branquís": "branquir",
    "branquísse": "branquir",
    "branquísseis": "branquir",
    "branquíssem": "branquir",
    "branquíssemos": "branquir",
    "branquísses": "branquir",
    "branquíssima": "branco",
    "branquíssimas": "branco",
    "branquíssimo": "branco",
    "branquíssimos": "branco",
    "branquíste": "branquir",
    "branquístes": "branquir",
    "branzas": "branza",
    "braquiada": "braquiado",
    "braquiadas": "braquiado",
    "braquiados": "braquiado",
    "braquiais": "braquial",
    "braquialgias": "braquialgia",
    "braquicefalias": "braquicefalia",
    "braquicéfala": "braquicéfalo",
    "braquicéfalas": "braquicéfalo",
    "braquicéfalos": "braquicéfalo",
    "braquidiagonais": "braquidiagonal",
    "braquidáctila": "braquidáctilo",
    "braquidáctilas": "braquidáctilo",
    "braquidáctilos": "braquidáctilo",
    "braquigrafias": "braquigrafia",
    "braquigráfica": "braquigráfico",
    "braquigráficas": "braquigráfico",
    "braquigráficos": "braquigráfico",
    "braquilogias": "braquilogia",
    "braquilóloga": "braquilólogo",
    "braquilólogas": "braquilólogo",
    "braquilólogos": "braquilólogo",
    "braquimetropias": "braquimetropia",
    "braquimetrópica": "braquimetrópico",
    "braquimetrópicas": "braquimetrópico",
    "braquimetrópicos": "braquimetrópico",
    "braquimétropes": "braquimétrope",
    "braquiossauros": "braquiossauro",
    "braquiotomias": "braquiotomia",
    "braquipneias": "braquipneia",
    "braquissílabos": "braquissílabo",
    "braquistócronas": "braquistócrona",
    "braquiópodes": "braquiópode",
    "braquiúra": "braquiúro",
    "braquiúras": "braquiúro",
    "braquiúros": "braquiúro",
    "braquígrafa": "braquígrafo",
    "braquígrafas": "braquígrafo",
    "braquígrafos": "braquígrafo",
    "braquípodes": "braquípode",
    "braquíptera": "braquíptero",
    "braquípteras": "braquíptero",
    "braquípteros": "braquíptero",
    "brasagens": "brasagem",
    "brasas": "brasa",
    "braseiras": "braseira",
    "braseiros": "braseiro",
    "brasidos": "brasido",
    "brasileira": "brasileiro",
    "brasileiradas": "brasileirada",
    "brasileiras": "brasileiro",
    "brasileirazinha": "brasileiro",
    "brasileirazinhas": "brasileiro",
    "brasileirazita": "brasileiro",
    "brasileirazitas": "brasileiro",
    "brasileiresca": "brasileiresco",
    "brasileirescas": "brasileiresco",
    "brasileirescos": "brasileiresco",
    "brasileirices": "brasileirice",
    "brasileirinha": "brasileiro",
    "brasileirinhas": "brasileiro",
    "brasileirinho": "brasileiro",
    "brasileirinhos": "brasileiro",
    "brasileirismos": "brasileirismo",
    "brasileirita": "brasileiro",
    "brasileiritas": "brasileiro",
    "brasileirito": "brasileiro",
    "brasileiritos": "brasileiro",
    "brasileirizações": "brasileirização",
    "brasileirona": "brasileirão",
    "brasileironas": "brasileirão",
    "brasileiros": "brasileiro",
    "brasileirota": "brasileirote",
    "brasileirotas": "brasileirote",
    "brasileirotes": "brasileirote",
    "brasileirozinho": "brasileiro",
    "brasileirozinhos": "brasileiro",
    "brasileirozito": "brasileiro",
    "brasileirozitos": "brasileiro",
    "brasileirões": "brasileirão",
    "brasilenses": "brasilense",
    "brasiletes": "brasilete",
    "brasiliana": "brasiliano",
    "brasilianas": "brasiliano",
    "brasilianos": "brasiliano",
    "brasilidades": "brasilidade",
    "brasilienses": "brasiliense",
    "brasilinas": "brasilina",
    "brasiliofilias": "brasiliofilia",
    "brasiliofobias": "brasiliofobia",
    "brasiliófila": "brasiliófilo",
    "brasiliófilas": "brasiliófilo",
    "brasiliófilos": "brasiliófilo",
    "brasiliófoba": "brasiliófobo",
    "brasiliófobas": "brasiliófobo",
    "brasiliófobos": "brasiliófobo",
    "brasilíndia": "brasilíndio",
    "brasilíndias": "brasilíndio",
    "brasilíndios": "brasilíndio",
    "brasina": "brasino",
    "brasinas": "brasino",
    "brasinha": "brasa",
    "brasinhas": "brasa",
    "brasinos": "brasino",
    "brasis": "brasil",
    "brasita": "brasa",
    "brasitas": "brasa",
    "brasoa": "brasoar",
    "brasoada": "brasoar",
    "brasoadas": "brasoar",
    "brasoado": "brasoar",
    "brasoados": "brasoar",
    "brasoai": "brasoar",
    "brasoais": "brasoar",
    "brasoam": "brasoar",
    "brasoamo": "brasoar",
    "brasoamos": "brasoar",
    "brasoando": "brasoar",
    "brasoara": "brasoar",
    "brasoaram": "brasoar",
    "brasoaras": "brasoar",
    "brasoarde": "brasoar",
    "brasoardes": "brasoar",
    "brasoare": "brasoar",
    "brasoarei": "brasoar",
    "brasoareis": "brasoar",
    "brasoarem": "brasoar",
    "brasoaremos": "brasoar",
    "brasoares": "brasoar",
    "brasoaria": "brasoar",
    "brasoariam": "brasoar",
    "brasoarias": "brasoar",
    "brasoarmo": "brasoar",
    "brasoarmos": "brasoar",
    "brasoará": "brasoar",
    "brasoarás": "brasoar",
    "brasoarão": "brasoar",
    "brasoaríamos": "brasoar",
    "brasoaríeis": "brasoar",
    "brasoas": "brasoar",
    "brasoasse": "brasoar",
    "brasoassem": "brasoar",
    "brasoasses": "brasoar",
    "brasoaste": "brasoar",
    "brasoastes": "brasoar",
    "brasoava": "brasoar",
    "brasoavam": "brasoar",
    "brasoavas": "brasoar",
    "brasoe": "brasoar",
    "brasoei": "brasoar",
    "brasoeis": "brasoar",
    "brasoem": "brasoar",
    "brasoemo": "brasoar",
    "brasoemos": "brasoar",
    "brasoes": "brasoar",
    "brasona": "brasonar",
    "brasonada": "brasonar",
    "brasonadas": "brasonar",
    "brasonado": "brasonar",
    "brasonados": "brasonar",
    "brasonai": "brasonar",
    "brasonais": "brasonar",
    "brasonam": "brasonar",
    "brasonamo": "brasonar",
    "brasonamos": "brasonar",
    "brasonando": "brasonar",
    "brasonara": "brasonar",
    "brasonaram": "brasonar",
    "brasonaras": "brasonar",
    "brasonarde": "brasonar",
    "brasonardes": "brasonar",
    "brasonare": "brasonar",
    "brasonarei": "brasonar",
    "brasonareis": "brasonar",
    "brasonarem": "brasonar",
    "brasonaremos": "brasonar",
    "brasonares": "brasonar",
    "brasonaria": "brasonar",
    "brasonariam": "brasonar",
    "brasonarias": "brasonar",
    "brasonarmo": "brasonar",
    "brasonarmos": "brasonar",
    "brasonará": "brasonar",
    "brasonarás": "brasonar",
    "brasonarão": "brasonar",
    "brasonaríamos": "brasonar",
    "brasonaríeis": "brasonar",
    "brasonas": "brasonar",
    "brasonasse": "brasonar",
    "brasonassem": "brasonar",
    "brasonasses": "brasonar",
    "brasonaste": "brasonar",
    "brasonastes": "brasonar",
    "brasonava": "brasonar",
    "brasonavam": "brasonar",
    "brasonavas": "brasonar",
    "brasone": "brasonar",
    "brasonei": "brasonar",
    "brasoneis": "brasonar",
    "brasonem": "brasonar",
    "brasonemo": "brasonar",
    "brasonemos": "brasonar",
    "brasones": "brasonar",
    "brasono": "brasonar",
    "brasonou": "brasonar",
    "brasoná": "brasonar",
    "brasonámo": "brasonar",
    "brasonámos": "brasonar",
    "brasonáramo": "brasonar",
    "brasonáramos": "brasonar",
    "brasonárei": "brasonar",
    "brasonáreis": "brasonar",
    "brasonásseis": "brasonar",
    "brasonássemos": "brasonar",
    "brasonávamo": "brasonar",
    "brasonávamos": "brasonar",
    "brasonávei": "brasonar",
    "brasonáveis": "brasonar",
    "brasoo": "brasoar",
    "brasoou": "brasoar",
    "brasoá": "brasoar",
    "brasoámo": "brasoar",
    "brasoámos": "brasoar",
    "brasoáramo": "brasoar",
    "brasoáramos": "brasoar",
    "brasoárei": "brasoar",
    "brasoáreis": "brasoar",
    "brasoásseis": "brasoar",
    "brasoássemos": "brasoar",
    "brasoávamo": "brasoar",
    "brasoávamos": "brasoar",
    "brasoávei": "brasoar",
    "brasoáveis": "brasoar",
    "brassaduras": "brassadura",
    "brassagens": "brassagem",
    "brassicácea": "brassicáceo",
    "brassicáceas": "brassicáceo",
    "brassicáceos": "brassicáceo",
    "brasucas": "brasuca",
    "brasumes": "brasume",
    "brasílica": "brasílico",
    "brasílicas": "brasílico",
    "brasílicos": "brasílico",
    "brasões": "brasão",
    "bratwursts": "bratwurst",
    "braunites": "braunite",
    "brava": "bravo",
    "bravas": "bravo",
    "bravatas": "bravata",
    "bravateada": "bravatear",
    "bravateadas": "bravatear",
    "bravateadeira": "bravateador",
    "bravateadeiras": "bravateador",
    "bravateado": "bravatear",
    "bravateadora": "bravateador",
    "bravateadoras": "bravateador",
    "bravateadores": "bravateador",
    "bravateados": "bravatear",
    "bravateai": "bravatear",
    "bravateais": "bravatear",
    "bravateamo": "bravatear",
    "bravateamos": "bravatear",
    "bravateando": "bravatear",
    "bravateara": "bravatear",
    "bravatearam": "bravatear",
    "bravatearas": "bravatear",
    "bravateardes": "bravatear",
    "bravatearei": "bravatear",
    "bravateareis": "bravatear",
    "bravatearem": "bravatear",
    "bravatearemos": "bravatear",
    "bravateares": "bravatear",
    "bravatearia": "bravatear",
    "bravateariam": "bravatear",
    "bravatearias": "bravatear",
    "bravatearmo": "bravatear",
    "bravatearmos": "bravatear",
    "bravateará": "bravatear",
    "bravatearás": "bravatear",
    "bravatearão": "bravatear",
    "bravatearíamos": "bravatear",
    "bravatearíeis": "bravatear",
    "bravateasse": "bravatear",
    "bravateassem": "bravatear",
    "bravateasses": "bravatear",
    "bravateaste": "bravatear",
    "bravateastes": "bravatear",
    "bravateava": "bravatear",
    "bravateavam": "bravatear",
    "bravateavas": "bravatear",
    "bravateei": "bravatear",
    "bravateeis": "bravatear",
    "bravateemo": "bravatear",
    "bravateemos": "bravatear",
    "bravateia": "bravatear",
    "bravateiam": "bravatear",
    "bravateias": "bravatear",
    "bravateie": "bravatear",
    "bravateiem": "bravatear",
    "bravateies": "bravatear",
    "bravateio": "bravatear",
    "bravateira": "bravateiro",
    "bravateiras": "bravateiro",
    "bravateiros": "bravateiro",
    "bravateou": "bravatear",
    "bravateámo": "bravatear",
    "bravateámos": "bravatear",
    "bravateáramo": "bravatear",
    "bravateáramos": "bravatear",
    "bravateáreis": "bravatear",
    "bravateásseis": "bravatear",
    "bravateássemos": "bravatear",
    "bravateávamo": "bravatear",
    "bravateávamos": "bravatear",
    "bravateáveis": "bravatear",
    "bravatona": "bravatão",
    "bravatonas": "bravatão",
    "bravatões": "bravatão",
    "braveada": "bravear",
    "braveadas": "bravear",
    "braveado": "bravear",
    "braveados": "bravear",
    "braveai": "bravear",
    "braveais": "bravear",
    "braveamo": "bravear",
    "braveamos": "bravear",
    "braveando": "bravear",
    "braveara": "bravear",
    "bravearam": "bravear",
    "bravearas": "bravear",
    "braveardes": "bravear",
    "bravearei": "bravear",
    "braveareis": "bravear",
    "bravearem": "bravear",
    "bravearemos": "bravear",
    "braveares": "bravear",
    "bravearia": "bravear",
    "braveariam": "bravear",
    "bravearias": "bravear",
    "bravearmo": "bravear",
    "bravearmos": "bravear",
    "braveará": "bravear",
    "bravearás": "bravear",
    "bravearão": "bravear",
    "bravearíamos": "bravear",
    "bravearíeis": "bravear",
    "braveasse": "bravear",
    "braveassem": "bravear",
    "braveasses": "bravear",
    "braveaste": "bravear",
    "braveastes": "bravear",
    "braveava": "bravear",
    "braveavam": "bravear",
    "braveavas": "bravear",
    "braveei": "bravear",
    "braveeis": "bravear",
    "braveemo": "bravear",
    "braveemos": "bravear",
    "braveia": "bravear",
    "braveiam": "bravear",
    "braveias": "bravear",
    "braveie": "bravear",
    "braveiem": "bravear",
    "braveies": "bravear",
    "braveio": "bravear",
    "braveja": "bravejar",
    "bravejada": "bravejar",
    "bravejadas": "bravejar",
    "bravejado": "bravejar",
    "bravejados": "bravejar",
    "bravejai": "bravejar",
    "bravejais": "bravejar",
    "bravejam": "bravejar",
    "bravejamo": "bravejar",
    "bravejamos": "bravejar",
    "bravejando": "bravejar",
    "bravejara": "bravejar",
    "bravejaram": "bravejar",
    "bravejaras": "bravejar",
    "bravejardes": "bravejar",
    "bravejarei": "bravejar",
    "bravejareis": "bravejar",
    "bravejarem": "bravejar",
    "bravejaremos": "bravejar",
    "bravejares": "bravejar",
    "bravejaria": "bravejar",
    "bravejariam": "bravejar",
    "bravejarias": "bravejar",
    "bravejarmo": "bravejar",
    "bravejarmos": "bravejar",
    "bravejará": "bravejar",
    "bravejarás": "bravejar",
    "bravejarão": "bravejar",
    "bravejaríamos": "bravejar",
    "bravejaríeis": "bravejar",
    "bravejas": "bravejar",
    "bravejasse": "bravejar",
    "bravejassem": "bravejar",
    "bravejasses": "bravejar",
    "bravejaste": "bravejar",
    "bravejastes": "bravejar",
    "bravejava": "bravejar",
    "bravejavam": "bravejar",
    "bravejavas": "bravejar",
    "braveje": "bravejar",
    "bravejei": "bravejar",
    "bravejeis": "bravejar",
    "bravejem": "bravejar",
    "bravejemo": "bravejar",
    "bravejemos": "bravejar",
    "bravejes": "bravejar",
    "bravejo": "bravejar",
    "bravejou": "bravejar",
    "bravejámo": "bravejar",
    "bravejámos": "bravejar",
    "bravejáramo": "bravejar",
    "bravejáramos": "bravejar",
    "bravejáreis": "bravejar",
    "bravejásseis": "bravejar",
    "bravejássemos": "bravejar",
    "bravejávamo": "bravejar",
    "bravejávamos": "bravejar",
    "bravejáveis": "bravejar",
    "braveou": "bravear",
    "bravezas": "braveza",
    "braveámo": "bravear",
    "braveámos": "bravear",
    "braveáramo": "bravear",
    "braveáramos": "bravear",
    "braveáreis": "bravear",
    "braveásseis": "bravear",
    "braveássemos": "bravear",
    "braveávamo": "bravear",
    "braveávamos": "bravear",
    "braveáveis": "bravear",
    "bravia": "bravio",
    "bravias": "bravio",
    "bravios": "bravio",
    "bravos": "bravo",
    "bravuras": "bravura",
    "bravíssima": "bravo",
    "bravíssimas": "bravo",
    "bravíssimo": "bravo",
    "bravíssimos": "bravo",
    "braçadas": "braçada",
    "braçadeiras": "braçadeira",
    "braçados": "braçado",
    "braçaduras": "braçadura",
    "braçagens": "braçagem",
    "braçais": "braçal",
    "braçarias": "braçaria",
    "braças": "braça",
    "braçoladas": "braçolada",
    "braçolas": "braçola",
    "braços": "braço",
    "braçozinho": "braço",
    "braçozinhos": "braço",
    "braçozito": "braço",
    "braçozitos": "braço",
    "braçuda": "braçudo",
    "braçudas": "braçudo",
    "braçudos": "braçudo",
    "brações": "bração",
    "braúnas": "braúna",
    "breada": "brear",
    "breadas": "brear",
    "breado": "brear",
    "breados": "brear",
    "breai": "brear",
    "breais": "brear",
    "breamo": "brear",
    "breamos": "brear",
    "breando": "brear",
    "breara": "brear",
    "brearam": "brear",
    "brearas": "brear",
    "brearde": "brear",
    "breardes": "brear",
    "breare": "brear",
    "brearei": "brear",
    "breareis": "brear",
    "brearem": "brear",
    "brearemos": "brear",
    "breares": "brear",
    "brearia": "brear",
    "breariam": "brear",
    "brearias": "brear",
    "brearmo": "brear",
    "brearmos": "brear",
    "breará": "brear",
    "brearás": "brear",
    "brearão": "brear",
    "brearíamos": "brear",
    "brearíeis": "brear",
    "breasse": "brear",
    "breassem": "brear",
    "breasses": "brear",
    "breaste": "brear",
    "breastes": "brear",
    "breava": "brear",
    "breavam": "brear",
    "breavas": "brear",
    "breca": "brecar",
    "brecada": "brecar",
    "brecadas": "brecar",
    "brecado": "brecar",
    "brecados": "brecar",
    "brecai": "brecar",
    "brecais": "brecar",
    "brecam": "brecar",
    "brecamo": "brecar",
    "brecamos": "brecar",
    "brecando": "brecar",
    "brecara": "brecar",
    "brecaram": "brecar",
    "brecaras": "brecar",
    "brecarde": "brecar",
    "brecardes": "brecar",
    "brecare": "brecar",
    "brecarei": "brecar",
    "brecareis": "brecar",
    "brecarem": "brecar",
    "brecaremos": "brecar",
    "brecares": "brecar",
    "brecaria": "brecar",
    "brecariam": "brecar",
    "brecarias": "brecar",
    "brecarmo": "brecar",
    "brecarmos": "brecar",
    "brecará": "brecar",
    "brecarás": "brecar",
    "brecarão": "brecar",
    "brecaríamos": "brecar",
    "brecaríeis": "brecar",
    "brecas": "brecar",
    "brecasse": "brecar",
    "brecassem": "brecar",
    "brecasses": "brecar",
    "brecaste": "brecar",
    "brecastes": "brecar",
    "brecava": "brecar",
    "brecavam": "brecar",
    "brecavas": "brecar",
    "brechas": "brecha",
    "breco": "brecar",
    "brecou": "brecar",
    "brecá": "brecar",
    "brecámo": "brecar",
    "brecámos": "brecar",
    "brecáramo": "brecar",
    "brecáramos": "brecar",
    "brecárei": "brecar",
    "brecáreis": "brecar",
    "brecásseis": "brecar",
    "brecássemos": "brecar",
    "brecávamo": "brecar",
    "brecávamos": "brecar",
    "brecávei": "brecar",
    "brecáveis": "brecar",
    "breda": "bredo",
    "bredas": "bredo",
    "bredos": "bredo",
    "breei": "brear",
    "breeis": "brear",
    "breemo": "brear",
    "breemos": "brear",
    "bregais": "bregal",
    "bregantinos": "bregantino",
    "breia": "brear",
    "breiam": "brear",
    "breias": "brear",
    "breie": "brear",
    "breiem": "brear",
    "breies": "brear",
    "breio": "brear",
    "brejais": "brejal",
    "brejeira": "brejeiro",
    "brejeirada": "brejeirar",
    "brejeiradas": "brejeirar",
    "brejeirado": "brejeirar",
    "brejeirados": "brejeirar",
    "brejeirai": "brejeirar",
    "brejeirais": "brejeirar",
    "brejeiram": "brejeirar",
    "brejeiramo": "brejeirar",
    "brejeiramos": "brejeirar",
    "brejeirando": "brejeirar",
    "brejeirara": "brejeirar",
    "brejeiraram": "brejeirar",
    "brejeiraras": "brejeirar",
    "brejeirardes": "brejeirar",
    "brejeirarei": "brejeirar",
    "brejeirareis": "brejeirar",
    "brejeirarem": "brejeirar",
    "brejeiraremos": "brejeirar",
    "brejeirares": "brejeirar",
    "brejeiraria": "brejeirar",
    "brejeirariam": "brejeirar",
    "brejeirarias": "brejeirar",
    "brejeirarmo": "brejeirar",
    "brejeirarmos": "brejeirar",
    "brejeirará": "brejeirar",
    "brejeirarás": "brejeirar",
    "brejeirarão": "brejeirar",
    "brejeiraríamos": "brejeirar",
    "brejeiraríeis": "brejeirar",
    "brejeiras": "brejeiro",
    "brejeirasse": "brejeirar",
    "brejeirassem": "brejeirar",
    "brejeirasses": "brejeirar",
    "brejeiraste": "brejeirar",
    "brejeirastes": "brejeirar",
    "brejeirava": "brejeirar",
    "brejeiravam": "brejeirar",
    "brejeiravas": "brejeirar",
    "brejeire": "brejeirar",
    "brejeirei": "brejeirar",
    "brejeireis": "brejeirar",
    "brejeirem": "brejeirar",
    "brejeiremo": "brejeirar",
    "brejeiremos": "brejeirar",
    "brejeires": "brejeirar",
    "brejeirices": "brejeirice",
    "brejeiro": "brejeirar",
    "brejeiros": "brejeiro",
    "brejeirotes": "brejeirote",
    "brejeirou": "brejeirar",
    "brejeirámo": "brejeirar",
    "brejeirámos": "brejeirar",
    "brejeiráramo": "brejeirar",
    "brejeiráramos": "brejeirar",
    "brejeiráreis": "brejeirar",
    "brejeirásseis": "brejeirar",
    "brejeirássemos": "brejeirar",
    "brejeirávamo": "brejeirar",
    "brejeirávamos": "brejeirar",
    "brejeiráveis": "brejeirar",
    "brejos": "brejo",
    "brejosa": "brejoso",
    "brejosas": "brejoso",
    "brejosos": "brejoso",
    "bremas": "brema",
    "brenhas": "brenha",
    "brenhosa": "brenhoso",
    "brenhosas": "brenhoso",
    "brenhosos": "brenhoso",
    "breou": "brear",
    "breque": "brecar",
    "brequefestes": "brequefeste",
    "brequei": "brecar",
    "brequeis": "brecar",
    "brequem": "brecar",
    "brequemo": "brecar",
    "brequemos": "brecar",
    "breques": "breque",
    "bretanhas": "bretanha",
    "bretanjis": "bretanjil",
    "bretes": "brete",
    "bretoa": "bretão",
    "bretoas": "bretão",
    "bretã": "bretão",
    "bretãs": "bretão",
    "bretões": "bretão",
    "breus": "breu",
    "breves": "breve",
    "breveta": "brevetar",
    "brevetada": "brevetar",
    "brevetadas": "brevetar",
    "brevetado": "brevetar",
    "brevetados": "brevetar",
    "brevetai": "brevetar",
    "brevetais": "brevetar",
    "brevetam": "brevetar",
    "brevetamo": "brevetar",
    "brevetamos": "brevetar",
    "brevetando": "brevetar",
    "brevetara": "brevetar",
    "brevetaram": "brevetar",
    "brevetaras": "brevetar",
    "brevetarde": "brevetar",
    "brevetardes": "brevetar",
    "brevetare": "brevetar",
    "brevetarei": "brevetar",
    "brevetareis": "brevetar",
    "brevetarem": "brevetar",
    "brevetaremos": "brevetar",
    "brevetares": "brevetar",
    "brevetaria": "brevetar",
    "brevetariam": "brevetar",
    "brevetarias": "brevetar",
    "brevetarmo": "brevetar",
    "brevetarmos": "brevetar",
    "brevetará": "brevetar",
    "brevetarás": "brevetar",
    "brevetarão": "brevetar",
    "brevetaríamos": "brevetar",
    "brevetaríeis": "brevetar",
    "brevetas": "brevetar",
    "brevetasse": "brevetar",
    "brevetassem": "brevetar",
    "brevetasses": "brevetar",
    "brevetaste": "brevetar",
    "brevetastes": "brevetar",
    "brevetava": "brevetar",
    "brevetavam": "brevetar",
    "brevetavas": "brevetar",
    "brevete": "brevetar",
    "brevetei": "brevetar",
    "breveteis": "brevetar",
    "brevetem": "brevetar",
    "brevetemo": "brevetar",
    "brevetemos": "brevetar",
    "brevetes": "brevete",
    "breveto": "brevetar",
    "brevetou": "brevetar",
    "brevetá": "brevetar",
    "brevetámo": "brevetar",
    "brevetámos": "brevetar",
    "brevetáramo": "brevetar",
    "brevetáramos": "brevetar",
    "brevetárei": "brevetar",
    "brevetáreis": "brevetar",
    "brevetásseis": "brevetar",
    "brevetássemos": "brevetar",
    "brevetávamo": "brevetar",
    "brevetávamos": "brevetar",
    "brevetávei": "brevetar",
    "brevetáveis": "brevetar",
    "brevicaudes": "brevicaude",
    "brevicórnea": "brevicórneo",
    "brevicórneas": "brevicórneo",
    "brevicórneos": "brevicórneo",
    "brevidades": "brevidade",
    "brevidigitada": "brevidigitado",
    "brevidigitadas": "brevidigitado",
    "brevidigitados": "brevidigitado",
    "brevipenes": "brevipene",
    "brevirrostra": "brevirrostro",
    "brevirrostrada": "brevirrostrado",
    "brevirrostradas": "brevirrostrado",
    "brevirrostrados": "brevirrostrado",
    "brevirrostras": "brevirrostro",
    "brevirrostros": "brevirrostro",
    "brevistas": "brevista",
    "breviários": "breviário",
    "brevês": "brevê",
    "brevíssima": "breve",
    "brevíssimas": "breve",
    "brevíssimo": "breve",
    "brevíssimos": "breve",
    "breá": "brear",
    "breámo": "brear",
    "breámos": "brear",
    "breáramo": "brear",
    "breáramos": "brear",
    "breárei": "brear",
    "breáreis": "brear",
    "breásseis": "brear",
    "breássemos": "brear",
    "breávamo": "brear",
    "breávamos": "brear",
    "breávei": "brear",
    "breáveis": "brear",
    "briaduras": "briadura",
    "briagens": "briagem",
    "briais": "brial",
    "bricabraques": "bricabraque",
    "bricabrequistas": "bricabrequista",
    "bricas": "brica",
    "briches": "briche",
    "brichotes": "brichote",
    "bricolagens": "bricolagem",
    "bricolages": "bricolage",
    "bricomanias": "bricomania",
    "bricos": "brico",
    "bricómana": "bricómano",
    "bricómanas": "bricómano",
    "bricómanos": "bricómano",
    "brida": "bridar",
    "bridada": "bridar",
    "bridadas": "bridar",
    "bridado": "bridar",
    "bridados": "bridar",
    "bridai": "bridar",
    "bridais": "bridar",
    "bridam": "bridar",
    "bridamo": "bridar",
    "bridamos": "bridar",
    "bridando": "bridar",
    "bridara": "bridar",
    "bridaram": "bridar",
    "bridaras": "bridar",
    "bridarde": "bridar",
    "bridardes": "bridar",
    "bridare": "bridar",
    "bridarei": "bridar",
    "bridareis": "bridar",
    "bridarem": "bridar",
    "bridaremos": "bridar",
    "bridares": "bridar",
    "bridaria": "bridar",
    "bridariam": "bridar",
    "bridarias": "bridar",
    "bridarmo": "bridar",
    "bridarmos": "bridar",
    "bridará": "bridar",
    "bridarás": "bridar",
    "bridarão": "bridar",
    "bridaríamos": "bridar",
    "bridaríeis": "bridar",
    "bridas": "bridar",
    "bridasse": "bridar",
    "bridassem": "bridar",
    "bridasses": "bridar",
    "bridaste": "bridar",
    "bridastes": "bridar",
    "bridava": "bridar",
    "bridavam": "bridar",
    "bridavas": "bridar",
    "bride": "bridar",
    "bridei": "bridar",
    "brideis": "bridar",
    "bridem": "bridar",
    "bridemo": "bridar",
    "bridemos": "bridar",
    "brides": "bridar",
    "bridges": "bridge",
    "bridgistas": "bridgista",
    "brido": "bridar",
    "bridou": "bridar",
    "bridá": "bridar",
    "bridámo": "bridar",
    "bridámos": "bridar",
    "bridáramo": "bridar",
    "bridáramos": "bridar",
    "bridárei": "bridar",
    "bridáreis": "bridar",
    "bridásseis": "bridar",
    "bridássemos": "bridar",
    "bridávamo": "bridar",
    "bridávamos": "bridar",
    "bridávei": "bridar",
    "bridáveis": "bridar",
    "bridões": "bridão",
    "briga": "brigar",
    "brigada": "brigar",
    "brigadas": "brigar",
    "brigadeira": "brigador",
    "brigadeiras": "brigador",
    "brigadeiros": "brigadeiro",
    "brigadistas": "brigadista",
    "brigado": "brigar",
    "brigadora": "brigador",
    "brigadoras": "brigador",
    "brigadores": "brigador",
    "brigados": "brigar",
    "brigai": "brigar",
    "brigais": "brigar",
    "brigalhadas": "brigalhada",
    "brigam": "brigar",
    "brigamo": "brigar",
    "brigamos": "brigar",
    "brigando": "brigar",
    "brigantes": "brigante",
    "brigantina": "brigantino",
    "brigantinas": "brigantino",
    "brigantinos": "brigantino",
    "brigara": "brigar",
    "brigaram": "brigar",
    "brigaras": "brigar",
    "brigardes": "brigar",
    "brigarei": "brigar",
    "brigareis": "brigar",
    "brigarem": "brigar",
    "brigaremos": "brigar",
    "brigares": "brigar",
    "brigaria": "brigar",
    "brigariam": "brigar",
    "brigarias": "brigar",
    "brigarmo": "brigar",
    "brigarmos": "brigar",
    "brigará": "brigar",
    "brigarás": "brigar",
    "brigarão": "brigar",
    "brigaríamos": "brigar",
    "brigaríeis": "brigar",
    "brigas": "brigar",
    "brigasse": "brigar",
    "brigassem": "brigar",
    "brigasses": "brigar",
    "brigaste": "brigar",
    "brigastes": "brigar",
    "brigava": "brigar",
    "brigavam": "brigar",
    "brigavas": "brigar",
    "brigo": "brigar",
    "brigona": "brigão",
    "brigonas": "brigão",
    "brigosa": "brigoso",
    "brigosas": "brigoso",
    "brigosos": "brigoso",
    "brigou": "brigar",
    "brigue": "brigar",
    "briguei": "brigar",
    "brigueis": "brigar",
    "briguem": "brigar",
    "briguemo": "brigar",
    "briguemos": "brigar",
    "briguenta": "briguento",
    "briguentas": "briguento",
    "briguentos": "briguento",
    "brigues": "brigue",
    "brigámo": "brigar",
    "brigámos": "brigar",
    "brigáramo": "brigar",
    "brigáramos": "brigar",
    "brigáreis": "brigar",
    "brigásseis": "brigar",
    "brigássemos": "brigar",
    "brigávamo": "brigar",
    "brigávamos": "brigar",
    "brigáveis": "brigar",
    "brigões": "brigão",
    "brilha": "brilhar",
    "brilhada": "brilhar",
    "brilhadas": "brilhar",
    "brilhado": "brilhar",
    "brilhados": "brilhar",
    "brilhai": "brilhar",
    "brilhais": "brilhar",
    "brilham": "brilhar",
    "brilhamo": "brilhar",
    "brilhamos": "brilhar",
    "brilhando": "brilhar",
    "brilhantes": "brilhante",
    "brilhantinas": "brilhantina",
    "brilhantismos": "brilhantismo",
    "brilhantíssima": "brilhante",
    "brilhantíssimas": "brilhante",
    "brilhantíssimo": "brilhante",
    "brilhantíssimos": "brilhante",
    "brilhara": "brilhar",
    "brilharam": "brilhar",
    "brilharas": "brilhar",
    "brilhardes": "brilhar",
    "brilharei": "brilhar",
    "brilhareis": "brilhar",
    "brilharem": "brilhar",
    "brilharemos": "brilhar",
    "brilhares": "brilhar",
    "brilharetes": "brilharete",
    "brilharetos": "brilhareto",
    "brilharia": "brilhar",
    "brilhariam": "brilhar",
    "brilharias": "brilhar",
    "brilharmo": "brilhar",
    "brilharmos": "brilhar",
    "brilhará": "brilhar",
    "brilharás": "brilhar",
    "brilharão": "brilhar",
    "brilharíamos": "brilhar",
    "brilharíeis": "brilhar",
    "brilhas": "brilhar",
    "brilhasse": "brilhar",
    "brilhassem": "brilhar",
    "brilhasses": "brilhar",
    "brilhaste": "brilhar",
    "brilhastes": "brilhar",
    "brilhava": "brilhar",
    "brilhavam": "brilhar",
    "brilhavas": "brilhar",
    "brilhe": "brilhar",
    "brilhei": "brilhar",
    "brilheis": "brilhar",
    "brilhem": "brilhar",
    "brilhemo": "brilhar",
    "brilhemos": "brilhar",
    "brilhes": "brilhar",
    "brilhinho": "brilho",
    "brilhinhos": "brilho",
    "brilhito": "brilho",
    "brilhitos": "brilho",
    "brilho": "brilhar",
    "brilhos": "brilho",
    "brilhou": "brilhar",
    "brilhozinho": "brilho",
    "brilhozinhos": "brilho",
    "brilhozito": "brilho",
    "brilhozitos": "brilho",
    "brilhámo": "brilhar",
    "brilhámos": "brilhar",
    "brilháramo": "brilhar",
    "brilháramos": "brilhar",
    "brilháreis": "brilhar",
    "brilhásseis": "brilhar",
    "brilhássemos": "brilhar",
    "brilhávamo": "brilhar",
    "brilhávamos": "brilhar",
    "brilháveis": "brilhar",
    "brilhâncias": "brilhância",
    "brinca": "brincar",
    "brincada": "brincar",
    "brincadas": "brincar",
    "brincadeiras": "brincadeira",
    "brincadeirinha": "brincadeira",
    "brincadeirinhas": "brincadeira",
    "brincadeirita": "brincadeira",
    "brincadeiritas": "brincadeira",
    "brincado": "brincar",
    "brincadora": "brincador",
    "brincadoras": "brincador",
    "brincadores": "brincador",
    "brincados": "brincar",
    "brincais": "brincar",
    "brincalhetas": "brincalheta",
    "brincalhona": "brincalhão",
    "brincalhonas": "brincalhão",
    "brincalhões": "brincalhão",
    "brincam": "brincar",
    "brincamo": "brincar",
    "brincamos": "brincar",
    "brincando": "brincar",
    "brincara": "brincar",
    "brincaram": "brincar",
    "brincaras": "brincar",
    "brincardes": "brincar",
    "brincarei": "brincar",
    "brincareis": "brincar",
    "brincarem": "brincar",
    "brincaremos": "brincar",
    "brincares": "brincar",
    "brincaria": "brincar",
    "brincariam": "brincar",
    "brincarias": "brincar",
    "brincarmo": "brincar",
    "brincarmos": "brincar",
    "brincará": "brincar",
    "brincarás": "brincar",
    "brincarão": "brincar",
    "brincaríamos": "brincar",
    "brincaríeis": "brincar",
    "brincas": "brincar",
    "brincasse": "brincar",
    "brincassem": "brincar",
    "brincasses": "brincar",
    "brincaste": "brincar",
    "brincastes": "brincar",
    "brincava": "brincar",
    "brincavam": "brincar",
    "brincavas": "brincar",
    "brinco": "brincar",
    "brincona": "brincão",
    "brinconas": "brincão",
    "brincos": "brinco",
    "brincou": "brincar",
    "brincámo": "brincar",
    "brincámos": "brincar",
    "brincáramo": "brincar",
    "brincáramos": "brincar",
    "brincáreis": "brincar",
    "brincásseis": "brincar",
    "brincássemos": "brincar",
    "brincávamo": "brincar",
    "brincávamos": "brincar",
    "brincáveis": "brincar",
    "brincões": "brincão",
    "brinda": "brindar",
    "brindada": "brindar",
    "brindadas": "brindar",
    "brindado": "brindar",
    "brindados": "brindar",
    "brindai": "brindar",
    "brindais": "brindar",
    "brindam": "brindar",
    "brindamo": "brindar",
    "brindamos": "brindar",
    "brindando": "brindar",
    "brindara": "brindar",
    "brindaram": "brindar",
    "brindaras": "brindar",
    "brindarde": "brindar",
    "brindardes": "brindar",
    "brindare": "brindar",
    "brindarei": "brindar",
    "brindareis": "brindar",
    "brindarem": "brindar",
    "brindaremos": "brindar",
    "brindares": "brindar",
    "brindaria": "brindar",
    "brindariam": "brindar",
    "brindarias": "brindar",
    "brindarmo": "brindar",
    "brindarmos": "brindar",
    "brindará": "brindar",
    "brindarás": "brindar",
    "brindarão": "brindar",
    "brindaríamos": "brindar",
    "brindaríeis": "brindar",
    "brindas": "brindar",
    "brindasse": "brindar",
    "brindassem": "brindar",
    "brindasses": "brindar",
    "brindaste": "brindar",
    "brindastes": "brindar",
    "brindava": "brindar",
    "brindavam": "brindar",
    "brindavas": "brindar",
    "brinde": "brindar",
    "brindei": "brindar",
    "brindeis": "brindar",
    "brindem": "brindar",
    "brindemo": "brindar",
    "brindemos": "brindar",
    "brindes": "brinde",
    "brindezinho": "brinde",
    "brindezinhos": "brinde",
    "brindezito": "brinde",
    "brindezitos": "brinde",
    "brindo": "brindar",
    "brindou": "brindar",
    "brindá": "brindar",
    "brindámo": "brindar",
    "brindámos": "brindar",
    "brindáramo": "brindar",
    "brindáramos": "brindar",
    "brindárei": "brindar",
    "brindáreis": "brindar",
    "brindásseis": "brindar",
    "brindássemos": "brindar",
    "brindávamo": "brindar",
    "brindávamos": "brindar",
    "brindávei": "brindar",
    "brindáveis": "brindar",
    "brindões": "brindão",
    "brinque": "brincar",
    "brinquedos": "brinquedo",
    "brinquei": "brincar",
    "brinqueis": "brincar",
    "brinquem": "brincar",
    "brinquemos": "brincar",
    "brinques": "brincar",
    "brinquetes": "brinquete",
    "brinquetos": "brinqueto",
    "brinquinharias": "brinquinharia",
    "brinquinho": "brinco",
    "brinquinhos": "brinco",
    "brinquito": "brinco",
    "brinquitos": "brinco",
    "brins": "brim",
    "brinças": "brinça",
    "brioches": "brioche",
    "briologias": "briologia",
    "briologistas": "briologista",
    "brios": "brio",
    "briosa": "brioso",
    "briosas": "brioso",
    "briosos": "brioso",
    "briozoária": "briozoário",
    "briozoárias": "briozoário",
    "briozoários": "briozoário",
    "briques": "brique",
    "briqueta": "briquetar",
    "briquetada": "briquetar",
    "briquetadas": "briquetar",
    "briquetado": "briquetar",
    "briquetados": "briquetar",
    "briquetagens": "briquetagem",
    "briquetai": "briquetar",
    "briquetais": "briquetar",
    "briquetam": "briquetar",
    "briquetamo": "briquetar",
    "briquetamos": "briquetar",
    "briquetando": "briquetar",
    "briquetara": "briquetar",
    "briquetaram": "briquetar",
    "briquetaras": "briquetar",
    "briquetarde": "briquetar",
    "briquetardes": "briquetar",
    "briquetare": "briquetar",
    "briquetarei": "briquetar",
    "briquetareis": "briquetar",
    "briquetarem": "briquetar",
    "briquetaremos": "briquetar",
    "briquetares": "briquetar",
    "briquetaria": "briquetar",
    "briquetariam": "briquetar",
    "briquetarias": "briquetar",
    "briquetarmo": "briquetar",
    "briquetarmos": "briquetar",
    "briquetará": "briquetar",
    "briquetarás": "briquetar",
    "briquetarão": "briquetar",
    "briquetaríamos": "briquetar",
    "briquetaríeis": "briquetar",
    "briquetas": "briquetar",
    "briquetasse": "briquetar",
    "briquetassem": "briquetar",
    "briquetasses": "briquetar",
    "briquetaste": "briquetar",
    "briquetastes": "briquetar",
    "briquetava": "briquetar",
    "briquetavam": "briquetar",
    "briquetavas": "briquetar",
    "briquete": "briquetar",
    "briquetei": "briquetar",
    "briqueteis": "briquetar",
    "briquetem": "briquetar",
    "briquetemo": "briquetar",
    "briquetemos": "briquetar",
    "briquetes": "briquete",
    "briqueto": "briquetar",
    "briquetou": "briquetar",
    "briquetá": "briquetar",
    "briquetámo": "briquetar",
    "briquetámos": "briquetar",
    "briquetáramo": "briquetar",
    "briquetáramos": "briquetar",
    "briquetárei": "briquetar",
    "briquetáreis": "briquetar",
    "briquetásseis": "briquetar",
    "briquetássemos": "briquetar",
    "briquetávamo": "briquetar",
    "briquetávamos": "briquetar",
    "briquetávei": "briquetar",
    "briquetáveis": "briquetar",
    "briquita": "briquitar",
    "briquitada": "briquitar",
    "briquitadas": "briquitar",
    "briquitado": "briquitar",
    "briquitados": "briquitar",
    "briquitai": "briquitar",
    "briquitais": "briquitar",
    "briquitam": "briquitar",
    "briquitamo": "briquitar",
    "briquitamos": "briquitar",
    "briquitando": "briquitar",
    "briquitara": "briquitar",
    "briquitaram": "briquitar",
    "briquitaras": "briquitar",
    "briquitarde": "briquitar",
    "briquitardes": "briquitar",
    "briquitare": "briquitar",
    "briquitarei": "briquitar",
    "briquitareis": "briquitar",
    "briquitarem": "briquitar",
    "briquitaremos": "briquitar",
    "briquitares": "briquitar",
    "briquitaria": "briquitar",
    "briquitariam": "briquitar",
    "briquitarias": "briquitar",
    "briquitarmo": "briquitar",
    "briquitarmos": "briquitar",
    "briquitará": "briquitar",
    "briquitarás": "briquitar",
    "briquitarão": "briquitar",
    "briquitaríamos": "briquitar",
    "briquitaríeis": "briquitar",
    "briquitas": "briquitar",
    "briquitasse": "briquitar",
    "briquitassem": "briquitar",
    "briquitasses": "briquitar",
    "briquitaste": "briquitar",
    "briquitastes": "briquitar",
    "briquitava": "briquitar",
    "briquitavam": "briquitar",
    "briquitavas": "briquitar",
    "briquite": "briquitar",
    "briquitei": "briquitar",
    "briquiteis": "briquitar",
    "briquitem": "briquitar",
    "briquitemo": "briquitar",
    "briquitemos": "briquitar",
    "briquites": "briquitar",
    "briquito": "briquitar",
    "briquitou": "briquitar",
    "briquitá": "briquitar",
    "briquitámo": "briquitar",
    "briquitámos": "briquitar",
    "briquitáramo": "briquitar",
    "briquitáramos": "briquitar",
    "briquitárei": "briquitar",
    "briquitáreis": "briquitar",
    "briquitásseis": "briquitar",
    "briquitássemos": "briquitar",
    "briquitávamo": "briquitar",
    "briquitávamos": "briquitar",
    "briquitávei": "briquitar",
    "briquitáveis": "briquitar",
    "brisas": "brisa",
    "brisazinha": "brisa",
    "brisazinhas": "brisa",
    "brisazita": "brisa",
    "brisazitas": "brisa",
    "brisâncias": "brisância",
    "brita": "britar",
    "britada": "britar",
    "britadas": "britar",
    "britadeira": "britador",
    "britadeiras": "britador",
    "britado": "britar",
    "britadora": "britador",
    "britadoras": "britador",
    "britadores": "britador",
    "britados": "britar",
    "britagens": "britagem",
    "britai": "britar",
    "britais": "britar",
    "britam": "britar",
    "britamentos": "britamento",
    "britamo": "britar",
    "britamos": "britar",
    "britando": "britar",
    "britangos": "britango",
    "britanismos": "britanismo",
    "britara": "britar",
    "britaram": "britar",
    "britaras": "britar",
    "britarde": "britar",
    "britardes": "britar",
    "britare": "britar",
    "britarei": "britar",
    "britareis": "britar",
    "britarem": "britar",
    "britaremos": "britar",
    "britares": "britar",
    "britaria": "britar",
    "britariam": "britar",
    "britarias": "britar",
    "britarmo": "britar",
    "britarmos": "britar",
    "britará": "britar",
    "britarás": "britar",
    "britarão": "britar",
    "britaríamos": "britar",
    "britaríeis": "britar",
    "britas": "britar",
    "britasse": "britar",
    "britassem": "britar",
    "britasses": "britar",
    "britaste": "britar",
    "britastes": "britar",
    "britava": "britar",
    "britavam": "britar",
    "britavas": "britar",
    "brite": "britar",
    "britei": "britar",
    "briteis": "britar",
    "britem": "britar",
    "britemo": "britar",
    "britemos": "britar",
    "brites": "britar",
    "brito": "britar",
    "britou": "britar",
    "britá": "britar",
    "britámo": "britar",
    "britámos": "britar",
    "britáramo": "britar",
    "britáramos": "britar",
    "britárei": "britar",
    "britáreis": "britar",
    "britásseis": "britar",
    "britássemos": "britar",
    "britávamo": "britar",
    "britávamos": "britar",
    "britávei": "britar",
    "britáveis": "britar",
    "britânica": "britânico",
    "britânicas": "britânico",
    "britânicos": "britânico",
    "brives": "brive",
    "brizumancias": "brizumancia",
    "brizumantes": "brizumante",
    "brizumântica": "brizumântico",
    "brizumânticas": "brizumântico",
    "brizumânticos": "brizumântico",
    "briófitas": "briófita",
    "briófitos": "briófito",
    "brióis": "briol",
    "brióloga": "briólogo",
    "briólogas": "briólogo",
    "briólogos": "briólogo",
    "broas": "broa",
    "broca": "brocar",
    "brocada": "brocar",
    "brocadas": "brocar",
    "brocado": "brocar",
    "brocados": "brocar",
    "brocagens": "brocagem",
    "brocai": "brocar",
    "brocais": "brocar",
    "brocam": "brocar",
    "brocamentos": "brocamento",
    "brocamo": "brocar",
    "brocamos": "brocar",
    "brocando": "brocar",
    "brocara": "brocar",
    "brocaram": "brocar",
    "brocaras": "brocar",
    "brocarde": "brocar",
    "brocardes": "brocar",
    "brocardos": "brocardo",
    "brocare": "brocar",
    "brocarei": "brocar",
    "brocareis": "brocar",
    "brocarem": "brocar",
    "brocaremos": "brocar",
    "brocares": "brocar",
    "brocaria": "brocar",
    "brocariam": "brocar",
    "brocarias": "brocar",
    "brocarmo": "brocar",
    "brocarmos": "brocar",
    "brocará": "brocar",
    "brocarás": "brocar",
    "brocarão": "brocar",
    "brocaríamos": "brocar",
    "brocaríeis": "brocar",
    "brocas": "brocar",
    "brocasse": "brocar",
    "brocassem": "brocar",
    "brocasses": "brocar",
    "brocaste": "brocar",
    "brocastes": "brocar",
    "brocatelos": "brocatelo",
    "brocatéis": "brocatel",
    "brocava": "brocar",
    "brocavam": "brocar",
    "brocavas": "brocar",
    "brocha": "brochar",
    "brochada": "brochar",
    "brochadas": "brochar",
    "brochadeira": "brochador",
    "brochadeiras": "brochador",
    "brochadelas": "brochadela",
    "brochado": "brochar",
    "brochadora": "brochador",
    "brochadoras": "brochador",
    "brochadores": "brochador",
    "brochados": "brochar",
    "brochagens": "brochagem",
    "brochai": "brochar",
    "brochais": "brochar",
    "brocham": "brochar",
    "brochamo": "brochar",
    "brochamos": "brochar",
    "brochando": "brochar",
    "brochara": "brochar",
    "brocharam": "brochar",
    "brocharas": "brochar",
    "brocharde": "brochar",
    "brochardes": "brochar",
    "brochare": "brochar",
    "brocharei": "brochar",
    "brochareis": "brochar",
    "brocharem": "brochar",
    "brocharemos": "brochar",
    "brochares": "brochar",
    "brocharia": "brochar",
    "brochariam": "brochar",
    "brocharias": "brochar",
    "brocharmo": "brochar",
    "brocharmos": "brochar",
    "brochará": "brochar",
    "brocharás": "brochar",
    "brocharão": "brochar",
    "brocharíamos": "brochar",
    "brocharíeis": "brochar",
    "brochas": "brochar",
    "brochasse": "brochar",
    "brochassem": "brochar",
    "brochasses": "brochar",
    "brochaste": "brochar",
    "brochastes": "brochar",
    "brochava": "brochar",
    "brochavam": "brochar",
    "brochavas": "brochar",
    "broche": "brochar",
    "brochei": "brochar",
    "brocheis": "brochar",
    "brochem": "brochar",
    "brochemo": "brochar",
    "brochemos": "brochar",
    "broches": "broche",
    "brochetes": "brochete",
    "brocho": "brochar",
    "brochou": "brochar",
    "brochuras": "brochura",
    "brochá": "brochar",
    "brochámo": "brochar",
    "brochámos": "brochar",
    "brocháramo": "brochar",
    "brocháramos": "brochar",
    "brochárei": "brochar",
    "brocháreis": "brochar",
    "brochásseis": "brochar",
    "brochássemos": "brochar",
    "brochávamo": "brochar",
    "brochávamos": "brochar",
    "brochávei": "brochar",
    "brocháveis": "brochar",
    "broco": "brocar",
    "brocofonias": "brocofonia",
    "brocou": "brocar",
    "brocá": "brocar",
    "brocámo": "brocar",
    "brocámos": "brocar",
    "brocáramo": "brocar",
    "brocáramos": "brocar",
    "brocárei": "brocar",
    "brocáreis": "brocar",
    "brocásseis": "brocar",
    "brocássemos": "brocar",
    "brocávamo": "brocar",
    "brocávamos": "brocar",
    "brocávei": "brocar",
    "brocáveis": "brocável",
    "brodistas": "brodista",
    "broeira": "broeiro",
    "broeiras": "broeiro",
    "broeiros": "broeiro",
    "broma": "bromar",
    "bromada": "bromar",
    "bromadas": "bromar",
    "bromado": "bromar",
    "bromados": "bromar",
    "bromai": "bromar",
    "bromais": "bromar",
    "bromam": "bromar",
    "bromamo": "bromar",
    "bromamos": "bromar",
    "bromando": "bromar",
    "bromara": "bromar",
    "bromaram": "bromar",
    "bromaras": "bromar",
    "bromarde": "bromar",
    "bromardes": "bromar",
    "bromare": "bromar",
    "bromarei": "bromar",
    "bromareis": "bromar",
    "bromarem": "bromar",
    "bromaremos": "bromar",
    "bromares": "bromar",
    "bromaria": "bromar",
    "bromariam": "bromar",
    "bromarias": "bromar",
    "bromarmo": "bromar",
    "bromarmos": "bromar",
    "bromará": "bromar",
    "bromarás": "bromar",
    "bromarão": "bromar",
    "bromaríamos": "bromar",
    "bromaríeis": "bromar",
    "bromas": "bromar",
    "bromasse": "bromar",
    "bromassem": "bromar",
    "bromasses": "bromar",
    "bromaste": "bromar",
    "bromastes": "bromar",
    "bromatologias": "bromatologia",
    "bromatometrias": "bromatometria",
    "bromatométrica": "bromatométrico",
    "bromatométricas": "bromatométrico",
    "bromatométricos": "bromatométrico",
    "bromatos": "bromato",
    "bromatóloga": "bromatólogo",
    "bromatólogas": "bromatólogo",
    "bromatólogos": "bromatólogo",
    "bromatómetros": "bromatómetro",
    "bromava": "bromar",
    "bromavam": "bromar",
    "bromavas": "bromar",
    "brome": "bromar",
    "bromei": "bromar",
    "bromeis": "bromar",
    "bromeliácea": "bromeliáceo",
    "bromeliáceas": "bromeliáceo",
    "bromeliáceos": "bromeliáceo",
    "bromem": "bromar",
    "bromemo": "bromar",
    "bromemos": "bromar",
    "bromes": "bromar",
    "brometos": "brometo",
    "bromidroses": "bromidrose",
    "bromismos": "bromismo",
    "bromo": "bromar",
    "bromofórmios": "bromofórmio",
    "bromos": "bromo",
    "bromou": "bromar",
    "bromá": "bromar",
    "bromámo": "bromar",
    "bromámos": "bromar",
    "bromáramo": "bromar",
    "bromáramos": "bromar",
    "bromárei": "bromar",
    "bromáreis": "bromar",
    "bromásseis": "bromar",
    "bromássemos": "bromar",
    "bromávamo": "bromar",
    "bromávamos": "bromar",
    "bromávei": "bromar",
    "bromáveis": "bromar",
    "bromídias": "bromídia",
    "bromídrica": "bromídrico",
    "bromídricas": "bromídrico",
    "bromídricos": "bromídrico",
    "bronca": "bronco",
    "broncas": "bronco",
    "broncocorragias": "broncocorragia",
    "broncocoscópica": "broncocoscópico",
    "broncocoscópicas": "broncocoscópico",
    "broncocoscópicos": "broncocoscópico",
    "broncocoscópios": "broncocoscópio",
    "broncocéis": "broncocel",
    "broncodilatadores": "broncodilatador",
    "broncopleurisias": "broncopleurisia",
    "broncopneumonias": "broncopneumonia",
    "broncos": "bronco",
    "broncoscopias": "broncoscopia",
    "broncófona": "broncófono",
    "broncófonas": "broncófono",
    "broncófonos": "broncófono",
    "bronquectasias": "bronquectasia",
    "bronquiais": "bronquial",
    "bronquices": "bronquice",
    "bronquiectasias": "bronquiectasia",
    "bronquites": "bronquite",
    "bronquíolos": "bronquíolo",
    "brontossauros": "brontossauro",
    "bronzagens": "bronzagem",
    "bronzeada": "bronzear",
    "bronzeadas": "bronzear",
    "bronzeado": "bronzear",
    "bronzeadores": "bronzeador",
    "bronzeados": "bronzear",
    "bronzeadíssima": "bronzeado",
    "bronzeadíssimas": "bronzeado",
    "bronzeadíssimo": "bronzeado",
    "bronzeadíssimos": "bronzeado",
    "bronzeai": "bronzear",
    "bronzeais": "bronzear",
    "bronzeamentos": "bronzeamento",
    "bronzeamo": "bronzear",
    "bronzeamos": "bronzear",
    "bronzeando": "bronzear",
    "bronzeara": "bronzear",
    "bronzearam": "bronzear",
    "bronzearas": "bronzear",
    "bronzearde": "bronzear",
    "bronzeardes": "bronzear",
    "bronzeare": "bronzear",
    "bronzearei": "bronzear",
    "bronzeareis": "bronzear",
    "bronzearem": "bronzear",
    "bronzearemos": "bronzear",
    "bronzeares": "bronzear",
    "bronzearia": "bronzear",
    "bronzeariam": "bronzear",
    "bronzearias": "bronzear",
    "bronzearmo": "bronzear",
    "bronzearmos": "bronzear",
    "bronzeará": "bronzear",
    "bronzearás": "bronzear",
    "bronzearão": "bronzear",
    "bronzearíamos": "bronzear",
    "bronzearíeis": "bronzear",
    "bronzeasse": "bronzear",
    "bronzeassem": "bronzear",
    "bronzeasses": "bronzear",
    "bronzeaste": "bronzear",
    "bronzeastes": "bronzear",
    "bronzeava": "bronzear",
    "bronzeavam": "bronzear",
    "bronzeavas": "bronzear",
    "bronzeei": "bronzear",
    "bronzeeis": "bronzear",
    "bronzeemo": "bronzear",
    "bronzeemos": "bronzear",
    "bronzeia": "bronzear",
    "bronzeiam": "bronzear",
    "bronzeias": "bronzear",
    "bronzeie": "bronzear",
    "bronzeiem": "bronzear",
    "bronzeies": "bronzear",
    "bronzeio": "bronzear",
    "bronzeou": "bronzear",
    "bronzes": "bronze",
    "bronzeá": "bronzear",
    "bronzeámo": "bronzear",
    "bronzeámos": "bronzear",
    "bronzeáramo": "bronzear",
    "bronzeáramos": "bronzear",
    "bronzeárei": "bronzear",
    "bronzeáreis": "bronzear",
    "bronzeásseis": "bronzear",
    "bronzeássemos": "bronzear",
    "bronzeávamo": "bronzear",
    "bronzeávamos": "bronzear",
    "bronzeávei": "bronzear",
    "bronzeáveis": "bronzear",
    "bronzistas": "bronzista",
    "bronzites": "bronzite",
    "broque": "brocar",
    "broqueada": "broquear",
    "broqueadas": "broquear",
    "broqueado": "broquear",
    "broqueados": "broquear",
    "broqueai": "broquear",
    "broqueais": "broquear",
    "broqueamentos": "broqueamento",
    "broqueamo": "broquear",
    "broqueamos": "broquear",
    "broqueando": "broquear",
    "broqueara": "broquear",
    "broquearam": "broquear",
    "broquearas": "broquear",
    "broquearde": "broquear",
    "broqueardes": "broquear",
    "broqueare": "broquear",
    "broquearei": "broquear",
    "broqueareis": "broquear",
    "broquearem": "broquear",
    "broquearemos": "broquear",
    "broqueares": "broquear",
    "broquearia": "broquear",
    "broqueariam": "broquear",
    "broquearias": "broquear",
    "broquearmo": "broquear",
    "broquearmos": "broquear",
    "broqueará": "broquear",
    "broquearás": "broquear",
    "broquearão": "broquear",
    "broquearíamos": "broquear",
    "broquearíeis": "broquear",
    "broqueasse": "broquear",
    "broqueassem": "broquear",
    "broqueasses": "broquear",
    "broqueaste": "broquear",
    "broqueastes": "broquear",
    "broqueava": "broquear",
    "broqueavam": "broquear",
    "broqueavas": "broquear",
    "broqueei": "broquear",
    "broqueeis": "broquear",
    "broqueemo": "broquear",
    "broqueemos": "broquear",
    "broquei": "brocar",
    "broqueia": "broquear",
    "broqueiam": "broquear",
    "broqueias": "broquear",
    "broqueie": "broquear",
    "broqueiem": "broquear",
    "broqueies": "broquear",
    "broqueio": "broquear",
    "broqueis": "brocar",
    "broquela": "broquelar",
    "broquelada": "broquelar",
    "broqueladas": "broquelar",
    "broquelado": "broquelar",
    "broquelados": "broquelar",
    "broquelai": "broquelar",
    "broquelais": "broquelar",
    "broquelam": "broquelar",
    "broquelamo": "broquelar",
    "broquelamos": "broquelar",
    "broquelando": "broquelar",
    "broquelara": "broquelar",
    "broquelaram": "broquelar",
    "broquelaras": "broquelar",
    "broquelarde": "broquelar",
    "broquelardes": "broquelar",
    "broquelare": "broquelar",
    "broquelarei": "broquelar",
    "broquelareis": "broquelar",
    "broquelarem": "broquelar",
    "broquelaremos": "broquelar",
    "broquelares": "broquelar",
    "broquelaria": "broquelar",
    "broquelariam": "broquelar",
    "broquelarias": "broquelar",
    "broquelarmo": "broquelar",
    "broquelarmos": "broquelar",
    "broquelará": "broquelar",
    "broquelarás": "broquelar",
    "broquelarão": "broquelar",
    "broquelaríamos": "broquelar",
    "broquelaríeis": "broquelar",
    "broquelas": "broquelar",
    "broquelasse": "broquelar",
    "broquelassem": "broquelar",
    "broquelasses": "broquelar",
    "broquelaste": "broquelar",
    "broquelastes": "broquelar",
    "broquelava": "broquelar",
    "broquelavam": "broquelar",
    "broquelavas": "broquelar",
    "broquele": "broquelar",
    "broquelei": "broquelar",
    "broqueleira": "broqueleiro",
    "broqueleiras": "broqueleiro",
    "broqueleiros": "broqueleiro",
    "broqueleis": "broquelar",
    "broquelem": "broquelar",
    "broquelemo": "broquelar",
    "broquelemos": "broquelar",
    "broqueles": "broquelar",
    "broquelo": "broquelar",
    "broquelou": "broquelar",
    "broquelá": "broquelar",
    "broquelámo": "broquelar",
    "broquelámos": "broquelar",
    "broqueláramo": "broquelar",
    "broqueláramos": "broquelar",
    "broquelárei": "broquelar",
    "broqueláreis": "broquelar",
    "broquelásseis": "broquelar",
    "broquelássemos": "broquelar",
    "broquelávamo": "broquelar",
    "broquelávamos": "broquelar",
    "broquelávei": "broquelar",
    "broqueláveis": "broquelar",
    "broquem": "brocar",
    "broquemo": "brocar",
    "broquemos": "brocar",
    "broquenta": "broquento",
    "broquentas": "broquento",
    "broquentos": "broquento",
    "broqueou": "broquear",
    "broques": "broque",
    "broqueá": "broquear",
    "broqueámo": "broquear",
    "broqueámos": "broquear",
    "broqueáramo": "broquear",
    "broqueáramos": "broquear",
    "broqueárei": "broquear",
    "broqueáreis": "broquear",
    "broqueásseis": "broquear",
    "broqueássemos": "broquear",
    "broqueávamo": "broquear",
    "broqueávamos": "broquear",
    "broqueávei": "broquear",
    "broqueáveis": "broquear",
    "broquéis": "broquel",
    "brossa": "brossar",
    "brossada": "brossar",
    "brossadas": "brossar",
    "brossado": "brossar",
    "brossados": "brossar",
    "brossai": "brossar",
    "brossais": "brossar",
    "brossam": "brossar",
    "brossamo": "brossar",
    "brossamos": "brossar",
    "brossando": "brossar",
    "brossara": "brossar",
    "brossaram": "brossar",
    "brossaras": "brossar",
    "brossarde": "brossar",
    "brossardes": "brossar",
    "brossare": "brossar",
    "brossarei": "brossar",
    "brossareis": "brossar",
    "brossarem": "brossar",
    "brossaremos": "brossar",
    "brossares": "brossar",
    "brossaria": "brossar",
    "brossariam": "brossar",
    "brossarias": "brossar",
    "brossarmo": "brossar",
    "brossarmos": "brossar",
    "brossará": "brossar",
    "brossarás": "brossar",
    "brossarão": "brossar",
    "brossaríamos": "brossar",
    "brossaríeis": "brossar",
    "brossas": "brossar",
    "brossasse": "brossar",
    "brossassem": "brossar",
    "brossasses": "brossar",
    "brossaste": "brossar",
    "brossastes": "brossar",
    "brossava": "brossar",
    "brossavam": "brossar",
    "brossavas": "brossar",
    "brosse": "brossar",
    "brossei": "brossar",
    "brosseis": "brossar",
    "brossem": "brossar",
    "brossemo": "brossar",
    "brossemos": "brossar",
    "brosses": "brossar",
    "brosso": "brossar",
    "brossou": "brossar",
    "brossá": "brossar",
    "brossámo": "brossar",
    "brossámos": "brossar",
    "brossáramo": "brossar",
    "brossáramos": "brossar",
    "brossárei": "brossar",
    "brossáreis": "brossar",
    "brossásseis": "brossar",
    "brossássemos": "brossar",
    "brossávamo": "brossar",
    "brossávamos": "brossar",
    "brossávei": "brossar",
    "brossáveis": "brossar",
    "brota": "brotar",
    "brotada": "brotar",
    "brotadas": "brotar",
    "brotado": "brotar",
    "brotados": "brotar",
    "brotai": "brotar",
    "brotais": "brotar",
    "brotam": "brotar",
    "brotamentos": "brotamento",
    "brotamo": "brotar",
    "brotamos": "brotar",
    "brotando": "brotar",
    "brotara": "brotar",
    "brotaram": "brotar",
    "brotaras": "brotar",
    "brotardes": "brotar",
    "brotarei": "brotar",
    "brotareis": "brotar",
    "brotarem": "brotar",
    "brotaremos": "brotar",
    "brotares": "brotar",
    "brotaria": "brotar",
    "brotariam": "brotar",
    "brotarias": "brotar",
    "brotarmo": "brotar",
    "brotarmos": "brotar",
    "brotará": "brotar",
    "brotarás": "brotar",
    "brotarão": "brotar",
    "brotaríamos": "brotar",
    "brotaríeis": "brotar",
    "brotas": "brotar",
    "brotasse": "brotar",
    "brotassem": "brotar",
    "brotasses": "brotar",
    "brotaste": "brotar",
    "brotastes": "brotar",
    "brotava": "brotar",
    "brotavam": "brotar",
    "brotavas": "brotar",
    "brote": "brotar",
    "brotei": "brotar",
    "broteis": "brotar",
    "brotem": "brotar",
    "brotemo": "brotar",
    "brotemos": "brotar",
    "brotes": "brotar",
    "brotinha": "broto",
    "brotinhas": "broto",
    "brotinho": "broto",
    "brotinhos": "broto",
    "brotita": "broto",
    "brotitas": "broto",
    "brotito": "broto",
    "brotitos": "broto",
    "broto": "brotar",
    "brotoejas": "brotoeja",
    "brotos": "broto",
    "brotou": "brotar",
    "brotámo": "brotar",
    "brotámos": "brotar",
    "brotáramo": "brotar",
    "brotáramos": "brotar",
    "brotáreis": "brotar",
    "brotásseis": "brotar",
    "brotássemos": "brotar",
    "brotávamo": "brotar",
    "brotávamos": "brotar",
    "brotáveis": "brotar",
    "browniana": "browniano",
    "brownianas": "browniano",
    "brownianos": "browniano",
    "broxa": "broxar",
    "broxada": "broxar",
    "broxadas": "broxar",
    "broxado": "broxar",
    "broxados": "broxar",
    "broxai": "broxar",
    "broxais": "broxar",
    "broxam": "broxar",
    "broxamo": "broxar",
    "broxamos": "broxar",
    "broxando": "broxar",
    "broxantes": "broxante",
    "broxara": "broxar",
    "broxaram": "broxar",
    "broxaras": "broxar",
    "broxarde": "broxar",
    "broxardes": "broxar",
    "broxare": "broxar",
    "broxarei": "broxar",
    "broxareis": "broxar",
    "broxarem": "broxar",
    "broxaremos": "broxar",
    "broxares": "broxar",
    "broxaria": "broxar",
    "broxariam": "broxar",
    "broxarias": "broxar",
    "broxarmo": "broxar",
    "broxarmos": "broxar",
    "broxará": "broxar",
    "broxarás": "broxar",
    "broxarão": "broxar",
    "broxaríamos": "broxar",
    "broxaríeis": "broxar",
    "broxas": "broxar",
    "broxasse": "broxar",
    "broxassem": "broxar",
    "broxasses": "broxar",
    "broxaste": "broxar",
    "broxastes": "broxar",
    "broxava": "broxar",
    "broxavam": "broxar",
    "broxavas": "broxar",
    "broxe": "broxar",
    "broxei": "broxar",
    "broxeis": "broxar",
    "broxem": "broxar",
    "broxemo": "broxar",
    "broxemos": "broxar",
    "broxes": "broxar",
    "broxo": "broxar",
    "broxou": "broxar",
    "broxá": "broxar",
    "broxámo": "broxar",
    "broxámos": "broxar",
    "broxáramo": "broxar",
    "broxáramos": "broxar",
    "broxárei": "broxar",
    "broxáreis": "broxar",
    "broxásseis": "broxar",
    "broxássemos": "broxar",
    "broxávamo": "broxar",
    "broxávamos": "broxar",
    "broxávei": "broxar",
    "broxáveis": "broxar",
    "broças": "broça",
    "bruaás": "bruaá",
    "bruceloses": "brucelose",
    "brucinas": "brucina",
    "brucitas": "brucita",
    "brucites": "brucite",
    "brucos": "bruco",
    "bruegas": "bruega",
    "bruleios": "bruleio",
    "brulhas": "brulha",
    "brulhos": "brulho",
    "brulotes": "brulote",
    "brumaceira": "brumaceiro",
    "brumaceiras": "brumaceiro",
    "brumaceiros": "brumaceiro",
    "brumais": "brumal",
    "brumas": "bruma",
    "brumosa": "brumoso",
    "brumosas": "brumoso",
    "brumosos": "brumoso",
    "brumários": "brumário",
    "bruna": "bruno",
    "brunais": "brunir",
    "brunam": "brunir",
    "brunamo": "brunir",
    "brunamos": "brunir",
    "brunas": "bruno",
    "brune": "brunir",
    "brunem": "brunir",
    "brunes": "brunir",
    "brunhos": "brunho",
    "bruni": "brunir",
    "brunia": "brunir",
    "bruniam": "brunir",
    "brunias": "brunir",
    "brunida": "brunir",
    "brunidas": "brunir",
    "brunideira": "brunidor",
    "brunideiras": "brunidor",
    "brunido": "brunir",
    "brunidora": "brunidor",
    "brunidoras": "brunidor",
    "brunidores": "brunidor",
    "brunidos": "brunir",
    "bruniduras": "brunidura",
    "brunimo": "brunir",
    "brunimos": "brunir",
    "brunindo": "brunir",
    "brunira": "brunir",
    "bruniram": "brunir",
    "bruniras": "brunir",
    "brunirde": "brunir",
    "brunirdes": "brunir",
    "brunire": "brunir",
    "brunirei": "brunir",
    "brunireis": "brunir",
    "brunirem": "brunir",
    "bruniremos": "brunir",
    "brunires": "brunir",
    "bruniria": "brunir",
    "bruniriam": "brunir",
    "brunirias": "brunir",
    "brunirmo": "brunir",
    "brunirmos": "brunir",
    "brunirá": "brunir",
    "brunirás": "brunir",
    "brunirão": "brunir",
    "bruniríamos": "brunir",
    "bruniríeis": "brunir",
    "brunis": "brunir",
    "brunisse": "brunir",
    "brunissem": "brunir",
    "brunisses": "brunir",
    "bruniste": "brunir",
    "brunistes": "brunir",
    "bruniu": "brunir",
    "bruno": "brunir",
    "brunos": "bruno",
    "bruníamo": "brunir",
    "bruníamos": "brunir",
    "bruníei": "brunir",
    "bruníeis": "brunir",
    "bruníramo": "brunir",
    "bruníramos": "brunir",
    "brunírei": "brunir",
    "bruníreis": "brunir",
    "brunísseis": "brunir",
    "bruníssemos": "brunir",
    "brusca": "brusco",
    "bruscas": "brusco",
    "bruscos": "brusco",
    "brusquidões": "brusquidão",
    "brusquíssima": "brusco",
    "brusquíssimas": "brusco",
    "brusquíssimo": "brusco",
    "brusquíssimos": "brusco",
    "bruta": "bruto",
    "brutais": "brutal",
    "brutalhadas": "brutalhada",
    "brutalices": "brutalice",
    "brutalidades": "brutalidade",
    "brutaliza": "brutalizar",
    "brutalizada": "brutalizar",
    "brutalizadas": "brutalizar",
    "brutalizado": "brutalizar",
    "brutalizados": "brutalizar",
    "brutalizai": "brutalizar",
    "brutalizais": "brutalizar",
    "brutalizam": "brutalizar",
    "brutalizamo": "brutalizar",
    "brutalizamos": "brutalizar",
    "brutalizando": "brutalizar",
    "brutalizara": "brutalizar",
    "brutalizaram": "brutalizar",
    "brutalizaras": "brutalizar",
    "brutalizarde": "brutalizar",
    "brutalizardes": "brutalizar",
    "brutalizare": "brutalizar",
    "brutalizarei": "brutalizar",
    "brutalizareis": "brutalizar",
    "brutalizarem": "brutalizar",
    "brutalizaremos": "brutalizar",
    "brutalizares": "brutalizar",
    "brutalizaria": "brutalizar",
    "brutalizariam": "brutalizar",
    "brutalizarias": "brutalizar",
    "brutalizarmo": "brutalizar",
    "brutalizarmos": "brutalizar",
    "brutalizará": "brutalizar",
    "brutalizarás": "brutalizar",
    "brutalizarão": "brutalizar",
    "brutalizaríamos": "brutalizar",
    "brutalizaríeis": "brutalizar",
    "brutalizas": "brutalizar",
    "brutalizasse": "brutalizar",
    "brutalizassem": "brutalizar",
    "brutalizasses": "brutalizar",
    "brutalizaste": "brutalizar",
    "brutalizastes": "brutalizar",
    "brutalizava": "brutalizar",
    "brutalizavam": "brutalizar",
    "brutalizavas": "brutalizar",
    "brutalizações": "brutalização",
    "brutalize": "brutalizar",
    "brutalizei": "brutalizar",
    "brutalizeis": "brutalizar",
    "brutalizem": "brutalizar",
    "brutalizemo": "brutalizar",
    "brutalizemos": "brutalizar",
    "brutalizes": "brutalizar",
    "brutalizo": "brutalizar",
    "brutalizou": "brutalizar",
    "brutalizá": "brutalizar",
    "brutalizámo": "brutalizar",
    "brutalizámos": "brutalizar",
    "brutalizáramo": "brutalizar",
    "brutalizáramos": "brutalizar",
    "brutalizárei": "brutalizar",
    "brutalizáreis": "brutalizar",
    "brutalizásseis": "brutalizar",
    "brutalizássemos": "brutalizar",
    "brutalizávamo": "brutalizar",
    "brutalizávamos": "brutalizar",
    "brutalizávei": "brutalizar",
    "brutalizáveis": "brutalizar",
    "brutas": "bruto",
    "brutesca": "brutesco",
    "brutescas": "brutesco",
    "brutescos": "brutesco",
    "brutezas": "bruteza",
    "brutidades": "brutidade",
    "brutidões": "brutidão",
    "brutifica": "brutificar",
    "brutificada": "brutificar",
    "brutificadas": "brutificar",
    "brutificado": "brutificar",
    "brutificadora": "brutificador",
    "brutificadoras": "brutificador",
    "brutificadores": "brutificador",
    "brutificados": "brutificar",
    "brutificai": "brutificar",
    "brutificais": "brutificar",
    "brutificam": "brutificar",
    "brutificamo": "brutificar",
    "brutificamos": "brutificar",
    "brutificando": "brutificar",
    "brutificara": "brutificar",
    "brutificaram": "brutificar",
    "brutificaras": "brutificar",
    "brutificarde": "brutificar",
    "brutificardes": "brutificar",
    "brutificare": "brutificar",
    "brutificarei": "brutificar",
    "brutificareis": "brutificar",
    "brutificarem": "brutificar",
    "brutificaremos": "brutificar",
    "brutificares": "brutificar",
    "brutificaria": "brutificar",
    "brutificariam": "brutificar",
    "brutificarias": "brutificar",
    "brutificarmo": "brutificar",
    "brutificarmos": "brutificar",
    "brutificará": "brutificar",
    "brutificarás": "brutificar",
    "brutificarão": "brutificar",
    "brutificaríamos": "brutificar",
    "brutificaríeis": "brutificar",
    "brutificas": "brutificar",
    "brutificasse": "brutificar",
    "brutificassem": "brutificar",
    "brutificasses": "brutificar",
    "brutificaste": "brutificar",
    "brutificastes": "brutificar",
    "brutificava": "brutificar",
    "brutificavam": "brutificar",
    "brutificavas": "brutificar",
    "brutificações": "brutificação",
    "brutifico": "brutificar",
    "brutificou": "brutificar",
    "brutificá": "brutificar",
    "brutificámo": "brutificar",
    "brutificámos": "brutificar",
    "brutificáramo": "brutificar",
    "brutificáramos": "brutificar",
    "brutificárei": "brutificar",
    "brutificáreis": "brutificar",
    "brutificásseis": "brutificar",
    "brutificássemos": "brutificar",
    "brutificávamo": "brutificar",
    "brutificávamos": "brutificar",
    "brutificávei": "brutificar",
    "brutificáveis": "brutificar",
    "brutifique": "brutificar",
    "brutifiquei": "brutificar",
    "brutifiqueis": "brutificar",
    "brutifiquem": "brutificar",
    "brutifiquemo": "brutificar",
    "brutifiquemos": "brutificar",
    "brutifiques": "brutificar",
    "brutinha": "bruto",
    "brutinhas": "bruto",
    "brutinho": "bruto",
    "brutinhos": "bruto",
    "brutita": "bruto",
    "brutitas": "bruto",
    "brutito": "bruto",
    "brutitos": "bruto",
    "brutos": "bruto",
    "brutíssima": "bruto",
    "brutíssimas": "bruto",
    "brutíssimo": "bruto",
    "brutíssimos": "bruto",
    "bruxa": "bruxo",
    "bruxada": "bruxar",
    "bruxadas": "bruxar",
    "bruxado": "bruxar",
    "bruxados": "bruxar",
    "bruxai": "bruxar",
    "bruxais": "bruxar",
    "bruxam": "bruxar",
    "bruxamo": "bruxar",
    "bruxamos": "bruxar",
    "bruxando": "bruxar",
    "bruxara": "bruxar",
    "bruxaram": "bruxar",
    "bruxaras": "bruxar",
    "bruxardes": "bruxar",
    "bruxarei": "bruxar",
    "bruxareis": "bruxar",
    "bruxarem": "bruxar",
    "bruxaremos": "bruxar",
    "bruxares": "bruxar",
    "bruxaria": "bruxar",
    "bruxariam": "bruxar",
    "bruxarias": "bruxaria",
    "bruxarmo": "bruxar",
    "bruxarmos": "bruxar",
    "bruxará": "bruxar",
    "bruxarás": "bruxar",
    "bruxarão": "bruxar",
    "bruxaríamos": "bruxar",
    "bruxaríeis": "bruxar",
    "bruxas": "bruxo",
    "bruxasse": "bruxar",
    "bruxassem": "bruxar",
    "bruxasses": "bruxar",
    "bruxaste": "bruxar",
    "bruxastes": "bruxar",
    "bruxava": "bruxar",
    "bruxavam": "bruxar",
    "bruxavas": "bruxar",
    "bruxe": "bruxar",
    "bruxeada": "bruxear",
    "bruxeadas": "bruxear",
    "bruxeado": "bruxear",
    "bruxeados": "bruxear",
    "bruxeai": "bruxear",
    "bruxeais": "bruxear",
    "bruxeamo": "bruxear",
    "bruxeamos": "bruxear",
    "bruxeando": "bruxear",
    "bruxeara": "bruxear",
    "bruxearam": "bruxear",
    "bruxearas": "bruxear",
    "bruxeardes": "bruxear",
    "bruxearei": "bruxear",
    "bruxeareis": "bruxear",
    "bruxearem": "bruxear",
    "bruxearemos": "bruxear",
    "bruxeares": "bruxear",
    "bruxearia": "bruxear",
    "bruxeariam": "bruxear",
    "bruxearias": "bruxear",
    "bruxearmo": "bruxear",
    "bruxearmos": "bruxear",
    "bruxeará": "bruxear",
    "bruxearás": "bruxear",
    "bruxearão": "bruxear",
    "bruxearíamos": "bruxear",
    "bruxearíeis": "bruxear",
    "bruxeasse": "bruxear",
    "bruxeassem": "bruxear",
    "bruxeasses": "bruxear",
    "bruxeaste": "bruxear",
    "bruxeastes": "bruxear",
    "bruxeava": "bruxear",
    "bruxeavam": "bruxear",
    "bruxeavas": "bruxear",
    "bruxedos": "bruxedo",
    "bruxeei": "bruxear",
    "bruxeeis": "bruxear",
    "bruxeemo": "bruxear",
    "bruxeemos": "bruxear",
    "bruxei": "bruxar",
    "bruxeia": "bruxear",
    "bruxeiam": "bruxear",
    "bruxeias": "bruxear",
    "bruxeie": "bruxear",
    "bruxeiem": "bruxear",
    "bruxeies": "bruxear",
    "bruxeio": "bruxear",
    "bruxeis": "bruxar",
    "bruxelenses": "bruxelense",
    "bruxelesa": "bruxelês",
    "bruxelesas": "bruxelês",
    "bruxeleses": "bruxelês",
    "bruxem": "bruxar",
    "bruxemo": "bruxar",
    "bruxemos": "bruxar",
    "bruxeou": "bruxear",
    "bruxes": "bruxar",
    "bruxeámo": "bruxear",
    "bruxeámos": "bruxear",
    "bruxeáramo": "bruxear",
    "bruxeáramos": "bruxear",
    "bruxeáreis": "bruxear",
    "bruxeásseis": "bruxear",
    "bruxeássemos": "bruxear",
    "bruxeávamo": "bruxear",
    "bruxeávamos": "bruxear",
    "bruxeáveis": "bruxear",
    "bruxinha": "bruxo",
    "bruxinhas": "bruxo",
    "bruxinho": "bruxo",
    "bruxinhos": "bruxo",
    "bruxita": "bruxo",
    "bruxitas": "bruxo",
    "bruxito": "bruxo",
    "bruxitos": "bruxo",
    "bruxo": "bruxar",
    "bruxos": "bruxo",
    "bruxou": "bruxar",
    "bruxuleada": "bruxulear",
    "bruxuleadas": "bruxulear",
    "bruxuleado": "bruxulear",
    "bruxuleados": "bruxulear",
    "bruxuleai": "bruxulear",
    "bruxuleais": "bruxulear",
    "bruxuleamo": "bruxulear",
    "bruxuleamos": "bruxulear",
    "bruxuleando": "bruxulear",
    "bruxuleantes": "bruxuleante",
    "bruxuleara": "bruxulear",
    "bruxulearam": "bruxulear",
    "bruxulearas": "bruxulear",
    "bruxuleardes": "bruxulear",
    "bruxulearei": "bruxulear",
    "bruxuleareis": "bruxulear",
    "bruxulearem": "bruxulear",
    "bruxulearemos": "bruxulear",
    "bruxuleares": "bruxulear",
    "bruxulearia": "bruxulear",
    "bruxuleariam": "bruxulear",
    "bruxulearias": "bruxulear",
    "bruxulearmo": "bruxulear",
    "bruxulearmos": "bruxulear",
    "bruxuleará": "bruxulear",
    "bruxulearás": "bruxulear",
    "bruxulearão": "bruxulear",
    "bruxulearíamos": "bruxulear",
    "bruxulearíeis": "bruxulear",
    "bruxuleasse": "bruxulear",
    "bruxuleassem": "bruxulear",
    "bruxuleasses": "bruxulear",
    "bruxuleaste": "bruxulear",
    "bruxuleastes": "bruxulear",
    "bruxuleava": "bruxulear",
    "bruxuleavam": "bruxulear",
    "bruxuleavas": "bruxulear",
    "bruxuleei": "bruxulear",
    "bruxuleeis": "bruxulear",
    "bruxuleemo": "bruxulear",
    "bruxuleemos": "bruxulear",
    "bruxuleia": "bruxulear",
    "bruxuleiam": "bruxulear",
    "bruxuleias": "bruxulear",
    "bruxuleie": "bruxulear",
    "bruxuleiem": "bruxulear",
    "bruxuleies": "bruxulear",
    "bruxuleio": "bruxulear",
    "bruxuleou": "bruxulear",
    "bruxuleámo": "bruxulear",
    "bruxuleámos": "bruxulear",
    "bruxuleáramo": "bruxulear",
    "bruxuleáramos": "bruxulear",
    "bruxuleáreis": "bruxulear",
    "bruxuleásseis": "bruxulear",
    "bruxuleássemos": "bruxulear",
    "bruxuleávamo": "bruxulear",
    "bruxuleávamos": "bruxulear",
    "bruxuleáveis": "bruxulear",
    "bruxámo": "bruxar",
    "bruxámos": "bruxar",
    "bruxáramo": "bruxar",
    "bruxáramos": "bruxar",
    "bruxáreis": "bruxar",
    "bruxásseis": "bruxar",
    "bruxássemos": "bruxar",
    "bruxávamo": "bruxar",
    "bruxávamos": "bruxar",
    "bruxáveis": "bruxar",
    "bruás": "bruá",
    "brácara": "brácaro",
    "brácaras": "brácaro",
    "brácaros": "brácaro",
    "brácteas": "bráctea",
    "bráquias": "bráquia",
    "brâmanes": "brâmane",
    "brânqueas": "brânquea",
    "brânquica": "brânquico",
    "brânquicas": "brânquico",
    "brânquicos": "brânquico",
    "brístoles": "brístol",
    "bródios": "bródio",
    "brómica": "brómico",
    "brómicas": "brómico",
    "brómicos": "brómico",
    "brônquios": "brônquio",
    "brônzea": "brônzeo",
    "brônzeas": "brônzeo",
    "brônzeos": "brônzeo",
    "bua": "buir",
    "buais": "buir",
    "buam": "buir",
    "buamo": "buir",
    "buamos": "buir",
    "buas": "buir",
    "bubas": "buba",
    "bubelas": "bubela",
    "bubonalgias": "bubonalgia",
    "bubonoceles": "bubonocele",
    "bubónias": "bubónia",
    "bubónica": "bubónico",
    "bubónicas": "bubónico",
    "bubónicos": "bubónico",
    "bubões": "bubão",
    "bucais": "bucal",
    "bucelares": "bucelar",
    "bucelária": "bucelário",
    "bucelárias": "bucelário",
    "bucelários": "bucelário",
    "bucentauros": "bucentauro",
    "buchada": "buchado",
    "buchadas": "buchado",
    "buchados": "buchado",
    "buchas": "bucha",
    "bucheiros": "bucheiro",
    "buchelas": "buchela",
    "buchinha": "bucha",
    "buchinhas": "bucha",
    "buchins": "buchim",
    "buchita": "bucha",
    "buchitas": "bucha",
    "buchos": "bucho",
    "buchuda": "buchudo",
    "buchudas": "buchudo",
    "buchudos": "buchudo",
    "bucinadora": "bucinador",
    "bucinadoras": "bucinador",
    "bucinadores": "bucinador",
    "bucins": "bucim",
    "bucolismos": "bucolismo",
    "buconídea": "buconídeo",
    "buconídeas": "buconídeo",
    "buconídeos": "buconídeo",
    "bucos": "buco",
    "bucrânios": "bucrânio",
    "buculas": "bucula",
    "buculistas": "buculista",
    "bucéfala": "bucéfalo",
    "bucéfalas": "bucéfalo",
    "bucéfalos": "bucéfalo",
    "bucólica": "bucólico",
    "bucólicas": "bucólico",
    "bucólicos": "bucólico",
    "bucónidas": "bucónida",
    "budas": "buda",
    "budismos": "budismo",
    "budistas": "budista",
    "bueiras": "bueira",
    "bueiros": "bueiro",
    "buelas": "buela",
    "buem": "buir",
    "buetneríea": "buetneríeo",
    "buetneríeas": "buetneríeo",
    "buetneríeos": "buetneríeo",
    "bufa": "bufo",
    "bufada": "bufar",
    "bufadas": "bufar",
    "bufado": "bufar",
    "bufados": "bufar",
    "bufai": "bufar",
    "bufais": "bufar",
    "bufalina": "bufalino",
    "bufalinas": "bufalino",
    "bufalinos": "bufalino",
    "bufam": "bufar",
    "bufamo": "bufar",
    "bufamos": "bufar",
    "bufando": "bufar",
    "bufara": "bufar",
    "bufaram": "bufar",
    "bufaras": "bufar",
    "bufardes": "bufar",
    "bufarei": "bufar",
    "bufareis": "bufar",
    "bufarem": "bufar",
    "bufaremos": "bufar",
    "bufares": "bufar",
    "bufaria": "bufar",
    "bufariam": "bufar",
    "bufarias": "bufar",
    "bufarinhas": "bufarinha",
    "bufarinheiros": "bufarinheiro",
    "bufarmo": "bufar",
    "bufarmos": "bufar",
    "bufará": "bufar",
    "bufarás": "bufar",
    "bufarão": "bufar",
    "bufaríamos": "bufar",
    "bufaríeis": "bufar",
    "bufas": "bufo",
    "bufasse": "bufar",
    "bufassem": "bufar",
    "bufasses": "bufar",
    "bufaste": "bufar",
    "bufastes": "bufar",
    "bufava": "bufar",
    "bufavam": "bufar",
    "bufavas": "bufar",
    "bufe": "bufar",
    "bufei": "bufar",
    "bufeiras": "bufeira",
    "bufeis": "bufar",
    "bufem": "bufar",
    "bufemo": "bufar",
    "bufemos": "bufar",
    "bufes": "bufar",
    "bufetes": "bufete",
    "bufidos": "bufido",
    "bufo": "bufar",
    "bufona": "bufão",
    "bufonarias": "bufonaria",
    "bufonas": "bufão",
    "bufoneada": "bufonear",
    "bufoneadas": "bufonear",
    "bufoneado": "bufonear",
    "bufoneados": "bufonear",
    "bufoneai": "bufonear",
    "bufoneais": "bufonear",
    "bufoneamo": "bufonear",
    "bufoneamos": "bufonear",
    "bufoneando": "bufonear",
    "bufoneara": "bufonear",
    "bufonearam": "bufonear",
    "bufonearas": "bufonear",
    "bufoneardes": "bufonear",
    "bufonearei": "bufonear",
    "bufoneareis": "bufonear",
    "bufonearem": "bufonear",
    "bufonearemos": "bufonear",
    "bufoneares": "bufonear",
    "bufonearia": "bufonear",
    "bufoneariam": "bufonear",
    "bufonearias": "bufonear",
    "bufonearmo": "bufonear",
    "bufonearmos": "bufonear",
    "bufoneará": "bufonear",
    "bufonearás": "bufonear",
    "bufonearão": "bufonear",
    "bufonearíamos": "bufonear",
    "bufonearíeis": "bufonear",
    "bufoneasse": "bufonear",
    "bufoneassem": "bufonear",
    "bufoneasses": "bufonear",
    "bufoneaste": "bufonear",
    "bufoneastes": "bufonear",
    "bufoneava": "bufonear",
    "bufoneavam": "bufonear",
    "bufoneavas": "bufonear",
    "bufoneei": "bufonear",
    "bufoneeis": "bufonear",
    "bufoneemo": "bufonear",
    "bufoneemos": "bufonear",
    "bufoneia": "bufonear",
    "bufoneiam": "bufonear",
    "bufoneias": "bufonear",
    "bufoneie": "bufonear",
    "bufoneiem": "bufonear",
    "bufoneies": "bufonear",
    "bufoneio": "bufonear",
    "bufoneou": "bufonear",
    "bufoneámo": "bufonear",
    "bufoneámos": "bufonear",
    "bufoneáramo": "bufonear",
    "bufoneáramos": "bufonear",
    "bufoneáreis": "bufonear",
    "bufoneásseis": "bufonear",
    "bufoneássemos": "bufonear",
    "bufoneávamo": "bufonear",
    "bufoneávamos": "bufonear",
    "bufoneáveis": "bufonear",
    "bufonídea": "bufonídeo",
    "bufonídeas": "bufonídeo",
    "bufonídeos": "bufonídeo",
    "bufos": "bufo",
    "bufou": "bufar",
    "bufámo": "bufar",
    "bufámos": "bufar",
    "bufáramo": "bufar",
    "bufáramos": "bufar",
    "bufáreis": "bufar",
    "bufásseis": "bufar",
    "bufássemos": "bufar",
    "bufávamo": "bufar",
    "bufávamos": "bufar",
    "bufáveis": "bufar",
    "bufês": "bufê",
    "bufónidas": "bufónida",
    "bufões": "bufão",
    "bufúrdios": "bufúrdio",
    "bugalhas": "bugalha",
    "bugalhinhas": "bugalhinha",
    "bugalhos": "bugalho",
    "bugalhuda": "bugalhudo",
    "bugalhudas": "bugalhudo",
    "bugalhudos": "bugalhudo",
    "buganvílias": "buganvília",
    "bugia": "bugiar",
    "bugiada": "bugiar",
    "bugiadas": "bugiar",
    "bugiado": "bugiar",
    "bugiados": "bugiar",
    "bugiai": "bugiar",
    "bugiais": "bugiar",
    "bugiam": "bugiar",
    "bugiamo": "bugiar",
    "bugiamos": "bugiar",
    "bugiando": "bugiar",
    "bugiara": "bugiar",
    "bugiaram": "bugiar",
    "bugiaras": "bugiar",
    "bugiardes": "bugiar",
    "bugiarei": "bugiar",
    "bugiareis": "bugiar",
    "bugiarem": "bugiar",
    "bugiaremos": "bugiar",
    "bugiares": "bugiar",
    "bugiaria": "bugiar",
    "bugiariam": "bugiar",
    "bugiarias": "bugiaria",
    "bugiarmo": "bugiar",
    "bugiarmos": "bugiar",
    "bugiará": "bugiar",
    "bugiarás": "bugiar",
    "bugiarão": "bugiar",
    "bugiaríamos": "bugiar",
    "bugiaríeis": "bugiar",
    "bugias": "bugiar",
    "bugiasse": "bugiar",
    "bugiassem": "bugiar",
    "bugiasses": "bugiar",
    "bugiaste": "bugiar",
    "bugiastes": "bugiar",
    "bugiava": "bugiar",
    "bugiavam": "bugiar",
    "bugiavas": "bugiar",
    "bugie": "bugiar",
    "bugiei": "bugiar",
    "bugieis": "bugiar",
    "bugiem": "bugiar",
    "bugiemo": "bugiar",
    "bugiemos": "bugiar",
    "bugies": "bugiar",
    "bugigangarias": "bugigangaria",
    "bugigangas": "bugiganga",
    "bugio": "bugiar",
    "bugios": "bugio",
    "bugiou": "bugiar",
    "bugiámo": "bugiar",
    "bugiámos": "bugiar",
    "bugiáramo": "bugiar",
    "bugiáramos": "bugiar",
    "bugiáreis": "bugiar",
    "bugiásseis": "bugiar",
    "bugiássemos": "bugiar",
    "bugiávamo": "bugiar",
    "bugiávamos": "bugiar",
    "bugiáveis": "bugiar",
    "buglossas": "buglossa",
    "bugras": "bugra",
    "bugres": "bugre",
    "bui": "buir",
    "buindo": "buir",
    "buingelas": "buingela",
    "buinhos": "buinho",
    "buirde": "buir",
    "buirdes": "buir",
    "buirei": "buir",
    "buireis": "buir",
    "buiremos": "buir",
    "buiria": "buir",
    "buiriam": "buir",
    "buirias": "buir",
    "buirmo": "buir",
    "buirmos": "buir",
    "buirá": "buir",
    "buirás": "buir",
    "buirão": "buir",
    "buiríamos": "buir",
    "buiríeis": "buir",
    "buis": "buir",
    "buiu": "buir",
    "bujardas": "bujarda",
    "bujarronas": "bujarrona",
    "bujões": "bujão",
    "bula": "bulir",
    "bulada": "bular",
    "buladas": "bular",
    "bulado": "bular",
    "bulados": "bular",
    "bulai": "bular",
    "bulais": "bulir",
    "bulam": "bulir",
    "bulamo": "bulir",
    "bulamos": "bulir",
    "bulando": "bular",
    "bulara": "bular",
    "bularam": "bular",
    "bularas": "bular",
    "bularde": "bular",
    "bulardes": "bular",
    "bulare": "bular",
    "bularei": "bular",
    "bulareis": "bular",
    "bularem": "bular",
    "bularemos": "bular",
    "bulares": "bular",
    "bularia": "bular",
    "bulariam": "bular",
    "bularias": "bular",
    "bularmo": "bular",
    "bularmos": "bular",
    "bulará": "bular",
    "bularás": "bular",
    "bularão": "bular",
    "bularíamos": "bular",
    "bularíeis": "bular",
    "bulas": "bulir",
    "bulasse": "bular",
    "bulassem": "bular",
    "bulasses": "bular",
    "bulaste": "bular",
    "bulastenias": "bulastenia",
    "bulastes": "bular",
    "bulava": "bular",
    "bulavam": "bular",
    "bulavas": "bular",
    "bulbiformes": "bulbiforme",
    "bulbilhos": "bulbilho",
    "bulbilos": "bulbilo",
    "bulbos": "bulbo",
    "bulbosa": "bulboso",
    "bulbosas": "bulboso",
    "bulbosos": "bulboso",
    "bulbífera": "bulbífero",
    "bulbíferas": "bulbífero",
    "bulbíferos": "bulbífero",
    "bulbípara": "bulbíparo",
    "bulbíparas": "bulbíparo",
    "bulbíparos": "bulbíparo",
    "bulcões": "bulcão",
    "buldogues": "buldogue",
    "buldozeres": "buldozer",
    "bule": "bulir",
    "bulei": "bular",
    "buleiros": "buleiro",
    "buleis": "bular",
    "bulem": "bulir",
    "bulemo": "bular",
    "bulemos": "bular",
    "bules": "bulir",
    "bulevares": "bulevar",
    "bulha": "bulhar",
    "bulhada": "bulhar",
    "bulhadas": "bulhar",
    "bulhado": "bulhar",
    "bulhados": "bulhar",
    "bulhai": "bulhar",
    "bulhais": "bulhar",
    "bulham": "bulhar",
    "bulhamo": "bulhar",
    "bulhamos": "bulhar",
    "bulhando": "bulhar",
    "bulhara": "bulhar",
    "bulharam": "bulhar",
    "bulharas": "bulhar",
    "bulhardes": "bulhar",
    "bulharei": "bulhar",
    "bulhareis": "bulhar",
    "bulharem": "bulhar",
    "bulharemos": "bulhar",
    "bulhares": "bulhar",
    "bulharia": "bulhar",
    "bulhariam": "bulhar",
    "bulharias": "bulhar",
    "bulharmo": "bulhar",
    "bulharmos": "bulhar",
    "bulhará": "bulhar",
    "bulharás": "bulhar",
    "bulharão": "bulhar",
    "bulharíamos": "bulhar",
    "bulharíeis": "bulhar",
    "bulhas": "bulhar",
    "bulhasse": "bulhar",
    "bulhassem": "bulhar",
    "bulhasses": "bulhar",
    "bulhaste": "bulhar",
    "bulhastes": "bulhar",
    "bulhava": "bulhar",
    "bulhavam": "bulhar",
    "bulhavas": "bulhar",
    "bulhe": "bulhar",
    "bulhei": "bulhar",
    "bulheis": "bulhar",
    "bulhem": "bulhar",
    "bulhemo": "bulhar",
    "bulhemos": "bulhar",
    "bulhenta": "bulhento",
    "bulhentas": "bulhento",
    "bulhentos": "bulhento",
    "bulhes": "bulhar",
    "bulho": "bulhar",
    "bulhona": "bulhão",
    "bulhonas": "bulhão",
    "bulhou": "bulhar",
    "bulhámo": "bulhar",
    "bulhámos": "bulhar",
    "bulháramo": "bulhar",
    "bulháramos": "bulhar",
    "bulháreis": "bulhar",
    "bulhásseis": "bulhar",
    "bulhássemos": "bulhar",
    "bulhávamo": "bulhar",
    "bulhávamos": "bulhar",
    "bulháveis": "bulhar",
    "bulhões": "bulhão",
    "buli": "bulir",
    "bulia": "bulir",
    "buliam": "bulir",
    "bulias": "bulir",
    "bulida": "bulir",
    "bulidas": "bulir",
    "bulideiras": "bulideira",
    "bulidelas": "bulidela",
    "bulido": "bulir",
    "bulidos": "bulir",
    "bulimias": "bulimia",
    "bulimo": "bulir",
    "bulimos": "bulir",
    "bulindo": "bulir",
    "bulira": "bulir",
    "buliram": "bulir",
    "buliras": "bulir",
    "bulirdes": "bulir",
    "bulirei": "bulir",
    "bulireis": "bulir",
    "bulirem": "bulir",
    "buliremos": "bulir",
    "bulires": "bulir",
    "buliria": "bulir",
    "buliriam": "bulir",
    "bulirias": "bulir",
    "bulirmo": "bulir",
    "bulirmos": "bulir",
    "bulirá": "bulir",
    "bulirás": "bulir",
    "bulirão": "bulir",
    "buliríamos": "bulir",
    "buliríeis": "bulir",
    "bulis": "bulir",
    "bulisse": "bulir",
    "bulissem": "bulir",
    "bulisses": "bulir",
    "bulistas": "bulista",
    "buliste": "bulir",
    "bulistes": "bulir",
    "buliu": "bulir",
    "buliçosa": "buliçoso",
    "buliçosas": "buliçoso",
    "buliçosos": "buliçoso",
    "bulo": "bulir",
    "bulou": "bular",
    "bulá": "bular",
    "bulámo": "bular",
    "bulámos": "bular",
    "buláramo": "bular",
    "buláramos": "bular",
    "bulárei": "bular",
    "buláreis": "bular",
    "bulários": "bulário",
    "bulásseis": "bular",
    "bulássemos": "bular",
    "bulávamo": "bular",
    "bulávamos": "bular",
    "bulávei": "bular",
    "buláveis": "bular",
    "bulíamo": "bulir",
    "bulíamos": "bulir",
    "bulícios": "bulício",
    "bulíeis": "bulir",
    "bulíramo": "bulir",
    "bulíramos": "bulir",
    "bulíreis": "bulir",
    "bulísseis": "bulir",
    "bulíssemos": "bulir",
    "bumba": "bumbar",
    "bumbada": "bumbar",
    "bumbadas": "bumbar",
    "bumbado": "bumbar",
    "bumbados": "bumbar",
    "bumbai": "bumbar",
    "bumbais": "bumbar",
    "bumbam": "bumbar",
    "bumbamo": "bumbar",
    "bumbamos": "bumbar",
    "bumbando": "bumbar",
    "bumbara": "bumbar",
    "bumbaram": "bumbar",
    "bumbaras": "bumbar",
    "bumbarde": "bumbar",
    "bumbardes": "bumbar",
    "bumbare": "bumbar",
    "bumbarei": "bumbar",
    "bumbareis": "bumbar",
    "bumbarem": "bumbar",
    "bumbaremos": "bumbar",
    "bumbares": "bumbar",
    "bumbaria": "bumbar",
    "bumbariam": "bumbar",
    "bumbarias": "bumbar",
    "bumbarmo": "bumbar",
    "bumbarmos": "bumbar",
    "bumbará": "bumbar",
    "bumbarás": "bumbar",
    "bumbarão": "bumbar",
    "bumbaríamos": "bumbar",
    "bumbaríeis": "bumbar",
    "bumbas": "bumbar",
    "bumbasse": "bumbar",
    "bumbassem": "bumbar",
    "bumbasses": "bumbar",
    "bumbaste": "bumbar",
    "bumbastes": "bumbar",
    "bumbava": "bumbar",
    "bumbavam": "bumbar",
    "bumbavas": "bumbar",
    "bumbe": "bumbar",
    "bumbei": "bumbar",
    "bumbeis": "bumbar",
    "bumbem": "bumbar",
    "bumbemo": "bumbar",
    "bumbemos": "bumbar",
    "bumbes": "bumbar",
    "bumbo": "bumbar",
    "bumbos": "bumbo",
    "bumbou": "bumbar",
    "bumbuns": "bumbum",
    "bumbá": "bumbar",
    "bumbámo": "bumbar",
    "bumbámos": "bumbar",
    "bumbáramo": "bumbar",
    "bumbáramos": "bumbar",
    "bumbárei": "bumbar",
    "bumbáreis": "bumbar",
    "bumbásseis": "bumbar",
    "bumbássemos": "bumbar",
    "bumbávamo": "bumbar",
    "bumbávamos": "bumbar",
    "bumbávei": "bumbar",
    "bumbáveis": "bumbar",
    "bumerangues": "bumerangue",
    "bundanas": "bundana",
    "bundas": "bunda",
    "bundinha": "bunda",
    "bundinhas": "bunda",
    "bundita": "bunda",
    "bunditas": "bunda",
    "bundos": "bundo",
    "bunheiros": "bunheiro",
    "bunhos": "bunho",
    "bunkers": "bunker",
    "bunodontes": "bunodonte",
    "buns": "bum",
    "buo": "buir",
    "buprestídea": "buprestídeo",
    "buprestídeas": "buprestídeo",
    "buprestídeos": "buprestídeo",
    "bupréstidas": "bupréstida",
    "buques": "buque",
    "buquês": "buquê",
    "buraca": "buracar",
    "buracada": "buracar",
    "buracadas": "buracar",
    "buracado": "buracar",
    "buracados": "buracar",
    "buracai": "buracar",
    "buracais": "buracar",
    "buracam": "buracar",
    "buracamo": "buracar",
    "buracamos": "buracar",
    "buracando": "buracar",
    "buracara": "buracar",
    "buracaram": "buracar",
    "buracaras": "buracar",
    "buracarde": "buracar",
    "buracardes": "buracar",
    "buracare": "buracar",
    "buracarei": "buracar",
    "buracareis": "buracar",
    "buracarem": "buracar",
    "buracaremos": "buracar",
    "buracares": "buracar",
    "buracaria": "buracar",
    "buracariam": "buracar",
    "buracarias": "buracar",
    "buracarmo": "buracar",
    "buracarmos": "buracar",
    "buracará": "buracar",
    "buracarás": "buracar",
    "buracarão": "buracar",
    "buracaríamos": "buracar",
    "buracaríeis": "buracar",
    "buracas": "buracar",
    "buracasse": "buracar",
    "buracassem": "buracar",
    "buracasses": "buracar",
    "buracaste": "buracar",
    "buracastes": "buracar",
    "buracava": "buracar",
    "buracavam": "buracar",
    "buracavas": "buracar",
    "buraco": "buracar",
    "buracos": "buraco",
    "buracou": "buracar",
    "buracá": "buracar",
    "buracámo": "buracar",
    "buracámos": "buracar",
    "buracáramo": "buracar",
    "buracáramos": "buracar",
    "buracárei": "buracar",
    "buracáreis": "buracar",
    "buracásseis": "buracar",
    "buracássemos": "buracar",
    "buracávamo": "buracar",
    "buracávamos": "buracar",
    "buracávei": "buracar",
    "buracáveis": "buracar",
    "buracões": "buracão",
    "buraque": "buracar",
    "buraquei": "buracar",
    "buraqueira": "buraqueiro",
    "buraqueiras": "buraqueiro",
    "buraqueiros": "buraqueiro",
    "buraqueis": "buracar",
    "buraquem": "buracar",
    "buraquemo": "buracar",
    "buraquemos": "buracar",
    "buraques": "buracar",
    "buraquinho": "buraco",
    "buraquinhos": "buraco",
    "buraquito": "buraco",
    "buraquitos": "buraco",
    "buratos": "burato",
    "burbureja": "burburejar",
    "burburejada": "burburejar",
    "burburejadas": "burburejar",
    "burburejado": "burburejar",
    "burburejados": "burburejar",
    "burburejai": "burburejar",
    "burburejais": "burburejar",
    "burburejam": "burburejar",
    "burburejamo": "burburejar",
    "burburejamos": "burburejar",
    "burburejando": "burburejar",
    "burburejara": "burburejar",
    "burburejaram": "burburejar",
    "burburejaras": "burburejar",
    "burburejardes": "burburejar",
    "burburejarei": "burburejar",
    "burburejareis": "burburejar",
    "burburejarem": "burburejar",
    "burburejaremos": "burburejar",
    "burburejares": "burburejar",
    "burburejaria": "burburejar",
    "burburejariam": "burburejar",
    "burburejarias": "burburejar",
    "burburejarmo": "burburejar",
    "burburejarmos": "burburejar",
    "burburejará": "burburejar",
    "burburejarás": "burburejar",
    "burburejarão": "burburejar",
    "burburejaríamos": "burburejar",
    "burburejaríeis": "burburejar",
    "burburejas": "burburejar",
    "burburejasse": "burburejar",
    "burburejassem": "burburejar",
    "burburejasses": "burburejar",
    "burburejaste": "burburejar",
    "burburejastes": "burburejar",
    "burburejava": "burburejar",
    "burburejavam": "burburejar",
    "burburejavas": "burburejar",
    "burbureje": "burburejar",
    "burburejei": "burburejar",
    "burburejeis": "burburejar",
    "burburejem": "burburejar",
    "burburejemo": "burburejar",
    "burburejemos": "burburejar",
    "burburejes": "burburejar",
    "burburejo": "burburejar",
    "burburejou": "burburejar",
    "burburejámo": "burburejar",
    "burburejámos": "burburejar",
    "burburejáramo": "burburejar",
    "burburejáramos": "burburejar",
    "burburejáreis": "burburejar",
    "burburejásseis": "burburejar",
    "burburejássemos": "burburejar",
    "burburejávamo": "burburejar",
    "burburejávamos": "burburejar",
    "burburejáveis": "burburejar",
    "burburija": "burburijar",
    "burburijada": "burburijar",
    "burburijadas": "burburijar",
    "burburijado": "burburijar",
    "burburijados": "burburijar",
    "burburijai": "burburijar",
    "burburijais": "burburijar",
    "burburijam": "burburijar",
    "burburijamo": "burburijar",
    "burburijamos": "burburijar",
    "burburijando": "burburijar",
    "burburijara": "burburijar",
    "burburijaram": "burburijar",
    "burburijaras": "burburijar",
    "burburijardes": "burburijar",
    "burburijarei": "burburijar",
    "burburijareis": "burburijar",
    "burburijarem": "burburijar",
    "burburijaremos": "burburijar",
    "burburijares": "burburijar",
    "burburijaria": "burburijar",
    "burburijariam": "burburijar",
    "burburijarias": "burburijar",
    "burburijarmo": "burburijar",
    "burburijarmos": "burburijar",
    "burburijará": "burburijar",
    "burburijarás": "burburijar",
    "burburijarão": "burburijar",
    "burburijaríamos": "burburijar",
    "burburijaríeis": "burburijar",
    "burburijas": "burburijar",
    "burburijasse": "burburijar",
    "burburijassem": "burburijar",
    "burburijasses": "burburijar",
    "burburijaste": "burburijar",
    "burburijastes": "burburijar",
    "burburijava": "burburijar",
    "burburijavam": "burburijar",
    "burburijavas": "burburijar",
    "burburije": "burburijar",
    "burburijei": "burburijar",
    "burburijeis": "burburijar",
    "burburijem": "burburijar",
    "burburijemo": "burburijar",
    "burburijemos": "burburijar",
    "burburijes": "burburijar",
    "burburijo": "burburijar",
    "burburijou": "burburijar",
    "burburijámo": "burburijar",
    "burburijámos": "burburijar",
    "burburijáramo": "burburijar",
    "burburijáramos": "burburijar",
    "burburijáreis": "burburijar",
    "burburijásseis": "burburijar",
    "burburijássemos": "burburijar",
    "burburijávamo": "burburijar",
    "burburijávamos": "burburijar",
    "burburijáveis": "burburijar",
    "burburinha": "burburinhar",
    "burburinhada": "burburinhar",
    "burburinhadas": "burburinhar",
    "burburinhado": "burburinhar",
    "burburinhados": "burburinhar",
    "burburinhai": "burburinhar",
    "burburinhais": "burburinhar",
    "burburinham": "burburinhar",
    "burburinhamo": "burburinhar",
    "burburinhamos": "burburinhar",
    "burburinhando": "burburinhar",
    "burburinhara": "burburinhar",
    "burburinharam": "burburinhar",
    "burburinharas": "burburinhar",
    "burburinhardes": "burburinhar",
    "burburinharei": "burburinhar",
    "burburinhareis": "burburinhar",
    "burburinharem": "burburinhar",
    "burburinharemos": "burburinhar",
    "burburinhares": "burburinhar",
    "burburinharia": "burburinhar",
    "burburinhariam": "burburinhar",
    "burburinharias": "burburinhar",
    "burburinharmo": "burburinhar",
    "burburinharmos": "burburinhar",
    "burburinhará": "burburinhar",
    "burburinharás": "burburinhar",
    "burburinharão": "burburinhar",
    "burburinharíamos": "burburinhar",
    "burburinharíeis": "burburinhar",
    "burburinhas": "burburinhar",
    "burburinhasse": "burburinhar",
    "burburinhassem": "burburinhar",
    "burburinhasses": "burburinhar",
    "burburinhaste": "burburinhar",
    "burburinhastes": "burburinhar",
    "burburinhava": "burburinhar",
    "burburinhavam": "burburinhar",
    "burburinhavas": "burburinhar",
    "burburinhe": "burburinhar",
    "burburinhei": "burburinhar",
    "burburinheis": "burburinhar",
    "burburinhem": "burburinhar",
    "burburinhemo": "burburinhar",
    "burburinhemos": "burburinhar",
    "burburinhes": "burburinhar",
    "burburinho": "burburinhar",
    "burburinhos": "burburinho",
    "burburinhou": "burburinhar",
    "burburinhámo": "burburinhar",
    "burburinhámos": "burburinhar",
    "burburinháramo": "burburinhar",
    "burburinháramos": "burburinhar",
    "burburinháreis": "burburinhar",
    "burburinhásseis": "burburinhar",
    "burburinhássemos": "burburinhar",
    "burburinhávamo": "burburinhar",
    "burburinhávamos": "burburinhar",
    "burburinháveis": "burburinhar",
    "burdangas": "burdanga",
    "burdigaliana": "burdigaliano",
    "burdigalianas": "burdigaliano",
    "burdigalianos": "burdigaliano",
    "burelada": "burelado",
    "bureladas": "burelado",
    "burelados": "burelado",
    "burelinas": "burelina",
    "buretas": "bureta",
    "burgalhões": "burgalhão",
    "burgaudinas": "burgaudina",
    "burgaus": "burgau",
    "burgessa": "burgesso",
    "burgessas": "burgesso",
    "burgessos": "burgesso",
    "burgomestra": "burgomestre",
    "burgomestras": "burgomestre",
    "burgomestres": "burgomestre",
    "burgos": "burgo",
    "burgravados": "burgravado",
    "burgraves": "burgrave",
    "burguesa": "burguês",
    "burguesas": "burguês",
    "burgueses": "burguês",
    "burguesias": "burguesia",
    "burguesismos": "burguesismo",
    "burguinhões": "burguinhão",
    "burila": "burilar",
    "burilada": "burilar",
    "buriladas": "burilar",
    "buriladeira": "burilador",
    "buriladeiras": "burilador",
    "burilado": "burilar",
    "buriladora": "burilador",
    "buriladoras": "burilador",
    "buriladores": "burilador",
    "burilados": "burilar",
    "burilai": "burilar",
    "burilais": "burilar",
    "burilam": "burilar",
    "burilamo": "burilar",
    "burilamos": "burilar",
    "burilando": "burilar",
    "burilara": "burilar",
    "burilaram": "burilar",
    "burilaras": "burilar",
    "burilarde": "burilar",
    "burilardes": "burilar",
    "burilare": "burilar",
    "burilarei": "burilar",
    "burilareis": "burilar",
    "burilarem": "burilar",
    "burilaremos": "burilar",
    "burilares": "burilar",
    "burilaria": "burilar",
    "burilariam": "burilar",
    "burilarias": "burilar",
    "burilarmo": "burilar",
    "burilarmos": "burilar",
    "burilará": "burilar",
    "burilarás": "burilar",
    "burilarão": "burilar",
    "burilaríamos": "burilar",
    "burilaríeis": "burilar",
    "burilas": "burilar",
    "burilasse": "burilar",
    "burilassem": "burilar",
    "burilasses": "burilar",
    "burilaste": "burilar",
    "burilastes": "burilar",
    "burilava": "burilar",
    "burilavam": "burilar",
    "burilavas": "burilar",
    "burile": "burilar",
    "burilei": "burilar",
    "burileis": "burilar",
    "burilem": "burilar",
    "burilemo": "burilar",
    "burilemos": "burilar",
    "buriles": "burilar",
    "burilo": "burilar",
    "burilou": "burilar",
    "burilá": "burilar",
    "burilámo": "burilar",
    "burilámos": "burilar",
    "buriláramo": "burilar",
    "buriláramos": "burilar",
    "burilárei": "burilar",
    "buriláreis": "burilar",
    "burilásseis": "burilar",
    "burilássemos": "burilar",
    "burilávamo": "burilar",
    "burilávamos": "burilar",
    "burilávei": "burilar",
    "buriláveis": "burilar",
    "buris": "buril",
    "buritizadas": "buritizada",
    "buritizais": "buritizal",
    "buriéis": "buriel",
    "burjacas": "burjaca",
    "burjassotes": "burjassote",
    "burla": "burlar",
    "burlada": "burlar",
    "burladas": "burlar",
    "burlado": "burlar",
    "burladora": "burlador",
    "burladoras": "burlador",
    "burladores": "burlador",
    "burlados": "burlar",
    "burlai": "burlar",
    "burlais": "burlar",
    "burlam": "burlar",
    "burlamo": "burlar",
    "burlamos": "burlar",
    "burlando": "burlar",
    "burlara": "burlar",
    "burlaram": "burlar",
    "burlaras": "burlar",
    "burlarde": "burlar",
    "burlardes": "burlar",
    "burlare": "burlar",
    "burlarei": "burlar",
    "burlareis": "burlar",
    "burlarem": "burlar",
    "burlaremos": "burlar",
    "burlares": "burlar",
    "burlaria": "burlar",
    "burlariam": "burlar",
    "burlarias": "burlar",
    "burlarmo": "burlar",
    "burlarmos": "burlar",
    "burlará": "burlar",
    "burlarás": "burlar",
    "burlarão": "burlar",
    "burlaríamos": "burlar",
    "burlaríeis": "burlar",
    "burlas": "burlar",
    "burlasse": "burlar",
    "burlassem": "burlar",
    "burlasses": "burlar",
    "burlaste": "burlar",
    "burlastes": "burlar",
    "burlava": "burlar",
    "burlavam": "burlar",
    "burlavas": "burlar",
    "burle": "burlar",
    "burlei": "burlar",
    "burleis": "burlar",
    "burlem": "burlar",
    "burlemo": "burlar",
    "burlemos": "burlar",
    "burles": "burlar",
    "burlesca": "burlesco",
    "burlescas": "burlesco",
    "burlescos": "burlesco",
    "burlesqueada": "burlesquear",
    "burlesqueadas": "burlesquear",
    "burlesqueado": "burlesquear",
    "burlesqueados": "burlesquear",
    "burlesqueai": "burlesquear",
    "burlesqueais": "burlesquear",
    "burlesqueamo": "burlesquear",
    "burlesqueamos": "burlesquear",
    "burlesqueando": "burlesquear",
    "burlesqueara": "burlesquear",
    "burlesquearam": "burlesquear",
    "burlesquearas": "burlesquear",
    "burlesqueardes": "burlesquear",
    "burlesquearei": "burlesquear",
    "burlesqueareis": "burlesquear",
    "burlesquearem": "burlesquear",
    "burlesquearemos": "burlesquear",
    "burlesqueares": "burlesquear",
    "burlesquearia": "burlesquear",
    "burlesqueariam": "burlesquear",
    "burlesquearias": "burlesquear",
    "burlesquearmo": "burlesquear",
    "burlesquearmos": "burlesquear",
    "burlesqueará": "burlesquear",
    "burlesquearás": "burlesquear",
    "burlesquearão": "burlesquear",
    "burlesquearíamos": "burlesquear",
    "burlesquearíeis": "burlesquear",
    "burlesqueasse": "burlesquear",
    "burlesqueassem": "burlesquear",
    "burlesqueasses": "burlesquear",
    "burlesqueaste": "burlesquear",
    "burlesqueastes": "burlesquear",
    "burlesqueava": "burlesquear",
    "burlesqueavam": "burlesquear",
    "burlesqueavas": "burlesquear",
    "burlesqueei": "burlesquear",
    "burlesqueeis": "burlesquear",
    "burlesqueemo": "burlesquear",
    "burlesqueemos": "burlesquear",
    "burlesqueia": "burlesquear",
    "burlesqueiam": "burlesquear",
    "burlesqueias": "burlesquear",
    "burlesqueie": "burlesquear",
    "burlesqueiem": "burlesquear",
    "burlesqueies": "burlesquear",
    "burlesqueio": "burlesquear",
    "burlesqueou": "burlesquear",
    "burlesqueámo": "burlesquear",
    "burlesqueámos": "burlesquear",
    "burlesqueáramo": "burlesquear",
    "burlesqueáramos": "burlesquear",
    "burlesqueáreis": "burlesquear",
    "burlesqueásseis": "burlesquear",
    "burlesqueássemos": "burlesquear",
    "burlesqueávamo": "burlesquear",
    "burlesqueávamos": "burlesquear",
    "burlesqueáveis": "burlesquear",
    "burletas": "burleta",
    "burlistas": "burlista",
    "burlo": "burlar",
    "burlona": "burlão",
    "burlonas": "burlão",
    "burlosa": "burloso",
    "burlosas": "burloso",
    "burlosos": "burloso",
    "burlou": "burlar",
    "burlá": "burlar",
    "burlámo": "burlar",
    "burlámos": "burlar",
    "burláramo": "burlar",
    "burláramos": "burlar",
    "burlárei": "burlar",
    "burláreis": "burlar",
    "burlásseis": "burlar",
    "burlássemos": "burlar",
    "burlávamo": "burlar",
    "burlávamos": "burlar",
    "burlávei": "burlar",
    "burláveis": "burlável",
    "burlões": "burlão",
    "burneira": "burneiro",
    "burneiras": "burneiro",
    "burneiros": "burneiro",
    "burocracias": "burocracia",
    "burocracismos": "burocracismo",
    "burocratas": "burocrata",
    "burocratismos": "burocratismo",
    "burocratiza": "burocratizar",
    "burocratizada": "burocratizar",
    "burocratizadas": "burocratizar",
    "burocratizado": "burocratizar",
    "burocratizados": "burocratizar",
    "burocratizai": "burocratizar",
    "burocratizais": "burocratizar",
    "burocratizam": "burocratizar",
    "burocratizamo": "burocratizar",
    "burocratizamos": "burocratizar",
    "burocratizando": "burocratizar",
    "burocratizara": "burocratizar",
    "burocratizaram": "burocratizar",
    "burocratizaras": "burocratizar",
    "burocratizarde": "burocratizar",
    "burocratizardes": "burocratizar",
    "burocratizare": "burocratizar",
    "burocratizarei": "burocratizar",
    "burocratizareis": "burocratizar",
    "burocratizarem": "burocratizar",
    "burocratizaremos": "burocratizar",
    "burocratizares": "burocratizar",
    "burocratizaria": "burocratizar",
    "burocratizariam": "burocratizar",
    "burocratizarias": "burocratizar",
    "burocratizarmo": "burocratizar",
    "burocratizarmos": "burocratizar",
    "burocratizará": "burocratizar",
    "burocratizarás": "burocratizar",
    "burocratizarão": "burocratizar",
    "burocratizaríamos": "burocratizar",
    "burocratizaríeis": "burocratizar",
    "burocratizas": "burocratizar",
    "burocratizasse": "burocratizar",
    "burocratizassem": "burocratizar",
    "burocratizasses": "burocratizar",
    "burocratizaste": "burocratizar",
    "burocratizastes": "burocratizar",
    "burocratizava": "burocratizar",
    "burocratizavam": "burocratizar",
    "burocratizavas": "burocratizar",
    "burocratizações": "burocratização",
    "burocratize": "burocratizar",
    "burocratizei": "burocratizar",
    "burocratizeis": "burocratizar",
    "burocratizem": "burocratizar",
    "burocratizemo": "burocratizar",
    "burocratizemos": "burocratizar",
    "burocratizes": "burocratizar",
    "burocratizo": "burocratizar",
    "burocratizou": "burocratizar",
    "burocratizá": "burocratizar",
    "burocratizámo": "burocratizar",
    "burocratizámos": "burocratizar",
    "burocratizáramo": "burocratizar",
    "burocratizáramos": "burocratizar",
    "burocratizárei": "burocratizar",
    "burocratizáreis": "burocratizar",
    "burocratizásseis": "burocratizar",
    "burocratizássemos": "burocratizar",
    "burocratizávamo": "burocratizar",
    "burocratizávamos": "burocratizar",
    "burocratizávei": "burocratizar",
    "burocratizáveis": "burocratizar",
    "burocrática": "burocrático",
    "burocráticas": "burocrático",
    "burocráticos": "burocrático",
    "burra": "burro",
    "burradas": "burrada",
    "burragens": "burragem",
    "burrancas": "burranca",
    "burras": "burro",
    "burreca": "burreco",
    "burrecas": "burreco",
    "burrecos": "burreco",
    "burrega": "burrego",
    "burregas": "burrego",
    "burregos": "burrego",
    "burrica": "burrico",
    "burricadas": "burricada",
    "burricas": "burrico",
    "burrices": "burrice",
    "burricos": "burrico",
    "burrifica": "burrificar",
    "burrificada": "burrificar",
    "burrificadas": "burrificar",
    "burrificado": "burrificar",
    "burrificados": "burrificar",
    "burrificai": "burrificar",
    "burrificais": "burrificar",
    "burrificam": "burrificar",
    "burrificamo": "burrificar",
    "burrificamos": "burrificar",
    "burrificando": "burrificar",
    "burrificara": "burrificar",
    "burrificaram": "burrificar",
    "burrificaras": "burrificar",
    "burrificarde": "burrificar",
    "burrificardes": "burrificar",
    "burrificare": "burrificar",
    "burrificarei": "burrificar",
    "burrificareis": "burrificar",
    "burrificarem": "burrificar",
    "burrificaremos": "burrificar",
    "burrificares": "burrificar",
    "burrificaria": "burrificar",
    "burrificariam": "burrificar",
    "burrificarias": "burrificar",
    "burrificarmo": "burrificar",
    "burrificarmos": "burrificar",
    "burrificará": "burrificar",
    "burrificarás": "burrificar",
    "burrificarão": "burrificar",
    "burrificaríamos": "burrificar",
    "burrificaríeis": "burrificar",
    "burrificas": "burrificar",
    "burrificasse": "burrificar",
    "burrificassem": "burrificar",
    "burrificasses": "burrificar",
    "burrificaste": "burrificar",
    "burrificastes": "burrificar",
    "burrificava": "burrificar",
    "burrificavam": "burrificar",
    "burrificavas": "burrificar",
    "burrifico": "burrificar",
    "burrificou": "burrificar",
    "burrificá": "burrificar",
    "burrificámo": "burrificar",
    "burrificámos": "burrificar",
    "burrificáramo": "burrificar",
    "burrificáramos": "burrificar",
    "burrificárei": "burrificar",
    "burrificáreis": "burrificar",
    "burrificásseis": "burrificar",
    "burrificássemos": "burrificar",
    "burrificávamo": "burrificar",
    "burrificávamos": "burrificar",
    "burrificávei": "burrificar",
    "burrificáveis": "burrificar",
    "burrifique": "burrificar",
    "burrifiquei": "burrificar",
    "burrifiqueis": "burrificar",
    "burrifiquem": "burrificar",
    "burrifiquemo": "burrificar",
    "burrifiquemos": "burrificar",
    "burrifiques": "burrificar",
    "burrinha": "burro",
    "burrinhas": "burro",
    "burrinho": "burro",
    "burrinhos": "burro",
    "burriqueira": "burriqueiro",
    "burriqueiras": "burriqueiro",
    "burriqueiros": "burriqueiro",
    "burrita": "burro",
    "burritas": "burro",
    "burrito": "burro",
    "burritos": "burro",
    "burriés": "burrié",
    "burrocracias": "burrocracia",
    "burrona": "burrão",
    "burronas": "burrão",
    "burros": "burro",
    "burrões": "burrão",
    "bursites": "bursite",
    "burundiana": "burundiano",
    "burundianas": "burundiano",
    "burundianos": "burundiano",
    "burundinesa": "burundinês",
    "burundinesas": "burundinês",
    "burundineses": "burundinês",
    "bururus": "bururu",
    "burusos": "buruso",
    "burussos": "burusso",
    "burzigadas": "burzigada",
    "buréis": "burel",
    "burés": "buré",
    "busanos": "busano",
    "busaranhos": "busaranho",
    "busardos": "busardo",
    "busca": "buscar",
    "buscada": "buscar",
    "buscadas": "buscar",
    "buscadeira": "buscador",
    "buscadeiras": "buscador",
    "buscado": "buscar",
    "buscadora": "buscador",
    "buscadoras": "buscador",
    "buscadores": "buscador",
    "buscados": "buscar",
    "buscai": "buscar",
    "buscais": "buscar",
    "buscam": "buscar",
    "buscamo": "buscar",
    "buscamos": "buscar",
    "buscando": "buscar",
    "buscantes": "buscante",
    "buscara": "buscar",
    "buscaram": "buscar",
    "buscaras": "buscar",
    "buscarde": "buscar",
    "buscardes": "buscar",
    "buscare": "buscar",
    "buscarei": "buscar",
    "buscareis": "buscar",
    "buscarem": "buscar",
    "buscaremos": "buscar",
    "buscares": "buscar",
    "buscaria": "buscar",
    "buscariam": "buscar",
    "buscarias": "buscar",
    "buscarmo": "buscar",
    "buscarmos": "buscar",
    "buscará": "buscar",
    "buscarás": "buscar",
    "buscarão": "buscar",
    "buscaríamos": "buscar",
    "buscaríeis": "buscar",
    "buscas": "buscar",
    "buscasse": "buscar",
    "buscassem": "buscar",
    "buscasses": "buscar",
    "buscaste": "buscar",
    "buscastes": "buscar",
    "buscava": "buscar",
    "buscavam": "buscar",
    "buscavas": "buscar",
    "busco": "buscar",
    "buscou": "buscar",
    "buscá": "buscar",
    "buscámo": "buscar",
    "buscámos": "buscar",
    "buscáramo": "buscar",
    "buscáramos": "buscar",
    "buscárei": "buscar",
    "buscáreis": "buscar",
    "buscásseis": "buscar",
    "buscássemos": "buscar",
    "buscávamo": "buscar",
    "buscávamos": "buscar",
    "buscávei": "buscar",
    "buscáveis": "buscar",
    "buseiras": "buseira",
    "buseiros": "buseiro",
    "buserácea": "buseráceo",
    "buseráceas": "buseráceo",
    "buseráceos": "buseráceo",
    "busque": "buscar",
    "busquei": "buscar",
    "busqueis": "buscar",
    "busquem": "buscar",
    "busquemo": "buscar",
    "busquemos": "buscar",
    "busques": "buscar",
    "bustos": "busto",
    "bustuários": "bustuário",
    "butana": "butano",
    "butanas": "butano",
    "butanos": "butano",
    "butenos": "buteno",
    "butes": "bute",
    "butilos": "butilo",
    "butins": "butim",
    "butiques": "butique",
    "butiradas": "butirada",
    "butirinas": "butirina",
    "butirosa": "butiroso",
    "butirosas": "butiroso",
    "butirosos": "butiroso",
    "butirácea": "butiráceo",
    "butiráceas": "butiráceo",
    "butiráceos": "butiráceo",
    "butirómetros": "butirómetro",
    "butomáceas": "butomácea",
    "butuas": "butua",
    "butuca": "butucar",
    "butucada": "butucar",
    "butucadas": "butucar",
    "butucado": "butucar",
    "butucados": "butucar",
    "butucai": "butucar",
    "butucais": "butucar",
    "butucam": "butucar",
    "butucamo": "butucar",
    "butucamos": "butucar",
    "butucando": "butucar",
    "butucara": "butucar",
    "butucaram": "butucar",
    "butucaras": "butucar",
    "butucarde": "butucar",
    "butucardes": "butucar",
    "butucare": "butucar",
    "butucarei": "butucar",
    "butucareis": "butucar",
    "butucarem": "butucar",
    "butucaremos": "butucar",
    "butucares": "butucar",
    "butucaria": "butucar",
    "butucariam": "butucar",
    "butucarias": "butucar",
    "butucarmo": "butucar",
    "butucarmos": "butucar",
    "butucará": "butucar",
    "butucarás": "butucar",
    "butucarão": "butucar",
    "butucaríamos": "butucar",
    "butucaríeis": "butucar",
    "butucas": "butucar",
    "butucasse": "butucar",
    "butucassem": "butucar",
    "butucasses": "butucar",
    "butucaste": "butucar",
    "butucastes": "butucar",
    "butucava": "butucar",
    "butucavam": "butucar",
    "butucavas": "butucar",
    "butuco": "butucar",
    "butucou": "butucar",
    "butucá": "butucar",
    "butucámo": "butucar",
    "butucámos": "butucar",
    "butucáramo": "butucar",
    "butucáramos": "butucar",
    "butucárei": "butucar",
    "butucáreis": "butucar",
    "butucásseis": "butucar",
    "butucássemos": "butucar",
    "butucávamo": "butucar",
    "butucávamos": "butucar",
    "butucávei": "butucar",
    "butucáveis": "butucar",
    "butuque": "butucar",
    "butuquei": "butucar",
    "butuqueis": "butucar",
    "butuquem": "butucar",
    "butuquemo": "butucar",
    "butuquemos": "butucar",
    "butuques": "butucar",
    "butílios": "butílio",
    "butírica": "butírico",
    "butíricas": "butírico",
    "butíricos": "butírico",
    "buxais": "buxal",
    "buxeiras": "buxeira",
    "buxeiros": "buxeiro",
    "buxetes": "buxete",
    "buxos": "buxo",
    "buxácea": "buxáceo",
    "buxáceas": "buxáceo",
    "buxáceos": "buxáceo",
    "buzarates": "buzarate",
    "buzilhões": "buzilhão",
    "buzina": "buzinar",
    "buzinada": "buzinar",
    "buzinadas": "buzinar",
    "buzinadelas": "buzinadela",
    "buzinado": "buzinar",
    "buzinados": "buzinar",
    "buzinai": "buzinar",
    "buzinais": "buzinar",
    "buzinam": "buzinar",
    "buzinamo": "buzinar",
    "buzinamos": "buzinar",
    "buzinando": "buzinar",
    "buzinara": "buzinar",
    "buzinaram": "buzinar",
    "buzinaras": "buzinar",
    "buzinarde": "buzinar",
    "buzinardes": "buzinar",
    "buzinare": "buzinar",
    "buzinarei": "buzinar",
    "buzinareis": "buzinar",
    "buzinarem": "buzinar",
    "buzinaremos": "buzinar",
    "buzinares": "buzinar",
    "buzinaria": "buzinar",
    "buzinariam": "buzinar",
    "buzinarias": "buzinar",
    "buzinarmo": "buzinar",
    "buzinarmos": "buzinar",
    "buzinará": "buzinar",
    "buzinarás": "buzinar",
    "buzinarão": "buzinar",
    "buzinaríamos": "buzinar",
    "buzinaríeis": "buzinar",
    "buzinas": "buzinar",
    "buzinasse": "buzinar",
    "buzinassem": "buzinar",
    "buzinasses": "buzinar",
    "buzinaste": "buzinar",
    "buzinastes": "buzinar",
    "buzinava": "buzinar",
    "buzinavam": "buzinar",
    "buzinavas": "buzinar",
    "buzinações": "buzinação",
    "buzine": "buzinar",
    "buzinei": "buzinar",
    "buzineis": "buzinar",
    "buzinem": "buzinar",
    "buzinemo": "buzinar",
    "buzinemos": "buzinar",
    "buzines": "buzinar",
    "buzino": "buzinar",
    "buzinou": "buzinar",
    "buziná": "buzinar",
    "buzinámo": "buzinar",
    "buzinámos": "buzinar",
    "buzináramo": "buzinar",
    "buzináramos": "buzinar",
    "buzinárei": "buzinar",
    "buzináreis": "buzinar",
    "buzinásseis": "buzinar",
    "buzinássemos": "buzinar",
    "buzinávamo": "buzinar",
    "buzinávamos": "buzinar",
    "buzinávei": "buzinar",
    "buzináveis": "buzinar",
    "buzinões": "buzinão",
    "buços": "buço",
    "buí": "buir",
    "buía": "buir",
    "buíam": "buir",
    "buíamo": "buir",
    "buíamos": "buir",
    "buías": "buir",
    "buída": "buir",
    "buídas": "buir",
    "buído": "buir",
    "buídos": "buir",
    "buíei": "buir",
    "buíeis": "buir",
    "buímo": "buir",
    "buímos": "buir",
    "buíra": "buir",
    "buíram": "buir",
    "buíramo": "buir",
    "buíramos": "buir",
    "buíras": "buir",
    "buíre": "buir",
    "buírei": "buir",
    "buíreis": "buir",
    "buírem": "buir",
    "buíres": "buir",
    "buís": "buir",
    "buísse": "buir",
    "buísseis": "buir",
    "buíssem": "buir",
    "buíssemos": "buir",
    "buísses": "buir",
    "buíste": "buir",
    "buístes": "buir",
    "byroniana": "byroniano",
    "byronianas": "byroniano",
    "byronianos": "byroniano",
    "bácaros": "bácaro",
    "bácora": "bácoro",
    "bácoras": "bácoro",
    "bácoros": "bácoro",
    "báculos": "báculo",
    "bálanos": "bálano",
    "bálsamos": "bálsamo",
    "báltica": "báltico",
    "bálticas": "báltico",
    "bálticos": "báltico",
    "báquica": "báquico",
    "báquicas": "báquico",
    "báquicos": "báquico",
    "báquios": "báquio",
    "báratros": "báratro",
    "bárbara": "bárbaro",
    "bárbaras": "bárbaro",
    "bárbaros": "bárbaro",
    "bárbulas": "bárbula",
    "bárdica": "bárdico",
    "bárdicas": "bárdico",
    "bárdicos": "bárdico",
    "bárias": "bária",
    "bárica": "bárico",
    "báricas": "bárico",
    "báricos": "bárico",
    "básculas": "báscula",
    "básculos": "básculo",
    "báseos": "báseo",
    "básica": "básico",
    "básicas": "básico",
    "básicos": "básico",
    "básquetes": "básquete",
    "bátegas": "bátega",
    "bávara": "bávaro",
    "bávaras": "bávaro",
    "bávaros": "bávaro",
    "bécuas": "bécua",
    "bédulos": "bédulo",
    "bélbutes": "bélbute",
    "bélica": "bélico",
    "bélicas": "bélico",
    "bélicos": "bélico",
    "béquica": "béquico",
    "béquicas": "béquico",
    "béquicos": "béquico",
    "bérnios": "bérnio",
    "béstias": "béstia",
    "bételes": "bétele",
    "bética": "bético",
    "béticas": "bético",
    "béticos": "bético",
    "bétulas": "bétula",
    "bétéis": "bétel",
    "béus": "béu",
    "bêbada": "bêbado",
    "bêbadas": "bêbado",
    "bêbados": "bêbado",
    "bêbeda": "bêbedo",
    "bêbedas": "bêbedo",
    "bêbedos": "bêbedo",
    "bêberas": "bêbera",
    "bênçãos": "bênção",
    "bês": "bê",
    "bíblias": "bíblia",
    "bíblica": "bíblico",
    "bíblicas": "bíblico",
    "bíblicos": "bíblico",
    "bíbula": "bíbulo",
    "bíbulas": "bíbulo",
    "bíbulos": "bíbulo",
    "bícroma": "bícromo",
    "bícromas": "bícromo",
    "bícromos": "bícromo",
    "bíduos": "bíduo",
    "bífera": "bífero",
    "bíferas": "bífero",
    "bíferos": "bífero",
    "bífida": "bífido",
    "bífidas": "bífido",
    "bífidos": "bífido",
    "bífores": "bífore",
    "bígama": "bígamo",
    "bígamas": "bígamo",
    "bígamos": "bígamo",
    "bíjuga": "bíjugo",
    "bíjugas": "bíjugo",
    "bíjugos": "bíjugo",
    "bímana": "bímano",
    "bímanas": "bímano",
    "bímanos": "bímano",
    "bínuba": "bínubo",
    "bínubas": "bínubo",
    "bínubos": "bínubo",
    "bípara": "bíparo",
    "bíparas": "bíparo",
    "bíparos": "bíparo",
    "bípedes": "bípede",
    "bípenes": "bípene",
    "bísara": "bísaro",
    "bísaras": "bísaro",
    "bísaros": "bísaro",
    "bívia": "bívio",
    "bívias": "bívio",
    "bívios": "bívio",
    "bócios": "bócio",
    "bóeres": "bóer",
    "bóers": "bóer",
    "bófias": "bófia",
    "bóia": "boiar",
    "bóiam": "boiar",
    "bóias": "boiar",
    "bóie": "boiar",
    "bóiem": "boiar",
    "bóies": "boiar",
    "bóio": "boiar",
    "bólides": "bólide",
    "bólidos": "bólido",
    "bóraces": "bórace",
    "bóraxes": "bóraxe",
    "bóreas": "bórea",
    "bórica": "bórico",
    "bóricas": "bórico",
    "bóricos": "bórico",
    "bósnia": "bósnio",
    "bósnias": "bósnio",
    "bósnios": "bósnio",
    "bóstunes": "bóstune",
    "bóvidas": "bóvida",
    "bóxers": "bóxer",
    "bômbaxes": "bômbax",
    "búbalos": "búbalo",
    "búdica": "búdico",
    "búdicas": "búdico",
    "búdicos": "búdico",
    "búfalos": "búfalo",
    "búgulas": "búgula",
    "búlgara": "búlgaro",
    "búlgaras": "búlgaro",
    "búlgaros": "búlgaro",
    "bússolas": "bússola",
    "búteos": "búteo",
    "bútios": "bútio",
    "búzeras": "búzera",
    "búzios": "búzio",
    "cabaceiras": "cabaceira",
    "cabaceiros": "cabaceiro",
    "cabacinha": "cabaça",
    "cabacinhas": "cabacinha",
    "cabacinho": "cabaço",
    "cabacinhos": "cabaço",
    "cabacita": "cabaça",
    "cabacitas": "cabaça",
    "cabacito": "cabaço",
    "cabacitos": "cabaço",
    "cabaias": "cabaia",
    "cabais": "cabal",
    "cabalas": "cabala",
    "cabaletas": "cabaleta",
    "cabalina": "cabalino",
    "cabalinas": "cabalino",
    "cabalinos": "cabalino",
    "cabalistas": "cabalista",
    "cabalística": "cabalístico",
    "cabalísticas": "cabalístico",
    "cabalísticos": "cabalístico",
    "cabana": "cabano",
    "cabanadas": "cabanada",
    "cabanagens": "cabanagem",
    "cabanais": "cabanal",
    "cabanas": "cabano",
    "cabaneiros": "cabaneiro",
    "cabanejos": "cabanejo",
    "cabanhas": "cabanha",
    "cabanilhos": "cabanilho",
    "cabaninha": "cabana",
    "cabaninhas": "cabana",
    "cabanis": "cabanil",
    "cabanita": "cabana",
    "cabanitas": "cabana",
    "cabanos": "cabano",
    "cabanéis": "cabanel",
    "cabaralistas": "cabaralista",
    "cabareteira": "cabareteiro",
    "cabareteiras": "cabareteiro",
    "cabareteiros": "cabareteiro",
    "cabarets": "cabaret",
    "cabarés": "cabaré",
    "cabazadas": "cabazada",
    "cabazeiros": "cabazeiro",
    "cabazes": "cabaz",
    "cabazinho": "cabaz",
    "cabazinhos": "cabaz",
    "cabazito": "cabaz",
    "cabazitos": "cabaz",
    "cabaçadas": "cabaçada",
    "cabaçais": "cabaçal",
    "cabaças": "cabaça",
    "cabaços": "cabaço",
    "cabaçudas": "cabaçuda",
    "cabaçudazinha": "cabaçuda",
    "cabaçudazinhas": "cabaçuda",
    "cabaçudazita": "cabaçuda",
    "cabaçudazitas": "cabaçuda",
    "cabações": "cabação",
    "cabe": "caber",
    "cabeada": "cabear",
    "cabeadas": "cabear",
    "cabeado": "cabear",
    "cabeados": "cabear",
    "cabeai": "cabear",
    "cabeais": "cabear",
    "cabeamo": "cabear",
    "cabeamos": "cabear",
    "cabeando": "cabear",
    "cabeara": "cabear",
    "cabearam": "cabear",
    "cabearas": "cabear",
    "cabeardes": "cabear",
    "cabearei": "cabear",
    "cabeareis": "cabear",
    "cabearem": "cabear",
    "cabearemos": "cabear",
    "cabeares": "cabear",
    "cabearia": "cabear",
    "cabeariam": "cabear",
    "cabearias": "cabear",
    "cabearmo": "cabear",
    "cabearmos": "cabear",
    "cabeará": "cabear",
    "cabearás": "cabear",
    "cabearão": "cabear",
    "cabearíamos": "cabear",
    "cabearíeis": "cabear",
    "cabeasse": "cabear",
    "cabeassem": "cabear",
    "cabeasses": "cabear",
    "cabeaste": "cabear",
    "cabeastes": "cabear",
    "cabeava": "cabear",
    "cabeavam": "cabear",
    "cabeavas": "cabear",
    "cabeceada": "cabecear",
    "cabeceadas": "cabecear",
    "cabeceado": "cabecear",
    "cabeceados": "cabecear",
    "cabeceai": "cabecear",
    "cabeceais": "cabecear",
    "cabeceamentos": "cabeceamento",
    "cabeceamo": "cabecear",
    "cabeceamos": "cabecear",
    "cabeceando": "cabecear",
    "cabeceara": "cabecear",
    "cabecearam": "cabecear",
    "cabecearas": "cabecear",
    "cabeceardes": "cabecear",
    "cabecearei": "cabecear",
    "cabeceareis": "cabecear",
    "cabecearem": "cabecear",
    "cabecearemos": "cabecear",
    "cabeceares": "cabecear",
    "cabecearia": "cabecear",
    "cabeceariam": "cabecear",
    "cabecearias": "cabecear",
    "cabecearmo": "cabecear",
    "cabecearmos": "cabecear",
    "cabeceará": "cabecear",
    "cabecearás": "cabecear",
    "cabecearão": "cabecear",
    "cabecearíamos": "cabecear",
    "cabecearíeis": "cabecear",
    "cabeceasse": "cabecear",
    "cabeceassem": "cabecear",
    "cabeceasses": "cabecear",
    "cabeceaste": "cabecear",
    "cabeceastes": "cabecear",
    "cabeceava": "cabecear",
    "cabeceavam": "cabecear",
    "cabeceavas": "cabecear",
    "cabeceei": "cabecear",
    "cabeceeis": "cabecear",
    "cabeceemo": "cabecear",
    "cabeceemos": "cabecear",
    "cabeceia": "cabecear",
    "cabeceiam": "cabecear",
    "cabeceias": "cabecear",
    "cabeceie": "cabecear",
    "cabeceiem": "cabecear",
    "cabeceies": "cabecear",
    "cabeceio": "cabecear",
    "cabeceios": "cabeceio",
    "cabeceiras": "cabeceira",
    "cabeceirenses": "cabeceirense",
    "cabeceiros": "cabeceiro",
    "cabeceou": "cabecear",
    "cabeceámo": "cabecear",
    "cabeceámos": "cabecear",
    "cabeceáramo": "cabecear",
    "cabeceáramos": "cabecear",
    "cabeceáreis": "cabecear",
    "cabeceásseis": "cabecear",
    "cabeceássemos": "cabecear",
    "cabeceávamo": "cabecear",
    "cabeceávamos": "cabecear",
    "cabeceáveis": "cabecear",
    "cabecilhas": "cabecilha",
    "cabecinha": "cabeça",
    "cabecinhas": "cabecinha",
    "cabecita": "cabeça",
    "cabecitas": "cabeça",
    "cabecéis": "cabecel",
    "cabedais": "cabedal",
    "cabedelos": "cabedelo",
    "cabeei": "cabear",
    "cabeeis": "cabear",
    "cabeemo": "cabear",
    "cabeemos": "cabear",
    "cabei": "caber",
    "cabeia": "cabear",
    "cabeiam": "cabear",
    "cabeias": "cabear",
    "cabeie": "cabear",
    "cabeiem": "cabear",
    "cabeies": "cabear",
    "cabeio": "cabear",
    "cabeira": "cabeiro",
    "cabeiras": "cabeiro",
    "cabeiros": "cabeiro",
    "cabeis": "caber",
    "cabela": "cabelar",
    "cabelada": "cabelar",
    "cabeladas": "cabelar",
    "cabelado": "cabelar",
    "cabelados": "cabelar",
    "cabeladuras": "cabeladura",
    "cabelai": "cabelar",
    "cabelais": "cabelar",
    "cabelam": "cabelar",
    "cabelames": "cabelame",
    "cabelamo": "cabelar",
    "cabelamos": "cabelar",
    "cabelando": "cabelar",
    "cabelara": "cabelar",
    "cabelaram": "cabelar",
    "cabelaras": "cabelar",
    "cabelardes": "cabelar",
    "cabelarei": "cabelar",
    "cabelareis": "cabelar",
    "cabelarem": "cabelar",
    "cabelaremos": "cabelar",
    "cabelares": "cabelar",
    "cabelaria": "cabelar",
    "cabelariam": "cabelar",
    "cabelarias": "cabelar",
    "cabelarmo": "cabelar",
    "cabelarmos": "cabelar",
    "cabelará": "cabelar",
    "cabelarás": "cabelar",
    "cabelarão": "cabelar",
    "cabelaríamos": "cabelar",
    "cabelaríeis": "cabelar",
    "cabelas": "cabelar",
    "cabelasse": "cabelar",
    "cabelassem": "cabelar",
    "cabelasses": "cabelar",
    "cabelaste": "cabelar",
    "cabelastes": "cabelar",
    "cabelava": "cabelar",
    "cabelavam": "cabelar",
    "cabelavas": "cabelar",
    "cabele": "cabelar",
    "cabelei": "cabelar",
    "cabeleiras": "cabeleira",
    "cabeleireira": "cabeleireiro",
    "cabeleireiras": "cabeleireiro",
    "cabeleireiros": "cabeleireiro",
    "cabeleiros": "cabeleiro",
    "cabeleis": "cabelar",
    "cabelem": "cabelar",
    "cabelemo": "cabelar",
    "cabelemos": "cabelar",
    "cabeles": "cabelar",
    "cabelinho": "cabelo",
    "cabelinhos": "cabelo",
    "cabelito": "cabelo",
    "cabelitos": "cabelo",
    "cabelo": "cabelar",
    "cabelos": "cabelo",
    "cabelou": "cabelar",
    "cabeluda": "cabeludo",
    "cabeludas": "cabeludo",
    "cabeludos": "cabeludo",
    "cabelámo": "cabelar",
    "cabelámos": "cabelar",
    "cabeláramo": "cabelar",
    "cabeláramos": "cabelar",
    "cabeláreis": "cabelar",
    "cabelásseis": "cabelar",
    "cabelássemos": "cabelar",
    "cabelávamo": "cabelar",
    "cabelávamos": "cabelar",
    "cabeláveis": "cabelar",
    "cabem": "caber",
    "cabemo": "caber",
    "cabemos": "caber",
    "cabendo": "caber",
    "cabeou": "cabear",
    "caberdes": "caber",
    "caberei": "caber",
    "cabereis": "caber",
    "caberem": "caber",
    "caberemos": "caber",
    "caberes": "caber",
    "caberia": "caber",
    "caberiam": "caber",
    "caberias": "caber",
    "cabermo": "caber",
    "cabermos": "caber",
    "caberá": "caber",
    "caberás": "caber",
    "caberão": "caber",
    "caberíamos": "caber",
    "caberíeis": "caber",
    "cabes": "caber",
    "cabeámo": "cabear",
    "cabeámos": "cabear",
    "cabeáramo": "cabear",
    "cabeáramos": "cabear",
    "cabeáreis": "cabear",
    "cabeásseis": "cabear",
    "cabeássemos": "cabear",
    "cabeávamo": "cabear",
    "cabeávamos": "cabear",
    "cabeáveis": "cabear",
    "cabeçadas": "cabeçada",
    "cabeçais": "cabeçal",
    "cabeçalhas": "cabeçalha",
    "cabeçalhos": "cabeçalho",
    "cabeças": "cabeça",
    "cabeçorras": "cabeçorra",
    "cabeçorros": "cabeçorro",
    "cabeços": "cabeço",
    "cabeçotes": "cabeçote",
    "cabeçuda": "cabeçudo",
    "cabeçudas": "cabeçudo",
    "cabeçudos": "cabeçudo",
    "cabeções": "cabeção",
    "cabia": "caber",
    "cabiam": "caber",
    "cabias": "caber",
    "cabida": "caber",
    "cabidas": "cabida",
    "cabidelas": "cabidela",
    "cabides": "cabide",
    "cabido": "caber",
    "cabidos": "cabido",
    "cabiduais": "cabidual",
    "cabilas": "cabila",
    "cabildas": "cabilda",
    "cabinas": "cabina",
    "cabindas": "cabinda",
    "cabine": "cabina",
    "cabines": "cabina",
    "cabisbaixa": "cabisbaixo",
    "cabisbaixas": "cabisbaixo",
    "cabisbaixos": "cabisbaixo",
    "cabochões": "cabochão",
    "cabocladas": "caboclada",
    "caboilas": "caboila",
    "cabolcla": "cabolclo",
    "cabolclas": "cabolclo",
    "cabolclazinha": "cabolclo",
    "cabolclazinhas": "cabolclo",
    "cabolclazita": "cabolclo",
    "cabolclazitas": "cabolclo",
    "cabolclinha": "cabolclo",
    "cabolclinhas": "cabolclo",
    "cabolclinho": "cabolclo",
    "cabolclinhos": "cabolclo",
    "cabolclita": "cabolclo",
    "cabolclitas": "cabolclo",
    "cabolclito": "cabolclo",
    "cabolclitos": "cabolclo",
    "cabolclos": "cabolclo",
    "cabolclozinho": "cabolclo",
    "cabolclozinhos": "cabolclo",
    "cabolclozito": "cabolclo",
    "cabolclozitos": "cabolclo",
    "cabondes": "cabonde",
    "cabos": "cabo",
    "cabota": "cabotar",
    "cabotada": "cabotar",
    "cabotadas": "cabotar",
    "cabotado": "cabotar",
    "cabotados": "cabotar",
    "cabotagens": "cabotagem",
    "cabotai": "cabotar",
    "cabotais": "cabotar",
    "cabotam": "cabotar",
    "cabotamo": "cabotar",
    "cabotamos": "cabotar",
    "cabotando": "cabotar",
    "cabotara": "cabotar",
    "cabotaram": "cabotar",
    "cabotaras": "cabotar",
    "cabotardes": "cabotar",
    "cabotarei": "cabotar",
    "cabotareis": "cabotar",
    "cabotarem": "cabotar",
    "cabotaremos": "cabotar",
    "cabotares": "cabotar",
    "cabotaria": "cabotar",
    "cabotariam": "cabotar",
    "cabotarias": "cabotar",
    "cabotarmo": "cabotar",
    "cabotarmos": "cabotar",
    "cabotará": "cabotar",
    "cabotarás": "cabotar",
    "cabotarão": "cabotar",
    "cabotaríamos": "cabotar",
    "cabotaríeis": "cabotar",
    "cabotas": "cabotar",
    "cabotasse": "cabotar",
    "cabotassem": "cabotar",
    "cabotasses": "cabotar",
    "cabotaste": "cabotar",
    "cabotastes": "cabotar",
    "cabotava": "cabotar",
    "cabotavam": "cabotar",
    "cabotavas": "cabotar",
    "cabote": "cabotar",
    "cabotei": "cabotar",
    "caboteis": "cabotar",
    "cabotem": "cabotar",
    "cabotemo": "cabotar",
    "cabotemos": "cabotar",
    "cabotes": "cabotar",
    "cabotina": "cabotino",
    "cabotinagens": "cabotinagem",
    "cabotinas": "cabotino",
    "cabotinismos": "cabotinismo",
    "cabotinos": "cabotino",
    "cabotiníssima": "cabotino",
    "cabotiníssimas": "cabotino",
    "cabotiníssimo": "cabotino",
    "cabotiníssimos": "cabotino",
    "caboto": "cabotar",
    "cabotou": "cabotar",
    "cabotámo": "cabotar",
    "cabotámos": "cabotar",
    "cabotáramo": "cabotar",
    "cabotáramos": "cabotar",
    "cabotáreis": "cabotar",
    "cabotásseis": "cabotar",
    "cabotássemos": "cabotar",
    "cabotávamo": "cabotar",
    "cabotávamos": "cabotar",
    "cabotáveis": "cabotar",
    "cabouca": "caboucar",
    "caboucada": "caboucar",
    "caboucadas": "caboucar",
    "caboucado": "caboucar",
    "caboucados": "caboucar",
    "caboucai": "caboucar",
    "caboucais": "caboucar",
    "caboucam": "caboucar",
    "caboucamo": "caboucar",
    "caboucamos": "caboucar",
    "caboucando": "caboucar",
    "caboucara": "caboucar",
    "caboucaram": "caboucar",
    "caboucaras": "caboucar",
    "caboucarde": "caboucar",
    "caboucardes": "caboucar",
    "caboucare": "caboucar",
    "caboucarei": "caboucar",
    "caboucareis": "caboucar",
    "caboucarem": "caboucar",
    "caboucaremos": "caboucar",
    "caboucares": "caboucar",
    "caboucaria": "caboucar",
    "caboucariam": "caboucar",
    "caboucarias": "caboucar",
    "caboucarmo": "caboucar",
    "caboucarmos": "caboucar",
    "caboucará": "caboucar",
    "caboucarás": "caboucar",
    "caboucarão": "caboucar",
    "caboucaríamos": "caboucar",
    "caboucaríeis": "caboucar",
    "caboucas": "caboucar",
    "caboucasse": "caboucar",
    "caboucassem": "caboucar",
    "caboucasses": "caboucar",
    "caboucaste": "caboucar",
    "caboucastes": "caboucar",
    "caboucava": "caboucar",
    "caboucavam": "caboucar",
    "caboucavas": "caboucar",
    "cabouco": "caboucar",
    "caboucos": "cabouco",
    "caboucou": "caboucar",
    "caboucá": "caboucar",
    "caboucámo": "caboucar",
    "caboucámos": "caboucar",
    "caboucáramo": "caboucar",
    "caboucáramos": "caboucar",
    "caboucárei": "caboucar",
    "caboucáreis": "caboucar",
    "caboucásseis": "caboucar",
    "caboucássemos": "caboucar",
    "caboucávamo": "caboucar",
    "caboucávamos": "caboucar",
    "caboucávei": "caboucar",
    "caboucáveis": "caboucar",
    "cabouque": "caboucar",
    "cabouquei": "caboucar",
    "cabouqueiros": "cabouqueiro",
    "cabouqueis": "caboucar",
    "cabouquem": "caboucar",
    "cabouquemo": "caboucar",
    "cabouquemos": "caboucar",
    "cabouques": "caboucar",
    "caboverdiana": "caboverdiano",
    "caboverdianas": "caboverdiano",
    "caboverdianos": "caboverdiano",
    "cabozes": "caboz",
    "cabradas": "cabrada",
    "cabralina": "cabralino",
    "cabralinas": "cabralino",
    "cabralinos": "cabralino",
    "cabralismos": "cabralismo",
    "cabralistas": "cabralista",
    "cabramos": "cabramo",
    "cabras": "cabra",
    "cabraza": "cabrazar",
    "cabrazada": "cabrazar",
    "cabrazadas": "cabrazar",
    "cabrazado": "cabrazar",
    "cabrazados": "cabrazar",
    "cabrazai": "cabrazar",
    "cabrazais": "cabrazar",
    "cabrazam": "cabrazar",
    "cabrazamo": "cabrazar",
    "cabrazamos": "cabrazar",
    "cabrazando": "cabrazar",
    "cabrazara": "cabrazar",
    "cabrazaram": "cabrazar",
    "cabrazaras": "cabrazar",
    "cabrazarde": "cabrazar",
    "cabrazardes": "cabrazar",
    "cabrazare": "cabrazar",
    "cabrazarei": "cabrazar",
    "cabrazareis": "cabrazar",
    "cabrazarem": "cabrazar",
    "cabrazaremos": "cabrazar",
    "cabrazares": "cabrazar",
    "cabrazaria": "cabrazar",
    "cabrazariam": "cabrazar",
    "cabrazarias": "cabrazar",
    "cabrazarmo": "cabrazar",
    "cabrazarmos": "cabrazar",
    "cabrazará": "cabrazar",
    "cabrazarás": "cabrazar",
    "cabrazarão": "cabrazar",
    "cabrazaríamos": "cabrazar",
    "cabrazaríeis": "cabrazar",
    "cabrazas": "cabrazar",
    "cabrazasse": "cabrazar",
    "cabrazassem": "cabrazar",
    "cabrazasses": "cabrazar",
    "cabrazaste": "cabrazar",
    "cabrazastes": "cabrazar",
    "cabrazava": "cabrazar",
    "cabrazavam": "cabrazar",
    "cabrazavas": "cabrazar",
    "cabraze": "cabrazar",
    "cabrazei": "cabrazar",
    "cabrazeis": "cabrazar",
    "cabrazem": "cabrazar",
    "cabrazemo": "cabrazar",
    "cabrazemos": "cabrazar",
    "cabrazes": "cabrazar",
    "cabrazo": "cabrazar",
    "cabrazou": "cabrazar",
    "cabrazá": "cabrazar",
    "cabrazámo": "cabrazar",
    "cabrazámos": "cabrazar",
    "cabrazáramo": "cabrazar",
    "cabrazáramos": "cabrazar",
    "cabrazárei": "cabrazar",
    "cabrazáreis": "cabrazar",
    "cabrazásseis": "cabrazar",
    "cabrazássemos": "cabrazar",
    "cabrazávamo": "cabrazar",
    "cabrazávamos": "cabrazar",
    "cabrazávei": "cabrazar",
    "cabrazáveis": "cabrazar",
    "cabreada": "cabrear",
    "cabreadas": "cabrear",
    "cabreado": "cabrear",
    "cabreados": "cabrear",
    "cabreai": "cabrear",
    "cabreais": "cabrear",
    "cabreamo": "cabrear",
    "cabreamos": "cabrear",
    "cabreando": "cabrear",
    "cabreara": "cabrear",
    "cabrearam": "cabrear",
    "cabrearas": "cabrear",
    "cabreardes": "cabrear",
    "cabrearei": "cabrear",
    "cabreareis": "cabrear",
    "cabrearem": "cabrear",
    "cabrearemos": "cabrear",
    "cabreares": "cabrear",
    "cabrearia": "cabrear",
    "cabreariam": "cabrear",
    "cabrearias": "cabrear",
    "cabrearmo": "cabrear",
    "cabrearmos": "cabrear",
    "cabreará": "cabrear",
    "cabrearás": "cabrear",
    "cabrearão": "cabrear",
    "cabrearíamos": "cabrear",
    "cabrearíeis": "cabrear",
    "cabreasse": "cabrear",
    "cabreassem": "cabrear",
    "cabreasses": "cabrear",
    "cabreaste": "cabrear",
    "cabreastes": "cabrear",
    "cabreava": "cabrear",
    "cabreavam": "cabrear",
    "cabreavas": "cabrear",
    "cabreei": "cabrear",
    "cabreeis": "cabrear",
    "cabreemo": "cabrear",
    "cabreemos": "cabrear",
    "cabreia": "cabrear",
    "cabreiam": "cabrear",
    "cabreias": "cabrear",
    "cabreie": "cabrear",
    "cabreiem": "cabrear",
    "cabreies": "cabrear",
    "cabreio": "cabrear",
    "cabreira": "cabreiro",
    "cabreiras": "cabreiro",
    "cabreiros": "cabreiro",
    "cabreja": "cabrejar",
    "cabrejada": "cabrejar",
    "cabrejadas": "cabrejar",
    "cabrejado": "cabrejar",
    "cabrejados": "cabrejar",
    "cabrejai": "cabrejar",
    "cabrejais": "cabrejar",
    "cabrejam": "cabrejar",
    "cabrejamo": "cabrejar",
    "cabrejamos": "cabrejar",
    "cabrejando": "cabrejar",
    "cabrejara": "cabrejar",
    "cabrejaram": "cabrejar",
    "cabrejaras": "cabrejar",
    "cabrejardes": "cabrejar",
    "cabrejarei": "cabrejar",
    "cabrejareis": "cabrejar",
    "cabrejarem": "cabrejar",
    "cabrejaremos": "cabrejar",
    "cabrejares": "cabrejar",
    "cabrejaria": "cabrejar",
    "cabrejariam": "cabrejar",
    "cabrejarias": "cabrejar",
    "cabrejarmo": "cabrejar",
    "cabrejarmos": "cabrejar",
    "cabrejará": "cabrejar",
    "cabrejarás": "cabrejar",
    "cabrejarão": "cabrejar",
    "cabrejaríamos": "cabrejar",
    "cabrejaríeis": "cabrejar",
    "cabrejas": "cabrejar",
    "cabrejasse": "cabrejar",
    "cabrejassem": "cabrejar",
    "cabrejasses": "cabrejar",
    "cabrejaste": "cabrejar",
    "cabrejastes": "cabrejar",
    "cabrejava": "cabrejar",
    "cabrejavam": "cabrejar",
    "cabrejavas": "cabrejar",
    "cabreje": "cabrejar",
    "cabrejei": "cabrejar",
    "cabrejeis": "cabrejar",
    "cabrejem": "cabrejar",
    "cabrejemo": "cabrejar",
    "cabrejemos": "cabrejar",
    "cabrejes": "cabrejar",
    "cabrejo": "cabrejar",
    "cabrejou": "cabrejar",
    "cabrejámo": "cabrejar",
    "cabrejámos": "cabrejar",
    "cabrejáramo": "cabrejar",
    "cabrejáramos": "cabrejar",
    "cabrejáreis": "cabrejar",
    "cabrejásseis": "cabrejar",
    "cabrejássemos": "cabrejar",
    "cabrejávamo": "cabrejar",
    "cabrejávamos": "cabrejar",
    "cabrejáveis": "cabrejar",
    "cabreou": "cabrear",
    "cabrestantes": "cabrestante",
    "cabresteada": "cabrestear",
    "cabresteadas": "cabrestear",
    "cabresteado": "cabrestear",
    "cabresteados": "cabrestear",
    "cabresteai": "cabrestear",
    "cabresteais": "cabrestear",
    "cabresteamo": "cabrestear",
    "cabresteamos": "cabrestear",
    "cabresteando": "cabrestear",
    "cabresteara": "cabrestear",
    "cabrestearam": "cabrestear",
    "cabrestearas": "cabrestear",
    "cabresteardes": "cabrestear",
    "cabrestearei": "cabrestear",
    "cabresteareis": "cabrestear",
    "cabrestearem": "cabrestear",
    "cabrestearemos": "cabrestear",
    "cabresteares": "cabrestear",
    "cabrestearia": "cabrestear",
    "cabresteariam": "cabrestear",
    "cabrestearias": "cabrestear",
    "cabrestearmo": "cabrestear",
    "cabrestearmos": "cabrestear",
    "cabresteará": "cabrestear",
    "cabrestearás": "cabrestear",
    "cabrestearão": "cabrestear",
    "cabrestearíamos": "cabrestear",
    "cabrestearíeis": "cabrestear",
    "cabresteasse": "cabrestear",
    "cabresteassem": "cabrestear",
    "cabresteasses": "cabrestear",
    "cabresteaste": "cabrestear",
    "cabresteastes": "cabrestear",
    "cabresteava": "cabrestear",
    "cabresteavam": "cabrestear",
    "cabresteavas": "cabrestear",
    "cabresteei": "cabrestear",
    "cabresteeis": "cabrestear",
    "cabresteemo": "cabrestear",
    "cabresteemos": "cabrestear",
    "cabresteia": "cabrestear",
    "cabresteiam": "cabrestear",
    "cabresteias": "cabrestear",
    "cabresteie": "cabrestear",
    "cabresteiem": "cabrestear",
    "cabresteies": "cabrestear",
    "cabresteio": "cabrestear",
    "cabresteira": "cabresteiro",
    "cabresteiras": "cabresteiro",
    "cabresteiros": "cabresteiro",
    "cabresteou": "cabrestear",
    "cabresteámo": "cabrestear",
    "cabresteámos": "cabrestear",
    "cabresteáramo": "cabrestear",
    "cabresteáramos": "cabrestear",
    "cabresteáreis": "cabrestear",
    "cabresteásseis": "cabrestear",
    "cabresteássemos": "cabrestear",
    "cabresteávamo": "cabrestear",
    "cabresteávamos": "cabrestear",
    "cabresteáveis": "cabrestear",
    "cabrestilhos": "cabrestilho",
    "cabrestos": "cabresto",
    "cabrestões": "cabrestão",
    "cabreámo": "cabrear",
    "cabreámos": "cabrear",
    "cabreáramo": "cabrear",
    "cabreáramos": "cabrear",
    "cabreáreis": "cabrear",
    "cabreásseis": "cabrear",
    "cabreássemos": "cabrear",
    "cabreávamo": "cabrear",
    "cabreávamos": "cabrear",
    "cabreáveis": "cabrear",
    "cabrilhas": "cabrilha",
    "cabrinha": "cabra",
    "cabrinhas": "cabra",
    "cabrins": "cabrim",
    "cabriola": "cabriolar",
    "cabriolada": "cabriolar",
    "cabrioladas": "cabriolar",
    "cabriolado": "cabriolar",
    "cabriolados": "cabriolar",
    "cabriolai": "cabriolar",
    "cabriolais": "cabriolar",
    "cabriolam": "cabriolar",
    "cabriolamo": "cabriolar",
    "cabriolamos": "cabriolar",
    "cabriolando": "cabriolar",
    "cabriolara": "cabriolar",
    "cabriolaram": "cabriolar",
    "cabriolaras": "cabriolar",
    "cabriolardes": "cabriolar",
    "cabriolarei": "cabriolar",
    "cabriolareis": "cabriolar",
    "cabriolarem": "cabriolar",
    "cabriolaremos": "cabriolar",
    "cabriolares": "cabriolar",
    "cabriolaria": "cabriolar",
    "cabriolariam": "cabriolar",
    "cabriolarias": "cabriolar",
    "cabriolarmo": "cabriolar",
    "cabriolarmos": "cabriolar",
    "cabriolará": "cabriolar",
    "cabriolarás": "cabriolar",
    "cabriolarão": "cabriolar",
    "cabriolaríamos": "cabriolar",
    "cabriolaríeis": "cabriolar",
    "cabriolas": "cabriolar",
    "cabriolasse": "cabriolar",
    "cabriolassem": "cabriolar",
    "cabriolasses": "cabriolar",
    "cabriolaste": "cabriolar",
    "cabriolastes": "cabriolar",
    "cabriolava": "cabriolar",
    "cabriolavam": "cabriolar",
    "cabriolavas": "cabriolar",
    "cabriole": "cabriolar",
    "cabriolei": "cabriolar",
    "cabrioleis": "cabriolar",
    "cabriolem": "cabriolar",
    "cabriolemo": "cabriolar",
    "cabriolemos": "cabriolar",
    "cabrioles": "cabriolar",
    "cabriolices": "cabriolice",
    "cabriolo": "cabriolar",
    "cabriolou": "cabriolar",
    "cabriolámo": "cabriolar",
    "cabriolámos": "cabriolar",
    "cabrioláramo": "cabriolar",
    "cabrioláramos": "cabriolar",
    "cabrioláreis": "cabriolar",
    "cabriolásseis": "cabriolar",
    "cabriolássemos": "cabriolar",
    "cabriolávamo": "cabriolar",
    "cabriolávamos": "cabriolar",
    "cabrioláveis": "cabriolar",
    "cabriolés": "cabriolé",
    "cabris": "cabril",
    "cabrita": "cabrito",
    "cabritada": "cabritar",
    "cabritadas": "cabritar",
    "cabritado": "cabritar",
    "cabritados": "cabritar",
    "cabritai": "cabritar",
    "cabritais": "cabritar",
    "cabritam": "cabritar",
    "cabritamo": "cabritar",
    "cabritamos": "cabritar",
    "cabritando": "cabritar",
    "cabritara": "cabritar",
    "cabritaram": "cabritar",
    "cabritaras": "cabritar",
    "cabritardes": "cabritar",
    "cabritarei": "cabritar",
    "cabritareis": "cabritar",
    "cabritarem": "cabritar",
    "cabritaremos": "cabritar",
    "cabritares": "cabritar",
    "cabritaria": "cabritar",
    "cabritariam": "cabritar",
    "cabritarias": "cabritar",
    "cabritarmo": "cabritar",
    "cabritarmos": "cabritar",
    "cabritará": "cabritar",
    "cabritarás": "cabritar",
    "cabritarão": "cabritar",
    "cabritaríamos": "cabritar",
    "cabritaríeis": "cabritar",
    "cabritas": "cabrito",
    "cabritasse": "cabritar",
    "cabritassem": "cabritar",
    "cabritasses": "cabritar",
    "cabritaste": "cabritar",
    "cabritastes": "cabritar",
    "cabritava": "cabritar",
    "cabritavam": "cabritar",
    "cabritavas": "cabritar",
    "cabrite": "cabritar",
    "cabritei": "cabritar",
    "cabriteira": "cabriteiro",
    "cabriteiras": "cabriteiro",
    "cabriteiros": "cabriteiro",
    "cabriteis": "cabritar",
    "cabritem": "cabritar",
    "cabritemo": "cabritar",
    "cabritemos": "cabritar",
    "cabrites": "cabritar",
    "cabritinha": "cabrito",
    "cabritinhas": "cabrito",
    "cabritinho": "cabrito",
    "cabritinhos": "cabrito",
    "cabritita": "cabrito",
    "cabrititas": "cabrito",
    "cabritito": "cabrito",
    "cabrititos": "cabrito",
    "cabrito": "cabritar",
    "cabritos": "cabrito",
    "cabritou": "cabritar",
    "cabritámo": "cabritar",
    "cabritámos": "cabritar",
    "cabritáramo": "cabritar",
    "cabritáramos": "cabritar",
    "cabritáreis": "cabritar",
    "cabritásseis": "cabritar",
    "cabritássemos": "cabritar",
    "cabritávamo": "cabritar",
    "cabritávamos": "cabritar",
    "cabritáveis": "cabritar",
    "cabriões": "cabrião",
    "cabrona": "cabrão",
    "cabronas": "cabrão",
    "cabronazinha": "cabrão",
    "cabronazinhas": "cabrão",
    "cabronazita": "cabrão",
    "cabronazitas": "cabrão",
    "cabros": "cabro",
    "cabruns": "cabrum",
    "cabrãozinho": "cabrão",
    "cabrãozito": "cabrão",
    "cabrões": "cabrão",
    "cabrõezinhos": "cabrão",
    "cabrõezitos": "cabrão",
    "cabuchos": "cabucho",
    "cabuchões": "cabuchão",
    "cabula": "cabular",
    "cabulada": "cabular",
    "cabuladas": "cabular",
    "cabulado": "cabular",
    "cabulados": "cabular",
    "cabulai": "cabular",
    "cabulais": "cabular",
    "cabulam": "cabular",
    "cabulamo": "cabular",
    "cabulamos": "cabular",
    "cabulando": "cabular",
    "cabulara": "cabular",
    "cabularam": "cabular",
    "cabularas": "cabular",
    "cabulardes": "cabular",
    "cabularei": "cabular",
    "cabulareis": "cabular",
    "cabularem": "cabular",
    "cabularemos": "cabular",
    "cabulares": "cabular",
    "cabularia": "cabular",
    "cabulariam": "cabular",
    "cabularias": "cabular",
    "cabularmo": "cabular",
    "cabularmos": "cabular",
    "cabulará": "cabular",
    "cabularás": "cabular",
    "cabularão": "cabular",
    "cabularíamos": "cabular",
    "cabularíeis": "cabular",
    "cabulas": "cabular",
    "cabulasse": "cabular",
    "cabulassem": "cabular",
    "cabulasses": "cabular",
    "cabulaste": "cabular",
    "cabulastes": "cabular",
    "cabulava": "cabular",
    "cabulavam": "cabular",
    "cabulavas": "cabular",
    "cabule": "cabular",
    "cabulei": "cabular",
    "cabuleis": "cabular",
    "cabulem": "cabular",
    "cabulemo": "cabular",
    "cabulemos": "cabular",
    "cabules": "cabular",
    "cabulices": "cabulice",
    "cabulo": "cabular",
    "cabulou": "cabular",
    "cabulámo": "cabular",
    "cabulámos": "cabular",
    "cabuláramo": "cabular",
    "cabuláramos": "cabular",
    "cabuláreis": "cabular",
    "cabulásseis": "cabular",
    "cabulássemos": "cabular",
    "cabulávamo": "cabular",
    "cabulávamos": "cabular",
    "cabuláveis": "cabular",
    "cabíamo": "caber",
    "cabíamos": "caber",
    "cabídolas": "cabídola",
    "cabíeis": "caber",
    "cacaborradas": "cacaborrada",
    "cacadas": "cacada",
    "cacaracás": "cacaracá",
    "cacarecos": "cacareco",
    "cacareja": "cacarejar",
    "cacarejada": "cacarejar",
    "cacarejadas": "cacarejar",
    "cacarejado": "cacarejar",
    "cacarejadora": "cacarejador",
    "cacarejadoras": "cacarejador",
    "cacarejadores": "cacarejador",
    "cacarejados": "cacarejar",
    "cacarejai": "cacarejar",
    "cacarejais": "cacarejar",
    "cacarejam": "cacarejar",
    "cacarejamo": "cacarejar",
    "cacarejamos": "cacarejar",
    "cacarejando": "cacarejar",
    "cacarejara": "cacarejar",
    "cacarejaram": "cacarejar",
    "cacarejaras": "cacarejar",
    "cacarejarde": "cacarejar",
    "cacarejardes": "cacarejar",
    "cacarejare": "cacarejar",
    "cacarejarei": "cacarejar",
    "cacarejareis": "cacarejar",
    "cacarejarem": "cacarejar",
    "cacarejaremos": "cacarejar",
    "cacarejares": "cacarejar",
    "cacarejaria": "cacarejar",
    "cacarejariam": "cacarejar",
    "cacarejarias": "cacarejar",
    "cacarejarmo": "cacarejar",
    "cacarejarmos": "cacarejar",
    "cacarejará": "cacarejar",
    "cacarejarás": "cacarejar",
    "cacarejarão": "cacarejar",
    "cacarejaríamos": "cacarejar",
    "cacarejaríeis": "cacarejar",
    "cacarejas": "cacarejar",
    "cacarejasse": "cacarejar",
    "cacarejassem": "cacarejar",
    "cacarejasses": "cacarejar",
    "cacarejaste": "cacarejar",
    "cacarejastes": "cacarejar",
    "cacarejava": "cacarejar",
    "cacarejavam": "cacarejar",
    "cacarejavas": "cacarejar",
    "cacareje": "cacarejar",
    "cacarejei": "cacarejar",
    "cacarejeis": "cacarejar",
    "cacarejem": "cacarejar",
    "cacarejemo": "cacarejar",
    "cacarejemos": "cacarejar",
    "cacarejes": "cacarejar",
    "cacarejo": "cacarejar",
    "cacarejos": "cacarejo",
    "cacarejou": "cacarejar",
    "cacarejá": "cacarejar",
    "cacarejámo": "cacarejar",
    "cacarejámos": "cacarejar",
    "cacarejáramo": "cacarejar",
    "cacarejáramos": "cacarejar",
    "cacarejárei": "cacarejar",
    "cacarejáreis": "cacarejar",
    "cacarejásseis": "cacarejar",
    "cacarejássemos": "cacarejar",
    "cacarejávamo": "cacarejar",
    "cacarejávamos": "cacarejar",
    "cacarejávei": "cacarejar",
    "cacarejáveis": "cacarejar",
    "cacarias": "cacaria",
    "cacaréus": "cacaréu",
    "cacas": "caca",
    "cacatuas": "cacatua",
    "cacauais": "cacaual",
    "cacaueiros": "cacaueiro",
    "cacaus": "cacau",
    "cacauzeirais": "cacauzeiral",
    "cacauzeiros": "cacauzeiro",
    "cace": "caçar",
    "caceada": "cacear",
    "caceadas": "cacear",
    "caceado": "cacear",
    "caceados": "cacear",
    "caceai": "cacear",
    "caceais": "cacear",
    "caceamo": "cacear",
    "caceamos": "cacear",
    "caceando": "cacear",
    "caceara": "cacear",
    "cacearam": "cacear",
    "cacearas": "cacear",
    "caceardes": "cacear",
    "cacearei": "cacear",
    "caceareis": "cacear",
    "cacearem": "cacear",
    "cacearemos": "cacear",
    "caceares": "cacear",
    "cacearia": "cacear",
    "caceariam": "cacear",
    "cacearias": "cacear",
    "cacearmo": "cacear",
    "cacearmos": "cacear",
    "caceará": "cacear",
    "cacearás": "cacear",
    "cacearão": "cacear",
    "cacearíamos": "cacear",
    "cacearíeis": "cacear",
    "caceasse": "cacear",
    "caceassem": "cacear",
    "caceasses": "cacear",
    "caceaste": "cacear",
    "caceastes": "cacear",
    "caceava": "cacear",
    "caceavam": "cacear",
    "caceavas": "cacear",
    "caceei": "cacear",
    "caceeis": "cacear",
    "caceemo": "cacear",
    "caceemos": "cacear",
    "cacei": "caçar",
    "caceia": "cacear",
    "caceiam": "cacear",
    "caceias": "caceia",
    "caceie": "cacear",
    "caceiem": "cacear",
    "caceies": "cacear",
    "caceio": "cacear",
    "caceios": "caceio",
    "caceis": "caçar",
    "cacem": "caçar",
    "cacemo": "caçar",
    "cacemos": "caçar",
    "caceou": "cacear",
    "caces": "caçar",
    "cacetadas": "cacetada",
    "cacetas": "caceta",
    "caceteada": "cacetear",
    "caceteadas": "cacetear",
    "caceteado": "cacetear",
    "caceteados": "cacetear",
    "caceteai": "cacetear",
    "caceteais": "cacetear",
    "caceteamo": "cacetear",
    "caceteamos": "cacetear",
    "caceteando": "cacetear",
    "caceteara": "cacetear",
    "cacetearam": "cacetear",
    "cacetearas": "cacetear",
    "cacetearde": "cacetear",
    "caceteardes": "cacetear",
    "caceteare": "cacetear",
    "cacetearei": "cacetear",
    "caceteareis": "cacetear",
    "cacetearem": "cacetear",
    "cacetearemos": "cacetear",
    "caceteares": "cacetear",
    "cacetearia": "cacetear",
    "caceteariam": "cacetear",
    "cacetearias": "cacetear",
    "cacetearmo": "cacetear",
    "cacetearmos": "cacetear",
    "caceteará": "cacetear",
    "cacetearás": "cacetear",
    "cacetearão": "cacetear",
    "cacetearíamos": "cacetear",
    "cacetearíeis": "cacetear",
    "caceteasse": "cacetear",
    "caceteassem": "cacetear",
    "caceteasses": "cacetear",
    "caceteaste": "cacetear",
    "caceteastes": "cacetear",
    "caceteava": "cacetear",
    "caceteavam": "cacetear",
    "caceteavas": "cacetear",
    "caceteações": "caceteação",
    "caceteei": "cacetear",
    "caceteeis": "cacetear",
    "caceteemo": "cacetear",
    "caceteemos": "cacetear",
    "caceteia": "cacetear",
    "caceteiam": "cacetear",
    "caceteias": "cacetear",
    "caceteie": "cacetear",
    "caceteiem": "cacetear",
    "caceteies": "cacetear",
    "caceteio": "cacetear",
    "caceteira": "caceteiro",
    "caceteiras": "caceteiro",
    "caceteiros": "caceteiro",
    "caceteou": "cacetear",
    "cacetes": "cacete",
    "caceteá": "cacetear",
    "caceteámo": "cacetear",
    "caceteámos": "cacetear",
    "caceteáramo": "cacetear",
    "caceteáramos": "cacetear",
    "caceteárei": "cacetear",
    "caceteáreis": "cacetear",
    "caceteásseis": "cacetear",
    "caceteássemos": "cacetear",
    "caceteávamo": "cacetear",
    "caceteávamos": "cacetear",
    "caceteávei": "cacetear",
    "caceteáveis": "cacetear",
    "caceámo": "cacear",
    "caceámos": "cacear",
    "caceáramo": "cacear",
    "caceáramos": "cacear",
    "caceáreis": "cacear",
    "caceásseis": "cacear",
    "caceássemos": "cacear",
    "caceávamo": "cacear",
    "caceávamos": "cacear",
    "caceáveis": "cacear",
    "cacha": "cachar",
    "cachaceira": "cachaceiro",
    "cachaceiras": "cachaceiro",
    "cachaceiros": "cachaceiro",
    "cachada": "cachar",
    "cachadas": "cachar",
    "cachado": "cachar",
    "cachados": "cachar",
    "cachafundos": "cachafundo",
    "cachafurgos": "cachafurgo",
    "cachagens": "cachagem",
    "cachai": "cachar",
    "cachais": "cachar",
    "cachalotes": "cachalote",
    "cacham": "cachar",
    "cachamo": "cachar",
    "cachamorradas": "cachamorrada",
    "cachamorras": "cachamorra",
    "cachamorreira": "cachamorreiro",
    "cachamorreiras": "cachamorreiro",
    "cachamorreiros": "cachamorreiro",
    "cachamos": "cachar",
    "cachando": "cachar",
    "cachapeiras": "cachapeira",
    "cachapeiros": "cachapeiro",
    "cachapins": "cachapim",
    "cachaporradas": "cachaporrada",
    "cachaporras": "cachaporra",
    "cachapuços": "cachapuço",
    "cachara": "cachar",
    "cacharam": "cachar",
    "cacharas": "cachar",
    "cacharde": "cachar",
    "cachardes": "cachar",
    "cachare": "cachar",
    "cacharei": "cachar",
    "cachareis": "cachar",
    "cacharem": "cachar",
    "cacharemos": "cachar",
    "cachares": "cachar",
    "cacharia": "cachar",
    "cachariam": "cachar",
    "cacharias": "cachar",
    "cacharmo": "cachar",
    "cacharmos": "cachar",
    "cacharoletes": "cacharolete",
    "cachará": "cachar",
    "cacharás": "cachar",
    "cacharão": "cachar",
    "cacharíamos": "cachar",
    "cacharíeis": "cachar",
    "cachas": "cachar",
    "cachasse": "cachar",
    "cachassem": "cachar",
    "cachasses": "cachar",
    "cachaste": "cachar",
    "cachastes": "cachar",
    "cachava": "cachar",
    "cachavam": "cachar",
    "cachavas": "cachar",
    "cachaçadas": "cachaçada",
    "cachaças": "cachaça",
    "cachaços": "cachaço",
    "cachaçuda": "cachaçudo",
    "cachaçudas": "cachaçudo",
    "cachaçudos": "cachaçudo",
    "cachações": "cachação",
    "cache": "cachar",
    "cacheada": "cachear",
    "cacheadas": "cachear",
    "cacheado": "cachear",
    "cacheados": "cachear",
    "cacheai": "cachear",
    "cacheais": "cachear",
    "cacheamo": "cachear",
    "cacheamos": "cachear",
    "cacheando": "cachear",
    "cacheara": "cachear",
    "cachearam": "cachear",
    "cachearas": "cachear",
    "cacheardes": "cachear",
    "cachearei": "cachear",
    "cacheareis": "cachear",
    "cachearem": "cachear",
    "cachearemos": "cachear",
    "cacheares": "cachear",
    "cachearia": "cachear",
    "cacheariam": "cachear",
    "cachearias": "cachear",
    "cachearmo": "cachear",
    "cachearmos": "cachear",
    "cacheará": "cachear",
    "cachearás": "cachear",
    "cachearão": "cachear",
    "cachearíamos": "cachear",
    "cachearíeis": "cachear",
    "cacheasse": "cachear",
    "cacheassem": "cachear",
    "cacheasses": "cachear",
    "cacheaste": "cachear",
    "cacheastes": "cachear",
    "cacheava": "cachear",
    "cacheavam": "cachear",
    "cacheavas": "cachear",
    "cachecóis": "cachecol",
    "cacheei": "cachear",
    "cacheeis": "cachear",
    "cacheemo": "cachear",
    "cacheemos": "cachear",
    "cachei": "cachar",
    "cacheia": "cachear",
    "cacheiam": "cachear",
    "cacheias": "cachear",
    "cacheie": "cachear",
    "cacheiem": "cachear",
    "cacheies": "cachear",
    "cacheio": "cachear",
    "cacheiradas": "cacheirada",
    "cacheiras": "cacheira",
    "cacheiros": "cacheiro",
    "cacheis": "cachar",
    "cachem": "cachar",
    "cachemo": "cachar",
    "cachemos": "cachar",
    "cachenés": "cachené",
    "cacheou": "cachear",
    "cachepôs": "cachepô",
    "cacherás": "cacherá",
    "caches": "cache",
    "cacheta": "cachetar",
    "cachetada": "cachetar",
    "cachetadas": "cachetar",
    "cachetado": "cachetar",
    "cachetados": "cachetar",
    "cachetai": "cachetar",
    "cachetais": "cachetar",
    "cachetam": "cachetar",
    "cachetamo": "cachetar",
    "cachetamos": "cachetar",
    "cachetando": "cachetar",
    "cachetara": "cachetar",
    "cachetaram": "cachetar",
    "cachetaras": "cachetar",
    "cachetardes": "cachetar",
    "cachetarei": "cachetar",
    "cachetareis": "cachetar",
    "cachetarem": "cachetar",
    "cachetaremos": "cachetar",
    "cachetares": "cachetar",
    "cachetaria": "cachetar",
    "cachetariam": "cachetar",
    "cachetarias": "cachetar",
    "cachetarmo": "cachetar",
    "cachetarmos": "cachetar",
    "cachetará": "cachetar",
    "cachetarás": "cachetar",
    "cachetarão": "cachetar",
    "cachetaríamos": "cachetar",
    "cachetaríeis": "cachetar",
    "cachetas": "cachetar",
    "cachetasse": "cachetar",
    "cachetassem": "cachetar",
    "cachetasses": "cachetar",
    "cachetaste": "cachetar",
    "cachetastes": "cachetar",
    "cachetava": "cachetar",
    "cachetavam": "cachetar",
    "cachetavas": "cachetar",
    "cachete": "cachetar",
    "cachetei": "cachetar",
    "cacheteis": "cachetar",
    "cachetem": "cachetar",
    "cachetemo": "cachetar",
    "cachetemos": "cachetar",
    "cachetes": "cachete",
    "cacheto": "cachetar",
    "cachetou": "cachetar",
    "cachets": "cachet",
    "cachetámo": "cachetar",
    "cachetámos": "cachetar",
    "cachetáramo": "cachetar",
    "cachetáramos": "cachetar",
    "cachetáreis": "cachetar",
    "cachetásseis": "cachetar",
    "cachetássemos": "cachetar",
    "cachetávamo": "cachetar",
    "cachetávamos": "cachetar",
    "cachetáveis": "cachetar",
    "cacheámo": "cachear",
    "cacheámos": "cachear",
    "cacheáramo": "cachear",
    "cacheáramos": "cachear",
    "cacheáreis": "cachear",
    "cacheásseis": "cachear",
    "cacheássemos": "cachear",
    "cacheávamo": "cachear",
    "cacheávamos": "cachear",
    "cacheáveis": "cachear",
    "cachias": "cachia",
    "cachilros": "cachilro",
    "cachimanas": "cachimana",
    "cachimanhas": "cachimanha",
    "cachimba": "cachimbar",
    "cachimbada": "cachimbar",
    "cachimbadas": "cachimbar",
    "cachimbado": "cachimbar",
    "cachimbadora": "cachimbador",
    "cachimbadoras": "cachimbador",
    "cachimbadores": "cachimbador",
    "cachimbados": "cachimbar",
    "cachimbai": "cachimbar",
    "cachimbais": "cachimbar",
    "cachimbam": "cachimbar",
    "cachimbamo": "cachimbar",
    "cachimbamos": "cachimbar",
    "cachimbando": "cachimbar",
    "cachimbara": "cachimbar",
    "cachimbaram": "cachimbar",
    "cachimbaras": "cachimbar",
    "cachimbardes": "cachimbar",
    "cachimbarei": "cachimbar",
    "cachimbareis": "cachimbar",
    "cachimbarem": "cachimbar",
    "cachimbaremos": "cachimbar",
    "cachimbares": "cachimbar",
    "cachimbaria": "cachimbar",
    "cachimbariam": "cachimbar",
    "cachimbarias": "cachimbar",
    "cachimbarmo": "cachimbar",
    "cachimbarmos": "cachimbar",
    "cachimbará": "cachimbar",
    "cachimbarás": "cachimbar",
    "cachimbarão": "cachimbar",
    "cachimbaríamos": "cachimbar",
    "cachimbaríeis": "cachimbar",
    "cachimbas": "cachimbar",
    "cachimbasse": "cachimbar",
    "cachimbassem": "cachimbar",
    "cachimbasses": "cachimbar",
    "cachimbaste": "cachimbar",
    "cachimbastes": "cachimbar",
    "cachimbava": "cachimbar",
    "cachimbavam": "cachimbar",
    "cachimbavas": "cachimbar",
    "cachimbe": "cachimbar",
    "cachimbei": "cachimbar",
    "cachimbeis": "cachimbar",
    "cachimbem": "cachimbar",
    "cachimbemo": "cachimbar",
    "cachimbemos": "cachimbar",
    "cachimbes": "cachimbar",
    "cachimbo": "cachimbar",
    "cachimbos": "cachimbo",
    "cachimbou": "cachimbar",
    "cachimbámo": "cachimbar",
    "cachimbámos": "cachimbar",
    "cachimbáramo": "cachimbar",
    "cachimbáramos": "cachimbar",
    "cachimbáreis": "cachimbar",
    "cachimbásseis": "cachimbar",
    "cachimbássemos": "cachimbar",
    "cachimbávamo": "cachimbar",
    "cachimbávamos": "cachimbar",
    "cachimbáveis": "cachimbar",
    "cachimónias": "cachimónia",
    "cachina": "cachinar",
    "cachinada": "cachinar",
    "cachinadas": "cachinar",
    "cachinado": "cachinar",
    "cachinadora": "cachinador",
    "cachinadoras": "cachinador",
    "cachinadores": "cachinador",
    "cachinados": "cachinar",
    "cachinai": "cachinar",
    "cachinais": "cachinar",
    "cachinam": "cachinar",
    "cachinamo": "cachinar",
    "cachinamos": "cachinar",
    "cachinando": "cachinar",
    "cachinara": "cachinar",
    "cachinaram": "cachinar",
    "cachinaras": "cachinar",
    "cachinardes": "cachinar",
    "cachinarei": "cachinar",
    "cachinareis": "cachinar",
    "cachinarem": "cachinar",
    "cachinaremos": "cachinar",
    "cachinares": "cachinar",
    "cachinaria": "cachinar",
    "cachinariam": "cachinar",
    "cachinarias": "cachinar",
    "cachinarmo": "cachinar",
    "cachinarmos": "cachinar",
    "cachinará": "cachinar",
    "cachinarás": "cachinar",
    "cachinarão": "cachinar",
    "cachinaríamos": "cachinar",
    "cachinaríeis": "cachinar",
    "cachinas": "cachinar",
    "cachinasse": "cachinar",
    "cachinassem": "cachinar",
    "cachinasses": "cachinar",
    "cachinaste": "cachinar",
    "cachinastes": "cachinar",
    "cachinava": "cachinar",
    "cachinavam": "cachinar",
    "cachinavas": "cachinar",
    "cachine": "cachinar",
    "cachinei": "cachinar",
    "cachineis": "cachinar",
    "cachinem": "cachinar",
    "cachinemo": "cachinar",
    "cachinemos": "cachinar",
    "cachines": "cachinar",
    "cachinhas": "cachinha",
    "cachinho": "cacho",
    "cachinhos": "cacho",
    "cachino": "cachinar",
    "cachinou": "cachinar",
    "cachinámo": "cachinar",
    "cachinámos": "cachinar",
    "cachináramo": "cachinar",
    "cachináramos": "cachinar",
    "cachináreis": "cachinar",
    "cachinásseis": "cachinar",
    "cachinássemos": "cachinar",
    "cachinávamo": "cachinar",
    "cachinávamos": "cachinar",
    "cachináveis": "cachinar",
    "cachito": "cacho",
    "cachitos": "cacho",
    "cachiças": "cachiça",
    "cachiços": "cachiço",
    "cacho": "cachar",
    "cachoa": "cachoar",
    "cachoada": "cachoar",
    "cachoadas": "cachoar",
    "cachoado": "cachoar",
    "cachoados": "cachoar",
    "cachoai": "cachoar",
    "cachoais": "cachoar",
    "cachoam": "cachoar",
    "cachoamo": "cachoar",
    "cachoamos": "cachoar",
    "cachoando": "cachoar",
    "cachoantes": "cachoante",
    "cachoara": "cachoar",
    "cachoaram": "cachoar",
    "cachoaras": "cachoar",
    "cachoardes": "cachoar",
    "cachoarei": "cachoar",
    "cachoareis": "cachoar",
    "cachoarem": "cachoar",
    "cachoaremos": "cachoar",
    "cachoares": "cachoar",
    "cachoaria": "cachoar",
    "cachoariam": "cachoar",
    "cachoarias": "cachoar",
    "cachoarmo": "cachoar",
    "cachoarmos": "cachoar",
    "cachoará": "cachoar",
    "cachoarás": "cachoar",
    "cachoarão": "cachoar",
    "cachoaríamos": "cachoar",
    "cachoaríeis": "cachoar",
    "cachoas": "cachoar",
    "cachoasse": "cachoar",
    "cachoassem": "cachoar",
    "cachoasses": "cachoar",
    "cachoaste": "cachoar",
    "cachoastes": "cachoar",
    "cachoava": "cachoar",
    "cachoavam": "cachoar",
    "cachoavas": "cachoar",
    "cachoe": "cachoar",
    "cachoei": "cachoar",
    "cachoeira": "cachoeirar",
    "cachoeirada": "cachoeirar",
    "cachoeiradas": "cachoeirar",
    "cachoeirado": "cachoeirar",
    "cachoeirados": "cachoeirar",
    "cachoeirai": "cachoeirar",
    "cachoeirais": "cachoeirar",
    "cachoeiram": "cachoeirar",
    "cachoeiramo": "cachoeirar",
    "cachoeiramos": "cachoeirar",
    "cachoeirana": "cachoeirano",
    "cachoeiranas": "cachoeirano",
    "cachoeirando": "cachoeirar",
    "cachoeiranos": "cachoeirano",
    "cachoeirara": "cachoeirar",
    "cachoeiraram": "cachoeirar",
    "cachoeiraras": "cachoeirar",
    "cachoeirardes": "cachoeirar",
    "cachoeirarei": "cachoeirar",
    "cachoeirareis": "cachoeirar",
    "cachoeirarem": "cachoeirar",
    "cachoeiraremos": "cachoeirar",
    "cachoeirares": "cachoeirar",
    "cachoeiraria": "cachoeirar",
    "cachoeirariam": "cachoeirar",
    "cachoeirarias": "cachoeirar",
    "cachoeirarmo": "cachoeirar",
    "cachoeirarmos": "cachoeirar",
    "cachoeirará": "cachoeirar",
    "cachoeirarás": "cachoeirar",
    "cachoeirarão": "cachoeirar",
    "cachoeiraríamos": "cachoeirar",
    "cachoeiraríeis": "cachoeirar",
    "cachoeiras": "cachoeirar",
    "cachoeirasse": "cachoeirar",
    "cachoeirassem": "cachoeirar",
    "cachoeirasses": "cachoeirar",
    "cachoeiraste": "cachoeirar",
    "cachoeirastes": "cachoeirar",
    "cachoeirava": "cachoeirar",
    "cachoeiravam": "cachoeirar",
    "cachoeiravas": "cachoeirar",
    "cachoeire": "cachoeirar",
    "cachoeirei": "cachoeirar",
    "cachoeireis": "cachoeirar",
    "cachoeirem": "cachoeirar",
    "cachoeiremo": "cachoeirar",
    "cachoeiremos": "cachoeirar",
    "cachoeirenses": "cachoeirense",
    "cachoeires": "cachoeirar",
    "cachoeiro": "cachoeirar",
    "cachoeiros": "cachoeiro",
    "cachoeirou": "cachoeirar",
    "cachoeirámo": "cachoeirar",
    "cachoeirámos": "cachoeirar",
    "cachoeiráramo": "cachoeirar",
    "cachoeiráramos": "cachoeirar",
    "cachoeiráreis": "cachoeirar",
    "cachoeirásseis": "cachoeirar",
    "cachoeirássemos": "cachoeirar",
    "cachoeirávamo": "cachoeirar",
    "cachoeirávamos": "cachoeirar",
    "cachoeiráveis": "cachoeirar",
    "cachoeis": "cachoar",
    "cachoem": "cachoar",
    "cachoemo": "cachoar",
    "cachoemos": "cachoar",
    "cachoes": "cachoar",
    "cacholadas": "cacholada",
    "cacholas": "cachola",
    "cacholeiras": "cacholeira",
    "cacholetas": "cacholeta",
    "cachonceiras": "cachonceira",
    "cachondas": "cachonda",
    "cachondeada": "cachondear",
    "cachondeadas": "cachondear",
    "cachondeado": "cachondear",
    "cachondeados": "cachondear",
    "cachondeai": "cachondear",
    "cachondeais": "cachondear",
    "cachondeamo": "cachondear",
    "cachondeamos": "cachondear",
    "cachondeando": "cachondear",
    "cachondeara": "cachondear",
    "cachondearam": "cachondear",
    "cachondearas": "cachondear",
    "cachondeardes": "cachondear",
    "cachondearei": "cachondear",
    "cachondeareis": "cachondear",
    "cachondearem": "cachondear",
    "cachondearemos": "cachondear",
    "cachondeares": "cachondear",
    "cachondearia": "cachondear",
    "cachondeariam": "cachondear",
    "cachondearias": "cachondear",
    "cachondearmo": "cachondear",
    "cachondearmos": "cachondear",
    "cachondeará": "cachondear",
    "cachondearás": "cachondear",
    "cachondearão": "cachondear",
    "cachondearíamos": "cachondear",
    "cachondearíeis": "cachondear",
    "cachondeasse": "cachondear",
    "cachondeassem": "cachondear",
    "cachondeasses": "cachondear",
    "cachondeaste": "cachondear",
    "cachondeastes": "cachondear",
    "cachondeava": "cachondear",
    "cachondeavam": "cachondear",
    "cachondeavas": "cachondear",
    "cachondeei": "cachondear",
    "cachondeeis": "cachondear",
    "cachondeemo": "cachondear",
    "cachondeemos": "cachondear",
    "cachondeia": "cachondear",
    "cachondeiam": "cachondear",
    "cachondeias": "cachondear",
    "cachondeie": "cachondear",
    "cachondeiem": "cachondear",
    "cachondeies": "cachondear",
    "cachondeio": "cachondear",
    "cachondeou": "cachondear",
    "cachondeámo": "cachondear",
    "cachondeámos": "cachondear",
    "cachondeáramo": "cachondear",
    "cachondeáramos": "cachondear",
    "cachondeáreis": "cachondear",
    "cachondeásseis": "cachondear",
    "cachondeássemos": "cachondear",
    "cachondeávamo": "cachondear",
    "cachondeávamos": "cachondear",
    "cachondeáveis": "cachondear",
    "cachoo": "cachoar",
    "cachoou": "cachoar",
    "cachopa": "cachopo",
    "cachoparrões": "cachoparrão",
    "cachopas": "cachopo",
    "cachopices": "cachopice",
    "cachopos": "cachopo",
    "cachorra": "cachorro",
    "cachorradas": "cachorrada",
    "cachorras": "cachorro",
    "cachorreiras": "cachorreira",
    "cachorrices": "cachorrice",
    "cachorrinha": "cachorro",
    "cachorrinhas": "cachorro",
    "cachorrinho": "cachorro",
    "cachorrinhos": "cachorro",
    "cachorrita": "cachorro",
    "cachorritas": "cachorro",
    "cachorrito": "cachorro",
    "cachorritos": "cachorro",
    "cachorros": "cachorro",
    "cachorrões": "cachorrão",
    "cachos": "cacho",
    "cachou": "cachar",
    "cachoámo": "cachoar",
    "cachoámos": "cachoar",
    "cachoáramo": "cachoar",
    "cachoáramos": "cachoar",
    "cachoáreis": "cachoar",
    "cachoásseis": "cachoar",
    "cachoássemos": "cachoar",
    "cachoávamo": "cachoar",
    "cachoávamos": "cachoar",
    "cachoáveis": "cachoar",
    "cachoças": "cachoça",
    "cachucha": "cachuchar",
    "cachuchada": "cachuchar",
    "cachuchadas": "cachuchar",
    "cachuchado": "cachuchar",
    "cachuchados": "cachuchar",
    "cachuchai": "cachuchar",
    "cachuchais": "cachuchar",
    "cachucham": "cachuchar",
    "cachuchamo": "cachuchar",
    "cachuchamos": "cachuchar",
    "cachuchando": "cachuchar",
    "cachuchara": "cachuchar",
    "cachucharam": "cachuchar",
    "cachucharas": "cachuchar",
    "cachuchardes": "cachuchar",
    "cachucharei": "cachuchar",
    "cachuchareis": "cachuchar",
    "cachucharem": "cachuchar",
    "cachucharemos": "cachuchar",
    "cachuchares": "cachuchar",
    "cachucharia": "cachuchar",
    "cachuchariam": "cachuchar",
    "cachucharias": "cachuchar",
    "cachucharmo": "cachuchar",
    "cachucharmos": "cachuchar",
    "cachuchará": "cachuchar",
    "cachucharás": "cachuchar",
    "cachucharão": "cachuchar",
    "cachucharíamos": "cachuchar",
    "cachucharíeis": "cachuchar",
    "cachuchas": "cachuchar",
    "cachuchasse": "cachuchar",
    "cachuchassem": "cachuchar",
    "cachuchasses": "cachuchar",
    "cachuchaste": "cachuchar",
    "cachuchastes": "cachuchar",
    "cachuchava": "cachuchar",
    "cachuchavam": "cachuchar",
    "cachuchavas": "cachuchar",
    "cachuche": "cachuchar",
    "cachuchei": "cachuchar",
    "cachucheis": "cachuchar",
    "cachuchem": "cachuchar",
    "cachuchemo": "cachuchar",
    "cachuchemos": "cachuchar",
    "cachuches": "cachuchar",
    "cachucho": "cachuchar",
    "cachuchos": "cachucho",
    "cachuchou": "cachuchar",
    "cachuchámo": "cachuchar",
    "cachuchámos": "cachuchar",
    "cachucháramo": "cachuchar",
    "cachucháramos": "cachuchar",
    "cachucháreis": "cachuchar",
    "cachuchásseis": "cachuchar",
    "cachuchássemos": "cachuchar",
    "cachuchávamo": "cachuchar",
    "cachuchávamos": "cachuchar",
    "cachucháveis": "cachuchar",
    "cachuda": "cachudo",
    "cachudas": "cachudo",
    "cachudos": "cachudo",
    "cachundés": "cachundé",
    "cachupas": "cachupa",
    "cachá": "cachar",
    "cachámo": "cachar",
    "cachámos": "cachar",
    "cacháramo": "cachar",
    "cacháramos": "cachar",
    "cachárei": "cachar",
    "cacháreis": "cachar",
    "cachásseis": "cachar",
    "cachássemos": "cachar",
    "cachávamo": "cachar",
    "cachávamos": "cachar",
    "cachávei": "cachar",
    "cacháveis": "cachar",
    "cachês": "cachê",
    "cachões": "cachão",
    "cacica": "cacicar",
    "cacicada": "cacicar",
    "cacicadas": "cacicar",
    "cacicado": "cacicar",
    "cacicados": "cacicar",
    "cacicais": "cacicar",
    "cacicam": "cacicar",
    "cacicamo": "cacicar",
    "cacicamos": "cacicar",
    "cacicando": "cacicar",
    "cacicara": "cacicar",
    "cacicaram": "cacicar",
    "cacicaras": "cacicar",
    "cacicardes": "cacicar",
    "cacicarei": "cacicar",
    "cacicareis": "cacicar",
    "cacicarem": "cacicar",
    "cacicaremos": "cacicar",
    "cacicares": "cacicar",
    "cacicaria": "cacicar",
    "cacicariam": "cacicar",
    "cacicarias": "cacicar",
    "cacicarmo": "cacicar",
    "cacicarmos": "cacicar",
    "cacicará": "cacicar",
    "cacicarás": "cacicar",
    "cacicarão": "cacicar",
    "cacicaríamos": "cacicar",
    "cacicaríeis": "cacicar",
    "cacicas": "cacicar",
    "cacicasse": "cacicar",
    "cacicassem": "cacicar",
    "cacicasses": "cacicar",
    "cacicaste": "cacicar",
    "cacicastes": "cacicar",
    "cacicava": "cacicar",
    "cacicavam": "cacicar",
    "cacicavas": "cacicar",
    "cacico": "cacicar",
    "cacicou": "cacicar",
    "cacicámo": "cacicar",
    "cacicámos": "cacicar",
    "cacicáramo": "cacicar",
    "cacicáramos": "cacicar",
    "cacicáreis": "cacicar",
    "cacicásseis": "cacicar",
    "cacicássemos": "cacicar",
    "cacicávamo": "cacicar",
    "cacicávamos": "cacicar",
    "cacicáveis": "cacicar",
    "cacifeira": "cacifeiro",
    "cacifeiras": "cacifeiro",
    "cacifeiros": "cacifeiro",
    "cacifos": "cacifo",
    "cacifres": "cacifre",
    "cacifros": "cacifro",
    "cacilheira": "cacilheiro",
    "cacilheiras": "cacilheiro",
    "cacilheiros": "cacilheiro",
    "cacimba": "cacimbar",
    "cacimbada": "cacimbar",
    "cacimbadas": "cacimbar",
    "cacimbado": "cacimbar",
    "cacimbados": "cacimbar",
    "cacimbai": "cacimbar",
    "cacimbais": "cacimbar",
    "cacimbam": "cacimbar",
    "cacimbamo": "cacimbar",
    "cacimbamos": "cacimbar",
    "cacimbando": "cacimbar",
    "cacimbara": "cacimbar",
    "cacimbaram": "cacimbar",
    "cacimbaras": "cacimbar",
    "cacimbardes": "cacimbar",
    "cacimbarei": "cacimbar",
    "cacimbareis": "cacimbar",
    "cacimbarem": "cacimbar",
    "cacimbaremos": "cacimbar",
    "cacimbares": "cacimbar",
    "cacimbaria": "cacimbar",
    "cacimbariam": "cacimbar",
    "cacimbarias": "cacimbar",
    "cacimbarmo": "cacimbar",
    "cacimbarmos": "cacimbar",
    "cacimbará": "cacimbar",
    "cacimbarás": "cacimbar",
    "cacimbarão": "cacimbar",
    "cacimbaríamos": "cacimbar",
    "cacimbaríeis": "cacimbar",
    "cacimbas": "cacimbar",
    "cacimbasse": "cacimbar",
    "cacimbassem": "cacimbar",
    "cacimbasses": "cacimbar",
    "cacimbaste": "cacimbar",
    "cacimbastes": "cacimbar",
    "cacimbava": "cacimbar",
    "cacimbavam": "cacimbar",
    "cacimbavas": "cacimbar",
    "cacimbe": "cacimbar",
    "cacimbei": "cacimbar",
    "cacimbeis": "cacimbar",
    "cacimbem": "cacimbar",
    "cacimbemo": "cacimbar",
    "cacimbemos": "cacimbar",
    "cacimbes": "cacimbar",
    "cacimbo": "cacimbar",
    "cacimbou": "cacimbar",
    "cacimbámo": "cacimbar",
    "cacimbámos": "cacimbar",
    "cacimbáramo": "cacimbar",
    "cacimbáramos": "cacimbar",
    "cacimbáreis": "cacimbar",
    "cacimbásseis": "cacimbar",
    "cacimbássemos": "cacimbar",
    "cacimbávamo": "cacimbar",
    "cacimbávamos": "cacimbar",
    "cacimbáveis": "cacimbar",
    "cacique": "cacicar",
    "caciquei": "cacicar",
    "caciqueis": "cacicar",
    "caciquem": "cacicar",
    "caciquemos": "cacicar",
    "caciques": "cacique",
    "caciquismos": "caciquismo",
    "cacizes": "caciz",
    "caclabulha": "caclabulhar",
    "caclabulhada": "caclabulhar",
    "caclabulhadas": "caclabulhar",
    "caclabulhado": "caclabulhar",
    "caclabulhados": "caclabulhar",
    "caclabulhai": "caclabulhar",
    "caclabulhais": "caclabulhar",
    "caclabulham": "caclabulhar",
    "caclabulhamo": "caclabulhar",
    "caclabulhamos": "caclabulhar",
    "caclabulhando": "caclabulhar",
    "caclabulhara": "caclabulhar",
    "caclabulharam": "caclabulhar",
    "caclabulharas": "caclabulhar",
    "caclabulharde": "caclabulhar",
    "caclabulhardes": "caclabulhar",
    "caclabulhare": "caclabulhar",
    "caclabulharei": "caclabulhar",
    "caclabulhareis": "caclabulhar",
    "caclabulharem": "caclabulhar",
    "caclabulharemos": "caclabulhar",
    "caclabulhares": "caclabulhar",
    "caclabulharia": "caclabulhar",
    "caclabulhariam": "caclabulhar",
    "caclabulharias": "caclabulhar",
    "caclabulharmo": "caclabulhar",
    "caclabulharmos": "caclabulhar",
    "caclabulhará": "caclabulhar",
    "caclabulharás": "caclabulhar",
    "caclabulharão": "caclabulhar",
    "caclabulharíamos": "caclabulhar",
    "caclabulharíeis": "caclabulhar",
    "caclabulhas": "caclabulhar",
    "caclabulhasse": "caclabulhar",
    "caclabulhassem": "caclabulhar",
    "caclabulhasses": "caclabulhar",
    "caclabulhaste": "caclabulhar",
    "caclabulhastes": "caclabulhar",
    "caclabulhava": "caclabulhar",
    "caclabulhavam": "caclabulhar",
    "caclabulhavas": "caclabulhar",
    "caclabulhe": "caclabulhar",
    "caclabulhei": "caclabulhar",
    "caclabulheis": "caclabulhar",
    "caclabulhem": "caclabulhar",
    "caclabulhemo": "caclabulhar",
    "caclabulhemos": "caclabulhar",
    "caclabulhes": "caclabulhar",
    "caclabulho": "caclabulhar",
    "caclabulhou": "caclabulhar",
    "caclabulhá": "caclabulhar",
    "caclabulhámo": "caclabulhar",
    "caclabulhámos": "caclabulhar",
    "caclabulháramo": "caclabulhar",
    "caclabulháramos": "caclabulhar",
    "caclabulhárei": "caclabulhar",
    "caclabulháreis": "caclabulhar",
    "caclabulhásseis": "caclabulhar",
    "caclabulhássemos": "caclabulhar",
    "caclabulhávamo": "caclabulhar",
    "caclabulhávamos": "caclabulhar",
    "caclabulhávei": "caclabulhar",
    "caclabulháveis": "caclabulhar",
    "cacodilatos": "cacodilato",
    "cacodilos": "cacodilo",
    "cacodílica": "cacodílico",
    "cacodílicas": "cacodílico",
    "cacodílicos": "cacodílico",
    "cacoeiros": "cacoeiro",
    "cacoestesias": "cacoestesia",
    "cacoetes": "cacoete",
    "cacofagias": "cacofagia",
    "cacofatomanias": "cacofatomania",
    "cacofatomaníaca": "cacofatomaníaco",
    "cacofatomaníacas": "cacofatomaníaco",
    "cacofatomaníacos": "cacofatomaníaco",
    "cacofilias": "cacofilia",
    "cacofonias": "cacofonia",
    "cacofónica": "cacofónico",
    "cacofónicas": "cacofónico",
    "cacofónicos": "cacofónico",
    "cacografa": "cacografar",
    "cacografada": "cacografar",
    "cacografadas": "cacografar",
    "cacografado": "cacografar",
    "cacografados": "cacografar",
    "cacografai": "cacografar",
    "cacografais": "cacografar",
    "cacografam": "cacografar",
    "cacografamo": "cacografar",
    "cacografamos": "cacografar",
    "cacografando": "cacografar",
    "cacografara": "cacografar",
    "cacografaram": "cacografar",
    "cacografaras": "cacografar",
    "cacografarde": "cacografar",
    "cacografardes": "cacografar",
    "cacografare": "cacografar",
    "cacografarei": "cacografar",
    "cacografareis": "cacografar",
    "cacografarem": "cacografar",
    "cacografaremos": "cacografar",
    "cacografares": "cacografar",
    "cacografaria": "cacografar",
    "cacografariam": "cacografar",
    "cacografarias": "cacografar",
    "cacografarmo": "cacografar",
    "cacografarmos": "cacografar",
    "cacografará": "cacografar",
    "cacografarás": "cacografar",
    "cacografarão": "cacografar",
    "cacografaríamos": "cacografar",
    "cacografaríeis": "cacografar",
    "cacografas": "cacografar",
    "cacografasse": "cacografar",
    "cacografassem": "cacografar",
    "cacografasses": "cacografar",
    "cacografaste": "cacografar",
    "cacografastes": "cacografar",
    "cacografava": "cacografar",
    "cacografavam": "cacografar",
    "cacografavas": "cacografar",
    "cacografe": "cacografar",
    "cacografei": "cacografar",
    "cacografeis": "cacografar",
    "cacografem": "cacografar",
    "cacografemo": "cacografar",
    "cacografemos": "cacografar",
    "cacografes": "cacografar",
    "cacografias": "cacografia",
    "cacografo": "cacografar",
    "cacografou": "cacografar",
    "cacografá": "cacografar",
    "cacografámo": "cacografar",
    "cacografámos": "cacografar",
    "cacografáramo": "cacografar",
    "cacografáramos": "cacografar",
    "cacografárei": "cacografar",
    "cacografáreis": "cacografar",
    "cacografásseis": "cacografar",
    "cacografássemos": "cacografar",
    "cacografávamo": "cacografar",
    "cacografávamos": "cacografar",
    "cacografávei": "cacografar",
    "cacografáveis": "cacografar",
    "cacográfica": "cacográfico",
    "cacográficas": "cacográfico",
    "cacográficos": "cacográfico",
    "cacolalias": "cacolalia",
    "cacologias": "cacologia",
    "cacolálica": "cacolálico",
    "cacolálicas": "cacolálico",
    "cacolálicos": "cacolálico",
    "cacológica": "cacológico",
    "cacológicas": "cacológico",
    "cacológicos": "cacológico",
    "cacometrias": "cacometria",
    "cacométrica": "cacométrico",
    "cacométricas": "cacométrico",
    "cacométricos": "cacométrico",
    "cacopatas": "cacopata",
    "cacopatias": "cacopatia",
    "cacoquimias": "cacoquimia",
    "cacoquímica": "cacoquímico",
    "cacoquímicas": "cacoquímico",
    "cacoquímicos": "cacoquímico",
    "cacos": "caco",
    "cacosa": "cacoso",
    "cacosas": "cacoso",
    "cacosmias": "cacosmia",
    "cacosos": "cacoso",
    "cacotecnias": "cacotecnia",
    "cacotécnica": "cacotécnico",
    "cacotécnicas": "cacotécnico",
    "cacotécnicos": "cacotécnico",
    "cacoépias": "cacoépia",
    "cactiformes": "cactiforme",
    "cactos": "cacto",
    "cactácea": "cactáceo",
    "cactáceas": "cactáceo",
    "cactáceos": "cactáceo",
    "cactóides": "cactóide",
    "cacuais": "cacual",
    "cacueiros": "cacueiro",
    "cacuminais": "cacuminal",
    "cacófaga": "cacófago",
    "cacófagas": "cacófago",
    "cacófagos": "cacófago",
    "cacófatons": "cacófaton",
    "cacófatos": "cacófato",
    "cacófila": "cacófilo",
    "cacófilas": "cacófilo",
    "cacófilos": "cacófilo",
    "cacófona": "cacófono",
    "cacófonas": "cacófono",
    "cacófonos": "cacófono",
    "cacógrafa": "cacógrafo",
    "cacógrafas": "cacógrafo",
    "cacógrafos": "cacógrafo",
    "cacúmenes": "cacúmen",
    "cadabulhos": "cadabulho",
    "cadafalsos": "cadafalso",
    "cadaneira": "cadaneiro",
    "cadaneiras": "cadaneiro",
    "cadaneiros": "cadaneiro",
    "cadarços": "cadarço",
    "cadastes": "cadaste",
    "cadastra": "cadastrar",
    "cadastrada": "cadastrar",
    "cadastradas": "cadastrar",
    "cadastrado": "cadastrar",
    "cadastrados": "cadastrar",
    "cadastragens": "cadastragem",
    "cadastrai": "cadastrar",
    "cadastrais": "cadastrar",
    "cadastram": "cadastrar",
    "cadastramo": "cadastrar",
    "cadastramos": "cadastrar",
    "cadastrando": "cadastrar",
    "cadastrara": "cadastrar",
    "cadastraram": "cadastrar",
    "cadastraras": "cadastrar",
    "cadastrarde": "cadastrar",
    "cadastrardes": "cadastrar",
    "cadastrare": "cadastrar",
    "cadastrarei": "cadastrar",
    "cadastrareis": "cadastrar",
    "cadastrarem": "cadastrar",
    "cadastraremos": "cadastrar",
    "cadastrares": "cadastrar",
    "cadastraria": "cadastrar",
    "cadastrariam": "cadastrar",
    "cadastrarias": "cadastrar",
    "cadastrarmo": "cadastrar",
    "cadastrarmos": "cadastrar",
    "cadastrará": "cadastrar",
    "cadastrarás": "cadastrar",
    "cadastrarão": "cadastrar",
    "cadastraríamos": "cadastrar",
    "cadastraríeis": "cadastrar",
    "cadastras": "cadastrar",
    "cadastrasse": "cadastrar",
    "cadastrassem": "cadastrar",
    "cadastrasses": "cadastrar",
    "cadastraste": "cadastrar",
    "cadastrastes": "cadastrar",
    "cadastrava": "cadastrar",
    "cadastravam": "cadastrar",
    "cadastravas": "cadastrar",
    "cadastre": "cadastrar",
    "cadastrei": "cadastrar",
    "cadastreis": "cadastrar",
    "cadastrem": "cadastrar",
    "cadastremo": "cadastrar",
    "cadastremos": "cadastrar",
    "cadastres": "cadastrar",
    "cadastro": "cadastrar",
    "cadastros": "cadastro",
    "cadastrou": "cadastrar",
    "cadastrá": "cadastrar",
    "cadastrámo": "cadastrar",
    "cadastrámos": "cadastrar",
    "cadastráramo": "cadastrar",
    "cadastráramos": "cadastrar",
    "cadastrárei": "cadastrar",
    "cadastráreis": "cadastrar",
    "cadastrásseis": "cadastrar",
    "cadastrássemos": "cadastrar",
    "cadastrávamo": "cadastrar",
    "cadastrávamos": "cadastrar",
    "cadastrávei": "cadastrar",
    "cadastráveis": "cadastrar",
    "cadavais": "cadaval",
    "cadaverinas": "cadaverina",
    "cadaverosa": "cadaveroso",
    "cadaverosas": "cadaveroso",
    "cadaverosos": "cadaveroso",
    "cadavérica": "cadavérico",
    "cadavéricas": "cadavérico",
    "cadavéricos": "cadavérico",
    "cadaxos": "cadaxo",
    "cadeados": "cadeado",
    "cadeeira": "cadeeiro",
    "cadeeiras": "cadeeiro",
    "cadeeiros": "cadeeiro",
    "cadeias": "cadeia",
    "cadeirada": "cadeirado",
    "cadeiradas": "cadeirado",
    "cadeirados": "cadeirado",
    "cadeirais": "cadeiral",
    "cadeiras": "cadeira",
    "cadeirinha": "cadeira",
    "cadeirinhas": "cadeirinha",
    "cadeirita": "cadeira",
    "cadeiritas": "cadeira",
    "cadeirões": "cadeirão",
    "cadeixos": "cadeixo",
    "cadela": "cão",
    "cadelas": "cão",
    "cadelazinha": "cão",
    "cadelazinhas": "cão",
    "cadelazita": "cão",
    "cadelazitas": "cão",
    "cadelinha": "cão",
    "cadelinhas": "cão",
    "cadelita": "cão",
    "cadelitas": "cão",
    "cadelonas": "cadelona",
    "cadelos": "cadelo",
    "cadencia": "cadenciar",
    "cadenciada": "cadenciar",
    "cadenciadas": "cadenciar",
    "cadenciado": "cadenciar",
    "cadenciados": "cadenciar",
    "cadenciai": "cadenciar",
    "cadenciais": "cadenciar",
    "cadenciam": "cadenciar",
    "cadenciamo": "cadenciar",
    "cadenciamos": "cadenciar",
    "cadenciando": "cadenciar",
    "cadenciara": "cadenciar",
    "cadenciaram": "cadenciar",
    "cadenciaras": "cadenciar",
    "cadenciarde": "cadenciar",
    "cadenciardes": "cadenciar",
    "cadenciare": "cadenciar",
    "cadenciarei": "cadenciar",
    "cadenciareis": "cadenciar",
    "cadenciarem": "cadenciar",
    "cadenciaremos": "cadenciar",
    "cadenciares": "cadenciar",
    "cadenciaria": "cadenciar",
    "cadenciariam": "cadenciar",
    "cadenciarias": "cadenciar",
    "cadenciarmo": "cadenciar",
    "cadenciarmos": "cadenciar",
    "cadenciará": "cadenciar",
    "cadenciarás": "cadenciar",
    "cadenciarão": "cadenciar",
    "cadenciaríamos": "cadenciar",
    "cadenciaríeis": "cadenciar",
    "cadencias": "cadenciar",
    "cadenciasse": "cadenciar",
    "cadenciassem": "cadenciar",
    "cadenciasses": "cadenciar",
    "cadenciaste": "cadenciar",
    "cadenciastes": "cadenciar",
    "cadenciava": "cadenciar",
    "cadenciavam": "cadenciar",
    "cadenciavas": "cadenciar",
    "cadencie": "cadenciar",
    "cadenciei": "cadenciar",
    "cadencieis": "cadenciar",
    "cadenciem": "cadenciar",
    "cadenciemo": "cadenciar",
    "cadenciemos": "cadenciar",
    "cadencies": "cadenciar",
    "cadencio": "cadenciar",
    "cadenciosa": "cadencioso",
    "cadenciosas": "cadencioso",
    "cadenciosos": "cadencioso",
    "cadenciou": "cadenciar",
    "cadenciá": "cadenciar",
    "cadenciámo": "cadenciar",
    "cadenciámos": "cadenciar",
    "cadenciáramo": "cadenciar",
    "cadenciáramos": "cadenciar",
    "cadenciárei": "cadenciar",
    "cadenciáreis": "cadenciar",
    "cadenciásseis": "cadenciar",
    "cadenciássemos": "cadenciar",
    "cadenciávamo": "cadenciar",
    "cadenciávamos": "cadenciar",
    "cadenciávei": "cadenciar",
    "cadenciáveis": "cadenciar",
    "cadenilhas": "cadenilha",
    "cadentes": "cadente",
    "cadernais": "cadernal",
    "cadernas": "caderna",
    "cadernaços": "cadernaço",
    "cadernetas": "caderneta",
    "caderninho": "caderno",
    "caderninhos": "caderno",
    "cadernito": "caderno",
    "cadernitos": "caderno",
    "cadernos": "caderno",
    "cades": "cade",
    "cadetes": "cadete",
    "cadexos": "cadexo",
    "cadilhas": "cadilha",
    "cadilhos": "cadilho",
    "cadima": "cadimo",
    "cadimas": "cadimo",
    "cadimes": "cadime",
    "cadimos": "cadimo",
    "cadinhos": "cadinho",
    "cadiva": "cadivo",
    "cadivas": "cadivo",
    "cadivos": "cadivo",
    "cadmeia": "cadmeu",
    "cadmeias": "cadmeu",
    "cadmeus": "cadmeu",
    "cadmias": "cadmia",
    "cadornos": "cadorno",
    "cados": "cado",
    "cadouras": "cadoura",
    "cadouços": "cadouço",
    "cadoxos": "cadoxo",
    "cadozes": "cadoz",
    "caduca": "caduco",
    "caducada": "caducar",
    "caducadas": "caducar",
    "caducado": "caducar",
    "caducados": "caducar",
    "caducais": "caducar",
    "caducam": "caducar",
    "caducamo": "caducar",
    "caducamos": "caducar",
    "caducando": "caducar",
    "caducantes": "caducante",
    "caducara": "caducar",
    "caducaram": "caducar",
    "caducaras": "caducar",
    "caducardes": "caducar",
    "caducarei": "caducar",
    "caducareis": "caducar",
    "caducarem": "caducar",
    "caducaremos": "caducar",
    "caducares": "caducar",
    "caducaria": "caducar",
    "caducariam": "caducar",
    "caducarias": "caducar",
    "caducarmo": "caducar",
    "caducarmos": "caducar",
    "caducará": "caducar",
    "caducarás": "caducar",
    "caducarão": "caducar",
    "caducaríamos": "caducar",
    "caducaríeis": "caducar",
    "caducas": "caduco",
    "caducasse": "caducar",
    "caducassem": "caducar",
    "caducasses": "caducar",
    "caducaste": "caducar",
    "caducastes": "caducar",
    "caducava": "caducar",
    "caducavam": "caducar",
    "caducavas": "caducar",
    "caduceadora": "caduceador",
    "caduceadoras": "caduceador",
    "caduceadores": "caduceador",
    "caduceus": "caduceu",
    "caducibrânqia": "caducibrânqio",
    "caducibrânqias": "caducibrânqio",
    "caducibrânqios": "caducibrânqio",
    "caducibrânquios": "caducibrânquio",
    "caducidades": "caducidade",
    "caducifólia": "caducifólio",
    "caducifólias": "caducifólio",
    "caducifólios": "caducifólio",
    "caduco": "caducar",
    "caducos": "caduco",
    "caducou": "caducar",
    "caducámo": "caducar",
    "caducámos": "caducar",
    "caducáramo": "caducar",
    "caducáramos": "caducar",
    "caducáreis": "caducar",
    "caducária": "caducário",
    "caducárias": "caducário",
    "caducários": "caducário",
    "caducásseis": "caducar",
    "caducássemos": "caducar",
    "caducávamo": "caducar",
    "caducávamos": "caducar",
    "caducáveis": "caducar",
    "caducífera": "caducífero",
    "caducíferas": "caducífero",
    "caducíferos": "caducífero",
    "caduque": "caducar",
    "caduquei": "caducar",
    "caduqueis": "caducar",
    "caduquem": "caducar",
    "caduquemos": "caducar",
    "caduques": "caducar",
    "caduquices": "caduquice",
    "cadáveres": "cadáver",
    "cadências": "cadência",
    "caem": "cair",
    "cafais": "cafal",
    "cafajestes": "cafajeste",
    "cafarnauns": "cafarnaum",
    "cafeais": "cafeal",
    "cafedórios": "cafedório",
    "cafeeira": "cafeeiro",
    "cafeeirais": "cafeeiral",
    "cafeeiras": "cafeeiro",
    "cafeeiros": "cafeeiro",
    "cafeica": "cafeico",
    "cafeicas": "cafeico",
    "cafeicos": "cafeico",
    "cafeicultora": "cafeicultor",
    "cafeicultoras": "cafeicultor",
    "cafeicultores": "cafeicultor",
    "cafeiculturas": "cafeicultura",
    "cafeinismos": "cafeinismo",
    "cafeocracias": "cafeocracia",
    "cafeonas": "cafeona",
    "cafetarias": "cafetaria",
    "cafeteira": "cafeteiro",
    "cafeteiras": "cafeteiro",
    "cafeteiros": "cafeteiro",
    "cafetãs": "cafetã",
    "cafezadas": "cafezada",
    "cafezais": "cafezal",
    "cafezeira": "cafezeiro",
    "cafezeirais": "cafezeiral",
    "cafezeiras": "cafezeiro",
    "cafezeiros": "cafezeiro",
    "cafezinho": "café",
    "cafezinhos": "café",
    "cafezistas": "cafezista",
    "cafezito": "café",
    "cafezitos": "café",
    "cafeísmos": "cafeísmo",
    "cafrarias": "cafraria",
    "cafreais": "cafreal",
    "cafres": "cafre",
    "cafrices": "cafrice",
    "caftas": "cafta",
    "cafuas": "cafua",
    "cafunés": "cafuné",
    "cafurnas": "cafurna",
    "cafuza": "cafuzo",
    "cafuzas": "cafuzo",
    "cafuzos": "cafuzo",
    "cafés": "café",
    "caga": "cagar",
    "cagada": "cagar",
    "cagadas": "cagar",
    "cagado": "cagar",
    "cagados": "cagar",
    "cagai": "cagar",
    "cagais": "cagar",
    "cagaitas": "cagaita",
    "cagaiteiras": "cagaiteira",
    "cagalhões": "cagalhão",
    "cagam": "cagar",
    "cagamassos": "cagamasso",
    "cagamo": "cagar",
    "cagamos": "cagar",
    "caganatos": "caganato",
    "cagando": "cagar",
    "caganeiras": "caganeira",
    "caganetas": "caganeta",
    "caganifrantes": "caganifrante",
    "caganifâncias": "caganifância",
    "caganita": "caganito",
    "caganitas": "caganito",
    "caganitos": "caganito",
    "cagara": "cagar",
    "cagaram": "cagar",
    "cagaras": "cagar",
    "cagarde": "cagar",
    "cagardes": "cagar",
    "cagare": "cagar",
    "cagarei": "cagar",
    "cagareis": "cagar",
    "cagarem": "cagar",
    "cagaremos": "cagar",
    "cagares": "cagar",
    "cagaria": "cagar",
    "cagariam": "cagar",
    "cagarias": "cagar",
    "cagarmo": "cagar",
    "cagarmos": "cagar",
    "cagarolas": "cagarola",
    "cagarrazes": "cagarraz",
    "cagarretaa": "cagarreta",
    "cagarretaas": "cagarreta",
    "cagarretaes": "cagarreta",
    "cagará": "cagar",
    "cagarás": "cagar",
    "cagarão": "cagar",
    "cagaréus": "cagaréu",
    "cagaríamos": "cagar",
    "cagaríeis": "cagar",
    "cagas": "cagar",
    "cagasse": "cagar",
    "cagassem": "cagar",
    "cagasses": "cagar",
    "cagaste": "cagar",
    "cagastes": "cagar",
    "cagava": "cagar",
    "cagavam": "cagar",
    "cagavas": "cagar",
    "cagaçais": "cagaçal",
    "cagaços": "cagaço",
    "cago": "cagar",
    "cagona": "cagão",
    "cagonas": "cagão",
    "cagou": "cagar",
    "cague": "cagar",
    "caguei": "cagar",
    "cagueis": "cagar",
    "caguem": "cagar",
    "caguemo": "cagar",
    "caguemos": "cagar",
    "cagues": "cagar",
    "caguinchas": "caguincha",
    "cagunços": "cagunço",
    "cagá": "cagar",
    "cagámo": "cagar",
    "cagámos": "cagar",
    "cagáramo": "cagar",
    "cagáramos": "cagar",
    "cagárei": "cagar",
    "cagáreis": "cagar",
    "cagásseis": "cagar",
    "cagássemos": "cagar",
    "cagávamo": "cagar",
    "cagávamos": "cagar",
    "cagávei": "cagar",
    "cagáveis": "cagar",
    "cagões": "cagão",
    "caheira": "caheiro",
    "caheiras": "caheiro",
    "caheiros": "caheiro",
    "cai": "cair",
    "caia": "cair",
    "caiada": "caiar",
    "caiadas": "caiar",
    "caiadelas": "caiadela",
    "caiado": "caiar",
    "caiadora": "caiador",
    "caiadoras": "caiador",
    "caiadores": "caiador",
    "caiados": "caiar",
    "caiaduras": "caiadura",
    "caiai": "caiar",
    "caiais": "cair",
    "caiam": "cair",
    "caiamo": "cair",
    "caiamos": "cair",
    "caiando": "caiar",
    "caiaques": "caiaque",
    "caiara": "caiar",
    "caiaram": "caiar",
    "caiaras": "caiar",
    "caiarde": "caiar",
    "caiardes": "caiar",
    "caiare": "caiar",
    "caiarei": "caiar",
    "caiareis": "caiar",
    "caiarem": "caiar",
    "caiaremos": "caiar",
    "caiares": "caiar",
    "caiaria": "caiar",
    "caiariam": "caiar",
    "caiarias": "caiar",
    "caiarmo": "caiar",
    "caiarmos": "caiar",
    "caiará": "caiar",
    "caiarás": "caiar",
    "caiarão": "caiar",
    "caiaríamos": "caiar",
    "caiaríeis": "caiar",
    "caias": "cair",
    "caiasse": "caiar",
    "caiassem": "caiar",
    "caiasses": "caiar",
    "caiaste": "caiar",
    "caiastes": "caiar",
    "caiava": "caiar",
    "caiavam": "caiar",
    "caiavas": "caiar",
    "caiações": "caiação",
    "caiba": "caber",
    "caibais": "caber",
    "caibam": "caber",
    "caibamo": "caber",
    "caibamos": "caber",
    "caibas": "caber",
    "caibo": "caber",
    "caibra": "caibrar",
    "caibrada": "caibrar",
    "caibradas": "caibrar",
    "caibrado": "caibrar",
    "caibrados": "caibrar",
    "caibrai": "caibrar",
    "caibrais": "caibrar",
    "caibram": "caibrar",
    "caibramentos": "caibramento",
    "caibramo": "caibrar",
    "caibramos": "caibrar",
    "caibrando": "caibrar",
    "caibrara": "caibrar",
    "caibraram": "caibrar",
    "caibraras": "caibrar",
    "caibrarde": "caibrar",
    "caibrardes": "caibrar",
    "caibrare": "caibrar",
    "caibrarei": "caibrar",
    "caibrareis": "caibrar",
    "caibrarem": "caibrar",
    "caibraremos": "caibrar",
    "caibrares": "caibrar",
    "caibraria": "caibrar",
    "caibrariam": "caibrar",
    "caibrarias": "caibrar",
    "caibrarmo": "caibrar",
    "caibrarmos": "caibrar",
    "caibrará": "caibrar",
    "caibrarás": "caibrar",
    "caibrarão": "caibrar",
    "caibraríamos": "caibrar",
    "caibraríeis": "caibrar",
    "caibras": "caibrar",
    "caibrasse": "caibrar",
    "caibrassem": "caibrar",
    "caibrasses": "caibrar",
    "caibraste": "caibrar",
    "caibrastes": "caibrar",
    "caibrava": "caibrar",
    "caibravam": "caibrar",
    "caibravas": "caibrar",
    "caibre": "caibrar",
    "caibrei": "caibrar",
    "caibreis": "caibrar",
    "caibrem": "caibrar",
    "caibremo": "caibrar",
    "caibremos": "caibrar",
    "caibres": "caibrar",
    "caibro": "caibrar",
    "caibros": "caibro",
    "caibrou": "caibrar",
    "caibrá": "caibrar",
    "caibrámo": "caibrar",
    "caibrámos": "caibrar",
    "caibráramo": "caibrar",
    "caibráramos": "caibrar",
    "caibrárei": "caibrar",
    "caibráreis": "caibrar",
    "caibrásseis": "caibrar",
    "caibrássemos": "caibrar",
    "caibrávamo": "caibrar",
    "caibrávamos": "caibrar",
    "caibrávei": "caibrar",
    "caibráveis": "caibrar",
    "caicais": "caicai",
    "caicanhas": "caicanha",
    "caideira": "caideiro",
    "caideiras": "caideiro",
    "caideiros": "caideiro",
    "caidelas": "caidela",
    "caides": "caide",
    "caidinha": "caído",
    "caidinhas": "caído",
    "caidinho": "caído",
    "caidinhos": "caído",
    "caidita": "caído",
    "caiditas": "caído",
    "caidito": "caído",
    "caiditos": "caído",
    "caidiça": "caidiço",
    "caidiças": "caidiço",
    "caidiços": "caidiço",
    "caie": "caiar",
    "caiei": "caiar",
    "caieiras": "caieira",
    "caieiros": "caieiro",
    "caieis": "caiar",
    "caiem": "caiar",
    "caiemo": "caiar",
    "caiemos": "caiar",
    "caienas": "caiena",
    "caies": "caiar",
    "caimentos": "caimento",
    "caimões": "caimão",
    "caince": "cainçar",
    "caincei": "cainçar",
    "cainceis": "cainçar",
    "caincem": "cainçar",
    "caincemo": "cainçar",
    "caincemos": "cainçar",
    "cainces": "cainçar",
    "caindo": "cair",
    "cainha": "cainho",
    "cainhada": "cainhar",
    "cainhadas": "cainhar",
    "cainhado": "cainhar",
    "cainhados": "cainhar",
    "cainhai": "cainhar",
    "cainhais": "cainhar",
    "cainham": "cainhar",
    "cainhamo": "cainhar",
    "cainhamos": "cainhar",
    "cainhando": "cainhar",
    "cainhara": "cainhar",
    "cainharam": "cainhar",
    "cainharas": "cainhar",
    "cainhardes": "cainhar",
    "cainharei": "cainhar",
    "cainhareis": "cainhar",
    "cainharem": "cainhar",
    "cainharemos": "cainhar",
    "cainhares": "cainhar",
    "cainharia": "cainhar",
    "cainhariam": "cainhar",
    "cainharias": "cainhar",
    "cainharmo": "cainhar",
    "cainharmos": "cainhar",
    "cainhará": "cainhar",
    "cainharás": "cainhar",
    "cainharão": "cainhar",
    "cainharíamos": "cainhar",
    "cainharíeis": "cainhar",
    "cainhas": "cainho",
    "cainhasse": "cainhar",
    "cainhassem": "cainhar",
    "cainhasses": "cainhar",
    "cainhaste": "cainhar",
    "cainhastes": "cainhar",
    "cainhava": "cainhar",
    "cainhavam": "cainhar",
    "cainhavas": "cainhar",
    "cainhe": "cainhar",
    "cainhei": "cainhar",
    "cainheis": "cainhar",
    "cainhem": "cainhar",
    "cainhemo": "cainhar",
    "cainhemos": "cainhar",
    "cainhes": "cainhar",
    "cainhezas": "cainheza",
    "cainho": "cainhar",
    "cainhos": "cainho",
    "cainhou": "cainhar",
    "cainhámo": "cainhar",
    "cainhámos": "cainhar",
    "cainháramo": "cainhar",
    "cainháramos": "cainhar",
    "cainháreis": "cainhar",
    "cainhásseis": "cainhar",
    "cainhássemos": "cainhar",
    "cainhávamo": "cainhar",
    "cainhávamos": "cainhar",
    "cainháveis": "cainhar",
    "cains": "caim",
    "cainça": "cainçar",
    "cainçada": "cainçar",
    "cainçadas": "cainçar",
    "cainçado": "cainçar",
    "cainçados": "cainçar",
    "cainçai": "cainçar",
    "cainçais": "cainçar",
    "cainçalhas": "cainçalha",
    "cainçam": "cainçar",
    "cainçamo": "cainçar",
    "cainçamos": "cainçar",
    "cainçando": "cainçar",
    "cainçara": "cainçar",
    "cainçaram": "cainçar",
    "cainçaras": "cainçar",
    "cainçardes": "cainçar",
    "cainçarei": "cainçar",
    "cainçareis": "cainçar",
    "cainçarem": "cainçar",
    "cainçaremos": "cainçar",
    "cainçares": "cainçar",
    "cainçaria": "cainçar",
    "cainçariam": "cainçar",
    "cainçarias": "cainçar",
    "cainçarmo": "cainçar",
    "cainçarmos": "cainçar",
    "cainçará": "cainçar",
    "cainçarás": "cainçar",
    "cainçarão": "cainçar",
    "cainçaríamos": "cainçar",
    "cainçaríeis": "cainçar",
    "cainças": "cainçar",
    "cainçasse": "cainçar",
    "cainçassem": "cainçar",
    "cainçasses": "cainçar",
    "cainçaste": "cainçar",
    "cainçastes": "cainçar",
    "cainçava": "cainçar",
    "cainçavam": "cainçar",
    "cainçavas": "cainçar",
    "cainçentas": "cainçenta",
    "cainço": "cainçar",
    "cainçou": "cainçar",
    "cainçámo": "cainçar",
    "cainçámos": "cainçar",
    "cainçáramo": "cainçar",
    "cainçáramos": "cainçar",
    "cainçáreis": "cainçar",
    "cainçásseis": "cainçar",
    "cainçássemos": "cainçar",
    "cainçávamo": "cainçar",
    "cainçávamos": "cainçar",
    "cainçáveis": "cainçar",
    "caio": "cair",
    "caiorros": "caiorro",
    "caios": "caio",
    "caiotas": "caiota",
    "caiou": "caiar",
    "caipiradas": "caipirada",
    "caipiras": "caipira",
    "caipirinhas": "caipirinha",
    "caiporas": "caipora",
    "caiporices": "caiporice",
    "caiporismos": "caiporismo",
    "caiqueira": "caiqueiro",
    "caiqueiras": "caiqueiro",
    "caiqueiros": "caiqueiro",
    "cairdes": "cair",
    "cairei": "cair",
    "caireis": "cair",
    "cairemos": "cair",
    "cairia": "cair",
    "cairiam": "cair",
    "cairias": "cair",
    "cairmo": "cair",
    "cairmos": "cair",
    "cairos": "cairo",
    "cairotas": "cairota",
    "cairá": "cair",
    "cairás": "cair",
    "cairão": "cair",
    "cairéis": "cairel",
    "cairíamos": "cair",
    "cairíeis": "cair",
    "cais": "cal",
    "caititus": "caititu",
    "caitoniácea": "caitoniáceo",
    "caitoniáceas": "caitoniáceo",
    "caitoniáceos": "caitoniáceo",
    "caitónias": "caitónia",
    "caiu": "cair",
    "caixarias": "caixaria",
    "caixas": "caixa",
    "caixeira": "caixeiro",
    "caixeiradas": "caixeirada",
    "caixeirais": "caixeiral",
    "caixeiras": "caixeiro",
    "caixeiros": "caixeiro",
    "caixetas": "caixeta",
    "caixilhames": "caixilhame",
    "caixilharias": "caixilharia",
    "caixilhos": "caixilho",
    "caixinha": "caixa",
    "caixinhas": "caixa",
    "caixistas": "caixista",
    "caixita": "caixa",
    "caixitas": "caixa",
    "caixotarias": "caixotaria",
    "caixoteira": "caixoteiro",
    "caixoteiras": "caixoteiro",
    "caixoteiros": "caixoteiro",
    "caixotes": "caixote",
    "caixotins": "caixotim",
    "caixotos": "caixoto",
    "caixotões": "caixotão",
    "caixões": "caixão",
    "caiá": "caiar",
    "caiámo": "caiar",
    "caiámos": "caiar",
    "caiáramo": "caiar",
    "caiáramos": "caiar",
    "caiárei": "caiar",
    "caiáreis": "caiar",
    "caiásseis": "caiar",
    "caiássemos": "caiar",
    "caiávamo": "caiar",
    "caiávamos": "caiar",
    "caiávei": "caiar",
    "caiáveis": "caiar",
    "cajadadas": "cajadada",
    "cajados": "cajado",
    "cajaranas": "cajarana",
    "cajazeiras": "cajazeira",
    "cajazeiros": "cajazeiro",
    "cajuadas": "cajuada",
    "cajuais": "cajual",
    "cajueirais": "cajueiral",
    "cajueiros": "cajueiro",
    "cajus": "caju",
    "cajuzeiros": "cajuzeiro",
    "cajuínas": "cajuína",
    "cajuís": "cajuí",
    "cajás": "cajá",
    "cala": "calar",
    "calabaças": "calabaça",
    "calaboiços": "calaboiço",
    "calabouços": "calabouço",
    "calabres": "calabre",
    "calabresa": "calabrês",
    "calabresas": "calabrês",
    "calabreses": "calabrês",
    "calabretes": "calabrete",
    "calabriana": "calabriano",
    "calabrianas": "calabriano",
    "calabrianos": "calabriano",
    "calabrotes": "calabrote",
    "calaceada": "calacear",
    "calaceadas": "calacear",
    "calaceado": "calacear",
    "calaceados": "calacear",
    "calaceai": "calacear",
    "calaceais": "calacear",
    "calaceamo": "calacear",
    "calaceamos": "calacear",
    "calaceando": "calacear",
    "calaceara": "calacear",
    "calacearam": "calacear",
    "calacearas": "calacear",
    "calaceardes": "calacear",
    "calacearei": "calacear",
    "calaceareis": "calacear",
    "calacearem": "calacear",
    "calacearemos": "calacear",
    "calaceares": "calacear",
    "calacearia": "calacear",
    "calaceariam": "calacear",
    "calacearias": "calacear",
    "calacearmo": "calacear",
    "calacearmos": "calacear",
    "calaceará": "calacear",
    "calacearás": "calacear",
    "calacearão": "calacear",
    "calacearíamos": "calacear",
    "calacearíeis": "calacear",
    "calaceasse": "calacear",
    "calaceassem": "calacear",
    "calaceasses": "calacear",
    "calaceaste": "calacear",
    "calaceastes": "calacear",
    "calaceava": "calacear",
    "calaceavam": "calacear",
    "calaceavas": "calacear",
    "calaceei": "calacear",
    "calaceeis": "calacear",
    "calaceemo": "calacear",
    "calaceemos": "calacear",
    "calaceia": "calacear",
    "calaceiam": "calacear",
    "calaceias": "calacear",
    "calaceie": "calacear",
    "calaceiem": "calacear",
    "calaceies": "calacear",
    "calaceio": "calacear",
    "calaceira": "calaceiro",
    "calaceirada": "calaceirar",
    "calaceiradas": "calaceirar",
    "calaceirado": "calaceirar",
    "calaceirados": "calaceirar",
    "calaceirai": "calaceirar",
    "calaceirais": "calaceirar",
    "calaceiram": "calaceirar",
    "calaceiramo": "calaceirar",
    "calaceiramos": "calaceirar",
    "calaceirando": "calaceirar",
    "calaceirara": "calaceirar",
    "calaceiraram": "calaceirar",
    "calaceiraras": "calaceirar",
    "calaceirardes": "calaceirar",
    "calaceirarei": "calaceirar",
    "calaceirareis": "calaceirar",
    "calaceirarem": "calaceirar",
    "calaceiraremos": "calaceirar",
    "calaceirares": "calaceirar",
    "calaceiraria": "calaceirar",
    "calaceirariam": "calaceirar",
    "calaceirarias": "calaceirar",
    "calaceirarmo": "calaceirar",
    "calaceirarmos": "calaceirar",
    "calaceirará": "calaceirar",
    "calaceirarás": "calaceirar",
    "calaceirarão": "calaceirar",
    "calaceiraríamos": "calaceirar",
    "calaceiraríeis": "calaceirar",
    "calaceiras": "calaceiro",
    "calaceirasse": "calaceirar",
    "calaceirassem": "calaceirar",
    "calaceirasses": "calaceirar",
    "calaceiraste": "calaceirar",
    "calaceirastes": "calaceirar",
    "calaceirava": "calaceirar",
    "calaceiravam": "calaceirar",
    "calaceiravas": "calaceirar",
    "calaceire": "calaceirar",
    "calaceirei": "calaceirar",
    "calaceireis": "calaceirar",
    "calaceirem": "calaceirar",
    "calaceiremo": "calaceirar",
    "calaceiremos": "calaceirar",
    "calaceires": "calaceirar",
    "calaceirices": "calaceirice",
    "calaceiro": "calaceirar",
    "calaceiros": "calaceiro",
    "calaceirou": "calaceirar",
    "calaceirámo": "calaceirar",
    "calaceirámos": "calaceirar",
    "calaceiráramo": "calaceirar",
    "calaceiráramos": "calaceirar",
    "calaceiráreis": "calaceirar",
    "calaceirásseis": "calaceirar",
    "calaceirássemos": "calaceirar",
    "calaceirávamo": "calaceirar",
    "calaceirávamos": "calaceirar",
    "calaceiráveis": "calaceirar",
    "calaceou": "calacear",
    "calaceámo": "calacear",
    "calaceámos": "calacear",
    "calaceáramo": "calacear",
    "calaceáramos": "calacear",
    "calaceáreis": "calacear",
    "calaceásseis": "calacear",
    "calaceássemos": "calacear",
    "calaceávamo": "calacear",
    "calaceávamos": "calacear",
    "calaceáveis": "calacear",
    "calacices": "calacice",
    "calacres": "calacre",
    "calada": "calar",
    "caladas": "calar",
    "caladinha": "calado",
    "caladinhas": "calado",
    "caladinho": "calado",
    "caladinhos": "calado",
    "caladita": "calado",
    "caladitas": "calado",
    "caladito": "calado",
    "caladitos": "calado",
    "calado": "calar",
    "caladores": "calador",
    "calados": "calar",
    "caladuras": "caladura",
    "caladíssima": "calado",
    "caladíssimas": "calado",
    "caladíssimo": "calado",
    "caladíssimos": "calado",
    "calafates": "calafate",
    "calafeta": "calafetar",
    "calafetada": "calafetar",
    "calafetadas": "calafetar",
    "calafetado": "calafetar",
    "calafetados": "calafetar",
    "calafetagens": "calafetagem",
    "calafetai": "calafetar",
    "calafetais": "calafetar",
    "calafetam": "calafetar",
    "calafetamentos": "calafetamento",
    "calafetamo": "calafetar",
    "calafetamos": "calafetar",
    "calafetando": "calafetar",
    "calafetara": "calafetar",
    "calafetaram": "calafetar",
    "calafetaras": "calafetar",
    "calafetarde": "calafetar",
    "calafetardes": "calafetar",
    "calafetare": "calafetar",
    "calafetarei": "calafetar",
    "calafetareis": "calafetar",
    "calafetarem": "calafetar",
    "calafetaremos": "calafetar",
    "calafetares": "calafetar",
    "calafetaria": "calafetar",
    "calafetariam": "calafetar",
    "calafetarias": "calafetar",
    "calafetarmo": "calafetar",
    "calafetarmos": "calafetar",
    "calafetará": "calafetar",
    "calafetarás": "calafetar",
    "calafetarão": "calafetar",
    "calafetaríamos": "calafetar",
    "calafetaríeis": "calafetar",
    "calafetas": "calafetar",
    "calafetasse": "calafetar",
    "calafetassem": "calafetar",
    "calafetasses": "calafetar",
    "calafetaste": "calafetar",
    "calafetastes": "calafetar",
    "calafetava": "calafetar",
    "calafetavam": "calafetar",
    "calafetavas": "calafetar",
    "calafetações": "calafetação",
    "calafete": "calafetar",
    "calafetei": "calafetar",
    "calafeteis": "calafetar",
    "calafetem": "calafetar",
    "calafetemo": "calafetar",
    "calafetemos": "calafetar",
    "calafetes": "calafetar",
    "calafeto": "calafetar",
    "calafetos": "calafeto",
    "calafetou": "calafetar",
    "calafetá": "calafetar",
    "calafetámo": "calafetar",
    "calafetámos": "calafetar",
    "calafetáramo": "calafetar",
    "calafetáramos": "calafetar",
    "calafetárei": "calafetar",
    "calafetáreis": "calafetar",
    "calafetásseis": "calafetar",
    "calafetássemos": "calafetar",
    "calafetávamo": "calafetar",
    "calafetávamos": "calafetar",
    "calafetávei": "calafetar",
    "calafetáveis": "calafetável",
    "calafrios": "calafrio",
    "calagens": "calagem",
    "calagoiçadas": "calagoiçada",
    "calagoiças": "calagoiça",
    "calagoiços": "calagoiço",
    "calagouçadas": "calagouçada",
    "calagouças": "calagouça",
    "calagouços": "calagouço",
    "calai": "calar",
    "calais": "calar",
    "calam": "calar",
    "calamares": "calamar",
    "calambaques": "calambaque",
    "calambucas": "calambuca",
    "calambucos": "calambuco",
    "calambuques": "calambuque",
    "calambás": "calambá",
    "calamentos": "calamento",
    "calamidades": "calamidade",
    "calamiformes": "calamiforme",
    "calaminas": "calamina",
    "calamintas": "calaminta",
    "calamistra": "calamistrar",
    "calamistrada": "calamistrar",
    "calamistradas": "calamistrar",
    "calamistrado": "calamistrar",
    "calamistrados": "calamistrar",
    "calamistrai": "calamistrar",
    "calamistrais": "calamistrar",
    "calamistram": "calamistrar",
    "calamistramo": "calamistrar",
    "calamistramos": "calamistrar",
    "calamistrando": "calamistrar",
    "calamistrara": "calamistrar",
    "calamistraram": "calamistrar",
    "calamistraras": "calamistrar",
    "calamistrarde": "calamistrar",
    "calamistrardes": "calamistrar",
    "calamistrare": "calamistrar",
    "calamistrarei": "calamistrar",
    "calamistrareis": "calamistrar",
    "calamistrarem": "calamistrar",
    "calamistraremos": "calamistrar",
    "calamistrares": "calamistrar",
    "calamistraria": "calamistrar",
    "calamistrariam": "calamistrar",
    "calamistrarias": "calamistrar",
    "calamistrarmo": "calamistrar",
    "calamistrarmos": "calamistrar",
    "calamistrará": "calamistrar",
    "calamistrarás": "calamistrar",
    "calamistrarão": "calamistrar",
    "calamistraríamos": "calamistrar",
    "calamistraríeis": "calamistrar",
    "calamistras": "calamistrar",
    "calamistrasse": "calamistrar",
    "calamistrassem": "calamistrar",
    "calamistrasses": "calamistrar",
    "calamistraste": "calamistrar",
    "calamistrastes": "calamistrar",
    "calamistrava": "calamistrar",
    "calamistravam": "calamistrar",
    "calamistravas": "calamistrar",
    "calamistre": "calamistrar",
    "calamistrei": "calamistrar",
    "calamistreis": "calamistrar",
    "calamistrem": "calamistrar",
    "calamistremo": "calamistrar",
    "calamistremos": "calamistrar",
    "calamistres": "calamistrar",
    "calamistro": "calamistrar",
    "calamistros": "calamistro",
    "calamistrou": "calamistrar",
    "calamistrá": "calamistrar",
    "calamistrámo": "calamistrar",
    "calamistrámos": "calamistrar",
    "calamistráramo": "calamistrar",
    "calamistráramos": "calamistrar",
    "calamistrárei": "calamistrar",
    "calamistráreis": "calamistrar",
    "calamistrásseis": "calamistrar",
    "calamistrássemos": "calamistrar",
    "calamistrávamo": "calamistrar",
    "calamistrávamos": "calamistrar",
    "calamistrávei": "calamistrar",
    "calamistráveis": "calamistrar",
    "calamitas": "calamita",
    "calamites": "calamite",
    "calamitosa": "calamitoso",
    "calamitosas": "calamitoso",
    "calamitosos": "calamitoso",
    "calamo": "calar",
    "calamoca": "calamocar",
    "calamocada": "calamocar",
    "calamocadas": "calamocar",
    "calamocado": "calamocar",
    "calamocados": "calamocar",
    "calamocai": "calamocar",
    "calamocais": "calamocar",
    "calamocam": "calamocar",
    "calamocamo": "calamocar",
    "calamocamos": "calamocar",
    "calamocando": "calamocar",
    "calamocara": "calamocar",
    "calamocaram": "calamocar",
    "calamocaras": "calamocar",
    "calamocarde": "calamocar",
    "calamocardes": "calamocar",
    "calamocare": "calamocar",
    "calamocarei": "calamocar",
    "calamocareis": "calamocar",
    "calamocarem": "calamocar",
    "calamocaremos": "calamocar",
    "calamocares": "calamocar",
    "calamocaria": "calamocar",
    "calamocariam": "calamocar",
    "calamocarias": "calamocar",
    "calamocarmo": "calamocar",
    "calamocarmos": "calamocar",
    "calamocará": "calamocar",
    "calamocarás": "calamocar",
    "calamocarão": "calamocar",
    "calamocaríamos": "calamocar",
    "calamocaríeis": "calamocar",
    "calamocas": "calamocar",
    "calamocasse": "calamocar",
    "calamocassem": "calamocar",
    "calamocasses": "calamocar",
    "calamocaste": "calamocar",
    "calamocastes": "calamocar",
    "calamocava": "calamocar",
    "calamocavam": "calamocar",
    "calamocavas": "calamocar",
    "calamoco": "calamocar",
    "calamocou": "calamocar",
    "calamocá": "calamocar",
    "calamocámo": "calamocar",
    "calamocámos": "calamocar",
    "calamocáramo": "calamocar",
    "calamocáramos": "calamocar",
    "calamocárei": "calamocar",
    "calamocáreis": "calamocar",
    "calamocásseis": "calamocar",
    "calamocássemos": "calamocar",
    "calamocávamo": "calamocar",
    "calamocávamos": "calamocar",
    "calamocávei": "calamocar",
    "calamocáveis": "calamocar",
    "calamoque": "calamocar",
    "calamoquei": "calamocar",
    "calamoqueis": "calamocar",
    "calamoquem": "calamocar",
    "calamoquemo": "calamocar",
    "calamoquemos": "calamocar",
    "calamoques": "calamocar",
    "calamos": "calar",
    "calamários": "calamário",
    "calamídea": "calamídeo",
    "calamídeas": "calamídeo",
    "calamídeos": "calamídeo",
    "calamífera": "calamífero",
    "calamíferas": "calamífero",
    "calamíferos": "calamífero",
    "calando": "calar",
    "calandra": "calandrar",
    "calandrada": "calandrar",
    "calandradas": "calandrar",
    "calandrado": "calandrar",
    "calandrados": "calandrar",
    "calandragens": "calandragem",
    "calandrai": "calandrar",
    "calandrais": "calandrar",
    "calandram": "calandrar",
    "calandramo": "calandrar",
    "calandramos": "calandrar",
    "calandrando": "calandrar",
    "calandrara": "calandrar",
    "calandraram": "calandrar",
    "calandraras": "calandrar",
    "calandrarde": "calandrar",
    "calandrardes": "calandrar",
    "calandrare": "calandrar",
    "calandrarei": "calandrar",
    "calandrareis": "calandrar",
    "calandrarem": "calandrar",
    "calandraremos": "calandrar",
    "calandrares": "calandrar",
    "calandraria": "calandrar",
    "calandrariam": "calandrar",
    "calandrarias": "calandrar",
    "calandrarmo": "calandrar",
    "calandrarmos": "calandrar",
    "calandrará": "calandrar",
    "calandrarás": "calandrar",
    "calandrarão": "calandrar",
    "calandraríamos": "calandrar",
    "calandraríeis": "calandrar",
    "calandras": "calandrar",
    "calandrasse": "calandrar",
    "calandrassem": "calandrar",
    "calandrasses": "calandrar",
    "calandraste": "calandrar",
    "calandrastes": "calandrar",
    "calandrava": "calandrar",
    "calandravam": "calandrar",
    "calandravas": "calandrar",
    "calandre": "calandrar",
    "calandrei": "calandrar",
    "calandreira": "calandreiro",
    "calandreiras": "calandreiro",
    "calandreiros": "calandreiro",
    "calandreis": "calandrar",
    "calandrem": "calandrar",
    "calandremo": "calandrar",
    "calandremos": "calandrar",
    "calandres": "calandrar",
    "calandristas": "calandrista",
    "calandro": "calandrar",
    "calandrou": "calandrar",
    "calandrá": "calandrar",
    "calandrámo": "calandrar",
    "calandrámos": "calandrar",
    "calandráramo": "calandrar",
    "calandráramos": "calandrar",
    "calandrárei": "calandrar",
    "calandráreis": "calandrar",
    "calandrásseis": "calandrar",
    "calandrássemos": "calandrar",
    "calandrávamo": "calandrar",
    "calandrávamos": "calandrar",
    "calandrávei": "calandrar",
    "calandráveis": "calandrar",
    "calara": "calar",
    "calaram": "calar",
    "calaras": "calar",
    "calarde": "calar",
    "calardes": "calar",
    "calare": "calar",
    "calarei": "calar",
    "calareis": "calar",
    "calarem": "calar",
    "calaremos": "calar",
    "calares": "calar",
    "calaria": "calar",
    "calariam": "calar",
    "calarias": "calar",
    "calarmo": "calar",
    "calarmos": "calar",
    "calará": "calar",
    "calarás": "calar",
    "calarão": "calar",
    "calaríamos": "calar",
    "calaríeis": "calar",
    "calas": "calar",
    "calasse": "calar",
    "calassem": "calar",
    "calasses": "calar",
    "calaste": "calar",
    "calastes": "calar",
    "calatiformes": "calatiforme",
    "calatravenses": "calatravense",
    "calaus": "calau",
    "calava": "calar",
    "calavam": "calar",
    "calavas": "calar",
    "calaverites": "calaverite",
    "calazas": "calaza",
    "calaçarias": "calaçaria",
    "calaças": "calaça",
    "calaítas": "calaíta",
    "calaítes": "calaíte",
    "calca": "calcar",
    "calcada": "calcar",
    "calcadas": "calcar",
    "calcadeiras": "calcadeira",
    "calcadelas": "calcadela",
    "calcado": "calcar",
    "calcadoiros": "calcadoiro",
    "calcadora": "calcador",
    "calcadoras": "calcador",
    "calcadores": "calcador",
    "calcados": "calcar",
    "calcadouros": "calcadouro",
    "calcaduras": "calcadura",
    "calcagens": "calcagem",
    "calcai": "calcar",
    "calcais": "calcar",
    "calcam": "calcar",
    "calcamentos": "calcamento",
    "calcamo": "calcar",
    "calcamos": "calcar",
    "calcando": "calcar",
    "calcaneana": "calcaneano",
    "calcaneanas": "calcaneano",
    "calcaneanos": "calcaneano",
    "calcanhares": "calcanhar",
    "calcanheiras": "calcanheira",
    "calcantes": "calcante",
    "calcara": "calcar",
    "calcaram": "calcar",
    "calcaras": "calcar",
    "calcarde": "calcar",
    "calcardes": "calcar",
    "calcare": "calcar",
    "calcarei": "calcar",
    "calcareis": "calcar",
    "calcarem": "calcar",
    "calcaremos": "calcar",
    "calcares": "calcar",
    "calcaria": "calcar",
    "calcariam": "calcar",
    "calcarias": "calcar",
    "calcarmo": "calcar",
    "calcarmos": "calcar",
    "calcará": "calcar",
    "calcarás": "calcar",
    "calcarão": "calcar",
    "calcarés": "calcaré",
    "calcaríamos": "calcar",
    "calcaríeis": "calcar",
    "calcas": "calcar",
    "calcasse": "calcar",
    "calcassem": "calcar",
    "calcasses": "calcar",
    "calcaste": "calcar",
    "calcastes": "calcar",
    "calcatripas": "calcatripa",
    "calcava": "calcar",
    "calcavam": "calcar",
    "calcavas": "calcar",
    "calce": "calçar",
    "calcedónia": "calcedónio",
    "calcedónias": "calcedónio",
    "calcedónios": "calcedónio",
    "calcei": "calçar",
    "calceira": "calceiro",
    "calceiras": "calceiro",
    "calceiros": "calceiro",
    "calceis": "calçar",
    "calcem": "calçar",
    "calcemias": "calcemia",
    "calcemo": "calçar",
    "calcemos": "calçar",
    "calceolárias": "calceolária",
    "calces": "calce",
    "calceta": "calcetar",
    "calcetada": "calcetar",
    "calcetadas": "calcetar",
    "calcetado": "calcetar",
    "calcetados": "calcetar",
    "calcetai": "calcetar",
    "calcetais": "calcetar",
    "calcetam": "calcetar",
    "calcetamentos": "calcetamento",
    "calcetamo": "calcetar",
    "calcetamos": "calcetar",
    "calcetando": "calcetar",
    "calcetara": "calcetar",
    "calcetaram": "calcetar",
    "calcetaras": "calcetar",
    "calcetarde": "calcetar",
    "calcetardes": "calcetar",
    "calcetare": "calcetar",
    "calcetarei": "calcetar",
    "calcetareis": "calcetar",
    "calcetarem": "calcetar",
    "calcetaremos": "calcetar",
    "calcetares": "calcetar",
    "calcetaria": "calcetar",
    "calcetariam": "calcetar",
    "calcetarias": "calcetaria",
    "calcetarmo": "calcetar",
    "calcetarmos": "calcetar",
    "calcetará": "calcetar",
    "calcetarás": "calcetar",
    "calcetarão": "calcetar",
    "calcetaríamos": "calcetar",
    "calcetaríeis": "calcetar",
    "calcetas": "calcetar",
    "calcetasse": "calcetar",
    "calcetassem": "calcetar",
    "calcetasses": "calcetar",
    "calcetaste": "calcetar",
    "calcetastes": "calcetar",
    "calcetava": "calcetar",
    "calcetavam": "calcetar",
    "calcetavas": "calcetar",
    "calcete": "calcetar",
    "calcetei": "calcetar",
    "calceteira": "calceteiro",
    "calceteiras": "calceteiro",
    "calceteiros": "calceteiro",
    "calceteis": "calcetar",
    "calcetem": "calcetar",
    "calcetemo": "calcetar",
    "calcetemos": "calcetar",
    "calcetes": "calcetar",
    "calceto": "calcetar",
    "calcetou": "calcetar",
    "calcetá": "calcetar",
    "calcetámo": "calcetar",
    "calcetámos": "calcetar",
    "calcetáramo": "calcetar",
    "calcetáramos": "calcetar",
    "calcetárei": "calcetar",
    "calcetáreis": "calcetar",
    "calcetásseis": "calcetar",
    "calcetássemos": "calcetar",
    "calcetávamo": "calcetar",
    "calcetávamos": "calcetar",
    "calcetávei": "calcetar",
    "calcetáveis": "calcetar",
    "calciferóis": "calciferol",
    "calcifica": "calcificar",
    "calcificada": "calcificar",
    "calcificadas": "calcificar",
    "calcificado": "calcificar",
    "calcificados": "calcificar",
    "calcificai": "calcificar",
    "calcificais": "calcificar",
    "calcificam": "calcificar",
    "calcificamo": "calcificar",
    "calcificamos": "calcificar",
    "calcificando": "calcificar",
    "calcificara": "calcificar",
    "calcificaram": "calcificar",
    "calcificaras": "calcificar",
    "calcificarde": "calcificar",
    "calcificardes": "calcificar",
    "calcificare": "calcificar",
    "calcificarei": "calcificar",
    "calcificareis": "calcificar",
    "calcificarem": "calcificar",
    "calcificaremos": "calcificar",
    "calcificares": "calcificar",
    "calcificaria": "calcificar",
    "calcificariam": "calcificar",
    "calcificarias": "calcificar",
    "calcificarmo": "calcificar",
    "calcificarmos": "calcificar",
    "calcificará": "calcificar",
    "calcificarás": "calcificar",
    "calcificarão": "calcificar",
    "calcificaríamos": "calcificar",
    "calcificaríeis": "calcificar",
    "calcificas": "calcificar",
    "calcificasse": "calcificar",
    "calcificassem": "calcificar",
    "calcificasses": "calcificar",
    "calcificaste": "calcificar",
    "calcificastes": "calcificar",
    "calcificava": "calcificar",
    "calcificavam": "calcificar",
    "calcificavas": "calcificar",
    "calcificações": "calcificação",
    "calcifico": "calcificar",
    "calcificou": "calcificar",
    "calcificá": "calcificar",
    "calcificámo": "calcificar",
    "calcificámos": "calcificar",
    "calcificáramo": "calcificar",
    "calcificáramos": "calcificar",
    "calcificárei": "calcificar",
    "calcificáreis": "calcificar",
    "calcificásseis": "calcificar",
    "calcificássemos": "calcificar",
    "calcificávamo": "calcificar",
    "calcificávamos": "calcificar",
    "calcificávei": "calcificar",
    "calcificáveis": "calcificar",
    "calcifique": "calcificar",
    "calcifiquei": "calcificar",
    "calcifiqueis": "calcificar",
    "calcifiquem": "calcificar",
    "calcifiquemo": "calcificar",
    "calcifiquemos": "calcificar",
    "calcifiques": "calcificar",
    "calcina": "calcinar",
    "calcinada": "calcinar",
    "calcinadas": "calcinar",
    "calcinado": "calcinar",
    "calcinados": "calcinar",
    "calcinai": "calcinar",
    "calcinais": "calcinar",
    "calcinam": "calcinar",
    "calcinamo": "calcinar",
    "calcinamos": "calcinar",
    "calcinando": "calcinar",
    "calcinantea": "calcinante",
    "calcinanteas": "calcinante",
    "calcinantees": "calcinante",
    "calcinara": "calcinar",
    "calcinaram": "calcinar",
    "calcinaras": "calcinar",
    "calcinarde": "calcinar",
    "calcinardes": "calcinar",
    "calcinare": "calcinar",
    "calcinarei": "calcinar",
    "calcinareis": "calcinar",
    "calcinarem": "calcinar",
    "calcinaremos": "calcinar",
    "calcinares": "calcinar",
    "calcinaria": "calcinar",
    "calcinariam": "calcinar",
    "calcinarias": "calcinar",
    "calcinarmo": "calcinar",
    "calcinarmos": "calcinar",
    "calcinará": "calcinar",
    "calcinarás": "calcinar",
    "calcinarão": "calcinar",
    "calcinaríamos": "calcinar",
    "calcinaríeis": "calcinar",
    "calcinas": "calcinar",
    "calcinasse": "calcinar",
    "calcinassem": "calcinar",
    "calcinasses": "calcinar",
    "calcinaste": "calcinar",
    "calcinastes": "calcinar",
    "calcinatória": "calcinatório",
    "calcinatórias": "calcinatório",
    "calcinatórios": "calcinatório",
    "calcinava": "calcinar",
    "calcinavam": "calcinar",
    "calcinavas": "calcinar",
    "calcinações": "calcinação",
    "calcine": "calcinar",
    "calcinei": "calcinar",
    "calcineis": "calcinar",
    "calcinem": "calcinar",
    "calcinemo": "calcinar",
    "calcinemos": "calcinar",
    "calcines": "calcinar",
    "calcinha": "calça",
    "calcinhas": "calças",
    "calcino": "calcinar",
    "calcinou": "calcinar",
    "calciná": "calcinar",
    "calcinámo": "calcinar",
    "calcinámos": "calcinar",
    "calcináramo": "calcinar",
    "calcináramos": "calcinar",
    "calcinárei": "calcinar",
    "calcináreis": "calcinar",
    "calcinásseis": "calcinar",
    "calcinássemos": "calcinar",
    "calcinávamo": "calcinar",
    "calcinávamos": "calcinar",
    "calcinávei": "calcinar",
    "calcináveis": "calcinável",
    "calcioterapeutas": "calcioterapeuta",
    "calcioterapias": "calcioterapia",
    "calcioterapistas": "calcioterapista",
    "calcioterapêutica": "calcioterapêutico",
    "calcioterapêuticas": "calcioterapêutico",
    "calcioterapêuticos": "calcioterapêutico",
    "calcioterápica": "calcioterápico",
    "calcioterápicas": "calcioterápico",
    "calcioterápicos": "calcioterápico",
    "calcispongias": "calcispongia",
    "calcisponjas": "calcisponja",
    "calcita": "calça",
    "calcitas": "calças",
    "calcites": "calcite",
    "calco": "calcar",
    "calcografa": "calcografar",
    "calcografada": "calcografar",
    "calcografadas": "calcografar",
    "calcografado": "calcografar",
    "calcografados": "calcografar",
    "calcografai": "calcografar",
    "calcografais": "calcografar",
    "calcografam": "calcografar",
    "calcografamo": "calcografar",
    "calcografamos": "calcografar",
    "calcografando": "calcografar",
    "calcografara": "calcografar",
    "calcografaram": "calcografar",
    "calcografaras": "calcografar",
    "calcografarde": "calcografar",
    "calcografardes": "calcografar",
    "calcografare": "calcografar",
    "calcografarei": "calcografar",
    "calcografareis": "calcografar",
    "calcografarem": "calcografar",
    "calcografaremos": "calcografar",
    "calcografares": "calcografar",
    "calcografaria": "calcografar",
    "calcografariam": "calcografar",
    "calcografarias": "calcografar",
    "calcografarmo": "calcografar",
    "calcografarmos": "calcografar",
    "calcografará": "calcografar",
    "calcografarás": "calcografar",
    "calcografarão": "calcografar",
    "calcografaríamos": "calcografar",
    "calcografaríeis": "calcografar",
    "calcografas": "calcografar",
    "calcografasse": "calcografar",
    "calcografassem": "calcografar",
    "calcografasses": "calcografar",
    "calcografaste": "calcografar",
    "calcografastes": "calcografar",
    "calcografava": "calcografar",
    "calcografavam": "calcografar",
    "calcografavas": "calcografar",
    "calcografe": "calcografar",
    "calcografei": "calcografar",
    "calcografeis": "calcografar",
    "calcografem": "calcografar",
    "calcografemo": "calcografar",
    "calcografemos": "calcografar",
    "calcografes": "calcografar",
    "calcografias": "calcografia",
    "calcografo": "calcografar",
    "calcografou": "calcografar",
    "calcografá": "calcografar",
    "calcografámo": "calcografar",
    "calcografámos": "calcografar",
    "calcografáramo": "calcografar",
    "calcografáramos": "calcografar",
    "calcografárei": "calcografar",
    "calcografáreis": "calcografar",
    "calcografásseis": "calcografar",
    "calcografássemos": "calcografar",
    "calcografávamo": "calcografar",
    "calcografávamos": "calcografar",
    "calcografávei": "calcografar",
    "calcografáveis": "calcografar",
    "calcográfica": "calcográfico",
    "calcográficas": "calcográfico",
    "calcográficos": "calcográfico",
    "calcolitografias": "calcolitografia",
    "calcolitográfica": "calcolitográfico",
    "calcolitográficas": "calcolitográfico",
    "calcolitográficos": "calcolitográfico",
    "calcolitógrafos": "calcolitógrafo",
    "calcopirites": "calcopirite",
    "calcorreada": "calcorrear",
    "calcorreadas": "calcorrear",
    "calcorreado": "calcorrear",
    "calcorreadora": "calcorreador",
    "calcorreadoras": "calcorreador",
    "calcorreadores": "calcorreador",
    "calcorreados": "calcorrear",
    "calcorreai": "calcorrear",
    "calcorreais": "calcorrear",
    "calcorreamo": "calcorrear",
    "calcorreamos": "calcorrear",
    "calcorreando": "calcorrear",
    "calcorreantes": "calcorreante",
    "calcorreara": "calcorrear",
    "calcorrearam": "calcorrear",
    "calcorrearas": "calcorrear",
    "calcorreardes": "calcorrear",
    "calcorrearei": "calcorrear",
    "calcorreareis": "calcorrear",
    "calcorrearem": "calcorrear",
    "calcorrearemos": "calcorrear",
    "calcorreares": "calcorrear",
    "calcorrearia": "calcorrear",
    "calcorreariam": "calcorrear",
    "calcorrearias": "calcorrear",
    "calcorrearmo": "calcorrear",
    "calcorrearmos": "calcorrear",
    "calcorreará": "calcorrear",
    "calcorrearás": "calcorrear",
    "calcorrearão": "calcorrear",
    "calcorrearíamos": "calcorrear",
    "calcorrearíeis": "calcorrear",
    "calcorreasse": "calcorrear",
    "calcorreassem": "calcorrear",
    "calcorreasses": "calcorrear",
    "calcorreaste": "calcorrear",
    "calcorreastes": "calcorrear",
    "calcorreava": "calcorrear",
    "calcorreavam": "calcorrear",
    "calcorreavas": "calcorrear",
    "calcorreei": "calcorrear",
    "calcorreeis": "calcorrear",
    "calcorreemo": "calcorrear",
    "calcorreemos": "calcorrear",
    "calcorreia": "calcorrear",
    "calcorreiam": "calcorrear",
    "calcorreias": "calcorrear",
    "calcorreie": "calcorrear",
    "calcorreiem": "calcorrear",
    "calcorreies": "calcorrear",
    "calcorreio": "calcorrear",
    "calcorreou": "calcorrear",
    "calcorreámo": "calcorrear",
    "calcorreámos": "calcorrear",
    "calcorreáramo": "calcorrear",
    "calcorreáramos": "calcorrear",
    "calcorreáreis": "calcorrear",
    "calcorreásseis": "calcorrear",
    "calcorreássemos": "calcorrear",
    "calcorreávamo": "calcorrear",
    "calcorreávamos": "calcorrear",
    "calcorreáveis": "calcorrear",
    "calcos": "calco",
    "calcosinas": "calcosina",
    "calcositas": "calcosita",
    "calcotipias": "calcotipia",
    "calcotipos": "calcotipo",
    "calcou": "calcar",
    "calcoxistos": "calcoxisto",
    "calcula": "calcular",
    "calculada": "calcular",
    "calculadas": "calcular",
    "calculado": "calcular",
    "calculadora": "calculador",
    "calculadoras": "calculadora",
    "calculadores": "calculador",
    "calculados": "calcular",
    "calculai": "calcular",
    "calculais": "calcular",
    "calculam": "calcular",
    "calculamo": "calcular",
    "calculamos": "calcular",
    "calculando": "calcular",
    "calculara": "calcular",
    "calcularam": "calcular",
    "calcularas": "calcular",
    "calcularde": "calcular",
    "calculardes": "calcular",
    "calculare": "calcular",
    "calcularei": "calcular",
    "calculareis": "calcular",
    "calcularem": "calcular",
    "calcularemos": "calcular",
    "calculares": "calcular",
    "calcularia": "calcular",
    "calculariam": "calcular",
    "calcularias": "calcular",
    "calcularmo": "calcular",
    "calcularmos": "calcular",
    "calculará": "calcular",
    "calcularás": "calcular",
    "calcularão": "calcular",
    "calcularíamos": "calcular",
    "calcularíeis": "calcular",
    "calculas": "calcular",
    "calculasse": "calcular",
    "calculassem": "calcular",
    "calculasses": "calcular",
    "calculaste": "calcular",
    "calculastes": "calcular",
    "calculava": "calcular",
    "calculavam": "calcular",
    "calculavas": "calcular",
    "calcule": "calcular",
    "calculei": "calcular",
    "calculeis": "calcular",
    "calculem": "calcular",
    "calculemo": "calcular",
    "calculemos": "calcular",
    "calcules": "calcular",
    "calculismos": "calculismo",
    "calculistas": "calculista",
    "calculo": "calcular",
    "calculosa": "calculoso",
    "calculosas": "calculoso",
    "calculosos": "calculoso",
    "calculou": "calcular",
    "calculá": "calcular",
    "calculámo": "calcular",
    "calculámos": "calcular",
    "calculáramo": "calcular",
    "calculáramos": "calcular",
    "calculárei": "calcular",
    "calculáreis": "calcular",
    "calculásseis": "calcular",
    "calculássemos": "calcular",
    "calculávamo": "calcular",
    "calculávamos": "calcular",
    "calculávei": "calcular",
    "calculáveis": "calculável",
    "calcá": "calcar",
    "calcámo": "calcar",
    "calcámos": "calcar",
    "calcáramo": "calcar",
    "calcáramos": "calcar",
    "calcárei": "calcar",
    "calcáreis": "calcar",
    "calcária": "calcário",
    "calcárias": "calcário",
    "calcários": "calcário",
    "calcásseis": "calcar",
    "calcássemos": "calcar",
    "calcávamo": "calcar",
    "calcávamos": "calcar",
    "calcávei": "calcar",
    "calcáveis": "calcar",
    "calcâneos": "calcâneo",
    "calcêses": "calcês",
    "calcícolas": "calcícola",
    "calcífera": "calcífero",
    "calcíferas": "calcífero",
    "calcíferos": "calcífero",
    "calcífuga": "calcífugo",
    "calcífugas": "calcífugo",
    "calcífugos": "calcífugo",
    "calcímetros": "calcímetro",
    "calcófila": "calcófilo",
    "calcófilas": "calcófilo",
    "calcófilos": "calcófilo",
    "calcógrafos": "calcógrafo",
    "calcões": "calcão",
    "calda": "caldo",
    "caldada": "caldar",
    "caldadas": "caldar",
    "caldado": "caldar",
    "caldados": "caldar",
    "caldai": "caldar",
    "caldaica": "caldaico",
    "caldaicas": "caldaico",
    "caldaicos": "caldaico",
    "caldais": "caldar",
    "caldam": "caldar",
    "caldamo": "caldar",
    "caldamos": "caldar",
    "caldando": "caldar",
    "caldara": "caldar",
    "caldaram": "caldar",
    "caldaras": "caldar",
    "caldarde": "caldar",
    "caldardes": "caldar",
    "caldare": "caldar",
    "caldarei": "caldar",
    "caldareis": "caldar",
    "caldarem": "caldar",
    "caldaremos": "caldar",
    "caldares": "caldar",
    "caldaria": "caldar",
    "caldariam": "caldar",
    "caldarias": "caldar",
    "caldarmo": "caldar",
    "caldarmos": "caldar",
    "caldará": "caldar",
    "caldarás": "caldar",
    "caldarão": "caldar",
    "caldaríamos": "caldar",
    "caldaríeis": "caldar",
    "caldas": "caldo",
    "caldasse": "caldar",
    "caldassem": "caldar",
    "caldasses": "caldar",
    "caldaste": "caldar",
    "caldastes": "caldar",
    "caldava": "caldar",
    "caldavam": "caldar",
    "caldavas": "caldar",
    "caldazinha": "caldo",
    "caldazinhas": "caldo",
    "caldazita": "caldo",
    "caldazitas": "caldo",
    "caldaças": "caldaça",
    "calde": "caldar",
    "caldeada": "caldear",
    "caldeadas": "caldear",
    "caldeado": "caldear",
    "caldeados": "caldear",
    "caldeai": "caldear",
    "caldeais": "caldear",
    "caldeamentos": "caldeamento",
    "caldeamo": "caldear",
    "caldeamos": "caldear",
    "caldeando": "caldear",
    "caldeara": "caldear",
    "caldearam": "caldear",
    "caldearas": "caldear",
    "caldearde": "caldear",
    "caldeardes": "caldear",
    "caldeare": "caldear",
    "caldearei": "caldear",
    "caldeareis": "caldear",
    "caldearem": "caldear",
    "caldearemos": "caldear",
    "caldeares": "caldear",
    "caldearia": "caldear",
    "caldeariam": "caldear",
    "caldearias": "caldear",
    "caldearmo": "caldear",
    "caldearmos": "caldear",
    "caldeará": "caldear",
    "caldearás": "caldear",
    "caldearão": "caldear",
    "caldearíamos": "caldear",
    "caldearíeis": "caldear",
    "caldeasse": "caldear",
    "caldeassem": "caldear",
    "caldeasses": "caldear",
    "caldeaste": "caldear",
    "caldeastes": "caldear",
    "caldeava": "caldear",
    "caldeavam": "caldear",
    "caldeavas": "caldear",
    "caldeações": "caldeação",
    "caldeei": "caldear",
    "caldeeis": "caldear",
    "caldeemo": "caldear",
    "caldeemos": "caldear",
    "caldei": "caldar",
    "caldeia": "caldeu",
    "caldeiam": "caldear",
    "caldeias": "caldeu",
    "caldeie": "caldear",
    "caldeiem": "caldear",
    "caldeies": "caldear",
    "caldeio": "caldear",
    "caldeira": "caldeirar",
    "caldeirada": "caldeirar",
    "caldeiradas": "caldeirar",
    "caldeirado": "caldeirar",
    "caldeirados": "caldeirar",
    "caldeirai": "caldeirar",
    "caldeirais": "caldeirar",
    "caldeiram": "caldeirar",
    "caldeiramo": "caldeirar",
    "caldeiramos": "caldeirar",
    "caldeirando": "caldeirar",
    "caldeirara": "caldeirar",
    "caldeiraram": "caldeirar",
    "caldeiraras": "caldeirar",
    "caldeirarde": "caldeirar",
    "caldeirardes": "caldeirar",
    "caldeirare": "caldeirar",
    "caldeirarei": "caldeirar",
    "caldeirareis": "caldeirar",
    "caldeirarem": "caldeirar",
    "caldeiraremos": "caldeirar",
    "caldeirares": "caldeirar",
    "caldeiraria": "caldeirar",
    "caldeirariam": "caldeirar",
    "caldeirarias": "caldeiraria",
    "caldeirarmo": "caldeirar",
    "caldeirarmos": "caldeirar",
    "caldeirará": "caldeirar",
    "caldeirarás": "caldeirar",
    "caldeirarão": "caldeirar",
    "caldeiraríamos": "caldeirar",
    "caldeiraríeis": "caldeirar",
    "caldeiras": "caldeirar",
    "caldeirasse": "caldeirar",
    "caldeirassem": "caldeirar",
    "caldeirasses": "caldeirar",
    "caldeiraste": "caldeirar",
    "caldeirastes": "caldeirar",
    "caldeirava": "caldeirar",
    "caldeiravam": "caldeirar",
    "caldeiravas": "caldeirar",
    "caldeire": "caldeirar",
    "caldeirei": "caldeirar",
    "caldeireia": "caldeireio",
    "caldeireias": "caldeireio",
    "caldeireios": "caldeireio",
    "caldeireis": "caldeirar",
    "caldeirem": "caldeirar",
    "caldeiremo": "caldeirar",
    "caldeiremos": "caldeirar",
    "caldeires": "caldeirar",
    "caldeirinha": "caldeira",
    "caldeirinhas": "caldeira",
    "caldeirinho": "caldeiro",
    "caldeirinhos": "caldeiro",
    "caldeirita": "caldeira",
    "caldeiritas": "caldeira",
    "caldeirito": "caldeiro",
    "caldeiritos": "caldeiro",
    "caldeiro": "caldeirar",
    "caldeiros": "caldeiro",
    "caldeirou": "caldeirar",
    "caldeirá": "caldeirar",
    "caldeirámo": "caldeirar",
    "caldeirámos": "caldeirar",
    "caldeiráramo": "caldeirar",
    "caldeiráramos": "caldeirar",
    "caldeirárei": "caldeirar",
    "caldeiráreis": "caldeirar",
    "caldeirásseis": "caldeirar",
    "caldeirássemos": "caldeirar",
    "caldeirávamo": "caldeirar",
    "caldeirávamos": "caldeirar",
    "caldeirávei": "caldeirar",
    "caldeiráveis": "caldeirar",
    "caldeirões": "caldeirão",
    "caldeis": "caldar",
    "caldem": "caldar",
    "caldemo": "caldar",
    "caldemos": "caldar",
    "caldenses": "caldense",
    "caldeou": "caldear",
    "caldes": "caldar",
    "caldeus": "caldeu",
    "caldeá": "caldear",
    "caldeámo": "caldear",
    "caldeámos": "caldear",
    "caldeáramo": "caldear",
    "caldeáramos": "caldear",
    "caldeárei": "caldear",
    "caldeáreis": "caldear",
    "caldeásseis": "caldear",
    "caldeássemos": "caldear",
    "caldeávamo": "caldear",
    "caldeávamos": "caldear",
    "caldeávei": "caldear",
    "caldeáveis": "caldear",
    "caldinho": "caldo",
    "caldinhos": "caldo",
    "caldito": "caldo",
    "calditos": "caldo",
    "caldivanas": "caldivana",
    "caldo": "caldar",
    "caldoneiras": "caldoneira",
    "caldoneiros": "caldoneiro",
    "caldos": "caldo",
    "caldou": "caldar",
    "caldozinho": "caldo",
    "caldozinhos": "caldo",
    "caldozito": "caldo",
    "caldozitos": "caldo",
    "caldá": "caldar",
    "caldámo": "caldar",
    "caldámos": "caldar",
    "caldáramo": "caldar",
    "caldáramos": "caldar",
    "caldárei": "caldar",
    "caldáreis": "caldar",
    "caldásseis": "caldar",
    "caldássemos": "caldar",
    "caldávamo": "caldar",
    "caldávamos": "caldar",
    "caldávei": "caldar",
    "caldáveis": "caldar",
    "cale": "calar",
    "caleada": "calear",
    "caleadas": "calear",
    "caleadelas": "caleadela",
    "caleado": "calear",
    "caleados": "calear",
    "caleai": "calear",
    "caleais": "calear",
    "caleamo": "calear",
    "caleamos": "calear",
    "caleando": "calear",
    "caleara": "calear",
    "calearam": "calear",
    "calearas": "calear",
    "calearde": "calear",
    "caleardes": "calear",
    "caleare": "calear",
    "calearei": "calear",
    "caleareis": "calear",
    "calearem": "calear",
    "calearemos": "calear",
    "caleares": "calear",
    "calearia": "calear",
    "caleariam": "calear",
    "calearias": "calear",
    "calearmo": "calear",
    "calearmos": "calear",
    "caleará": "calear",
    "calearás": "calear",
    "calearão": "calear",
    "calearíamos": "calear",
    "calearíeis": "calear",
    "caleasse": "calear",
    "caleassem": "calear",
    "caleasses": "calear",
    "caleaste": "calear",
    "caleastes": "calear",
    "caleava": "calear",
    "caleavam": "calear",
    "caleavas": "calear",
    "caleceira": "caleceiro",
    "caleceiras": "caleceiro",
    "caleceiros": "caleceiro",
    "caleches": "caleche",
    "caledonianos": "caledoniano",
    "caledónia": "caledónio",
    "caledónias": "caledónio",
    "caledónica": "caledónico",
    "caledónicas": "caledónico",
    "caledónicos": "caledónico",
    "caledónidas": "caledónida",
    "caledónios": "caledónio",
    "caleei": "calear",
    "caleeis": "calear",
    "caleemo": "calear",
    "caleemos": "calear",
    "calefacientes": "calefaciente",
    "calefactora": "calefactor",
    "calefactoras": "calefactor",
    "calefactores": "calefactor",
    "calefactórios": "calefactório",
    "calefacções": "calefacção",
    "calefrios": "calefrio",
    "calefriozinho": "calefrio",
    "calefriozinhos": "calefrio",
    "calefriozito": "calefrio",
    "calefriozitos": "calefrio",
    "calei": "calar",
    "caleia": "calear",
    "caleiam": "calear",
    "caleias": "calear",
    "caleidoscópica": "caleidoscópico",
    "caleidoscópicas": "caleidoscópico",
    "caleidoscópicos": "caleidoscópico",
    "caleidoscópios": "caleidoscópio",
    "caleie": "calear",
    "caleiem": "calear",
    "caleies": "calear",
    "caleio": "calear",
    "caleiras": "caleira",
    "caleiros": "caleiro",
    "caleis": "calei",
    "caleja": "calejar",
    "calejaa": "calejao",
    "calejaas": "calejao",
    "calejada": "calejar",
    "calejadas": "calejar",
    "calejado": "calejar",
    "calejadora": "calejador",
    "calejadoras": "calejador",
    "calejadores": "calejador",
    "calejados": "calejar",
    "calejadíssima": "calejado",
    "calejadíssimas": "calejado",
    "calejadíssimo": "calejado",
    "calejadíssimos": "calejado",
    "calejai": "calejar",
    "calejais": "calejar",
    "calejam": "calejar",
    "calejamentos": "calejamento",
    "calejamo": "calejar",
    "calejamos": "calejar",
    "calejando": "calejar",
    "calejaos": "calejao",
    "calejara": "calejar",
    "calejaram": "calejar",
    "calejaras": "calejar",
    "calejarde": "calejar",
    "calejardes": "calejar",
    "calejare": "calejar",
    "calejarei": "calejar",
    "calejareis": "calejar",
    "calejarem": "calejar",
    "calejaremos": "calejar",
    "calejares": "calejar",
    "calejaria": "calejar",
    "calejariam": "calejar",
    "calejarias": "calejar",
    "calejarmo": "calejar",
    "calejarmos": "calejar",
    "calejará": "calejar",
    "calejarás": "calejar",
    "calejarão": "calejar",
    "calejaríamos": "calejar",
    "calejaríeis": "calejar",
    "calejas": "calejar",
    "calejasse": "calejar",
    "calejassem": "calejar",
    "calejasses": "calejar",
    "calejaste": "calejar",
    "calejastes": "calejar",
    "calejava": "calejar",
    "calejavam": "calejar",
    "calejavas": "calejar",
    "caleje": "calejar",
    "calejei": "calejar",
    "calejeis": "calejar",
    "calejem": "calejar",
    "calejemo": "calejar",
    "calejemos": "calejar",
    "calejes": "calejar",
    "calejo": "calejar",
    "calejou": "calejar",
    "calejá": "calejar",
    "calejámo": "calejar",
    "calejámos": "calejar",
    "calejáramo": "calejar",
    "calejáramos": "calejar",
    "calejárei": "calejar",
    "calejáreis": "calejar",
    "calejásseis": "calejar",
    "calejássemos": "calejar",
    "calejávamo": "calejar",
    "calejávamos": "calejar",
    "calejávei": "calejar",
    "calejáveis": "calejar",
    "calem": "calar",
    "calemas": "calema",
    "calembura": "calemburar",
    "calemburada": "calemburar",
    "calemburadas": "calemburar",
    "calemburado": "calemburar",
    "calemburados": "calemburar",
    "calemburai": "calemburar",
    "calemburais": "calemburar",
    "calemburam": "calemburar",
    "calemburamo": "calemburar",
    "calemburamos": "calemburar",
    "calemburando": "calemburar",
    "calemburara": "calemburar",
    "calemburaram": "calemburar",
    "calemburaras": "calemburar",
    "calemburardes": "calemburar",
    "calemburarei": "calemburar",
    "calemburareis": "calemburar",
    "calemburarem": "calemburar",
    "calemburaremos": "calemburar",
    "calemburares": "calemburar",
    "calemburaria": "calemburar",
    "calemburariam": "calemburar",
    "calemburarias": "calemburar",
    "calemburarmo": "calemburar",
    "calemburarmos": "calemburar",
    "calemburará": "calemburar",
    "calemburarás": "calemburar",
    "calemburarão": "calemburar",
    "calemburaríamos": "calemburar",
    "calemburaríeis": "calemburar",
    "calemburas": "calemburar",
    "calemburasse": "calemburar",
    "calemburassem": "calemburar",
    "calemburasses": "calemburar",
    "calemburaste": "calemburar",
    "calemburastes": "calemburar",
    "calemburava": "calemburar",
    "calemburavam": "calemburar",
    "calemburavas": "calemburar",
    "calembure": "calemburar",
    "calemburei": "calemburar",
    "calembureis": "calemburar",
    "calemburem": "calemburar",
    "calemburemo": "calemburar",
    "calemburemos": "calemburar",
    "calembures": "calemburar",
    "calemburga": "calemburgar",
    "calemburgada": "calemburgar",
    "calemburgadas": "calemburgar",
    "calemburgado": "calemburgar",
    "calemburgados": "calemburgar",
    "calemburgai": "calemburgar",
    "calemburgais": "calemburgar",
    "calemburgam": "calemburgar",
    "calemburgamo": "calemburgar",
    "calemburgamos": "calemburgar",
    "calemburgando": "calemburgar",
    "calemburgara": "calemburgar",
    "calemburgaram": "calemburgar",
    "calemburgaras": "calemburgar",
    "calemburgardes": "calemburgar",
    "calemburgarei": "calemburgar",
    "calemburgareis": "calemburgar",
    "calemburgarem": "calemburgar",
    "calemburgaremos": "calemburgar",
    "calemburgares": "calemburgar",
    "calemburgaria": "calemburgar",
    "calemburgariam": "calemburgar",
    "calemburgarias": "calemburgar",
    "calemburgarmo": "calemburgar",
    "calemburgarmos": "calemburgar",
    "calemburgará": "calemburgar",
    "calemburgarás": "calemburgar",
    "calemburgarão": "calemburgar",
    "calemburgaríamos": "calemburgar",
    "calemburgaríeis": "calemburgar",
    "calemburgas": "calemburgar",
    "calemburgasse": "calemburgar",
    "calemburgassem": "calemburgar",
    "calemburgasses": "calemburgar",
    "calemburgaste": "calemburgar",
    "calemburgastes": "calemburgar",
    "calemburgava": "calemburgar",
    "calemburgavam": "calemburgar",
    "calemburgavas": "calemburgar",
    "calemburgo": "calemburgar",
    "calemburgos": "calemburgo",
    "calemburgou": "calemburgar",
    "calemburgue": "calemburgar",
    "calemburguei": "calemburgar",
    "calemburgueis": "calemburgar",
    "calemburguem": "calemburgar",
    "calemburguemo": "calemburgar",
    "calemburguemos": "calemburgar",
    "calemburgues": "calemburgar",
    "calemburgámo": "calemburgar",
    "calemburgámos": "calemburgar",
    "calemburgáramo": "calemburgar",
    "calemburgáramos": "calemburgar",
    "calemburgáreis": "calemburgar",
    "calemburgásseis": "calemburgar",
    "calemburgássemos": "calemburgar",
    "calemburgávamo": "calemburgar",
    "calemburgávamos": "calemburgar",
    "calemburgáveis": "calemburgar",
    "calemburistas": "calemburista",
    "calemburo": "calemburar",
    "calemburou": "calemburar",
    "calemburámo": "calemburar",
    "calemburámos": "calemburar",
    "calemburáramo": "calemburar",
    "calemburáramos": "calemburar",
    "calemburáreis": "calemburar",
    "calemburásseis": "calemburar",
    "calemburássemos": "calemburar",
    "calemburávamo": "calemburar",
    "calemburávamos": "calemburar",
    "calemburáveis": "calemburar",
    "calemo": "calar",
    "calemos": "calar",
    "calendaristas": "calendarista",
    "calendariza": "calendarizar",
    "calendarizada": "calendarizar",
    "calendarizadas": "calendarizar",
    "calendarizado": "calendarizar",
    "calendarizados": "calendarizar",
    "calendarizai": "calendarizar",
    "calendarizais": "calendarizar",
    "calendarizam": "calendarizar",
    "calendarizamo": "calendarizar",
    "calendarizamos": "calendarizar",
    "calendarizando": "calendarizar",
    "calendarizara": "calendarizar",
    "calendarizaram": "calendarizar",
    "calendarizaras": "calendarizar",
    "calendarizarde": "calendarizar",
    "calendarizardes": "calendarizar",
    "calendarizare": "calendarizar",
    "calendarizarei": "calendarizar",
    "calendarizareis": "calendarizar",
    "calendarizarem": "calendarizar",
    "calendarizaremos": "calendarizar",
    "calendarizares": "calendarizar",
    "calendarizaria": "calendarizar",
    "calendarizariam": "calendarizar",
    "calendarizarias": "calendarizar",
    "calendarizarmo": "calendarizar",
    "calendarizarmos": "calendarizar",
    "calendarizará": "calendarizar",
    "calendarizarás": "calendarizar",
    "calendarizarão": "calendarizar",
    "calendarizaríamos": "calendarizar",
    "calendarizaríeis": "calendarizar",
    "calendarizas": "calendarizar",
    "calendarizasse": "calendarizar",
    "calendarizassem": "calendarizar",
    "calendarizasses": "calendarizar",
    "calendarizaste": "calendarizar",
    "calendarizastes": "calendarizar",
    "calendarizava": "calendarizar",
    "calendarizavam": "calendarizar",
    "calendarizavas": "calendarizar",
    "calendarizações": "calendarização",
    "calendarize": "calendarizar",
    "calendarizei": "calendarizar",
    "calendarizeis": "calendarizar",
    "calendarizem": "calendarizar",
    "calendarizemo": "calendarizar",
    "calendarizemos": "calendarizar",
    "calendarizes": "calendarizar",
    "calendarizo": "calendarizar",
    "calendarizou": "calendarizar",
    "calendarizá": "calendarizar",
    "calendarizámo": "calendarizar",
    "calendarizámos": "calendarizar",
    "calendarizáramo": "calendarizar",
    "calendarizáramos": "calendarizar",
    "calendarizárei": "calendarizar",
    "calendarizáreis": "calendarizar",
    "calendarizásseis": "calendarizar",
    "calendarizássemos": "calendarizar",
    "calendarizávamo": "calendarizar",
    "calendarizávamos": "calendarizar",
    "calendarizávei": "calendarizar",
    "calendarizáveis": "calendarizar",
    "calendários": "calendário",
    "calenturas": "calentura",
    "caleou": "calear",
    "calepinos": "calepino",
    "cales": "cale",
    "caletas": "caleta",
    "caletes": "calete",
    "caleá": "calear",
    "caleámo": "calear",
    "caleámos": "calear",
    "caleáramo": "calear",
    "caleáramos": "calear",
    "caleárei": "calear",
    "caleáreis": "calear",
    "caleásseis": "calear",
    "caleássemos": "calear",
    "caleávamo": "calear",
    "caleávamos": "calear",
    "caleávei": "calear",
    "caleáveis": "calear",
    "caleças": "caleça",
    "calfes": "calfe",
    "calha": "calhar",
    "calhada": "calhar",
    "calhadas": "calhar",
    "calhado": "calhar",
    "calhadoiros": "calhadoiro",
    "calhados": "calhar",
    "calhadouros": "calhadouro",
    "calhai": "calhar",
    "calhais": "calhar",
    "calham": "calhar",
    "calhamaçadas": "calhamaçada",
    "calhamaços": "calhamaço",
    "calhambeques": "calhambeque",
    "calhamo": "calhar",
    "calhamos": "calhar",
    "calhando": "calhar",
    "calhandra": "calhandro",
    "calhandras": "calhandro",
    "calhandrazinha": "calhandro",
    "calhandrazinhas": "calhandro",
    "calhandrazita": "calhandro",
    "calhandrazitas": "calhandro",
    "calhandreira": "calhandreiro",
    "calhandreiras": "calhandreiro",
    "calhandreirazinha": "calhandreiro",
    "calhandreirazinhas": "calhandreiro",
    "calhandreirazita": "calhandreiro",
    "calhandreirazitas": "calhandreiro",
    "calhandreiros": "calhandreiro",
    "calhandreirozinho": "calhandreiro",
    "calhandreirozinhos": "calhandreiro",
    "calhandreirozito": "calhandreiro",
    "calhandreirozitos": "calhandreiro",
    "calhandros": "calhandro",
    "calhandrozinho": "calhandro",
    "calhandrozinhos": "calhandro",
    "calhandrozito": "calhandro",
    "calhandrozitos": "calhandro",
    "calhanças": "calhança",
    "calhanços": "calhanço",
    "calhara": "calhar",
    "calharam": "calhar",
    "calharas": "calhar",
    "calharde": "calhar",
    "calhardes": "calhar",
    "calhare": "calhar",
    "calharei": "calhar",
    "calhareis": "calhar",
    "calharem": "calhar",
    "calharemos": "calhar",
    "calhares": "calhar",
    "calharia": "calhar",
    "calhariam": "calhar",
    "calharias": "calhar",
    "calharizes": "calhariz",
    "calharmo": "calhar",
    "calharmos": "calhar",
    "calhará": "calhar",
    "calharás": "calhar",
    "calharão": "calhar",
    "calharíamos": "calhar",
    "calharíeis": "calhar",
    "calhas": "calhar",
    "calhasse": "calhar",
    "calhassem": "calhar",
    "calhasses": "calhar",
    "calhaste": "calhar",
    "calhastes": "calhar",
    "calhastrizes": "calhastriz",
    "calhastrozes": "calhastroz",
    "calhaus": "calhau",
    "calhava": "calhar",
    "calhavam": "calhar",
    "calhavas": "calhar",
    "calhe": "calhar",
    "calhei": "calhar",
    "calheis": "calhar",
    "calhem": "calhar",
    "calhemo": "calhar",
    "calhemos": "calhar",
    "calhes": "calhe",
    "calhetas": "calheta",
    "calho": "calhar",
    "calhoa": "calhoar",
    "calhoada": "calhoar",
    "calhoadas": "calhoar",
    "calhoado": "calhoar",
    "calhoados": "calhoar",
    "calhoai": "calhoar",
    "calhoais": "calhoar",
    "calhoam": "calhoar",
    "calhoamo": "calhoar",
    "calhoamos": "calhoar",
    "calhoando": "calhoar",
    "calhoara": "calhoar",
    "calhoaram": "calhoar",
    "calhoaras": "calhoar",
    "calhoarde": "calhoar",
    "calhoardes": "calhoar",
    "calhoare": "calhoar",
    "calhoarei": "calhoar",
    "calhoareis": "calhoar",
    "calhoarem": "calhoar",
    "calhoaremos": "calhoar",
    "calhoares": "calhoar",
    "calhoaria": "calhoar",
    "calhoariam": "calhoar",
    "calhoarias": "calhoar",
    "calhoarmo": "calhoar",
    "calhoarmos": "calhoar",
    "calhoará": "calhoar",
    "calhoarás": "calhoar",
    "calhoarão": "calhoar",
    "calhoaríamos": "calhoar",
    "calhoaríeis": "calhoar",
    "calhoas": "calhoar",
    "calhoasse": "calhoar",
    "calhoassem": "calhoar",
    "calhoasses": "calhoar",
    "calhoaste": "calhoar",
    "calhoastes": "calhoar",
    "calhoava": "calhoar",
    "calhoavam": "calhoar",
    "calhoavas": "calhoar",
    "calhoe": "calhoar",
    "calhoei": "calhoar",
    "calhoeis": "calhoar",
    "calhoem": "calhoar",
    "calhoemo": "calhoar",
    "calhoemos": "calhoar",
    "calhoes": "calhoar",
    "calhoo": "calhoar",
    "calhoou": "calhoar",
    "calhordas": "calhorda",
    "calhotas": "calhota",
    "calhou": "calhar",
    "calhoá": "calhoar",
    "calhoámo": "calhoar",
    "calhoámos": "calhoar",
    "calhoáramo": "calhoar",
    "calhoáramos": "calhoar",
    "calhoárei": "calhoar",
    "calhoáreis": "calhoar",
    "calhoásseis": "calhoar",
    "calhoássemos": "calhoar",
    "calhoávamo": "calhoar",
    "calhoávamos": "calhoar",
    "calhoávei": "calhoar",
    "calhoáveis": "calhoar",
    "calhá": "calhar",
    "calhámo": "calhar",
    "calhámos": "calhar",
    "calháramo": "calhar",
    "calháramos": "calhar",
    "calhárei": "calhar",
    "calháreis": "calhar",
    "calhásseis": "calhar",
    "calhássemos": "calhar",
    "calhávamo": "calhar",
    "calhávamos": "calhar",
    "calhávei": "calhar",
    "calháveis": "calhar",
    "caliandras": "caliandra",
    "calibites": "calibite",
    "calibra": "calibrar",
    "calibrada": "calibrar",
    "calibradas": "calibrar",
    "calibrado": "calibrar",
    "calibradora": "calibrador",
    "calibradoras": "calibrador",
    "calibradores": "calibrador",
    "calibrados": "calibrar",
    "calibragens": "calibragem",
    "calibrai": "calibrar",
    "calibrais": "calibrar",
    "calibram": "calibrar",
    "calibramo": "calibrar",
    "calibramos": "calibrar",
    "calibrando": "calibrar",
    "calibrara": "calibrar",
    "calibraram": "calibrar",
    "calibraras": "calibrar",
    "calibrarde": "calibrar",
    "calibrardes": "calibrar",
    "calibrare": "calibrar",
    "calibrarei": "calibrar",
    "calibrareis": "calibrar",
    "calibrarem": "calibrar",
    "calibraremos": "calibrar",
    "calibrares": "calibrar",
    "calibraria": "calibrar",
    "calibrariam": "calibrar",
    "calibrarias": "calibrar",
    "calibrarmo": "calibrar",
    "calibrarmos": "calibrar",
    "calibrará": "calibrar",
    "calibrarás": "calibrar",
    "calibrarão": "calibrar",
    "calibraríamos": "calibrar",
    "calibraríeis": "calibrar",
    "calibras": "calibrar",
    "calibrasse": "calibrar",
    "calibrassem": "calibrar",
    "calibrasses": "calibrar",
    "calibraste": "calibrar",
    "calibrastes": "calibrar",
    "calibrava": "calibrar",
    "calibravam": "calibrar",
    "calibravas": "calibrar",
    "calibrações": "calibração",
    "calibre": "calibrar",
    "calibrei": "calibrar",
    "calibreis": "calibrar",
    "calibrem": "calibrar",
    "calibremo": "calibrar",
    "calibremos": "calibrar",
    "calibres": "calibre",
    "calibro": "calibrar",
    "calibrou": "calibrar",
    "calibrá": "calibrar",
    "calibrámo": "calibrar",
    "calibrámos": "calibrar",
    "calibráramo": "calibrar",
    "calibráramos": "calibrar",
    "calibrárei": "calibrar",
    "calibráreis": "calibrar",
    "calibrásseis": "calibrar",
    "calibrássemos": "calibrar",
    "calibrávamo": "calibrar",
    "calibrávamos": "calibrar",
    "calibrávei": "calibrar",
    "calibráveis": "calibrável",
    "calicezinho": "cálice",
    "calicezinhos": "cálice",
    "calicezito": "cálice",
    "calicezitos": "cálice",
    "caliches": "caliche",
    "caliciada": "caliciado",
    "caliciadas": "caliciado",
    "caliciados": "caliciado",
    "calicidas": "calicida",
    "caliciformes": "caliciforme",
    "calicinais": "calicinal",
    "calicroma": "calicromo",
    "calicromas": "calicromo",
    "calicromos": "calicromo",
    "calicromática": "calicromático",
    "calicromáticas": "calicromático",
    "calicromáticos": "calicromático",
    "caliculada": "caliculado",
    "caliculadas": "caliculado",
    "caliculados": "caliculado",
    "calicínea": "calicíneo",
    "calicíneas": "calicíneo",
    "calicíneos": "calicíneo",
    "calidezes": "calidez",
    "calidoscópica": "calidoscópico",
    "calidoscópicas": "calidoscópico",
    "calidoscópicos": "calidoscópico",
    "calidoscópios": "calidoscópio",
    "califados": "califado",
    "califas": "califa",
    "califasias": "califasia",
    "califonias": "califonia",
    "californiana": "californiano",
    "californianas": "californiano",
    "californianos": "californiano",
    "califórnia": "califórnio",
    "califórnias": "califórnio",
    "califórnios": "califórnio",
    "caligantes": "caligante",
    "caligens": "caligem",
    "caligina": "caliginar",
    "caliginada": "caliginar",
    "caliginadas": "caliginar",
    "caliginado": "caliginar",
    "caliginados": "caliginar",
    "caliginai": "caliginar",
    "caliginais": "caliginar",
    "caliginam": "caliginar",
    "caliginamo": "caliginar",
    "caliginamos": "caliginar",
    "caliginando": "caliginar",
    "caliginara": "caliginar",
    "caliginaram": "caliginar",
    "caliginaras": "caliginar",
    "caliginarde": "caliginar",
    "caliginardes": "caliginar",
    "caliginare": "caliginar",
    "caliginarei": "caliginar",
    "caliginareis": "caliginar",
    "caliginarem": "caliginar",
    "caliginaremos": "caliginar",
    "caliginares": "caliginar",
    "caliginaria": "caliginar",
    "caliginariam": "caliginar",
    "caliginarias": "caliginar",
    "caliginarmo": "caliginar",
    "caliginarmos": "caliginar",
    "caliginará": "caliginar",
    "caliginarás": "caliginar",
    "caliginarão": "caliginar",
    "caliginaríamos": "caliginar",
    "caliginaríeis": "caliginar",
    "caliginas": "caliginar",
    "caliginasse": "caliginar",
    "caliginassem": "caliginar",
    "caliginasses": "caliginar",
    "caliginaste": "caliginar",
    "caliginastes": "caliginar",
    "caliginava": "caliginar",
    "caliginavam": "caliginar",
    "caliginavas": "caliginar",
    "caligine": "caliginar",
    "caliginei": "caliginar",
    "caligineis": "caliginar",
    "caliginem": "caliginar",
    "caliginemo": "caliginar",
    "caliginemos": "caliginar",
    "caligines": "caliginar",
    "caligino": "caliginar",
    "caliginosa": "caliginoso",
    "caliginosas": "caliginoso",
    "caliginosos": "caliginoso",
    "caliginou": "caliginar",
    "caliginá": "caliginar",
    "caliginámo": "caliginar",
    "caliginámos": "caliginar",
    "caligináramo": "caliginar",
    "caligináramos": "caliginar",
    "caliginárei": "caliginar",
    "caligináreis": "caliginar",
    "caliginásseis": "caliginar",
    "caliginássemos": "caliginar",
    "caliginávamo": "caliginar",
    "caliginávamos": "caliginar",
    "caliginávei": "caliginar",
    "caligináveis": "caliginar",
    "caligrafa": "caligrafar",
    "caligrafada": "caligrafar",
    "caligrafadas": "caligrafar",
    "caligrafado": "caligrafar",
    "caligrafados": "caligrafar",
    "caligrafai": "caligrafar",
    "caligrafais": "caligrafar",
    "caligrafam": "caligrafar",
    "caligrafamo": "caligrafar",
    "caligrafamos": "caligrafar",
    "caligrafando": "caligrafar",
    "caligrafara": "caligrafar",
    "caligrafaram": "caligrafar",
    "caligrafaras": "caligrafar",
    "caligrafarde": "caligrafar",
    "caligrafardes": "caligrafar",
    "caligrafare": "caligrafar",
    "caligrafarei": "caligrafar",
    "caligrafareis": "caligrafar",
    "caligrafarem": "caligrafar",
    "caligrafaremos": "caligrafar",
    "caligrafares": "caligrafar",
    "caligrafaria": "caligrafar",
    "caligrafariam": "caligrafar",
    "caligrafarias": "caligrafar",
    "caligrafarmo": "caligrafar",
    "caligrafarmos": "caligrafar",
    "caligrafará": "caligrafar",
    "caligrafarás": "caligrafar",
    "caligrafarão": "caligrafar",
    "caligrafaríamos": "caligrafar",
    "caligrafaríeis": "caligrafar",
    "caligrafas": "caligrafar",
    "caligrafasse": "caligrafar",
    "caligrafassem": "caligrafar",
    "caligrafasses": "caligrafar",
    "caligrafaste": "caligrafar",
    "caligrafastes": "caligrafar",
    "caligrafava": "caligrafar",
    "caligrafavam": "caligrafar",
    "caligrafavas": "caligrafar",
    "caligrafe": "caligrafar",
    "caligrafei": "caligrafar",
    "caligrafeis": "caligrafar",
    "caligrafem": "caligrafar",
    "caligrafemo": "caligrafar",
    "caligrafemos": "caligrafar",
    "caligrafes": "caligrafar",
    "caligrafias": "caligrafia",
    "caligrafo": "caligrafar",
    "caligrafou": "caligrafar",
    "caligrafá": "caligrafar",
    "caligrafámo": "caligrafar",
    "caligrafámos": "caligrafar",
    "caligrafáramo": "caligrafar",
    "caligrafáramos": "caligrafar",
    "caligrafárei": "caligrafar",
    "caligrafáreis": "caligrafar",
    "caligrafásseis": "caligrafar",
    "caligrafássemos": "caligrafar",
    "caligrafávamo": "caligrafar",
    "caligrafávamos": "caligrafar",
    "caligrafávei": "caligrafar",
    "caligrafáveis": "caligrafar",
    "caligráfica": "caligráfico",
    "caligráficas": "caligráfico",
    "caligráficos": "caligráfico",
    "calilangas": "calilanga",
    "calilogias": "calilogia",
    "calimeiras": "calimeira",
    "calimenídea": "calimenídeo",
    "calimenídeas": "calimenídeo",
    "calimenídeos": "calimenídeo",
    "calimes": "calime",
    "calina": "calino",
    "calinadas": "calinada",
    "calinas": "calino",
    "calinites": "calinite",
    "calinos": "calino",
    "calipedias": "calipedia",
    "calipolenses": "calipolense",
    "calipolonses": "calipolonse",
    "caliptras": "caliptra",
    "calipédica": "calipédico",
    "calipédicas": "calipédico",
    "calipédicos": "calipédico",
    "calipígia": "calipígio",
    "calipígias": "calipígio",
    "calipígios": "calipígio",
    "calismos": "calismo",
    "calistas": "calista",
    "calistenias": "calistenia",
    "calistismos": "calistismo",
    "calistos": "calisto",
    "caliçadas": "caliçada",
    "caliças": "caliça",
    "caliços": "caliço",
    "calma": "calmo",
    "calmada": "calmar",
    "calmadas": "calmar",
    "calmado": "calmar",
    "calmados": "calmar",
    "calmai": "calmar",
    "calmais": "calmar",
    "calmam": "calmar",
    "calmamo": "calmar",
    "calmamos": "calmar",
    "calmando": "calmar",
    "calmantes": "calmante",
    "calmara": "calmar",
    "calmaram": "calmar",
    "calmaras": "calmar",
    "calmarde": "calmar",
    "calmardes": "calmar",
    "calmare": "calmar",
    "calmarei": "calmar",
    "calmareis": "calmar",
    "calmarem": "calmar",
    "calmaremos": "calmar",
    "calmares": "calmar",
    "calmaria": "calmar",
    "calmariam": "calmar",
    "calmarias": "calmaria",
    "calmarmo": "calmar",
    "calmarmos": "calmar",
    "calmará": "calmar",
    "calmarás": "calmar",
    "calmarão": "calmar",
    "calmaríamos": "calmar",
    "calmaríeis": "calmar",
    "calmas": "calmo",
    "calmasse": "calmar",
    "calmassem": "calmar",
    "calmasses": "calmar",
    "calmaste": "calmar",
    "calmastes": "calmar",
    "calmava": "calmar",
    "calmavam": "calmar",
    "calmavas": "calmar",
    "calme": "calmar",
    "calmei": "calmar",
    "calmeira": "calmeiro",
    "calmeiras": "calmeiro",
    "calmeirona": "calmeirão",
    "calmeironas": "calmeirão",
    "calmeiros": "calmeiro",
    "calmeirões": "calmeirão",
    "calmeis": "calmar",
    "calmem": "calmar",
    "calmemo": "calmar",
    "calmemos": "calmar",
    "calmes": "calmar",
    "calminha": "calmo",
    "calminhas": "calmo",
    "calminho": "calmo",
    "calminhos": "calmo",
    "calmita": "calmo",
    "calmitas": "calmo",
    "calmito": "calmo",
    "calmitos": "calmo",
    "calmo": "calmar",
    "calmorreada": "calmorrear",
    "calmorreadas": "calmorrear",
    "calmorreado": "calmorrear",
    "calmorreados": "calmorrear",
    "calmorreai": "calmorrear",
    "calmorreais": "calmorrear",
    "calmorreamo": "calmorrear",
    "calmorreamos": "calmorrear",
    "calmorreando": "calmorrear",
    "calmorreara": "calmorrear",
    "calmorrearam": "calmorrear",
    "calmorrearas": "calmorrear",
    "calmorrearde": "calmorrear",
    "calmorreardes": "calmorrear",
    "calmorreare": "calmorrear",
    "calmorrearei": "calmorrear",
    "calmorreareis": "calmorrear",
    "calmorrearem": "calmorrear",
    "calmorrearemos": "calmorrear",
    "calmorreares": "calmorrear",
    "calmorrearia": "calmorrear",
    "calmorreariam": "calmorrear",
    "calmorrearias": "calmorrear",
    "calmorrearmo": "calmorrear",
    "calmorrearmos": "calmorrear",
    "calmorreará": "calmorrear",
    "calmorrearás": "calmorrear",
    "calmorrearão": "calmorrear",
    "calmorrearíamos": "calmorrear",
    "calmorrearíeis": "calmorrear",
    "calmorreasse": "calmorrear",
    "calmorreassem": "calmorrear",
    "calmorreasses": "calmorrear",
    "calmorreaste": "calmorrear",
    "calmorreastes": "calmorrear",
    "calmorreava": "calmorrear",
    "calmorreavam": "calmorrear",
    "calmorreavas": "calmorrear",
    "calmorreei": "calmorrear",
    "calmorreeis": "calmorrear",
    "calmorreemo": "calmorrear",
    "calmorreemos": "calmorrear",
    "calmorreia": "calmorrear",
    "calmorreiam": "calmorrear",
    "calmorreias": "calmorrear",
    "calmorreie": "calmorrear",
    "calmorreiem": "calmorrear",
    "calmorreies": "calmorrear",
    "calmorreio": "calmorrear",
    "calmorreou": "calmorrear",
    "calmorreá": "calmorrear",
    "calmorreámo": "calmorrear",
    "calmorreámos": "calmorrear",
    "calmorreáramo": "calmorrear",
    "calmorreáramos": "calmorrear",
    "calmorreárei": "calmorrear",
    "calmorreáreis": "calmorrear",
    "calmorreásseis": "calmorrear",
    "calmorreássemos": "calmorrear",
    "calmorreávamo": "calmorrear",
    "calmorreávamos": "calmorrear",
    "calmorreávei": "calmorrear",
    "calmorreáveis": "calmorrear",
    "calmos": "calmo",
    "calmosa": "calmoso",
    "calmosas": "calmoso",
    "calmosos": "calmoso",
    "calmou": "calmar",
    "calmá": "calmar",
    "calmámo": "calmar",
    "calmámos": "calmar",
    "calmáramo": "calmar",
    "calmáramos": "calmar",
    "calmárei": "calmar",
    "calmáreis": "calmar",
    "calmásseis": "calmar",
    "calmássemos": "calmar",
    "calmávamo": "calmar",
    "calmávamos": "calmar",
    "calmávei": "calmar",
    "calmáveis": "calmar",
    "calmíssima": "calmo",
    "calmíssimas": "calmo",
    "calmíssimo": "calmo",
    "calmíssimos": "calmo",
    "calmões": "calmão",
    "calo": "calar",
    "calofila": "calofilo",
    "calofilas": "calofilo",
    "calofilos": "calofilo",
    "caloidoscópica": "caloidoscópico",
    "caloidoscópicas": "caloidoscópico",
    "caloidoscópicos": "caloidoscópico",
    "caloidoscópios": "caloidoscópio",
    "caloira": "caloiro",
    "caloiradas": "caloirada",
    "caloiras": "caloiro",
    "caloirices": "caloirice",
    "caloiros": "caloiro",
    "calombos": "calombo",
    "calombros": "calombro",
    "calomelanos": "calomelano",
    "calondros": "calondro",
    "caloramas": "calorama",
    "caloraças": "caloraça",
    "calorenta": "calorento",
    "calorentas": "calorento",
    "calorentos": "calorento",
    "calores": "calor",
    "calorescências": "calorescência",
    "calorias": "caloria",
    "caloricidades": "caloricidade",
    "calorifica": "calorificar",
    "calorificada": "calorificar",
    "calorificadas": "calorificar",
    "calorificado": "calorificar",
    "calorificados": "calorificar",
    "calorificai": "calorificar",
    "calorificais": "calorificar",
    "calorificam": "calorificar",
    "calorificamo": "calorificar",
    "calorificamos": "calorificar",
    "calorificando": "calorificar",
    "calorificara": "calorificar",
    "calorificaram": "calorificar",
    "calorificaras": "calorificar",
    "calorificarde": "calorificar",
    "calorificardes": "calorificar",
    "calorificare": "calorificar",
    "calorificarei": "calorificar",
    "calorificareis": "calorificar",
    "calorificarem": "calorificar",
    "calorificaremos": "calorificar",
    "calorificares": "calorificar",
    "calorificaria": "calorificar",
    "calorificariam": "calorificar",
    "calorificarias": "calorificar",
    "calorificarmo": "calorificar",
    "calorificarmos": "calorificar",
    "calorificará": "calorificar",
    "calorificarás": "calorificar",
    "calorificarão": "calorificar",
    "calorificaríamos": "calorificar",
    "calorificaríeis": "calorificar",
    "calorificas": "calorificar",
    "calorificasse": "calorificar",
    "calorificassem": "calorificar",
    "calorificasses": "calorificar",
    "calorificaste": "calorificar",
    "calorificastes": "calorificar",
    "calorificava": "calorificar",
    "calorificavam": "calorificar",
    "calorificavas": "calorificar",
    "calorificações": "calorificação",
    "calorifico": "calorificar",
    "calorificou": "calorificar",
    "calorificá": "calorificar",
    "calorificámo": "calorificar",
    "calorificámos": "calorificar",
    "calorificáramo": "calorificar",
    "calorificáramos": "calorificar",
    "calorificárei": "calorificar",
    "calorificáreis": "calorificar",
    "calorificásseis": "calorificar",
    "calorificássemos": "calorificar",
    "calorificávamo": "calorificar",
    "calorificávamos": "calorificar",
    "calorificávei": "calorificar",
    "calorificáveis": "calorificar",
    "calorifique": "calorificar",
    "calorifiquei": "calorificar",
    "calorifiqueis": "calorificar",
    "calorifiquem": "calorificar",
    "calorifiquemo": "calorificar",
    "calorifiquemos": "calorificar",
    "calorifiques": "calorificar",
    "calorimetrias": "calorimetria",
    "calorimétrica": "calorimétrico",
    "calorimétricas": "calorimétrico",
    "calorimétricos": "calorimétrico",
    "calorosa": "caloroso",
    "calorosas": "caloroso",
    "calorosos": "caloroso",
    "calorzinho": "calor",
    "calorzinhos": "calor",
    "calorzito": "calor",
    "calorzitos": "calor",
    "calorífera": "calorífero",
    "caloríferas": "calorífero",
    "caloríferos": "calorífero",
    "calorífica": "calorífico",
    "caloríficas": "calorífico",
    "caloríficos": "calorífico",
    "calorífuga": "calorífugo",
    "calorífugas": "calorífugo",
    "calorífugos": "calorífugo",
    "calorímetros": "calorímetro",
    "calorões": "calorão",
    "calos": "calo",
    "calosa": "caloso",
    "calosas": "caloso",
    "calosidades": "calosidade",
    "calosos": "caloso",
    "calotas": "calota",
    "caloteada": "calotear",
    "caloteadas": "calotear",
    "caloteado": "calotear",
    "caloteados": "calotear",
    "caloteai": "calotear",
    "caloteais": "calotear",
    "caloteamo": "calotear",
    "caloteamos": "calotear",
    "caloteando": "calotear",
    "caloteara": "calotear",
    "calotearam": "calotear",
    "calotearas": "calotear",
    "calotearde": "calotear",
    "caloteardes": "calotear",
    "caloteare": "calotear",
    "calotearei": "calotear",
    "caloteareis": "calotear",
    "calotearem": "calotear",
    "calotearemos": "calotear",
    "caloteares": "calotear",
    "calotearia": "calotear",
    "caloteariam": "calotear",
    "calotearias": "calotear",
    "calotearmo": "calotear",
    "calotearmos": "calotear",
    "caloteará": "calotear",
    "calotearás": "calotear",
    "calotearão": "calotear",
    "calotearíamos": "calotear",
    "calotearíeis": "calotear",
    "caloteasse": "calotear",
    "caloteassem": "calotear",
    "caloteasses": "calotear",
    "caloteaste": "calotear",
    "caloteastes": "calotear",
    "caloteava": "calotear",
    "caloteavam": "calotear",
    "caloteavas": "calotear",
    "caloteei": "calotear",
    "caloteeis": "calotear",
    "caloteemo": "calotear",
    "caloteemos": "calotear",
    "caloteia": "calotear",
    "caloteiam": "calotear",
    "caloteias": "calotear",
    "caloteie": "calotear",
    "caloteiem": "calotear",
    "caloteies": "calotear",
    "caloteio": "calotear",
    "caloteira": "caloteiro",
    "caloteiras": "caloteiro",
    "caloteirismos": "caloteirismo",
    "caloteiros": "caloteiro",
    "caloteou": "calotear",
    "calotes": "calote",
    "caloteá": "calotear",
    "caloteámo": "calotear",
    "caloteámos": "calotear",
    "caloteáramo": "calotear",
    "caloteáramos": "calotear",
    "caloteárei": "calotear",
    "caloteáreis": "calotear",
    "caloteásseis": "calotear",
    "caloteássemos": "calotear",
    "caloteávamo": "calotear",
    "caloteávamos": "calotear",
    "caloteávei": "calotear",
    "caloteáveis": "calotear",
    "calotismos": "calotismo",
    "calou": "calar",
    "caloura": "calouro",
    "calouras": "calouro",
    "calourices": "calourice",
    "calouros": "calouro",
    "caloviana": "caloviano",
    "calovianas": "caloviano",
    "calovianos": "caloviano",
    "calpas": "calpa",
    "calpenses": "calpense",
    "calque": "calcar",
    "calquei": "calcar",
    "calqueis": "calcar",
    "calquem": "calcar",
    "calquemo": "calcar",
    "calquemos": "calcar",
    "calques": "calque",
    "calquirés": "calquiré",
    "calrachos": "calracho",
    "caltas": "calta",
    "calunia": "caluniar",
    "caluniada": "caluniar",
    "caluniadas": "caluniar",
    "caluniado": "caluniar",
    "caluniadora": "caluniador",
    "caluniadoras": "caluniador",
    "caluniadores": "caluniador",
    "caluniados": "caluniar",
    "caluniadíssima": "caluniado",
    "caluniadíssimas": "caluniado",
    "caluniadíssimo": "caluniado",
    "caluniadíssimos": "caluniado",
    "caluniai": "caluniar",
    "caluniais": "caluniar",
    "caluniam": "caluniar",
    "caluniamo": "caluniar",
    "caluniamos": "caluniar",
    "caluniando": "caluniar",
    "caluniara": "caluniar",
    "caluniaram": "caluniar",
    "caluniaras": "caluniar",
    "caluniarde": "caluniar",
    "caluniardes": "caluniar",
    "caluniare": "caluniar",
    "caluniarei": "caluniar",
    "caluniareis": "caluniar",
    "caluniarem": "caluniar",
    "caluniaremos": "caluniar",
    "caluniares": "caluniar",
    "caluniaria": "caluniar",
    "caluniariam": "caluniar",
    "caluniarias": "caluniar",
    "caluniarmo": "caluniar",
    "caluniarmos": "caluniar",
    "caluniará": "caluniar",
    "caluniarás": "caluniar",
    "caluniarão": "caluniar",
    "caluniaríamos": "caluniar",
    "caluniaríeis": "caluniar",
    "calunias": "caluniar",
    "caluniasse": "caluniar",
    "caluniassem": "caluniar",
    "caluniasses": "caluniar",
    "caluniaste": "caluniar",
    "caluniastes": "caluniar",
    "caluniava": "caluniar",
    "caluniavam": "caluniar",
    "caluniavas": "caluniar",
    "calunie": "caluniar",
    "caluniei": "caluniar",
    "calunieis": "caluniar",
    "caluniem": "caluniar",
    "caluniemo": "caluniar",
    "caluniemos": "caluniar",
    "calunies": "caluniar",
    "calunio": "caluniar",
    "caluniosa": "calunioso",
    "caluniosas": "calunioso",
    "caluniosos": "calunioso",
    "caluniou": "caluniar",
    "caluniá": "caluniar",
    "caluniámo": "caluniar",
    "caluniámos": "caluniar",
    "caluniáramo": "caluniar",
    "caluniáramos": "caluniar",
    "caluniárei": "caluniar",
    "caluniáreis": "caluniar",
    "caluniásseis": "caluniar",
    "caluniássemos": "caluniar",
    "caluniávamo": "caluniar",
    "caluniávamos": "caluniar",
    "caluniávei": "caluniar",
    "caluniáveis": "caluniável",
    "calutrões": "calutrão",
    "calva": "calvo",
    "calvada": "calvar",
    "calvadas": "calvar",
    "calvado": "calvar",
    "calvados": "calvar",
    "calvai": "calvar",
    "calvais": "calvar",
    "calvam": "calvar",
    "calvamo": "calvar",
    "calvamos": "calvar",
    "calvando": "calvar",
    "calvara": "calvar",
    "calvaram": "calvar",
    "calvaras": "calvar",
    "calvarde": "calvar",
    "calvardes": "calvar",
    "calvare": "calvar",
    "calvarei": "calvar",
    "calvareis": "calvar",
    "calvarem": "calvar",
    "calvaremos": "calvar",
    "calvares": "calvar",
    "calvaria": "calvar",
    "calvariam": "calvar",
    "calvarias": "calvar",
    "calvarmo": "calvar",
    "calvarmos": "calvar",
    "calvará": "calvar",
    "calvarás": "calvar",
    "calvarão": "calvar",
    "calvaríamos": "calvar",
    "calvaríeis": "calvar",
    "calvas": "calvo",
    "calvasse": "calvar",
    "calvassem": "calvar",
    "calvasses": "calvar",
    "calvaste": "calvar",
    "calvastes": "calvar",
    "calvava": "calvar",
    "calvavam": "calvar",
    "calvavas": "calvar",
    "calve": "calvar",
    "calvei": "calvar",
    "calveis": "calvar",
    "calveja": "calvejar",
    "calvejada": "calvejar",
    "calvejadas": "calvejar",
    "calvejado": "calvejar",
    "calvejados": "calvejar",
    "calvejai": "calvejar",
    "calvejais": "calvejar",
    "calvejam": "calvejar",
    "calvejamo": "calvejar",
    "calvejamos": "calvejar",
    "calvejando": "calvejar",
    "calvejara": "calvejar",
    "calvejaram": "calvejar",
    "calvejaras": "calvejar",
    "calvejarde": "calvejar",
    "calvejardes": "calvejar",
    "calvejare": "calvejar",
    "calvejarei": "calvejar",
    "calvejareis": "calvejar",
    "calvejarem": "calvejar",
    "calvejaremos": "calvejar",
    "calvejares": "calvejar",
    "calvejaria": "calvejar",
    "calvejariam": "calvejar",
    "calvejarias": "calvejar",
    "calvejarmo": "calvejar",
    "calvejarmos": "calvejar",
    "calvejará": "calvejar",
    "calvejarás": "calvejar",
    "calvejarão": "calvejar",
    "calvejaríamos": "calvejar",
    "calvejaríeis": "calvejar",
    "calvejas": "calvejar",
    "calvejasse": "calvejar",
    "calvejassem": "calvejar",
    "calvejasses": "calvejar",
    "calvejaste": "calvejar",
    "calvejastes": "calvejar",
    "calvejava": "calvejar",
    "calvejavam": "calvejar",
    "calvejavas": "calvejar",
    "calveje": "calvejar",
    "calvejei": "calvejar",
    "calvejeis": "calvejar",
    "calvejem": "calvejar",
    "calvejemo": "calvejar",
    "calvejemos": "calvejar",
    "calvejes": "calvejar",
    "calvejo": "calvejar",
    "calvejou": "calvejar",
    "calvejá": "calvejar",
    "calvejámo": "calvejar",
    "calvejámos": "calvejar",
    "calvejáramo": "calvejar",
    "calvejáramos": "calvejar",
    "calvejárei": "calvejar",
    "calvejáreis": "calvejar",
    "calvejásseis": "calvejar",
    "calvejássemos": "calvejar",
    "calvejávamo": "calvejar",
    "calvejávamos": "calvejar",
    "calvejávei": "calvejar",
    "calvejáveis": "calvejar",
    "calvem": "calvar",
    "calvemo": "calvar",
    "calvemos": "calvar",
    "calves": "calvar",
    "calvinismos": "calvinismo",
    "calvinistas": "calvinista",
    "calvo": "calvar",
    "calvos": "calvo",
    "calvou": "calvar",
    "calvá": "calvar",
    "calvámo": "calvar",
    "calvámos": "calvar",
    "calváramo": "calvar",
    "calváramos": "calvar",
    "calvárei": "calvar",
    "calváreis": "calvar",
    "calvários": "calvário",
    "calvásseis": "calvar",
    "calvássemos": "calvar",
    "calvávamo": "calvar",
    "calvávamos": "calvar",
    "calvávei": "calvar",
    "calváveis": "calvar",
    "calvícies": "calvície",
    "calá": "calar",
    "calábrica": "calábrico",
    "calábricas": "calábrico",
    "calábricos": "calábrico",
    "calámo": "calar",
    "calámos": "calar",
    "caláramo": "calar",
    "caláramos": "calar",
    "calárei": "calar",
    "caláreis": "calar",
    "calásseis": "calar",
    "calássemos": "calar",
    "calátides": "calátide",
    "calávamo": "calar",
    "calávamos": "calar",
    "calávei": "calar",
    "caláveis": "calável",
    "calânticas": "calântica",
    "calça": "calçar",
    "calçada": "calçar",
    "calçadas": "calçar",
    "calçadeiras": "calçadeira",
    "calçado": "calçar",
    "calçadora": "calçador",
    "calçadoras": "calçador",
    "calçadores": "calçador",
    "calçados": "calçar",
    "calçaduras": "calçadura",
    "calçai": "calçar",
    "calçais": "calçar",
    "calçam": "calçar",
    "calçamo": "calçar",
    "calçamos": "calçar",
    "calçando": "calçar",
    "calçara": "calçar",
    "calçaram": "calçar",
    "calçaras": "calçar",
    "calçarde": "calçar",
    "calçardes": "calçar",
    "calçare": "calçar",
    "calçarei": "calçar",
    "calçareis": "calçar",
    "calçarem": "calçar",
    "calçaremos": "calçar",
    "calçares": "calçar",
    "calçaria": "calçar",
    "calçariam": "calçar",
    "calçarias": "calçar",
    "calçarmo": "calçar",
    "calçarmos": "calçar",
    "calçará": "calçar",
    "calçarás": "calçar",
    "calçarão": "calçar",
    "calçaríamos": "calçar",
    "calçaríeis": "calçar",
    "calças": "calçar",
    "calçasse": "calçar",
    "calçassem": "calçar",
    "calçasses": "calçar",
    "calçaste": "calçar",
    "calçastes": "calçar",
    "calçava": "calçar",
    "calçavam": "calçar",
    "calçavas": "calçar",
    "calçazinhas": "calças",
    "calçazitas": "calças",
    "calço": "calçar",
    "calços": "calço",
    "calçou": "calçar",
    "calçuda": "calçudo",
    "calçudas": "calçudo",
    "calçudos": "calçudo",
    "calçá": "calçar",
    "calçámo": "calçar",
    "calçámos": "calçar",
    "calçáramo": "calçar",
    "calçáramos": "calçar",
    "calçárei": "calçar",
    "calçáreis": "calçar",
    "calçásseis": "calçar",
    "calçássemos": "calçar",
    "calçávamo": "calçar",
    "calçávamos": "calçar",
    "calçávei": "calçar",
    "calçáveis": "calçar",
    "calçãozinho": "calção",
    "calçãozito": "calção",
    "calções": "calção",
    "calçõezinhos": "calção",
    "calçõezitos": "calção",
    "calêndulas": "calêndula",
    "calíbia": "calíbio",
    "calíbias": "calíbio",
    "calíbios": "calíbio",
    "calículos": "calículo",
    "calígrafa": "calígrafo",
    "calígrafas": "calígrafo",
    "calígrafos": "calígrafo",
    "calígulas": "calígula",
    "calípica": "calípico",
    "calípicas": "calípico",
    "calípicos": "calípico",
    "calóptera": "calóptero",
    "calópteras": "calóptero",
    "calópteros": "calóptero",
    "calórica": "calórico",
    "calóricas": "calórico",
    "calóricos": "calórico",
    "calões": "calão",
    "calúnias": "calúnia",
    "camadas": "camada",
    "camadinha": "camada",
    "camadinhas": "camada",
    "camadita": "camada",
    "camaditas": "camada",
    "camadonas": "camadona",
    "camafeus": "camafeu",
    "camais": "camal",
    "camaleões": "camaleão",
    "camalhas": "camalha",
    "camalhões": "camalhão",
    "camaradagens": "camaradagem",
    "camaradas": "camarada",
    "camaradazinha": "camarada",
    "camaradazinhas": "camarada",
    "camaradazinho": "camarada",
    "camaradazinhos": "camarada",
    "camaradazita": "camarada",
    "camaradazitas": "camarada",
    "camaradazito": "camarada",
    "camaradazitos": "camarada",
    "camaradinha": "camarada",
    "camaradinhas": "camarada",
    "camaradita": "camarada",
    "camaraditas": "camarada",
    "camaradona": "camaradão",
    "camaradonas": "camaradão",
    "camaradões": "camaradão",
    "camaranchões": "camaranchão",
    "camararias": "camararia",
    "camaratas": "camarata",
    "camarates": "camarate",
    "camareira": "camareiro",
    "camareiras": "camareiro",
    "camareiros": "camareiro",
    "camarenta": "camarento",
    "camarentas": "camarento",
    "camarentos": "camarento",
    "camarilhas": "camarilha",
    "camarinha": "camarinhar",
    "camarinhada": "camarinhar",
    "camarinhadas": "camarinhar",
    "camarinhado": "camarinhar",
    "camarinhados": "camarinhar",
    "camarinhai": "camarinhar",
    "camarinhais": "camarinhar",
    "camarinham": "camarinhar",
    "camarinhamo": "camarinhar",
    "camarinhamos": "camarinhar",
    "camarinhando": "camarinhar",
    "camarinhara": "camarinhar",
    "camarinharam": "camarinhar",
    "camarinharas": "camarinhar",
    "camarinharde": "camarinhar",
    "camarinhardes": "camarinhar",
    "camarinhare": "camarinhar",
    "camarinharei": "camarinhar",
    "camarinhareis": "camarinhar",
    "camarinharem": "camarinhar",
    "camarinharemos": "camarinhar",
    "camarinhares": "camarinhar",
    "camarinharia": "camarinhar",
    "camarinhariam": "camarinhar",
    "camarinharias": "camarinhar",
    "camarinharmo": "camarinhar",
    "camarinharmos": "camarinhar",
    "camarinhará": "camarinhar",
    "camarinharás": "camarinhar",
    "camarinharão": "camarinhar",
    "camarinharíamos": "camarinhar",
    "camarinharíeis": "camarinhar",
    "camarinhas": "camarinhar",
    "camarinhasse": "camarinhar",
    "camarinhassem": "camarinhar",
    "camarinhasses": "camarinhar",
    "camarinhaste": "camarinhar",
    "camarinhastes": "camarinhar",
    "camarinhava": "camarinhar",
    "camarinhavam": "camarinhar",
    "camarinhavas": "camarinhar",
    "camarinhe": "camarinhar",
    "camarinhei": "camarinhar",
    "camarinheiras": "camarinheira",
    "camarinheis": "camarinhar",
    "camarinhem": "camarinhar",
    "camarinhemo": "camarinhar",
    "camarinhemos": "camarinhar",
    "camarinhes": "camarinhar",
    "camarinho": "camarinhar",
    "camarinhou": "camarinhar",
    "camarinhá": "camarinhar",
    "camarinhámo": "camarinhar",
    "camarinhámos": "camarinhar",
    "camarinháramo": "camarinhar",
    "camarinháramos": "camarinhar",
    "camarinhárei": "camarinhar",
    "camarinháreis": "camarinhar",
    "camarinhásseis": "camarinhar",
    "camarinhássemos": "camarinhar",
    "camarinhávamo": "camarinhar",
    "camarinhávamos": "camarinhar",
    "camarinhávei": "camarinhar",
    "camarinháveis": "camarinhar",
    "camarins": "camarim",
    "camarlengos": "camarlengo",
    "camaroeiros": "camaroeiro",
    "camaroteira": "camaroteiro",
    "camaroteiras": "camaroteiro",
    "camaroteiros": "camaroteiro",
    "camarotes": "camarote",
    "camartela": "camartelar",
    "camartelada": "camartelar",
    "camarteladas": "camartelar",
    "camartelado": "camartelar",
    "camartelados": "camartelar",
    "camartelai": "camartelar",
    "camartelais": "camartelar",
    "camartelam": "camartelar",
    "camartelamo": "camartelar",
    "camartelamos": "camartelar",
    "camartelando": "camartelar",
    "camartelara": "camartelar",
    "camartelaram": "camartelar",
    "camartelaras": "camartelar",
    "camartelarde": "camartelar",
    "camartelardes": "camartelar",
    "camartelare": "camartelar",
    "camartelarei": "camartelar",
    "camartelareis": "camartelar",
    "camartelarem": "camartelar",
    "camartelaremos": "camartelar",
    "camartelares": "camartelar",
    "camartelaria": "camartelar",
    "camartelariam": "camartelar",
    "camartelarias": "camartelar",
    "camartelarmo": "camartelar",
    "camartelarmos": "camartelar",
    "camartelará": "camartelar",
    "camartelarás": "camartelar",
    "camartelarão": "camartelar",
    "camartelaríamos": "camartelar",
    "camartelaríeis": "camartelar",
    "camartelas": "camartelar",
    "camartelasse": "camartelar",
    "camartelassem": "camartelar",
    "camartelasses": "camartelar",
    "camartelaste": "camartelar",
    "camartelastes": "camartelar",
    "camartelava": "camartelar",
    "camartelavam": "camartelar",
    "camartelavas": "camartelar",
    "camartele": "camartelar",
    "camartelei": "camartelar",
    "camarteleis": "camartelar",
    "camartelem": "camartelar",
    "camartelemo": "camartelar",
    "camartelemos": "camartelar",
    "camarteles": "camartelar",
    "camartelo": "camartelar",
    "camartelos": "camartelo",
    "camartelou": "camartelar",
    "camartelá": "camartelar",
    "camartelámo": "camartelar",
    "camartelámos": "camartelar",
    "camarteláramo": "camartelar",
    "camarteláramos": "camartelar",
    "camartelárei": "camartelar",
    "camarteláreis": "camartelar",
    "camartelásseis": "camartelar",
    "camartelássemos": "camartelar",
    "camartelávamo": "camartelar",
    "camartelávamos": "camartelar",
    "camartelávei": "camartelar",
    "camarteláveis": "camartelar",
    "camarária": "camarário",
    "camarárias": "camarário",
    "camarários": "camarário",
    "camarãozinho": "camarão",
    "camarãozito": "camarão",
    "camarçadas": "camarçada",
    "camarços": "camarço",
    "camarções": "camarção",
    "camarões": "camarão",
    "camarõezinhos": "camarão",
    "camarõezitos": "camarão",
    "camas": "cama",
    "camauros": "camauro",
    "camba": "cambar",
    "cambada": "cambar",
    "cambadas": "cambar",
    "cambadelas": "cambadela",
    "cambado": "cambar",
    "cambadoiros": "cambadoiro",
    "cambados": "cambar",
    "cambadouros": "cambadouro",
    "cambai": "cambar",
    "cambaia": "cambaio",
    "cambaias": "cambaio",
    "cambaios": "cambaio",
    "cambais": "cambar",
    "cambalacha": "cambalachar",
    "cambalachada": "cambalachar",
    "cambalachadas": "cambalachar",
    "cambalachado": "cambalachar",
    "cambalachados": "cambalachar",
    "cambalachai": "cambalachar",
    "cambalachais": "cambalachar",
    "cambalacham": "cambalachar",
    "cambalachamo": "cambalachar",
    "cambalachamos": "cambalachar",
    "cambalachando": "cambalachar",
    "cambalachara": "cambalachar",
    "cambalacharam": "cambalachar",
    "cambalacharas": "cambalachar",
    "cambalachardes": "cambalachar",
    "cambalacharei": "cambalachar",
    "cambalachareis": "cambalachar",
    "cambalacharem": "cambalachar",
    "cambalacharemos": "cambalachar",
    "cambalachares": "cambalachar",
    "cambalacharia": "cambalachar",
    "cambalachariam": "cambalachar",
    "cambalacharias": "cambalachar",
    "cambalacharmo": "cambalachar",
    "cambalacharmos": "cambalachar",
    "cambalachará": "cambalachar",
    "cambalacharás": "cambalachar",
    "cambalacharão": "cambalachar",
    "cambalacharíamos": "cambalachar",
    "cambalacharíeis": "cambalachar",
    "cambalachas": "cambalachar",
    "cambalachasse": "cambalachar",
    "cambalachassem": "cambalachar",
    "cambalachasses": "cambalachar",
    "cambalachaste": "cambalachar",
    "cambalachastes": "cambalachar",
    "cambalachava": "cambalachar",
    "cambalachavam": "cambalachar",
    "cambalachavas": "cambalachar",
    "cambalache": "cambalachar",
    "cambalachei": "cambalachar",
    "cambalacheis": "cambalachar",
    "cambalachem": "cambalachar",
    "cambalachemo": "cambalachar",
    "cambalachemos": "cambalachar",
    "cambalaches": "cambalachar",
    "cambalacho": "cambalachar",
    "cambalachos": "cambalacho",
    "cambalachou": "cambalachar",
    "cambalachámo": "cambalachar",
    "cambalachámos": "cambalachar",
    "cambalacháramo": "cambalachar",
    "cambalacháramos": "cambalachar",
    "cambalacháreis": "cambalachar",
    "cambalachásseis": "cambalachar",
    "cambalachássemos": "cambalachar",
    "cambalachávamo": "cambalachar",
    "cambalachávamos": "cambalachar",
    "cambalacháveis": "cambalachar",
    "cambaleada": "cambalear",
    "cambaleadas": "cambalear",
    "cambaleado": "cambalear",
    "cambaleados": "cambalear",
    "cambaleai": "cambalear",
    "cambaleais": "cambalear",
    "cambaleamo": "cambalear",
    "cambaleamos": "cambalear",
    "cambaleando": "cambalear",
    "cambaleantes": "cambaleante",
    "cambaleara": "cambalear",
    "cambalearam": "cambalear",
    "cambalearas": "cambalear",
    "cambaleardes": "cambalear",
    "cambalearei": "cambalear",
    "cambaleareis": "cambalear",
    "cambalearem": "cambalear",
    "cambalearemos": "cambalear",
    "cambaleares": "cambalear",
    "cambalearia": "cambalear",
    "cambaleariam": "cambalear",
    "cambalearias": "cambalear",
    "cambalearmo": "cambalear",
    "cambalearmos": "cambalear",
    "cambaleará": "cambalear",
    "cambalearás": "cambalear",
    "cambalearão": "cambalear",
    "cambalearíamos": "cambalear",
    "cambalearíeis": "cambalear",
    "cambaleasse": "cambalear",
    "cambaleassem": "cambalear",
    "cambaleasses": "cambalear",
    "cambaleaste": "cambalear",
    "cambaleastes": "cambalear",
    "cambaleava": "cambalear",
    "cambaleavam": "cambalear",
    "cambaleavas": "cambalear",
    "cambaleei": "cambalear",
    "cambaleeis": "cambalear",
    "cambaleemo": "cambalear",
    "cambaleemos": "cambalear",
    "cambaleia": "cambalear",
    "cambaleiam": "cambalear",
    "cambaleias": "cambalear",
    "cambaleie": "cambalear",
    "cambaleiem": "cambalear",
    "cambaleies": "cambalear",
    "cambaleio": "cambalear",
    "cambaleios": "cambaleio",
    "cambaleou": "cambalear",
    "cambaleámo": "cambalear",
    "cambaleámos": "cambalear",
    "cambaleáramo": "cambalear",
    "cambaleáramos": "cambalear",
    "cambaleáreis": "cambalear",
    "cambaleásseis": "cambalear",
    "cambaleássemos": "cambalear",
    "cambaleávamo": "cambalear",
    "cambaleávamos": "cambalear",
    "cambaleáveis": "cambalear",
    "cambalhota": "cambalhotar",
    "cambalhotada": "cambalhotar",
    "cambalhotadas": "cambalhotar",
    "cambalhotado": "cambalhotar",
    "cambalhotados": "cambalhotar",
    "cambalhotai": "cambalhotar",
    "cambalhotais": "cambalhotar",
    "cambalhotam": "cambalhotar",
    "cambalhotamo": "cambalhotar",
    "cambalhotamos": "cambalhotar",
    "cambalhotando": "cambalhotar",
    "cambalhotara": "cambalhotar",
    "cambalhotaram": "cambalhotar",
    "cambalhotaras": "cambalhotar",
    "cambalhotardes": "cambalhotar",
    "cambalhotarei": "cambalhotar",
    "cambalhotareis": "cambalhotar",
    "cambalhotarem": "cambalhotar",
    "cambalhotaremos": "cambalhotar",
    "cambalhotares": "cambalhotar",
    "cambalhotaria": "cambalhotar",
    "cambalhotariam": "cambalhotar",
    "cambalhotarias": "cambalhotar",
    "cambalhotarmo": "cambalhotar",
    "cambalhotarmos": "cambalhotar",
    "cambalhotará": "cambalhotar",
    "cambalhotarás": "cambalhotar",
    "cambalhotarão": "cambalhotar",
    "cambalhotaríamos": "cambalhotar",
    "cambalhotaríeis": "cambalhotar",
    "cambalhotas": "cambalhotar",
    "cambalhotasse": "cambalhotar",
    "cambalhotassem": "cambalhotar",
    "cambalhotasses": "cambalhotar",
    "cambalhotaste": "cambalhotar",
    "cambalhotastes": "cambalhotar",
    "cambalhotava": "cambalhotar",
    "cambalhotavam": "cambalhotar",
    "cambalhotavas": "cambalhotar",
    "cambalhote": "cambalhotar",
    "cambalhotei": "cambalhotar",
    "cambalhoteis": "cambalhotar",
    "cambalhotem": "cambalhotar",
    "cambalhotemo": "cambalhotar",
    "cambalhotemos": "cambalhotar",
    "cambalhotes": "cambalhotar",
    "cambalhoto": "cambalhotar",
    "cambalhotou": "cambalhotar",
    "cambalhotámo": "cambalhotar",
    "cambalhotámos": "cambalhotar",
    "cambalhotáramo": "cambalhotar",
    "cambalhotáramos": "cambalhotar",
    "cambalhotáreis": "cambalhotar",
    "cambalhotásseis": "cambalhotar",
    "cambalhotássemos": "cambalhotar",
    "cambalhotávamo": "cambalhotar",
    "cambalhotávamos": "cambalhotar",
    "cambalhotáveis": "cambalhotar",
    "cambalhões": "cambalhão",
    "cambaluzes": "cambaluz",
    "cambaluços": "cambaluço",
    "cambam": "cambar",
    "cambamo": "cambar",
    "cambamos": "cambar",
    "cambando": "cambar",
    "cambanitos": "cambanito",
    "cambapés": "cambapé",
    "cambara": "cambar",
    "cambaram": "cambar",
    "cambaras": "cambar",
    "cambardes": "cambar",
    "cambarei": "cambar",
    "cambareis": "cambar",
    "cambarem": "cambar",
    "cambaremos": "cambar",
    "cambares": "cambar",
    "cambaria": "cambar",
    "cambariam": "cambar",
    "cambarias": "cambar",
    "cambarmo": "cambar",
    "cambarmos": "cambar",
    "cambará": "cambar",
    "cambarás": "cambar",
    "cambarão": "cambar",
    "cambaríamos": "cambar",
    "cambaríeis": "cambar",
    "cambas": "cambar",
    "cambasse": "cambar",
    "cambassem": "cambar",
    "cambasses": "cambar",
    "cambaste": "cambar",
    "cambastes": "cambar",
    "cambava": "cambar",
    "cambavam": "cambar",
    "cambavas": "cambar",
    "cambe": "cambar",
    "cambei": "cambar",
    "cambeiradas": "cambeirada",
    "cambeirais": "cambeiral",
    "cambeiras": "cambeira",
    "cambeiros": "cambeiro",
    "cambeis": "cambar",
    "cambem": "cambar",
    "cambemo": "cambar",
    "cambemos": "cambar",
    "cambes": "cambar",
    "cambetas": "cambeta",
    "cambeteada": "cambetear",
    "cambeteadas": "cambetear",
    "cambeteado": "cambetear",
    "cambeteados": "cambetear",
    "cambeteai": "cambetear",
    "cambeteais": "cambetear",
    "cambeteamo": "cambetear",
    "cambeteamos": "cambetear",
    "cambeteando": "cambetear",
    "cambeteara": "cambetear",
    "cambetearam": "cambetear",
    "cambetearas": "cambetear",
    "cambeteardes": "cambetear",
    "cambetearei": "cambetear",
    "cambeteareis": "cambetear",
    "cambetearem": "cambetear",
    "cambetearemos": "cambetear",
    "cambeteares": "cambetear",
    "cambetearia": "cambetear",
    "cambeteariam": "cambetear",
    "cambetearias": "cambetear",
    "cambetearmo": "cambetear",
    "cambetearmos": "cambetear",
    "cambeteará": "cambetear",
    "cambetearás": "cambetear",
    "cambetearão": "cambetear",
    "cambetearíamos": "cambetear",
    "cambetearíeis": "cambetear",
    "cambeteasse": "cambetear",
    "cambeteassem": "cambetear",
    "cambeteasses": "cambetear",
    "cambeteaste": "cambetear",
    "cambeteastes": "cambetear",
    "cambeteava": "cambetear",
    "cambeteavam": "cambetear",
    "cambeteavas": "cambetear",
    "cambeteei": "cambetear",
    "cambeteeis": "cambetear",
    "cambeteemo": "cambetear",
    "cambeteemos": "cambetear",
    "cambeteia": "cambetear",
    "cambeteiam": "cambetear",
    "cambeteias": "cambetear",
    "cambeteie": "cambetear",
    "cambeteiem": "cambetear",
    "cambeteies": "cambetear",
    "cambeteio": "cambetear",
    "cambeteou": "cambetear",
    "cambeteámo": "cambetear",
    "cambeteámos": "cambetear",
    "cambeteáramo": "cambetear",
    "cambeteáramos": "cambetear",
    "cambeteáreis": "cambetear",
    "cambeteásseis": "cambetear",
    "cambeteássemos": "cambetear",
    "cambeteávamo": "cambetear",
    "cambeteávamos": "cambetear",
    "cambeteáveis": "cambetear",
    "cambia": "cambiar",
    "cambiada": "cambiar",
    "cambiadas": "cambiar",
    "cambiado": "cambiar",
    "cambiados": "cambiar",
    "cambiai": "cambiar",
    "cambiais": "cambiar",
    "cambialidades": "cambialidade",
    "cambiam": "cambiar",
    "cambiamo": "cambiar",
    "cambiamos": "cambiar",
    "cambiando": "cambiar",
    "cambiantes": "cambiante",
    "cambiara": "cambiar",
    "cambiaram": "cambiar",
    "cambiaras": "cambiar",
    "cambiarde": "cambiar",
    "cambiardes": "cambiar",
    "cambiare": "cambiar",
    "cambiarei": "cambiar",
    "cambiareis": "cambiar",
    "cambiarem": "cambiar",
    "cambiaremos": "cambiar",
    "cambiares": "cambiar",
    "cambiaria": "cambiar",
    "cambiariam": "cambiar",
    "cambiarias": "cambiar",
    "cambiarmo": "cambiar",
    "cambiarmos": "cambiar",
    "cambiará": "cambiar",
    "cambiarás": "cambiar",
    "cambiarão": "cambiar",
    "cambiaríamos": "cambiar",
    "cambiaríeis": "cambiar",
    "cambias": "cambiar",
    "cambiasse": "cambiar",
    "cambiassem": "cambiar",
    "cambiasses": "cambiar",
    "cambiaste": "cambiar",
    "cambiastes": "cambiar",
    "cambiava": "cambiar",
    "cambiavam": "cambiar",
    "cambiavas": "cambiar",
    "cambiações": "cambiação",
    "cambie": "cambiar",
    "cambiei": "cambiar",
    "cambieis": "cambiar",
    "cambiem": "cambiar",
    "cambiemo": "cambiar",
    "cambiemos": "cambiar",
    "cambies": "cambiar",
    "cambio": "cambiar",
    "cambiou": "cambiar",
    "cambismos": "cambismo",
    "cambistas": "cambista",
    "cambiá": "cambiar",
    "cambiámo": "cambiar",
    "cambiámos": "cambiar",
    "cambiáramo": "cambiar",
    "cambiáramos": "cambiar",
    "cambiárei": "cambiar",
    "cambiáreis": "cambiar",
    "cambiásseis": "cambiar",
    "cambiássemos": "cambiar",
    "cambiávamo": "cambiar",
    "cambiávamos": "cambiar",
    "cambiávei": "cambiar",
    "cambiáveis": "cambiável",
    "cambo": "cambar",
    "camboa": "camboar",
    "camboada": "camboar",
    "camboadas": "camboar",
    "camboado": "camboar",
    "camboados": "camboar",
    "camboai": "camboar",
    "camboais": "camboar",
    "camboam": "camboar",
    "camboamo": "camboar",
    "camboamos": "camboar",
    "camboando": "camboar",
    "camboara": "camboar",
    "camboaram": "camboar",
    "camboaras": "camboar",
    "camboardes": "camboar",
    "camboarei": "camboar",
    "camboareis": "camboar",
    "camboarem": "camboar",
    "camboaremos": "camboar",
    "camboares": "camboar",
    "camboaria": "camboar",
    "camboariam": "camboar",
    "camboarias": "camboar",
    "camboarmo": "camboar",
    "camboarmos": "camboar",
    "camboará": "camboar",
    "camboarás": "camboar",
    "camboarão": "camboar",
    "camboaríamos": "camboar",
    "camboaríeis": "camboar",
    "camboas": "camboar",
    "camboasse": "camboar",
    "camboassem": "camboar",
    "camboasses": "camboar",
    "camboaste": "camboar",
    "camboastes": "camboar",
    "camboava": "camboar",
    "camboavam": "camboar",
    "camboavas": "camboar",
    "camboe": "camboar",
    "camboei": "camboar",
    "camboeiras": "camboeira",
    "camboeis": "camboar",
    "camboem": "camboar",
    "camboemo": "camboar",
    "camboemos": "camboar",
    "camboes": "camboar",
    "cambojana": "cambojano",
    "cambojanas": "cambojano",
    "cambojanos": "cambojano",
    "cambola": "cambolar",
    "cambolada": "cambolar",
    "camboladas": "cambolar",
    "cambolado": "cambolar",
    "camboladora": "cambolador",
    "camboladoras": "cambolador",
    "camboladores": "cambolador",
    "cambolados": "cambolar",
    "cambolai": "cambolar",
    "cambolais": "cambolar",
    "cambolam": "cambolar",
    "cambolamo": "cambolar",
    "cambolamos": "cambolar",
    "cambolando": "cambolar",
    "cambolara": "cambolar",
    "cambolaram": "cambolar",
    "cambolaras": "cambolar",
    "cambolarde": "cambolar",
    "cambolardes": "cambolar",
    "cambolare": "cambolar",
    "cambolarei": "cambolar",
    "cambolareis": "cambolar",
    "cambolarem": "cambolar",
    "cambolaremos": "cambolar",
    "cambolares": "cambolar",
    "cambolaria": "cambolar",
    "cambolariam": "cambolar",
    "cambolarias": "cambolar",
    "cambolarmo": "cambolar",
    "cambolarmos": "cambolar",
    "cambolará": "cambolar",
    "cambolarás": "cambolar",
    "cambolarão": "cambolar",
    "cambolaríamos": "cambolar",
    "cambolaríeis": "cambolar",
    "cambolas": "cambolar",
    "cambolasse": "cambolar",
    "cambolassem": "cambolar",
    "cambolasses": "cambolar",
    "cambolaste": "cambolar",
    "cambolastes": "cambolar",
    "cambolava": "cambolar",
    "cambolavam": "cambolar",
    "cambolavas": "cambolar",
    "cambolações": "cambolação",
    "cambole": "cambolar",
    "cambolei": "cambolar",
    "camboleis": "cambolar",
    "cambolem": "cambolar",
    "cambolemo": "cambolar",
    "cambolemos": "cambolar",
    "camboles": "cambolar",
    "cambolo": "cambolar",
    "cambolou": "cambolar",
    "cambolá": "cambolar",
    "cambolámo": "cambolar",
    "cambolámos": "cambolar",
    "camboláramo": "cambolar",
    "camboláramos": "cambolar",
    "cambolárei": "cambolar",
    "camboláreis": "cambolar",
    "cambolásseis": "cambolar",
    "cambolássemos": "cambolar",
    "cambolávamo": "cambolar",
    "cambolávamos": "cambolar",
    "cambolávei": "cambolar",
    "camboláveis": "cambolar",
    "cambonas": "cambona",
    "camboo": "camboar",
    "camboou": "camboar",
    "cambos": "cambo",
    "cambotas": "cambota",
    "cambou": "cambar",
    "camboámo": "camboar",
    "camboámos": "camboar",
    "camboáramo": "camboar",
    "camboáramos": "camboar",
    "camboáreis": "camboar",
    "camboásseis": "camboar",
    "camboássemos": "camboar",
    "camboávamo": "camboar",
    "camboávamos": "camboar",
    "camboáveis": "camboar",
    "cambra": "cambrar",
    "cambrada": "cambrar",
    "cambradas": "cambrar",
    "cambrado": "cambrar",
    "cambrados": "cambrar",
    "cambrai": "cambrar",
    "cambraias": "cambraia",
    "cambraietas": "cambraieta",
    "cambrais": "cambrar",
    "cambram": "cambrar",
    "cambramo": "cambrar",
    "cambramos": "cambrar",
    "cambrando": "cambrar",
    "cambrara": "cambrar",
    "cambraram": "cambrar",
    "cambraras": "cambrar",
    "cambrarde": "cambrar",
    "cambrardes": "cambrar",
    "cambrare": "cambrar",
    "cambrarei": "cambrar",
    "cambrareis": "cambrar",
    "cambrarem": "cambrar",
    "cambraremos": "cambrar",
    "cambrares": "cambrar",
    "cambraria": "cambrar",
    "cambrariam": "cambrar",
    "cambrarias": "cambrar",
    "cambrarmo": "cambrar",
    "cambrarmos": "cambrar",
    "cambrará": "cambrar",
    "cambrarás": "cambrar",
    "cambrarão": "cambrar",
    "cambraríamos": "cambrar",
    "cambraríeis": "cambrar",
    "cambras": "cambrar",
    "cambrasse": "cambrar",
    "cambrassem": "cambrar",
    "cambrasses": "cambrar",
    "cambraste": "cambrar",
    "cambrastes": "cambrar",
    "cambrava": "cambrar",
    "cambravam": "cambrar",
    "cambravas": "cambrar",
    "cambre": "cambrar",
    "cambrei": "cambrar",
    "cambreis": "cambrar",
    "cambrem": "cambrar",
    "cambremo": "cambrar",
    "cambremos": "cambrar",
    "cambres": "cambrar",
    "cambriana": "cambriano",
    "cambrianas": "cambriano",
    "cambrianos": "cambriano",
    "cambro": "cambrar",
    "cambroeiras": "cambroeira",
    "cambrou": "cambrar",
    "cambrá": "cambrar",
    "cambrámo": "cambrar",
    "cambrámos": "cambrar",
    "cambráramo": "cambrar",
    "cambráramos": "cambrar",
    "cambrárei": "cambrar",
    "cambráreis": "cambrar",
    "cambrásseis": "cambrar",
    "cambrássemos": "cambrar",
    "cambrávamo": "cambrar",
    "cambrávamos": "cambrar",
    "cambrávei": "cambrar",
    "cambráveis": "cambrar",
    "cambrões": "cambrão",
    "cambuda": "cambudo",
    "cambudas": "cambudo",
    "cambudos": "cambudo",
    "cambulhadas": "cambulhada",
    "cambulhas": "cambulha",
    "cambulhos": "cambulho",
    "cambulhões": "cambulhão",
    "cambámo": "cambar",
    "cambámos": "cambar",
    "cambáramo": "cambar",
    "cambáramos": "cambar",
    "cambáreis": "cambar",
    "cambásseis": "cambar",
    "cambássemos": "cambar",
    "cambávamo": "cambar",
    "cambávamos": "cambar",
    "cambáveis": "cambar",
    "cambões": "cambão",
    "cameada": "camear",
    "cameadas": "camear",
    "cameado": "camear",
    "cameados": "camear",
    "cameai": "camear",
    "cameais": "camear",
    "cameamo": "camear",
    "cameamos": "camear",
    "cameando": "camear",
    "cameara": "camear",
    "camearam": "camear",
    "camearas": "camear",
    "camearde": "camear",
    "cameardes": "camear",
    "cameare": "camear",
    "camearei": "camear",
    "cameareis": "camear",
    "camearem": "camear",
    "camearemos": "camear",
    "cameares": "camear",
    "camearia": "camear",
    "cameariam": "camear",
    "camearias": "camear",
    "camearmo": "camear",
    "camearmos": "camear",
    "cameará": "camear",
    "camearás": "camear",
    "camearão": "camear",
    "camearíamos": "camear",
    "camearíeis": "camear",
    "cameasse": "camear",
    "cameassem": "camear",
    "cameasses": "camear",
    "cameaste": "camear",
    "cameastes": "camear",
    "cameava": "camear",
    "cameavam": "camear",
    "cameavas": "camear",
    "camecefalias": "camecefalia",
    "camecéfala": "camecéfalo",
    "camecéfalas": "camecéfalo",
    "camecéfalos": "camecéfalo",
    "cameei": "camear",
    "cameeis": "camear",
    "cameemo": "camear",
    "cameemos": "camear",
    "cameia": "camear",
    "cameiam": "camear",
    "cameias": "camear",
    "cameie": "camear",
    "cameiem": "camear",
    "cameies": "camear",
    "cameio": "camear",
    "cameleiras": "cameleira",
    "cameleiros": "cameleiro",
    "cameleontídeos": "cameleontídeo",
    "cameleôntidas": "cameleôntida",
    "cameleões": "cameleão",
    "camelices": "camelice",
    "cameliformes": "cameliforme",
    "camelina": "camelino",
    "camelinas": "camelino",
    "camelinos": "camelino",
    "camelopárdales": "camelopárdale",
    "camelornitos": "camelornito",
    "camelos": "camelo",
    "camelídeos": "camelídeo",
    "camelôs": "camelô",
    "camelões": "camelão",
    "camenas": "camena",
    "cameou": "camear",
    "camerlengados": "camerlengado",
    "camerlengos": "camerlengo",
    "cameá": "camear",
    "cameámo": "camear",
    "cameámos": "camear",
    "cameáramo": "camear",
    "cameáramos": "camear",
    "cameárei": "camear",
    "cameáreis": "camear",
    "cameásseis": "camear",
    "cameássemos": "camear",
    "cameávamo": "camear",
    "cameávamos": "camear",
    "cameávei": "camear",
    "cameáveis": "camear",
    "camicases": "camicase",
    "camilas": "camila",
    "camilhas": "camilha",
    "camiliana": "camiliano",
    "camilianas": "camiliano",
    "camilianistas": "camilianista",
    "camilianos": "camiliano",
    "camilistas": "camilista",
    "camilongas": "camilonga",
    "caminha": "caminhar",
    "caminhada": "caminhar",
    "caminhadas": "caminhar",
    "caminhado": "caminhar",
    "caminhadora": "caminhador",
    "caminhadoras": "caminhador",
    "caminhadores": "caminhador",
    "caminhados": "caminhar",
    "caminhai": "caminhar",
    "caminhais": "caminhar",
    "caminham": "caminhar",
    "caminhamo": "caminhar",
    "caminhamos": "caminhar",
    "caminhando": "caminhar",
    "caminhantes": "caminhante",
    "caminhara": "caminhar",
    "caminharam": "caminhar",
    "caminharas": "caminhar",
    "caminhardes": "caminhar",
    "caminharei": "caminhar",
    "caminhareis": "caminhar",
    "caminharem": "caminhar",
    "caminharemos": "caminhar",
    "caminhares": "caminhar",
    "caminharia": "caminhar",
    "caminhariam": "caminhar",
    "caminharias": "caminhar",
    "caminharmo": "caminhar",
    "caminharmos": "caminhar",
    "caminhará": "caminhar",
    "caminharás": "caminhar",
    "caminharão": "caminhar",
    "caminharíamos": "caminhar",
    "caminharíeis": "caminhar",
    "caminhas": "caminhar",
    "caminhasse": "caminhar",
    "caminhassem": "caminhar",
    "caminhasses": "caminhar",
    "caminhaste": "caminhar",
    "caminhastes": "caminhar",
    "caminhava": "caminhar",
    "caminhavam": "caminhar",
    "caminhavas": "caminhar",
    "caminhe": "caminhar",
    "caminhei": "caminhar",
    "caminheira": "caminheiro",
    "caminheiras": "caminheiro",
    "caminheiros": "caminheiro",
    "caminheis": "caminhar",
    "caminhem": "caminhar",
    "caminhemo": "caminhar",
    "caminhemos": "caminhar",
    "caminhenses": "caminhense",
    "caminhes": "caminhar",
    "caminhetas": "caminheta",
    "caminho": "caminhar",
    "caminhos": "caminho",
    "caminhou": "caminhar",
    "caminhámo": "caminhar",
    "caminhámos": "caminhar",
    "caminháramo": "caminhar",
    "caminháramos": "caminhar",
    "caminháreis": "caminhar",
    "caminhásseis": "caminhar",
    "caminhássemos": "caminhar",
    "caminhávamo": "caminhar",
    "caminhávamos": "caminhar",
    "caminháveis": "caminhar",
    "caminhões": "caminhão",
    "caminologias": "caminologia",
    "caminotecnias": "caminotecnia",
    "camins": "camim",
    "camionagens": "camionagem",
    "camionetas": "camioneta",
    "camionetes": "camionete",
    "camionistas": "camionista",
    "camisarias": "camisaria",
    "camisas": "camisa",
    "camiseira": "camiseiro",
    "camiseiras": "camiseiro",
    "camiseiros": "camiseiro",
    "camisetas": "camiseta",
    "camisinha": "camisa",
    "camisinhas": "camisa",
    "camisita": "camisa",
    "camisitas": "camisa",
    "camisolas": "camisola",
    "camisoleiros": "camisoleiro",
    "camisolões": "camisolão",
    "camisotes": "camisote",
    "camisões": "camisão",
    "camita": "cama",
    "camitas": "camita",
    "camiões": "camião",
    "camochos": "camocho",
    "camocicas": "camocica",
    "camoecas": "camoeca",
    "camoesas": "camoesa",
    "camomilas": "camomila",
    "camomilhas": "camomilha",
    "camonhadora": "camonhador",
    "camonhadoras": "camonhador",
    "camonhadores": "camonhador",
    "camoniana": "camoniano",
    "camonianas": "camoniano",
    "camonianistas": "camonianista",
    "camonianos": "camoniano",
    "camonologias": "camonologia",
    "camorras": "camorra",
    "campa": "campar",
    "campada": "campar",
    "campadas": "campar",
    "campado": "campar",
    "campados": "campar",
    "campai": "campar",
    "campainhadas": "campainhada",
    "campainhadelas": "campainhadela",
    "campainhas": "campainha",
    "campainheiros": "campainheiro",
    "campainhões": "campainhão",
    "campais": "campar",
    "campam": "campar",
    "campamo": "campar",
    "campamos": "campar",
    "campanas": "campana",
    "campando": "campar",
    "campaneira": "campaneiro",
    "campaneiras": "campaneiro",
    "campaneiros": "campaneiro",
    "campanhas": "campanha",
    "campanhistas": "campanhista",
    "campaniana": "campaniano",
    "campanianas": "campaniano",
    "campanianos": "campaniano",
    "campaniformes": "campaniforme",
    "campanilos": "campanilo",
    "campanis": "campanil",
    "campaniça": "campaniço",
    "campaniças": "campaniço",
    "campaniços": "campaniço",
    "campanologias": "campanologia",
    "campanuda": "campanudo",
    "campanudas": "campanudo",
    "campanudos": "campanudo",
    "campanulada": "campanulado",
    "campanuladas": "campanulado",
    "campanulados": "campanulado",
    "campanulara": "campanular",
    "campanularas": "campanular",
    "campanulares": "campanular",
    "campanulácea": "campanuláceo",
    "campanuláceas": "campanuláceo",
    "campanuláceos": "campanuláceo",
    "campanários": "campanário",
    "campanóloga": "campanólogo",
    "campanólogas": "campanólogo",
    "campanólogos": "campanólogo",
    "campara": "campar",
    "camparam": "campar",
    "camparas": "campar",
    "campardes": "campar",
    "camparei": "campar",
    "campareis": "campar",
    "camparem": "campar",
    "camparemos": "campar",
    "campares": "campar",
    "camparia": "campar",
    "campariam": "campar",
    "camparias": "campar",
    "camparmo": "campar",
    "camparmos": "campar",
    "campará": "campar",
    "camparás": "campar",
    "camparão": "campar",
    "camparíamos": "campar",
    "camparíeis": "campar",
    "campas": "campar",
    "campasse": "campar",
    "campassem": "campar",
    "campasses": "campar",
    "campaste": "campar",
    "campastes": "campar",
    "campava": "campar",
    "campavam": "campar",
    "campavas": "campar",
    "campações": "campação",
    "campe": "campar",
    "campeada": "campear",
    "campeadas": "campear",
    "campeado": "campear",
    "campeadora": "campeador",
    "campeadoras": "campeador",
    "campeadores": "campeador",
    "campeados": "campear",
    "campeai": "campear",
    "campeais": "campear",
    "campeamo": "campear",
    "campeamos": "campear",
    "campeando": "campear",
    "campeara": "campear",
    "campearam": "campear",
    "campearas": "campear",
    "campeardes": "campear",
    "campearei": "campear",
    "campeareis": "campear",
    "campearem": "campear",
    "campearemos": "campear",
    "campeares": "campear",
    "campearia": "campear",
    "campeariam": "campear",
    "campearias": "campear",
    "campearmo": "campear",
    "campearmos": "campear",
    "campeará": "campear",
    "campearás": "campear",
    "campearão": "campear",
    "campearíamos": "campear",
    "campearíeis": "campear",
    "campeasse": "campear",
    "campeassem": "campear",
    "campeasses": "campear",
    "campeaste": "campear",
    "campeastes": "campear",
    "campeava": "campear",
    "campeavam": "campear",
    "campeavas": "campear",
    "campecheiros": "campecheiro",
    "campeches": "campeche",
    "campeei": "campear",
    "campeeis": "campear",
    "campeemo": "campear",
    "campeemos": "campear",
    "campei": "campar",
    "campeia": "campear",
    "campeiam": "campear",
    "campeias": "campear",
    "campeie": "campear",
    "campeiem": "campear",
    "campeies": "campear",
    "campeio": "campear",
    "campeira": "campeiro",
    "campeiras": "campeiro",
    "campeiros": "campeiro",
    "campeis": "campar",
    "campem": "campar",
    "campemo": "campar",
    "campemos": "campar",
    "campenomias": "campenomia",
    "campeonatos": "campeonato",
    "campeou": "campear",
    "campes": "campar",
    "campesina": "campesino",
    "campesinas": "campesino",
    "campesinatos": "campesinato",
    "campesinha": "campesinho",
    "campesinhas": "campesinho",
    "campesinhos": "campesinho",
    "campesinos": "campesino",
    "campestres": "campestre",
    "campeámo": "campear",
    "campeámos": "campear",
    "campeáramo": "campear",
    "campeáramos": "campear",
    "campeáreis": "campear",
    "campeásseis": "campear",
    "campeássemos": "campear",
    "campeávamo": "campear",
    "campeávamos": "campear",
    "campeáveis": "campear",
    "campeã": "campeão",
    "campeãs": "campeão",
    "campeões": "campeão",
    "campi": "campus",
    "campilotrópica": "campilotrópico",
    "campilotrópicas": "campilotrópico",
    "campilotrópicos": "campilotrópico",
    "campilótropa": "campilótropo",
    "campilótropas": "campilótropo",
    "campilótropos": "campilótropo",
    "campimetrias": "campimetria",
    "campimétrica": "campimétrico",
    "campimétricas": "campimétrico",
    "campimétricos": "campimétrico",
    "campina": "campino",
    "campinas": "campino",
    "campineira": "campineiro",
    "campineiras": "campineiro",
    "campineiros": "campineiro",
    "campinenses": "campinense",
    "campings": "camping",
    "campinos": "campino",
    "campismos": "campismo",
    "campistas": "campista",
    "campo": "campar",
    "camponesa": "camponês",
    "camponesas": "camponês",
    "camponeses": "camponês",
    "campos": "campo",
    "camposa": "camposo",
    "camposas": "camposo",
    "camposos": "camposo",
    "campou": "campar",
    "camptologias": "camptologia",
    "camptonitos": "camptonito",
    "campámo": "campar",
    "campámos": "campar",
    "campáramo": "campar",
    "campáramos": "campar",
    "campáreis": "campar",
    "campásseis": "campar",
    "campássemos": "campar",
    "campávamo": "campar",
    "campávamos": "campar",
    "campáveis": "campar",
    "campânulas": "campânula",
    "campéfaga": "campéfago",
    "campéfagas": "campéfago",
    "campéfagos": "campéfago",
    "campícolas": "campícola",
    "campímetros": "campímetro",
    "campónia": "campónio",
    "campónias": "campónio",
    "campónios": "campónio",
    "campões": "campão",
    "camufla": "camuflar",
    "camuflaa": "camuflao",
    "camuflaas": "camuflao",
    "camuflada": "camuflar",
    "camufladas": "camuflar",
    "camuflado": "camuflar",
    "camuflados": "camuflar",
    "camuflagens": "camuflagem",
    "camuflai": "camuflar",
    "camuflais": "camuflar",
    "camuflam": "camuflar",
    "camuflamo": "camuflar",
    "camuflamos": "camuflar",
    "camuflando": "camuflar",
    "camuflaos": "camuflao",
    "camuflara": "camuflar",
    "camuflaram": "camuflar",
    "camuflaras": "camuflar",
    "camuflarde": "camuflar",
    "camuflardes": "camuflar",
    "camuflare": "camuflar",
    "camuflarei": "camuflar",
    "camuflareis": "camuflar",
    "camuflarem": "camuflar",
    "camuflaremos": "camuflar",
    "camuflares": "camuflar",
    "camuflaria": "camuflar",
    "camuflariam": "camuflar",
    "camuflarias": "camuflar",
    "camuflarmo": "camuflar",
    "camuflarmos": "camuflar",
    "camuflará": "camuflar",
    "camuflarás": "camuflar",
    "camuflarão": "camuflar",
    "camuflaríamos": "camuflar",
    "camuflaríeis": "camuflar",
    "camuflas": "camuflar",
    "camuflasse": "camuflar",
    "camuflassem": "camuflar",
    "camuflasses": "camuflar",
    "camuflaste": "camuflar",
    "camuflastes": "camuflar",
    "camuflava": "camuflar",
    "camuflavam": "camuflar",
    "camuflavas": "camuflar",
    "camufle": "camuflar",
    "camuflei": "camuflar",
    "camufleis": "camuflar",
    "camuflem": "camuflar",
    "camuflemo": "camuflar",
    "camuflemos": "camuflar",
    "camufles": "camuflar",
    "camuflo": "camuflar",
    "camuflou": "camuflar",
    "camuflá": "camuflar",
    "camuflámo": "camuflar",
    "camuflámos": "camuflar",
    "camufláramo": "camuflar",
    "camufláramos": "camuflar",
    "camuflárei": "camuflar",
    "camufláreis": "camuflar",
    "camuflásseis": "camuflar",
    "camuflássemos": "camuflar",
    "camuflávamo": "camuflar",
    "camuflávamos": "camuflar",
    "camuflávei": "camuflar",
    "camufláveis": "camuflar",
    "camundongos": "camundongo",
    "camurce": "camurçar",
    "camurcei": "camurçar",
    "camurceis": "camurçar",
    "camurcem": "camurçar",
    "camurcemo": "camurçar",
    "camurcemos": "camurçar",
    "camurces": "camurçar",
    "camurcinas": "camurcina",
    "camurcites": "camurcite",
    "camurça": "camurçar",
    "camurçaa": "camurçao",
    "camurçaas": "camurçao",
    "camurçada": "camurçar",
    "camurçadas": "camurçar",
    "camurçado": "camurçar",
    "camurçados": "camurçar",
    "camurçagens": "camurçagem",
    "camurçai": "camurçar",
    "camurçais": "camurçar",
    "camurçam": "camurçar",
    "camurçamo": "camurçar",
    "camurçamos": "camurçar",
    "camurçando": "camurçar",
    "camurçaos": "camurçao",
    "camurçara": "camurçar",
    "camurçaram": "camurçar",
    "camurçaras": "camurçar",
    "camurçarde": "camurçar",
    "camurçardes": "camurçar",
    "camurçare": "camurçar",
    "camurçarei": "camurçar",
    "camurçareis": "camurçar",
    "camurçarem": "camurçar",
    "camurçaremos": "camurçar",
    "camurçares": "camurçar",
    "camurçaria": "camurçar",
    "camurçariam": "camurçar",
    "camurçarias": "camurçar",
    "camurçarmo": "camurçar",
    "camurçarmos": "camurçar",
    "camurçará": "camurçar",
    "camurçarás": "camurçar",
    "camurçarão": "camurçar",
    "camurçaríamos": "camurçar",
    "camurçaríeis": "camurçar",
    "camurças": "camurçar",
    "camurçasse": "camurçar",
    "camurçassem": "camurçar",
    "camurçasses": "camurçar",
    "camurçaste": "camurçar",
    "camurçastes": "camurçar",
    "camurçava": "camurçar",
    "camurçavam": "camurçar",
    "camurçavas": "camurçar",
    "camurço": "camurçar",
    "camurçou": "camurçar",
    "camurçá": "camurçar",
    "camurçámo": "camurçar",
    "camurçámos": "camurçar",
    "camurçáramo": "camurçar",
    "camurçáramos": "camurçar",
    "camurçárei": "camurçar",
    "camurçáreis": "camurçar",
    "camurçásseis": "camurçar",
    "camurçássemos": "camurçar",
    "camurçávamo": "camurçar",
    "camurçávamos": "camurçar",
    "camurçávei": "camurçar",
    "camurçáveis": "camurçar",
    "camáldulas": "camáldula",
    "camândulas": "camândula",
    "camélias": "camélia",
    "camélidas": "camélida",
    "camítica": "camítico",
    "camíticas": "camítico",
    "camíticos": "camítico",
    "camões": "camão",
    "cana": "cano",
    "canabinácea": "canabináceo",
    "canabináceas": "canabináceo",
    "canabináceos": "canabináceo",
    "canabráses": "canabrás",
    "canabuchos": "canabucho",
    "canabíneas": "canabínea",
    "canabínia": "canabínio",
    "canabínias": "canabínio",
    "canabínios": "canabínio",
    "canadas": "canada",
    "canadelas": "canadela",
    "canadenses": "canadense",
    "canadiana": "canadiano",
    "canadianas": "canadiano",
    "canadianos": "canadiano",
    "canados": "canado",
    "canafrechas": "canafrecha",
    "canafístulas": "canafístula",
    "canais": "canal",
    "canalhadas": "canalhada",
    "canalhas": "canalha",
    "canalhices": "canalhice",
    "canalhismos": "canalhismo",
    "canaliculaa": "canaliculao",
    "canaliculaas": "canaliculao",
    "canaliculaos": "canaliculao",
    "canaliculara": "canalicular",
    "canalicularas": "canalicular",
    "canaliculares": "canalicular",
    "canaliformes": "canaliforme",
    "canaliza": "canalizar",
    "canalizada": "canalizar",
    "canalizadas": "canalizar",
    "canalizado": "canalizar",
    "canalizadora": "canalizador",
    "canalizadoras": "canalizador",
    "canalizadores": "canalizador",
    "canalizados": "canalizar",
    "canalizai": "canalizar",
    "canalizais": "canalizar",
    "canalizam": "canalizar",
    "canalizamo": "canalizar",
    "canalizamos": "canalizar",
    "canalizando": "canalizar",
    "canalizara": "canalizar",
    "canalizaram": "canalizar",
    "canalizaras": "canalizar",
    "canalizarde": "canalizar",
    "canalizardes": "canalizar",
    "canalizare": "canalizar",
    "canalizarei": "canalizar",
    "canalizareis": "canalizar",
    "canalizarem": "canalizar",
    "canalizaremos": "canalizar",
    "canalizares": "canalizar",
    "canalizaria": "canalizar",
    "canalizariam": "canalizar",
    "canalizarias": "canalizar",
    "canalizarmo": "canalizar",
    "canalizarmos": "canalizar",
    "canalizará": "canalizar",
    "canalizarás": "canalizar",
    "canalizarão": "canalizar",
    "canalizaríamos": "canalizar",
    "canalizaríeis": "canalizar",
    "canalizas": "canalizar",
    "canalizasse": "canalizar",
    "canalizassem": "canalizar",
    "canalizasses": "canalizar",
    "canalizaste": "canalizar",
    "canalizastes": "canalizar",
    "canalizava": "canalizar",
    "canalizavam": "canalizar",
    "canalizavas": "canalizar",
    "canalizações": "canalização",
    "canalize": "canalizar",
    "canalizei": "canalizar",
    "canalizeis": "canalizar",
    "canalizem": "canalizar",
    "canalizemo": "canalizar",
    "canalizemos": "canalizar",
    "canalizes": "canalizar",
    "canalizo": "canalizar",
    "canalizou": "canalizar",
    "canalizá": "canalizar",
    "canalizámo": "canalizar",
    "canalizámos": "canalizar",
    "canalizáramo": "canalizar",
    "canalizáramos": "canalizar",
    "canalizárei": "canalizar",
    "canalizáreis": "canalizar",
    "canalizásseis": "canalizar",
    "canalizássemos": "canalizar",
    "canalizávamo": "canalizar",
    "canalizávamos": "canalizar",
    "canalizávei": "canalizar",
    "canalizáveis": "canalizável",
    "canalículos": "canalículo",
    "canalífera": "canalífero",
    "canalíferas": "canalífero",
    "canalíferos": "canalífero",
    "canamões": "canamão",
    "cananas": "canana",
    "cananeia": "cananeu",
    "cananeias": "cananeu",
    "cananeus": "cananeu",
    "canapés": "canapé",
    "canareiras": "canareira",
    "canarias": "canaria",
    "canariazinha": "canário",
    "canariazinhas": "canário",
    "canariazita": "canário",
    "canariazitas": "canário",
    "canarina": "canarino",
    "canarinas": "canarino",
    "canarinha": "canário",
    "canarinhas": "canário",
    "canarinho": "canário",
    "canarinhos": "canário",
    "canarinos": "canarino",
    "canarins": "canarim",
    "canariozinho": "canário",
    "canariozinhos": "canário",
    "canariozito": "canário",
    "canariozitos": "canário",
    "canarita": "canário",
    "canaritas": "canário",
    "canarito": "canário",
    "canaritos": "canário",
    "canas": "cano",
    "canastas": "canasta",
    "canastrada": "canastrado",
    "canastradas": "canastrado",
    "canastrados": "canastrado",
    "canastras": "canastra",
    "canastreiros": "canastreiro",
    "canastrona": "canastrão",
    "canastronas": "canastrão",
    "canastros": "canastro",
    "canastréis": "canastrel",
    "canastrões": "canastrão",
    "canaveiras": "canaveira",
    "canavesa": "canavês",
    "canavesas": "canavês",
    "canaveses": "canavês",
    "canaviais": "canavial",
    "canavieiras": "canavieira",
    "canavieiros": "canavieiro",
    "canavouras": "canavoura",
    "canavêsa": "canavês",
    "canavêsas": "canavês",
    "canavêses": "canavês",
    "canazes": "canaz",
    "cancaborradas": "cancaborrada",
    "cancana": "cancanar",
    "cancanada": "cancanar",
    "cancanadas": "cancanar",
    "cancanado": "cancanar",
    "cancanados": "cancanar",
    "cancanai": "cancanar",
    "cancanais": "cancanar",
    "cancanam": "cancanar",
    "cancanamo": "cancanar",
    "cancanamos": "cancanar",
    "cancanando": "cancanar",
    "cancanara": "cancanar",
    "cancanaram": "cancanar",
    "cancanaras": "cancanar",
    "cancanarde": "cancanar",
    "cancanardes": "cancanar",
    "cancanare": "cancanar",
    "cancanarei": "cancanar",
    "cancanareis": "cancanar",
    "cancanarem": "cancanar",
    "cancanaremos": "cancanar",
    "cancanares": "cancanar",
    "cancanaria": "cancanar",
    "cancanariam": "cancanar",
    "cancanarias": "cancanar",
    "cancanarmo": "cancanar",
    "cancanarmos": "cancanar",
    "cancanará": "cancanar",
    "cancanarás": "cancanar",
    "cancanarão": "cancanar",
    "cancanaríamos": "cancanar",
    "cancanaríeis": "cancanar",
    "cancanas": "cancanar",
    "cancanasse": "cancanar",
    "cancanassem": "cancanar",
    "cancanasses": "cancanar",
    "cancanaste": "cancanar",
    "cancanastes": "cancanar",
    "cancanava": "cancanar",
    "cancanavam": "cancanar",
    "cancanavas": "cancanar",
    "cancane": "cancanar",
    "cancanei": "cancanar",
    "cancaneis": "cancanar",
    "cancanem": "cancanar",
    "cancanemo": "cancanar",
    "cancanemos": "cancanar",
    "cancanes": "cancanar",
    "cancanistas": "cancanista",
    "cancano": "cancanar",
    "cancanou": "cancanar",
    "cancaná": "cancanar",
    "cancanámo": "cancanar",
    "cancanámos": "cancanar",
    "cancanáramo": "cancanar",
    "cancanáramos": "cancanar",
    "cancanárei": "cancanar",
    "cancanáreis": "cancanar",
    "cancanásseis": "cancanar",
    "cancanássemos": "cancanar",
    "cancanávamo": "cancanar",
    "cancanávamos": "cancanar",
    "cancanávei": "cancanar",
    "cancanáveis": "cancanar",
    "cancela": "cancelar",
    "cancelada": "cancelar",
    "canceladas": "cancelar",
    "cancelado": "cancelar",
    "cancelados": "cancelar",
    "canceladuras": "canceladura",
    "cancelai": "cancelar",
    "cancelais": "cancelar",
    "cancelam": "cancelar",
    "cancelamentos": "cancelamento",
    "cancelamo": "cancelar",
    "cancelamos": "cancelar",
    "cancelando": "cancelar",
    "cancelara": "cancelar",
    "cancelaram": "cancelar",
    "cancelaras": "cancelar",
    "cancelarde": "cancelar",
    "cancelardes": "cancelar",
    "cancelare": "cancelar",
    "cancelarei": "cancelar",
    "cancelareis": "cancelar",
    "cancelarem": "cancelar",
    "cancelaremos": "cancelar",
    "cancelares": "cancelar",
    "cancelaria": "cancelar",
    "cancelariam": "cancelar",
    "cancelarias": "cancelar",
    "cancelarmo": "cancelar",
    "cancelarmos": "cancelar",
    "cancelará": "cancelar",
    "cancelarás": "cancelar",
    "cancelarão": "cancelar",
    "cancelaríamos": "cancelar",
    "cancelaríeis": "cancelar",
    "cancelas": "cancelar",
    "cancelasse": "cancelar",
    "cancelassem": "cancelar",
    "cancelasses": "cancelar",
    "cancelaste": "cancelar",
    "cancelastes": "cancelar",
    "cancelava": "cancelar",
    "cancelavam": "cancelar",
    "cancelavas": "cancelar",
    "cancele": "cancelar",
    "cancelei": "cancelar",
    "canceleis": "cancelar",
    "cancelem": "cancelar",
    "cancelemo": "cancelar",
    "cancelemos": "cancelar",
    "canceles": "cancelar",
    "cancelo": "cancelar",
    "cancelos": "cancelo",
    "cancelou": "cancelar",
    "cancelá": "cancelar",
    "cancelámo": "cancelar",
    "cancelámos": "cancelar",
    "canceláramo": "cancelar",
    "canceláramos": "cancelar",
    "cancelárei": "cancelar",
    "canceláreis": "cancelar",
    "cancelários": "cancelário",
    "cancelásseis": "cancelar",
    "cancelássemos": "cancelar",
    "cancelávamo": "cancelar",
    "cancelávamos": "cancelar",
    "cancelávei": "cancelar",
    "canceláveis": "cancelável",
    "cancera": "cancerar",
    "cancerada": "cancerar",
    "canceradas": "cancerar",
    "cancerado": "cancerar",
    "cancerados": "cancerar",
    "cancerai": "cancerar",
    "cancerais": "cancerar",
    "canceram": "cancerar",
    "canceramo": "cancerar",
    "canceramos": "cancerar",
    "cancerando": "cancerar",
    "cancerara": "cancerar",
    "canceraram": "cancerar",
    "canceraras": "cancerar",
    "cancerardes": "cancerar",
    "cancerarei": "cancerar",
    "cancerareis": "cancerar",
    "cancerarem": "cancerar",
    "canceraremos": "cancerar",
    "cancerares": "cancerar",
    "canceraria": "cancerar",
    "cancerariam": "cancerar",
    "cancerarias": "cancerar",
    "cancerarmo": "cancerar",
    "cancerarmos": "cancerar",
    "cancerará": "cancerar",
    "cancerarás": "cancerar",
    "cancerarão": "cancerar",
    "canceraríamos": "cancerar",
    "canceraríeis": "cancerar",
    "canceras": "cancerar",
    "cancerasse": "cancerar",
    "cancerassem": "cancerar",
    "cancerasses": "cancerar",
    "canceraste": "cancerar",
    "cancerastes": "cancerar",
    "cancerava": "cancerar",
    "canceravam": "cancerar",
    "canceravas": "cancerar",
    "cancerações": "canceração",
    "cancere": "cancerar",
    "cancerei": "cancerar",
    "cancereis": "cancerar",
    "cancerem": "cancerar",
    "canceremo": "cancerar",
    "canceremos": "cancerar",
    "canceres": "cancerar",
    "canceriformes": "canceriforme",
    "canceriza": "cancerizar",
    "cancerizada": "cancerizar",
    "cancerizadas": "cancerizar",
    "cancerizado": "cancerizar",
    "cancerizados": "cancerizar",
    "cancerizai": "cancerizar",
    "cancerizais": "cancerizar",
    "cancerizam": "cancerizar",
    "cancerizamo": "cancerizar",
    "cancerizamos": "cancerizar",
    "cancerizando": "cancerizar",
    "cancerizara": "cancerizar",
    "cancerizaram": "cancerizar",
    "cancerizaras": "cancerizar",
    "cancerizardes": "cancerizar",
    "cancerizarei": "cancerizar",
    "cancerizareis": "cancerizar",
    "cancerizarem": "cancerizar",
    "cancerizaremos": "cancerizar",
    "cancerizares": "cancerizar",
    "cancerizaria": "cancerizar",
    "cancerizariam": "cancerizar",
    "cancerizarias": "cancerizar",
    "cancerizarmo": "cancerizar",
    "cancerizarmos": "cancerizar",
    "cancerizará": "cancerizar",
    "cancerizarás": "cancerizar",
    "cancerizarão": "cancerizar",
    "cancerizaríamos": "cancerizar",
    "cancerizaríeis": "cancerizar",
    "cancerizas": "cancerizar",
    "cancerizasse": "cancerizar",
    "cancerizassem": "cancerizar",
    "cancerizasses": "cancerizar",
    "cancerizaste": "cancerizar",
    "cancerizastes": "cancerizar",
    "cancerizava": "cancerizar",
    "cancerizavam": "cancerizar",
    "cancerizavas": "cancerizar",
    "cancerizações": "cancerização",
    "cancerize": "cancerizar",
    "cancerizei": "cancerizar",
    "cancerizeis": "cancerizar",
    "cancerizem": "cancerizar",
    "cancerizemo": "cancerizar",
    "cancerizemos": "cancerizar",
    "cancerizes": "cancerizar",
    "cancerizo": "cancerizar",
    "cancerizou": "cancerizar",
    "cancerizámo": "cancerizar",
    "cancerizámos": "cancerizar",
    "cancerizáramo": "cancerizar",
    "cancerizáramos": "cancerizar",
    "cancerizáreis": "cancerizar",
    "cancerizásseis": "cancerizar",
    "cancerizássemos": "cancerizar",
    "cancerizávamo": "cancerizar",
    "cancerizávamos": "cancerizar",
    "cancerizáveis": "cancerizar",
    "cancero": "cancerar",
    "cancerosa": "canceroso",
    "cancerosas": "canceroso",
    "cancerosos": "canceroso",
    "cancerou": "cancerar",
    "cancerámo": "cancerar",
    "cancerámos": "cancerar",
    "canceráramo": "cancerar",
    "canceráramos": "cancerar",
    "canceráreis": "cancerar",
    "cancerásseis": "cancerar",
    "cancerássemos": "cancerar",
    "cancerávamo": "cancerar",
    "cancerávamos": "cancerar",
    "canceráveis": "cancerar",
    "cancerígena": "cancerígeno",
    "cancerígenas": "cancerígeno",
    "cancerígenos": "cancerígeno",
    "canchas": "cancha",
    "cancheada": "canchear",
    "cancheadas": "canchear",
    "cancheado": "canchear",
    "cancheados": "canchear",
    "cancheai": "canchear",
    "cancheais": "canchear",
    "cancheamo": "canchear",
    "cancheamos": "canchear",
    "cancheando": "canchear",
    "cancheara": "canchear",
    "canchearam": "canchear",
    "canchearas": "canchear",
    "canchearde": "canchear",
    "cancheardes": "canchear",
    "cancheare": "canchear",
    "canchearei": "canchear",
    "cancheareis": "canchear",
    "canchearem": "canchear",
    "canchearemos": "canchear",
    "cancheares": "canchear",
    "canchearia": "canchear",
    "cancheariam": "canchear",
    "canchearias": "canchear",
    "canchearmo": "canchear",
    "canchearmos": "canchear",
    "cancheará": "canchear",
    "canchearás": "canchear",
    "canchearão": "canchear",
    "canchearíamos": "canchear",
    "canchearíeis": "canchear",
    "cancheasse": "canchear",
    "cancheassem": "canchear",
    "cancheasses": "canchear",
    "cancheaste": "canchear",
    "cancheastes": "canchear",
    "cancheava": "canchear",
    "cancheavam": "canchear",
    "cancheavas": "canchear",
    "cancheei": "canchear",
    "cancheeis": "canchear",
    "cancheemo": "canchear",
    "cancheemos": "canchear",
    "cancheia": "canchear",
    "cancheiam": "canchear",
    "cancheias": "canchear",
    "cancheie": "canchear",
    "cancheiem": "canchear",
    "cancheies": "canchear",
    "cancheio": "canchear",
    "cancheou": "canchear",
    "cancheá": "canchear",
    "cancheámo": "canchear",
    "cancheámos": "canchear",
    "cancheáramo": "canchear",
    "cancheáramos": "canchear",
    "cancheárei": "canchear",
    "cancheáreis": "canchear",
    "cancheásseis": "canchear",
    "cancheássemos": "canchear",
    "cancheávamo": "canchear",
    "cancheávamos": "canchear",
    "cancheávei": "canchear",
    "cancheáveis": "canchear",
    "cancioneiros": "cancioneiro",
    "cancionistas": "cancionista",
    "cancriformes": "cancriforme",
    "cancrinites": "cancrinite",
    "cancros": "cancro",
    "cancróides": "cancróide",
    "cancãs": "cancã",
    "candados": "candado",
    "candanga": "candango",
    "candangas": "candango",
    "candangos": "candango",
    "candeada": "candear",
    "candeadas": "candear",
    "candeado": "candear",
    "candeados": "candear",
    "candeai": "candear",
    "candeais": "candear",
    "candeamo": "candear",
    "candeamos": "candear",
    "candeando": "candear",
    "candeara": "candear",
    "candearam": "candear",
    "candearas": "candear",
    "candearde": "candear",
    "candeardes": "candear",
    "candeare": "candear",
    "candearei": "candear",
    "candeareis": "candear",
    "candearem": "candear",
    "candearemos": "candear",
    "candeares": "candear",
    "candearia": "candear",
    "candeariam": "candear",
    "candearias": "candearia",
    "candearmo": "candear",
    "candearmos": "candear",
    "candeará": "candear",
    "candearás": "candear",
    "candearão": "candear",
    "candearíamos": "candear",
    "candearíeis": "candear",
    "candeasse": "candear",
    "candeassem": "candear",
    "candeasses": "candear",
    "candeaste": "candear",
    "candeastes": "candear",
    "candeava": "candear",
    "candeavam": "candear",
    "candeavas": "candear",
    "candeei": "candear",
    "candeeiradas": "candeeirada",
    "candeeiros": "candeeiro",
    "candeeis": "candear",
    "candeemo": "candear",
    "candeemos": "candear",
    "candeia": "candear",
    "candeiam": "candear",
    "candeias": "candeia",
    "candeie": "candear",
    "candeiem": "candear",
    "candeies": "candear",
    "candeio": "candear",
    "candeios": "candeio",
    "candelabros": "candelabro",
    "candelas": "candela",
    "candelinhas": "candelinha",
    "candeliças": "candeliça",
    "candelábrica": "candelábrico",
    "candelábricas": "candelábrico",
    "candelábricos": "candelábrico",
    "candelárias": "candelária",
    "candentes": "candente",
    "candeou": "candear",
    "candeá": "candear",
    "candeámo": "candear",
    "candeámos": "candear",
    "candeáramo": "candear",
    "candeáramos": "candear",
    "candeárei": "candear",
    "candeáreis": "candear",
    "candeásseis": "candear",
    "candeássemos": "candear",
    "candeávamo": "candear",
    "candeávamos": "candear",
    "candeávei": "candear",
    "candeáveis": "candear",
    "candiais": "candial",
    "candidas": "candida",
    "candidata": "candidato",
    "candidatada": "candidatar",
    "candidatadas": "candidatar",
    "candidatado": "candidatar",
    "candidatados": "candidatar",
    "candidatai": "candidatar",
    "candidatais": "candidatar",
    "candidatam": "candidatar",
    "candidatamo": "candidatar",
    "candidatamos": "candidatar",
    "candidatando": "candidatar",
    "candidatara": "candidatar",
    "candidataram": "candidatar",
    "candidataras": "candidatar",
    "candidatardes": "candidatar",
    "candidatarei": "candidatar",
    "candidatareis": "candidatar",
    "candidatarem": "candidatar",
    "candidataremos": "candidatar",
    "candidatares": "candidatar",
    "candidataria": "candidatar",
    "candidatariam": "candidatar",
    "candidatarias": "candidatar",
    "candidatarmo": "candidatar",
    "candidatarmos": "candidatar",
    "candidatará": "candidatar",
    "candidatarás": "candidatar",
    "candidatarão": "candidatar",
    "candidataríamos": "candidatar",
    "candidataríeis": "candidatar",
    "candidatas": "candidato",
    "candidatasse": "candidatar",
    "candidatassem": "candidatar",
    "candidatasses": "candidatar",
    "candidataste": "candidatar",
    "candidatastes": "candidatar",
    "candidatava": "candidatar",
    "candidatavam": "candidatar",
    "candidatavas": "candidatar",
    "candidate": "candidatar",
    "candidatei": "candidatar",
    "candidateis": "candidatar",
    "candidatem": "candidatar",
    "candidatemo": "candidatar",
    "candidatemos": "candidatar",
    "candidates": "candidatar",
    "candidato": "candidatar",
    "candidatos": "candidato",
    "candidatou": "candidatar",
    "candidaturas": "candidatura",
    "candidatámo": "candidatar",
    "candidatámos": "candidatar",
    "candidatáramo": "candidatar",
    "candidatáramos": "candidatar",
    "candidatáreis": "candidatar",
    "candidatásseis": "candidatar",
    "candidatássemos": "candidatar",
    "candidatávamo": "candidatar",
    "candidatávamos": "candidatar",
    "candidatáveis": "candidatar",
    "candila": "candilar",
    "candilada": "candilar",
    "candiladas": "candilar",
    "candilado": "candilar",
    "candilados": "candilar",
    "candilai": "candilar",
    "candilais": "candilar",
    "candilam": "candilar",
    "candilamo": "candilar",
    "candilamos": "candilar",
    "candilando": "candilar",
    "candilara": "candilar",
    "candilaram": "candilar",
    "candilaras": "candilar",
    "candilarde": "candilar",
    "candilardes": "candilar",
    "candilare": "candilar",
    "candilarei": "candilar",
    "candilareis": "candilar",
    "candilarem": "candilar",
    "candilaremos": "candilar",
    "candilares": "candilar",
    "candilaria": "candilar",
    "candilariam": "candilar",
    "candilarias": "candilar",
    "candilarmo": "candilar",
    "candilarmos": "candilar",
    "candilará": "candilar",
    "candilarás": "candilar",
    "candilarão": "candilar",
    "candilaríamos": "candilar",
    "candilaríeis": "candilar",
    "candilas": "candilar",
    "candilasse": "candilar",
    "candilassem": "candilar",
    "candilasses": "candilar",
    "candilaste": "candilar",
    "candilastes": "candilar",
    "candilava": "candilar",
    "candilavam": "candilar",
    "candilavas": "candilar",
    "candile": "candilar",
    "candilei": "candilar",
    "candileis": "candilar",
    "candilem": "candilar",
    "candilemo": "candilar",
    "candilemos": "candilar",
    "candiles": "candilar",
    "candilo": "candilar",
    "candilou": "candilar",
    "candilá": "candilar",
    "candilámo": "candilar",
    "candilámos": "candilar",
    "candiláramo": "candilar",
    "candiláramos": "candilar",
    "candilárei": "candilar",
    "candiláreis": "candilar",
    "candilásseis": "candilar",
    "candilássemos": "candilar",
    "candilávamo": "candilar",
    "candilávamos": "candilar",
    "candilávei": "candilar",
    "candiláveis": "candilar",
    "candis": "candil",
    "candombes": "candombe",
    "candomblés": "candomblé",
    "candonga": "candongar",
    "candongada": "candongar",
    "candongadas": "candongar",
    "candongado": "candongar",
    "candongados": "candongar",
    "candongagens": "candongagem",
    "candongai": "candongar",
    "candongais": "candongar",
    "candongam": "candongar",
    "candongamo": "candongar",
    "candongamos": "candongar",
    "candongando": "candongar",
    "candongara": "candongar",
    "candongaram": "candongar",
    "candongaras": "candongar",
    "candongardes": "candongar",
    "candongarei": "candongar",
    "candongareis": "candongar",
    "candongarem": "candongar",
    "candongaremos": "candongar",
    "candongares": "candongar",
    "candongaria": "candongar",
    "candongariam": "candongar",
    "candongarias": "candongar",
    "candongarmo": "candongar",
    "candongarmos": "candongar",
    "candongará": "candongar",
    "candongarás": "candongar",
    "candongarão": "candongar",
    "candongaríamos": "candongar",
    "candongaríeis": "candongar",
    "candongas": "candongar",
    "candongasse": "candongar",
    "candongassem": "candongar",
    "candongasses": "candongar",
    "candongaste": "candongar",
    "candongastes": "candongar",
    "candongava": "candongar",
    "candongavam": "candongar",
    "candongavas": "candongar",
    "candongo": "candongar",
    "candongou": "candongar",
    "candongue": "candongar",
    "candonguei": "candongar",
    "candongueira": "candongueiro",
    "candongueiras": "candongueiro",
    "candongueiros": "candongueiro",
    "candongueis": "candongar",
    "candonguem": "candongar",
    "candonguemo": "candongar",
    "candonguemos": "candongar",
    "candongues": "candongar",
    "candonguices": "candonguice",
    "candongámo": "candongar",
    "candongámos": "candongar",
    "candongáramo": "candongar",
    "candongáramos": "candongar",
    "candongáreis": "candongar",
    "candongásseis": "candongar",
    "candongássemos": "candongar",
    "candongávamo": "candongar",
    "candongávamos": "candongar",
    "candongáveis": "candongar",
    "candores": "candor",
    "candorças": "candorça",
    "candos": "cando",
    "canduras": "candura",
    "candências": "candência",
    "canecadas": "canecada",
    "canecas": "caneca",
    "canecos": "caneco",
    "canefórias": "canefória",
    "caneiras": "caneira",
    "caneiros": "caneiro",
    "caneja": "canejo",
    "canejas": "canejo",
    "canejos": "canejo",
    "canela": "canelar",
    "canelada": "canelar",
    "caneladas": "canelar",
    "canelado": "canelar",
    "canelados": "canelar",
    "caneladuras": "caneladura",
    "canelagens": "canelagem",
    "canelai": "canelar",
    "canelais": "canelar",
    "canelam": "canelar",
    "canelamo": "canelar",
    "canelamos": "canelar",
    "canelando": "canelar",
    "canelara": "canelar",
    "canelaram": "canelar",
    "canelaras": "canelar",
    "canelarde": "canelar",
    "canelardes": "canelar",
    "canelare": "canelar",
    "canelarei": "canelar",
    "canelareis": "canelar",
    "canelarem": "canelar",
    "canelaremos": "canelar",
    "canelares": "canelar",
    "canelaria": "canelar",
    "canelariam": "canelar",
    "canelarias": "canelar",
    "canelarmo": "canelar",
    "canelarmos": "canelar",
    "canelará": "canelar",
    "canelarás": "canelar",
    "canelarão": "canelar",
    "canelaríamos": "canelar",
    "canelaríeis": "canelar",
    "canelas": "canelar",
    "canelasse": "canelar",
    "canelassem": "canelar",
    "canelasses": "canelar",
    "canelaste": "canelar",
    "canelastes": "canelar",
    "canelava": "canelar",
    "canelavam": "canelar",
    "canelavas": "canelar",
    "canele": "canelar",
    "canelei": "canelar",
    "caneleira": "caneleiro",
    "caneleiras": "caneleiro",
    "caneleiros": "caneleiro",
    "caneleis": "canelar",
    "canelem": "canelar",
    "canelemo": "canelar",
    "canelemos": "canelar",
    "caneles": "canelar",
    "canelhas": "canelha",
    "canelinas": "canelina",
    "canelins": "canelim",
    "canelo": "canelar",
    "canelos": "canelo",
    "canelou": "canelar",
    "caneluras": "canelura",
    "canelá": "canelar",
    "caneláceas": "canelácea",
    "canelámo": "canelar",
    "canelámos": "canelar",
    "caneláramo": "canelar",
    "caneláramos": "canelar",
    "canelárei": "canelar",
    "caneláreis": "canelar",
    "canelásseis": "canelar",
    "canelássemos": "canelar",
    "canelávamo": "canelar",
    "canelávamos": "canelar",
    "canelávei": "canelar",
    "caneláveis": "canelar",
    "canelões": "canelão",
    "canequinha": "caneca",
    "canequinhas": "caneca",
    "canequita": "caneca",
    "canequitas": "caneca",
    "canetas": "caneta",
    "canetinha": "caneta",
    "canetinhas": "caneta",
    "canetita": "caneta",
    "canetitas": "caneta",
    "canetões": "canetão",
    "canevões": "canevão",
    "canfanos": "canfano",
    "canfenos": "canfeno",
    "canfora": "canforar",
    "canforada": "canforar",
    "canforadas": "canforar",
    "canforado": "canforar",
    "canforados": "canforar",
    "canforai": "canforar",
    "canforais": "canforar",
    "canforam": "canforar",
    "canforamo": "canforar",
    "canforamos": "canforar",
    "canforando": "canforar",
    "canforara": "canforar",
    "canforaram": "canforar",
    "canforaras": "canforar",
    "canforarde": "canforar",
    "canforardes": "canforar",
    "canforare": "canforar",
    "canforarei": "canforar",
    "canforareis": "canforar",
    "canforarem": "canforar",
    "canforaremos": "canforar",
    "canforares": "canforar",
    "canforaria": "canforar",
    "canforariam": "canforar",
    "canforarias": "canforar",
    "canforarmo": "canforar",
    "canforarmos": "canforar",
    "canforará": "canforar",
    "canforarás": "canforar",
    "canforarão": "canforar",
    "canforaríamos": "canforar",
    "canforaríeis": "canforar",
    "canforas": "canforar",
    "canforasse": "canforar",
    "canforassem": "canforar",
    "canforasses": "canforar",
    "canforaste": "canforar",
    "canforastes": "canforar",
    "canforava": "canforar",
    "canforavam": "canforar",
    "canforavas": "canforar",
    "canfore": "canforar",
    "canforei": "canforar",
    "canforeiras": "canforeira",
    "canforeiros": "canforeiro",
    "canforeis": "canforar",
    "canforem": "canforar",
    "canforemo": "canforar",
    "canforemos": "canforar",
    "canfores": "canforar",
    "canforo": "canforar",
    "canforomanias": "canforomania",
    "canforomaníaca": "canforomaníaco",
    "canforomaníacas": "canforomaníaco",
    "canforomaníacos": "canforomaníaco",
    "canforou": "canforar",
    "canforá": "canforar",
    "canforámo": "canforar",
    "canforámos": "canforar",
    "canforáramo": "canforar",
    "canforáramos": "canforar",
    "canforárei": "canforar",
    "canforáreis": "canforar",
    "canforásseis": "canforar",
    "canforássemos": "canforar",
    "canforávamo": "canforar",
    "canforávamos": "canforar",
    "canforávei": "canforar",
    "canforáveis": "canforar",
    "canforífera": "canforífero",
    "canforíferas": "canforífero",
    "canforíferos": "canforífero",
    "canforóides": "canforóide",
    "canga": "cangar",
    "cangaceira": "cangaceiro",
    "cangaceiras": "cangaceiro",
    "cangaceiros": "cangaceiro",
    "cangada": "cangar",
    "cangadas": "cangar",
    "cangado": "cangar",
    "cangados": "cangar",
    "cangai": "cangar",
    "cangais": "cangar",
    "cangalhadas": "cangalhada",
    "cangalhas": "cangalha",
    "cangalheira": "cangalheiro",
    "cangalheiras": "cangalheiro",
    "cangalheiros": "cangalheiro",
    "cangalhos": "cangalho",
    "cangam": "cangar",
    "cangamo": "cangar",
    "cangamos": "cangar",
    "cangando": "cangar",
    "canganhos": "canganho",
    "cangara": "cangar",
    "cangaram": "cangar",
    "cangaras": "cangar",
    "cangarde": "cangar",
    "cangardes": "cangar",
    "cangare": "cangar",
    "cangarei": "cangar",
    "cangareis": "cangar",
    "cangarem": "cangar",
    "cangaremos": "cangar",
    "cangares": "cangar",
    "cangaria": "cangar",
    "cangariam": "cangar",
    "cangarias": "cangar",
    "cangarilhadas": "cangarilhada",
    "cangarinhas": "cangarinha",
    "cangarmo": "cangar",
    "cangarmos": "cangar",
    "cangará": "cangar",
    "cangarás": "cangar",
    "cangarão": "cangar",
    "cangaríamos": "cangar",
    "cangaríeis": "cangar",
    "cangas": "cangar",
    "cangasse": "cangar",
    "cangassem": "cangar",
    "cangasses": "cangar",
    "cangaste": "cangar",
    "cangastes": "cangar",
    "cangava": "cangar",
    "cangavam": "cangar",
    "cangavas": "cangar",
    "cangaços": "cangaço",
    "cango": "cangar",
    "cangos": "cango",
    "cangostas": "cangosta",
    "cangotes": "cangote",
    "cangou": "cangar",
    "cangue": "cangar",
    "canguei": "cangar",
    "cangueira": "cangueiro",
    "cangueiras": "cangueiro",
    "cangueiros": "cangueiro",
    "cangueis": "cangar",
    "canguem": "cangar",
    "canguemo": "cangar",
    "canguemos": "cangar",
    "cangues": "cangar",
    "canguinha": "canguinhar",
    "canguinhada": "canguinhar",
    "canguinhadas": "canguinhar",
    "canguinhado": "canguinhar",
    "canguinhados": "canguinhar",
    "canguinhai": "canguinhar",
    "canguinhais": "canguinhar",
    "canguinham": "canguinhar",
    "canguinhamo": "canguinhar",
    "canguinhamos": "canguinhar",
    "canguinhando": "canguinhar",
    "canguinhara": "canguinhar",
    "canguinharam": "canguinhar",
    "canguinharas": "canguinhar",
    "canguinhardes": "canguinhar",
    "canguinharei": "canguinhar",
    "canguinhareis": "canguinhar",
    "canguinharem": "canguinhar",
    "canguinharemos": "canguinhar",
    "canguinhares": "canguinhar",
    "canguinharia": "canguinhar",
    "canguinhariam": "canguinhar",
    "canguinharias": "canguinhar",
    "canguinharmo": "canguinhar",
    "canguinharmos": "canguinhar",
    "canguinhará": "canguinhar",
    "canguinharás": "canguinhar",
    "canguinharão": "canguinhar",
    "canguinharíamos": "canguinhar",
    "canguinharíeis": "canguinhar",
    "canguinhas": "canguinhar",
    "canguinhasse": "canguinhar",
    "canguinhassem": "canguinhar",
    "canguinhasses": "canguinhar",
    "canguinhaste": "canguinhar",
    "canguinhastes": "canguinhar",
    "canguinhava": "canguinhar",
    "canguinhavam": "canguinhar",
    "canguinhavas": "canguinhar",
    "canguinhe": "canguinhar",
    "canguinhei": "canguinhar",
    "canguinheis": "canguinhar",
    "canguinhem": "canguinhar",
    "canguinhemo": "canguinhar",
    "canguinhemos": "canguinhar",
    "canguinhes": "canguinhar",
    "canguinho": "canguinhar",
    "canguinhou": "canguinhar",
    "canguinhámo": "canguinhar",
    "canguinhámos": "canguinhar",
    "canguinháramo": "canguinhar",
    "canguinháramos": "canguinhar",
    "canguinháreis": "canguinhar",
    "canguinhásseis": "canguinhar",
    "canguinhássemos": "canguinhar",
    "canguinhávamo": "canguinhar",
    "canguinhávamos": "canguinhar",
    "canguinháveis": "canguinhar",
    "cangulos": "cangulo",
    "cangurus": "canguru",
    "canguçus": "canguçu",
    "cangá": "cangar",
    "cangámo": "cangar",
    "cangámos": "cangar",
    "cangáramo": "cangar",
    "cangáramos": "cangar",
    "cangárei": "cangar",
    "cangáreis": "cangar",
    "cangásseis": "cangar",
    "cangássemos": "cangar",
    "cangávamo": "cangar",
    "cangávamos": "cangar",
    "cangávei": "cangar",
    "cangáveis": "cangar",
    "canha": "canho",
    "canhada": "canhar",
    "canhadas": "canhar",
    "canhado": "canhar",
    "canhados": "canhar",
    "canhai": "canhar",
    "canhais": "canhar",
    "canham": "canhar",
    "canhamaços": "canhamaço",
    "canhameirais": "canhameiral",
    "canhameiras": "canhameira",
    "canhamiça": "canhamiço",
    "canhamiças": "canhamiço",
    "canhamiços": "canhamiço",
    "canhamo": "canhar",
    "canhamos": "canhar",
    "canhando": "canhar",
    "canhanhos": "canhanho",
    "canhara": "canhar",
    "canharam": "canhar",
    "canharas": "canhar",
    "canhardes": "canhar",
    "canharei": "canhar",
    "canhareis": "canhar",
    "canharem": "canhar",
    "canharemos": "canhar",
    "canhares": "canhar",
    "canharia": "canhar",
    "canhariam": "canhar",
    "canharias": "canhar",
    "canharmo": "canhar",
    "canharmos": "canhar",
    "canhará": "canhar",
    "canharás": "canhar",
    "canharão": "canhar",
    "canharíamos": "canhar",
    "canharíeis": "canhar",
    "canhas": "canho",
    "canhasse": "canhar",
    "canhassem": "canhar",
    "canhasses": "canhar",
    "canhaste": "canhar",
    "canhastes": "canhar",
    "canhava": "canhar",
    "canhavam": "canhar",
    "canhavas": "canhar",
    "canhe": "canhar",
    "canhei": "canhar",
    "canheiros": "canheiro",
    "canheis": "canhar",
    "canhem": "canhar",
    "canhemo": "canhar",
    "canhemos": "canhar",
    "canhenha": "canhenho",
    "canhenhas": "canhenho",
    "canhenhos": "canhenho",
    "canhes": "canhar",
    "canhestra": "canhestro",
    "canhestras": "canhestro",
    "canhestros": "canhestro",
    "canho": "canhar",
    "canhoeiras": "canhoeira",
    "canhoeiros": "canhoeiro",
    "canholas": "canhola",
    "canhona": "canhonar",
    "canhonada": "canhonar",
    "canhonadas": "canhonar",
    "canhonado": "canhonar",
    "canhonados": "canhonar",
    "canhonai": "canhonar",
    "canhonais": "canhonar",
    "canhonam": "canhonar",
    "canhonamo": "canhonar",
    "canhonamos": "canhonar",
    "canhonando": "canhonar",
    "canhonara": "canhonar",
    "canhonaram": "canhonar",
    "canhonaras": "canhonar",
    "canhonarde": "canhonar",
    "canhonardes": "canhonar",
    "canhonare": "canhonar",
    "canhonarei": "canhonar",
    "canhonareis": "canhonar",
    "canhonarem": "canhonar",
    "canhonaremos": "canhonar",
    "canhonares": "canhonar",
    "canhonaria": "canhonar",
    "canhonariam": "canhonar",
    "canhonarias": "canhonar",
    "canhonarmo": "canhonar",
    "canhonarmos": "canhonar",
    "canhonará": "canhonar",
    "canhonarás": "canhonar",
    "canhonarão": "canhonar",
    "canhonaríamos": "canhonar",
    "canhonaríeis": "canhonar",
    "canhonas": "canhonar",
    "canhonasse": "canhonar",
    "canhonassem": "canhonar",
    "canhonasses": "canhonar",
    "canhonaste": "canhonar",
    "canhonastes": "canhonar",
    "canhonava": "canhonar",
    "canhonavam": "canhonar",
    "canhonavas": "canhonar",
    "canhonaços": "canhonaço",
    "canhone": "canhonar",
    "canhoneada": "canhonear",
    "canhoneadas": "canhonear",
    "canhoneado": "canhonear",
    "canhoneados": "canhonear",
    "canhoneai": "canhonear",
    "canhoneais": "canhonear",
    "canhoneamo": "canhonear",
    "canhoneamos": "canhonear",
    "canhoneando": "canhonear",
    "canhoneara": "canhonear",
    "canhonearam": "canhonear",
    "canhonearas": "canhonear",
    "canhonearde": "canhonear",
    "canhoneardes": "canhonear",
    "canhoneare": "canhonear",
    "canhonearei": "canhonear",
    "canhoneareis": "canhonear",
    "canhonearem": "canhonear",
    "canhonearemos": "canhonear",
    "canhoneares": "canhonear",
    "canhonearia": "canhonear",
    "canhoneariam": "canhonear",
    "canhonearias": "canhonear",
    "canhonearmo": "canhonear",
    "canhonearmos": "canhonear",
    "canhoneará": "canhonear",
    "canhonearás": "canhonear",
    "canhonearão": "canhonear",
    "canhonearíamos": "canhonear",
    "canhonearíeis": "canhonear",
    "canhoneasse": "canhonear",
    "canhoneassem": "canhonear",
    "canhoneasses": "canhonear",
    "canhoneaste": "canhonear",
    "canhoneastes": "canhonear",
    "canhoneava": "canhonear",
    "canhoneavam": "canhonear",
    "canhoneavas": "canhonear",
    "canhoneei": "canhonear",
    "canhoneeis": "canhonear",
    "canhoneemo": "canhonear",
    "canhoneemos": "canhonear",
    "canhonei": "canhonar",
    "canhoneia": "canhonear",
    "canhoneiam": "canhonear",
    "canhoneias": "canhonear",
    "canhoneie": "canhonear",
    "canhoneiem": "canhonear",
    "canhoneies": "canhonear",
    "canhoneio": "canhonear",
    "canhoneios": "canhoneio",
    "canhoneira": "canhoneiro",
    "canhoneiras": "canhoneiro",
    "canhoneiros": "canhoneiro",
    "canhoneis": "canhonar",
    "canhonem": "canhonar",
    "canhonemo": "canhonar",
    "canhonemos": "canhonar",
    "canhoneou": "canhonear",
    "canhones": "canhonar",
    "canhoneá": "canhonear",
    "canhoneámo": "canhonear",
    "canhoneámos": "canhonear",
    "canhoneáramo": "canhonear",
    "canhoneáramos": "canhonear",
    "canhoneárei": "canhonear",
    "canhoneáreis": "canhonear",
    "canhoneásseis": "canhonear",
    "canhoneássemos": "canhonear",
    "canhoneávamo": "canhonear",
    "canhoneávamos": "canhonear",
    "canhoneávei": "canhonear",
    "canhoneáveis": "canhonear",
    "canhono": "canhonar",
    "canhonou": "canhonar",
    "canhoná": "canhonar",
    "canhonámo": "canhonar",
    "canhonámos": "canhonar",
    "canhonáramo": "canhonar",
    "canhonáramos": "canhonar",
    "canhonárei": "canhonar",
    "canhonáreis": "canhonar",
    "canhonásseis": "canhonar",
    "canhonássemos": "canhonar",
    "canhonávamo": "canhonar",
    "canhonávamos": "canhonar",
    "canhonávei": "canhonar",
    "canhonáveis": "canhonar",
    "canhos": "canho",
    "canhota": "canhoto",
    "canhotas": "canhoto",
    "canhotos": "canhoto",
    "canhou": "canhar",
    "canhámo": "canhar",
    "canhámos": "canhar",
    "canháramo": "canhar",
    "canháramos": "canhar",
    "canháreis": "canhar",
    "canhásseis": "canhar",
    "canhássemos": "canhar",
    "canhávamo": "canhar",
    "canhávamos": "canhar",
    "canháveis": "canhar",
    "canhões": "canhão",
    "canibais": "canibal",
    "canibalesca": "canibalesco",
    "canibalescas": "canibalesco",
    "canibalescos": "canibalesco",
    "canibalismos": "canibalismo",
    "canibalizações": "canibalização",
    "caniculara": "canicular",
    "canicularas": "canicular",
    "caniculares": "canicular",
    "caniculturas": "canicultura",
    "canifobias": "canifobia",
    "canifraza": "canifraz",
    "canifrazas": "canifraz",
    "canifrazes": "canifraz",
    "canilhas": "canilha",
    "canina": "canino",
    "caninanas": "caninana",
    "caninas": "canino",
    "caninha": "cana",
    "caninhas": "cana",
    "caninho": "cano",
    "caninhos": "cano",
    "caninos": "canino",
    "canis": "canil",
    "canistréis": "canistrel",
    "canita": "cana",
    "canitas": "cana",
    "canito": "cano",
    "canitos": "cano",
    "canivada": "canivado",
    "canivadas": "canivado",
    "canivados": "canivado",
    "canivetadas": "canivetada",
    "canivetaços": "canivetaço",
    "caniveteiros": "caniveteiro",
    "canivetes": "canivete",
    "canivetezinho": "canivete",
    "canivetezinhos": "canivete",
    "canivetezito": "canivete",
    "canivetezitos": "canivete",
    "caniçadas": "caniçada",
    "caniçados": "caniçado",
    "caniçais": "caniçal",
    "caniçalhas": "caniçalha",
    "caniçalhos": "caniçalho",
    "caniças": "caniça",
    "caniços": "caniço",
    "canjas": "canja",
    "canjinha": "canja",
    "canjinhas": "canja",
    "canjirões": "canjirão",
    "canjita": "canja",
    "canjitas": "canja",
    "canoagens": "canoagem",
    "canoas": "canoa",
    "canocos": "canoco",
    "canoeira": "canoeiro",
    "canoeiras": "canoeiro",
    "canoeiros": "canoeiro",
    "canoilas": "canoila",
    "canoilos": "canoilo",
    "canoiras": "canoira",
    "canonicais": "canonical",
    "canonicatos": "canonicato",
    "canonicidades": "canonicidade",
    "canonisas": "canonisa",
    "canonistas": "canonista",
    "canoniza": "canonizar",
    "canonizada": "canonizar",
    "canonizadas": "canonizar",
    "canonizado": "canonizar",
    "canonizadores": "canonizador",
    "canonizados": "canonizar",
    "canonizai": "canonizar",
    "canonizais": "canonizar",
    "canonizam": "canonizar",
    "canonizamo": "canonizar",
    "canonizamos": "canonizar",
    "canonizando": "canonizar",
    "canonizara": "canonizar",
    "canonizaram": "canonizar",
    "canonizaras": "canonizar",
    "canonizarde": "canonizar",
    "canonizardes": "canonizar",
    "canonizare": "canonizar",
    "canonizarei": "canonizar",
    "canonizareis": "canonizar",
    "canonizarem": "canonizar",
    "canonizaremos": "canonizar",
    "canonizares": "canonizar",
    "canonizaria": "canonizar",
    "canonizariam": "canonizar",
    "canonizarias": "canonizar",
    "canonizarmo": "canonizar",
    "canonizarmos": "canonizar",
    "canonizará": "canonizar",
    "canonizarás": "canonizar",
    "canonizarão": "canonizar",
    "canonizaríamos": "canonizar",
    "canonizaríeis": "canonizar",
    "canonizas": "canonizar",
    "canonizasse": "canonizar",
    "canonizassem": "canonizar",
    "canonizasses": "canonizar",
    "canonizaste": "canonizar",
    "canonizastes": "canonizar",
    "canonizava": "canonizar",
    "canonizavam": "canonizar",
    "canonizavas": "canonizar",
    "canonizações": "canonização",
    "canonize": "canonizar",
    "canonizei": "canonizar",
    "canonizeis": "canonizar",
    "canonizem": "canonizar",
    "canonizemo": "canonizar",
    "canonizemos": "canonizar",
    "canonizes": "canonizar",
    "canonizo": "canonizar",
    "canonizou": "canonizar",
    "canonizá": "canonizar",
    "canonizámo": "canonizar",
    "canonizámos": "canonizar",
    "canonizáramo": "canonizar",
    "canonizáramos": "canonizar",
    "canonizárei": "canonizar",
    "canonizáreis": "canonizar",
    "canonizásseis": "canonizar",
    "canonizássemos": "canonizar",
    "canonizávamo": "canonizar",
    "canonizávamos": "canonizar",
    "canonizávei": "canonizar",
    "canonizáveis": "canonizável",
    "canora": "canoro",
    "canoras": "canoro",
    "canoros": "canoro",
    "canos": "cano",
    "canotarias": "canotaria",
    "canoulas": "canoula",
    "canouras": "canoura",
    "canoístas": "canoísta",
    "cansa": "cansar",
    "cansada": "cansar",
    "cansadas": "cansar",
    "cansadinha": "cansado",
    "cansadinhas": "cansado",
    "cansadinho": "cansado",
    "cansadinhos": "cansado",
    "cansadita": "cansado",
    "cansaditas": "cansado",
    "cansadito": "cansado",
    "cansaditos": "cansado",
    "cansado": "cansar",
    "cansados": "cansar",
    "cansadíssima": "cansado",
    "cansadíssimas": "cansado",
    "cansadíssimo": "cansado",
    "cansadíssimos": "cansado",
    "cansai": "cansar",
    "cansais": "cansar",
    "cansam": "cansar",
    "cansamo": "cansar",
    "cansamos": "cansar",
    "cansando": "cansar",
    "cansara": "cansar",
    "cansaram": "cansar",
    "cansaras": "cansar",
    "cansarde": "cansar",
    "cansardes": "cansar",
    "cansare": "cansar",
    "cansarei": "cansar",
    "cansareis": "cansar",
    "cansarem": "cansar",
    "cansaremos": "cansar",
    "cansares": "cansar",
    "cansaria": "cansar",
    "cansariam": "cansar",
    "cansarias": "cansar",
    "cansarmo": "cansar",
    "cansarmos": "cansar",
    "cansará": "cansar",
    "cansarás": "cansar",
    "cansarão": "cansar",
    "cansaríamos": "cansar",
    "cansaríeis": "cansar",
    "cansas": "cansar",
    "cansasse": "cansar",
    "cansassem": "cansar",
    "cansasses": "cansar",
    "cansaste": "cansar",
    "cansastes": "cansar",
    "cansativa": "cansativo",
    "cansativas": "cansativo",
    "cansativos": "cansativo",
    "cansava": "cansar",
    "cansavam": "cansar",
    "cansavas": "cansar",
    "cansaços": "cansaço",
    "cansações": "cansação",
    "canse": "cansar",
    "cansei": "cansar",
    "canseiras": "canseira",
    "canseirosa": "canseiroso",
    "canseirosas": "canseiroso",
    "canseirosos": "canseiroso",
    "canseis": "cansar",
    "cansem": "cansar",
    "cansemo": "cansar",
    "cansemos": "cansar",
    "canses": "cansar",
    "canso": "cansar",
    "cansou": "cansar",
    "cansá": "cansar",
    "cansámo": "cansar",
    "cansámos": "cansar",
    "cansáramo": "cansar",
    "cansáramos": "cansar",
    "cansárei": "cansar",
    "cansáreis": "cansar",
    "cansásseis": "cansar",
    "cansássemos": "cansar",
    "cansávamo": "cansar",
    "cansávamos": "cansar",
    "cansávei": "cansar",
    "cansáveis": "cansar",
    "canta": "cantar",
    "cantada": "cantar",
    "cantadas": "cantar",
    "cantadeira": "cantador",
    "cantadeiras": "cantador",
    "cantadelas": "cantadela",
    "cantado": "cantar",
    "cantadoiras": "cantadoira",
    "cantadores": "cantador",
    "cantados": "cantar",
    "cantadouras": "cantadoura",
    "cantai": "cantar",
    "cantais": "cantar",
    "cantam": "cantar",
    "cantamo": "cantar",
    "cantamos": "cantar",
    "cantando": "cantar",
    "cantantes": "cantante",
    "cantara": "cantar",
    "cantaram": "cantar",
    "cantaras": "cantar",
    "cantarde": "cantar",
    "cantardes": "cantar",
    "cantare": "cantar",
    "cantarei": "cantar",
    "cantareiras": "cantareira",
    "cantareis": "cantar",
    "cantareja": "cantarejar",
    "cantarejada": "cantarejar",
    "cantarejadas": "cantarejar",
    "cantarejado": "cantarejar",
    "cantarejados": "cantarejar",
    "cantarejai": "cantarejar",
    "cantarejais": "cantarejar",
    "cantarejam": "cantarejar",
    "cantarejamo": "cantarejar",
    "cantarejamos": "cantarejar",
    "cantarejando": "cantarejar",
    "cantarejara": "cantarejar",
    "cantarejaram": "cantarejar",
    "cantarejaras": "cantarejar",
    "cantarejarde": "cantarejar",
    "cantarejardes": "cantarejar",
    "cantarejare": "cantarejar",
    "cantarejarei": "cantarejar",
    "cantarejareis": "cantarejar",
    "cantarejarem": "cantarejar",
    "cantarejaremos": "cantarejar",
    "cantarejares": "cantarejar",
    "cantarejaria": "cantarejar",
    "cantarejariam": "cantarejar",
    "cantarejarias": "cantarejar",
    "cantarejarmo": "cantarejar",
    "cantarejarmos": "cantarejar",
    "cantarejará": "cantarejar",
    "cantarejarás": "cantarejar",
    "cantarejarão": "cantarejar",
    "cantarejaríamos": "cantarejar",
    "cantarejaríeis": "cantarejar",
    "cantarejas": "cantarejar",
    "cantarejasse": "cantarejar",
    "cantarejassem": "cantarejar",
    "cantarejasses": "cantarejar",
    "cantarejaste": "cantarejar",
    "cantarejastes": "cantarejar",
    "cantarejava": "cantarejar",
    "cantarejavam": "cantarejar",
    "cantarejavas": "cantarejar",
    "cantareje": "cantarejar",
    "cantarejei": "cantarejar",
    "cantarejeis": "cantarejar",
    "cantarejem": "cantarejar",
    "cantarejemo": "cantarejar",
    "cantarejemos": "cantarejar",
    "cantarejes": "cantarejar",
    "cantarejo": "cantarejar",
    "cantarejos": "cantarejo",
    "cantarejou": "cantarejar",
    "cantarejá": "cantarejar",
    "cantarejámo": "cantarejar",
    "cantarejámos": "cantarejar",
    "cantarejáramo": "cantarejar",
    "cantarejáramos": "cantarejar",
    "cantarejárei": "cantarejar",
    "cantarejáreis": "cantarejar",
    "cantarejásseis": "cantarejar",
    "cantarejássemos": "cantarejar",
    "cantarejávamo": "cantarejar",
    "cantarejávamos": "cantarejar",
    "cantarejávei": "cantarejar",
    "cantarejáveis": "cantarejar",
    "cantarem": "cantar",
    "cantaremos": "cantar",
    "cantares": "cantar",
    "cantaria": "cantar",
    "cantariam": "cantar",
    "cantarias": "cantaria",
    "cantarida": "cantaridar",
    "cantaridada": "cantaridar",
    "cantaridadas": "cantaridar",
    "cantaridado": "cantaridar",
    "cantaridados": "cantaridar",
    "cantaridai": "cantaridar",
    "cantaridais": "cantaridar",
    "cantaridam": "cantaridar",
    "cantaridamo": "cantaridar",
    "cantaridamos": "cantaridar",
    "cantaridando": "cantaridar",
    "cantaridara": "cantaridar",
    "cantaridaram": "cantaridar",
    "cantaridaras": "cantaridar",
    "cantaridarde": "cantaridar",
    "cantaridardes": "cantaridar",
    "cantaridare": "cantaridar",
    "cantaridarei": "cantaridar",
    "cantaridareis": "cantaridar",
    "cantaridarem": "cantaridar",
    "cantaridaremos": "cantaridar",
    "cantaridares": "cantaridar",
    "cantaridaria": "cantaridar",
    "cantaridariam": "cantaridar",
    "cantaridarias": "cantaridar",
    "cantaridarmo": "cantaridar",
    "cantaridarmos": "cantaridar",
    "cantaridará": "cantaridar",
    "cantaridarás": "cantaridar",
    "cantaridarão": "cantaridar",
    "cantaridaríamos": "cantaridar",
    "cantaridaríeis": "cantaridar",
    "cantaridas": "cantaridar",
    "cantaridasse": "cantaridar",
    "cantaridassem": "cantaridar",
    "cantaridasses": "cantaridar",
    "cantaridaste": "cantaridar",
    "cantaridastes": "cantaridar",
    "cantaridava": "cantaridar",
    "cantaridavam": "cantaridar",
    "cantaridavas": "cantaridar",
    "cantaride": "cantaridar",
    "cantaridei": "cantaridar",
    "cantarideis": "cantaridar",
    "cantaridem": "cantaridar",
    "cantaridemo": "cantaridar",
    "cantaridemos": "cantaridar",
    "cantarides": "cantaridar",
    "cantaridinas": "cantaridina",
    "cantaridismos": "cantaridismo",
    "cantarido": "cantaridar",
    "cantaridou": "cantaridar",
    "cantaridá": "cantaridar",
    "cantaridámo": "cantaridar",
    "cantaridámos": "cantaridar",
    "cantaridáramo": "cantaridar",
    "cantaridáramos": "cantaridar",
    "cantaridárei": "cantaridar",
    "cantaridáreis": "cantaridar",
    "cantaridásseis": "cantaridar",
    "cantaridássemos": "cantaridar",
    "cantaridávamo": "cantaridar",
    "cantaridávamos": "cantaridar",
    "cantaridávei": "cantaridar",
    "cantaridáveis": "cantaridar",
    "cantarilhas": "cantarilha",
    "cantarilhos": "cantarilho",
    "cantarizes": "cantariz",
    "cantarmo": "cantar",
    "cantarmos": "cantar",
    "cantarola": "cantarolar",
    "cantarolada": "cantarolar",
    "cantaroladas": "cantarolar",
    "cantarolado": "cantarolar",
    "cantarolados": "cantarolar",
    "cantarolai": "cantarolar",
    "cantarolais": "cantarolar",
    "cantarolam": "cantarolar",
    "cantarolamo": "cantarolar",
    "cantarolamos": "cantarolar",
    "cantarolando": "cantarolar",
    "cantarolara": "cantarolar",
    "cantarolaram": "cantarolar",
    "cantarolaras": "cantarolar",
    "cantarolarde": "cantarolar",
    "cantarolardes": "cantarolar",
    "cantarolare": "cantarolar",
    "cantarolarei": "cantarolar",
    "cantarolareis": "cantarolar",
    "cantarolarem": "cantarolar",
    "cantarolaremos": "cantarolar",
    "cantarolares": "cantarolar",
    "cantarolaria": "cantarolar",
    "cantarolariam": "cantarolar",
    "cantarolarias": "cantarolar",
    "cantarolarmo": "cantarolar",
    "cantarolarmos": "cantarolar",
    "cantarolará": "cantarolar",
    "cantarolarás": "cantarolar",
    "cantarolarão": "cantarolar",
    "cantarolaríamos": "cantarolar",
    "cantarolaríeis": "cantarolar",
    "cantarolas": "cantarolar",
    "cantarolasse": "cantarolar",
    "cantarolassem": "cantarolar",
    "cantarolasses": "cantarolar",
    "cantarolaste": "cantarolar",
    "cantarolastes": "cantarolar",
    "cantarolava": "cantarolar",
    "cantarolavam": "cantarolar",
    "cantarolavas": "cantarolar",
    "cantarole": "cantarolar",
    "cantarolei": "cantarolar",
    "cantaroleis": "cantarolar",
    "cantarolem": "cantarolar",
    "cantarolemo": "cantarolar",
    "cantarolemos": "cantarolar",
    "cantaroles": "cantarolar",
    "cantarolo": "cantarolar",
    "cantarolou": "cantarolar",
    "cantarolá": "cantarolar",
    "cantarolámo": "cantarolar",
    "cantarolámos": "cantarolar",
    "cantaroláramo": "cantarolar",
    "cantaroláramos": "cantarolar",
    "cantarolárei": "cantarolar",
    "cantaroláreis": "cantarolar",
    "cantarolásseis": "cantarolar",
    "cantarolássemos": "cantarolar",
    "cantarolávamo": "cantarolar",
    "cantarolávamos": "cantarolar",
    "cantarolávei": "cantarolar",
    "cantaroláveis": "cantarolar",
    "cantará": "cantar",
    "cantarás": "cantar",
    "cantarão": "cantar",
    "cantaríamos": "cantar",
    "cantaríeis": "cantar",
    "cantas": "cantar",
    "cantasse": "cantar",
    "cantassem": "cantar",
    "cantasses": "cantar",
    "cantaste": "cantar",
    "cantastes": "cantar",
    "cantatas": "cantata",
    "cantava": "cantar",
    "cantavam": "cantar",
    "cantavas": "cantar",
    "cante": "cantar",
    "cantei": "cantar",
    "canteiras": "canteira",
    "canteirinho": "canteiro",
    "canteirinhos": "canteiro",
    "canteirito": "canteiro",
    "canteiritos": "canteiro",
    "canteiros": "canteiro",
    "canteirozinho": "canteiro",
    "canteirozinhos": "canteiro",
    "canteirozito": "canteiro",
    "canteirozitos": "canteiro",
    "canteis": "cantar",
    "cantem": "cantar",
    "cantemo": "cantar",
    "cantemos": "cantar",
    "cantes": "cantar",
    "cantigas": "cantiga",
    "cantiguinha": "cantiga",
    "cantiguinhas": "cantiga",
    "cantiguita": "cantiga",
    "cantiguitas": "cantiga",
    "cantilenas": "cantilena",
    "cantimploras": "cantimplora",
    "cantinas": "cantina",
    "cantineira": "cantineiro",
    "cantineiras": "cantineiro",
    "cantineiros": "cantineiro",
    "cantinho": "canto",
    "cantinhos": "canto",
    "cantis": "cantil",
    "cantito": "canto",
    "cantitos": "canto",
    "canto": "cantar",
    "cantochanistas": "cantochanista",
    "cantochões": "cantochão",
    "cantoeiras": "cantoeira",
    "cantonada": "cantonado",
    "cantonadas": "cantonado",
    "cantonados": "cantonado",
    "cantonais": "cantonal",
    "cantoneira": "cantoneiro",
    "cantoneiras": "cantoneiro",
    "cantoneiros": "cantoneiro",
    "cantonenses": "cantonense",
    "cantora": "cantor",
    "cantoras": "cantor",
    "cantorazinha": "cantor",
    "cantorazinhas": "cantor",
    "cantorazita": "cantor",
    "cantorazitas": "cantor",
    "cantores": "cantor",
    "cantorias": "cantoria",
    "cantorzinho": "cantor",
    "cantorzinhos": "cantor",
    "cantorzito": "cantor",
    "cantorzitos": "cantor",
    "cantos": "canto",
    "cantou": "cantar",
    "cantá": "cantar",
    "cantábria": "cantábrio",
    "cantábrias": "cantábrio",
    "cantábrica": "cantábrico",
    "cantábricas": "cantábrico",
    "cantábricos": "cantábrico",
    "cantábrios": "cantábrio",
    "cantámo": "cantar",
    "cantámos": "cantar",
    "cantáramo": "cantar",
    "cantáramos": "cantar",
    "cantárei": "cantar",
    "cantáreis": "cantar",
    "cantáridas": "cantárida",
    "cantárides": "cantáride",
    "cantásseis": "cantar",
    "cantássemos": "cantar",
    "cantávamo": "cantar",
    "cantávamos": "cantar",
    "cantávei": "cantar",
    "cantáveis": "cantável",
    "cantãs": "cantã",
    "cantões": "cantão",
    "canudinho": "canudo",
    "canudinhos": "canudo",
    "canudito": "canudo",
    "canuditos": "canudo",
    "canudos": "canudo",
    "canures": "canure",
    "canutilhos": "canutilho",
    "canzarrona": "canzarrão",
    "canzarronas": "canzarrão",
    "canzarrões": "canzarrão",
    "canzeira": "canzeiro",
    "canzeiras": "canzeiro",
    "canzeiros": "canzeiro",
    "canzis": "canzil",
    "canzoadas": "canzoada",
    "canzoais": "canzoal",
    "canária": "canário",
    "canárias": "canário",
    "canários": "canário",
    "cançonetas": "cançoneta",
    "cançonetismos": "cançonetismo",
    "cançonetistas": "cançonetista",
    "canções": "canção",
    "canéforas": "canéfora",
    "canícies": "canície",
    "canículas": "canícula",
    "canídea": "canídeo",
    "canídeas": "canídeo",
    "canídeos": "canídeo",
    "canífoba": "canífobo",
    "canífobas": "canífobo",
    "canífobos": "canífobo",
    "canóculos": "canóculo",
    "canódromos": "canódromo",
    "canónica": "canónico",
    "canónicas": "canónico",
    "canónicos": "canónico",
    "caocos": "caoco",
    "caotiza": "caotizar",
    "caotizada": "caotizar",
    "caotizadas": "caotizar",
    "caotizado": "caotizar",
    "caotizados": "caotizar",
    "caotizai": "caotizar",
    "caotizais": "caotizar",
    "caotizam": "caotizar",
    "caotizamo": "caotizar",
    "caotizamos": "caotizar",
    "caotizando": "caotizar",
    "caotizara": "caotizar",
    "caotizaram": "caotizar",
    "caotizaras": "caotizar",
    "caotizarde": "caotizar",
    "caotizardes": "caotizar",
    "caotizare": "caotizar",
    "caotizarei": "caotizar",
    "caotizareis": "caotizar",
    "caotizarem": "caotizar",
    "caotizaremos": "caotizar",
    "caotizares": "caotizar",
    "caotizaria": "caotizar",
    "caotizariam": "caotizar",
    "caotizarias": "caotizar",
    "caotizarmo": "caotizar",
    "caotizarmos": "caotizar",
    "caotizará": "caotizar",
    "caotizarás": "caotizar",
    "caotizarão": "caotizar",
    "caotizaríamos": "caotizar",
    "caotizaríeis": "caotizar",
    "caotizas": "caotizar",
    "caotizasse": "caotizar",
    "caotizassem": "caotizar",
    "caotizasses": "caotizar",
    "caotizaste": "caotizar",
    "caotizastes": "caotizar",
    "caotizava": "caotizar",
    "caotizavam": "caotizar",
    "caotizavas": "caotizar",
    "caotizações": "caotização",
    "caotize": "caotizar",
    "caotizei": "caotizar",
    "caotizeis": "caotizar",
    "caotizem": "caotizar",
    "caotizemo": "caotizar",
    "caotizemos": "caotizar",
    "caotizes": "caotizar",
    "caotizo": "caotizar",
    "caotizou": "caotizar",
    "caotizá": "caotizar",
    "caotizámo": "caotizar",
    "caotizámos": "caotizar",
    "caotizáramo": "caotizar",
    "caotizáramos": "caotizar",
    "caotizárei": "caotizar",
    "caotizáreis": "caotizar",
    "caotizásseis": "caotizar",
    "caotizássemos": "caotizar",
    "caotizávamo": "caotizar",
    "caotizávamos": "caotizar",
    "caotizávei": "caotizar",
    "caotizáveis": "caotizar",
    "capa": "capar",
    "capacetes": "capacete",
    "capacheiros": "capacheiro",
    "capachices": "capachice",
    "capachinho": "capacho",
    "capachinhos": "capacho",
    "capachismos": "capachismo",
    "capachito": "capacho",
    "capachitos": "capacho",
    "capachos": "capacho",
    "capacidades": "capacidade",
    "capacidadezinha": "capacidade",
    "capacidadezinhas": "capacidade",
    "capacidadezita": "capacidade",
    "capacidadezitas": "capacidade",
    "capacita": "capacitar",
    "capacitada": "capacitar",
    "capacitadas": "capacitar",
    "capacitado": "capacitar",
    "capacitados": "capacitar",
    "capacitai": "capacitar",
    "capacitais": "capacitar",
    "capacitam": "capacitar",
    "capacitamo": "capacitar",
    "capacitamos": "capacitar",
    "capacitando": "capacitar",
    "capacitara": "capacitar",
    "capacitaram": "capacitar",
    "capacitaras": "capacitar",
    "capacitarde": "capacitar",
    "capacitardes": "capacitar",
    "capacitare": "capacitar",
    "capacitarei": "capacitar",
    "capacitareis": "capacitar",
    "capacitarem": "capacitar",
    "capacitaremos": "capacitar",
    "capacitares": "capacitar",
    "capacitaria": "capacitar",
    "capacitariam": "capacitar",
    "capacitarias": "capacitar",
    "capacitarmo": "capacitar",
    "capacitarmos": "capacitar",
    "capacitará": "capacitar",
    "capacitarás": "capacitar",
    "capacitarão": "capacitar",
    "capacitaríamos": "capacitar",
    "capacitaríeis": "capacitar",
    "capacitas": "capacitar",
    "capacitasse": "capacitar",
    "capacitassem": "capacitar",
    "capacitasses": "capacitar",
    "capacitaste": "capacitar",
    "capacitastes": "capacitar",
    "capacitava": "capacitar",
    "capacitavam": "capacitar",
    "capacitavas": "capacitar",
    "capacitações": "capacitação",
    "capacite": "capacitar",
    "capacitei": "capacitar",
    "capaciteis": "capacitar",
    "capacitem": "capacitar",
    "capacitemo": "capacitar",
    "capacitemos": "capacitar",
    "capacites": "capacitar",
    "capacito": "capacitar",
    "capacitou": "capacitar",
    "capacitá": "capacitar",
    "capacitámo": "capacitar",
    "capacitámos": "capacitar",
    "capacitáramo": "capacitar",
    "capacitáramos": "capacitar",
    "capacitárei": "capacitar",
    "capacitáreis": "capacitar",
    "capacitásseis": "capacitar",
    "capacitássemos": "capacitar",
    "capacitávamo": "capacitar",
    "capacitávamos": "capacitar",
    "capacitávei": "capacitar",
    "capacitáveis": "capacitar",
    "capacitâncias": "capacitância",
    "capacímetros": "capacímetro",
    "capacíssima": "capaz",
    "capacíssimas": "capaz",
    "capacíssimo": "capaz",
    "capacíssimos": "capaz",
    "capada": "capar",
    "capadarias": "capadaria",
    "capadas": "capar",
    "capadeira": "capadeiro",
    "capadeiras": "capadeiro",
    "capadeiros": "capadeiro",
    "capado": "capar",
    "capadores": "capador",
    "capados": "capar",
    "capaduras": "capadura",
    "capadócia": "capadócio",
    "capadócias": "capadócio",
    "capadócios": "capadócio",
    "capai": "capar",
    "capais": "capar",
    "capam": "capar",
    "capamo": "capar",
    "capamos": "capar",
    "capando": "capar",
    "capanduas": "capandua",
    "capangadas": "capangada",
    "capangagens": "capangagem",
    "capangas": "capanga",
    "capangueira": "capangueiro",
    "capangueiras": "capangueiro",
    "capangueiros": "capangueiro",
    "capara": "capar",
    "caparam": "capar",
    "caparas": "capar",
    "caparazonaa": "caparazonao",
    "caparazonaas": "caparazonao",
    "caparazonaos": "caparazonao",
    "caparazões": "caparazão",
    "caparde": "capar",
    "capardes": "capar",
    "capare": "capar",
    "caparei": "capar",
    "capareis": "capar",
    "caparem": "capar",
    "caparemos": "capar",
    "capares": "capar",
    "caparia": "capar",
    "capariam": "capar",
    "caparias": "capar",
    "caparidáceas": "caparidácea",
    "caparmo": "capar",
    "caparmos": "capar",
    "caparoeira": "caparoeiro",
    "caparoeiras": "caparoeiro",
    "caparoeiros": "caparoeiro",
    "caparrossas": "caparrossa",
    "capará": "capar",
    "caparás": "capar",
    "caparão": "capar",
    "caparíamos": "capar",
    "caparíeis": "capar",
    "caparões": "caparão",
    "capas": "capar",
    "capasse": "capar",
    "capassem": "capar",
    "capasses": "capar",
    "capaste": "capar",
    "capastes": "capar",
    "capatazes": "capataz",
    "capatazias": "capatazia",
    "capatorras": "capatorra",
    "capatázia": "capatázio",
    "capatázias": "capatázio",
    "capatázios": "capatázio",
    "capatões": "capatão",
    "capava": "capar",
    "capavam": "capar",
    "capavas": "capar",
    "capazes": "capaz",
    "capações": "capação",
    "capciosa": "capcioso",
    "capciosas": "capcioso",
    "capciosos": "capcioso",
    "cape": "capar",
    "capeada": "capear",
    "capeadas": "capear",
    "capeado": "capear",
    "capeadores": "capeador",
    "capeados": "capear",
    "capeai": "capear",
    "capeais": "capear",
    "capeamentos": "capeamento",
    "capeamo": "capear",
    "capeamos": "capear",
    "capeando": "capear",
    "capeara": "capear",
    "capearam": "capear",
    "capearas": "capear",
    "capearde": "capear",
    "capeardes": "capear",
    "capeare": "capear",
    "capearei": "capear",
    "capeareis": "capear",
    "capearem": "capear",
    "capearemos": "capear",
    "capeares": "capear",
    "capearia": "capear",
    "capeariam": "capear",
    "capearias": "capear",
    "capearmo": "capear",
    "capearmos": "capear",
    "capeará": "capear",
    "capearás": "capear",
    "capearão": "capear",
    "capearíamos": "capear",
    "capearíeis": "capear",
    "capeasse": "capear",
    "capeassem": "capear",
    "capeasses": "capear",
    "capeaste": "capear",
    "capeastes": "capear",
    "capeava": "capear",
    "capeavam": "capear",
    "capeavas": "capear",
    "capeei": "capear",
    "capeeis": "capear",
    "capeemo": "capear",
    "capeemos": "capear",
    "capei": "capar",
    "capeia": "capear",
    "capeiam": "capear",
    "capeias": "capeia",
    "capeie": "capear",
    "capeiem": "capear",
    "capeies": "capear",
    "capeio": "capear",
    "capeiros": "capeiro",
    "capeis": "capar",
    "capeladas": "capelada",
    "capelanias": "capelania",
    "capelas": "capela",
    "capeleiras": "capeleira",
    "capelenses": "capelense",
    "capelinas": "capelina",
    "capelines": "capeline",
    "capelinha": "capela",
    "capelinhas": "capela",
    "capelistas": "capelista",
    "capelita": "capela",
    "capelitas": "capela",
    "capelos": "capelo",
    "capeluda": "capeludo",
    "capeludas": "capeludo",
    "capeludos": "capeludo",
    "capelões": "capelão",
    "capem": "capar",
    "capemo": "capar",
    "capemos": "capar",
    "capeou": "capear",
    "caperotadas": "caperotada",
    "capes": "capar",
    "capeá": "capear",
    "capeámo": "capear",
    "capeámos": "capear",
    "capeáramo": "capear",
    "capeáramos": "capear",
    "capeárei": "capear",
    "capeáreis": "capear",
    "capeásseis": "capear",
    "capeássemos": "capear",
    "capeávamo": "capear",
    "capeávamos": "capear",
    "capeávei": "capear",
    "capeáveis": "capear",
    "capialços": "capialço",
    "capicuas": "capicua",
    "capigorrões": "capigorrão",
    "capilamentos": "capilamento",
    "capilara": "capilar",
    "capilaras": "capilar",
    "capilares": "capilar",
    "capilaridades": "capilaridade",
    "capilarímetros": "capilarímetro",
    "capilhas": "capilha",
    "capiliformes": "capiliforme",
    "capilotas": "capilota",
    "capilácea": "capiláceo",
    "capiláceas": "capiláceo",
    "capiláceos": "capiláceo",
    "capilárias": "capilária",
    "capilés": "capilé",
    "capina": "capinar",
    "capinada": "capinar",
    "capinadas": "capinar",
    "capinadeira": "capinador",
    "capinadeiras": "capinador",
    "capinado": "capinar",
    "capinadora": "capinador",
    "capinadoras": "capinador",
    "capinadores": "capinador",
    "capinados": "capinar",
    "capinai": "capinar",
    "capinais": "capinar",
    "capinam": "capinar",
    "capinamo": "capinar",
    "capinamos": "capinar",
    "capinando": "capinar",
    "capinara": "capinar",
    "capinaram": "capinar",
    "capinaras": "capinar",
    "capinarde": "capinar",
    "capinardes": "capinar",
    "capinare": "capinar",
    "capinarei": "capinar",
    "capinareis": "capinar",
    "capinarem": "capinar",
    "capinaremos": "capinar",
    "capinares": "capinar",
    "capinaria": "capinar",
    "capinariam": "capinar",
    "capinarias": "capinar",
    "capinarmo": "capinar",
    "capinarmos": "capinar",
    "capinará": "capinar",
    "capinarás": "capinar",
    "capinarão": "capinar",
    "capinaríamos": "capinar",
    "capinaríeis": "capinar",
    "capinas": "capinar",
    "capinasse": "capinar",
    "capinassem": "capinar",
    "capinasses": "capinar",
    "capinaste": "capinar",
    "capinastes": "capinar",
    "capinava": "capinar",
    "capinavam": "capinar",
    "capinavas": "capinar",
    "capinações": "capinação",
    "capindós": "capindó",
    "capine": "capinar",
    "capinei": "capinar",
    "capineira": "capineiro",
    "capineiras": "capineiro",
    "capineiros": "capineiro",
    "capineis": "capinar",
    "capinem": "capinar",
    "capinemo": "capinar",
    "capinemos": "capinar",
    "capines": "capinar",
    "capinha": "capa",
    "capinhas": "capinha",
    "capino": "capinar",
    "capinou": "capinar",
    "capins": "capim",
    "capinzais": "capinzal",
    "capiná": "capinar",
    "capinámo": "capinar",
    "capinámos": "capinar",
    "capináramo": "capinar",
    "capináramos": "capinar",
    "capinárei": "capinar",
    "capináreis": "capinar",
    "capinásseis": "capinar",
    "capinássemos": "capinar",
    "capinávamo": "capinar",
    "capinávamos": "capinar",
    "capinávei": "capinar",
    "capináveis": "capinar",
    "capirotes": "capirote",
    "capisca": "capiscar",
    "capiscada": "capiscar",
    "capiscadas": "capiscar",
    "capiscado": "capiscar",
    "capiscados": "capiscar",
    "capiscai": "capiscar",
    "capiscais": "capiscar",
    "capiscam": "capiscar",
    "capiscamo": "capiscar",
    "capiscamos": "capiscar",
    "capiscando": "capiscar",
    "capiscara": "capiscar",
    "capiscaram": "capiscar",
    "capiscaras": "capiscar",
    "capiscarde": "capiscar",
    "capiscardes": "capiscar",
    "capiscare": "capiscar",
    "capiscarei": "capiscar",
    "capiscareis": "capiscar",
    "capiscarem": "capiscar",
    "capiscaremos": "capiscar",
    "capiscares": "capiscar",
    "capiscaria": "capiscar",
    "capiscariam": "capiscar",
    "capiscarias": "capiscar",
    "capiscarmo": "capiscar",
    "capiscarmos": "capiscar",
    "capiscará": "capiscar",
    "capiscarás": "capiscar",
    "capiscarão": "capiscar",
    "capiscaríamos": "capiscar",
    "capiscaríeis": "capiscar",
    "capiscas": "capiscar",
    "capiscasse": "capiscar",
    "capiscassem": "capiscar",
    "capiscasses": "capiscar",
    "capiscaste": "capiscar",
    "capiscastes": "capiscar",
    "capiscava": "capiscar",
    "capiscavam": "capiscar",
    "capiscavas": "capiscar",
    "capisco": "capiscar",
    "capiscou": "capiscar",
    "capiscá": "capiscar",
    "capiscámo": "capiscar",
    "capiscámos": "capiscar",
    "capiscáramo": "capiscar",
    "capiscáramos": "capiscar",
    "capiscárei": "capiscar",
    "capiscáreis": "capiscar",
    "capiscásseis": "capiscar",
    "capiscássemos": "capiscar",
    "capiscávamo": "capiscar",
    "capiscávamos": "capiscar",
    "capiscávei": "capiscar",
    "capiscáveis": "capiscar",
    "capisque": "capiscar",
    "capisquei": "capiscar",
    "capisqueis": "capiscar",
    "capisquem": "capiscar",
    "capisquemo": "capiscar",
    "capisquemos": "capiscar",
    "capisques": "capiscar",
    "capistas": "capista",
    "capistra": "capistrar",
    "capistrada": "capistrar",
    "capistradas": "capistrar",
    "capistrado": "capistrar",
    "capistrados": "capistrar",
    "capistrai": "capistrar",
    "capistrais": "capistrar",
    "capistram": "capistrar",
    "capistramo": "capistrar",
    "capistramos": "capistrar",
    "capistrando": "capistrar",
    "capistrara": "capistrar",
    "capistraram": "capistrar",
    "capistraras": "capistrar",
    "capistrarde": "capistrar",
    "capistrardes": "capistrar",
    "capistrare": "capistrar",
    "capistrarei": "capistrar",
    "capistrareis": "capistrar",
    "capistrarem": "capistrar",
    "capistraremos": "capistrar",
    "capistrares": "capistrar",
    "capistraria": "capistrar",
    "capistrariam": "capistrar",
    "capistrarias": "capistrar",
    "capistrarmo": "capistrar",
    "capistrarmos": "capistrar",
    "capistrará": "capistrar",
    "capistrarás": "capistrar",
    "capistrarão": "capistrar",
    "capistraríamos": "capistrar",
    "capistraríeis": "capistrar",
    "capistras": "capistrar",
    "capistrasse": "capistrar",
    "capistrassem": "capistrar",
    "capistrasses": "capistrar",
    "capistraste": "capistrar",
    "capistrastes": "capistrar",
    "capistrava": "capistrar",
    "capistravam": "capistrar",
    "capistravas": "capistrar",
    "capistre": "capistrar",
    "capistrei": "capistrar",
    "capistreis": "capistrar",
    "capistrem": "capistrar",
    "capistremo": "capistrar",
    "capistremos": "capistrar",
    "capistres": "capistrar",
    "capistro": "capistrar",
    "capistros": "capistro",
    "capistrou": "capistrar",
    "capistrá": "capistrar",
    "capistrámo": "capistrar",
    "capistrámos": "capistrar",
    "capistráramo": "capistrar",
    "capistráramos": "capistrar",
    "capistrárei": "capistrar",
    "capistráreis": "capistrar",
    "capistrásseis": "capistrar",
    "capistrássemos": "capistrar",
    "capistrávamo": "capistrar",
    "capistrávamos": "capistrar",
    "capistrávei": "capistrar",
    "capistráveis": "capistrar",
    "capita": "capitar",
    "capitada": "capitar",
    "capitadas": "capitar",
    "capitado": "capitar",
    "capitados": "capitar",
    "capitai": "capitar",
    "capitais": "capitar",
    "capitalismos": "capitalismo",
    "capitalistas": "capitalista",
    "capitaliza": "capitalizar",
    "capitalizada": "capitalizar",
    "capitalizadas": "capitalizar",
    "capitalizado": "capitalizar",
    "capitalizados": "capitalizar",
    "capitalizai": "capitalizar",
    "capitalizais": "capitalizar",
    "capitalizam": "capitalizar",
    "capitalizamo": "capitalizar",
    "capitalizamos": "capitalizar",
    "capitalizando": "capitalizar",
    "capitalizara": "capitalizar",
    "capitalizaram": "capitalizar",
    "capitalizaras": "capitalizar",
    "capitalizarde": "capitalizar",
    "capitalizardes": "capitalizar",
    "capitalizare": "capitalizar",
    "capitalizarei": "capitalizar",
    "capitalizareis": "capitalizar",
    "capitalizarem": "capitalizar",
    "capitalizaremos": "capitalizar",
    "capitalizares": "capitalizar",
    "capitalizaria": "capitalizar",
    "capitalizariam": "capitalizar",
    "capitalizarias": "capitalizar",
    "capitalizarmo": "capitalizar",
    "capitalizarmos": "capitalizar",
    "capitalizará": "capitalizar",
    "capitalizarás": "capitalizar",
    "capitalizarão": "capitalizar",
    "capitalizaríamos": "capitalizar",
    "capitalizaríeis": "capitalizar",
    "capitalizas": "capitalizar",
    "capitalizasse": "capitalizar",
    "capitalizassem": "capitalizar",
    "capitalizasses": "capitalizar",
    "capitalizaste": "capitalizar",
    "capitalizastes": "capitalizar",
    "capitalizava": "capitalizar",
    "capitalizavam": "capitalizar",
    "capitalizavas": "capitalizar",
    "capitalizações": "capitalização",
    "capitalize": "capitalizar",
    "capitalizei": "capitalizar",
    "capitalizeis": "capitalizar",
    "capitalizem": "capitalizar",
    "capitalizemo": "capitalizar",
    "capitalizemos": "capitalizar",
    "capitalizes": "capitalizar",
    "capitalizo": "capitalizar",
    "capitalizou": "capitalizar",
    "capitalizá": "capitalizar",
    "capitalizámo": "capitalizar",
    "capitalizámos": "capitalizar",
    "capitalizáramo": "capitalizar",
    "capitalizáramos": "capitalizar",
    "capitalizárei": "capitalizar",
    "capitalizáreis": "capitalizar",
    "capitalizásseis": "capitalizar",
    "capitalizássemos": "capitalizar",
    "capitalizávamo": "capitalizar",
    "capitalizávamos": "capitalizar",
    "capitalizávei": "capitalizar",
    "capitalizáveis": "capitalizável",
    "capitam": "capitar",
    "capitamo": "capitar",
    "capitamos": "capitar",
    "capitando": "capitar",
    "capitaneada": "capitanear",
    "capitaneadas": "capitanear",
    "capitaneado": "capitanear",
    "capitaneados": "capitanear",
    "capitaneai": "capitanear",
    "capitaneais": "capitanear",
    "capitaneamo": "capitanear",
    "capitaneamos": "capitanear",
    "capitaneando": "capitanear",
    "capitaneara": "capitanear",
    "capitanearam": "capitanear",
    "capitanearas": "capitanear",
    "capitanearde": "capitanear",
    "capitaneardes": "capitanear",
    "capitaneare": "capitanear",
    "capitanearei": "capitanear",
    "capitaneareis": "capitanear",
    "capitanearem": "capitanear",
    "capitanearemos": "capitanear",
    "capitaneares": "capitanear",
    "capitanearia": "capitanear",
    "capitaneariam": "capitanear",
    "capitanearias": "capitanear",
    "capitanearmo": "capitanear",
    "capitanearmos": "capitanear",
    "capitaneará": "capitanear",
    "capitanearás": "capitanear",
    "capitanearão": "capitanear",
    "capitanearíamos": "capitanear",
    "capitanearíeis": "capitanear",
    "capitaneasse": "capitanear",
    "capitaneassem": "capitanear",
    "capitaneasses": "capitanear",
    "capitaneaste": "capitanear",
    "capitaneastes": "capitanear",
    "capitaneava": "capitanear",
    "capitaneavam": "capitanear",
    "capitaneavas": "capitanear",
    "capitaneei": "capitanear",
    "capitaneeis": "capitanear",
    "capitaneemo": "capitanear",
    "capitaneemos": "capitanear",
    "capitaneia": "capitanear",
    "capitaneiam": "capitanear",
    "capitaneias": "capitanear",
    "capitaneie": "capitanear",
    "capitaneiem": "capitanear",
    "capitaneies": "capitanear",
    "capitaneio": "capitanear",
    "capitaneou": "capitanear",
    "capitaneá": "capitanear",
    "capitaneámo": "capitanear",
    "capitaneámos": "capitanear",
    "capitaneáramo": "capitanear",
    "capitaneáramos": "capitanear",
    "capitaneárei": "capitanear",
    "capitaneáreis": "capitanear",
    "capitaneásseis": "capitanear",
    "capitaneássemos": "capitanear",
    "capitaneávamo": "capitanear",
    "capitaneávamos": "capitanear",
    "capitaneávei": "capitanear",
    "capitaneáveis": "capitanear",
    "capitanias": "capitania",
    "capitara": "capitar",
    "capitaram": "capitar",
    "capitaras": "capitar",
    "capitarde": "capitar",
    "capitardes": "capitar",
    "capitare": "capitar",
    "capitarei": "capitar",
    "capitareis": "capitar",
    "capitarem": "capitar",
    "capitaremos": "capitar",
    "capitares": "capitar",
    "capitaria": "capitar",
    "capitariam": "capitar",
    "capitarias": "capitar",
    "capitarmo": "capitar",
    "capitarmos": "capitar",
    "capitará": "capitar",
    "capitarás": "capitar",
    "capitarão": "capitar",
    "capitaríamos": "capitar",
    "capitaríeis": "capitar",
    "capitas": "capitar",
    "capitasse": "capitar",
    "capitassem": "capitar",
    "capitasses": "capitar",
    "capitaste": "capitar",
    "capitastes": "capitar",
    "capitata": "capitato",
    "capitatas": "capitato",
    "capitatos": "capitato",
    "capitava": "capitar",
    "capitavam": "capitar",
    "capitavas": "capitar",
    "capitações": "capitação",
    "capite": "capitar",
    "capitei": "capitar",
    "capiteis": "capitel",
    "capitem": "capitar",
    "capitemo": "capitar",
    "capitemos": "capitar",
    "capites": "capitar",
    "capitiformes": "capitiforme",
    "capitilúvios": "capitilúvio",
    "capito": "capitar",
    "capitoas": "capitoa",
    "capitolina": "capitolino",
    "capitolinas": "capitolino",
    "capitolinos": "capitolino",
    "capitosa": "capitoso",
    "capitosas": "capitoso",
    "capitosos": "capitoso",
    "capitou": "capitar",
    "capitula": "capitular",
    "capitulada": "capitular",
    "capituladas": "capitular",
    "capitulado": "capitular",
    "capitulados": "capitular",
    "capitulai": "capitular",
    "capitulais": "capitular",
    "capitulam": "capitular",
    "capitulamo": "capitular",
    "capitulamos": "capitular",
    "capitulando": "capitular",
    "capitulantes": "capitulante",
    "capitulara": "capitular",
    "capitularam": "capitular",
    "capitularas": "capitular",
    "capitularde": "capitular",
    "capitulardes": "capitular",
    "capitulare": "capitular",
    "capitularei": "capitular",
    "capitulareis": "capitular",
    "capitularem": "capitular",
    "capitularemos": "capitular",
    "capitulares": "capitular",
    "capitularia": "capitular",
    "capitulariam": "capitular",
    "capitularias": "capitular",
    "capitularmo": "capitular",
    "capitularmos": "capitular",
    "capitulará": "capitular",
    "capitularás": "capitular",
    "capitularão": "capitular",
    "capitularíamos": "capitular",
    "capitularíeis": "capitular",
    "capitulas": "capitular",
    "capitulasse": "capitular",
    "capitulassem": "capitular",
    "capitulasses": "capitular",
    "capitulaste": "capitular",
    "capitulastes": "capitular",
    "capitulava": "capitular",
    "capitulavam": "capitular",
    "capitulavas": "capitular",
    "capitulações": "capitulação",
    "capitule": "capitular",
    "capitulei": "capitular",
    "capituleiros": "capituleiro",
    "capituleis": "capitular",
    "capitulem": "capitular",
    "capitulemo": "capitular",
    "capitulemos": "capitular",
    "capitules": "capitular",
    "capitulo": "capitular",
    "capitulou": "capitular",
    "capitulá": "capitular",
    "capitulámo": "capitular",
    "capitulámos": "capitular",
    "capituláramo": "capitular",
    "capituláramos": "capitular",
    "capitulárei": "capitular",
    "capituláreis": "capitular",
    "capitulásseis": "capitular",
    "capitulássemos": "capitular",
    "capitulávamo": "capitular",
    "capitulávamos": "capitular",
    "capitulávei": "capitular",
    "capituláveis": "capitular",
    "capitá": "capitar",
    "capitámo": "capitar",
    "capitámos": "capitar",
    "capitáramo": "capitar",
    "capitáramos": "capitar",
    "capitárei": "capitar",
    "capitáreis": "capitar",
    "capitásseis": "capitar",
    "capitássemos": "capitar",
    "capitávamo": "capitar",
    "capitávamos": "capitar",
    "capitávei": "capitar",
    "capitáveis": "capitar",
    "capitânias": "capitânia",
    "capitã": "capitão",
    "capitães": "capitão",
    "capitãs": "capitão",
    "capitólios": "capitólio",
    "capivaras": "capivara",
    "capnomancias": "capnomancia",
    "capnomantes": "capnomante",
    "capnomântica": "capnomântico",
    "capnomânticas": "capnomântico",
    "capnomânticos": "capnomântico",
    "capnófaga": "capnófago",
    "capnófagas": "capnófago",
    "capnófagos": "capnófago",
    "capo": "capar",
    "capoeira": "capoeiro",
    "capoeiras": "capoeiro",
    "capoeiros": "capoeiro",
    "caponas": "capona",
    "caporais": "caporal",
    "caporros": "caporro",
    "capota": "capotar",
    "capotada": "capotar",
    "capotadas": "capotar",
    "capotado": "capotar",
    "capotados": "capotar",
    "capotagens": "capotagem",
    "capotai": "capotar",
    "capotais": "capotar",
    "capotam": "capotar",
    "capotamentos": "capotamento",
    "capotamo": "capotar",
    "capotamos": "capotar",
    "capotando": "capotar",
    "capotara": "capotar",
    "capotaram": "capotar",
    "capotaras": "capotar",
    "capotarde": "capotar",
    "capotardes": "capotar",
    "capotare": "capotar",
    "capotarei": "capotar",
    "capotareis": "capotar",
    "capotarem": "capotar",
    "capotaremos": "capotar",
    "capotares": "capotar",
    "capotaria": "capotar",
    "capotariam": "capotar",
    "capotarias": "capotar",
    "capotarmo": "capotar",
    "capotarmos": "capotar",
    "capotará": "capotar",
    "capotarás": "capotar",
    "capotarão": "capotar",
    "capotaríamos": "capotar",
    "capotaríeis": "capotar",
    "capotas": "capotar",
    "capotasse": "capotar",
    "capotassem": "capotar",
    "capotasses": "capotar",
    "capotaste": "capotar",
    "capotastes": "capotar",
    "capotava": "capotar",
    "capotavam": "capotar",
    "capotavas": "capotar",
    "capote": "capotar",
    "capoteada": "capotear",
    "capoteadas": "capotear",
    "capoteado": "capotear",
    "capoteados": "capotear",
    "capoteai": "capotear",
    "capoteais": "capotear",
    "capoteamo": "capotear",
    "capoteamos": "capotear",
    "capoteando": "capotear",
    "capoteara": "capotear",
    "capotearam": "capotear",
    "capotearas": "capotear",
    "capotearde": "capotear",
    "capoteardes": "capotear",
    "capoteare": "capotear",
    "capotearei": "capotear",
    "capoteareis": "capotear",
    "capotearem": "capotear",
    "capotearemos": "capotear",
    "capoteares": "capotear",
    "capotearia": "capotear",
    "capoteariam": "capotear",
    "capotearias": "capotear",
    "capotearmo": "capotear",
    "capotearmos": "capotear",
    "capoteará": "capotear",
    "capotearás": "capotear",
    "capotearão": "capotear",
    "capotearíamos": "capotear",
    "capotearíeis": "capotear",
    "capoteasse": "capotear",
    "capoteassem": "capotear",
    "capoteasses": "capotear",
    "capoteaste": "capotear",
    "capoteastes": "capotear",
    "capoteava": "capotear",
    "capoteavam": "capotear",
    "capoteavas": "capotear",
    "capoteei": "capotear",
    "capoteeis": "capotear",
    "capoteemo": "capotear",
    "capoteemos": "capotear",
    "capotei": "capotar",
    "capoteia": "capotear",
    "capoteiam": "capotear",
    "capoteias": "capotear",
    "capoteie": "capotear",
    "capoteiem": "capotear",
    "capoteies": "capotear",
    "capoteio": "capotear",
    "capoteiras": "capoteira",
    "capoteis": "capotar",
    "capotem": "capotar",
    "capotemo": "capotar",
    "capotemos": "capotar",
    "capoteou": "capotear",
    "capotes": "capote",
    "capoteá": "capotear",
    "capoteámo": "capotear",
    "capoteámos": "capotear",
    "capoteáramo": "capotear",
    "capoteáramos": "capotear",
    "capoteárei": "capotear",
    "capoteáreis": "capotear",
    "capoteásseis": "capotear",
    "capoteássemos": "capotear",
    "capoteávamo": "capotear",
    "capoteávamos": "capotear",
    "capoteávei": "capotear",
    "capoteáveis": "capotear",
    "capotilhas": "capotilha",
    "capotilhos": "capotilho",
    "capoto": "capotar",
    "capotou": "capotar",
    "capotá": "capotar",
    "capotámo": "capotar",
    "capotámos": "capotar",
    "capotáramo": "capotar",
    "capotáramos": "capotar",
    "capotárei": "capotar",
    "capotáreis": "capotar",
    "capotásseis": "capotar",
    "capotássemos": "capotar",
    "capotávamo": "capotar",
    "capotávamos": "capotar",
    "capotávei": "capotar",
    "capotáveis": "capotar",
    "capotão": "capote",
    "capotões": "capote",
    "capou": "capar",
    "capreolares": "capreolar",
    "capribarbuda": "capribarbudo",
    "capribarbudas": "capribarbudo",
    "capribarbudos": "capribarbudo",
    "capricha": "caprichar",
    "caprichada": "caprichar",
    "caprichadas": "caprichar",
    "caprichado": "caprichar",
    "caprichados": "caprichar",
    "caprichai": "caprichar",
    "caprichais": "caprichar",
    "capricham": "caprichar",
    "caprichamo": "caprichar",
    "caprichamos": "caprichar",
    "caprichando": "caprichar",
    "caprichara": "caprichar",
    "capricharam": "caprichar",
    "capricharas": "caprichar",
    "caprichardes": "caprichar",
    "capricharei": "caprichar",
    "caprichareis": "caprichar",
    "capricharem": "caprichar",
    "capricharemos": "caprichar",
    "caprichares": "caprichar",
    "capricharia": "caprichar",
    "caprichariam": "caprichar",
    "capricharias": "caprichar",
    "capricharmo": "caprichar",
    "capricharmos": "caprichar",
    "caprichará": "caprichar",
    "capricharás": "caprichar",
    "capricharão": "caprichar",
    "capricharíamos": "caprichar",
    "capricharíeis": "caprichar",
    "caprichas": "caprichar",
    "caprichasse": "caprichar",
    "caprichassem": "caprichar",
    "caprichasses": "caprichar",
    "caprichaste": "caprichar",
    "caprichastes": "caprichar",
    "caprichava": "caprichar",
    "caprichavam": "caprichar",
    "caprichavas": "caprichar",
    "capriche": "caprichar",
    "caprichei": "caprichar",
    "capricheiras": "capricheira",
    "capricheis": "caprichar",
    "caprichem": "caprichar",
    "caprichemo": "caprichar",
    "caprichemos": "caprichar",
    "capriches": "caprichar",
    "capricho": "caprichar",
    "caprichos": "capricho",
    "caprichosa": "caprichoso",
    "caprichosas": "caprichoso",
    "caprichosos": "caprichoso",
    "caprichou": "caprichar",
    "caprichozinho": "capricho",
    "caprichozinhos": "capricho",
    "caprichozito": "capricho",
    "caprichozitos": "capricho",
    "caprichámo": "caprichar",
    "caprichámos": "caprichar",
    "capricháramo": "caprichar",
    "capricháramos": "caprichar",
    "capricháreis": "caprichar",
    "caprichásseis": "caprichar",
    "caprichássemos": "caprichar",
    "caprichávamo": "caprichar",
    "caprichávamos": "caprichar",
    "capricháveis": "caprichar",
    "capricórnia": "capricórnio",
    "capricórnias": "capricórnio",
    "capricórnios": "capricórnio",
    "caprifica": "caprificar",
    "caprificada": "caprificar",
    "caprificadas": "caprificar",
    "caprificado": "caprificar",
    "caprificados": "caprificar",
    "caprificai": "caprificar",
    "caprificais": "caprificar",
    "caprificam": "caprificar",
    "caprificamo": "caprificar",
    "caprificamos": "caprificar",
    "caprificando": "caprificar",
    "caprificara": "caprificar",
    "caprificaram": "caprificar",
    "caprificaras": "caprificar",
    "caprificarde": "caprificar",
    "caprificardes": "caprificar",
    "caprificare": "caprificar",
    "caprificarei": "caprificar",
    "caprificareis": "caprificar",
    "caprificarem": "caprificar",
    "caprificaremos": "caprificar",
    "caprificares": "caprificar",
    "caprificaria": "caprificar",
    "caprificariam": "caprificar",
    "caprificarias": "caprificar",
    "caprificarmo": "caprificar",
    "caprificarmos": "caprificar",
    "caprificará": "caprificar",
    "caprificarás": "caprificar",
    "caprificarão": "caprificar",
    "caprificaríamos": "caprificar",
    "caprificaríeis": "caprificar",
    "caprificas": "caprificar",
    "caprificasse": "caprificar",
    "caprificassem": "caprificar",
    "caprificasses": "caprificar",
    "caprificaste": "caprificar",
    "caprificastes": "caprificar",
    "caprificava": "caprificar",
    "caprificavam": "caprificar",
    "caprificavas": "caprificar",
    "caprificações": "caprificação",
    "caprifico": "caprificar",
    "caprificou": "caprificar",
    "caprificá": "caprificar",
    "caprificámo": "caprificar",
    "caprificámos": "caprificar",
    "caprificáramo": "caprificar",
    "caprificáramos": "caprificar",
    "caprificárei": "caprificar",
    "caprificáreis": "caprificar",
    "caprificásseis": "caprificar",
    "caprificássemos": "caprificar",
    "caprificávamo": "caprificar",
    "caprificávamos": "caprificar",
    "caprificávei": "caprificar",
    "caprificáveis": "caprificar",
    "caprifique": "caprificar",
    "caprifiquei": "caprificar",
    "caprifiqueis": "caprificar",
    "caprifiquem": "caprificar",
    "caprifiquemo": "caprificar",
    "caprifiquemos": "caprificar",
    "caprifiques": "caprificar",
    "caprifoleáceas": "caprifoleácea",
    "caprifoliácea": "caprifoliáceo",
    "caprifoliáceas": "caprifoliáceo",
    "caprifoliáceos": "caprifoliáceo",
    "caprimulgídea": "caprimulgídeo",
    "caprimulgídeas": "caprimulgídeo",
    "caprimulgídeos": "caprimulgídeo",
    "caprimúlgidas": "caprimúlgida",
    "caprina": "caprino",
    "caprinas": "caprino",
    "caprinos": "caprino",
    "capruns": "caprum",
    "caprárias": "caprária",
    "capréolos": "capréolo",
    "caprídea": "caprídeo",
    "caprídeas": "caprídeo",
    "caprídeos": "caprídeo",
    "caprílica": "caprílico",
    "caprílicas": "caprílico",
    "caprílicos": "caprílico",
    "caprínea": "capríneo",
    "capríneas": "capríneo",
    "capríneos": "capríneo",
    "caprípedes": "caprípede",
    "capsuladores": "capsulador",
    "capsulares": "capsular",
    "capsulações": "capsulação",
    "capsulífera": "capsulífero",
    "capsulíferas": "capsulífero",
    "capsulíferos": "capsulífero",
    "capta": "captar",
    "captada": "captar",
    "captadas": "captar",
    "captado": "captar",
    "captadores": "captador",
    "captados": "captar",
    "captai": "captar",
    "captais": "captar",
    "captam": "captar",
    "captamo": "captar",
    "captamos": "captar",
    "captando": "captar",
    "captara": "captar",
    "captaram": "captar",
    "captaras": "captar",
    "captarde": "captar",
    "captardes": "captar",
    "captare": "captar",
    "captarei": "captar",
    "captareis": "captar",
    "captarem": "captar",
    "captaremos": "captar",
    "captares": "captar",
    "captaria": "captar",
    "captariam": "captar",
    "captarias": "captar",
    "captarmo": "captar",
    "captarmos": "captar",
    "captará": "captar",
    "captarás": "captar",
    "captarão": "captar",
    "captaríamos": "captar",
    "captaríeis": "captar",
    "captas": "captar",
    "captasse": "captar",
    "captassem": "captar",
    "captasses": "captar",
    "captaste": "captar",
    "captastes": "captar",
    "captava": "captar",
    "captavam": "captar",
    "captavas": "captar",
    "captações": "captação",
    "capte": "captar",
    "captei": "captar",
    "capteis": "captar",
    "captem": "captar",
    "captemo": "captar",
    "captemos": "captar",
    "captes": "captar",
    "capto": "captar",
    "captora": "captor",
    "captoras": "captor",
    "captores": "captor",
    "captou": "captar",
    "captura": "capturar",
    "capturada": "capturar",
    "capturadas": "capturar",
    "capturado": "capturar",
    "capturadora": "capturador",
    "capturadoras": "capturador",
    "capturadores": "capturador",
    "capturados": "capturar",
    "capturai": "capturar",
    "capturais": "capturar",
    "capturam": "capturar",
    "capturamo": "capturar",
    "capturamos": "capturar",
    "capturando": "capturar",
    "capturara": "capturar",
    "capturaram": "capturar",
    "capturaras": "capturar",
    "capturarde": "capturar",
    "capturardes": "capturar",
    "capturare": "capturar",
    "capturarei": "capturar",
    "capturareis": "capturar",
    "capturarem": "capturar",
    "capturaremos": "capturar",
    "capturares": "capturar",
    "capturaria": "capturar",
    "capturariam": "capturar",
    "capturarias": "capturar",
    "capturarmo": "capturar",
    "capturarmos": "capturar",
    "capturará": "capturar",
    "capturarás": "capturar",
    "capturarão": "capturar",
    "capturaríamos": "capturar",
    "capturaríeis": "capturar",
    "capturas": "capturar",
    "capturasse": "capturar",
    "capturassem": "capturar",
    "capturasses": "capturar",
    "capturaste": "capturar",
    "capturastes": "capturar",
    "capturava": "capturar",
    "capturavam": "capturar",
    "capturavas": "capturar",
    "capture": "capturar",
    "capturei": "capturar",
    "captureis": "capturar",
    "capturem": "capturar",
    "capturemo": "capturar",
    "capturemos": "capturar",
    "captures": "capturar",
    "capturo": "capturar",
    "capturou": "capturar",
    "capturá": "capturar",
    "capturámo": "capturar",
    "capturámos": "capturar",
    "capturáramo": "capturar",
    "capturáramos": "capturar",
    "capturárei": "capturar",
    "capturáreis": "capturar",
    "capturásseis": "capturar",
    "capturássemos": "capturar",
    "capturávamo": "capturar",
    "capturávamos": "capturar",
    "capturávei": "capturar",
    "capturáveis": "capturável",
    "captá": "captar",
    "captámo": "captar",
    "captámos": "captar",
    "captáramo": "captar",
    "captáramos": "captar",
    "captárei": "captar",
    "captáreis": "captar",
    "captásseis": "captar",
    "captássemos": "captar",
    "captávamo": "captar",
    "captávamos": "captar",
    "captávei": "captar",
    "captáveis": "captável",
    "capucha": "capucho",
    "capuchada": "capuchar",
    "capuchadas": "capuchar",
    "capuchado": "capuchar",
    "capuchados": "capuchar",
    "capuchai": "capuchar",
    "capuchais": "capuchar",
    "capucham": "capuchar",
    "capuchamo": "capuchar",
    "capuchamos": "capuchar",
    "capuchando": "capuchar",
    "capuchara": "capuchar",
    "capucharam": "capuchar",
    "capucharas": "capuchar",
    "capucharde": "capuchar",
    "capuchardes": "capuchar",
    "capuchare": "capuchar",
    "capucharei": "capuchar",
    "capuchareis": "capuchar",
    "capucharem": "capuchar",
    "capucharemos": "capuchar",
    "capuchares": "capuchar",
    "capucharia": "capuchar",
    "capuchariam": "capuchar",
    "capucharias": "capuchar",
    "capucharmo": "capuchar",
    "capucharmos": "capuchar",
    "capuchará": "capuchar",
    "capucharás": "capuchar",
    "capucharão": "capuchar",
    "capucharíamos": "capuchar",
    "capucharíeis": "capuchar",
    "capuchas": "capucho",
    "capuchasse": "capuchar",
    "capuchassem": "capuchar",
    "capuchasses": "capuchar",
    "capuchaste": "capuchar",
    "capuchastes": "capuchar",
    "capuchava": "capuchar",
    "capuchavam": "capuchar",
    "capuchavas": "capuchar",
    "capuche": "capuchar",
    "capuchei": "capuchar",
    "capucheira": "capucheiro",
    "capucheiras": "capucheiro",
    "capucheiros": "capucheiro",
    "capucheis": "capuchar",
    "capuchem": "capuchar",
    "capuchemo": "capuchar",
    "capuchemos": "capuchar",
    "capuches": "capuchar",
    "capuchinha": "capuchinho",
    "capuchinhas": "capuchinho",
    "capuchinhos": "capuchinho",
    "capucho": "capuchar",
    "capuchos": "capucho",
    "capuchou": "capuchar",
    "capuchá": "capuchar",
    "capuchámo": "capuchar",
    "capuchámos": "capuchar",
    "capucháramo": "capuchar",
    "capucháramos": "capuchar",
    "capuchárei": "capuchar",
    "capucháreis": "capuchar",
    "capuchásseis": "capuchar",
    "capuchássemos": "capuchar",
    "capuchávamo": "capuchar",
    "capuchávamos": "capuchar",
    "capuchávei": "capuchar",
    "capucháveis": "capuchar",
    "capulanas": "capulana",
    "capulhos": "capulho",
    "capuzes": "capuz",
    "capá": "capar",
    "capámo": "capar",
    "capámos": "capar",
    "capáramo": "capar",
    "capáramos": "capar",
    "capárei": "capar",
    "capáreis": "capar",
    "capásseis": "capar",
    "capássemos": "capar",
    "capávamo": "capar",
    "capávamos": "capar",
    "capávei": "capar",
    "capáveis": "capar",
    "capítulas": "capítula",
    "capítulos": "capítulo",
    "capôs": "capô",
    "capões": "capão",
    "caqueada": "caquear",
    "caqueadas": "caquear",
    "caqueado": "caquear",
    "caqueados": "caquear",
    "caqueai": "caquear",
    "caqueais": "caquear",
    "caqueamo": "caquear",
    "caqueamos": "caquear",
    "caqueando": "caquear",
    "caqueara": "caquear",
    "caquearam": "caquear",
    "caquearas": "caquear",
    "caquearde": "caquear",
    "caqueardes": "caquear",
    "caqueare": "caquear",
    "caquearei": "caquear",
    "caqueareis": "caquear",
    "caquearem": "caquear",
    "caquearemos": "caquear",
    "caqueares": "caquear",
    "caquearia": "caquear",
    "caqueariam": "caquear",
    "caquearias": "caquear",
    "caquearmo": "caquear",
    "caquearmos": "caquear",
    "caqueará": "caquear",
    "caquearás": "caquear",
    "caquearão": "caquear",
    "caquearíamos": "caquear",
    "caquearíeis": "caquear",
    "caqueasse": "caquear",
    "caqueassem": "caquear",
    "caqueasses": "caquear",
    "caqueaste": "caquear",
    "caqueastes": "caquear",
    "caqueava": "caquear",
    "caqueavam": "caquear",
    "caqueavas": "caquear",
    "caqueei": "caquear",
    "caqueeis": "caquear",
    "caqueemo": "caquear",
    "caqueemos": "caquear",
    "caqueia": "caquear",
    "caqueiam": "caquear",
    "caqueias": "caquear",
    "caqueie": "caquear",
    "caqueiem": "caquear",
    "caqueies": "caquear",
    "caqueio": "caquear",
    "caqueiradas": "caqueirada",
    "caqueiros": "caqueiro",
    "caqueou": "caquear",
    "caquexias": "caquexia",
    "caqueá": "caquear",
    "caqueámo": "caquear",
    "caqueámos": "caquear",
    "caqueáramo": "caquear",
    "caqueáramos": "caquear",
    "caqueárei": "caquear",
    "caqueáreis": "caquear",
    "caqueásseis": "caquear",
    "caqueássemos": "caquear",
    "caqueávamo": "caquear",
    "caqueávamos": "caquear",
    "caqueávei": "caquear",
    "caqueáveis": "caquear",
    "caquinha": "caca",
    "caquinhas": "caca",
    "caquis": "caqui",
    "caquita": "caca",
    "caquitas": "caca",
    "caquizeiros": "caquizeiro",
    "caquéctica": "caquéctico",
    "caquécticas": "caquéctico",
    "caquécticos": "caquéctico",
    "cara": "caro",
    "carabinadas": "carabinada",
    "carabinas": "carabina",
    "carabineiros": "carabineiro",
    "carabídeos": "carabídeo",
    "caracais": "caracal",
    "caracarás": "caracará",
    "caracola": "caracolar",
    "caracolada": "caracolar",
    "caracoladas": "caracolar",
    "caracolado": "caracolar",
    "caracolados": "caracolar",
    "caracolai": "caracolar",
    "caracolais": "caracolar",
    "caracolam": "caracolar",
    "caracolamo": "caracolar",
    "caracolamos": "caracolar",
    "caracolando": "caracolar",
    "caracolara": "caracolar",
    "caracolaram": "caracolar",
    "caracolaras": "caracolar",
    "caracolardes": "caracolar",
    "caracolarei": "caracolar",
    "caracolareis": "caracolar",
    "caracolarem": "caracolar",
    "caracolaremos": "caracolar",
    "caracolares": "caracolar",
    "caracolaria": "caracolar",
    "caracolariam": "caracolar",
    "caracolarias": "caracolar",
    "caracolarmo": "caracolar",
    "caracolarmos": "caracolar",
    "caracolará": "caracolar",
    "caracolarás": "caracolar",
    "caracolarão": "caracolar",
    "caracolaríamos": "caracolar",
    "caracolaríeis": "caracolar",
    "caracolas": "caracolar",
    "caracolasse": "caracolar",
    "caracolassem": "caracolar",
    "caracolasses": "caracolar",
    "caracolaste": "caracolar",
    "caracolastes": "caracolar",
    "caracolava": "caracolar",
    "caracolavam": "caracolar",
    "caracolavas": "caracolar",
    "caracole": "caracolar",
    "caracoleada": "caracolear",
    "caracoleadas": "caracolear",
    "caracoleado": "caracolear",
    "caracoleados": "caracolear",
    "caracoleai": "caracolear",
    "caracoleais": "caracolear",
    "caracoleamo": "caracolear",
    "caracoleamos": "caracolear",
    "caracoleando": "caracolear",
    "caracoleara": "caracolear",
    "caracolearam": "caracolear",
    "caracolearas": "caracolear",
    "caracoleardes": "caracolear",
    "caracolearei": "caracolear",
    "caracoleareis": "caracolear",
    "caracolearem": "caracolear",
    "caracolearemos": "caracolear",
    "caracoleares": "caracolear",
    "caracolearia": "caracolear",
    "caracoleariam": "caracolear",
    "caracolearias": "caracolear",
    "caracolearmo": "caracolear",
    "caracolearmos": "caracolear",
    "caracoleará": "caracolear",
    "caracolearás": "caracolear",
    "caracolearão": "caracolear",
    "caracolearíamos": "caracolear",
    "caracolearíeis": "caracolear",
    "caracoleasse": "caracolear",
    "caracoleassem": "caracolear",
    "caracoleasses": "caracolear",
    "caracoleaste": "caracolear",
    "caracoleastes": "caracolear",
    "caracoleava": "caracolear",
    "caracoleavam": "caracolear",
    "caracoleavas": "caracolear",
    "caracoleei": "caracolear",
    "caracoleeis": "caracolear",
    "caracoleemo": "caracolear",
    "caracoleemos": "caracolear",
    "caracolei": "caracolar",
    "caracoleia": "caracolear",
    "caracoleiam": "caracolear",
    "caracoleias": "caracolear",
    "caracoleie": "caracolear",
    "caracoleiem": "caracolear",
    "caracoleies": "caracolear",
    "caracoleio": "caracolear",
    "caracoleiros": "caracoleiro",
    "caracoleis": "caracolar",
    "caracolem": "caracolar",
    "caracolemo": "caracolar",
    "caracolemos": "caracolar",
    "caracoleou": "caracolear",
    "caracoles": "caracolar",
    "caracoletas": "caracoleta",
    "caracoleámo": "caracolear",
    "caracoleámos": "caracolear",
    "caracoleáramo": "caracolear",
    "caracoleáramos": "caracolear",
    "caracoleáreis": "caracolear",
    "caracoleásseis": "caracolear",
    "caracoleássemos": "caracolear",
    "caracoleávamo": "caracolear",
    "caracoleávamos": "caracolear",
    "caracoleáveis": "caracolear",
    "caracolo": "caracolar",
    "caracolou": "caracolar",
    "caracolámo": "caracolar",
    "caracolámos": "caracolar",
    "caracoláramo": "caracolar",
    "caracoláramos": "caracolar",
    "caracoláreis": "caracolar",
    "caracolásseis": "caracolar",
    "caracolássemos": "caracolar",
    "caracolávamo": "caracolar",
    "caracolávamos": "caracolar",
    "caracoláveis": "caracolar",
    "caracteres": "caractere",
    "caracteriais": "caracterial",
    "caracteriologias": "caracteriologia",
    "caracteriza": "caracterizar",
    "caracterizada": "caracterizar",
    "caracterizadas": "caracterizar",
    "caracterizado": "caracterizar",
    "caracterizadora": "caracterizador",
    "caracterizadoras": "caracterizador",
    "caracterizadores": "caracterizador",
    "caracterizados": "caracterizar",
    "caracterizai": "caracterizar",
    "caracterizais": "caracterizar",
    "caracterizam": "caracterizar",
    "caracterizamo": "caracterizar",
    "caracterizamos": "caracterizar",
    "caracterizando": "caracterizar",
    "caracterizantes": "caracterizante",
    "caracterizara": "caracterizar",
    "caracterizaram": "caracterizar",
    "caracterizaras": "caracterizar",
    "caracterizarde": "caracterizar",
    "caracterizardes": "caracterizar",
    "caracterizare": "caracterizar",
    "caracterizarei": "caracterizar",
    "caracterizareis": "caracterizar",
    "caracterizarem": "caracterizar",
    "caracterizaremos": "caracterizar",
    "caracterizares": "caracterizar",
    "caracterizaria": "caracterizar",
    "caracterizariam": "caracterizar",
    "caracterizarias": "caracterizar",
    "caracterizarmo": "caracterizar",
    "caracterizarmos": "caracterizar",
    "caracterizará": "caracterizar",
    "caracterizarás": "caracterizar",
    "caracterizarão": "caracterizar",
    "caracterizaríamos": "caracterizar",
    "caracterizaríeis": "caracterizar",
    "caracterizas": "caracterizar",
    "caracterizasse": "caracterizar",
    "caracterizassem": "caracterizar",
    "caracterizasses": "caracterizar",
    "caracterizaste": "caracterizar",
    "caracterizastes": "caracterizar",
    "caracterizava": "caracterizar",
    "caracterizavam": "caracterizar",
    "caracterizavas": "caracterizar",
    "caracterizações": "caracterização",
    "caracterize": "caracterizar",
    "caracterizei": "caracterizar",
    "caracterizeis": "caracterizar",
    "caracterizem": "caracterizar",
    "caracterizemo": "caracterizar",
    "caracterizemos": "caracterizar",
    "caracterizes": "caracterizar",
    "caracterizo": "caracterizar",
    "caracterizou": "caracterizar",
    "caracterizá": "caracterizar",
    "caracterizámo": "caracterizar",
    "caracterizámos": "caracterizar",
    "caracterizáramo": "caracterizar",
    "caracterizáramos": "caracterizar",
    "caracterizárei": "caracterizar",
    "caracterizáreis": "caracterizar",
    "caracterizásseis": "caracterizar",
    "caracterizássemos": "caracterizar",
    "caracterizávamo": "caracterizar",
    "caracterizávamos": "caracterizar",
    "caracterizávei": "caracterizar",
    "caracterizáveis": "caracterizável",
    "caracterológica": "caracterológico",
    "caracterológicas": "caracterológico",
    "caracterológicos": "caracterológico",
    "característica": "característico",
    "características": "característico",
    "característicos": "característico",
    "caraculos": "caraculo",
    "caracóis": "caracol",
    "caradociana": "caradociano",
    "caradocianas": "caradociano",
    "caradocianos": "caradociano",
    "caradriídas": "caradriída",
    "caradriídeos": "caradriídeo",
    "caragos": "carago",
    "carajurus": "carajuru",
    "caraletes": "caralete",
    "caralhos": "caralho",
    "caramancheis": "caramanchel",
    "caramanchões": "caramanchão",
    "carambanos": "carambano",
    "carambinas": "carambina",
    "carambola": "carambolar",
    "carambolada": "carambolar",
    "caramboladas": "carambolar",
    "carambolado": "carambolar",
    "carambolados": "carambolar",
    "carambolai": "carambolar",
    "carambolais": "carambolar",
    "carambolam": "carambolar",
    "carambolamo": "carambolar",
    "carambolamos": "carambolar",
    "carambolando": "carambolar",
    "carambolara": "carambolar",
    "carambolaram": "carambolar",
    "carambolaras": "carambolar",
    "carambolardes": "carambolar",
    "carambolarei": "carambolar",
    "carambolareis": "carambolar",
    "carambolarem": "carambolar",
    "carambolaremos": "carambolar",
    "carambolares": "carambolar",
    "carambolaria": "carambolar",
    "carambolariam": "carambolar",
    "carambolarias": "carambolar",
    "carambolarmo": "carambolar",
    "carambolarmos": "carambolar",
    "carambolará": "carambolar",
    "carambolarás": "carambolar",
    "carambolarão": "carambolar",
    "carambolaríamos": "carambolar",
    "carambolaríeis": "carambolar",
    "carambolas": "carambolar",
    "carambolasse": "carambolar",
    "carambolassem": "carambolar",
    "carambolasses": "carambolar",
    "carambolaste": "carambolar",
    "carambolastes": "carambolar",
    "carambolava": "carambolar",
    "carambolavam": "carambolar",
    "carambolavas": "carambolar",
    "carambole": "carambolar",
    "carambolei": "carambolar",
    "caramboleiras": "caramboleira",
    "caramboleiros": "caramboleiro",
    "caramboleis": "carambolar",
    "carambolem": "carambolar",
    "carambolemo": "carambolar",
    "carambolemos": "carambolar",
    "caramboles": "carambolar",
    "carambolices": "carambolice",
    "carambolins": "carambolim",
    "carambolo": "carambolar",
    "carambolou": "carambolar",
    "carambolámo": "carambolar",
    "carambolámos": "carambolar",
    "caramboláramo": "carambolar",
    "caramboláramos": "carambolar",
    "caramboláreis": "carambolar",
    "carambolásseis": "carambolar",
    "carambolássemos": "carambolar",
    "carambolávamo": "carambolar",
    "carambolávamos": "carambolar",
    "caramboláveis": "carambolar",
    "caramela": "caramelo",
    "caramelas": "caramelo",
    "carameleira": "carameleiro",
    "carameleiras": "carameleiro",
    "carameleiros": "carameleiro",
    "caramelgas": "caramelga",
    "carameliza": "caramelizar",
    "caramelizada": "caramelizar",
    "caramelizadas": "caramelizar",
    "caramelizado": "caramelizar",
    "caramelizados": "caramelizar",
    "caramelizai": "caramelizar",
    "caramelizais": "caramelizar",
    "caramelizam": "caramelizar",
    "caramelizamo": "caramelizar",
    "caramelizamos": "caramelizar",
    "caramelizando": "caramelizar",
    "caramelizara": "caramelizar",
    "caramelizaram": "caramelizar",
    "caramelizaras": "caramelizar",
    "caramelizarde": "caramelizar",
    "caramelizardes": "caramelizar",
    "caramelizare": "caramelizar",
    "caramelizarei": "caramelizar",
    "caramelizareis": "caramelizar",
    "caramelizarem": "caramelizar",
    "caramelizaremos": "caramelizar",
    "caramelizares": "caramelizar",
    "caramelizaria": "caramelizar",
    "caramelizariam": "caramelizar",
    "caramelizarias": "caramelizar",
    "caramelizarmo": "caramelizar",
    "caramelizarmos": "caramelizar",
    "caramelizará": "caramelizar",
    "caramelizarás": "caramelizar",
    "caramelizarão": "caramelizar",
    "caramelizaríamos": "caramelizar",
    "caramelizaríeis": "caramelizar",
    "caramelizas": "caramelizar",
    "caramelizasse": "caramelizar",
    "caramelizassem": "caramelizar",
    "caramelizasses": "caramelizar",
    "caramelizaste": "caramelizar",
    "caramelizastes": "caramelizar",
    "caramelizava": "caramelizar",
    "caramelizavam": "caramelizar",
    "caramelizavas": "caramelizar",
    "caramelizações": "caramelização",
    "caramelize": "caramelizar",
    "caramelizei": "caramelizar",
    "caramelizeis": "caramelizar",
    "caramelizem": "caramelizar",
    "caramelizemo": "caramelizar",
    "caramelizemos": "caramelizar",
    "caramelizes": "caramelizar",
    "caramelizo": "caramelizar",
    "caramelizou": "caramelizar",
    "caramelizá": "caramelizar",
    "caramelizámo": "caramelizar",
    "caramelizámos": "caramelizar",
    "caramelizáramo": "caramelizar",
    "caramelizáramos": "caramelizar",
    "caramelizárei": "caramelizar",
    "caramelizáreis": "caramelizar",
    "caramelizásseis": "caramelizar",
    "caramelizássemos": "caramelizar",
    "caramelizávamo": "caramelizar",
    "caramelizávamos": "caramelizar",
    "caramelizávei": "caramelizar",
    "caramelizáveis": "caramelizar",
    "caramelos": "caramelo",
    "caramilhos": "caramilho",
    "caramilos": "caramilo",
    "caraminholas": "caraminhola",
    "caramoiços": "caramoiço",
    "caramonos": "caramono",
    "caramouços": "caramouço",
    "carampões": "carampão",
    "caramujeiros": "caramujeiro",
    "caramujos": "caramujo",
    "caramulana": "caramulano",
    "caramulanas": "caramulano",
    "caramulanos": "caramulano",
    "caramulos": "caramulo",
    "caramunha": "caramunhar",
    "caramunhada": "caramunhar",
    "caramunhadas": "caramunhar",
    "caramunhado": "caramunhar",
    "caramunhados": "caramunhar",
    "caramunhai": "caramunhar",
    "caramunhais": "caramunhar",
    "caramunham": "caramunhar",
    "caramunhamo": "caramunhar",
    "caramunhamos": "caramunhar",
    "caramunhando": "caramunhar",
    "caramunhara": "caramunhar",
    "caramunharam": "caramunhar",
    "caramunharas": "caramunhar",
    "caramunhardes": "caramunhar",
    "caramunharei": "caramunhar",
    "caramunhareis": "caramunhar",
    "caramunharem": "caramunhar",
    "caramunharemos": "caramunhar",
    "caramunhares": "caramunhar",
    "caramunharia": "caramunhar",
    "caramunhariam": "caramunhar",
    "caramunharias": "caramunhar",
    "caramunharmo": "caramunhar",
    "caramunharmos": "caramunhar",
    "caramunhará": "caramunhar",
    "caramunharás": "caramunhar",
    "caramunharão": "caramunhar",
    "caramunharíamos": "caramunhar",
    "caramunharíeis": "caramunhar",
    "caramunhas": "caramunhar",
    "caramunhasse": "caramunhar",
    "caramunhassem": "caramunhar",
    "caramunhasses": "caramunhar",
    "caramunhaste": "caramunhar",
    "caramunhastes": "caramunhar",
    "caramunhava": "caramunhar",
    "caramunhavam": "caramunhar",
    "caramunhavas": "caramunhar",
    "caramunhe": "caramunhar",
    "caramunhei": "caramunhar",
    "caramunheira": "caramunheiro",
    "caramunheiras": "caramunheiro",
    "caramunheiros": "caramunheiro",
    "caramunheis": "caramunhar",
    "caramunhem": "caramunhar",
    "caramunhemo": "caramunhar",
    "caramunhemos": "caramunhar",
    "caramunhes": "caramunhar",
    "caramunho": "caramunhar",
    "caramunhou": "caramunhar",
    "caramunhámo": "caramunhar",
    "caramunhámos": "caramunhar",
    "caramunháramo": "caramunhar",
    "caramunháramos": "caramunhar",
    "caramunháreis": "caramunhar",
    "caramunhásseis": "caramunhar",
    "caramunhássemos": "caramunhar",
    "caramunhávamo": "caramunhar",
    "caramunhávamos": "caramunhar",
    "caramunháveis": "caramunhar",
    "caramurus": "caramuru",
    "caranchonas": "caranchona",
    "caranchos": "carancho",
    "carangos": "carango",
    "caranguejas": "carangueja",
    "caranguejeiras": "caranguejeira",
    "caranguejeiros": "caranguejeiro",
    "caranguejolas": "caranguejola",
    "caranguejos": "caranguejo",
    "carangídea": "carangídeo",
    "carangídeas": "carangídeo",
    "carangídeos": "carangídeo",
    "caranos": "carano",
    "carantonhas": "carantonha",
    "carapateiros": "carapateiro",
    "carapaus": "carapau",
    "carapaças": "carapaça",
    "carapelas": "carapela",
    "carapeta": "carapetar",
    "carapetada": "carapetar",
    "carapetadas": "carapetar",
    "carapetado": "carapetar",
    "carapetados": "carapetar",
    "carapetai": "carapetar",
    "carapetais": "carapetar",
    "carapetam": "carapetar",
    "carapetamo": "carapetar",
    "carapetamos": "carapetar",
    "carapetando": "carapetar",
    "carapetara": "carapetar",
    "carapetaram": "carapetar",
    "carapetaras": "carapetar",
    "carapetardes": "carapetar",
    "carapetarei": "carapetar",
    "carapetareis": "carapetar",
    "carapetarem": "carapetar",
    "carapetaremos": "carapetar",
    "carapetares": "carapetar",
    "carapetaria": "carapetar",
    "carapetariam": "carapetar",
    "carapetarias": "carapetar",
    "carapetarmo": "carapetar",
    "carapetarmos": "carapetar",
    "carapetará": "carapetar",
    "carapetarás": "carapetar",
    "carapetarão": "carapetar",
    "carapetaríamos": "carapetar",
    "carapetaríeis": "carapetar",
    "carapetas": "carapetar",
    "carapetasse": "carapetar",
    "carapetassem": "carapetar",
    "carapetasses": "carapetar",
    "carapetaste": "carapetar",
    "carapetastes": "carapetar",
    "carapetava": "carapetar",
    "carapetavam": "carapetar",
    "carapetavas": "carapetar",
    "carapete": "carapetar",
    "carapetei": "carapetar",
    "carapeteira": "carapeteiro",
    "carapeteiras": "carapeteiro",
    "carapeteiros": "carapeteiro",
    "carapeteis": "carapetar",
    "carapetem": "carapetar",
    "carapetemo": "carapetar",
    "carapetemos": "carapetar",
    "carapetes": "carapetar",
    "carapeto": "carapetar",
    "carapetos": "carapeto",
    "carapetou": "carapetar",
    "carapetámo": "carapetar",
    "carapetámos": "carapetar",
    "carapetáramo": "carapetar",
    "carapetáramos": "carapetar",
    "carapetáreis": "carapetar",
    "carapetásseis": "carapetar",
    "carapetássemos": "carapetar",
    "carapetávamo": "carapetar",
    "carapetávamos": "carapetar",
    "carapetáveis": "carapetar",
    "carapetões": "carapetão",
    "carapinha": "carapinho",
    "carapinhadas": "carapinhada",
    "carapinhas": "carapinho",
    "carapinheiras": "carapinheira",
    "carapinhos": "carapinho",
    "carapinhuda": "carapinhudo",
    "carapinhudas": "carapinhudo",
    "carapinhudos": "carapinhudo",
    "carapins": "carapim",
    "carapitos": "carapito",
    "carapuceira": "carapuceiro",
    "carapuceiras": "carapuceiro",
    "carapuceiros": "carapuceiro",
    "carapulas": "carapula",
    "carapulos": "carapulo",
    "carapuçadas": "carapuçada",
    "carapuças": "carapuça",
    "carapuços": "carapuço",
    "carapuções": "carapução",
    "caras": "caro",
    "carates": "carate",
    "caratês": "caratê",
    "caravanas": "caravana",
    "caravancerais": "caravancerai",
    "caravaneira": "caravaneiro",
    "caravaneiras": "caravaneiro",
    "caravaneiros": "caravaneiro",
    "caravançarais": "caravançarai",
    "caravas": "carava",
    "caravelas": "caravela",
    "caraveleira": "caraveleiro",
    "caraveleiras": "caraveleiro",
    "caraveleiros": "caraveleiro",
    "caravelhas": "caravelha",
    "caravelhos": "caravelho",
    "caravelões": "caravelão",
    "caraças": "caraça",
    "caraçuda": "caraçudo",
    "caraçudas": "caraçudo",
    "caraçudos": "caraçudo",
    "caraíbas": "caraíba",
    "carbamidas": "carbamida",
    "carbilaminas": "carbilamina",
    "carbites": "carbite",
    "carbonada": "carbonado",
    "carbonadas": "carbonado",
    "carbonadores": "carbonador",
    "carbonados": "carbonado",
    "carbonarismos": "carbonarismo",
    "carbonata": "carbonatar",
    "carbonatada": "carbonatar",
    "carbonatadas": "carbonatar",
    "carbonatado": "carbonatar",
    "carbonatados": "carbonatar",
    "carbonatai": "carbonatar",
    "carbonatais": "carbonatar",
    "carbonatam": "carbonatar",
    "carbonatamo": "carbonatar",
    "carbonatamos": "carbonatar",
    "carbonatando": "carbonatar",
    "carbonatara": "carbonatar",
    "carbonataram": "carbonatar",
    "carbonataras": "carbonatar",
    "carbonatarde": "carbonatar",
    "carbonatardes": "carbonatar",
    "carbonatare": "carbonatar",
    "carbonatarei": "carbonatar",
    "carbonatareis": "carbonatar",
    "carbonatarem": "carbonatar",
    "carbonataremos": "carbonatar",
    "carbonatares": "carbonatar",
    "carbonataria": "carbonatar",
    "carbonatariam": "carbonatar",
    "carbonatarias": "carbonatar",
    "carbonatarmo": "carbonatar",
    "carbonatarmos": "carbonatar",
    "carbonatará": "carbonatar",
    "carbonatarás": "carbonatar",
    "carbonatarão": "carbonatar",
    "carbonataríamos": "carbonatar",
    "carbonataríeis": "carbonatar",
    "carbonatas": "carbonatar",
    "carbonatasse": "carbonatar",
    "carbonatassem": "carbonatar",
    "carbonatasses": "carbonatar",
    "carbonataste": "carbonatar",
    "carbonatastes": "carbonatar",
    "carbonatava": "carbonatar",
    "carbonatavam": "carbonatar",
    "carbonatavas": "carbonatar",
    "carbonate": "carbonatar",
    "carbonatei": "carbonatar",
    "carbonateis": "carbonatar",
    "carbonatem": "carbonatar",
    "carbonatemo": "carbonatar",
    "carbonatemos": "carbonatar",
    "carbonates": "carbonatar",
    "carbonato": "carbonatar",
    "carbonatos": "carbonato",
    "carbonatou": "carbonatar",
    "carbonatá": "carbonatar",
    "carbonatámo": "carbonatar",
    "carbonatámos": "carbonatar",
    "carbonatáramo": "carbonatar",
    "carbonatáramos": "carbonatar",
    "carbonatárei": "carbonatar",
    "carbonatáreis": "carbonatar",
    "carbonatásseis": "carbonatar",
    "carbonatássemos": "carbonatar",
    "carbonatávamo": "carbonatar",
    "carbonatávamos": "carbonatar",
    "carbonatávei": "carbonatar",
    "carbonatáveis": "carbonatar",
    "carbonetos": "carboneto",
    "carbonites": "carbonite",
    "carboniza": "carbonizar",
    "carbonizada": "carbonizar",
    "carbonizadas": "carbonizar",
    "carbonizado": "carbonizar",
    "carbonizadora": "carbonizador",
    "carbonizadoras": "carbonizador",
    "carbonizadores": "carbonizador",
    "carbonizados": "carbonizar",
    "carbonizai": "carbonizar",
    "carbonizais": "carbonizar",
    "carbonizam": "carbonizar",
    "carbonizamo": "carbonizar",
    "carbonizamos": "carbonizar",
    "carbonizando": "carbonizar",
    "carbonizara": "carbonizar",
    "carbonizaram": "carbonizar",
    "carbonizaras": "carbonizar",
    "carbonizarde": "carbonizar",
    "carbonizardes": "carbonizar",
    "carbonizare": "carbonizar",
    "carbonizarei": "carbonizar",
    "carbonizareis": "carbonizar",
    "carbonizarem": "carbonizar",
    "carbonizaremos": "carbonizar",
    "carbonizares": "carbonizar",
    "carbonizaria": "carbonizar",
    "carbonizariam": "carbonizar",
    "carbonizarias": "carbonizar",
    "carbonizarmo": "carbonizar",
    "carbonizarmos": "carbonizar",
    "carbonizará": "carbonizar",
    "carbonizarás": "carbonizar",
    "carbonizarão": "carbonizar",
    "carbonizaríamos": "carbonizar",
    "carbonizaríeis": "carbonizar",
    "carbonizas": "carbonizar",
    "carbonizasse": "carbonizar",
    "carbonizassem": "carbonizar",
    "carbonizasses": "carbonizar",
    "carbonizaste": "carbonizar",
    "carbonizastes": "carbonizar",
    "carbonizava": "carbonizar",
    "carbonizavam": "carbonizar",
    "carbonizavas": "carbonizar",
    "carbonizações": "carbonização",
    "carbonize": "carbonizar",
    "carbonizei": "carbonizar",
    "carbonizeis": "carbonizar",
    "carbonizem": "carbonizar",
    "carbonizemo": "carbonizar",
    "carbonizemos": "carbonizar",
    "carbonizes": "carbonizar",
    "carbonizo": "carbonizar",
    "carbonizou": "carbonizar",
    "carbonizá": "carbonizar",
    "carbonizámo": "carbonizar",
    "carbonizámos": "carbonizar",
    "carbonizáramo": "carbonizar",
    "carbonizáramos": "carbonizar",
    "carbonizárei": "carbonizar",
    "carbonizáreis": "carbonizar",
    "carbonizásseis": "carbonizar",
    "carbonizássemos": "carbonizar",
    "carbonizávamo": "carbonizar",
    "carbonizávamos": "carbonizar",
    "carbonizávei": "carbonizar",
    "carbonizáveis": "carbonizável",
    "carbonos": "carbono",
    "carbonosa": "carbonoso",
    "carbonosas": "carbonoso",
    "carbonosos": "carbonoso",
    "carbonácea": "carbonáceo",
    "carbonáceas": "carbonáceo",
    "carbonáceos": "carbonáceo",
    "carbonária": "carbonário",
    "carbonárias": "carbonário",
    "carbonários": "carbonário",
    "carbonífera": "carbonífero",
    "carboníferas": "carbonífero",
    "carboníferos": "carbonífero",
    "carborundos": "carborundo",
    "carboxilos": "carboxilo",
    "carboxílica": "carboxílico",
    "carboxílicas": "carboxílico",
    "carboxílicos": "carboxílico",
    "carbunculares": "carbuncular",
    "carbunculosa": "carbunculoso",
    "carbunculosas": "carbunculoso",
    "carbunculosos": "carbunculoso",
    "carbura": "carburar",
    "carburada": "carburar",
    "carburadas": "carburar",
    "carburado": "carburar",
    "carburadores": "carburador",
    "carburados": "carburar",
    "carburai": "carburar",
    "carburais": "carburar",
    "carburam": "carburar",
    "carburamo": "carburar",
    "carburamos": "carburar",
    "carburando": "carburar",
    "carburantes": "carburante",
    "carburara": "carburar",
    "carburaram": "carburar",
    "carburaras": "carburar",
    "carburardes": "carburar",
    "carburarei": "carburar",
    "carburareis": "carburar",
    "carburarem": "carburar",
    "carburaremos": "carburar",
    "carburares": "carburar",
    "carburaria": "carburar",
    "carburariam": "carburar",
    "carburarias": "carburar",
    "carburarmo": "carburar",
    "carburarmos": "carburar",
    "carburará": "carburar",
    "carburarás": "carburar",
    "carburarão": "carburar",
    "carburaríamos": "carburar",
    "carburaríeis": "carburar",
    "carburas": "carburar",
    "carburasse": "carburar",
    "carburassem": "carburar",
    "carburasses": "carburar",
    "carburaste": "carburar",
    "carburastes": "carburar",
    "carburava": "carburar",
    "carburavam": "carburar",
    "carburavas": "carburar",
    "carburações": "carburação",
    "carbure": "carburar",
    "carburei": "carburar",
    "carbureis": "carburar",
    "carburem": "carburar",
    "carburemo": "carburar",
    "carburemos": "carburar",
    "carbures": "carburar",
    "carburetos": "carbureto",
    "carburo": "carburar",
    "carburou": "carburar",
    "carburámo": "carburar",
    "carburámos": "carburar",
    "carburáramo": "carburar",
    "carburáramos": "carburar",
    "carburáreis": "carburar",
    "carburásseis": "carburar",
    "carburássemos": "carburar",
    "carburávamo": "carburar",
    "carburávamos": "carburar",
    "carburáveis": "carburar",
    "carbâmica": "carbâmico",
    "carbâmicas": "carbâmico",
    "carbâmicos": "carbâmico",
    "carbónea": "carbóneo",
    "carbóneas": "carbóneo",
    "carbóneos": "carbóneo",
    "carbónica": "carbónico",
    "carbónicas": "carbónico",
    "carbónicos": "carbónico",
    "carbúnculos": "carbúnculo",
    "carcalhotas": "carcalhota",
    "carcamanos": "carcamano",
    "carcaneis": "carcanel",
    "carcavelenses": "carcavelense",
    "carcaças": "carcaça",
    "carcaçinha": "carcaça",
    "carcaçinhas": "carcaça",
    "carcaçita": "carcaça",
    "carcaçitas": "carcaça",
    "carceis": "carcel",
    "carcelas": "carcela",
    "carceragens": "carceragem",
    "carcereira": "carcereiro",
    "carcereiras": "carcereiro",
    "carcereiros": "carcereiro",
    "carcerulares": "carcerular",
    "carcerária": "carcerário",
    "carcerárias": "carcerário",
    "carcerários": "carcerário",
    "carcinogénea": "carcinogéneo",
    "carcinogéneas": "carcinogéneo",
    "carcinogéneos": "carcinogéneo",
    "carcinologias": "carcinologia",
    "carcinologistas": "carcinologista",
    "carcinomas": "carcinoma",
    "carcinomatosa": "carcinomatoso",
    "carcinomatosas": "carcinomatoso",
    "carcinomatosos": "carcinomatoso",
    "carcinoses": "carcinose",
    "carcinóides": "carcinóide",
    "carcolés": "carcolé",
    "carcoma": "carcomer",
    "carcomais": "carcomer",
    "carcomam": "carcomer",
    "carcomamo": "carcomer",
    "carcomamos": "carcomer",
    "carcomas": "carcomer",
    "carcome": "carcomer",
    "carcomei": "carcomer",
    "carcomeis": "carcomer",
    "carcomem": "carcomer",
    "carcomemo": "carcomer",
    "carcomemos": "carcomer",
    "carcomendo": "carcomer",
    "carcomera": "carcomer",
    "carcomeram": "carcomer",
    "carcomeras": "carcomer",
    "carcomerde": "carcomer",
    "carcomerdes": "carcomer",
    "carcomere": "carcomer",
    "carcomerei": "carcomer",
    "carcomereis": "carcomer",
    "carcomerem": "carcomer",
    "carcomeremos": "carcomer",
    "carcomeres": "carcomer",
    "carcomeria": "carcomer",
    "carcomeriam": "carcomer",
    "carcomerias": "carcomer",
    "carcomermo": "carcomer",
    "carcomermos": "carcomer",
    "carcomerá": "carcomer",
    "carcomerás": "carcomer",
    "carcomerão": "carcomer",
    "carcomeríamos": "carcomer",
    "carcomeríeis": "carcomer",
    "carcomes": "carcomer",
    "carcomesse": "carcomer",
    "carcomessem": "carcomer",
    "carcomesses": "carcomer",
    "carcomeste": "carcomer",
    "carcomestes": "carcomer",
    "carcomeu": "carcomer",
    "carcomi": "carcomer",
    "carcomia": "carcomer",
    "carcomiam": "carcomer",
    "carcomias": "carcomer",
    "carcomida": "carcomer",
    "carcomidas": "carcomer",
    "carcomido": "carcomer",
    "carcomidos": "carcomer",
    "carcomo": "carcomer",
    "carcomê": "carcomer",
    "carcomêramo": "carcomer",
    "carcomêramos": "carcomer",
    "carcomêrei": "carcomer",
    "carcomêreis": "carcomer",
    "carcomêsseis": "carcomer",
    "carcomêssemos": "carcomer",
    "carcomíamo": "carcomer",
    "carcomíamos": "carcomer",
    "carcomíei": "carcomer",
    "carcomíeis": "carcomer",
    "carcáses": "carcás",
    "carcérulas": "carcérula",
    "carcérulos": "carcérulo",
    "carcões": "carcão",
    "carda": "cardar",
    "cardada": "cardar",
    "cardadas": "cardar",
    "cardadeira": "cardador",
    "cardadeiras": "cardador",
    "cardado": "cardar",
    "cardadora": "cardador",
    "cardadoras": "cardador",
    "cardadores": "cardador",
    "cardados": "cardar",
    "cardaduras": "cardadura",
    "cardagens": "cardagem",
    "cardai": "cardar",
    "cardais": "cardar",
    "cardalejas": "cardaleja",
    "cardam": "cardar",
    "cardamo": "cardar",
    "cardamomos": "cardamomo",
    "cardamos": "cardar",
    "cardanais": "cardanal",
    "cardando": "cardar",
    "cardanhas": "cardanha",
    "cardanheira": "cardanheiro",
    "cardanheiras": "cardanheiro",
    "cardanheiros": "cardanheiro",
    "cardara": "cardar",
    "cardaram": "cardar",
    "cardaras": "cardar",
    "cardarde": "cardar",
    "cardardes": "cardar",
    "cardare": "cardar",
    "cardarei": "cardar",
    "cardareis": "cardar",
    "cardarem": "cardar",
    "cardaremos": "cardar",
    "cardares": "cardar",
    "cardaria": "cardar",
    "cardariam": "cardar",
    "cardarias": "cardar",
    "cardarmo": "cardar",
    "cardarmos": "cardar",
    "cardará": "cardar",
    "cardarás": "cardar",
    "cardarão": "cardar",
    "cardaríamos": "cardar",
    "cardaríeis": "cardar",
    "cardas": "cardar",
    "cardasse": "cardar",
    "cardassem": "cardar",
    "cardasses": "cardar",
    "cardaste": "cardar",
    "cardastes": "cardar",
    "cardava": "cardar",
    "cardavam": "cardar",
    "cardavas": "cardar",
    "cardazolas": "cardazola",
    "cardazóis": "cardazol",
    "cardaços": "cardaço",
    "cardações": "cardação",
    "carde": "cardar",
    "cardeada": "cardear",
    "cardeadas": "cardear",
    "cardeado": "cardear",
    "cardeados": "cardear",
    "cardeai": "cardear",
    "cardeais": "cardear",
    "cardealinas": "cardealina",
    "cardeamo": "cardear",
    "cardeamos": "cardear",
    "cardeando": "cardear",
    "cardeara": "cardear",
    "cardearam": "cardear",
    "cardearas": "cardear",
    "cardearde": "cardear",
    "cardeardes": "cardear",
    "cardeare": "cardear",
    "cardearei": "cardear",
    "cardeareis": "cardear",
    "cardearem": "cardear",
    "cardearemos": "cardear",
    "cardeares": "cardear",
    "cardearia": "cardear",
    "cardeariam": "cardear",
    "cardearias": "cardear",
    "cardearmo": "cardear",
    "cardearmos": "cardear",
    "cardeará": "cardear",
    "cardearás": "cardear",
    "cardearão": "cardear",
    "cardearíamos": "cardear",
    "cardearíeis": "cardear",
    "cardeasse": "cardear",
    "cardeassem": "cardear",
    "cardeasses": "cardear",
    "cardeaste": "cardear",
    "cardeastes": "cardear",
    "cardeava": "cardear",
    "cardeavam": "cardear",
    "cardeavas": "cardear",
    "cardeei": "cardear",
    "cardeeis": "cardear",
    "cardeemo": "cardear",
    "cardeemos": "cardear",
    "cardei": "cardar",
    "cardeia": "cardear",
    "cardeiam": "cardear",
    "cardeias": "cardear",
    "cardeie": "cardear",
    "cardeiem": "cardear",
    "cardeies": "cardear",
    "cardeio": "cardear",
    "cardeira": "cardeiro",
    "cardeiras": "cardeiro",
    "cardeiros": "cardeiro",
    "cardeis": "cardar",
    "cardem": "cardar",
    "cardemo": "cardar",
    "cardemos": "cardar",
    "cardenhas": "cardenha",
    "cardenhos": "cardenho",
    "cardenilhos": "cardenilho",
    "cardeou": "cardear",
    "cardes": "cardar",
    "cardetes": "cardete",
    "cardeá": "cardear",
    "cardeámo": "cardear",
    "cardeámos": "cardear",
    "cardeáramo": "cardear",
    "cardeáramos": "cardear",
    "cardeárei": "cardear",
    "cardeáreis": "cardear",
    "cardeásseis": "cardear",
    "cardeássemos": "cardear",
    "cardeávamo": "cardear",
    "cardeávamos": "cardear",
    "cardeávei": "cardear",
    "cardeáveis": "cardear",
    "cardiais": "cardial",
    "cardialgias": "cardialgia",
    "cardialgíaca": "cardialgíaco",
    "cardialgíacas": "cardialgíaco",
    "cardialgíacos": "cardialgíaco",
    "cardida": "cardido",
    "cardidas": "cardido",
    "cardidos": "cardido",
    "cardiectasias": "cardiectasia",
    "cardifes": "cardife",
    "cardinais": "cardinal",
    "cardinalados": "cardinalado",
    "cardinalatos": "cardinalato",
    "cardinalistas": "cardinalista",
    "cardinalícia": "cardinalício",
    "cardinalícias": "cardinalício",
    "cardinalícios": "cardinalício",
    "cardins": "cardim",
    "cardinífera": "cardinífero",
    "cardiníferas": "cardinífero",
    "cardiníferos": "cardinífero",
    "cardiografias": "cardiografia",
    "cardiogramas": "cardiograma",
    "cardiográfica": "cardiográfico",
    "cardiográficas": "cardiográfico",
    "cardiográficos": "cardiográfico",
    "cardiologias": "cardiologia",
    "cardiologistas": "cardiologista",
    "cardiométrica": "cardiométrico",
    "cardiométricas": "cardiométrico",
    "cardiométricos": "cardiométrico",
    "cardiopatas": "cardiopata",
    "cardiopatias": "cardiopatia",
    "cardioplegias": "cardioplegia",
    "cardiopulmonara": "cardiopulmonar",
    "cardiopulmonaras": "cardiopulmonar",
    "cardiopulmonares": "cardiopulmonar",
    "cardiopuncturas": "cardiopunctura",
    "cardiopétala": "cardiopétalo",
    "cardiopétalas": "cardiopétalo",
    "cardiopétalos": "cardiopétalo",
    "cardioscopias": "cardioscopia",
    "cardioscópica": "cardioscópico",
    "cardioscópicas": "cardioscópico",
    "cardioscópicos": "cardioscópico",
    "cardioscópios": "cardioscópio",
    "cardiotomias": "cardiotomia",
    "cardiotómica": "cardiotómico",
    "cardiotómicas": "cardiotómico",
    "cardiotómicos": "cardiotómico",
    "cardiotónica": "cardiotónico",
    "cardiotónicas": "cardiotónico",
    "cardiotónicos": "cardiotónico",
    "cardiovasculares": "cardiovascular",
    "cardites": "cardite",
    "cardiálgica": "cardiálgico",
    "cardiálgicas": "cardiálgico",
    "cardiálgicos": "cardiálgico",
    "cardiços": "cardiço",
    "cardiógrafos": "cardiógrafo",
    "cardióides": "cardióide",
    "cardiómetros": "cardiómetro",
    "cardióptera": "cardióptero",
    "cardiópteras": "cardióptero",
    "cardiópteros": "cardióptero",
    "cardiótipos": "cardiótipo",
    "cardo": "cardar",
    "cardométrica": "cardométrico",
    "cardométricas": "cardométrico",
    "cardométricos": "cardométrico",
    "cardos": "cardo",
    "cardou": "cardar",
    "carduce": "carduçar",
    "carducei": "carduçar",
    "carduceis": "carduçar",
    "carducem": "carduçar",
    "carducemo": "carduçar",
    "carducemos": "carduçar",
    "carduces": "carduçar",
    "cardumes": "cardume",
    "carduça": "carduçar",
    "carduçada": "carduçar",
    "carduçadas": "carduçar",
    "carduçado": "carduçar",
    "carduçadores": "carduçador",
    "carduçados": "carduçar",
    "carduçai": "carduçar",
    "carduçais": "carduçar",
    "carduçam": "carduçar",
    "carduçamo": "carduçar",
    "carduçamos": "carduçar",
    "carduçando": "carduçar",
    "carduçara": "carduçar",
    "carduçaram": "carduçar",
    "carduçaras": "carduçar",
    "carduçarde": "carduçar",
    "carduçardes": "carduçar",
    "carduçare": "carduçar",
    "carduçarei": "carduçar",
    "carduçareis": "carduçar",
    "carduçarem": "carduçar",
    "carduçaremos": "carduçar",
    "carduçares": "carduçar",
    "carduçaria": "carduçar",
    "carduçariam": "carduçar",
    "carduçarias": "carduçar",
    "carduçarmo": "carduçar",
    "carduçarmos": "carduçar",
    "carduçará": "carduçar",
    "carduçarás": "carduçar",
    "carduçarão": "carduçar",
    "carduçaríamos": "carduçar",
    "carduçaríeis": "carduçar",
    "carduças": "carduçar",
    "carduçasse": "carduçar",
    "carduçassem": "carduçar",
    "carduçasses": "carduçar",
    "carduçaste": "carduçar",
    "carduçastes": "carduçar",
    "carduçava": "carduçar",
    "carduçavam": "carduçar",
    "carduçavas": "carduçar",
    "carduço": "carduçar",
    "carduçou": "carduçar",
    "carduçá": "carduçar",
    "carduçámo": "carduçar",
    "carduçámos": "carduçar",
    "carduçáramo": "carduçar",
    "carduçáramos": "carduçar",
    "carduçárei": "carduçar",
    "carduçáreis": "carduçar",
    "carduçásseis": "carduçar",
    "carduçássemos": "carduçar",
    "carduçávamo": "carduçar",
    "carduçávamos": "carduçar",
    "carduçávei": "carduçar",
    "carduçáveis": "carduçar",
    "cardá": "cardar",
    "cardámo": "cardar",
    "cardámos": "cardar",
    "cardápios": "cardápio",
    "cardáramo": "cardar",
    "cardáramos": "cardar",
    "cardárei": "cardar",
    "cardáreis": "cardar",
    "cardásseis": "cardar",
    "cardássemos": "cardar",
    "cardávamo": "cardar",
    "cardávamos": "cardar",
    "cardávei": "cardar",
    "cardáveis": "cardar",
    "cardã": "cardão",
    "cardãos": "cardão",
    "cardãs": "cardão",
    "cardíaca": "cardíaco",
    "cardíacas": "cardíaco",
    "cardíacos": "cardíaco",
    "cardídea": "cardídeo",
    "cardídeas": "cardídeo",
    "cardídeos": "cardídeo",
    "cardítica": "cardítico",
    "cardíticas": "cardítico",
    "cardíticos": "cardítico",
    "cardómetros": "cardómetro",
    "careada": "carear",
    "careadas": "carear",
    "careado": "carear",
    "careados": "carear",
    "careai": "carear",
    "careais": "carear",
    "careamo": "carear",
    "careamos": "carear",
    "careando": "carear",
    "careara": "carear",
    "carearam": "carear",
    "carearas": "carear",
    "carearde": "carear",
    "careardes": "carear",
    "careare": "carear",
    "carearei": "carear",
    "careareis": "carear",
    "carearem": "carear",
    "carearemos": "carear",
    "careares": "carear",
    "carearia": "carear",
    "careariam": "carear",
    "carearias": "carear",
    "carearmo": "carear",
    "carearmos": "carear",
    "careará": "carear",
    "carearás": "carear",
    "carearão": "carear",
    "carearíamos": "carear",
    "carearíeis": "carear",
    "careasse": "carear",
    "careassem": "carear",
    "careasses": "carear",
    "careaste": "carear",
    "careastes": "carear",
    "careava": "carear",
    "careavam": "carear",
    "careavas": "carear",
    "careações": "careação",
    "carecas": "careca",
    "carece": "carecer",
    "carecedora": "carecedor",
    "carecedoras": "carecedor",
    "carecedores": "carecedor",
    "carecei": "carecer",
    "careceis": "carecer",
    "carecem": "carecer",
    "carecemo": "carecer",
    "carecemos": "carecer",
    "carecendo": "carecer",
    "carecentes": "carecente",
    "carecera": "carecer",
    "careceram": "carecer",
    "careceras": "carecer",
    "carecerdes": "carecer",
    "carecerei": "carecer",
    "carecereis": "carecer",
    "carecerem": "carecer",
    "careceremos": "carecer",
    "careceres": "carecer",
    "careceria": "carecer",
    "careceriam": "carecer",
    "carecerias": "carecer",
    "carecermo": "carecer",
    "carecermos": "carecer",
    "carecerá": "carecer",
    "carecerás": "carecer",
    "carecerão": "carecer",
    "careceríamos": "carecer",
    "careceríeis": "carecer",
    "careces": "carecer",
    "carecesse": "carecer",
    "carecessem": "carecer",
    "carecesses": "carecer",
    "careceste": "carecer",
    "carecestes": "carecer",
    "careceu": "carecer",
    "careci": "carecer",
    "carecia": "carecer",
    "careciam": "carecer",
    "carecias": "carecer",
    "carecida": "carecido",
    "carecidas": "carecido",
    "carecido": "carecer",
    "carecidos": "carecido",
    "carecimentos": "carecimento",
    "carecêramo": "carecer",
    "carecêramos": "carecer",
    "carecêreis": "carecer",
    "carecêsseis": "carecer",
    "carecêssemos": "carecer",
    "carecíamo": "carecer",
    "carecíamos": "carecer",
    "carecíeis": "carecer",
    "careei": "carear",
    "careeis": "carear",
    "careemo": "carear",
    "careemos": "carear",
    "careia": "carear",
    "careiam": "carear",
    "careias": "carear",
    "careie": "carear",
    "careiem": "carear",
    "careies": "carear",
    "careio": "carear",
    "careira": "careiro",
    "careiras": "careiro",
    "careiros": "careiro",
    "carenada": "carenado",
    "carenadas": "carenado",
    "carenados": "carenado",
    "carenas": "carena",
    "carenciada": "carenciado",
    "carenciadas": "carenciado",
    "carenciados": "carenciado",
    "careniformes": "careniforme",
    "carentes": "carente",
    "careou": "carear",
    "carepas": "carepa",
    "carepenta": "carepento",
    "carepentas": "carepento",
    "carepentos": "carepento",
    "careposa": "careposo",
    "careposas": "careposo",
    "careposos": "careposo",
    "carequinha": "careca",
    "carequinhas": "careca",
    "carequita": "careca",
    "carequitas": "careca",
    "carestias": "carestia",
    "careta": "careto",
    "caretas": "careto",
    "careteira": "careteiro",
    "careteiras": "careteiro",
    "careteiros": "careteiro",
    "caretices": "caretice",
    "caretos": "careto",
    "carezas": "careza",
    "careá": "carear",
    "careámo": "carear",
    "careámos": "carear",
    "careáramo": "carear",
    "careáramos": "carear",
    "careárei": "carear",
    "careáreis": "carear",
    "careásseis": "carear",
    "careássemos": "carear",
    "careávamo": "carear",
    "careávamos": "carear",
    "careávei": "carear",
    "careáveis": "carear",
    "careça": "carecer",
    "careçais": "carecer",
    "careçam": "carecer",
    "careçamo": "carecer",
    "careçamos": "carecer",
    "careças": "carecer",
    "careço": "carecer",
    "carfologias": "carfologia",
    "carfológica": "carfológico",
    "carfológicas": "carfológico",
    "carfológicos": "carfológico",
    "cargas": "carga",
    "cargos": "cargo",
    "cargueira": "cargueiro",
    "cargueiras": "cargueiro",
    "cargueiros": "cargueiro",
    "cargueja": "carguejar",
    "carguejada": "carguejar",
    "carguejadas": "carguejar",
    "carguejado": "carguejar",
    "carguejados": "carguejar",
    "carguejai": "carguejar",
    "carguejais": "carguejar",
    "carguejam": "carguejar",
    "carguejamo": "carguejar",
    "carguejamos": "carguejar",
    "carguejando": "carguejar",
    "carguejara": "carguejar",
    "carguejaram": "carguejar",
    "carguejaras": "carguejar",
    "carguejardes": "carguejar",
    "carguejarei": "carguejar",
    "carguejareis": "carguejar",
    "carguejarem": "carguejar",
    "carguejaremos": "carguejar",
    "carguejares": "carguejar",
    "carguejaria": "carguejar",
    "carguejariam": "carguejar",
    "carguejarias": "carguejar",
    "carguejarmo": "carguejar",
    "carguejarmos": "carguejar",
    "carguejará": "carguejar",
    "carguejarás": "carguejar",
    "carguejarão": "carguejar",
    "carguejaríamos": "carguejar",
    "carguejaríeis": "carguejar",
    "carguejas": "carguejar",
    "carguejasse": "carguejar",
    "carguejassem": "carguejar",
    "carguejasses": "carguejar",
    "carguejaste": "carguejar",
    "carguejastes": "carguejar",
    "carguejava": "carguejar",
    "carguejavam": "carguejar",
    "carguejavas": "carguejar",
    "cargueje": "carguejar",
    "carguejei": "carguejar",
    "carguejeis": "carguejar",
    "carguejem": "carguejar",
    "carguejemo": "carguejar",
    "carguejemos": "carguejar",
    "carguejes": "carguejar",
    "carguejo": "carguejar",
    "carguejou": "carguejar",
    "carguejámo": "carguejar",
    "carguejámos": "carguejar",
    "carguejáramo": "carguejar",
    "carguejáramos": "carguejar",
    "carguejáreis": "carguejar",
    "carguejásseis": "carguejar",
    "carguejássemos": "carguejar",
    "carguejávamo": "carguejar",
    "carguejávamos": "carguejar",
    "carguejáveis": "carguejar",
    "caria": "cariar",
    "cariada": "cariar",
    "cariadas": "cariar",
    "cariado": "cariar",
    "cariados": "cariar",
    "cariai": "cariar",
    "cariais": "cariar",
    "cariam": "cariar",
    "cariamo": "cariar",
    "cariamos": "cariar",
    "cariando": "cariar",
    "cariara": "cariar",
    "cariaram": "cariar",
    "cariaras": "cariar",
    "cariardes": "cariar",
    "cariarei": "cariar",
    "cariareis": "cariar",
    "cariarem": "cariar",
    "cariaremos": "cariar",
    "cariares": "cariar",
    "cariaria": "cariar",
    "cariariam": "cariar",
    "cariarias": "cariar",
    "cariarmo": "cariar",
    "cariarmos": "cariar",
    "cariará": "cariar",
    "cariarás": "cariar",
    "cariarão": "cariar",
    "cariaríamos": "cariar",
    "cariaríeis": "cariar",
    "carias": "cariar",
    "cariasse": "cariar",
    "cariassem": "cariar",
    "cariasses": "cariar",
    "cariaste": "cariar",
    "cariastes": "cariar",
    "cariava": "cariar",
    "cariavam": "cariar",
    "cariavas": "cariar",
    "caribdes": "caribde",
    "caricata": "caricato",
    "caricatas": "caricato",
    "caricatos": "caricato",
    "caricatura": "caricaturar",
    "caricaturada": "caricaturar",
    "caricaturadas": "caricaturar",
    "caricaturado": "caricaturar",
    "caricaturados": "caricaturar",
    "caricaturai": "caricaturar",
    "caricaturais": "caricaturar",
    "caricaturam": "caricaturar",
    "caricaturamo": "caricaturar",
    "caricaturamos": "caricaturar",
    "caricaturando": "caricaturar",
    "caricaturara": "caricaturar",
    "caricaturaram": "caricaturar",
    "caricaturaras": "caricaturar",
    "caricaturarde": "caricaturar",
    "caricaturardes": "caricaturar",
    "caricaturare": "caricaturar",
    "caricaturarei": "caricaturar",
    "caricaturareis": "caricaturar",
    "caricaturarem": "caricaturar",
    "caricaturaremos": "caricaturar",
    "caricaturares": "caricaturar",
    "caricaturaria": "caricaturar",
    "caricaturariam": "caricaturar",
    "caricaturarias": "caricaturar",
    "caricaturarmo": "caricaturar",
    "caricaturarmos": "caricaturar",
    "caricaturará": "caricaturar",
    "caricaturarás": "caricaturar",
    "caricaturarão": "caricaturar",
    "caricaturaríamos": "caricaturar",
    "caricaturaríeis": "caricaturar",
    "caricaturas": "caricaturar",
    "caricaturasse": "caricaturar",
    "caricaturassem": "caricaturar",
    "caricaturasses": "caricaturar",
    "caricaturaste": "caricaturar",
    "caricaturastes": "caricaturar",
    "caricaturava": "caricaturar",
    "caricaturavam": "caricaturar",
    "caricaturavas": "caricaturar",
    "caricature": "caricaturar",
    "caricaturei": "caricaturar",
    "caricatureis": "caricaturar",
    "caricaturem": "caricaturar",
    "caricaturemo": "caricaturar",
    "caricaturemos": "caricaturar",
    "caricatures": "caricaturar",
    "caricaturistas": "caricaturista",
    "caricaturiza": "caricaturizar",
    "caricaturizada": "caricaturizar",
    "caricaturizadas": "caricaturizar",
    "caricaturizado": "caricaturizar",
    "caricaturizados": "caricaturizar",
    "caricaturizai": "caricaturizar",
    "caricaturizais": "caricaturizar",
    "caricaturizam": "caricaturizar",
    "caricaturizamo": "caricaturizar",
    "caricaturizamos": "caricaturizar",
    "caricaturizando": "caricaturizar",
    "caricaturizara": "caricaturizar",
    "caricaturizaram": "caricaturizar",
    "caricaturizaras": "caricaturizar",
    "caricaturizarde": "caricaturizar",
    "caricaturizardes": "caricaturizar",
    "caricaturizare": "caricaturizar",
    "caricaturizarei": "caricaturizar",
    "caricaturizareis": "caricaturizar",
    "caricaturizarem": "caricaturizar",
    "caricaturizaremos": "caricaturizar",
    "caricaturizares": "caricaturizar",
    "caricaturizaria": "caricaturizar",
    "caricaturizariam": "caricaturizar",
    "caricaturizarias": "caricaturizar",
    "caricaturizarmo": "caricaturizar",
    "caricaturizarmos": "caricaturizar",
    "caricaturizará": "caricaturizar",
    "caricaturizarás": "caricaturizar",
    "caricaturizarão": "caricaturizar",
    "caricaturizaríamos": "caricaturizar",
    "caricaturizaríeis": "caricaturizar",
    "caricaturizas": "caricaturizar",
    "caricaturizasse": "caricaturizar",
    "caricaturizassem": "caricaturizar",
    "caricaturizasses": "caricaturizar",
    "caricaturizaste": "caricaturizar",
    "caricaturizastes": "caricaturizar",
    "caricaturizava": "caricaturizar",
    "caricaturizavam": "caricaturizar",
    "caricaturizavas": "caricaturizar",
    "caricaturize": "caricaturizar",
    "caricaturizei": "caricaturizar",
    "caricaturizeis": "caricaturizar",
    "caricaturizem": "caricaturizar",
    "caricaturizemo": "caricaturizar",
    "caricaturizemos": "caricaturizar",
    "caricaturizes": "caricaturizar",
    "caricaturizo": "caricaturizar",
    "caricaturizou": "caricaturizar",
    "caricaturizá": "caricaturizar",
    "caricaturizámo": "caricaturizar",
    "caricaturizámos": "caricaturizar",
    "caricaturizáramo": "caricaturizar",
    "caricaturizáramos": "caricaturizar",
    "caricaturizárei": "caricaturizar",
    "caricaturizáreis": "caricaturizar",
    "caricaturizásseis": "caricaturizar",
    "caricaturizássemos": "caricaturizar",
    "caricaturizávamo": "caricaturizar",
    "caricaturizávamos": "caricaturizar",
    "caricaturizávei": "caricaturizar",
    "caricaturizáveis": "caricaturizar",
    "caricaturo": "caricaturar",
    "caricaturou": "caricaturar",
    "caricaturá": "caricaturar",
    "caricaturámo": "caricaturar",
    "caricaturámos": "caricaturar",
    "caricaturáramo": "caricaturar",
    "caricaturáramos": "caricaturar",
    "caricaturárei": "caricaturar",
    "caricaturáreis": "caricaturar",
    "caricaturásseis": "caricaturar",
    "caricaturássemos": "caricaturar",
    "caricaturávamo": "caricaturar",
    "caricaturávamos": "caricaturar",
    "caricaturávei": "caricaturar",
    "caricaturáveis": "caricaturar",
    "caricia": "cariciar",
    "cariciada": "cariciar",
    "cariciadas": "cariciar",
    "cariciado": "cariciar",
    "cariciados": "cariciar",
    "cariciai": "cariciar",
    "cariciais": "cariciar",
    "cariciam": "cariciar",
    "cariciamo": "cariciar",
    "cariciamos": "cariciar",
    "cariciando": "cariciar",
    "cariciara": "cariciar",
    "cariciaram": "cariciar",
    "cariciaras": "cariciar",
    "cariciarde": "cariciar",
    "cariciardes": "cariciar",
    "cariciare": "cariciar",
    "cariciarei": "cariciar",
    "cariciareis": "cariciar",
    "cariciarem": "cariciar",
    "cariciaremos": "cariciar",
    "cariciares": "cariciar",
    "cariciaria": "cariciar",
    "cariciariam": "cariciar",
    "cariciarias": "cariciar",
    "cariciarmo": "cariciar",
    "cariciarmos": "cariciar",
    "cariciará": "cariciar",
    "cariciarás": "cariciar",
    "cariciarão": "cariciar",
    "cariciaríamos": "cariciar",
    "cariciaríeis": "cariciar",
    "caricias": "cariciar",
    "cariciasse": "cariciar",
    "cariciassem": "cariciar",
    "cariciasses": "cariciar",
    "cariciaste": "cariciar",
    "cariciastes": "cariciar",
    "cariciava": "cariciar",
    "cariciavam": "cariciar",
    "cariciavas": "cariciar",
    "caricie": "cariciar",
    "cariciei": "cariciar",
    "caricieis": "cariciar",
    "cariciem": "cariciar",
    "cariciemo": "cariciar",
    "cariciemos": "cariciar",
    "caricies": "cariciar",
    "caricio": "cariciar",
    "cariciosa": "caricioso",
    "cariciosas": "caricioso",
    "cariciosos": "caricioso",
    "cariciou": "cariciar",
    "cariciá": "cariciar",
    "cariciámo": "cariciar",
    "cariciámos": "cariciar",
    "cariciáramo": "cariciar",
    "cariciáramos": "cariciar",
    "cariciárei": "cariciar",
    "cariciáreis": "cariciar",
    "cariciásseis": "cariciar",
    "cariciássemos": "cariciar",
    "cariciávamo": "cariciar",
    "cariciávamos": "cariciar",
    "cariciávei": "cariciar",
    "cariciáveis": "cariciável",
    "caricáceas": "caricácea",
    "caridades": "caridade",
    "caridosa": "caridoso",
    "caridosas": "caridoso",
    "caridosos": "caridoso",
    "carie": "cariar",
    "cariei": "cariar",
    "carieis": "cariar",
    "cariem": "cariar",
    "cariemo": "cariar",
    "cariemos": "cariar",
    "caries": "cariar",
    "carifranza": "carifranzir",
    "carifranzais": "carifranzir",
    "carifranzam": "carifranzir",
    "carifranzamo": "carifranzir",
    "carifranzamos": "carifranzir",
    "carifranzas": "carifranzir",
    "carifranze": "carifranzir",
    "carifranzem": "carifranzir",
    "carifranzes": "carifranzir",
    "carifranzi": "carifranzir",
    "carifranzia": "carifranzir",
    "carifranziam": "carifranzir",
    "carifranzias": "carifranzir",
    "carifranzida": "carifranzir",
    "carifranzidas": "carifranzir",
    "carifranzido": "carifranzir",
    "carifranzidos": "carifranzir",
    "carifranzimo": "carifranzir",
    "carifranzimos": "carifranzir",
    "carifranzindo": "carifranzir",
    "carifranzira": "carifranzir",
    "carifranziram": "carifranzir",
    "carifranziras": "carifranzir",
    "carifranzirdes": "carifranzir",
    "carifranzirei": "carifranzir",
    "carifranzireis": "carifranzir",
    "carifranzirem": "carifranzir",
    "carifranziremos": "carifranzir",
    "carifranzires": "carifranzir",
    "carifranziria": "carifranzir",
    "carifranziriam": "carifranzir",
    "carifranzirias": "carifranzir",
    "carifranzirmo": "carifranzir",
    "carifranzirmos": "carifranzir",
    "carifranzirá": "carifranzir",
    "carifranzirás": "carifranzir",
    "carifranzirão": "carifranzir",
    "carifranziríamos": "carifranzir",
    "carifranziríeis": "carifranzir",
    "carifranzis": "carifranzir",
    "carifranzisse": "carifranzir",
    "carifranzissem": "carifranzir",
    "carifranzisses": "carifranzir",
    "carifranziste": "carifranzir",
    "carifranzistes": "carifranzir",
    "carifranziu": "carifranzir",
    "carifranzo": "carifranzir",
    "carifranzíamo": "carifranzir",
    "carifranzíamos": "carifranzir",
    "carifranzíeis": "carifranzir",
    "carifranzíramo": "carifranzir",
    "carifranzíramos": "carifranzir",
    "carifranzíreis": "carifranzir",
    "carifranzísseis": "carifranzir",
    "carifranzíssemos": "carifranzir",
    "carimba": "carimbar",
    "carimbada": "carimbar",
    "carimbadas": "carimbar",
    "carimbado": "carimbar",
    "carimbadores": "carimbador",
    "carimbados": "carimbar",
    "carimbagens": "carimbagem",
    "carimbai": "carimbar",
    "carimbais": "carimbar",
    "carimbam": "carimbar",
    "carimbamo": "carimbar",
    "carimbamos": "carimbar",
    "carimbando": "carimbar",
    "carimbara": "carimbar",
    "carimbaram": "carimbar",
    "carimbaras": "carimbar",
    "carimbarde": "carimbar",
    "carimbardes": "carimbar",
    "carimbare": "carimbar",
    "carimbarei": "carimbar",
    "carimbareis": "carimbar",
    "carimbarem": "carimbar",
    "carimbaremos": "carimbar",
    "carimbares": "carimbar",
    "carimbaria": "carimbar",
    "carimbariam": "carimbar",
    "carimbarias": "carimbar",
    "carimbarmo": "carimbar",
    "carimbarmos": "carimbar",
    "carimbará": "carimbar",
    "carimbarás": "carimbar",
    "carimbarão": "carimbar",
    "carimbaríamos": "carimbar",
    "carimbaríeis": "carimbar",
    "carimbas": "carimbar",
    "carimbasse": "carimbar",
    "carimbassem": "carimbar",
    "carimbasses": "carimbar",
    "carimbaste": "carimbar",
    "carimbastes": "carimbar",
    "carimbava": "carimbar",
    "carimbavam": "carimbar",
    "carimbavas": "carimbar",
    "carimbe": "carimbar",
    "carimbei": "carimbar",
    "carimbeis": "carimbar",
    "carimbem": "carimbar",
    "carimbemo": "carimbar",
    "carimbemos": "carimbar",
    "carimbes": "carimbar",
    "carimbo": "carimbar",
    "carimbos": "carimbo",
    "carimbou": "carimbar",
    "carimbá": "carimbar",
    "carimbámo": "carimbar",
    "carimbámos": "carimbar",
    "carimbáramo": "carimbar",
    "carimbáramos": "carimbar",
    "carimbárei": "carimbar",
    "carimbáreis": "carimbar",
    "carimbásseis": "carimbar",
    "carimbássemos": "carimbar",
    "carimbávamo": "carimbar",
    "carimbávamos": "carimbar",
    "carimbávei": "carimbar",
    "carimbáveis": "carimbar",
    "carinada": "carinado",
    "carinadas": "carinado",
    "carinados": "carinado",
    "carinais": "carinal",
    "carinas": "carina",
    "carinha": "caro",
    "carinhas": "caro",
    "carinho": "caro",
    "carinhos": "caro",
    "carinhosa": "carinhoso",
    "carinhosas": "carinhoso",
    "carinhosos": "carinhoso",
    "cario": "cariar",
    "cariocaráceas": "cariocarácea",
    "cariocas": "carioca",
    "cariocineses": "cariocinese",
    "cariocácea": "cariocáceo",
    "cariocáceas": "cariocáceo",
    "cariocáceos": "cariocáceo",
    "cariofiladas": "cariofilada",
    "cariofilácea": "cariofiláceo",
    "cariofiláceas": "cariofiláceo",
    "cariofiláceos": "cariofiláceo",
    "cariogamias": "cariogamia",
    "cariogâmica": "cariogâmico",
    "cariogâmicas": "cariogâmico",
    "cariogâmicos": "cariogâmico",
    "cariolinfas": "cariolinfa",
    "cariopses": "cariopse",
    "cariosa": "carioso",
    "cariosas": "carioso",
    "cariosos": "carioso",
    "cariossomos": "cariossomo",
    "cariotecas": "carioteca",
    "cariou": "cariar",
    "caris": "caril",
    "carismas": "carisma",
    "carismática": "carismático",
    "carismáticas": "carismático",
    "carismáticos": "carismático",
    "carita": "caro",
    "caritas": "caro",
    "caritativa": "caritativo",
    "caritativas": "caritativo",
    "caritativos": "caritativo",
    "carito": "caro",
    "caritos": "caro",
    "carizes": "cariz",
    "cariámo": "cariar",
    "cariámos": "cariar",
    "cariáramo": "cariar",
    "cariáramos": "cariar",
    "cariáreis": "cariar",
    "cariásseis": "cariar",
    "cariássemos": "cariar",
    "cariátides": "cariátide",
    "cariávamo": "cariar",
    "cariávamos": "cariar",
    "cariáveis": "cariar",
    "carlingas": "carlinga",
    "carlistas": "carlista",
    "carlotas": "carlota",
    "carlovíngia": "carlovíngio",
    "carlovíngias": "carlovíngio",
    "carlovíngios": "carlovíngio",
    "carlíngia": "carlíngio",
    "carlíngias": "carlíngio",
    "carlíngios": "carlíngio",
    "carmanholas": "carmanhola",
    "carmeada": "carmear",
    "carmeadas": "carmear",
    "carmeado": "carmear",
    "carmeadora": "carmeador",
    "carmeadoras": "carmeador",
    "carmeadores": "carmeador",
    "carmeados": "carmear",
    "carmeai": "carmear",
    "carmeais": "carmear",
    "carmeamo": "carmear",
    "carmeamos": "carmear",
    "carmeando": "carmear",
    "carmeara": "carmear",
    "carmearam": "carmear",
    "carmearas": "carmear",
    "carmearde": "carmear",
    "carmeardes": "carmear",
    "carmeare": "carmear",
    "carmearei": "carmear",
    "carmeareis": "carmear",
    "carmearem": "carmear",
    "carmearemos": "carmear",
    "carmeares": "carmear",
    "carmearia": "carmear",
    "carmeariam": "carmear",
    "carmearias": "carmear",
    "carmearmo": "carmear",
    "carmearmos": "carmear",
    "carmeará": "carmear",
    "carmearás": "carmear",
    "carmearão": "carmear",
    "carmearíamos": "carmear",
    "carmearíeis": "carmear",
    "carmeasse": "carmear",
    "carmeassem": "carmear",
    "carmeasses": "carmear",
    "carmeaste": "carmear",
    "carmeastes": "carmear",
    "carmeava": "carmear",
    "carmeavam": "carmear",
    "carmeavas": "carmear",
    "carmeei": "carmear",
    "carmeeis": "carmear",
    "carmeemo": "carmear",
    "carmeemos": "carmear",
    "carmeia": "carmear",
    "carmeiam": "carmear",
    "carmeias": "carmear",
    "carmeie": "carmear",
    "carmeiem": "carmear",
    "carmeies": "carmear",
    "carmeio": "carmear",
    "carmelinas": "carmelina",
    "carmelitana": "carmelitano",
    "carmelitanas": "carmelitano",
    "carmelitanos": "carmelitano",
    "carmelitas": "carmelita",
    "carmeou": "carmear",
    "carmes": "carme",
    "carmesinada": "carmesinado",
    "carmesinadas": "carmesinado",
    "carmesinados": "carmesinado",
    "carmesins": "carmesim",
    "carmeá": "carmear",
    "carmeámo": "carmear",
    "carmeámos": "carmear",
    "carmeáramo": "carmear",
    "carmeáramos": "carmear",
    "carmeárei": "carmear",
    "carmeáreis": "carmear",
    "carmeásseis": "carmear",
    "carmeássemos": "carmear",
    "carmeávamo": "carmear",
    "carmeávamos": "carmear",
    "carmeávei": "carmear",
    "carmeáveis": "carmear",
    "carmina": "carminar",
    "carminada": "carminar",
    "carminadas": "carminar",
    "carminado": "carminar",
    "carminados": "carminar",
    "carminai": "carminar",
    "carminais": "carminar",
    "carminam": "carminar",
    "carminamo": "carminar",
    "carminamos": "carminar",
    "carminando": "carminar",
    "carminara": "carminar",
    "carminaram": "carminar",
    "carminaras": "carminar",
    "carminarde": "carminar",
    "carminardes": "carminar",
    "carminare": "carminar",
    "carminarei": "carminar",
    "carminareis": "carminar",
    "carminarem": "carminar",
    "carminaremos": "carminar",
    "carminares": "carminar",
    "carminaria": "carminar",
    "carminariam": "carminar",
    "carminarias": "carminar",
    "carminarmo": "carminar",
    "carminarmos": "carminar",
    "carminará": "carminar",
    "carminarás": "carminar",
    "carminarão": "carminar",
    "carminaríamos": "carminar",
    "carminaríeis": "carminar",
    "carminas": "carminar",
    "carminasse": "carminar",
    "carminassem": "carminar",
    "carminasses": "carminar",
    "carminaste": "carminar",
    "carminastes": "carminar",
    "carminativa": "carminativo",
    "carminativas": "carminativo",
    "carminativos": "carminativo",
    "carminava": "carminar",
    "carminavam": "carminar",
    "carminavas": "carminar",
    "carmine": "carminar",
    "carminei": "carminar",
    "carmineis": "carminar",
    "carminem": "carminar",
    "carminemo": "carminar",
    "carminemos": "carminar",
    "carmines": "carminar",
    "carmino": "carminar",
    "carminou": "carminar",
    "carmins": "carmim",
    "carminá": "carminar",
    "carminámo": "carminar",
    "carminámos": "carminar",
    "carmináramo": "carminar",
    "carmináramos": "carminar",
    "carminárei": "carminar",
    "carmináreis": "carminar",
    "carminásseis": "carminar",
    "carminássemos": "carminar",
    "carminávamo": "carminar",
    "carminávamos": "carminar",
    "carminávei": "carminar",
    "carmináveis": "carminar",
    "carmonas": "carmona",
    "carmínea": "carmíneo",
    "carmíneas": "carmíneo",
    "carmíneos": "carmíneo",
    "carna": "carnar",
    "carnada": "carnar",
    "carnadas": "carnar",
    "carnado": "carnar",
    "carnados": "carnar",
    "carnaduras": "carnadura",
    "carnagens": "carnagem",
    "carnai": "carnar",
    "carnais": "carnar",
    "carnalidades": "carnalidade",
    "carnalites": "carnalite",
    "carnaliza": "carnalizar",
    "carnalizada": "carnalizar",
    "carnalizadas": "carnalizar",
    "carnalizado": "carnalizar",
    "carnalizados": "carnalizar",
    "carnalizai": "carnalizar",
    "carnalizais": "carnalizar",
    "carnalizam": "carnalizar",
    "carnalizamo": "carnalizar",
    "carnalizamos": "carnalizar",
    "carnalizando": "carnalizar",
    "carnalizara": "carnalizar",
    "carnalizaram": "carnalizar",
    "carnalizaras": "carnalizar",
    "carnalizarde": "carnalizar",
    "carnalizardes": "carnalizar",
    "carnalizare": "carnalizar",
    "carnalizarei": "carnalizar",
    "carnalizareis": "carnalizar",
    "carnalizarem": "carnalizar",
    "carnalizaremos": "carnalizar",
    "carnalizares": "carnalizar",
    "carnalizaria": "carnalizar",
    "carnalizariam": "carnalizar",
    "carnalizarias": "carnalizar",
    "carnalizarmo": "carnalizar",
    "carnalizarmos": "carnalizar",
    "carnalizará": "carnalizar",
    "carnalizarás": "carnalizar",
    "carnalizarão": "carnalizar",
    "carnalizaríamos": "carnalizar",
    "carnalizaríeis": "carnalizar",
    "carnalizas": "carnalizar",
    "carnalizasse": "carnalizar",
    "carnalizassem": "carnalizar",
    "carnalizasses": "carnalizar",
    "carnalizaste": "carnalizar",
    "carnalizastes": "carnalizar",
    "carnalizava": "carnalizar",
    "carnalizavam": "carnalizar",
    "carnalizavas": "carnalizar",
    "carnalizações": "carnalização",
    "carnalize": "carnalizar",
    "carnalizei": "carnalizar",
    "carnalizeis": "carnalizar",
    "carnalizem": "carnalizar",
    "carnalizemo": "carnalizar",
    "carnalizemos": "carnalizar",
    "carnalizes": "carnalizar",
    "carnalizo": "carnalizar",
    "carnalizou": "carnalizar",
    "carnalizá": "carnalizar",
    "carnalizámo": "carnalizar",
    "carnalizámos": "carnalizar",
    "carnalizáramo": "carnalizar",
    "carnalizáramos": "carnalizar",
    "carnalizárei": "carnalizar",
    "carnalizáreis": "carnalizar",
    "carnalizásseis": "carnalizar",
    "carnalizássemos": "carnalizar",
    "carnalizávamo": "carnalizar",
    "carnalizávamos": "carnalizar",
    "carnalizávei": "carnalizar",
    "carnalizáveis": "carnalizar",
    "carnam": "carnar",
    "carnamo": "carnar",
    "carnamos": "carnar",
    "carnando": "carnar",
    "carnara": "carnar",
    "carnaram": "carnar",
    "carnaras": "carnar",
    "carnarde": "carnar",
    "carnardes": "carnar",
    "carnare": "carnar",
    "carnarei": "carnar",
    "carnareis": "carnar",
    "carnarem": "carnar",
    "carnaremos": "carnar",
    "carnares": "carnar",
    "carnaria": "carnar",
    "carnariam": "carnar",
    "carnarias": "carnar",
    "carnarmo": "carnar",
    "carnarmos": "carnar",
    "carnará": "carnar",
    "carnarás": "carnar",
    "carnarão": "carnar",
    "carnaríamos": "carnar",
    "carnaríeis": "carnar",
    "carnas": "carnar",
    "carnasse": "carnar",
    "carnassem": "carnar",
    "carnasses": "carnar",
    "carnaste": "carnar",
    "carnastes": "carnar",
    "carnaubeiras": "carnaubeira",
    "carnava": "carnar",
    "carnavais": "carnaval",
    "carnavalesca": "carnavalesco",
    "carnavalescas": "carnavalesco",
    "carnavalescos": "carnavalesco",
    "carnavam": "carnar",
    "carnavas": "carnar",
    "carnazes": "carnaz",
    "carnaças": "carnaça",
    "carnações": "carnação",
    "carnaúbas": "carnaúba",
    "carne": "carnar",
    "carneada": "carnear",
    "carneadas": "carnear",
    "carneado": "carnear",
    "carneados": "carnear",
    "carneai": "carnear",
    "carneais": "carnear",
    "carneamo": "carnear",
    "carneamos": "carnear",
    "carneando": "carnear",
    "carneara": "carnear",
    "carnearam": "carnear",
    "carnearas": "carnear",
    "carnearde": "carnear",
    "carneardes": "carnear",
    "carneare": "carnear",
    "carnearei": "carnear",
    "carneareis": "carnear",
    "carnearem": "carnear",
    "carnearemos": "carnear",
    "carneares": "carnear",
    "carnearia": "carnear",
    "carneariam": "carnear",
    "carnearias": "carnear",
    "carnearmo": "carnear",
    "carnearmos": "carnear",
    "carneará": "carnear",
    "carnearás": "carnear",
    "carnearão": "carnear",
    "carnearíamos": "carnear",
    "carnearíeis": "carnear",
    "carneasse": "carnear",
    "carneassem": "carnear",
    "carneasses": "carnear",
    "carneaste": "carnear",
    "carneastes": "carnear",
    "carneava": "carnear",
    "carneavam": "carnear",
    "carneavas": "carnear",
    "carnecoitas": "carnecoita",
    "carneei": "carnear",
    "carneeis": "carnear",
    "carneemo": "carnear",
    "carneemos": "carnear",
    "carnegões": "carnegão",
    "carnei": "carnar",
    "carneia": "carnear",
    "carneiam": "carnear",
    "carneias": "carnear",
    "carneie": "carnear",
    "carneiem": "carnear",
    "carneies": "carnear",
    "carneio": "carnear",
    "carneira": "carneiro",
    "carneiradas": "carneirada",
    "carneiras": "carneiro",
    "carneireira": "carneireiro",
    "carneireiras": "carneireiro",
    "carneireiros": "carneireiro",
    "carneirinho": "carneiro",
    "carneirinhos": "carneiro",
    "carneirito": "carneiro",
    "carneiritos": "carneiro",
    "carneiros": "carneiro",
    "carneis": "carnar",
    "carnem": "carnar",
    "carnemo": "carnar",
    "carnemos": "carnar",
    "carneou": "carnear",
    "carnes": "carne",
    "carnezinha": "carne",
    "carnezinhas": "carne",
    "carnezita": "carne",
    "carnezitas": "carne",
    "carneá": "carnear",
    "carneámo": "carnear",
    "carneámos": "carnear",
    "carneáramo": "carnear",
    "carneáramos": "carnear",
    "carneárei": "carnear",
    "carneáreis": "carnear",
    "carneásseis": "carnear",
    "carneássemos": "carnear",
    "carneávamo": "carnear",
    "carneávamos": "carnear",
    "carneávei": "carnear",
    "carneáveis": "carnear",
    "carnicais": "carnical",
    "carniceira": "carniceiro",
    "carniceiras": "carniceiro",
    "carniceiros": "carniceiro",
    "carnicenta": "carnicento",
    "carnicentas": "carnicento",
    "carnicentos": "carnicento",
    "carnicões": "carnicão",
    "carnifarei": "carnifazer",
    "carnifareis": "carnifazer",
    "carnifaremos": "carnifazer",
    "carnifaria": "carnifazer",
    "carnifariam": "carnifazer",
    "carnifarias": "carnifazer",
    "carnifará": "carnifazer",
    "carnifarás": "carnifazer",
    "carnifarão": "carnifazer",
    "carnifaríamos": "carnifazer",
    "carnifaríeis": "carnifazer",
    "carnifaz": "carnifazer",
    "carnifaze": "carnifazer",
    "carnifazei": "carnifazer",
    "carnifazeis": "carnifazer",
    "carnifazem": "carnifazer",
    "carnifazemo": "carnifazer",
    "carnifazemos": "carnifazer",
    "carnifazendo": "carnifazer",
    "carnifazerde": "carnifazer",
    "carnifazerdes": "carnifazer",
    "carnifazere": "carnifazer",
    "carnifazerem": "carnifazer",
    "carnifazeres": "carnifazer",
    "carnifazermo": "carnifazer",
    "carnifazermos": "carnifazer",
    "carnifazes": "carnifazer",
    "carnifazia": "carnifazer",
    "carnifaziam": "carnifazer",
    "carnifazias": "carnifazer",
    "carnifazê": "carnifazer",
    "carnifazíamo": "carnifazer",
    "carnifazíamos": "carnifazer",
    "carnifazíei": "carnifazer",
    "carnifazíeis": "carnifazer",
    "carnifaça": "carnifazer",
    "carnifaçais": "carnifazer",
    "carnifaçam": "carnifazer",
    "carnifaçamo": "carnifazer",
    "carnifaçamos": "carnifazer",
    "carnifaças": "carnifazer",
    "carnifaço": "carnifazer",
    "carnifeita": "carnifazer",
    "carnifeitas": "carnifazer",
    "carnifeito": "carnifazer",
    "carnifeitos": "carnifazer",
    "carnifez": "carnifazer",
    "carnifi": "carnifazer",
    "carnifica": "carnificar",
    "carnificada": "carnificar",
    "carnificadas": "carnificar",
    "carnificado": "carnificar",
    "carnificados": "carnificar",
    "carnificai": "carnificar",
    "carnificais": "carnificar",
    "carnificam": "carnificar",
    "carnificamo": "carnificar",
    "carnificamos": "carnificar",
    "carnificando": "carnificar",
    "carnificara": "carnificar",
    "carnificaram": "carnificar",
    "carnificaras": "carnificar",
    "carnificarde": "carnificar",
    "carnificardes": "carnificar",
    "carnificare": "carnificar",
    "carnificarei": "carnificar",
    "carnificareis": "carnificar",
    "carnificarem": "carnificar",
    "carnificaremos": "carnificar",
    "carnificares": "carnificar",
    "carnificaria": "carnificar",
    "carnificariam": "carnificar",
    "carnificarias": "carnificar",
    "carnificarmo": "carnificar",
    "carnificarmos": "carnificar",
    "carnificará": "carnificar",
    "carnificarás": "carnificar",
    "carnificarão": "carnificar",
    "carnificaríamos": "carnificar",
    "carnificaríeis": "carnificar",
    "carnificas": "carnificar",
    "carnificasse": "carnificar",
    "carnificassem": "carnificar",
    "carnificasses": "carnificar",
    "carnificaste": "carnificar",
    "carnificastes": "carnificar",
    "carnificava": "carnificar",
    "carnificavam": "carnificar",
    "carnificavas": "carnificar",
    "carnificações": "carnificação",
    "carnificinas": "carnificina",
    "carnifico": "carnificar",
    "carnificou": "carnificar",
    "carnificá": "carnificar",
    "carnificámo": "carnificar",
    "carnificámos": "carnificar",
    "carnificáramo": "carnificar",
    "carnificáramos": "carnificar",
    "carnificárei": "carnificar",
    "carnificáreis": "carnificar",
    "carnificásseis": "carnificar",
    "carnificássemos": "carnificar",
    "carnificávamo": "carnificar",
    "carnificávamos": "carnificar",
    "carnificávei": "carnificar",
    "carnificáveis": "carnificar",
    "carnifique": "carnificar",
    "carnifiquei": "carnificar",
    "carnifiqueis": "carnificar",
    "carnifiquem": "carnificar",
    "carnifiquemo": "carnificar",
    "carnifiquemos": "carnificar",
    "carnifiques": "carnificar",
    "carnifiz": "carnifazer",
    "carnifizemo": "carnifazer",
    "carnifizemos": "carnifazer",
    "carnifizer": "carnifazer",
    "carnifizera": "carnifazer",
    "carnifizeram": "carnifazer",
    "carnifizeras": "carnifazer",
    "carnifizerdes": "carnifazer",
    "carnifizerem": "carnifazer",
    "carnifizeres": "carnifazer",
    "carnifizermos": "carnifazer",
    "carnifizesse": "carnifazer",
    "carnifizessem": "carnifazer",
    "carnifizesses": "carnifazer",
    "carnifizeste": "carnifazer",
    "carnifizestes": "carnifazer",
    "carnifizéramo": "carnifazer",
    "carnifizéramos": "carnifazer",
    "carnifizérei": "carnifazer",
    "carnifizéreis": "carnifazer",
    "carnifizésseis": "carnifazer",
    "carnifizéssemos": "carnifazer",
    "carniformes": "carniforme",
    "carnifá": "carnifazer",
    "carnifê": "carnifazer",
    "carninha": "carne",
    "carninhas": "carne",
    "carnismos": "carnismo",
    "carnita": "carne",
    "carnitas": "carne",
    "carnivorismos": "carnivorismo",
    "carniçarias": "carniçaria",
    "carniças": "carniça",
    "carniçeira": "carniçeiro",
    "carniçeiras": "carniçeiro",
    "carniçeiros": "carniçeiro",
    "carno": "carnar",
    "carnosa": "carnoso",
    "carnosas": "carnoso",
    "carnosidades": "carnosidade",
    "carnosos": "carnoso",
    "carnotites": "carnotite",
    "carnou": "carnar",
    "carnuda": "carnudo",
    "carnudas": "carnudo",
    "carnudos": "carnudo",
    "carná": "carnar",
    "carnámo": "carnar",
    "carnámos": "carnar",
    "carnáramo": "carnar",
    "carnáramos": "carnar",
    "carnárei": "carnar",
    "carnáreis": "carnar",
    "carnásseis": "carnar",
    "carnássemos": "carnar",
    "carnávamo": "carnar",
    "carnávamos": "carnar",
    "carnávei": "carnar",
    "carnáveis": "carnar",
    "carnéolas": "carnéola",
    "carnês": "carnê",
    "carnífices": "carnífice",
    "carnívora": "carnívoro",
    "carnívoras": "carnívoro",
    "carnívoros": "carnívoro",
    "caroca": "carocar",
    "carocada": "carocar",
    "carocadas": "carocar",
    "carocado": "carocar",
    "carocados": "carocar",
    "carocais": "carocar",
    "carocam": "carocar",
    "carocamo": "carocar",
    "carocamos": "carocar",
    "carocando": "carocar",
    "carocara": "carocar",
    "carocaram": "carocar",
    "carocaras": "carocar",
    "carocardes": "carocar",
    "carocarei": "carocar",
    "carocareis": "carocar",
    "carocarem": "carocar",
    "carocaremos": "carocar",
    "carocares": "carocar",
    "carocaria": "carocar",
    "carocariam": "carocar",
    "carocarias": "carocar",
    "carocarmo": "carocar",
    "carocarmos": "carocar",
    "carocará": "carocar",
    "carocarás": "carocar",
    "carocarão": "carocar",
    "carocaríamos": "carocar",
    "carocaríeis": "carocar",
    "carocas": "carocar",
    "carocasse": "carocar",
    "carocassem": "carocar",
    "carocasses": "carocar",
    "carocaste": "carocar",
    "carocastes": "carocar",
    "carocava": "carocar",
    "carocavam": "carocar",
    "carocavas": "carocar",
    "carochas": "carocha",
    "carochinha": "carocha",
    "carochinhas": "carocha",
    "carochita": "carocha",
    "carochitas": "carocha",
    "carochos": "carocho",
    "carocinho": "caroço",
    "carocinhos": "caroço",
    "carocito": "caroço",
    "carocitos": "caroço",
    "caroco": "carocar",
    "carocou": "carocar",
    "carocámo": "carocar",
    "carocámos": "carocar",
    "carocáramo": "carocar",
    "carocáramos": "carocar",
    "carocáreis": "carocar",
    "carocásseis": "carocar",
    "carocássemos": "carocar",
    "carocávamo": "carocar",
    "carocávamos": "carocar",
    "carocáveis": "carocar",
    "carolas": "carola",
    "carolices": "carolice",
    "carolina": "carolino",
    "carolinas": "carolino",
    "carolinos": "carolino",
    "carolins": "carolim",
    "carolismos": "carolismo",
    "carolos": "carolo",
    "carolíngia": "carolíngio",
    "carolíngias": "carolíngio",
    "carolíngios": "carolíngio",
    "caronadas": "caronada",
    "caropas": "caropa",
    "caroque": "carocar",
    "caroquei": "carocar",
    "caroqueis": "carocar",
    "caroquem": "carocar",
    "caroquemos": "carocar",
    "caroques": "carocar",
    "caros": "caro",
    "carotenos": "caroteno",
    "carotes": "carote",
    "carotidiana": "carotidiano",
    "carotidianas": "carotidiano",
    "carotidianos": "carotidiano",
    "carotinemias": "carotinemia",
    "carotinémica": "carotinémico",
    "carotinémicas": "carotinémico",
    "carotinémicos": "carotinémico",
    "carotídea": "carotídeo",
    "carotídeas": "carotídeo",
    "carotídeos": "carotídeo",
    "caroáveis": "caroável",
    "caroçames": "caroçame",
    "caroças": "caroça",
    "caroços": "caroço",
    "caroçuda": "caroçudo",
    "caroçudas": "caroçudo",
    "caroçudos": "caroçudo",
    "carpa": "carpir",
    "carpais": "carpir",
    "carpam": "carpir",
    "carpamo": "carpir",
    "carpamos": "carpir",
    "carpantas": "carpanta",
    "carpanéis": "carpanel",
    "carpas": "carpir",
    "carpe": "carpir",
    "carpeada": "carpear",
    "carpeadas": "carpear",
    "carpeado": "carpear",
    "carpeados": "carpear",
    "carpeaduras": "carpeadura",
    "carpeai": "carpear",
    "carpeais": "carpear",
    "carpeamo": "carpear",
    "carpeamos": "carpear",
    "carpeando": "carpear",
    "carpeara": "carpear",
    "carpearam": "carpear",
    "carpearas": "carpear",
    "carpearde": "carpear",
    "carpeardes": "carpear",
    "carpeare": "carpear",
    "carpearei": "carpear",
    "carpeareis": "carpear",
    "carpearem": "carpear",
    "carpearemos": "carpear",
    "carpeares": "carpear",
    "carpearia": "carpear",
    "carpeariam": "carpear",
    "carpearias": "carpear",
    "carpearmo": "carpear",
    "carpearmos": "carpear",
    "carpeará": "carpear",
    "carpearás": "carpear",
    "carpearão": "carpear",
    "carpearíamos": "carpear",
    "carpearíeis": "carpear",
    "carpeasse": "carpear",
    "carpeassem": "carpear",
    "carpeasses": "carpear",
    "carpeaste": "carpear",
    "carpeastes": "carpear",
    "carpeava": "carpear",
    "carpeavam": "carpear",
    "carpeavas": "carpear",
    "carpeei": "carpear",
    "carpeeis": "carpear",
    "carpeemo": "carpear",
    "carpeemos": "carpear",
    "carpeia": "carpear",
    "carpeiam": "carpear",
    "carpeias": "carpear",
    "carpeie": "carpear",
    "carpeiem": "carpear",
    "carpeies": "carpear",
    "carpeio": "carpear",
    "carpelara": "carpelar",
    "carpelaras": "carpelar",
    "carpelares": "carpelar",
    "carpelas": "carpela",
    "carpelos": "carpelo",
    "carpem": "carpir",
    "carpeou": "carpear",
    "carpes": "carpir",
    "carpetes": "carpete",
    "carpeá": "carpear",
    "carpeámo": "carpear",
    "carpeámos": "carpear",
    "carpeáramo": "carpear",
    "carpeáramos": "carpear",
    "carpeárei": "carpear",
    "carpeáreis": "carpear",
    "carpeásseis": "carpear",
    "carpeássemos": "carpear",
    "carpeávamo": "carpear",
    "carpeávamos": "carpear",
    "carpeávei": "carpear",
    "carpeáveis": "carpear",
    "carpi": "carpir",
    "carpia": "carpir",
    "carpiam": "carpir",
    "carpiana": "carpiano",
    "carpianas": "carpiano",
    "carpianos": "carpiano",
    "carpias": "carpir",
    "carpida": "carpir",
    "carpidas": "carpir",
    "carpideira": "carpidor",
    "carpideiras": "carpidor",
    "carpido": "carpir",
    "carpidora": "carpidor",
    "carpidoras": "carpidor",
    "carpidores": "carpidor",
    "carpidos": "carpir",
    "carpidoura": "carpidor",
    "carpidouras": "carpidor",
    "carpiduras": "carpidura",
    "carpimentos": "carpimento",
    "carpimo": "carpir",
    "carpimos": "carpir",
    "carpindo": "carpir",
    "carpins": "carpim",
    "carpintarias": "carpintaria",
    "carpinteira": "carpinteiro",
    "carpinteirada": "carpinteirar",
    "carpinteiradas": "carpinteirar",
    "carpinteirado": "carpinteirar",
    "carpinteirados": "carpinteirar",
    "carpinteirai": "carpinteirar",
    "carpinteirais": "carpinteirar",
    "carpinteiram": "carpinteirar",
    "carpinteiramo": "carpinteirar",
    "carpinteiramos": "carpinteirar",
    "carpinteirando": "carpinteirar",
    "carpinteirara": "carpinteirar",
    "carpinteiraram": "carpinteirar",
    "carpinteiraras": "carpinteirar",
    "carpinteirarde": "carpinteirar",
    "carpinteirardes": "carpinteirar",
    "carpinteirare": "carpinteirar",
    "carpinteirarei": "carpinteirar",
    "carpinteirareis": "carpinteirar",
    "carpinteirarem": "carpinteirar",
    "carpinteiraremos": "carpinteirar",
    "carpinteirares": "carpinteirar",
    "carpinteiraria": "carpinteirar",
    "carpinteirariam": "carpinteirar",
    "carpinteirarias": "carpinteirar",
    "carpinteirarmo": "carpinteirar",
    "carpinteirarmos": "carpinteirar",
    "carpinteirará": "carpinteirar",
    "carpinteirarás": "carpinteirar",
    "carpinteirarão": "carpinteirar",
    "carpinteiraríamos": "carpinteirar",
    "carpinteiraríeis": "carpinteirar",
    "carpinteiras": "carpinteiro",
    "carpinteirasse": "carpinteirar",
    "carpinteirassem": "carpinteirar",
    "carpinteirasses": "carpinteirar",
    "carpinteiraste": "carpinteirar",
    "carpinteirastes": "carpinteirar",
    "carpinteirava": "carpinteirar",
    "carpinteiravam": "carpinteirar",
    "carpinteiravas": "carpinteirar",
    "carpinteire": "carpinteirar",
    "carpinteirei": "carpinteirar",
    "carpinteireis": "carpinteirar",
    "carpinteirem": "carpinteirar",
    "carpinteiremo": "carpinteirar",
    "carpinteiremos": "carpinteirar",
    "carpinteires": "carpinteirar",
    "carpinteiro": "carpinteirar",
    "carpinteiros": "carpinteiro",
    "carpinteirou": "carpinteirar",
    "carpinteirá": "carpinteirar",
    "carpinteirámo": "carpinteirar",
    "carpinteirámos": "carpinteirar",
    "carpinteiráramo": "carpinteirar",
    "carpinteiráramos": "carpinteirar",
    "carpinteirárei": "carpinteirar",
    "carpinteiráreis": "carpinteirar",
    "carpinteirásseis": "carpinteirar",
    "carpinteirássemos": "carpinteirar",
    "carpinteirávamo": "carpinteirar",
    "carpinteirávamos": "carpinteirar",
    "carpinteirávei": "carpinteirar",
    "carpinteiráveis": "carpinteirar",
    "carpinteja": "carpintejar",
    "carpintejada": "carpintejar",
    "carpintejadas": "carpintejar",
    "carpintejado": "carpintejar",
    "carpintejados": "carpintejar",
    "carpintejai": "carpintejar",
    "carpintejais": "carpintejar",
    "carpintejam": "carpintejar",
    "carpintejamo": "carpintejar",
    "carpintejamos": "carpintejar",
    "carpintejando": "carpintejar",
    "carpintejara": "carpintejar",
    "carpintejaram": "carpintejar",
    "carpintejaras": "carpintejar",
    "carpintejarde": "carpintejar",
    "carpintejardes": "carpintejar",
    "carpintejare": "carpintejar",
    "carpintejarei": "carpintejar",
    "carpintejareis": "carpintejar",
    "carpintejarem": "carpintejar",
    "carpintejaremos": "carpintejar",
    "carpintejares": "carpintejar",
    "carpintejaria": "carpintejar",
    "carpintejariam": "carpintejar",
    "carpintejarias": "carpintejar",
    "carpintejarmo": "carpintejar",
    "carpintejarmos": "carpintejar",
    "carpintejará": "carpintejar",
    "carpintejarás": "carpintejar",
    "carpintejarão": "carpintejar",
    "carpintejaríamos": "carpintejar",
    "carpintejaríeis": "carpintejar",
    "carpintejas": "carpintejar",
    "carpintejasse": "carpintejar",
    "carpintejassem": "carpintejar",
    "carpintejasses": "carpintejar",
    "carpintejaste": "carpintejar",
    "carpintejastes": "carpintejar",
    "carpintejava": "carpintejar",
    "carpintejavam": "carpintejar",
    "carpintejavas": "carpintejar",
    "carpinteje": "carpintejar",
    "carpintejei": "carpintejar",
    "carpintejeis": "carpintejar",
    "carpintejem": "carpintejar",
    "carpintejemo": "carpintejar",
    "carpintejemos": "carpintejar",
    "carpintejes": "carpintejar",
    "carpintejo": "carpintejar",
    "carpintejou": "carpintejar",
    "carpintejá": "carpintejar",
    "carpintejámo": "carpintejar",
    "carpintejámos": "carpintejar",
    "carpintejáramo": "carpintejar",
    "carpintejáramos": "carpintejar",
    "carpintejárei": "carpintejar",
    "carpintejáreis": "carpintejar",
    "carpintejásseis": "carpintejar",
    "carpintejássemos": "carpintejar",
    "carpintejávamo": "carpintejar",
    "carpintejávamos": "carpintejar",
    "carpintejávei": "carpintejar",
    "carpintejáveis": "carpintejar",
    "carpira": "carpir",
    "carpiram": "carpir",
    "carpiras": "carpir",
    "carpirde": "carpir",
    "carpirdes": "carpir",
    "carpire": "carpir",
    "carpirei": "carpir",
    "carpireis": "carpir",
    "carpirem": "carpir",
    "carpiremos": "carpir",
    "carpires": "carpir",
    "carpiria": "carpir",
    "carpiriam": "carpir",
    "carpirias": "carpir",
    "carpirmo": "carpir",
    "carpirmos": "carpir",
    "carpirá": "carpir",
    "carpirás": "carpir",
    "carpirão": "carpir",
    "carpiríamos": "carpir",
    "carpiríeis": "carpir",
    "carpis": "carpir",
    "carpisse": "carpir",
    "carpissem": "carpir",
    "carpisses": "carpir",
    "carpiste": "carpir",
    "carpistes": "carpir",
    "carpiu": "carpir",
    "carpo": "carpir",
    "carpofagias": "carpofagia",
    "carpogenésica": "carpogenésico",
    "carpogenésicas": "carpogenésico",
    "carpogenésicos": "carpogenésico",
    "carpogenética": "carpogenético",
    "carpogenéticas": "carpogenético",
    "carpogenéticos": "carpogenético",
    "carpogéneses": "carpogénese",
    "carpogónica": "carpogónico",
    "carpogónicas": "carpogónico",
    "carpogónicos": "carpogónico",
    "carpogónios": "carpogónio",
    "carpologias": "carpologia",
    "carpológica": "carpológico",
    "carpológicas": "carpológico",
    "carpológicos": "carpológico",
    "carpos": "carpo",
    "carptores": "carptor",
    "carpíamo": "carpir",
    "carpíamos": "carpir",
    "carpíei": "carpir",
    "carpíeis": "carpir",
    "carpíramo": "carpir",
    "carpíramos": "carpir",
    "carpírei": "carpir",
    "carpíreis": "carpir",
    "carpísseis": "carpir",
    "carpíssemos": "carpir",
    "carpófaga": "carpófago",
    "carpófagas": "carpófago",
    "carpófagos": "carpófago",
    "carpófilos": "carpófilo",
    "carpóforos": "carpóforo",
    "carpólitos": "carpólito",
    "carpóspora": "carpósporo",
    "carpósporas": "carpósporo",
    "carpósporos": "carpósporo",
    "carqueja": "carquejar",
    "carquejada": "carquejar",
    "carquejadas": "carquejar",
    "carquejado": "carquejar",
    "carquejados": "carquejar",
    "carquejai": "carquejar",
    "carquejais": "carquejar",
    "carquejam": "carquejar",
    "carquejamo": "carquejar",
    "carquejamos": "carquejar",
    "carquejando": "carquejar",
    "carquejara": "carquejar",
    "carquejaram": "carquejar",
    "carquejaras": "carquejar",
    "carquejardes": "carquejar",
    "carquejarei": "carquejar",
    "carquejareis": "carquejar",
    "carquejarem": "carquejar",
    "carquejaremos": "carquejar",
    "carquejares": "carquejar",
    "carquejaria": "carquejar",
    "carquejariam": "carquejar",
    "carquejarias": "carquejar",
    "carquejarmo": "carquejar",
    "carquejarmos": "carquejar",
    "carquejará": "carquejar",
    "carquejarás": "carquejar",
    "carquejarão": "carquejar",
    "carquejaríamos": "carquejar",
    "carquejaríeis": "carquejar",
    "carquejas": "carquejar",
    "carquejasse": "carquejar",
    "carquejassem": "carquejar",
    "carquejasses": "carquejar",
    "carquejaste": "carquejar",
    "carquejastes": "carquejar",
    "carquejava": "carquejar",
    "carquejavam": "carquejar",
    "carquejavas": "carquejar",
    "carqueje": "carquejar",
    "carquejei": "carquejar",
    "carquejeira": "carquejeiro",
    "carquejeiras": "carquejeiro",
    "carquejeiros": "carquejeiro",
    "carquejeis": "carquejar",
    "carquejem": "carquejar",
    "carquejemo": "carquejar",
    "carquejemos": "carquejar",
    "carquejes": "carquejar",
    "carquejo": "carquejar",
    "carquejou": "carquejar",
    "carquejámo": "carquejar",
    "carquejámos": "carquejar",
    "carquejáramo": "carquejar",
    "carquejáramos": "carquejar",
    "carquejáreis": "carquejar",
    "carquejásseis": "carquejar",
    "carquejássemos": "carquejar",
    "carquejávamo": "carquejar",
    "carquejávamos": "carquejar",
    "carquejáveis": "carquejar",
    "carquilhas": "carquilha",
    "carracas": "carraca",
    "carrachos": "carracho",
    "carracinhas": "carracinha",
    "carradas": "carrada",
    "carrajós": "carrajó",
    "carrancas": "carranca",
    "carranchos": "carrancho",
    "carrancuda": "carrancudo",
    "carrancudas": "carrancudo",
    "carrancudos": "carrancudo",
    "carranhas": "carranha",
    "carranhosa": "carranhoso",
    "carranhosas": "carranhoso",
    "carranhosos": "carranhoso",
    "carranqueada": "carranquear",
    "carranqueadas": "carranquear",
    "carranqueado": "carranquear",
    "carranqueados": "carranquear",
    "carranqueai": "carranquear",
    "carranqueais": "carranquear",
    "carranqueamo": "carranquear",
    "carranqueamos": "carranquear",
    "carranqueando": "carranquear",
    "carranqueara": "carranquear",
    "carranquearam": "carranquear",
    "carranquearas": "carranquear",
    "carranqueardes": "carranquear",
    "carranquearei": "carranquear",
    "carranqueareis": "carranquear",
    "carranquearem": "carranquear",
    "carranquearemos": "carranquear",
    "carranqueares": "carranquear",
    "carranquearia": "carranquear",
    "carranqueariam": "carranquear",
    "carranquearias": "carranquear",
    "carranquearmo": "carranquear",
    "carranquearmos": "carranquear",
    "carranqueará": "carranquear",
    "carranquearás": "carranquear",
    "carranquearão": "carranquear",
    "carranquearíamos": "carranquear",
    "carranquearíeis": "carranquear",
    "carranqueasse": "carranquear",
    "carranqueassem": "carranquear",
    "carranqueasses": "carranquear",
    "carranqueaste": "carranquear",
    "carranqueastes": "carranquear",
    "carranqueava": "carranquear",
    "carranqueavam": "carranquear",
    "carranqueavas": "carranquear",
    "carranqueei": "carranquear",
    "carranqueeis": "carranquear",
    "carranqueemo": "carranquear",
    "carranqueemos": "carranquear",
    "carranqueia": "carranquear",
    "carranqueiam": "carranquear",
    "carranqueias": "carranquear",
    "carranqueie": "carranquear",
    "carranqueiem": "carranquear",
    "carranqueies": "carranquear",
    "carranqueio": "carranquear",
    "carranqueou": "carranquear",
    "carranqueámo": "carranquear",
    "carranqueámos": "carranquear",
    "carranqueáramo": "carranquear",
    "carranqueáramos": "carranquear",
    "carranqueáreis": "carranquear",
    "carranqueásseis": "carranquear",
    "carranqueássemos": "carranquear",
    "carranqueávamo": "carranquear",
    "carranqueávamos": "carranquear",
    "carranqueáveis": "carranquear",
    "carranças": "carrança",
    "carrapatas": "carrapata",
    "carrapateira": "carrapateiro",
    "carrapateiras": "carrapateiro",
    "carrapateiros": "carrapateiro",
    "carrapatos": "carrapato",
    "carrapetas": "carrapeta",
    "carrapetos": "carrapeto",
    "carrapicheiros": "carrapicheiro",
    "carrapichos": "carrapicho",
    "carrapitana": "carrapitano",
    "carrapitanas": "carrapitano",
    "carrapitanos": "carrapitano",
    "carrapitas": "carrapita",
    "carrapitos": "carrapito",
    "carrapiços": "carrapiço",
    "carraras": "carrara",
    "carrasca": "carrasco",
    "carrascais": "carrascal",
    "carrascas": "carrasco",
    "carrascos": "carrasco",
    "carrascões": "carrascão",
    "carraspanas": "carraspana",
    "carraspeiras": "carraspeira",
    "carraspuda": "carraspudo",
    "carraspudas": "carraspudo",
    "carraspudos": "carraspudo",
    "carrasqueira": "carrasqueiro",
    "carrasqueirais": "carrasqueiral",
    "carrasqueiras": "carrasqueiro",
    "carrasqueiros": "carrasqueiro",
    "carrasquenhas": "carrasquenha",
    "carrasquinha": "carrasquinho",
    "carrasquinhas": "carrasquinho",
    "carrasquinhos": "carrasquinho",
    "carraçarias": "carraçaria",
    "carraças": "carraça",
    "carreada": "carrear",
    "carreadas": "carrear",
    "carreado": "carrear",
    "carreados": "carrear",
    "carreai": "carrear",
    "carreais": "carrear",
    "carreamentos": "carreamento",
    "carreamo": "carrear",
    "carreamos": "carrear",
    "carreando": "carrear",
    "carreara": "carrear",
    "carrearam": "carrear",
    "carrearas": "carrear",
    "carrearde": "carrear",
    "carreardes": "carrear",
    "carreare": "carrear",
    "carrearei": "carrear",
    "carreareis": "carrear",
    "carrearem": "carrear",
    "carrearemos": "carrear",
    "carreares": "carrear",
    "carrearia": "carrear",
    "carreariam": "carrear",
    "carrearias": "carrear",
    "carrearmo": "carrear",
    "carrearmos": "carrear",
    "carreará": "carrear",
    "carrearás": "carrear",
    "carrearão": "carrear",
    "carrearíamos": "carrear",
    "carrearíeis": "carrear",
    "carreasse": "carrear",
    "carreassem": "carrear",
    "carreasses": "carrear",
    "carreaste": "carrear",
    "carreastes": "carrear",
    "carreava": "carrear",
    "carreavam": "carrear",
    "carreavas": "carrear",
    "carreações": "carreação",
    "carreei": "carrear",
    "carreeis": "carrear",
    "carreemo": "carrear",
    "carreemos": "carrear",
    "carrega": "carregar",
    "carregada": "carregar",
    "carregadas": "carregar",
    "carregadeiras": "carregadeira",
    "carregadinha": "carregado",
    "carregadinhas": "carregado",
    "carregadinho": "carregado",
    "carregadinhos": "carregado",
    "carregadita": "carregado",
    "carregaditas": "carregado",
    "carregadito": "carregado",
    "carregaditos": "carregado",
    "carregado": "carregar",
    "carregadora": "carregador",
    "carregadoras": "carregador",
    "carregadores": "carregador",
    "carregados": "carregar",
    "carregadíssima": "carregado",
    "carregadíssimas": "carregado",
    "carregadíssimo": "carregado",
    "carregadíssimos": "carregado",
    "carregai": "carregar",
    "carregais": "carregar",
    "carregam": "carregar",
    "carregamentos": "carregamento",
    "carregamo": "carregar",
    "carregamos": "carregar",
    "carregando": "carregar",
    "carregara": "carregar",
    "carregaram": "carregar",
    "carregaras": "carregar",
    "carregarde": "carregar",
    "carregardes": "carregar",
    "carregare": "carregar",
    "carregarei": "carregar",
    "carregareis": "carregar",
    "carregarem": "carregar",
    "carregaremos": "carregar",
    "carregares": "carregar",
    "carregaria": "carregar",
    "carregariam": "carregar",
    "carregarias": "carregar",
    "carregarmo": "carregar",
    "carregarmos": "carregar",
    "carregará": "carregar",
    "carregarás": "carregar",
    "carregarão": "carregar",
    "carregaríamos": "carregar",
    "carregaríeis": "carregar",
    "carregas": "carregar",
    "carregasse": "carregar",
    "carregassem": "carregar",
    "carregasses": "carregar",
    "carregaste": "carregar",
    "carregastes": "carregar",
    "carregava": "carregar",
    "carregavam": "carregar",
    "carregavas": "carregar",
    "carregações": "carregação",
    "carrego": "carregar",
    "carregos": "carrego",
    "carregosa": "carregoso",
    "carregosas": "carregoso",
    "carregosos": "carregoso",
    "carregou": "carregar",
    "carregue": "carregar",
    "carreguei": "carregar",
    "carregueis": "carregar",
    "carreguem": "carregar",
    "carreguemo": "carregar",
    "carreguemos": "carregar",
    "carregues": "carregar",
    "carregá": "carregar",
    "carregámo": "carregar",
    "carregámos": "carregar",
    "carregáramo": "carregar",
    "carregáramos": "carregar",
    "carregárei": "carregar",
    "carregáreis": "carregar",
    "carregásseis": "carregar",
    "carregássemos": "carregar",
    "carregávamo": "carregar",
    "carregávamos": "carregar",
    "carregávei": "carregar",
    "carregáveis": "carregar",
    "carreia": "carrear",
    "carreiam": "carrear",
    "carreias": "carrear",
    "carreie": "carrear",
    "carreiem": "carrear",
    "carreies": "carrear",
    "carreio": "carrear",
    "carreiras": "carreira",
    "carreirinhas": "carreirinha",
    "carreirinho": "carreiro",
    "carreirinhos": "carreiro",
    "carreirismos": "carreirismo",
    "carreiristas": "carreirista",
    "carreirito": "carreiro",
    "carreiritos": "carreiro",
    "carreirolas": "carreirola",
    "carreiros": "carreiro",
    "carreirões": "carreirão",
    "carreja": "carrejar",
    "carrejada": "carrejar",
    "carrejadas": "carrejar",
    "carrejado": "carrejar",
    "carrejados": "carrejar",
    "carrejai": "carrejar",
    "carrejais": "carrejar",
    "carrejam": "carrejar",
    "carrejamo": "carrejar",
    "carrejamos": "carrejar",
    "carrejando": "carrejar",
    "carrejara": "carrejar",
    "carrejaram": "carrejar",
    "carrejaras": "carrejar",
    "carrejarde": "carrejar",
    "carrejardes": "carrejar",
    "carrejare": "carrejar",
    "carrejarei": "carrejar",
    "carrejareis": "carrejar",
    "carrejarem": "carrejar",
    "carrejaremos": "carrejar",
    "carrejares": "carrejar",
    "carrejaria": "carrejar",
    "carrejariam": "carrejar",
    "carrejarias": "carrejar",
    "carrejarmo": "carrejar",
    "carrejarmos": "carrejar",
    "carrejará": "carrejar",
    "carrejarás": "carrejar",
    "carrejarão": "carrejar",
    "carrejaríamos": "carrejar",
    "carrejaríeis": "carrejar",
    "carrejas": "carrejar",
    "carrejasse": "carrejar",
    "carrejassem": "carrejar",
    "carrejasses": "carrejar",
    "carrejaste": "carrejar",
    "carrejastes": "carrejar",
    "carrejava": "carrejar",
    "carrejavam": "carrejar",
    "carrejavas": "carrejar",
    "carreje": "carrejar",
    "carrejei": "carrejar",
    "carrejeis": "carrejar",
    "carrejem": "carrejar",
    "carrejemo": "carrejar",
    "carrejemos": "carrejar",
    "carrejes": "carrejar",
    "carrejo": "carrejar",
    "carrejos": "carrejo",
    "carrejou": "carrejar",
    "carrejá": "carrejar",
    "carrejámo": "carrejar",
    "carrejámos": "carrejar",
    "carrejáramo": "carrejar",
    "carrejáramos": "carrejar",
    "carrejárei": "carrejar",
    "carrejáreis": "carrejar",
    "carrejásseis": "carrejar",
    "carrejássemos": "carrejar",
    "carrejávamo": "carrejar",
    "carrejávamos": "carrejar",
    "carrejávei": "carrejar",
    "carrejáveis": "carrejar",
    "carrejões": "carrejão",
    "carrelas": "carrela",
    "carreou": "carrear",
    "carreta": "carretar",
    "carretada": "carretar",
    "carretadas": "carretar",
    "carretado": "carretar",
    "carretados": "carretar",
    "carretagens": "carretagem",
    "carretai": "carretar",
    "carretais": "carretar",
    "carretam": "carretar",
    "carretamo": "carretar",
    "carretamos": "carretar",
    "carretando": "carretar",
    "carretara": "carretar",
    "carretaram": "carretar",
    "carretaras": "carretar",
    "carretarde": "carretar",
    "carretardes": "carretar",
    "carretare": "carretar",
    "carretarei": "carretar",
    "carretareis": "carretar",
    "carretarem": "carretar",
    "carretaremos": "carretar",
    "carretares": "carretar",
    "carretaria": "carretar",
    "carretariam": "carretar",
    "carretarias": "carretar",
    "carretarmo": "carretar",
    "carretarmos": "carretar",
    "carretará": "carretar",
    "carretarás": "carretar",
    "carretarão": "carretar",
    "carretaríamos": "carretar",
    "carretaríeis": "carretar",
    "carretas": "carretar",
    "carretasse": "carretar",
    "carretassem": "carretar",
    "carretasses": "carretar",
    "carretaste": "carretar",
    "carretastes": "carretar",
    "carretava": "carretar",
    "carretavam": "carretar",
    "carretavas": "carretar",
    "carrete": "carretar",
    "carreteada": "carretear",
    "carreteadas": "carretear",
    "carreteado": "carretear",
    "carreteados": "carretear",
    "carreteai": "carretear",
    "carreteais": "carretear",
    "carreteamo": "carretear",
    "carreteamos": "carretear",
    "carreteando": "carretear",
    "carreteara": "carretear",
    "carretearam": "carretear",
    "carretearas": "carretear",
    "carretearde": "carretear",
    "carreteardes": "carretear",
    "carreteare": "carretear",
    "carretearei": "carretear",
    "carreteareis": "carretear",
    "carretearem": "carretear",
    "carretearemos": "carretear",
    "carreteares": "carretear",
    "carretearia": "carretear",
    "carreteariam": "carretear",
    "carretearias": "carretear",
    "carretearmo": "carretear",
    "carretearmos": "carretear",
    "carreteará": "carretear",
    "carretearás": "carretear",
    "carretearão": "carretear",
    "carretearíamos": "carretear",
    "carretearíeis": "carretear",
    "carreteasse": "carretear",
    "carreteassem": "carretear",
    "carreteasses": "carretear",
    "carreteaste": "carretear",
    "carreteastes": "carretear",
    "carreteava": "carretear",
    "carreteavam": "carretear",
    "carreteavas": "carretear",
    "carreteei": "carretear",
    "carreteeis": "carretear",
    "carreteemo": "carretear",
    "carreteemos": "carretear",
    "carretei": "carretar",
    "carreteia": "carretear",
    "carreteiam": "carretear",
    "carreteias": "carretear",
    "carreteie": "carretear",
    "carreteiem": "carretear",
    "carreteies": "carretear",
    "carreteio": "carretear",
    "carreteira": "carreteiro",
    "carreteiras": "carreteiro",
    "carreteiros": "carreteiro",
    "carreteis": "carretar",
    "carretem": "carretar",
    "carretemo": "carretar",
    "carretemos": "carretar",
    "carreteou": "carretear",
    "carretes": "carrete",
    "carreteá": "carretear",
    "carreteámo": "carretear",
    "carreteámos": "carretear",
    "carreteáramo": "carretear",
    "carreteáramos": "carretear",
    "carreteárei": "carretear",
    "carreteáreis": "carretear",
    "carreteásseis": "carretear",
    "carreteássemos": "carretear",
    "carreteávamo": "carretear",
    "carreteávamos": "carretear",
    "carreteávei": "carretear",
    "carreteáveis": "carretear",
    "carretilhas": "carretilha",
    "carreto": "carretar",
    "carretos": "carreto",
    "carretou": "carretar",
    "carretá": "carretar",
    "carretámo": "carretar",
    "carretámos": "carretar",
    "carretáramo": "carretar",
    "carretáramos": "carretar",
    "carretárei": "carretar",
    "carretáreis": "carretar",
    "carretásseis": "carretar",
    "carretássemos": "carretar",
    "carretávamo": "carretar",
    "carretávamos": "carretar",
    "carretávei": "carretar",
    "carretáveis": "carretar",
    "carretãs": "carretã",
    "carretéis": "carretel",
    "carretões": "carretão",
    "carreá": "carrear",
    "carreámo": "carrear",
    "carreámos": "carrear",
    "carreáramo": "carrear",
    "carreáramos": "carrear",
    "carreárei": "carrear",
    "carreáreis": "carrear",
    "carreásseis": "carrear",
    "carreássemos": "carrear",
    "carreávamo": "carrear",
    "carreávamos": "carrear",
    "carreávei": "carrear",
    "carreáveis": "carrear",
    "carriagens": "carriagem",
    "carrichas": "carricha",
    "carricinhas": "carricinha",
    "carrila": "carrilar",
    "carrilada": "carrilar",
    "carriladas": "carrilar",
    "carrilado": "carrilar",
    "carrilados": "carrilar",
    "carrilai": "carrilar",
    "carrilais": "carrilar",
    "carrilam": "carrilar",
    "carrilamentos": "carrilamento",
    "carrilamo": "carrilar",
    "carrilamos": "carrilar",
    "carrilando": "carrilar",
    "carrilara": "carrilar",
    "carrilaram": "carrilar",
    "carrilaras": "carrilar",
    "carrilarde": "carrilar",
    "carrilardes": "carrilar",
    "carrilare": "carrilar",
    "carrilarei": "carrilar",
    "carrilareis": "carrilar",
    "carrilarem": "carrilar",
    "carrilaremos": "carrilar",
    "carrilares": "carrilar",
    "carrilaria": "carrilar",
    "carrilariam": "carrilar",
    "carrilarias": "carrilar",
    "carrilarmo": "carrilar",
    "carrilarmos": "carrilar",
    "carrilará": "carrilar",
    "carrilarás": "carrilar",
    "carrilarão": "carrilar",
    "carrilaríamos": "carrilar",
    "carrilaríeis": "carrilar",
    "carrilas": "carrilar",
    "carrilasse": "carrilar",
    "carrilassem": "carrilar",
    "carrilasses": "carrilar",
    "carrilaste": "carrilar",
    "carrilastes": "carrilar",
    "carrilava": "carrilar",
    "carrilavam": "carrilar",
    "carrilavas": "carrilar",
    "carrile": "carrilar",
    "carrilei": "carrilar",
    "carrileis": "carrilar",
    "carrilem": "carrilar",
    "carrilemo": "carrilar",
    "carrilemos": "carrilar",
    "carriles": "carrilar",
    "carrilhadora": "carrilhador",
    "carrilhadoras": "carrilhador",
    "carrilhadores": "carrilhador",
    "carrilhanistas": "carrilhanista",
    "carrilhanora": "carrilhanor",
    "carrilhanoras": "carrilhanor",
    "carrilhanores": "carrilhanor",
    "carrilheiras": "carrilheira",
    "carrilhona": "carrilhonar",
    "carrilhonada": "carrilhonar",
    "carrilhonadas": "carrilhonar",
    "carrilhonado": "carrilhonar",
    "carrilhonados": "carrilhonar",
    "carrilhonai": "carrilhonar",
    "carrilhonais": "carrilhonar",
    "carrilhonam": "carrilhonar",
    "carrilhonamo": "carrilhonar",
    "carrilhonamos": "carrilhonar",
    "carrilhonando": "carrilhonar",
    "carrilhonara": "carrilhonar",
    "carrilhonaram": "carrilhonar",
    "carrilhonaras": "carrilhonar",
    "carrilhonardes": "carrilhonar",
    "carrilhonarei": "carrilhonar",
    "carrilhonareis": "carrilhonar",
    "carrilhonarem": "carrilhonar",
    "carrilhonaremos": "carrilhonar",
    "carrilhonares": "carrilhonar",
    "carrilhonaria": "carrilhonar",
    "carrilhonariam": "carrilhonar",
    "carrilhonarias": "carrilhonar",
    "carrilhonarmo": "carrilhonar",
    "carrilhonarmos": "carrilhonar",
    "carrilhonará": "carrilhonar",
    "carrilhonarás": "carrilhonar",
    "carrilhonarão": "carrilhonar",
    "carrilhonaríamos": "carrilhonar",
    "carrilhonaríeis": "carrilhonar",
    "carrilhonas": "carrilhonar",
    "carrilhonasse": "carrilhonar",
    "carrilhonassem": "carrilhonar",
    "carrilhonasses": "carrilhonar",
    "carrilhonaste": "carrilhonar",
    "carrilhonastes": "carrilhonar",
    "carrilhonava": "carrilhonar",
    "carrilhonavam": "carrilhonar",
    "carrilhonavas": "carrilhonar",
    "carrilhone": "carrilhonar",
    "carrilhonei": "carrilhonar",
    "carrilhoneira": "carrilhoneiro",
    "carrilhoneiras": "carrilhoneiro",
    "carrilhoneiros": "carrilhoneiro",
    "carrilhoneis": "carrilhonar",
    "carrilhonem": "carrilhonar",
    "carrilhonemo": "carrilhonar",
    "carrilhonemos": "carrilhonar",
    "carrilhones": "carrilhonar",
    "carrilhonistas": "carrilhonista",
    "carrilhono": "carrilhonar",
    "carrilhonou": "carrilhonar",
    "carrilhonámo": "carrilhonar",
    "carrilhonámos": "carrilhonar",
    "carrilhonáramo": "carrilhonar",
    "carrilhonáramos": "carrilhonar",
    "carrilhonáreis": "carrilhonar",
    "carrilhonásseis": "carrilhonar",
    "carrilhonássemos": "carrilhonar",
    "carrilhonávamo": "carrilhonar",
    "carrilhonávamos": "carrilhonar",
    "carrilhonáveis": "carrilhonar",
    "carrilhos": "carrilho",
    "carrilhões": "carrilhão",
    "carrilo": "carrilar",
    "carrilou": "carrilar",
    "carrilá": "carrilar",
    "carrilámo": "carrilar",
    "carrilámos": "carrilar",
    "carriláramo": "carrilar",
    "carriláramos": "carrilar",
    "carrilárei": "carrilar",
    "carriláreis": "carrilar",
    "carrilásseis": "carrilar",
    "carrilássemos": "carrilar",
    "carrilávamo": "carrilar",
    "carrilávamos": "carrilar",
    "carrilávei": "carrilar",
    "carriláveis": "carrilar",
    "carrinhas": "carrinha",
    "carrinho": "carro",
    "carrinhos": "carro",
    "carriolas": "carriola",
    "carripadas": "carripada",
    "carripanas": "carripana",
    "carripanazinha": "carripana",
    "carripanazinhas": "carripana",
    "carripanazita": "carripana",
    "carripanazitas": "carripana",
    "carris": "carril",
    "carrito": "carro",
    "carritos": "carro",
    "carriçais": "carriçal",
    "carriças": "carriça",
    "carriços": "carriço",
    "carriões": "carrião",
    "carroce": "carroçar",
    "carrocei": "carroçar",
    "carroceira": "carroceiro",
    "carroceiras": "carroceiro",
    "carroceiros": "carroceiro",
    "carroceis": "carroçar",
    "carrocem": "carroçar",
    "carrocemo": "carroçar",
    "carrocemos": "carroçar",
    "carroces": "carroçar",
    "carrochas": "carrocha",
    "carrocinha": "carroça",
    "carrocinhas": "carroça",
    "carrocins": "carrocim",
    "carrocita": "carroça",
    "carrocitas": "carroça",
    "carropitos": "carropito",
    "carros": "carro",
    "carrosséis": "carrossel",
    "carroça": "carroçar",
    "carroçada": "carroçar",
    "carroçadas": "carroçar",
    "carroçado": "carroçar",
    "carroçados": "carroçar",
    "carroçai": "carroçar",
    "carroçais": "carroçar",
    "carroçam": "carroçar",
    "carroçamo": "carroçar",
    "carroçamos": "carroçar",
    "carroçando": "carroçar",
    "carroçara": "carroçar",
    "carroçaram": "carroçar",
    "carroçaras": "carroçar",
    "carroçarde": "carroçar",
    "carroçardes": "carroçar",
    "carroçare": "carroçar",
    "carroçarei": "carroçar",
    "carroçareis": "carroçar",
    "carroçarem": "carroçar",
    "carroçaremos": "carroçar",
    "carroçares": "carroçar",
    "carroçaria": "carroçar",
    "carroçariam": "carroçar",
    "carroçarias": "carroçaria",
    "carroçarmo": "carroçar",
    "carroçarmos": "carroçar",
    "carroçará": "carroçar",
    "carroçarás": "carroçar",
    "carroçarão": "carroçar",
    "carroçaríamos": "carroçar",
    "carroçaríeis": "carroçar",
    "carroças": "carroçar",
    "carroçasse": "carroçar",
    "carroçassem": "carroçar",
    "carroçasses": "carroçar",
    "carroçaste": "carroçar",
    "carroçastes": "carroçar",
    "carroçava": "carroçar",
    "carroçavam": "carroçar",
    "carroçavas": "carroçar",
    "carroço": "carroçar",
    "carroçou": "carroçar",
    "carroçá": "carroçar",
    "carroçámo": "carroçar",
    "carroçámos": "carroçar",
    "carroçáramo": "carroçar",
    "carroçáramos": "carroçar",
    "carroçárei": "carroçar",
    "carroçáreis": "carroçar",
    "carroçásseis": "carroçar",
    "carroçássemos": "carroçar",
    "carroçávamo": "carroçar",
    "carroçávamos": "carroçar",
    "carroçávei": "carroçar",
    "carroçáveis": "carroçável",
    "carroções": "carroção",
    "carruageira": "carruageiro",
    "carruageiras": "carruageiro",
    "carruageiros": "carruageiro",
    "carruagens": "carruagem",
    "carrulas": "carrula",
    "carrões": "carrão",
    "carta": "cartar",
    "cartabuxa": "cartabuxar",
    "cartabuxada": "cartabuxar",
    "cartabuxadas": "cartabuxar",
    "cartabuxado": "cartabuxar",
    "cartabuxados": "cartabuxar",
    "cartabuxai": "cartabuxar",
    "cartabuxais": "cartabuxar",
    "cartabuxam": "cartabuxar",
    "cartabuxamo": "cartabuxar",
    "cartabuxamos": "cartabuxar",
    "cartabuxando": "cartabuxar",
    "cartabuxara": "cartabuxar",
    "cartabuxaram": "cartabuxar",
    "cartabuxaras": "cartabuxar",
    "cartabuxarde": "cartabuxar",
    "cartabuxardes": "cartabuxar",
    "cartabuxare": "cartabuxar",
    "cartabuxarei": "cartabuxar",
    "cartabuxareis": "cartabuxar",
    "cartabuxarem": "cartabuxar",
    "cartabuxaremos": "cartabuxar",
    "cartabuxares": "cartabuxar",
    "cartabuxaria": "cartabuxar",
    "cartabuxariam": "cartabuxar",
    "cartabuxarias": "cartabuxar",
    "cartabuxarmo": "cartabuxar",
    "cartabuxarmos": "cartabuxar",
    "cartabuxará": "cartabuxar",
    "cartabuxarás": "cartabuxar",
    "cartabuxarão": "cartabuxar",
    "cartabuxaríamos": "cartabuxar",
    "cartabuxaríeis": "cartabuxar",
    "cartabuxas": "cartabuxar",
    "cartabuxasse": "cartabuxar",
    "cartabuxassem": "cartabuxar",
    "cartabuxasses": "cartabuxar",
    "cartabuxaste": "cartabuxar",
    "cartabuxastes": "cartabuxar",
    "cartabuxava": "cartabuxar",
    "cartabuxavam": "cartabuxar",
    "cartabuxavas": "cartabuxar",
    "cartabuxe": "cartabuxar",
    "cartabuxei": "cartabuxar",
    "cartabuxeis": "cartabuxar",
    "cartabuxem": "cartabuxar",
    "cartabuxemo": "cartabuxar",
    "cartabuxemos": "cartabuxar",
    "cartabuxes": "cartabuxar",
    "cartabuxo": "cartabuxar",
    "cartabuxou": "cartabuxar",
    "cartabuxá": "cartabuxar",
    "cartabuxámo": "cartabuxar",
    "cartabuxámos": "cartabuxar",
    "cartabuxáramo": "cartabuxar",
    "cartabuxáramos": "cartabuxar",
    "cartabuxárei": "cartabuxar",
    "cartabuxáreis": "cartabuxar",
    "cartabuxásseis": "cartabuxar",
    "cartabuxássemos": "cartabuxar",
    "cartabuxávamo": "cartabuxar",
    "cartabuxávamos": "cartabuxar",
    "cartabuxávei": "cartabuxar",
    "cartabuxáveis": "cartabuxar",
    "cartada": "cartar",
    "cartadas": "cartar",
    "cartado": "cartar",
    "cartados": "cartar",
    "cartaginenses": "cartaginense",
    "cartaginesa": "cartaginês",
    "cartaginesas": "cartaginês",
    "cartagineses": "cartaginês",
    "cartai": "cartar",
    "cartais": "cartar",
    "cartam": "cartar",
    "cartamo": "cartar",
    "cartamos": "cartar",
    "cartando": "cartar",
    "cartanhadas": "cartanhada",
    "cartapaços": "cartapaço",
    "cartapácios": "cartapácio",
    "cartara": "cartar",
    "cartaram": "cartar",
    "cartaras": "cartar",
    "cartarde": "cartar",
    "cartardes": "cartar",
    "cartare": "cartar",
    "cartarei": "cartar",
    "cartareis": "cartar",
    "cartarem": "cartar",
    "cartaremos": "cartar",
    "cartares": "cartar",
    "cartaria": "cartar",
    "cartariam": "cartar",
    "cartarias": "cartar",
    "cartarmo": "cartar",
    "cartarmos": "cartar",
    "cartará": "cartar",
    "cartarás": "cartar",
    "cartarão": "cartar",
    "cartaríamos": "cartar",
    "cartaríeis": "cartar",
    "cartas": "cartar",
    "cartasse": "cartar",
    "cartassem": "cartar",
    "cartasses": "cartar",
    "cartaste": "cartar",
    "cartastes": "cartar",
    "cartava": "cartar",
    "cartavam": "cartar",
    "cartavas": "cartar",
    "cartaxeira": "cartaxeiro",
    "cartaxeiras": "cartaxeiro",
    "cartaxeiros": "cartaxeiro",
    "cartaxenses": "cartaxense",
    "cartaxos": "cartaxo",
    "cartazeira": "cartazeiro",
    "cartazeiras": "cartazeiro",
    "cartazeiros": "cartazeiro",
    "cartazes": "cartaz",
    "cartazistas": "cartazista",
    "carte": "cartar",
    "carteada": "cartear",
    "carteadas": "cartear",
    "carteado": "cartear",
    "carteados": "cartear",
    "carteai": "cartear",
    "carteais": "cartear",
    "carteamentos": "carteamento",
    "carteamo": "cartear",
    "carteamos": "cartear",
    "carteando": "cartear",
    "carteara": "cartear",
    "cartearam": "cartear",
    "cartearas": "cartear",
    "cartearde": "cartear",
    "carteardes": "cartear",
    "carteare": "cartear",
    "cartearei": "cartear",
    "carteareis": "cartear",
    "cartearem": "cartear",
    "cartearemos": "cartear",
    "carteares": "cartear",
    "cartearia": "cartear",
    "carteariam": "cartear",
    "cartearias": "cartear",
    "cartearmo": "cartear",
    "cartearmos": "cartear",
    "carteará": "cartear",
    "cartearás": "cartear",
    "cartearão": "cartear",
    "cartearíamos": "cartear",
    "cartearíeis": "cartear",
    "carteasse": "cartear",
    "carteassem": "cartear",
    "carteasses": "cartear",
    "carteaste": "cartear",
    "carteastes": "cartear",
    "carteava": "cartear",
    "carteavam": "cartear",
    "carteavas": "cartear",
    "carteei": "cartear",
    "carteeis": "cartear",
    "carteemo": "cartear",
    "carteemos": "cartear",
    "cartei": "cartar",
    "carteia": "cartear",
    "carteiam": "cartear",
    "carteias": "cartear",
    "carteie": "cartear",
    "carteiem": "cartear",
    "carteies": "cartear",
    "carteio": "cartear",
    "carteios": "carteio",
    "carteira": "carteiro",
    "carteiras": "carteiro",
    "carteirinha": "carteira",
    "carteirinhas": "carteira",
    "carteiristas": "carteirista",
    "carteirita": "carteira",
    "carteiritas": "carteira",
    "carteiros": "carteiro",
    "carteis": "cartar",
    "cartelas": "cartela",
    "carteliza": "cartelizar",
    "cartelizada": "cartelizar",
    "cartelizadas": "cartelizar",
    "cartelizado": "cartelizar",
    "cartelizados": "cartelizar",
    "cartelizai": "cartelizar",
    "cartelizais": "cartelizar",
    "cartelizam": "cartelizar",
    "cartelizamo": "cartelizar",
    "cartelizamos": "cartelizar",
    "cartelizando": "cartelizar",
    "cartelizara": "cartelizar",
    "cartelizaram": "cartelizar",
    "cartelizaras": "cartelizar",
    "cartelizarde": "cartelizar",
    "cartelizardes": "cartelizar",
    "cartelizare": "cartelizar",
    "cartelizarei": "cartelizar",
    "cartelizareis": "cartelizar",
    "cartelizarem": "cartelizar",
    "cartelizaremos": "cartelizar",
    "cartelizares": "cartelizar",
    "cartelizaria": "cartelizar",
    "cartelizariam": "cartelizar",
    "cartelizarias": "cartelizar",
    "cartelizarmo": "cartelizar",
    "cartelizarmos": "cartelizar",
    "cartelizará": "cartelizar",
    "cartelizarás": "cartelizar",
    "cartelizarão": "cartelizar",
    "cartelizaríamos": "cartelizar",
    "cartelizaríeis": "cartelizar",
    "cartelizas": "cartelizar",
    "cartelizasse": "cartelizar",
    "cartelizassem": "cartelizar",
    "cartelizasses": "cartelizar",
    "cartelizaste": "cartelizar",
    "cartelizastes": "cartelizar",
    "cartelizava": "cartelizar",
    "cartelizavam": "cartelizar",
    "cartelizavas": "cartelizar",
    "cartelizações": "cartelização",
    "cartelize": "cartelizar",
    "cartelizei": "cartelizar",
    "cartelizeis": "cartelizar",
    "cartelizem": "cartelizar",
    "cartelizemo": "cartelizar",
    "cartelizemos": "cartelizar",
    "cartelizes": "cartelizar",
    "cartelizo": "cartelizar",
    "cartelizou": "cartelizar",
    "cartelizá": "cartelizar",
    "cartelizámo": "cartelizar",
    "cartelizámos": "cartelizar",
    "cartelizáramo": "cartelizar",
    "cartelizáramos": "cartelizar",
    "cartelizárei": "cartelizar",
    "cartelizáreis": "cartelizar",
    "cartelizásseis": "cartelizar",
    "cartelizássemos": "cartelizar",
    "cartelizávamo": "cartelizar",
    "cartelizávamos": "cartelizar",
    "cartelizávei": "cartelizar",
    "cartelizáveis": "cartelizar",
    "cartem": "cartar",
    "cartemo": "cartar",
    "cartemos": "cartar",
    "carteou": "cartear",
    "cartes": "cartar",
    "cartesiana": "cartesiano",
    "cartesianas": "cartesiano",
    "cartesianismos": "cartesianismo",
    "cartesianos": "cartesiano",
    "carteá": "cartear",
    "carteámo": "cartear",
    "carteámos": "cartear",
    "carteáramo": "cartear",
    "carteáramos": "cartear",
    "carteárei": "cartear",
    "carteáreis": "cartear",
    "carteásseis": "cartear",
    "carteássemos": "cartear",
    "carteávamo": "cartear",
    "carteávamos": "cartear",
    "carteávei": "cartear",
    "carteáveis": "cartear",
    "cartilagens": "cartilagem",
    "cartilaginosa": "cartilaginoso",
    "cartilaginosas": "cartilaginoso",
    "cartilaginosos": "cartilaginoso",
    "cartilagínea": "cartilagíneo",
    "cartilagíneas": "cartilagíneo",
    "cartilagíneos": "cartilagíneo",
    "cartilhas": "cartilha",
    "cartinha": "carta",
    "cartinhas": "carta",
    "cartistas": "cartista",
    "cartita": "carta",
    "cartitas": "carta",
    "carto": "cartar",
    "cartografa": "cartografar",
    "cartografada": "cartografar",
    "cartografadas": "cartografar",
    "cartografado": "cartografar",
    "cartografados": "cartografar",
    "cartografai": "cartografar",
    "cartografais": "cartografar",
    "cartografam": "cartografar",
    "cartografamo": "cartografar",
    "cartografamos": "cartografar",
    "cartografando": "cartografar",
    "cartografara": "cartografar",
    "cartografaram": "cartografar",
    "cartografaras": "cartografar",
    "cartografarde": "cartografar",
    "cartografardes": "cartografar",
    "cartografare": "cartografar",
    "cartografarei": "cartografar",
    "cartografareis": "cartografar",
    "cartografarem": "cartografar",
    "cartografaremos": "cartografar",
    "cartografares": "cartografar",
    "cartografaria": "cartografar",
    "cartografariam": "cartografar",
    "cartografarias": "cartografar",
    "cartografarmo": "cartografar",
    "cartografarmos": "cartografar",
    "cartografará": "cartografar",
    "cartografarás": "cartografar",
    "cartografarão": "cartografar",
    "cartografaríamos": "cartografar",
    "cartografaríeis": "cartografar",
    "cartografas": "cartografar",
    "cartografasse": "cartografar",
    "cartografassem": "cartografar",
    "cartografasses": "cartografar",
    "cartografaste": "cartografar",
    "cartografastes": "cartografar",
    "cartografava": "cartografar",
    "cartografavam": "cartografar",
    "cartografavas": "cartografar",
    "cartografe": "cartografar",
    "cartografei": "cartografar",
    "cartografeis": "cartografar",
    "cartografem": "cartografar",
    "cartografemo": "cartografar",
    "cartografemos": "cartografar",
    "cartografes": "cartografar",
    "cartografias": "cartografia",
    "cartografo": "cartografar",
    "cartografou": "cartografar",
    "cartografá": "cartografar",
    "cartografámo": "cartografar",
    "cartografámos": "cartografar",
    "cartografáramo": "cartografar",
    "cartografáramos": "cartografar",
    "cartografárei": "cartografar",
    "cartografáreis": "cartografar",
    "cartografásseis": "cartografar",
    "cartografássemos": "cartografar",
    "cartografávamo": "cartografar",
    "cartografávamos": "cartografar",
    "cartografávei": "cartografar",
    "cartografáveis": "cartografável",
    "cartográfica": "cartográfico",
    "cartográficas": "cartográfico",
    "cartográficos": "cartográfico",
    "cartolada": "cartolado",
    "cartoladas": "cartolado",
    "cartolados": "cartolado",
    "cartolas": "cartola",
    "cartolaços": "cartolaço",
    "cartolinas": "cartolina",
    "cartomancias": "cartomancia",
    "cartomantes": "cartomante",
    "cartomâncias": "cartomância",
    "cartomântica": "cartomântico",
    "cartomânticas": "cartomântico",
    "cartomânticos": "cartomântico",
    "cartona": "cartonar",
    "cartonada": "cartonar",
    "cartonadas": "cartonar",
    "cartonado": "cartonar",
    "cartonadora": "cartonador",
    "cartonadoras": "cartonador",
    "cartonadores": "cartonador",
    "cartonados": "cartonar",
    "cartonageira": "cartonageiro",
    "cartonageiras": "cartonageiro",
    "cartonageiros": "cartonageiro",
    "cartonagens": "cartonagem",
    "cartonai": "cartonar",
    "cartonais": "cartonar",
    "cartonam": "cartonar",
    "cartonamo": "cartonar",
    "cartonamos": "cartonar",
    "cartonando": "cartonar",
    "cartonara": "cartonar",
    "cartonaram": "cartonar",
    "cartonaras": "cartonar",
    "cartonarde": "cartonar",
    "cartonardes": "cartonar",
    "cartonare": "cartonar",
    "cartonarei": "cartonar",
    "cartonareis": "cartonar",
    "cartonarem": "cartonar",
    "cartonaremos": "cartonar",
    "cartonares": "cartonar",
    "cartonaria": "cartonar",
    "cartonariam": "cartonar",
    "cartonarias": "cartonar",
    "cartonarmo": "cartonar",
    "cartonarmos": "cartonar",
    "cartonará": "cartonar",
    "cartonarás": "cartonar",
    "cartonarão": "cartonar",
    "cartonaríamos": "cartonar",
    "cartonaríeis": "cartonar",
    "cartonas": "cartonar",
    "cartonasse": "cartonar",
    "cartonassem": "cartonar",
    "cartonasses": "cartonar",
    "cartonaste": "cartonar",
    "cartonastes": "cartonar",
    "cartonava": "cartonar",
    "cartonavam": "cartonar",
    "cartonavas": "cartonar",
    "cartone": "cartonar",
    "cartonei": "cartonar",
    "cartoneis": "cartonar",
    "cartonem": "cartonar",
    "cartonemo": "cartonar",
    "cartonemos": "cartonar",
    "cartones": "cartonar",
    "cartonistas": "cartonista",
    "cartono": "cartonar",
    "cartonou": "cartonar",
    "cartoná": "cartonar",
    "cartonámo": "cartonar",
    "cartonámos": "cartonar",
    "cartonáramo": "cartonar",
    "cartonáramos": "cartonar",
    "cartonárei": "cartonar",
    "cartonáreis": "cartonar",
    "cartonásseis": "cartonar",
    "cartonássemos": "cartonar",
    "cartonávamo": "cartonar",
    "cartonávamos": "cartonar",
    "cartonávei": "cartonar",
    "cartonáveis": "cartonar",
    "cartoonistas": "cartoonista",
    "cartoons": "cartoon",
    "cartoriais": "cartorial",
    "cartorária": "cartorário",
    "cartorárias": "cartorário",
    "cartorários": "cartorário",
    "cartou": "cartar",
    "cartucha": "cartucho",
    "cartuchames": "cartuchame",
    "cartuchas": "cartucho",
    "cartucheiras": "cartucheira",
    "cartucheiros": "cartucheiro",
    "cartuchinho": "cartucho",
    "cartuchinhos": "cartucho",
    "cartuchito": "cartucho",
    "cartuchitos": "cartucho",
    "cartuchos": "cartucho",
    "cartulários": "cartulário",
    "cartunistas": "cartunista",
    "cartuns": "cartum",
    "cartusiana": "cartusiano",
    "cartusianas": "cartusiano",
    "cartusianos": "cartusiano",
    "cartuxas": "cartuxa",
    "cartuxos": "cartuxo",
    "cartá": "cartar",
    "cartácea": "cartáceo",
    "cartáceas": "cartáceo",
    "cartáceos": "cartáceo",
    "cartámo": "cartar",
    "cartámos": "cartar",
    "cartáramo": "cartar",
    "cartáramos": "cartar",
    "cartárei": "cartar",
    "cartáreis": "cartar",
    "cartásseis": "cartar",
    "cartássemos": "cartar",
    "cartávamo": "cartar",
    "cartávamos": "cartar",
    "cartávei": "cartar",
    "cartáveis": "cartar",
    "cartãozinho": "cartão",
    "cartãozito": "cartão",
    "cartéis": "cartel",
    "cartógrafa": "cartógrafo",
    "cartógrafas": "cartógrafo",
    "cartógrafos": "cartógrafo",
    "cartóloga": "cartólogo",
    "cartólogas": "cartólogo",
    "cartólogos": "cartólogo",
    "cartórios": "cartório",
    "cartões": "cartão",
    "cartõezinhos": "cartão",
    "cartõezitos": "cartão",
    "carugens": "carugem",
    "caruja": "carujar",
    "carujada": "carujar",
    "carujadas": "carujar",
    "carujado": "carujar",
    "carujados": "carujar",
    "carujai": "carujar",
    "carujais": "carujar",
    "carujam": "carujar",
    "carujamo": "carujar",
    "carujamos": "carujar",
    "carujando": "carujar",
    "carujara": "carujar",
    "carujaram": "carujar",
    "carujaras": "carujar",
    "carujardes": "carujar",
    "carujarei": "carujar",
    "carujareis": "carujar",
    "carujarem": "carujar",
    "carujaremos": "carujar",
    "carujares": "carujar",
    "carujaria": "carujar",
    "carujariam": "carujar",
    "carujarias": "carujar",
    "carujarmo": "carujar",
    "carujarmos": "carujar",
    "carujará": "carujar",
    "carujarás": "carujar",
    "carujarão": "carujar",
    "carujaríamos": "carujar",
    "carujaríeis": "carujar",
    "carujas": "carujar",
    "carujasse": "carujar",
    "carujassem": "carujar",
    "carujasses": "carujar",
    "carujaste": "carujar",
    "carujastes": "carujar",
    "carujava": "carujar",
    "carujavam": "carujar",
    "carujavas": "carujar",
    "caruje": "carujar",
    "carujei": "carujar",
    "carujeiras": "carujeira",
    "carujeiros": "carujeiro",
    "carujeis": "carujar",
    "carujem": "carujar",
    "carujemo": "carujar",
    "carujemos": "carujar",
    "carujes": "carujar",
    "carujo": "carujar",
    "carujos": "carujo",
    "carujou": "carujar",
    "carujámo": "carujar",
    "carujámos": "carujar",
    "carujáramo": "carujar",
    "carujáramos": "carujar",
    "carujáreis": "carujar",
    "carujásseis": "carujar",
    "carujássemos": "carujar",
    "carujávamo": "carujar",
    "carujávamos": "carujar",
    "carujáveis": "carujar",
    "carumas": "caruma",
    "carumbas": "carumba",
    "carumeiras": "carumeira",
    "caruncha": "carunchar",
    "carunchada": "carunchar",
    "carunchadas": "carunchar",
    "carunchado": "carunchar",
    "carunchados": "carunchar",
    "carunchai": "carunchar",
    "carunchais": "carunchar",
    "caruncham": "carunchar",
    "carunchamo": "carunchar",
    "carunchamos": "carunchar",
    "carunchando": "carunchar",
    "carunchara": "carunchar",
    "caruncharam": "carunchar",
    "caruncharas": "carunchar",
    "carunchardes": "carunchar",
    "caruncharei": "carunchar",
    "carunchareis": "carunchar",
    "caruncharem": "carunchar",
    "caruncharemos": "carunchar",
    "carunchares": "carunchar",
    "caruncharia": "carunchar",
    "carunchariam": "carunchar",
    "caruncharias": "carunchar",
    "caruncharmo": "carunchar",
    "caruncharmos": "carunchar",
    "carunchará": "carunchar",
    "caruncharás": "carunchar",
    "caruncharão": "carunchar",
    "caruncharíamos": "carunchar",
    "caruncharíeis": "carunchar",
    "carunchas": "carunchar",
    "carunchasse": "carunchar",
    "carunchassem": "carunchar",
    "carunchasses": "carunchar",
    "carunchaste": "carunchar",
    "carunchastes": "carunchar",
    "carunchava": "carunchar",
    "carunchavam": "carunchar",
    "carunchavas": "carunchar",
    "carunche": "carunchar",
    "carunchei": "carunchar",
    "caruncheis": "carunchar",
    "carunchem": "carunchar",
    "carunchemo": "carunchar",
    "carunchemos": "carunchar",
    "carunchenta": "carunchento",
    "carunchentas": "carunchento",
    "carunchentos": "carunchento",
    "carunches": "carunchar",
    "caruncho": "carunchar",
    "carunchos": "caruncho",
    "carunchosa": "carunchoso",
    "carunchosas": "carunchoso",
    "carunchosos": "carunchoso",
    "carunchou": "carunchar",
    "carunchámo": "carunchar",
    "carunchámos": "carunchar",
    "caruncháramo": "carunchar",
    "caruncháramos": "carunchar",
    "caruncháreis": "carunchar",
    "carunchásseis": "carunchar",
    "carunchássemos": "carunchar",
    "carunchávamo": "carunchar",
    "carunchávamos": "carunchar",
    "caruncháveis": "carunchar",
    "carunculosa": "carunculoso",
    "carunculosas": "carunculoso",
    "carunculosos": "carunculoso",
    "carunhas": "carunha",
    "carusmas": "carusma",
    "carvalhais": "carvalhal",
    "carvalhas": "carvalha",
    "carvalheiras": "carvalheira",
    "carvalheiros": "carvalheiro",
    "carvalhinhas": "carvalhinha",
    "carvalhinho": "carvalho",
    "carvalhinhos": "carvalho",
    "carvalhito": "carvalho",
    "carvalhitos": "carvalho",
    "carvalhiças": "carvalhiça",
    "carvalhos": "carvalho",
    "carvoarias": "carvoaria",
    "carvoeira": "carvoeiro",
    "carvoeiras": "carvoeiro",
    "carvoeiros": "carvoeiro",
    "carvoeja": "carvoejar",
    "carvoejada": "carvoejar",
    "carvoejadas": "carvoejar",
    "carvoejado": "carvoejar",
    "carvoejados": "carvoejar",
    "carvoejai": "carvoejar",
    "carvoejais": "carvoejar",
    "carvoejam": "carvoejar",
    "carvoejamo": "carvoejar",
    "carvoejamos": "carvoejar",
    "carvoejando": "carvoejar",
    "carvoejara": "carvoejar",
    "carvoejaram": "carvoejar",
    "carvoejaras": "carvoejar",
    "carvoejardes": "carvoejar",
    "carvoejarei": "carvoejar",
    "carvoejareis": "carvoejar",
    "carvoejarem": "carvoejar",
    "carvoejaremos": "carvoejar",
    "carvoejares": "carvoejar",
    "carvoejaria": "carvoejar",
    "carvoejariam": "carvoejar",
    "carvoejarias": "carvoejar",
    "carvoejarmo": "carvoejar",
    "carvoejarmos": "carvoejar",
    "carvoejará": "carvoejar",
    "carvoejarás": "carvoejar",
    "carvoejarão": "carvoejar",
    "carvoejaríamos": "carvoejar",
    "carvoejaríeis": "carvoejar",
    "carvoejas": "carvoejar",
    "carvoejasse": "carvoejar",
    "carvoejassem": "carvoejar",
    "carvoejasses": "carvoejar",
    "carvoejaste": "carvoejar",
    "carvoejastes": "carvoejar",
    "carvoejava": "carvoejar",
    "carvoejavam": "carvoejar",
    "carvoejavas": "carvoejar",
    "carvoeje": "carvoejar",
    "carvoejei": "carvoejar",
    "carvoejeis": "carvoejar",
    "carvoejem": "carvoejar",
    "carvoejemo": "carvoejar",
    "carvoejemos": "carvoejar",
    "carvoejes": "carvoejar",
    "carvoejo": "carvoejar",
    "carvoejou": "carvoejar",
    "carvoejámo": "carvoejar",
    "carvoejámos": "carvoejar",
    "carvoejáramo": "carvoejar",
    "carvoejáramos": "carvoejar",
    "carvoejáreis": "carvoejar",
    "carvoejásseis": "carvoejar",
    "carvoejássemos": "carvoejar",
    "carvoejávamo": "carvoejar",
    "carvoejávamos": "carvoejar",
    "carvoejáveis": "carvoejar",
    "carvoenta": "carvoento",
    "carvoentas": "carvoento",
    "carvoentos": "carvoento",
    "carvoíços": "carvoíço",
    "carvões": "carvão",
    "carábidas": "carábida",
    "caráceas": "carácea",
    "carângidas": "carângida",
    "carências": "carência",
    "carícias": "carícia",
    "caríssima": "caro",
    "caríssimas": "caro",
    "caríssimo": "caro",
    "caríssimos": "caro",
    "carófitas": "carófita",
    "carótica": "carótico",
    "caróticas": "carótico",
    "caróticos": "carótico",
    "carótidas": "carótida",
    "carótides": "carótide",
    "carões": "carão",
    "carúnculas": "carúncula",
    "casa": "casar",
    "casabeques": "casabeque",
    "casacas": "casaca",
    "casacos": "casaco",
    "casacudos": "casacudo",
    "casacões": "casacão",
    "casada": "casar",
    "casadas": "casar",
    "casadeira": "casadeiro",
    "casadeiras": "casadeiro",
    "casadeiros": "casadeiro",
    "casadinha": "casado",
    "casadinhas": "casado",
    "casadinho": "casado",
    "casadinhos": "casado",
    "casadita": "casado",
    "casaditas": "casado",
    "casadito": "casado",
    "casaditos": "casado",
    "casadiça": "casadiço",
    "casadiças": "casadiço",
    "casadiços": "casadiço",
    "casado": "casar",
    "casadoira": "casadoiro",
    "casadoiras": "casadoiro",
    "casadoiros": "casadoiro",
    "casados": "casar",
    "casadoura": "casadouro",
    "casadouras": "casadouro",
    "casadouros": "casadouro",
    "casadíssima": "casado",
    "casadíssimas": "casado",
    "casadíssimo": "casado",
    "casadíssimos": "casado",
    "casai": "casar",
    "casais": "casar",
    "casaizinhos": "casal",
    "casaizitos": "casal",
    "casala": "casalar",
    "casalada": "casalar",
    "casaladas": "casalar",
    "casalado": "casalar",
    "casalados": "casalar",
    "casalai": "casalar",
    "casalais": "casalar",
    "casalam": "casalar",
    "casalamo": "casalar",
    "casalamos": "casalar",
    "casalando": "casalar",
    "casalara": "casalar",
    "casalaram": "casalar",
    "casalaras": "casalar",
    "casalarde": "casalar",
    "casalardes": "casalar",
    "casalare": "casalar",
    "casalarei": "casalar",
    "casalareis": "casalar",
    "casalarem": "casalar",
    "casalaremos": "casalar",
    "casalares": "casalar",
    "casalaria": "casalar",
    "casalariam": "casalar",
    "casalarias": "casalar",
    "casalarmo": "casalar",
    "casalarmos": "casalar",
    "casalará": "casalar",
    "casalarás": "casalar",
    "casalarão": "casalar",
    "casalaríamos": "casalar",
    "casalaríeis": "casalar",
    "casalas": "casalar",
    "casalasse": "casalar",
    "casalassem": "casalar",
    "casalasses": "casalar",
    "casalaste": "casalar",
    "casalastes": "casalar",
    "casalava": "casalar",
    "casalavam": "casalar",
    "casalavas": "casalar",
    "casale": "casalar",
    "casalei": "casalar",
    "casaleira": "casaleiro",
    "casaleiras": "casaleiro",
    "casaleiros": "casaleiro",
    "casaleis": "casalar",
    "casalejos": "casalejo",
    "casalem": "casalar",
    "casalemo": "casalar",
    "casalemos": "casalar",
    "casales": "casalar",
    "casalinho": "casal",
    "casalinhos": "casal",
    "casalito": "casal",
    "casalitos": "casal",
    "casalo": "casalar",
    "casalou": "casalar",
    "casalzinho": "casal",
    "casalzito": "casal",
    "casalá": "casalar",
    "casalámo": "casalar",
    "casalámos": "casalar",
    "casaláramo": "casalar",
    "casaláramos": "casalar",
    "casalárei": "casalar",
    "casaláreis": "casalar",
    "casalásseis": "casalar",
    "casalássemos": "casalar",
    "casalávamo": "casalar",
    "casalávamos": "casalar",
    "casalávei": "casalar",
    "casaláveis": "casalar",
    "casam": "casar",
    "casamata": "casamatar",
    "casamatada": "casamatar",
    "casamatadas": "casamatar",
    "casamatado": "casamatar",
    "casamatados": "casamatar",
    "casamatai": "casamatar",
    "casamatais": "casamatar",
    "casamatam": "casamatar",
    "casamatamo": "casamatar",
    "casamatamos": "casamatar",
    "casamatando": "casamatar",
    "casamatara": "casamatar",
    "casamataram": "casamatar",
    "casamataras": "casamatar",
    "casamatarde": "casamatar",
    "casamatardes": "casamatar",
    "casamatare": "casamatar",
    "casamatarei": "casamatar",
    "casamatareis": "casamatar",
    "casamatarem": "casamatar",
    "casamataremos": "casamatar",
    "casamatares": "casamatar",
    "casamataria": "casamatar",
    "casamatariam": "casamatar",
    "casamatarias": "casamatar",
    "casamatarmo": "casamatar",
    "casamatarmos": "casamatar",
    "casamatará": "casamatar",
    "casamatarás": "casamatar",
    "casamatarão": "casamatar",
    "casamataríamos": "casamatar",
    "casamataríeis": "casamatar",
    "casamatas": "casamatar",
    "casamatasse": "casamatar",
    "casamatassem": "casamatar",
    "casamatasses": "casamatar",
    "casamataste": "casamatar",
    "casamatastes": "casamatar",
    "casamatava": "casamatar",
    "casamatavam": "casamatar",
    "casamatavas": "casamatar",
    "casamate": "casamatar",
    "casamatei": "casamatar",
    "casamateira": "casamateiro",
    "casamateiras": "casamateiro",
    "casamateiros": "casamateiro",
    "casamateis": "casamatar",
    "casamatem": "casamatar",
    "casamatemo": "casamatar",
    "casamatemos": "casamatar",
    "casamates": "casamatar",
    "casamato": "casamatar",
    "casamatou": "casamatar",
    "casamatá": "casamatar",
    "casamatámo": "casamatar",
    "casamatámos": "casamatar",
    "casamatáramo": "casamatar",
    "casamatáramos": "casamatar",
    "casamatárei": "casamatar",
    "casamatáreis": "casamatar",
    "casamatásseis": "casamatar",
    "casamatássemos": "casamatar",
    "casamatávamo": "casamatar",
    "casamatávamos": "casamatar",
    "casamatávei": "casamatar",
    "casamatáveis": "casamatar",
    "casamenta": "casamentar",
    "casamentada": "casamentar",
    "casamentadas": "casamentar",
    "casamentado": "casamentar",
    "casamentados": "casamentar",
    "casamentai": "casamentar",
    "casamentais": "casamentar",
    "casamentam": "casamentar",
    "casamentamo": "casamentar",
    "casamentamos": "casamentar",
    "casamentando": "casamentar",
    "casamentara": "casamentar",
    "casamentaram": "casamentar",
    "casamentaras": "casamentar",
    "casamentarde": "casamentar",
    "casamentardes": "casamentar",
    "casamentare": "casamentar",
    "casamentarei": "casamentar",
    "casamentareis": "casamentar",
    "casamentarem": "casamentar",
    "casamentaremos": "casamentar",
    "casamentares": "casamentar",
    "casamentaria": "casamentar",
    "casamentariam": "casamentar",
    "casamentarias": "casamentar",
    "casamentarmo": "casamentar",
    "casamentarmos": "casamentar",
    "casamentará": "casamentar",
    "casamentarás": "casamentar",
    "casamentarão": "casamentar",
    "casamentaríamos": "casamentar",
    "casamentaríeis": "casamentar",
    "casamentas": "casamentar",
    "casamentasse": "casamentar",
    "casamentassem": "casamentar",
    "casamentasses": "casamentar",
    "casamentaste": "casamentar",
    "casamentastes": "casamentar",
    "casamentava": "casamentar",
    "casamentavam": "casamentar",
    "casamentavas": "casamentar",
    "casamente": "casamentar",
    "casamentei": "casamentar",
    "casamenteira": "casamenteiro",
    "casamenteiras": "casamenteiro",
    "casamenteiros": "casamenteiro",
    "casamenteis": "casamentar",
    "casamentem": "casamentar",
    "casamentemo": "casamentar",
    "casamentemos": "casamentar",
    "casamentes": "casamentar",
    "casamento": "casamentar",
    "casamentos": "casamento",
    "casamentou": "casamentar",
    "casamentá": "casamentar",
    "casamentámo": "casamentar",
    "casamentámos": "casamentar",
    "casamentáramo": "casamentar",
    "casamentáramos": "casamentar",
    "casamentárei": "casamentar",
    "casamentáreis": "casamentar",
    "casamentásseis": "casamentar",
    "casamentássemos": "casamentar",
    "casamentávamo": "casamentar",
    "casamentávamos": "casamentar",
    "casamentávei": "casamentar",
    "casamentáveis": "casamentar",
    "casamo": "casar",
    "casamos": "casar",
    "casando": "casar",
    "casanovas": "casanova",
    "casantes": "casante",
    "casaquelhos": "casaquelho",
    "casaquilhas": "casaquilha",
    "casaquinha": "casaca",
    "casaquinhas": "casaca",
    "casaquinho": "casaco",
    "casaquinhos": "casaco",
    "casaquita": "casaca",
    "casaquitas": "casaca",
    "casaquito": "casaco",
    "casaquitos": "casaco",
    "casara": "casar",
    "casaram": "casar",
    "casaras": "casar",
    "casarde": "casar",
    "casardes": "casar",
    "casare": "casar",
    "casarei": "casar",
    "casareis": "casar",
    "casarem": "casar",
    "casaremos": "casar",
    "casares": "casar",
    "casaria": "casar",
    "casariam": "casar",
    "casarias": "casaria",
    "casarios": "casario",
    "casarmo": "casar",
    "casarmos": "casar",
    "casaronas": "casarona",
    "casarredos": "casarredo",
    "casará": "casar",
    "casarás": "casar",
    "casarão": "casar",
    "casaréus": "casaréu",
    "casaríamos": "casar",
    "casaríeis": "casar",
    "casarões": "casarão",
    "casas": "casar",
    "casasse": "casar",
    "casassem": "casar",
    "casasses": "casar",
    "casaste": "casar",
    "casastes": "casar",
    "casava": "casar",
    "casavam": "casar",
    "casavas": "casar",
    "casca": "cascar",
    "cascabulha": "cascabulhar",
    "cascabulhada": "cascabulhar",
    "cascabulhadas": "cascabulhar",
    "cascabulhado": "cascabulhar",
    "cascabulhados": "cascabulhar",
    "cascabulhagens": "cascabulhagem",
    "cascabulhai": "cascabulhar",
    "cascabulhais": "cascabulhar",
    "cascabulham": "cascabulhar",
    "cascabulhamo": "cascabulhar",
    "cascabulhamos": "cascabulhar",
    "cascabulhando": "cascabulhar",
    "cascabulhara": "cascabulhar",
    "cascabulharam": "cascabulhar",
    "cascabulharas": "cascabulhar",
    "cascabulharde": "cascabulhar",
    "cascabulhardes": "cascabulhar",
    "cascabulhare": "cascabulhar",
    "cascabulharei": "cascabulhar",
    "cascabulhareis": "cascabulhar",
    "cascabulharem": "cascabulhar",
    "cascabulharemos": "cascabulhar",
    "cascabulhares": "cascabulhar",
    "cascabulharia": "cascabulhar",
    "cascabulhariam": "cascabulhar",
    "cascabulharias": "cascabulhar",
    "cascabulharmo": "cascabulhar",
    "cascabulharmos": "cascabulhar",
    "cascabulhará": "cascabulhar",
    "cascabulharás": "cascabulhar",
    "cascabulharão": "cascabulhar",
    "cascabulharíamos": "cascabulhar",
    "cascabulharíeis": "cascabulhar",
    "cascabulhas": "cascabulhar",
    "cascabulhasse": "cascabulhar",
    "cascabulhassem": "cascabulhar",
    "cascabulhasses": "cascabulhar",
    "cascabulhaste": "cascabulhar",
    "cascabulhastes": "cascabulhar",
    "cascabulhava": "cascabulhar",
    "cascabulhavam": "cascabulhar",
    "cascabulhavas": "cascabulhar",
    "cascabulhe": "cascabulhar",
    "cascabulhei": "cascabulhar",
    "cascabulheis": "cascabulhar",
    "cascabulhem": "cascabulhar",
    "cascabulhemo": "cascabulhar",
    "cascabulhemos": "cascabulhar",
    "cascabulhes": "cascabulhar",
    "cascabulho": "cascabulhar",
    "cascabulhos": "cascabulho",
    "cascabulhou": "cascabulhar",
    "cascabulhá": "cascabulhar",
    "cascabulhámo": "cascabulhar",
    "cascabulhámos": "cascabulhar",
    "cascabulháramo": "cascabulhar",
    "cascabulháramos": "cascabulhar",
    "cascabulhárei": "cascabulhar",
    "cascabulháreis": "cascabulhar",
    "cascabulhásseis": "cascabulhar",
    "cascabulhássemos": "cascabulhar",
    "cascabulhávamo": "cascabulhar",
    "cascabulhávamos": "cascabulhar",
    "cascabulhávei": "cascabulhar",
    "cascabulháveis": "cascabulhar",
    "cascada": "cascar",
    "cascadas": "cascar",
    "cascado": "cascar",
    "cascados": "cascar",
    "cascaenses": "cascaense",
    "cascais": "cascar",
    "cascalha": "cascalhar",
    "cascalhada": "cascalhar",
    "cascalhadas": "cascalhar",
    "cascalhado": "cascalhar",
    "cascalhados": "cascalhar",
    "cascalhai": "cascalhar",
    "cascalhais": "cascalhar",
    "cascalham": "cascalhar",
    "cascalhamo": "cascalhar",
    "cascalhamos": "cascalhar",
    "cascalhando": "cascalhar",
    "cascalhara": "cascalhar",
    "cascalharam": "cascalhar",
    "cascalharas": "cascalhar",
    "cascalhardes": "cascalhar",
    "cascalharei": "cascalhar",
    "cascalhareis": "cascalhar",
    "cascalharem": "cascalhar",
    "cascalharemos": "cascalhar",
    "cascalhares": "cascalhar",
    "cascalharia": "cascalhar",
    "cascalhariam": "cascalhar",
    "cascalharias": "cascalhar",
    "cascalharmo": "cascalhar",
    "cascalharmos": "cascalhar",
    "cascalhará": "cascalhar",
    "cascalharás": "cascalhar",
    "cascalharão": "cascalhar",
    "cascalharíamos": "cascalhar",
    "cascalharíeis": "cascalhar",
    "cascalhas": "cascalhar",
    "cascalhasse": "cascalhar",
    "cascalhassem": "cascalhar",
    "cascalhasses": "cascalhar",
    "cascalhaste": "cascalhar",
    "cascalhastes": "cascalhar",
    "cascalhava": "cascalhar",
    "cascalhavam": "cascalhar",
    "cascalhavas": "cascalhar",
    "cascalhe": "cascalhar",
    "cascalhei": "cascalhar",
    "cascalheiras": "cascalheira",
    "cascalheis": "cascalhar",
    "cascalhem": "cascalhar",
    "cascalhemo": "cascalhar",
    "cascalhemos": "cascalhar",
    "cascalhenta": "cascalhento",
    "cascalhentas": "cascalhento",
    "cascalhentos": "cascalhento",
    "cascalhes": "cascalhar",
    "cascalhinhos": "cascalhinho",
    "cascalho": "cascalhar",
    "cascalhos": "cascalho",
    "cascalhosa": "cascalhoso",
    "cascalhosas": "cascalhoso",
    "cascalhosos": "cascalhoso",
    "cascalhou": "cascalhar",
    "cascalhuda": "cascalhudo",
    "cascalhudas": "cascalhudo",
    "cascalhudos": "cascalhudo",
    "cascalhámo": "cascalhar",
    "cascalhámos": "cascalhar",
    "cascalháramo": "cascalhar",
    "cascalháramos": "cascalhar",
    "cascalháreis": "cascalhar",
    "cascalhásseis": "cascalhar",
    "cascalhássemos": "cascalhar",
    "cascalhávamo": "cascalhar",
    "cascalhávamos": "cascalhar",
    "cascalháveis": "cascalhar",
    "cascalva": "cascalvo",
    "cascalvas": "cascalvo",
    "cascalvos": "cascalvo",
    "cascam": "cascar",
    "cascamo": "cascar",
    "cascamos": "cascar",
    "cascando": "cascar",
    "cascara": "cascar",
    "cascaram": "cascar",
    "cascaras": "cascar",
    "cascardes": "cascar",
    "cascarei": "cascar",
    "cascareis": "cascar",
    "cascarem": "cascar",
    "cascaremos": "cascar",
    "cascares": "cascar",
    "cascaria": "cascar",
    "cascariam": "cascar",
    "cascarias": "cascaria",
    "cascarilhas": "cascarilha",
    "cascarinas": "cascarina",
    "cascarmo": "cascar",
    "cascarmos": "cascar",
    "cascarras": "cascarra",
    "cascarrilhas": "cascarrilha",
    "cascarrolhos": "cascarrolho",
    "cascarrões": "cascarrão",
    "cascará": "cascar",
    "cascarás": "cascar",
    "cascarão": "cascar",
    "cascaríamos": "cascar",
    "cascaríeis": "cascar",
    "cascas": "cascar",
    "cascasse": "cascar",
    "cascassem": "cascar",
    "cascasses": "cascar",
    "cascaste": "cascar",
    "cascastes": "cascar",
    "cascatas": "cascata",
    "cascatazinha": "cascata",
    "cascatazinhas": "cascata",
    "cascatazita": "cascata",
    "cascatazitas": "cascata",
    "cascateada": "cascatear",
    "cascateadas": "cascatear",
    "cascateado": "cascatear",
    "cascateados": "cascatear",
    "cascateai": "cascatear",
    "cascateais": "cascatear",
    "cascateamo": "cascatear",
    "cascateamos": "cascatear",
    "cascateando": "cascatear",
    "cascateara": "cascatear",
    "cascatearam": "cascatear",
    "cascatearas": "cascatear",
    "cascateardes": "cascatear",
    "cascatearei": "cascatear",
    "cascateareis": "cascatear",
    "cascatearem": "cascatear",
    "cascatearemos": "cascatear",
    "cascateares": "cascatear",
    "cascatearia": "cascatear",
    "cascateariam": "cascatear",
    "cascatearias": "cascatear",
    "cascatearmo": "cascatear",
    "cascatearmos": "cascatear",
    "cascateará": "cascatear",
    "cascatearás": "cascatear",
    "cascatearão": "cascatear",
    "cascatearíamos": "cascatear",
    "cascatearíeis": "cascatear",
    "cascateasse": "cascatear",
    "cascateassem": "cascatear",
    "cascateasses": "cascatear",
    "cascateaste": "cascatear",
    "cascateastes": "cascatear",
    "cascateava": "cascatear",
    "cascateavam": "cascatear",
    "cascateavas": "cascatear",
    "cascateei": "cascatear",
    "cascateeis": "cascatear",
    "cascateemo": "cascatear",
    "cascateemos": "cascatear",
    "cascateia": "cascatear",
    "cascateiam": "cascatear",
    "cascateias": "cascatear",
    "cascateie": "cascatear",
    "cascateiem": "cascatear",
    "cascateies": "cascatear",
    "cascateio": "cascatear",
    "cascateou": "cascatear",
    "cascateámo": "cascatear",
    "cascateámos": "cascatear",
    "cascateáramo": "cascatear",
    "cascateáramos": "cascatear",
    "cascateáreis": "cascatear",
    "cascateásseis": "cascatear",
    "cascateássemos": "cascatear",
    "cascateávamo": "cascatear",
    "cascateávamos": "cascatear",
    "cascateáveis": "cascatear",
    "cascava": "cascar",
    "cascavam": "cascar",
    "cascavas": "cascar",
    "cascaveis": "cascavel",
    "casco": "cascar",
    "cascos": "casco",
    "cascosa": "cascoso",
    "cascosas": "cascoso",
    "cascosos": "cascoso",
    "cascou": "cascar",
    "cascuda": "cascudo",
    "cascudas": "cascudo",
    "cascudos": "cascudo",
    "cascámo": "cascar",
    "cascámos": "cascar",
    "cascáramo": "cascar",
    "cascáramos": "cascar",
    "cascáreis": "cascar",
    "cascásseis": "cascar",
    "cascássemos": "cascar",
    "cascávamo": "cascar",
    "cascávamos": "cascar",
    "cascáveis": "cascar",
    "cascões": "cascão",
    "case": "casar",
    "caseada": "casear",
    "caseadas": "casear",
    "caseado": "casear",
    "caseados": "casear",
    "caseai": "casear",
    "caseais": "casear",
    "caseamo": "casear",
    "caseamos": "casear",
    "caseando": "casear",
    "caseara": "casear",
    "casearam": "casear",
    "casearas": "casear",
    "casearde": "casear",
    "caseardes": "casear",
    "caseare": "casear",
    "casearei": "casear",
    "caseareis": "casear",
    "casearem": "casear",
    "casearemos": "casear",
    "caseares": "casear",
    "casearia": "casear",
    "caseariam": "casear",
    "casearias": "casear",
    "casearmo": "casear",
    "casearmos": "casear",
    "caseará": "casear",
    "casearás": "casear",
    "casearão": "casear",
    "casearíamos": "casear",
    "casearíeis": "casear",
    "caseases": "casease",
    "caseasse": "casear",
    "caseassem": "casear",
    "caseasses": "casear",
    "caseaste": "casear",
    "caseastes": "casear",
    "caseava": "casear",
    "caseavam": "casear",
    "caseavas": "casear",
    "caseações": "caseação",
    "casebeques": "casebeque",
    "casebres": "casebre",
    "caseei": "casear",
    "caseeis": "casear",
    "caseemo": "casear",
    "caseemos": "casear",
    "casei": "casar",
    "caseia": "casear",
    "caseiam": "casear",
    "caseias": "casear",
    "caseie": "casear",
    "caseiem": "casear",
    "caseies": "casear",
    "caseifica": "caseificar",
    "caseificada": "caseificar",
    "caseificadas": "caseificar",
    "caseificado": "caseificar",
    "caseificados": "caseificar",
    "caseificai": "caseificar",
    "caseificais": "caseificar",
    "caseificam": "caseificar",
    "caseificamo": "caseificar",
    "caseificamos": "caseificar",
    "caseificando": "caseificar",
    "caseificara": "caseificar",
    "caseificaram": "caseificar",
    "caseificaras": "caseificar",
    "caseificarde": "caseificar",
    "caseificardes": "caseificar",
    "caseificare": "caseificar",
    "caseificarei": "caseificar",
    "caseificareis": "caseificar",
    "caseificarem": "caseificar",
    "caseificaremos": "caseificar",
    "caseificares": "caseificar",
    "caseificaria": "caseificar",
    "caseificariam": "caseificar",
    "caseificarias": "caseificar",
    "caseificarmo": "caseificar",
    "caseificarmos": "caseificar",
    "caseificará": "caseificar",
    "caseificarás": "caseificar",
    "caseificarão": "caseificar",
    "caseificaríamos": "caseificar",
    "caseificaríeis": "caseificar",
    "caseificas": "caseificar",
    "caseificasse": "caseificar",
    "caseificassem": "caseificar",
    "caseificasses": "caseificar",
    "caseificaste": "caseificar",
    "caseificastes": "caseificar",
    "caseificava": "caseificar",
    "caseificavam": "caseificar",
    "caseificavas": "caseificar",
    "caseificações": "caseificação",
    "caseifico": "caseificar",
    "caseificou": "caseificar",
    "caseificá": "caseificar",
    "caseificámo": "caseificar",
    "caseificámos": "caseificar",
    "caseificáramo": "caseificar",
    "caseificáramos": "caseificar",
    "caseificárei": "caseificar",
    "caseificáreis": "caseificar",
    "caseificásseis": "caseificar",
    "caseificássemos": "caseificar",
    "caseificávamo": "caseificar",
    "caseificávamos": "caseificar",
    "caseificávei": "caseificar",
    "caseificáveis": "caseificar",
    "caseifique": "caseificar",
    "caseifiquei": "caseificar",
    "caseifiqueis": "caseificar",
    "caseifiquem": "caseificar",
    "caseifiquemo": "caseificar",
    "caseifiquemos": "caseificar",
    "caseifiques": "caseificar",
    "caseiformes": "caseiforme",
    "caseinogénica": "caseinogénico",
    "caseinogénicas": "caseinogénico",
    "caseinogénicos": "caseinogénico",
    "caseinogénios": "caseinogénio",
    "caseio": "casear",
    "caseira": "caseiro",
    "caseiras": "caseiro",
    "caseiros": "caseiro",
    "caseis": "casar",
    "casem": "casar",
    "casemo": "casar",
    "casemos": "casar",
    "caseosa": "caseoso",
    "caseosas": "caseoso",
    "caseosos": "caseoso",
    "caseou": "casear",
    "casernas": "caserna",
    "caserneirais": "caserneiral",
    "caserneiros": "caserneiro",
    "cases": "casar",
    "caseá": "casear",
    "caseámo": "casear",
    "caseámos": "casear",
    "caseáramo": "casear",
    "caseáramos": "casear",
    "caseárei": "casear",
    "caseáreis": "casear",
    "caseásseis": "casear",
    "caseássemos": "casear",
    "caseávamo": "casear",
    "caseávamos": "casear",
    "caseávei": "casear",
    "caseáveis": "casear",
    "caseínas": "caseína",
    "caseínica": "caseínico",
    "caseínicas": "caseínico",
    "caseínicos": "caseínico",
    "casibeques": "casibeque",
    "casimiras": "casimira",
    "casinha": "casa",
    "casinhas": "casinha",
    "casinholas": "casinhola",
    "casinholos": "casinholo",
    "casinhotas": "casinhota",
    "casinhotos": "casinhoto",
    "casinos": "casino",
    "casita": "casa",
    "casitas": "casita",
    "casitéus": "casitéu",
    "casmurra": "casmurro",
    "casmurrada": "casmurrar",
    "casmurradas": "casmurrar",
    "casmurrado": "casmurrar",
    "casmurrados": "casmurrar",
    "casmurrai": "casmurrar",
    "casmurrais": "casmurrar",
    "casmurram": "casmurrar",
    "casmurramo": "casmurrar",
    "casmurramos": "casmurrar",
    "casmurrando": "casmurrar",
    "casmurrara": "casmurrar",
    "casmurraram": "casmurrar",
    "casmurraras": "casmurrar",
    "casmurrardes": "casmurrar",
    "casmurrarei": "casmurrar",
    "casmurrareis": "casmurrar",
    "casmurrarem": "casmurrar",
    "casmurraremos": "casmurrar",
    "casmurrares": "casmurrar",
    "casmurraria": "casmurrar",
    "casmurrariam": "casmurrar",
    "casmurrarias": "casmurrar",
    "casmurrarmo": "casmurrar",
    "casmurrarmos": "casmurrar",
    "casmurrará": "casmurrar",
    "casmurrarás": "casmurrar",
    "casmurrarão": "casmurrar",
    "casmurraríamos": "casmurrar",
    "casmurraríeis": "casmurrar",
    "casmurras": "casmurro",
    "casmurrasse": "casmurrar",
    "casmurrassem": "casmurrar",
    "casmurrasses": "casmurrar",
    "casmurraste": "casmurrar",
    "casmurrastes": "casmurrar",
    "casmurrava": "casmurrar",
    "casmurravam": "casmurrar",
    "casmurravas": "casmurrar",
    "casmurre": "casmurrar",
    "casmurrei": "casmurrar",
    "casmurreis": "casmurrar",
    "casmurrem": "casmurrar",
    "casmurremo": "casmurrar",
    "casmurremos": "casmurrar",
    "casmurres": "casmurrar",
    "casmurrices": "casmurrice",
    "casmurro": "casmurrar",
    "casmurros": "casmurro",
    "casmurrou": "casmurrar",
    "casmurrámo": "casmurrar",
    "casmurrámos": "casmurrar",
    "casmurráramo": "casmurrar",
    "casmurráramos": "casmurrar",
    "casmurráreis": "casmurrar",
    "casmurrásseis": "casmurrar",
    "casmurrássemos": "casmurrar",
    "casmurrávamo": "casmurrar",
    "casmurrávamos": "casmurrar",
    "casmurráveis": "casmurrar",
    "caso": "casar",
    "casos": "caso",
    "casotas": "casota",
    "casotos": "casoto",
    "casou": "casar",
    "caspachos": "caspacho",
    "caspas": "caspa",
    "caspenta": "caspento",
    "caspentas": "caspento",
    "caspentos": "caspento",
    "casposa": "casposo",
    "casposas": "casposo",
    "casposos": "casposo",
    "casque": "cascar",
    "casquei": "cascar",
    "casqueiras": "casqueira",
    "casqueiros": "casqueiro",
    "casqueis": "cascar",
    "casqueja": "casquejar",
    "casquejada": "casquejar",
    "casquejadas": "casquejar",
    "casquejado": "casquejar",
    "casquejados": "casquejar",
    "casquejai": "casquejar",
    "casquejais": "casquejar",
    "casquejam": "casquejar",
    "casquejamo": "casquejar",
    "casquejamos": "casquejar",
    "casquejando": "casquejar",
    "casquejara": "casquejar",
    "casquejaram": "casquejar",
    "casquejaras": "casquejar",
    "casquejardes": "casquejar",
    "casquejarei": "casquejar",
    "casquejareis": "casquejar",
    "casquejarem": "casquejar",
    "casquejaremos": "casquejar",
    "casquejares": "casquejar",
    "casquejaria": "casquejar",
    "casquejariam": "casquejar",
    "casquejarias": "casquejar",
    "casquejarmo": "casquejar",
    "casquejarmos": "casquejar",
    "casquejará": "casquejar",
    "casquejarás": "casquejar",
    "casquejarão": "casquejar",
    "casquejaríamos": "casquejar",
    "casquejaríeis": "casquejar",
    "casquejas": "casquejar",
    "casquejasse": "casquejar",
    "casquejassem": "casquejar",
    "casquejasses": "casquejar",
    "casquejaste": "casquejar",
    "casquejastes": "casquejar",
    "casquejava": "casquejar",
    "casquejavam": "casquejar",
    "casquejavas": "casquejar",
    "casqueje": "casquejar",
    "casquejei": "casquejar",
    "casquejeis": "casquejar",
    "casquejem": "casquejar",
    "casquejemo": "casquejar",
    "casquejemos": "casquejar",
    "casquejes": "casquejar",
    "casquejo": "casquejar",
    "casquejou": "casquejar",
    "casquejámo": "casquejar",
    "casquejámos": "casquejar",
    "casquejáramo": "casquejar",
    "casquejáramos": "casquejar",
    "casquejáreis": "casquejar",
    "casquejásseis": "casquejar",
    "casquejássemos": "casquejar",
    "casquejávamo": "casquejar",
    "casquejávamos": "casquejar",
    "casquejáveis": "casquejar",
    "casquem": "cascar",
    "casquemos": "cascar",
    "casquenta": "casquento",
    "casquentas": "casquento",
    "casquentos": "casquento",
    "casques": "cascar",
    "casquetas": "casqueta",
    "casquetes": "casquete",
    "casquibranda": "casquibrando",
    "casquibrandas": "casquibrando",
    "casquibrandos": "casquibrando",
    "casquilha": "casquilho",
    "casquilhada": "casquilhar",
    "casquilhadas": "casquilhar",
    "casquilhado": "casquilhar",
    "casquilhados": "casquilhar",
    "casquilhai": "casquilhar",
    "casquilhais": "casquilhar",
    "casquilham": "casquilhar",
    "casquilhamo": "casquilhar",
    "casquilhamos": "casquilhar",
    "casquilhando": "casquilhar",
    "casquilhara": "casquilhar",
    "casquilharam": "casquilhar",
    "casquilharas": "casquilhar",
    "casquilhardes": "casquilhar",
    "casquilharei": "casquilhar",
    "casquilhareis": "casquilhar",
    "casquilharem": "casquilhar",
    "casquilharemos": "casquilhar",
    "casquilhares": "casquilhar",
    "casquilharia": "casquilhar",
    "casquilhariam": "casquilhar",
    "casquilharias": "casquilharia",
    "casquilharmo": "casquilhar",
    "casquilharmos": "casquilhar",
    "casquilhará": "casquilhar",
    "casquilharás": "casquilhar",
    "casquilharão": "casquilhar",
    "casquilharíamos": "casquilhar",
    "casquilharíeis": "casquilhar",
    "casquilhas": "casquilho",
    "casquilhasse": "casquilhar",
    "casquilhassem": "casquilhar",
    "casquilhasses": "casquilhar",
    "casquilhaste": "casquilhar",
    "casquilhastes": "casquilhar",
    "casquilhava": "casquilhar",
    "casquilhavam": "casquilhar",
    "casquilhavas": "casquilhar",
    "casquilhe": "casquilhar",
    "casquilhei": "casquilhar",
    "casquilheira": "casquilheiro",
    "casquilheiras": "casquilheiro",
    "casquilheiros": "casquilheiro",
    "casquilheis": "casquilhar",
    "casquilhem": "casquilhar",
    "casquilhemo": "casquilhar",
    "casquilhemos": "casquilhar",
    "casquilhes": "casquilhar",
    "casquilhices": "casquilhice",
    "casquilho": "casquilhar",
    "casquilhos": "casquilho",
    "casquilhou": "casquilhar",
    "casquilhámo": "casquilhar",
    "casquilhámos": "casquilhar",
    "casquilháramo": "casquilhar",
    "casquilháramos": "casquilhar",
    "casquilháreis": "casquilhar",
    "casquilhásseis": "casquilhar",
    "casquilhássemos": "casquilhar",
    "casquilhávamo": "casquilhar",
    "casquilhávamos": "casquilhar",
    "casquilháveis": "casquilhar",
    "casquimoles": "casquimole",
    "casquina": "casquinar",
    "casquinada": "casquinar",
    "casquinadas": "casquinar",
    "casquinado": "casquinar",
    "casquinados": "casquinar",
    "casquinai": "casquinar",
    "casquinais": "casquinar",
    "casquinam": "casquinar",
    "casquinamo": "casquinar",
    "casquinamos": "casquinar",
    "casquinando": "casquinar",
    "casquinara": "casquinar",
    "casquinaram": "casquinar",
    "casquinaras": "casquinar",
    "casquinardes": "casquinar",
    "casquinarei": "casquinar",
    "casquinareis": "casquinar",
    "casquinarem": "casquinar",
    "casquinaremos": "casquinar",
    "casquinares": "casquinar",
    "casquinaria": "casquinar",
    "casquinariam": "casquinar",
    "casquinarias": "casquinar",
    "casquinarmo": "casquinar",
    "casquinarmos": "casquinar",
    "casquinará": "casquinar",
    "casquinarás": "casquinar",
    "casquinarão": "casquinar",
    "casquinaríamos": "casquinar",
    "casquinaríeis": "casquinar",
    "casquinas": "casquinar",
    "casquinasse": "casquinar",
    "casquinassem": "casquinar",
    "casquinasses": "casquinar",
    "casquinaste": "casquinar",
    "casquinastes": "casquinar",
    "casquinava": "casquinar",
    "casquinavam": "casquinar",
    "casquinavas": "casquinar",
    "casquine": "casquinar",
    "casquinei": "casquinar",
    "casquineis": "casquinar",
    "casquinem": "casquinar",
    "casquinemo": "casquinar",
    "casquinemos": "casquinar",
    "casquines": "casquinar",
    "casquinha": "casca",
    "casquinhas": "casquinha",
    "casquinheiros": "casquinheiro",
    "casquino": "casquinar",
    "casquinou": "casquinar",
    "casquinámo": "casquinar",
    "casquinámos": "casquinar",
    "casquináramo": "casquinar",
    "casquináramos": "casquinar",
    "casquináreis": "casquinar",
    "casquinásseis": "casquinar",
    "casquinássemos": "casquinar",
    "casquinávamo": "casquinar",
    "casquinávamos": "casquinar",
    "casquináveis": "casquinar",
    "casquita": "casca",
    "casquitas": "casca",
    "cassa": "casso",
    "cassacos": "cassaco",
    "cassada": "cassar",
    "cassadas": "cassar",
    "cassado": "cassar",
    "cassados": "cassar",
    "cassai": "cassar",
    "cassais": "cassar",
    "cassam": "cassar",
    "cassamo": "cassar",
    "cassamos": "cassar",
    "cassando": "cassar",
    "cassanges": "cassange",
    "cassara": "cassar",
    "cassaram": "cassar",
    "cassaras": "cassar",
    "cassarde": "cassar",
    "cassardes": "cassar",
    "cassare": "cassar",
    "cassarei": "cassar",
    "cassareis": "cassar",
    "cassarem": "cassar",
    "cassaremos": "cassar",
    "cassares": "cassar",
    "cassaria": "cassar",
    "cassariam": "cassar",
    "cassarias": "cassar",
    "cassarmo": "cassar",
    "cassarmos": "cassar",
    "cassará": "cassar",
    "cassarás": "cassar",
    "cassarão": "cassar",
    "cassaríamos": "cassar",
    "cassaríeis": "cassar",
    "cassas": "casso",
    "cassasse": "cassar",
    "cassassem": "cassar",
    "cassasses": "cassar",
    "cassaste": "cassar",
    "cassastes": "cassar",
    "cassatas": "cassata",
    "cassava": "cassar",
    "cassavam": "cassar",
    "cassavas": "cassar",
    "cassações": "cassação",
    "casse": "cassar",
    "casseada": "cassear",
    "casseadas": "cassear",
    "casseado": "cassear",
    "casseados": "cassear",
    "casseai": "cassear",
    "casseais": "cassear",
    "casseamo": "cassear",
    "casseamos": "cassear",
    "casseando": "cassear",
    "casseara": "cassear",
    "cassearam": "cassear",
    "cassearas": "cassear",
    "cassearde": "cassear",
    "casseardes": "cassear",
    "casseare": "cassear",
    "cassearei": "cassear",
    "casseareis": "cassear",
    "cassearem": "cassear",
    "cassearemos": "cassear",
    "casseares": "cassear",
    "cassearia": "cassear",
    "casseariam": "cassear",
    "cassearias": "cassear",
    "cassearmo": "cassear",
    "cassearmos": "cassear",
    "casseará": "cassear",
    "cassearás": "cassear",
    "cassearão": "cassear",
    "cassearíamos": "cassear",
    "cassearíeis": "cassear",
    "casseasse": "cassear",
    "casseassem": "cassear",
    "casseasses": "cassear",
    "casseaste": "cassear",
    "casseastes": "cassear",
    "casseava": "cassear",
    "casseavam": "cassear",
    "casseavas": "cassear",
    "casseei": "cassear",
    "casseeis": "cassear",
    "casseemo": "cassear",
    "casseemos": "cassear",
    "cassei": "cassar",
    "casseia": "cassear",
    "casseiam": "cassear",
    "casseias": "cassear",
    "casseie": "cassear",
    "casseiem": "cassear",
    "casseies": "cassear",
    "casseio": "cassear",
    "casseis": "cassar",
    "cassem": "cassar",
    "cassemo": "cassar",
    "cassemos": "cassar",
    "cassenges": "cassenge",
    "casseou": "cassear",
    "casses": "casse",
    "cassetes": "cassete",
    "cassetetes": "cassetete",
    "cassettes": "cassette",
    "casseá": "cassear",
    "casseámo": "cassear",
    "casseámos": "cassear",
    "casseáramo": "cassear",
    "casseáramos": "cassear",
    "casseárei": "cassear",
    "casseáreis": "cassear",
    "casseásseis": "cassear",
    "casseássemos": "cassear",
    "casseávamo": "cassear",
    "casseávamos": "cassear",
    "casseávei": "cassear",
    "casseáveis": "cassear",
    "cassiafístulas": "cassiafístula",
    "cassidária": "cassidário",
    "cassidárias": "cassidário",
    "cassidários": "cassidário",
    "cassidídea": "cassidídeo",
    "cassidídeas": "cassidídeo",
    "cassidídeos": "cassidídeo",
    "cassidónias": "cassidónia",
    "cassinas": "cassina",
    "cassinetas": "cassineta",
    "cassinos": "cassino",
    "cassiterites": "cassiterite",
    "casso": "cassar",
    "cassoas": "cassoa",
    "cassoiros": "cassoiro",
    "cassos": "casso",
    "cassou": "cassar",
    "cassouros": "cassouro",
    "cassunga": "cassungo",
    "cassungas": "cassungo",
    "cassungos": "cassungo",
    "cassá": "cassar",
    "cassámo": "cassar",
    "cassámos": "cassar",
    "cassáramo": "cassar",
    "cassáramos": "cassar",
    "cassárei": "cassar",
    "cassáreis": "cassar",
    "cassásseis": "cassar",
    "cassássemos": "cassar",
    "cassávamo": "cassar",
    "cassávamos": "cassar",
    "cassávei": "cassar",
    "cassáveis": "cassável",
    "cassídidas": "cassídida",
    "casta": "casto",
    "castanha": "castanho",
    "castanhais": "castanhal",
    "castanhas": "castanho",
    "castanhazinha": "castanho",
    "castanhazinhas": "castanho",
    "castanhazita": "castanho",
    "castanhazitas": "castanho",
    "castanhedos": "castanhedo",
    "castanheira": "castanheiro",
    "castanheiras": "castanheiro",
    "castanheiros": "castanheiro",
    "castanhetas": "castanheta",
    "castanhinha": "castanho",
    "castanhinhas": "castanho",
    "castanhinho": "castanho",
    "castanhinhos": "castanho",
    "castanhita": "castanho",
    "castanhitas": "castanho",
    "castanhito": "castanho",
    "castanhitos": "castanho",
    "castanhois": "castanhoi",
    "castanhola": "castanholar",
    "castanholada": "castanholar",
    "castanholadas": "castanholar",
    "castanholado": "castanholar",
    "castanholados": "castanholar",
    "castanholai": "castanholar",
    "castanholais": "castanholar",
    "castanholam": "castanholar",
    "castanholamo": "castanholar",
    "castanholamos": "castanholar",
    "castanholando": "castanholar",
    "castanholara": "castanholar",
    "castanholaram": "castanholar",
    "castanholaras": "castanholar",
    "castanholardes": "castanholar",
    "castanholarei": "castanholar",
    "castanholareis": "castanholar",
    "castanholarem": "castanholar",
    "castanholaremos": "castanholar",
    "castanholares": "castanholar",
    "castanholaria": "castanholar",
    "castanholariam": "castanholar",
    "castanholarias": "castanholar",
    "castanholarmo": "castanholar",
    "castanholarmos": "castanholar",
    "castanholará": "castanholar",
    "castanholarás": "castanholar",
    "castanholarão": "castanholar",
    "castanholaríamos": "castanholar",
    "castanholaríeis": "castanholar",
    "castanholas": "castanholar",
    "castanholasse": "castanholar",
    "castanholassem": "castanholar",
    "castanholasses": "castanholar",
    "castanholaste": "castanholar",
    "castanholastes": "castanholar",
    "castanholava": "castanholar",
    "castanholavam": "castanholar",
    "castanholavas": "castanholar",
    "castanhole": "castanholar",
    "castanholei": "castanholar",
    "castanholeis": "castanholar",
    "castanholem": "castanholar",
    "castanholemo": "castanholar",
    "castanholemos": "castanholar",
    "castanholes": "castanholar",
    "castanholo": "castanholar",
    "castanholou": "castanholar",
    "castanholámo": "castanholar",
    "castanholámos": "castanholar",
    "castanholáramo": "castanholar",
    "castanholáramos": "castanholar",
    "castanholáreis": "castanholar",
    "castanholásseis": "castanholar",
    "castanholássemos": "castanholar",
    "castanholávamo": "castanholar",
    "castanholávamos": "castanholar",
    "castanholáveis": "castanholar",
    "castanhos": "castanho",
    "castanhosa": "castanhoso",
    "castanhosas": "castanhoso",
    "castanhosos": "castanhoso",
    "castanhozinho": "castanho",
    "castanhozinhos": "castanho",
    "castanhozito": "castanho",
    "castanhozitos": "castanho",
    "castas": "casto",
    "castazinha": "casto",
    "castazinhas": "casto",
    "castazita": "casto",
    "castazitas": "casto",
    "castelanias": "castelania",
    "castelarias": "castelaria",
    "casteleira": "casteleiro",
    "casteleiras": "casteleiro",
    "casteleiros": "casteleiro",
    "castelejos": "castelejo",
    "casteletas": "casteleta",
    "castelhana": "castelhano",
    "castelhanas": "castelhano",
    "castelhanismos": "castelhanismo",
    "castelhaniza": "castelhanizar",
    "castelhanizada": "castelhanizar",
    "castelhanizadas": "castelhanizar",
    "castelhanizado": "castelhanizar",
    "castelhanizados": "castelhanizar",
    "castelhanizai": "castelhanizar",
    "castelhanizais": "castelhanizar",
    "castelhanizam": "castelhanizar",
    "castelhanizamo": "castelhanizar",
    "castelhanizamos": "castelhanizar",
    "castelhanizando": "castelhanizar",
    "castelhanizara": "castelhanizar",
    "castelhanizaram": "castelhanizar",
    "castelhanizaras": "castelhanizar",
    "castelhanizarde": "castelhanizar",
    "castelhanizardes": "castelhanizar",
    "castelhanizare": "castelhanizar",
    "castelhanizarei": "castelhanizar",
    "castelhanizareis": "castelhanizar",
    "castelhanizarem": "castelhanizar",
    "castelhanizaremos": "castelhanizar",
    "castelhanizares": "castelhanizar",
    "castelhanizaria": "castelhanizar",
    "castelhanizariam": "castelhanizar",
    "castelhanizarias": "castelhanizar",
    "castelhanizarmo": "castelhanizar",
    "castelhanizarmos": "castelhanizar",
    "castelhanizará": "castelhanizar",
    "castelhanizarás": "castelhanizar",
    "castelhanizarão": "castelhanizar",
    "castelhanizaríamos": "castelhanizar",
    "castelhanizaríeis": "castelhanizar",
    "castelhanizas": "castelhanizar",
    "castelhanizasse": "castelhanizar",
    "castelhanizassem": "castelhanizar",
    "castelhanizasses": "castelhanizar",
    "castelhanizaste": "castelhanizar",
    "castelhanizastes": "castelhanizar",
    "castelhanizava": "castelhanizar",
    "castelhanizavam": "castelhanizar",
    "castelhanizavas": "castelhanizar",
    "castelhanize": "castelhanizar",
    "castelhanizei": "castelhanizar",
    "castelhanizeis": "castelhanizar",
    "castelhanizem": "castelhanizar",
    "castelhanizemo": "castelhanizar",
    "castelhanizemos": "castelhanizar",
    "castelhanizes": "castelhanizar",
    "castelhanizo": "castelhanizar",
    "castelhanizou": "castelhanizar",
    "castelhanizá": "castelhanizar",
    "castelhanizámo": "castelhanizar",
    "castelhanizámos": "castelhanizar",
    "castelhanizáramo": "castelhanizar",
    "castelhanizáramos": "castelhanizar",
    "castelhanizárei": "castelhanizar",
    "castelhanizáreis": "castelhanizar",
    "castelhanizásseis": "castelhanizar",
    "castelhanizássemos": "castelhanizar",
    "castelhanizávamo": "castelhanizar",
    "castelhanizávamos": "castelhanizar",
    "castelhanizávei": "castelhanizar",
    "castelhanizáveis": "castelhanizável",
    "castelhanos": "castelhano",
    "castelinho": "castelo",
    "castelinhos": "castelo",
    "castelito": "castelo",
    "castelitos": "castelo",
    "casteloas": "casteloa",
    "castelos": "castelo",
    "castelã": "castelão",
    "castelãos": "castelão",
    "castelãs": "castelão",
    "castelórios": "castelório",
    "castelões": "castelão",
    "castice": "castiçar",
    "casticei": "castiçar",
    "casticeis": "castiçar",
    "casticem": "castiçar",
    "casticemo": "castiçar",
    "casticemos": "castiçar",
    "castices": "castiçar",
    "casticidades": "casticidade",
    "casticismos": "casticismo",
    "castidades": "castidade",
    "castifica": "castificar",
    "castificada": "castificar",
    "castificadas": "castificar",
    "castificado": "castificar",
    "castificados": "castificar",
    "castificai": "castificar",
    "castificais": "castificar",
    "castificam": "castificar",
    "castificamo": "castificar",
    "castificamos": "castificar",
    "castificando": "castificar",
    "castificara": "castificar",
    "castificaram": "castificar",
    "castificaras": "castificar",
    "castificarde": "castificar",
    "castificardes": "castificar",
    "castificare": "castificar",
    "castificarei": "castificar",
    "castificareis": "castificar",
    "castificarem": "castificar",
    "castificaremos": "castificar",
    "castificares": "castificar",
    "castificaria": "castificar",
    "castificariam": "castificar",
    "castificarias": "castificar",
    "castificarmo": "castificar",
    "castificarmos": "castificar",
    "castificará": "castificar",
    "castificarás": "castificar",
    "castificarão": "castificar",
    "castificaríamos": "castificar",
    "castificaríeis": "castificar",
    "castificas": "castificar",
    "castificasse": "castificar",
    "castificassem": "castificar",
    "castificasses": "castificar",
    "castificaste": "castificar",
    "castificastes": "castificar",
    "castificava": "castificar",
    "castificavam": "castificar",
    "castificavas": "castificar",
    "castificações": "castificação",
    "castifico": "castificar",
    "castificou": "castificar",
    "castificá": "castificar",
    "castificámo": "castificar",
    "castificámos": "castificar",
    "castificáramo": "castificar",
    "castificáramos": "castificar",
    "castificárei": "castificar",
    "castificáreis": "castificar",
    "castificásseis": "castificar",
    "castificássemos": "castificar",
    "castificávamo": "castificar",
    "castificávamos": "castificar",
    "castificávei": "castificar",
    "castificáveis": "castificar",
    "castifique": "castificar",
    "castifiquei": "castificar",
    "castifiqueis": "castificar",
    "castifiquem": "castificar",
    "castifiquemo": "castificar",
    "castifiquemos": "castificar",
    "castifiques": "castificar",
    "castiga": "castigar",
    "castigada": "castigar",
    "castigadas": "castigar",
    "castigado": "castigar",
    "castigadora": "castigador",
    "castigadoras": "castigador",
    "castigadores": "castigador",
    "castigados": "castigar",
    "castigadíssima": "castigado",
    "castigadíssimas": "castigado",
    "castigadíssimo": "castigado",
    "castigadíssimos": "castigado",
    "castigai": "castigar",
    "castigais": "castigar",
    "castigam": "castigar",
    "castigamo": "castigar",
    "castigamos": "castigar",
    "castigando": "castigar",
    "castigara": "castigar",
    "castigaram": "castigar",
    "castigaras": "castigar",
    "castigarde": "castigar",
    "castigardes": "castigar",
    "castigare": "castigar",
    "castigarei": "castigar",
    "castigareis": "castigar",
    "castigarem": "castigar",
    "castigaremos": "castigar",
    "castigares": "castigar",
    "castigaria": "castigar",
    "castigariam": "castigar",
    "castigarias": "castigar",
    "castigarmo": "castigar",
    "castigarmos": "castigar",
    "castigará": "castigar",
    "castigarás": "castigar",
    "castigarão": "castigar",
    "castigaríamos": "castigar",
    "castigaríeis": "castigar",
    "castigas": "castigar",
    "castigasse": "castigar",
    "castigassem": "castigar",
    "castigasses": "castigar",
    "castigaste": "castigar",
    "castigastes": "castigar",
    "castigava": "castigar",
    "castigavam": "castigar",
    "castigavas": "castigar",
    "castigações": "castigação",
    "castigo": "castigar",
    "castigos": "castigo",
    "castigou": "castigar",
    "castigue": "castigar",
    "castiguei": "castigar",
    "castigueiras": "castigueira",
    "castigueis": "castigar",
    "castiguem": "castigar",
    "castiguemo": "castigar",
    "castiguemos": "castigar",
    "castigues": "castigar",
    "castigá": "castigar",
    "castigámo": "castigar",
    "castigámos": "castigar",
    "castigáramo": "castigar",
    "castigáramos": "castigar",
    "castigárei": "castigar",
    "castigáreis": "castigar",
    "castigásseis": "castigar",
    "castigássemos": "castigar",
    "castigávamo": "castigar",
    "castigávamos": "castigar",
    "castigávei": "castigar",
    "castigáveis": "castigável",
    "castinas": "castina",
    "castinceiras": "castinceira",
    "castinceiros": "castinceiro",
    "castings": "casting",
    "castinhas": "castinha",
    "castinçais": "castinçal",
    "castiça": "castiço",
    "castiçada": "castiçar",
    "castiçadas": "castiçar",
    "castiçado": "castiçar",
    "castiçados": "castiçar",
    "castiçai": "castiçar",
    "castiçais": "castiçar",
    "castiçam": "castiçar",
    "castiçamo": "castiçar",
    "castiçamos": "castiçar",
    "castiçando": "castiçar",
    "castiçara": "castiçar",
    "castiçaram": "castiçar",
    "castiçaras": "castiçar",
    "castiçarde": "castiçar",
    "castiçardes": "castiçar",
    "castiçare": "castiçar",
    "castiçarei": "castiçar",
    "castiçareis": "castiçar",
    "castiçarem": "castiçar",
    "castiçaremos": "castiçar",
    "castiçares": "castiçar",
    "castiçaria": "castiçar",
    "castiçariam": "castiçar",
    "castiçarias": "castiçar",
    "castiçarmo": "castiçar",
    "castiçarmos": "castiçar",
    "castiçará": "castiçar",
    "castiçarás": "castiçar",
    "castiçarão": "castiçar",
    "castiçaríamos": "castiçar",
    "castiçaríeis": "castiçar",
    "castiças": "castiço",
    "castiçasse": "castiçar",
    "castiçassem": "castiçar",
    "castiçasses": "castiçar",
    "castiçaste": "castiçar",
    "castiçastes": "castiçar",
    "castiçava": "castiçar",
    "castiçavam": "castiçar",
    "castiçavas": "castiçar",
    "castiçazinha": "castiço",
    "castiçazinhas": "castiço",
    "castiçazita": "castiço",
    "castiçazitas": "castiço",
    "castiço": "castiçar",
    "castiços": "castiço",
    "castiçou": "castiçar",
    "castiçozinho": "castiço",
    "castiçozinhos": "castiço",
    "castiçozito": "castiço",
    "castiçozitos": "castiço",
    "castiçá": "castiçar",
    "castiçámo": "castiçar",
    "castiçámos": "castiçar",
    "castiçáramo": "castiçar",
    "castiçáramos": "castiçar",
    "castiçárei": "castiçar",
    "castiçáreis": "castiçar",
    "castiçásseis": "castiçar",
    "castiçássemos": "castiçar",
    "castiçávamo": "castiçar",
    "castiçávamos": "castiçar",
    "castiçávei": "castiçar",
    "castiçáveis": "castiçar",
    "castorenha": "castorenho",
    "castorenhas": "castorenho",
    "castorenhos": "castorenho",
    "castores": "castor",
    "castorinas": "castorina",
    "castorídea": "castorídeo",
    "castorídeas": "castorídeo",
    "castorídeos": "castorídeo",
    "castos": "casto",
    "castozinho": "casto",
    "castozinhos": "casto",
    "castozito": "casto",
    "castozitos": "casto",
    "castra": "castrar",
    "castrada": "castrar",
    "castradas": "castrar",
    "castrado": "castrar",
    "castradora": "castrador",
    "castradoras": "castrador",
    "castradores": "castrador",
    "castrados": "castrar",
    "castrai": "castrar",
    "castrais": "castrar",
    "castram": "castrar",
    "castramentos": "castramento",
    "castrametações": "castrametação",
    "castramo": "castrar",
    "castramos": "castrar",
    "castrando": "castrar",
    "castrantes": "castrante",
    "castrara": "castrar",
    "castraram": "castrar",
    "castraras": "castrar",
    "castrarde": "castrar",
    "castrardes": "castrar",
    "castrare": "castrar",
    "castrarei": "castrar",
    "castrareis": "castrar",
    "castrarem": "castrar",
    "castraremos": "castrar",
    "castrares": "castrar",
    "castraria": "castrar",
    "castrariam": "castrar",
    "castrarias": "castrar",
    "castrarmo": "castrar",
    "castrarmos": "castrar",
    "castrará": "castrar",
    "castrarás": "castrar",
    "castrarão": "castrar",
    "castraríamos": "castrar",
    "castraríeis": "castrar",
    "castras": "castrar",
    "castrasse": "castrar",
    "castrassem": "castrar",
    "castrasses": "castrar",
    "castraste": "castrar",
    "castrastes": "castrar",
    "castrava": "castrar",
    "castravam": "castrar",
    "castravas": "castrar",
    "castrações": "castração",
    "castre": "castrar",
    "castrei": "castrar",
    "castreis": "castrar",
    "castreja": "castrejo",
    "castrejas": "castrejo",
    "castrejos": "castrejo",
    "castrelos": "castrelo",
    "castrem": "castrar",
    "castremo": "castrar",
    "castremos": "castrar",
    "castrenses": "castrense",
    "castres": "castrar",
    "castrismos": "castrismo",
    "castristas": "castrista",
    "castro": "castrar",
    "castros": "castro",
    "castrou": "castrar",
    "castrá": "castrar",
    "castrámo": "castrar",
    "castrámos": "castrar",
    "castráramo": "castrar",
    "castráramos": "castrar",
    "castrárei": "castrar",
    "castráreis": "castrar",
    "castrásseis": "castrar",
    "castrássemos": "castrar",
    "castrávamo": "castrar",
    "castrávamos": "castrar",
    "castrávei": "castrar",
    "castráveis": "castrável",
    "castânea": "castâneo",
    "castâneas": "castâneo",
    "castâneos": "castâneo",
    "castórea": "castóreo",
    "castóreas": "castóreo",
    "castóreos": "castóreo",
    "castóridas": "castórida",
    "castões": "castão",
    "casuais": "casual",
    "casualidades": "casualidade",
    "casualismos": "casualismo",
    "casualistas": "casualista",
    "casuares": "casuar",
    "casuarinas": "casuarina",
    "casuarinácea": "casuarináceo",
    "casuarináceas": "casuarináceo",
    "casuarináceos": "casuarináceo",
    "casuarídea": "casuarídeo",
    "casuarídeas": "casuarídeo",
    "casuarídeos": "casuarídeo",
    "casulas": "casula",
    "casulos": "casulo",
    "casulosa": "casuloso",
    "casulosas": "casuloso",
    "casulosos": "casuloso",
    "casuáridas": "casuárida",
    "casuísmos": "casuísmo",
    "casuístas": "casuísta",
    "casuística": "casuístico",
    "casuísticas": "casuístico",
    "casuísticos": "casuístico",
    "casá": "casar",
    "casámo": "casar",
    "casámos": "casar",
    "casáramo": "casar",
    "casáramos": "casar",
    "casárei": "casar",
    "casáreis": "casar",
    "casásseis": "casar",
    "casássemos": "casar",
    "casávamo": "casar",
    "casávamos": "casar",
    "casávei": "casar",
    "casáveis": "casável",
    "casórios": "casório",
    "casões": "casão",
    "cata": "catar",
    "catabaptismos": "catabaptismo",
    "catabaptistas": "catabaptista",
    "catabolismos": "catabolismo",
    "catabática": "catabático",
    "catabáticas": "catabático",
    "catabáticos": "catabático",
    "catabólica": "catabólico",
    "catabólicas": "catabólico",
    "catabólicos": "catabólico",
    "cataclases": "cataclase",
    "cataclasitos": "cataclasito",
    "cataclismos": "cataclismo",
    "cataclítica": "cataclítico",
    "cataclíticas": "cataclítico",
    "cataclíticos": "cataclítico",
    "catacreses": "catacrese",
    "catacrética": "catacrético",
    "catacréticas": "catacrético",
    "catacréticos": "catacrético",
    "catacumbas": "catacumba",
    "catacuses": "catacus",
    "catacáustica": "catacáustico",
    "catacáusticas": "catacáustico",
    "catacáusticos": "catacáustico",
    "catacústica": "catacústico",
    "catacústicas": "catacústico",
    "catacústicos": "catacústico",
    "catada": "catar",
    "catadas": "catar",
    "catadeira": "catador",
    "catadeiras": "catador",
    "catadióptrica": "catadióptrico",
    "catadióptricas": "catadióptrico",
    "catadióptricos": "catadióptrico",
    "catado": "catar",
    "catadora": "catador",
    "catadoras": "catador",
    "catadores": "catador",
    "catados": "catar",
    "catadupas": "catadupa",
    "catadupeja": "catadupejar",
    "catadupejada": "catadupejar",
    "catadupejadas": "catadupejar",
    "catadupejado": "catadupejar",
    "catadupejados": "catadupejar",
    "catadupejai": "catadupejar",
    "catadupejais": "catadupejar",
    "catadupejam": "catadupejar",
    "catadupejamo": "catadupejar",
    "catadupejamos": "catadupejar",
    "catadupejando": "catadupejar",
    "catadupejara": "catadupejar",
    "catadupejaram": "catadupejar",
    "catadupejaras": "catadupejar",
    "catadupejardes": "catadupejar",
    "catadupejarei": "catadupejar",
    "catadupejareis": "catadupejar",
    "catadupejarem": "catadupejar",
    "catadupejaremos": "catadupejar",
    "catadupejares": "catadupejar",
    "catadupejaria": "catadupejar",
    "catadupejariam": "catadupejar",
    "catadupejarias": "catadupejar",
    "catadupejarmo": "catadupejar",
    "catadupejarmos": "catadupejar",
    "catadupejará": "catadupejar",
    "catadupejarás": "catadupejar",
    "catadupejarão": "catadupejar",
    "catadupejaríamos": "catadupejar",
    "catadupejaríeis": "catadupejar",
    "catadupejas": "catadupejar",
    "catadupejasse": "catadupejar",
    "catadupejassem": "catadupejar",
    "catadupejasses": "catadupejar",
    "catadupejaste": "catadupejar",
    "catadupejastes": "catadupejar",
    "catadupejava": "catadupejar",
    "catadupejavam": "catadupejar",
    "catadupejavas": "catadupejar",
    "catadupeje": "catadupejar",
    "catadupejei": "catadupejar",
    "catadupejeis": "catadupejar",
    "catadupejem": "catadupejar",
    "catadupejemo": "catadupejar",
    "catadupejemos": "catadupejar",
    "catadupejes": "catadupejar",
    "catadupejo": "catadupejar",
    "catadupejou": "catadupejar",
    "catadupejámo": "catadupejar",
    "catadupejámos": "catadupejar",
    "catadupejáramo": "catadupejar",
    "catadupejáramos": "catadupejar",
    "catadupejáreis": "catadupejar",
    "catadupejásseis": "catadupejar",
    "catadupejássemos": "catadupejar",
    "catadupejávamo": "catadupejar",
    "catadupejávamos": "catadupejar",
    "catadupejáveis": "catadupejar",
    "cataduras": "catadura",
    "catafalcos": "catafalco",
    "catafasias": "catafasia",
    "catafeda": "catafeder",
    "catafedais": "catafeder",
    "catafedam": "catafeder",
    "catafedamo": "catafeder",
    "catafedamos": "catafeder",
    "catafedas": "catafeder",
    "catafede": "catafeder",
    "catafedei": "catafeder",
    "catafedeis": "catafeder",
    "catafedem": "catafeder",
    "catafedemo": "catafeder",
    "catafedemos": "catafeder",
    "catafedendo": "catafeder",
    "catafedera": "catafeder",
    "catafederam": "catafeder",
    "catafederas": "catafeder",
    "catafederdes": "catafeder",
    "catafederei": "catafeder",
    "catafedereis": "catafeder",
    "catafederem": "catafeder",
    "catafederemos": "catafeder",
    "catafederes": "catafeder",
    "catafederia": "catafeder",
    "catafederiam": "catafeder",
    "catafederias": "catafeder",
    "catafedermo": "catafeder",
    "catafedermos": "catafeder",
    "catafederá": "catafeder",
    "catafederás": "catafeder",
    "catafederão": "catafeder",
    "catafederíamos": "catafeder",
    "catafederíeis": "catafeder",
    "catafedes": "catafeder",
    "catafedesse": "catafeder",
    "catafedessem": "catafeder",
    "catafedesses": "catafeder",
    "catafedeste": "catafeder",
    "catafedestes": "catafeder",
    "catafedeu": "catafeder",
    "catafedi": "catafeder",
    "catafedia": "catafeder",
    "catafediam": "catafeder",
    "catafedias": "catafeder",
    "catafedida": "catafeder",
    "catafedidas": "catafeder",
    "catafedido": "catafeder",
    "catafedidos": "catafeder",
    "catafedo": "catafeder",
    "catafedêramo": "catafeder",
    "catafedêramos": "catafeder",
    "catafedêreis": "catafeder",
    "catafedêsseis": "catafeder",
    "catafedêssemos": "catafeder",
    "catafedíamo": "catafeder",
    "catafedíamos": "catafeder",
    "catafedíeis": "catafeder",
    "catafonias": "catafonia",
    "cataforeses": "cataforese",
    "catafractas": "catafracta",
    "catafractária": "catafractário",
    "catafractárias": "catafractário",
    "catafractários": "catafractário",
    "catafásica": "catafásico",
    "catafásicas": "catafásico",
    "catafásicos": "catafásico",
    "catafónica": "catafónico",
    "catafónicas": "catafónico",
    "catafónicos": "catafónico",
    "cataglossos": "cataglosso",
    "cataglotismos": "cataglotismo",
    "cataglóssios": "cataglóssio",
    "cataglótica": "cataglótico",
    "cataglóticas": "cataglótico",
    "cataglóticos": "cataglótico",
    "catai": "catar",
    "catais": "catar",
    "catalectos": "catalecto",
    "catalepsias": "catalepsia",
    "catalisa": "catalisar",
    "catalisada": "catalisar",
    "catalisadas": "catalisar",
    "catalisado": "catalisar",
    "catalisadora": "catalisador",
    "catalisadoras": "catalisador",
    "catalisadores": "catalisador",
    "catalisados": "catalisar",
    "catalisai": "catalisar",
    "catalisais": "catalisar",
    "catalisam": "catalisar",
    "catalisamo": "catalisar",
    "catalisamos": "catalisar",
    "catalisando": "catalisar",
    "catalisara": "catalisar",
    "catalisaram": "catalisar",
    "catalisaras": "catalisar",
    "catalisarde": "catalisar",
    "catalisardes": "catalisar",
    "catalisare": "catalisar",
    "catalisarei": "catalisar",
    "catalisareis": "catalisar",
    "catalisarem": "catalisar",
    "catalisaremos": "catalisar",
    "catalisares": "catalisar",
    "catalisaria": "catalisar",
    "catalisariam": "catalisar",
    "catalisarias": "catalisar",
    "catalisarmo": "catalisar",
    "catalisarmos": "catalisar",
    "catalisará": "catalisar",
    "catalisarás": "catalisar",
    "catalisarão": "catalisar",
    "catalisaríamos": "catalisar",
    "catalisaríeis": "catalisar",
    "catalisas": "catalisar",
    "catalisasse": "catalisar",
    "catalisassem": "catalisar",
    "catalisasses": "catalisar",
    "catalisaste": "catalisar",
    "catalisastes": "catalisar",
    "catalisava": "catalisar",
    "catalisavam": "catalisar",
    "catalisavas": "catalisar",
    "catalise": "catalisar",
    "catalisei": "catalisar",
    "cataliseis": "catalisar",
    "catalisem": "catalisar",
    "catalisemo": "catalisar",
    "catalisemos": "catalisar",
    "catalises": "catalisar",
    "cataliso": "catalisar",
    "catalisou": "catalisar",
    "catalisá": "catalisar",
    "catalisámo": "catalisar",
    "catalisámos": "catalisar",
    "catalisáramo": "catalisar",
    "catalisáramos": "catalisar",
    "catalisárei": "catalisar",
    "catalisáreis": "catalisar",
    "catalisásseis": "catalisar",
    "catalisássemos": "catalisar",
    "catalisávamo": "catalisar",
    "catalisávamos": "catalisar",
    "catalisávei": "catalisar",
    "catalisáveis": "catalisável",
    "cataloga": "catalogar",
    "catalogada": "catalogar",
    "catalogadas": "catalogar",
    "catalogado": "catalogar",
    "catalogadora": "catalogador",
    "catalogadoras": "catalogador",
    "catalogadores": "catalogador",
    "catalogados": "catalogar",
    "catalogai": "catalogar",
    "catalogais": "catalogar",
    "catalogam": "catalogar",
    "catalogamo": "catalogar",
    "catalogamos": "catalogar",
    "catalogando": "catalogar",
    "catalogara": "catalogar",
    "catalogaram": "catalogar",
    "catalogaras": "catalogar",
    "catalogarde": "catalogar",
    "catalogardes": "catalogar",
    "catalogare": "catalogar",
    "catalogarei": "catalogar",
    "catalogareis": "catalogar",
    "catalogarem": "catalogar",
    "catalogaremos": "catalogar",
    "catalogares": "catalogar",
    "catalogaria": "catalogar",
    "catalogariam": "catalogar",
    "catalogarias": "catalogar",
    "catalogarmo": "catalogar",
    "catalogarmos": "catalogar",
    "catalogará": "catalogar",
    "catalogarás": "catalogar",
    "catalogarão": "catalogar",
    "catalogaríamos": "catalogar",
    "catalogaríeis": "catalogar",
    "catalogas": "catalogar",
    "catalogasse": "catalogar",
    "catalogassem": "catalogar",
    "catalogasses": "catalogar",
    "catalogaste": "catalogar",
    "catalogastes": "catalogar",
    "catalogava": "catalogar",
    "catalogavam": "catalogar",
    "catalogavas": "catalogar",
    "catalogações": "catalogação",
    "catalogo": "catalogar",
    "catalogou": "catalogar",
    "catalografias": "catalografia",
    "catalográfica": "catalográfico",
    "catalográficas": "catalográfico",
    "catalográficos": "catalográfico",
    "catalogue": "catalogar",
    "cataloguei": "catalogar",
    "catalogueis": "catalogar",
    "cataloguem": "catalogar",
    "cataloguemo": "catalogar",
    "cataloguemos": "catalogar",
    "catalogues": "catalogar",
    "catalogá": "catalogar",
    "catalogámo": "catalogar",
    "catalogámos": "catalogar",
    "catalogáramo": "catalogar",
    "catalogáramos": "catalogar",
    "catalogárei": "catalogar",
    "catalogáreis": "catalogar",
    "catalogásseis": "catalogar",
    "catalogássemos": "catalogar",
    "catalogávamo": "catalogar",
    "catalogávamos": "catalogar",
    "catalogávei": "catalogar",
    "catalogáveis": "catalogável",
    "catalunas": "cataluna",
    "catalásica": "catalásico",
    "catalásicas": "catalásico",
    "catalásicos": "catalásico",
    "catalã": "catalão",
    "catalães": "catalão",
    "catalãs": "catalão",
    "cataléctica": "cataléctico",
    "catalécticas": "cataléctico",
    "catalécticos": "cataléctico",
    "catalépsica": "catalépsico",
    "catalépsicas": "catalépsico",
    "catalépsicos": "catalépsico",
    "cataléptica": "cataléptico",
    "catalépticas": "cataléptico",
    "catalépticos": "cataléptico",
    "catalítica": "catalítico",
    "catalíticas": "catalítico",
    "catalíticos": "catalítico",
    "catam": "catar",
    "catamarãs": "catamarã",
    "catameniais": "catamenial",
    "catamentos": "catamento",
    "catamo": "catar",
    "catamos": "catar",
    "cataménica": "cataménico",
    "cataménicas": "cataménico",
    "cataménicos": "cataménico",
    "cataménios": "cataménio",
    "catanadas": "catanada",
    "catanas": "catana",
    "catando": "catar",
    "catanguesa": "catanguês",
    "catanguesas": "catanguês",
    "catangueses": "catanguês",
    "catanos": "catano",
    "catapereiros": "catapereiro",
    "cataplasma": "cataplasmar",
    "cataplasmada": "cataplasmar",
    "cataplasmadas": "cataplasmar",
    "cataplasmado": "cataplasmar",
    "cataplasmados": "cataplasmar",
    "cataplasmai": "cataplasmar",
    "cataplasmais": "cataplasmar",
    "cataplasmam": "cataplasmar",
    "cataplasmamo": "cataplasmar",
    "cataplasmamos": "cataplasmar",
    "cataplasmando": "cataplasmar",
    "cataplasmara": "cataplasmar",
    "cataplasmaram": "cataplasmar",
    "cataplasmaras": "cataplasmar",
    "cataplasmarde": "cataplasmar",
    "cataplasmardes": "cataplasmar",
    "cataplasmare": "cataplasmar",
    "cataplasmarei": "cataplasmar",
    "cataplasmareis": "cataplasmar",
    "cataplasmarem": "cataplasmar",
    "cataplasmaremos": "cataplasmar",
    "cataplasmares": "cataplasmar",
    "cataplasmaria": "cataplasmar",
    "cataplasmariam": "cataplasmar",
    "cataplasmarias": "cataplasmar",
    "cataplasmarmo": "cataplasmar",
    "cataplasmarmos": "cataplasmar",
    "cataplasmará": "cataplasmar",
    "cataplasmarás": "cataplasmar",
    "cataplasmarão": "cataplasmar",
    "cataplasmaríamos": "cataplasmar",
    "cataplasmaríeis": "cataplasmar",
    "cataplasmas": "cataplasmar",
    "cataplasmasse": "cataplasmar",
    "cataplasmassem": "cataplasmar",
    "cataplasmasses": "cataplasmar",
    "cataplasmaste": "cataplasmar",
    "cataplasmastes": "cataplasmar",
    "cataplasmava": "cataplasmar",
    "cataplasmavam": "cataplasmar",
    "cataplasmavas": "cataplasmar",
    "cataplasme": "cataplasmar",
    "cataplasmei": "cataplasmar",
    "cataplasmeis": "cataplasmar",
    "cataplasmem": "cataplasmar",
    "cataplasmemo": "cataplasmar",
    "cataplasmemos": "cataplasmar",
    "cataplasmes": "cataplasmar",
    "cataplasmo": "cataplasmar",
    "cataplasmou": "cataplasmar",
    "cataplasmá": "cataplasmar",
    "cataplasmámo": "cataplasmar",
    "cataplasmámos": "cataplasmar",
    "cataplasmáramo": "cataplasmar",
    "cataplasmáramos": "cataplasmar",
    "cataplasmárei": "cataplasmar",
    "cataplasmáreis": "cataplasmar",
    "cataplasmásseis": "cataplasmar",
    "cataplasmássemos": "cataplasmar",
    "cataplasmávamo": "cataplasmar",
    "cataplasmávamos": "cataplasmar",
    "cataplasmávei": "cataplasmar",
    "cataplasmáveis": "cataplasmar",
    "cataplexias": "cataplexia",
    "catapreiros": "catapreiro",
    "cataptoses": "cataptose",
    "cataptótica": "cataptótico",
    "cataptóticas": "cataptótico",
    "cataptóticos": "cataptótico",
    "catapulta": "catapultar",
    "catapultada": "catapultar",
    "catapultadas": "catapultar",
    "catapultado": "catapultar",
    "catapultados": "catapultar",
    "catapultai": "catapultar",
    "catapultais": "catapultar",
    "catapultam": "catapultar",
    "catapultamo": "catapultar",
    "catapultamos": "catapultar",
    "catapultando": "catapultar",
    "catapultara": "catapultar",
    "catapultaram": "catapultar",
    "catapultaras": "catapultar",
    "catapultarde": "catapultar",
    "catapultardes": "catapultar",
    "catapultare": "catapultar",
    "catapultarei": "catapultar",
    "catapultareis": "catapultar",
    "catapultarem": "catapultar",
    "catapultaremos": "catapultar",
    "catapultares": "catapultar",
    "catapultaria": "catapultar",
    "catapultariam": "catapultar",
    "catapultarias": "catapultar",
    "catapultarmo": "catapultar",
    "catapultarmos": "catapultar",
    "catapultará": "catapultar",
    "catapultarás": "catapultar",
    "catapultarão": "catapultar",
    "catapultaríamos": "catapultar",
    "catapultaríeis": "catapultar",
    "catapultas": "catapultar",
    "catapultasse": "catapultar",
    "catapultassem": "catapultar",
    "catapultasses": "catapultar",
    "catapultaste": "catapultar",
    "catapultastes": "catapultar",
    "catapultava": "catapultar",
    "catapultavam": "catapultar",
    "catapultavas": "catapultar",
    "catapulte": "catapultar",
    "catapultei": "catapultar",
    "catapulteis": "catapultar",
    "catapultem": "catapultar",
    "catapultemo": "catapultar",
    "catapultemos": "catapultar",
    "catapultes": "catapultar",
    "catapulto": "catapultar",
    "catapultou": "catapultar",
    "catapultá": "catapultar",
    "catapultámo": "catapultar",
    "catapultámos": "catapultar",
    "catapultáramo": "catapultar",
    "catapultáramos": "catapultar",
    "catapultárei": "catapultar",
    "catapultáreis": "catapultar",
    "catapultásseis": "catapultar",
    "catapultássemos": "catapultar",
    "catapultávamo": "catapultar",
    "catapultávamos": "catapultar",
    "catapultávei": "catapultar",
    "catapultáveis": "catapultar",
    "catara": "catar",
    "cataram": "catar",
    "cataras": "catar",
    "cataratas": "catarata",
    "catarde": "catar",
    "catardes": "catar",
    "catare": "catar",
    "catarei": "catar",
    "catareis": "catar",
    "catarem": "catar",
    "cataremos": "catar",
    "catares": "catar",
    "cataria": "catar",
    "catariam": "catar",
    "catarias": "catar",
    "catarina": "catarino",
    "catarinas": "catarino",
    "catarinenses": "catarinense",
    "catarinos": "catarino",
    "catarmo": "catar",
    "catarmos": "catar",
    "catarrais": "catarral",
    "catarreada": "catarrear",
    "catarreadas": "catarrear",
    "catarreado": "catarrear",
    "catarreados": "catarrear",
    "catarreai": "catarrear",
    "catarreais": "catarrear",
    "catarreamo": "catarrear",
    "catarreamos": "catarrear",
    "catarreando": "catarrear",
    "catarreara": "catarrear",
    "catarrearam": "catarrear",
    "catarrearas": "catarrear",
    "catarreardes": "catarrear",
    "catarrearei": "catarrear",
    "catarreareis": "catarrear",
    "catarrearem": "catarrear",
    "catarrearemos": "catarrear",
    "catarreares": "catarrear",
    "catarrearia": "catarrear",
    "catarreariam": "catarrear",
    "catarrearias": "catarrear",
    "catarrearmo": "catarrear",
    "catarrearmos": "catarrear",
    "catarreará": "catarrear",
    "catarrearás": "catarrear",
    "catarrearão": "catarrear",
    "catarrearíamos": "catarrear",
    "catarrearíeis": "catarrear",
    "catarreasse": "catarrear",
    "catarreassem": "catarrear",
    "catarreasses": "catarrear",
    "catarreaste": "catarrear",
    "catarreastes": "catarrear",
    "catarreava": "catarrear",
    "catarreavam": "catarrear",
    "catarreavas": "catarrear",
    "catarreei": "catarrear",
    "catarreeis": "catarrear",
    "catarreemo": "catarrear",
    "catarreemos": "catarrear",
    "catarreia": "catarrear",
    "catarreiam": "catarrear",
    "catarreias": "catarrear",
    "catarreie": "catarrear",
    "catarreiem": "catarrear",
    "catarreies": "catarrear",
    "catarreio": "catarrear",
    "catarreiras": "catarreira",
    "catarrenta": "catarrento",
    "catarrentas": "catarrento",
    "catarrentos": "catarrento",
    "catarreou": "catarrear",
    "catarreámo": "catarrear",
    "catarreámos": "catarrear",
    "catarreáramo": "catarrear",
    "catarreáramos": "catarrear",
    "catarreáreis": "catarrear",
    "catarreásseis": "catarrear",
    "catarreássemos": "catarrear",
    "catarreávamo": "catarrear",
    "catarreávamos": "catarrear",
    "catarreáveis": "catarrear",
    "catarrina": "catarrino",
    "catarrinas": "catarrino",
    "catarrinos": "catarrino",
    "catarros": "catarro",
    "catarrosa": "catarroso",
    "catarrosas": "catarroso",
    "catarrosos": "catarroso",
    "catarréctica": "catarréctico",
    "catarrécticas": "catarréctico",
    "catarrécticos": "catarréctico",
    "catarrínea": "catarríneo",
    "catarríneas": "catarríneo",
    "catarríneos": "catarríneo",
    "catarrões": "catarrão",
    "catarses": "catarse",
    "catarsias": "catarsia",
    "catará": "catar",
    "catarás": "catar",
    "catarão": "catar",
    "cataríamos": "catar",
    "cataríeis": "catar",
    "catas": "catar",
    "catasse": "catar",
    "catassem": "catar",
    "catasses": "catar",
    "catassóis": "catassol",
    "catastas": "catasta",
    "catastases": "catastase",
    "cataste": "catar",
    "catastes": "catar",
    "catastrofismos": "catastrofismo",
    "catastrófica": "catastrófico",
    "catastróficas": "catastrófico",
    "catastróficos": "catastrófico",
    "catataus": "catatau",
    "catatermometrias": "catatermometria",
    "catatermométrica": "catatermométrico",
    "catatermométricas": "catatermométrico",
    "catatermométricos": "catatermométrico",
    "catatermómetros": "catatermómetro",
    "catatonias": "catatonia",
    "catatuas": "catatua",
    "catatónica": "catatónico",
    "catatónicas": "catatónico",
    "catatónicos": "catatónico",
    "cataus": "catau",
    "catava": "catar",
    "catavam": "catar",
    "catavas": "catar",
    "catazonas": "catazona",
    "cate": "catar",
    "cateada": "catear",
    "cateadas": "catear",
    "cateado": "catear",
    "cateados": "catear",
    "cateai": "catear",
    "cateais": "catear",
    "cateamentos": "cateamento",
    "cateamo": "catear",
    "cateamos": "catear",
    "cateando": "catear",
    "cateara": "catear",
    "catearam": "catear",
    "catearas": "catear",
    "cateardes": "catear",
    "catearei": "catear",
    "cateareis": "catear",
    "catearem": "catear",
    "catearemos": "catear",
    "cateares": "catear",
    "catearia": "catear",
    "cateariam": "catear",
    "catearias": "catear",
    "catearmo": "catear",
    "catearmos": "catear",
    "cateará": "catear",
    "catearás": "catear",
    "catearão": "catear",
    "catearíamos": "catear",
    "catearíeis": "catear",
    "cateasse": "catear",
    "cateassem": "catear",
    "cateasses": "catear",
    "cateaste": "catear",
    "cateastes": "catear",
    "cateava": "catear",
    "cateavam": "catear",
    "cateavas": "catear",
    "catechueiras": "catechueira",
    "catechueiros": "catechueiro",
    "catechus": "catechu",
    "catecismos": "catecismo",
    "catecumenatos": "catecumenato",
    "catecúmena": "catecúmeno",
    "catecúmenas": "catecúmeno",
    "catecúmenos": "catecúmeno",
    "catedrais": "catedral",
    "catedralesca": "catedralesco",
    "catedralescas": "catedralesco",
    "catedralescos": "catedralesco",
    "catedratiza": "catedratizar",
    "catedratizada": "catedratizar",
    "catedratizadas": "catedratizar",
    "catedratizado": "catedratizar",
    "catedratizados": "catedratizar",
    "catedratizai": "catedratizar",
    "catedratizais": "catedratizar",
    "catedratizam": "catedratizar",
    "catedratizamo": "catedratizar",
    "catedratizamos": "catedratizar",
    "catedratizando": "catedratizar",
    "catedratizara": "catedratizar",
    "catedratizaram": "catedratizar",
    "catedratizaras": "catedratizar",
    "catedratizarde": "catedratizar",
    "catedratizardes": "catedratizar",
    "catedratizare": "catedratizar",
    "catedratizarei": "catedratizar",
    "catedratizareis": "catedratizar",
    "catedratizarem": "catedratizar",
    "catedratizaremos": "catedratizar",
    "catedratizares": "catedratizar",
    "catedratizaria": "catedratizar",
    "catedratizariam": "catedratizar",
    "catedratizarias": "catedratizar",
    "catedratizarmo": "catedratizar",
    "catedratizarmos": "catedratizar",
    "catedratizará": "catedratizar",
    "catedratizarás": "catedratizar",
    "catedratizarão": "catedratizar",
    "catedratizaríamos": "catedratizar",
    "catedratizaríeis": "catedratizar",
    "catedratizas": "catedratizar",
    "catedratizasse": "catedratizar",
    "catedratizassem": "catedratizar",
    "catedratizasses": "catedratizar",
    "catedratizaste": "catedratizar",
    "catedratizastes": "catedratizar",
    "catedratizava": "catedratizar",
    "catedratizavam": "catedratizar",
    "catedratizavas": "catedratizar",
    "catedratize": "catedratizar",
    "catedratizei": "catedratizar",
    "catedratizeis": "catedratizar",
    "catedratizem": "catedratizar",
    "catedratizemo": "catedratizar",
    "catedratizemos": "catedratizar",
    "catedratizes": "catedratizar",
    "catedratizo": "catedratizar",
    "catedratizou": "catedratizar",
    "catedratizá": "catedratizar",
    "catedratizámo": "catedratizar",
    "catedratizámos": "catedratizar",
    "catedratizáramo": "catedratizar",
    "catedratizáramos": "catedratizar",
    "catedratizárei": "catedratizar",
    "catedratizáreis": "catedratizar",
    "catedratizásseis": "catedratizar",
    "catedratizássemos": "catedratizar",
    "catedratizávamo": "catedratizar",
    "catedratizávamos": "catedratizar",
    "catedratizávei": "catedratizar",
    "catedratizáveis": "catedratizar",
    "catedrática": "catedrático",
    "catedráticas": "catedrático",
    "catedráticos": "catedrático",
    "cateei": "catear",
    "cateeis": "catear",
    "cateemo": "catear",
    "cateemos": "catear",
    "categoremas": "categorema",
    "categoriais": "categorial",
    "categorias": "categoria",
    "categoriza": "categorizar",
    "categorizada": "categorizar",
    "categorizadas": "categorizar",
    "categorizado": "categorizar",
    "categorizadora": "categorizador",
    "categorizadoras": "categorizador",
    "categorizadores": "categorizador",
    "categorizados": "categorizar",
    "categorizai": "categorizar",
    "categorizais": "categorizar",
    "categorizam": "categorizar",
    "categorizamo": "categorizar",
    "categorizamos": "categorizar",
    "categorizando": "categorizar",
    "categorizara": "categorizar",
    "categorizaram": "categorizar",
    "categorizaras": "categorizar",
    "categorizarde": "categorizar",
    "categorizardes": "categorizar",
    "categorizare": "categorizar",
    "categorizarei": "categorizar",
    "categorizareis": "categorizar",
    "categorizarem": "categorizar",
    "categorizaremos": "categorizar",
    "categorizares": "categorizar",
    "categorizaria": "categorizar",
    "categorizariam": "categorizar",
    "categorizarias": "categorizar",
    "categorizarmo": "categorizar",
    "categorizarmos": "categorizar",
    "categorizará": "categorizar",
    "categorizarás": "categorizar",
    "categorizarão": "categorizar",
    "categorizaríamos": "categorizar",
    "categorizaríeis": "categorizar",
    "categorizas": "categorizar",
    "categorizasse": "categorizar",
    "categorizassem": "categorizar",
    "categorizasses": "categorizar",
    "categorizaste": "categorizar",
    "categorizastes": "categorizar",
    "categorizava": "categorizar",
    "categorizavam": "categorizar",
    "categorizavas": "categorizar",
    "categorizações": "categorização",
    "categorize": "categorizar",
    "categorizei": "categorizar",
    "categorizeis": "categorizar",
    "categorizem": "categorizar",
    "categorizemo": "categorizar",
    "categorizemos": "categorizar",
    "categorizes": "categorizar",
    "categorizo": "categorizar",
    "categorizou": "categorizar",
    "categorizá": "categorizar",
    "categorizámo": "categorizar",
    "categorizámos": "categorizar",
    "categorizáramo": "categorizar",
    "categorizáramos": "categorizar",
    "categorizárei": "categorizar",
    "categorizáreis": "categorizar",
    "categorizásseis": "categorizar",
    "categorizássemos": "categorizar",
    "categorizávamo": "categorizar",
    "categorizávamos": "categorizar",
    "categorizávei": "categorizar",
    "categorizáveis": "categorizar",
    "categórica": "categórico",
    "categóricas": "categórico",
    "categóricos": "categórico",
    "catei": "catar",
    "cateia": "catear",
    "cateiam": "catear",
    "cateias": "catear",
    "cateie": "catear",
    "cateiem": "catear",
    "cateies": "catear",
    "cateio": "catear",
    "cateis": "catar",
    "catem": "catar",
    "catemo": "catar",
    "catemos": "catar",
    "catenas": "catena",
    "catenações": "catenação",
    "cateniformes": "cateniforme",
    "catenárias": "catenária",
    "catenífera": "catenífero",
    "cateníferas": "catenífero",
    "cateníferos": "catenífero",
    "catenóides": "catenóide",
    "cateou": "catear",
    "catequeses": "catequese",
    "catequistas": "catequista",
    "catequiza": "catequizar",
    "catequizada": "catequizar",
    "catequizadas": "catequizar",
    "catequizado": "catequizar",
    "catequizadora": "catequizador",
    "catequizadoras": "catequizador",
    "catequizadores": "catequizador",
    "catequizados": "catequizar",
    "catequizai": "catequizar",
    "catequizais": "catequizar",
    "catequizam": "catequizar",
    "catequizamo": "catequizar",
    "catequizamos": "catequizar",
    "catequizando": "catequizar",
    "catequizantes": "catequizante",
    "catequizara": "catequizar",
    "catequizaram": "catequizar",
    "catequizaras": "catequizar",
    "catequizarde": "catequizar",
    "catequizardes": "catequizar",
    "catequizare": "catequizar",
    "catequizarei": "catequizar",
    "catequizareis": "catequizar",
    "catequizarem": "catequizar",
    "catequizaremos": "catequizar",
    "catequizares": "catequizar",
    "catequizaria": "catequizar",
    "catequizariam": "catequizar",
    "catequizarias": "catequizar",
    "catequizarmo": "catequizar",
    "catequizarmos": "catequizar",
    "catequizará": "catequizar",
    "catequizarás": "catequizar",
    "catequizarão": "catequizar",
    "catequizaríamos": "catequizar",
    "catequizaríeis": "catequizar",
    "catequizas": "catequizar",
    "catequizasse": "catequizar",
    "catequizassem": "catequizar",
    "catequizasses": "catequizar",
    "catequizaste": "catequizar",
    "catequizastes": "catequizar",
    "catequizava": "catequizar",
    "catequizavam": "catequizar",
    "catequizavas": "catequizar",
    "catequizações": "catequização",
    "catequize": "catequizar",
    "catequizei": "catequizar",
    "catequizeis": "catequizar",
    "catequizem": "catequizar",
    "catequizemo": "catequizar",
    "catequizemos": "catequizar",
    "catequizes": "catequizar",
    "catequizo": "catequizar",
    "catequizou": "catequizar",
    "catequizá": "catequizar",
    "catequizámo": "catequizar",
    "catequizámos": "catequizar",
    "catequizáramo": "catequizar",
    "catequizáramos": "catequizar",
    "catequizárei": "catequizar",
    "catequizáreis": "catequizar",
    "catequizásseis": "catequizar",
    "catequizássemos": "catequizar",
    "catequizávamo": "catequizar",
    "catequizávamos": "catequizar",
    "catequizávei": "catequizar",
    "catequizáveis": "catequizar",
    "catequética": "catequético",
    "catequéticas": "catequético",
    "catequéticos": "catequético",
    "catervas": "caterva",
    "cates": "catar",
    "cateteres": "cateter",
    "cateterismos": "cateterismo",
    "catetes": "catete",
    "catetometrias": "catetometria",
    "catetométrica": "catetométrico",
    "catetométricas": "catetométrico",
    "catetométricos": "catetométrico",
    "catetos": "cateto",
    "catetómetros": "catetómetro",
    "cateámo": "catear",
    "cateámos": "catear",
    "cateáramo": "catear",
    "cateáramos": "catear",
    "cateáreis": "catear",
    "cateásseis": "catear",
    "cateássemos": "catear",
    "cateávamo": "catear",
    "cateávamos": "catear",
    "cateáveis": "catear",
    "catiana": "catiano",
    "catianas": "catiano",
    "catianos": "catiano",
    "catilinária": "catilinário",
    "catilinárias": "catilinário",
    "catilinários": "catilinário",
    "catimbaus": "catimbau",
    "catinga": "catingar",
    "catingada": "catingar",
    "catingadas": "catingar",
    "catingado": "catingar",
    "catingados": "catingar",
    "catingai": "catingar",
    "catingais": "catingar",
    "catingam": "catingar",
    "catingamo": "catingar",
    "catingamos": "catingar",
    "catingando": "catingar",
    "catingara": "catingar",
    "catingaram": "catingar",
    "catingaras": "catingar",
    "catingardes": "catingar",
    "catingarei": "catingar",
    "catingareis": "catingar",
    "catingarem": "catingar",
    "catingaremos": "catingar",
    "catingares": "catingar",
    "catingaria": "catingar",
    "catingariam": "catingar",
    "catingarias": "catingar",
    "catingarmo": "catingar",
    "catingarmos": "catingar",
    "catingará": "catingar",
    "catingarás": "catingar",
    "catingarão": "catingar",
    "catingaríamos": "catingar",
    "catingaríeis": "catingar",
    "catingas": "catingar",
    "catingasse": "catingar",
    "catingassem": "catingar",
    "catingasses": "catingar",
    "catingaste": "catingar",
    "catingastes": "catingar",
    "catingava": "catingar",
    "catingavam": "catingar",
    "catingavas": "catingar",
    "catingo": "catingar",
    "catingosa": "catingoso",
    "catingosas": "catingoso",
    "catingosos": "catingoso",
    "catingou": "catingar",
    "catingue": "catingar",
    "catinguei": "catingar",
    "catingueira": "catingueiro",
    "catingueiras": "catingueiro",
    "catingueiros": "catingueiro",
    "catingueis": "catingar",
    "catinguem": "catingar",
    "catinguemo": "catingar",
    "catinguemos": "catingar",
    "catingues": "catingar",
    "catingámo": "catingar",
    "catingámos": "catingar",
    "catingáramo": "catingar",
    "catingáramos": "catingar",
    "catingáreis": "catingar",
    "catingásseis": "catingar",
    "catingássemos": "catingar",
    "catingávamo": "catingar",
    "catingávamos": "catingar",
    "catingáveis": "catingar",
    "catita": "catitar",
    "catitada": "catitar",
    "catitadas": "catitar",
    "catitado": "catitar",
    "catitados": "catitar",
    "catitai": "catitar",
    "catitais": "catitar",
    "catitam": "catitar",
    "catitamo": "catitar",
    "catitamos": "catitar",
    "catitando": "catitar",
    "catitara": "catitar",
    "catitaram": "catitar",
    "catitaras": "catitar",
    "catitardes": "catitar",
    "catitarei": "catitar",
    "catitareis": "catitar",
    "catitarem": "catitar",
    "catitaremos": "catitar",
    "catitares": "catitar",
    "catitaria": "catitar",
    "catitariam": "catitar",
    "catitarias": "catitar",
    "catitarmo": "catitar",
    "catitarmos": "catitar",
    "catitará": "catitar",
    "catitarás": "catitar",
    "catitarão": "catitar",
    "catitaríamos": "catitar",
    "catitaríeis": "catitar",
    "catitas": "catitar",
    "catitasse": "catitar",
    "catitassem": "catitar",
    "catitasses": "catitar",
    "catitaste": "catitar",
    "catitastes": "catitar",
    "catitava": "catitar",
    "catitavam": "catitar",
    "catitavas": "catitar",
    "catite": "catitar",
    "catitei": "catitar",
    "catiteis": "catitar",
    "catitem": "catitar",
    "catitemo": "catitar",
    "catitemos": "catitar",
    "catites": "catitar",
    "catitices": "catitice",
    "catitinha": "catita",
    "catitinhas": "catita",
    "catitismos": "catitismo",
    "catitita": "catita",
    "catititas": "catita",
    "catito": "catitar",
    "catitou": "catitar",
    "catitámo": "catitar",
    "catitámos": "catitar",
    "catitáramo": "catitar",
    "catitáramos": "catitar",
    "catitáreis": "catitar",
    "catitásseis": "catitar",
    "catitássemos": "catitar",
    "catitávamo": "catitar",
    "catitávamos": "catitar",
    "catitáveis": "catitar",
    "cativa": "cativo",
    "cativada": "cativar",
    "cativadas": "cativar",
    "cativado": "cativar",
    "cativados": "cativar",
    "cativai": "cativar",
    "cativais": "cativar",
    "cativam": "cativar",
    "cativamo": "cativar",
    "cativamos": "cativar",
    "cativando": "cativar",
    "cativantes": "cativante",
    "cativara": "cativar",
    "cativaram": "cativar",
    "cativaras": "cativar",
    "cativarde": "cativar",
    "cativardes": "cativar",
    "cativare": "cativar",
    "cativarei": "cativar",
    "cativareis": "cativar",
    "cativarem": "cativar",
    "cativaremos": "cativar",
    "cativares": "cativar",
    "cativaria": "cativar",
    "cativariam": "cativar",
    "cativarias": "cativar",
    "cativarmo": "cativar",
    "cativarmos": "cativar",
    "cativará": "cativar",
    "cativarás": "cativar",
    "cativarão": "cativar",
    "cativaríamos": "cativar",
    "cativaríeis": "cativar",
    "cativas": "cativo",
    "cativasse": "cativar",
    "cativassem": "cativar",
    "cativasses": "cativar",
    "cativaste": "cativar",
    "cativastes": "cativar",
    "cativava": "cativar",
    "cativavam": "cativar",
    "cativavas": "cativar",
    "cativações": "cativação",
    "cative": "cativar",
    "cativei": "cativar",
    "cativeiros": "cativeiro",
    "cativeis": "cativar",
    "cativem": "cativar",
    "cativemo": "cativar",
    "cativemos": "cativar",
    "catives": "cativar",
    "cativo": "cativar",
    "cativos": "cativo",
    "cativou": "cativar",
    "cativá": "cativar",
    "cativámo": "cativar",
    "cativámos": "cativar",
    "cativáramo": "cativar",
    "cativáramos": "cativar",
    "cativárei": "cativar",
    "cativáreis": "cativar",
    "cativásseis": "cativar",
    "cativássemos": "cativar",
    "cativávamo": "cativar",
    "cativávamos": "cativar",
    "cativávei": "cativar",
    "cativáveis": "cativável",
    "catiões": "catião",
    "cato": "catar",
    "catodioluminescentes": "catodioluminescente",
    "catodioluminescências": "catodioluminescência",
    "catodoluminescências": "catodoluminescência",
    "catolicações": "catolicação",
    "catolicidades": "catolicidade",
    "catolicismos": "catolicismo",
    "catoliciza": "catolicizar",
    "catolicizada": "catolicizar",
    "catolicizadas": "catolicizar",
    "catolicizado": "catolicizar",
    "catolicizados": "catolicizar",
    "catolicizai": "catolicizar",
    "catolicizais": "catolicizar",
    "catolicizam": "catolicizar",
    "catolicizamo": "catolicizar",
    "catolicizamos": "catolicizar",
    "catolicizando": "catolicizar",
    "catolicizara": "catolicizar",
    "catolicizaram": "catolicizar",
    "catolicizaras": "catolicizar",
    "catolicizarde": "catolicizar",
    "catolicizardes": "catolicizar",
    "catolicizare": "catolicizar",
    "catolicizarei": "catolicizar",
    "catolicizareis": "catolicizar",
    "catolicizarem": "catolicizar",
    "catolicizaremos": "catolicizar",
    "catolicizares": "catolicizar",
    "catolicizaria": "catolicizar",
    "catolicizariam": "catolicizar",
    "catolicizarias": "catolicizar",
    "catolicizarmo": "catolicizar",
    "catolicizarmos": "catolicizar",
    "catolicizará": "catolicizar",
    "catolicizarás": "catolicizar",
    "catolicizarão": "catolicizar",
    "catolicizaríamos": "catolicizar",
    "catolicizaríeis": "catolicizar",
    "catolicizas": "catolicizar",
    "catolicizasse": "catolicizar",
    "catolicizassem": "catolicizar",
    "catolicizasses": "catolicizar",
    "catolicizaste": "catolicizar",
    "catolicizastes": "catolicizar",
    "catolicizava": "catolicizar",
    "catolicizavam": "catolicizar",
    "catolicizavas": "catolicizar",
    "catolicize": "catolicizar",
    "catolicizei": "catolicizar",
    "catolicizeis": "catolicizar",
    "catolicizem": "catolicizar",
    "catolicizemo": "catolicizar",
    "catolicizemos": "catolicizar",
    "catolicizes": "catolicizar",
    "catolicizo": "catolicizar",
    "catolicizou": "catolicizar",
    "catolicizá": "catolicizar",
    "catolicizámo": "catolicizar",
    "catolicizámos": "catolicizar",
    "catolicizáramo": "catolicizar",
    "catolicizáramos": "catolicizar",
    "catolicizárei": "catolicizar",
    "catolicizáreis": "catolicizar",
    "catolicizásseis": "catolicizar",
    "catolicizássemos": "catolicizar",
    "catolicizávamo": "catolicizar",
    "catolicizávamos": "catolicizar",
    "catolicizávei": "catolicizar",
    "catolicizáveis": "catolicizar",
    "catoliza": "catolizar",
    "catolizada": "catolizar",
    "catolizadas": "catolizar",
    "catolizado": "catolizar",
    "catolizados": "catolizar",
    "catolizai": "catolizar",
    "catolizais": "catolizar",
    "catolizam": "catolizar",
    "catolizamo": "catolizar",
    "catolizamos": "catolizar",
    "catolizando": "catolizar",
    "catolizara": "catolizar",
    "catolizaram": "catolizar",
    "catolizaras": "catolizar",
    "catolizarde": "catolizar",
    "catolizardes": "catolizar",
    "catolizare": "catolizar",
    "catolizarei": "catolizar",
    "catolizareis": "catolizar",
    "catolizarem": "catolizar",
    "catolizaremos": "catolizar",
    "catolizares": "catolizar",
    "catolizaria": "catolizar",
    "catolizariam": "catolizar",
    "catolizarias": "catolizar",
    "catolizarmo": "catolizar",
    "catolizarmos": "catolizar",
    "catolizará": "catolizar",
    "catolizarás": "catolizar",
    "catolizarão": "catolizar",
    "catolizaríamos": "catolizar",
    "catolizaríeis": "catolizar",
    "catolizas": "catolizar",
    "catolizasse": "catolizar",
    "catolizassem": "catolizar",
    "catolizasses": "catolizar",
    "catolizaste": "catolizar",
    "catolizastes": "catolizar",
    "catolizava": "catolizar",
    "catolizavam": "catolizar",
    "catolizavas": "catolizar",
    "catolizações": "catolização",
    "catolize": "catolizar",
    "catolizei": "catolizar",
    "catolizeis": "catolizar",
    "catolizem": "catolizar",
    "catolizemo": "catolizar",
    "catolizemos": "catolizar",
    "catolizes": "catolizar",
    "catolizo": "catolizar",
    "catolizou": "catolizar",
    "catolizá": "catolizar",
    "catolizámo": "catolizar",
    "catolizámos": "catolizar",
    "catolizáramo": "catolizar",
    "catolizáramos": "catolizar",
    "catolizárei": "catolizar",
    "catolizáreis": "catolizar",
    "catolizásseis": "catolizar",
    "catolizássemos": "catolizar",
    "catolizávamo": "catolizar",
    "catolizávamos": "catolizar",
    "catolizávei": "catolizar",
    "catolizáveis": "catolizar",
    "catoniana": "catoniano",
    "catonianas": "catoniano",
    "catonianos": "catoniano",
    "catonismos": "catonismo",
    "catoptrofobias": "catoptrofobia",
    "catoptromancias": "catoptromancia",
    "catoptromantes": "catoptromante",
    "catoptromântica": "catoptromântico",
    "catoptromânticas": "catoptromântico",
    "catoptromânticos": "catoptromântico",
    "catoptrófoba": "catoptrófobo",
    "catoptrófobas": "catoptrófobo",
    "catoptrófobos": "catoptrófobo",
    "catorzena": "catorzeno",
    "catorzenas": "catorzeno",
    "catorzenos": "catorzeno",
    "catos": "cato",
    "catou": "catar",
    "catrabuchas": "catrabucha",
    "catracega": "catracego",
    "catracegada": "catracegar",
    "catracegadas": "catracegar",
    "catracegado": "catracegar",
    "catracegados": "catracegar",
    "catracegai": "catracegar",
    "catracegais": "catracegar",
    "catracegam": "catracegar",
    "catracegamo": "catracegar",
    "catracegamos": "catracegar",
    "catracegando": "catracegar",
    "catracegara": "catracegar",
    "catracegaram": "catracegar",
    "catracegaras": "catracegar",
    "catracegardes": "catracegar",
    "catracegarei": "catracegar",
    "catracegareis": "catracegar",
    "catracegarem": "catracegar",
    "catracegaremos": "catracegar",
    "catracegares": "catracegar",
    "catracegaria": "catracegar",
    "catracegariam": "catracegar",
    "catracegarias": "catracegar",
    "catracegarmo": "catracegar",
    "catracegarmos": "catracegar",
    "catracegará": "catracegar",
    "catracegarás": "catracegar",
    "catracegarão": "catracegar",
    "catracegaríamos": "catracegar",
    "catracegaríeis": "catracegar",
    "catracegas": "catracego",
    "catracegasse": "catracegar",
    "catracegassem": "catracegar",
    "catracegasses": "catracegar",
    "catracegaste": "catracegar",
    "catracegastes": "catracegar",
    "catracegava": "catracegar",
    "catracegavam": "catracegar",
    "catracegavas": "catracegar",
    "catracego": "catracegar",
    "catracegos": "catracego",
    "catracegou": "catracegar",
    "catracegue": "catracegar",
    "catraceguei": "catracegar",
    "catracegueiras": "catracegueira",
    "catracegueis": "catracegar",
    "catraceguem": "catracegar",
    "catraceguemo": "catracegar",
    "catraceguemos": "catracegar",
    "catracegues": "catracegar",
    "catracegámo": "catracegar",
    "catracegámos": "catracegar",
    "catracegáramo": "catracegar",
    "catracegáramos": "catracegar",
    "catracegáreis": "catracegar",
    "catracegásseis": "catracegar",
    "catracegássemos": "catracegar",
    "catracegávamo": "catracegar",
    "catracegávamos": "catracegar",
    "catracegáveis": "catracegar",
    "catraeiros": "catraeiro",
    "catrafila": "catrafilar",
    "catrafilada": "catrafilar",
    "catrafiladas": "catrafilar",
    "catrafilado": "catrafilar",
    "catrafilados": "catrafilar",
    "catrafilai": "catrafilar",
    "catrafilais": "catrafilar",
    "catrafilam": "catrafilar",
    "catrafilamo": "catrafilar",
    "catrafilamos": "catrafilar",
    "catrafilando": "catrafilar",
    "catrafilara": "catrafilar",
    "catrafilaram": "catrafilar",
    "catrafilaras": "catrafilar",
    "catrafilarde": "catrafilar",
    "catrafilardes": "catrafilar",
    "catrafilare": "catrafilar",
    "catrafilarei": "catrafilar",
    "catrafilareis": "catrafilar",
    "catrafilarem": "catrafilar",
    "catrafilaremos": "catrafilar",
    "catrafilares": "catrafilar",
    "catrafilaria": "catrafilar",
    "catrafilariam": "catrafilar",
    "catrafilarias": "catrafilar",
    "catrafilarmo": "catrafilar",
    "catrafilarmos": "catrafilar",
    "catrafilará": "catrafilar",
    "catrafilarás": "catrafilar",
    "catrafilarão": "catrafilar",
    "catrafilaríamos": "catrafilar",
    "catrafilaríeis": "catrafilar",
    "catrafilas": "catrafilar",
    "catrafilasse": "catrafilar",
    "catrafilassem": "catrafilar",
    "catrafilasses": "catrafilar",
    "catrafilaste": "catrafilar",
    "catrafilastes": "catrafilar",
    "catrafilava": "catrafilar",
    "catrafilavam": "catrafilar",
    "catrafilavas": "catrafilar",
    "catrafile": "catrafilar",
    "catrafilei": "catrafilar",
    "catrafileis": "catrafilar",
    "catrafilem": "catrafilar",
    "catrafilemo": "catrafilar",
    "catrafilemos": "catrafilar",
    "catrafiles": "catrafilar",
    "catrafilo": "catrafilar",
    "catrafilou": "catrafilar",
    "catrafilá": "catrafilar",
    "catrafilámo": "catrafilar",
    "catrafilámos": "catrafilar",
    "catrafiláramo": "catrafilar",
    "catrafiláramos": "catrafilar",
    "catrafilárei": "catrafilar",
    "catrafiláreis": "catrafilar",
    "catrafilásseis": "catrafilar",
    "catrafilássemos": "catrafilar",
    "catrafilávamo": "catrafilar",
    "catrafilávamos": "catrafilar",
    "catrafilávei": "catrafilar",
    "catrafiláveis": "catrafilar",
    "catraia": "catraio",
    "catraiada": "catraiar",
    "catraiadas": "catraiar",
    "catraiado": "catraiar",
    "catraiados": "catraiar",
    "catraiai": "catraiar",
    "catraiais": "catraiar",
    "catraiam": "catraiar",
    "catraiamo": "catraiar",
    "catraiamos": "catraiar",
    "catraiando": "catraiar",
    "catraiara": "catraiar",
    "catraiaram": "catraiar",
    "catraiaras": "catraiar",
    "catraiarde": "catraiar",
    "catraiardes": "catraiar",
    "catraiare": "catraiar",
    "catraiarei": "catraiar",
    "catraiareis": "catraiar",
    "catraiarem": "catraiar",
    "catraiaremos": "catraiar",
    "catraiares": "catraiar",
    "catraiaria": "catraiar",
    "catraiariam": "catraiar",
    "catraiarias": "catraiar",
    "catraiarmo": "catraiar",
    "catraiarmos": "catraiar",
    "catraiará": "catraiar",
    "catraiarás": "catraiar",
    "catraiarão": "catraiar",
    "catraiaríamos": "catraiar",
    "catraiaríeis": "catraiar",
    "catraias": "catraio",
    "catraiasse": "catraiar",
    "catraiassem": "catraiar",
    "catraiasses": "catraiar",
    "catraiaste": "catraiar",
    "catraiastes": "catraiar",
    "catraiava": "catraiar",
    "catraiavam": "catraiar",
    "catraiavas": "catraiar",
    "catraie": "catraiar",
    "catraiei": "catraiar",
    "catraieira": "catraieiro",
    "catraieiras": "catraieiro",
    "catraieiros": "catraieiro",
    "catraieis": "catraiar",
    "catraiem": "catraiar",
    "catraiemo": "catraiar",
    "catraiemos": "catraiar",
    "catraies": "catraiar",
    "catraio": "catraiar",
    "catraios": "catraio",
    "catraiou": "catraiar",
    "catraiá": "catraiar",
    "catraiámo": "catraiar",
    "catraiámos": "catraiar",
    "catraiáramo": "catraiar",
    "catraiáramos": "catraiar",
    "catraiárei": "catraiar",
    "catraiáreis": "catraiar",
    "catraiásseis": "catraiar",
    "catraiássemos": "catraiar",
    "catraiávamo": "catraiar",
    "catraiávamos": "catraiar",
    "catraiávei": "catraiar",
    "catraiáveis": "catraiar",
    "catrameços": "catrameço",
    "catrapeada": "catrapear",
    "catrapeadas": "catrapear",
    "catrapeado": "catrapear",
    "catrapeados": "catrapear",
    "catrapeai": "catrapear",
    "catrapeais": "catrapear",
    "catrapeamo": "catrapear",
    "catrapeamos": "catrapear",
    "catrapeando": "catrapear",
    "catrapeara": "catrapear",
    "catrapearam": "catrapear",
    "catrapearas": "catrapear",
    "catrapeardes": "catrapear",
    "catrapearei": "catrapear",
    "catrapeareis": "catrapear",
    "catrapearem": "catrapear",
    "catrapearemos": "catrapear",
    "catrapeares": "catrapear",
    "catrapearia": "catrapear",
    "catrapeariam": "catrapear",
    "catrapearias": "catrapear",
    "catrapearmo": "catrapear",
    "catrapearmos": "catrapear",
    "catrapeará": "catrapear",
    "catrapearás": "catrapear",
    "catrapearão": "catrapear",
    "catrapearíamos": "catrapear",
    "catrapearíeis": "catrapear",
    "catrapeasse": "catrapear",
    "catrapeassem": "catrapear",
    "catrapeasses": "catrapear",
    "catrapeaste": "catrapear",
    "catrapeastes": "catrapear",
    "catrapeava": "catrapear",
    "catrapeavam": "catrapear",
    "catrapeavas": "catrapear",
    "catrapeei": "catrapear",
    "catrapeeis": "catrapear",
    "catrapeemo": "catrapear",
    "catrapeemos": "catrapear",
    "catrapeia": "catrapear",
    "catrapeiam": "catrapear",
    "catrapeias": "catrapear",
    "catrapeie": "catrapear",
    "catrapeiem": "catrapear",
    "catrapeies": "catrapear",
    "catrapeio": "catrapear",
    "catrapeou": "catrapear",
    "catrapeámo": "catrapear",
    "catrapeámos": "catrapear",
    "catrapeáramo": "catrapear",
    "catrapeáramos": "catrapear",
    "catrapeáreis": "catrapear",
    "catrapeásseis": "catrapear",
    "catrapeássemos": "catrapear",
    "catrapeávamo": "catrapear",
    "catrapeávamos": "catrapear",
    "catrapeáveis": "catrapear",
    "catrapisca": "catrapiscar",
    "catrapiscada": "catrapiscar",
    "catrapiscadas": "catrapiscar",
    "catrapiscado": "catrapiscar",
    "catrapiscados": "catrapiscar",
    "catrapiscai": "catrapiscar",
    "catrapiscais": "catrapiscar",
    "catrapiscam": "catrapiscar",
    "catrapiscamo": "catrapiscar",
    "catrapiscamos": "catrapiscar",
    "catrapiscando": "catrapiscar",
    "catrapiscara": "catrapiscar",
    "catrapiscaram": "catrapiscar",
    "catrapiscaras": "catrapiscar",
    "catrapiscarde": "catrapiscar",
    "catrapiscardes": "catrapiscar",
    "catrapiscare": "catrapiscar",
    "catrapiscarei": "catrapiscar",
    "catrapiscareis": "catrapiscar",
    "catrapiscarem": "catrapiscar",
    "catrapiscaremos": "catrapiscar",
    "catrapiscares": "catrapiscar",
    "catrapiscaria": "catrapiscar",
    "catrapiscariam": "catrapiscar",
    "catrapiscarias": "catrapiscar",
    "catrapiscarmo": "catrapiscar",
    "catrapiscarmos": "catrapiscar",
    "catrapiscará": "catrapiscar",
    "catrapiscarás": "catrapiscar",
    "catrapiscarão": "catrapiscar",
    "catrapiscaríamos": "catrapiscar",
    "catrapiscaríeis": "catrapiscar",
    "catrapiscas": "catrapiscar",
    "catrapiscasse": "catrapiscar",
    "catrapiscassem": "catrapiscar",
    "catrapiscasses": "catrapiscar",
    "catrapiscaste": "catrapiscar",
    "catrapiscastes": "catrapiscar",
    "catrapiscava": "catrapiscar",
    "catrapiscavam": "catrapiscar",
    "catrapiscavas": "catrapiscar",
    "catrapisco": "catrapiscar",
    "catrapiscou": "catrapiscar",
    "catrapiscá": "catrapiscar",
    "catrapiscámo": "catrapiscar",
    "catrapiscámos": "catrapiscar",
    "catrapiscáramo": "catrapiscar",
    "catrapiscáramos": "catrapiscar",
    "catrapiscárei": "catrapiscar",
    "catrapiscáreis": "catrapiscar",
    "catrapiscásseis": "catrapiscar",
    "catrapiscássemos": "catrapiscar",
    "catrapiscávamo": "catrapiscar",
    "catrapiscávamos": "catrapiscar",
    "catrapiscávei": "catrapiscar",
    "catrapiscáveis": "catrapiscar",
    "catrapisque": "catrapiscar",
    "catrapisquei": "catrapiscar",
    "catrapisqueis": "catrapiscar",
    "catrapisquem": "catrapiscar",
    "catrapisquemo": "catrapiscar",
    "catrapisquemos": "catrapiscar",
    "catrapisques": "catrapiscar",
    "catrapuses": "catrapus",
    "catrapázios": "catrapázio",
    "catrapóses": "catrapós",
    "catrefadas": "catrefada",
    "catrefas": "catrefa",
    "catres": "catre",
    "catrâmbias": "catrâmbia",
    "catuais": "catual",
    "catualias": "catualia",
    "catulos": "catulo",
    "caturra": "caturrar",
    "caturrada": "caturrar",
    "caturradas": "caturrar",
    "caturrado": "caturrar",
    "caturrados": "caturrar",
    "caturrai": "caturrar",
    "caturrais": "caturrar",
    "caturram": "caturrar",
    "caturramo": "caturrar",
    "caturramos": "caturrar",
    "caturrando": "caturrar",
    "caturrara": "caturrar",
    "caturraram": "caturrar",
    "caturraras": "caturrar",
    "caturrardes": "caturrar",
    "caturrarei": "caturrar",
    "caturrareis": "caturrar",
    "caturrarem": "caturrar",
    "caturraremos": "caturrar",
    "caturrares": "caturrar",
    "caturraria": "caturrar",
    "caturrariam": "caturrar",
    "caturrarias": "caturrar",
    "caturrarmo": "caturrar",
    "caturrarmos": "caturrar",
    "caturrará": "caturrar",
    "caturrarás": "caturrar",
    "caturrarão": "caturrar",
    "caturraríamos": "caturrar",
    "caturraríeis": "caturrar",
    "caturras": "caturrar",
    "caturrasse": "caturrar",
    "caturrassem": "caturrar",
    "caturrasses": "caturrar",
    "caturraste": "caturrar",
    "caturrastes": "caturrar",
    "caturrava": "caturrar",
    "caturravam": "caturrar",
    "caturravas": "caturrar",
    "caturre": "caturrar",
    "caturrei": "caturrar",
    "caturreiras": "caturreira",
    "caturreis": "caturrar",
    "caturrem": "caturrar",
    "caturremo": "caturrar",
    "caturremos": "caturrar",
    "caturres": "caturrar",
    "caturrices": "caturrice",
    "caturro": "caturrar",
    "caturros": "caturro",
    "caturrou": "caturrar",
    "caturrámo": "caturrar",
    "caturrámos": "caturrar",
    "caturráramo": "caturrar",
    "caturráramos": "caturrar",
    "caturráreis": "caturrar",
    "caturrásseis": "caturrar",
    "caturrássemos": "caturrar",
    "caturrávamo": "caturrar",
    "caturrávamos": "caturrar",
    "caturráveis": "caturrar",
    "catá": "catar",
    "catáfases": "catáfase",
    "catáforas": "catáfora",
    "catálases": "catálase",
    "catálises": "catálise",
    "catálogos": "catálogo",
    "catámo": "catar",
    "catámos": "catar",
    "catáramo": "catar",
    "catáramos": "catar",
    "catárei": "catar",
    "catáreis": "catar",
    "catártica": "catártico",
    "catárticas": "catártico",
    "catárticos": "catártico",
    "catásseis": "catar",
    "catássemos": "catar",
    "catástrofes": "catástrofe",
    "catávamo": "catar",
    "catávamos": "catar",
    "catávei": "catar",
    "catáveis": "catar",
    "caténulas": "caténula",
    "catódica": "catódico",
    "catódicas": "catódico",
    "catódicos": "catódico",
    "catódios": "catódio",
    "católica": "católico",
    "católicas": "católico",
    "católicos": "católico",
    "católitos": "católito",
    "catóptrica": "catóptrico",
    "catóptricas": "catóptrico",
    "catóptricos": "catóptrico",
    "catões": "catão",
    "caubóis": "caubói",
    "caucasiana": "caucasiano",
    "caucasianas": "caucasiano",
    "caucasianos": "caucasiano",
    "cauchais": "cauchal",
    "caucheira": "caucheiro",
    "caucheiras": "caucheiro",
    "caucheiros": "caucheiro",
    "cauchos": "caucho",
    "cauchuta": "cauchutar",
    "cauchutada": "cauchutar",
    "cauchutadas": "cauchutar",
    "cauchutado": "cauchutar",
    "cauchutados": "cauchutar",
    "cauchutai": "cauchutar",
    "cauchutais": "cauchutar",
    "cauchutam": "cauchutar",
    "cauchutamo": "cauchutar",
    "cauchutamos": "cauchutar",
    "cauchutando": "cauchutar",
    "cauchutara": "cauchutar",
    "cauchutaram": "cauchutar",
    "cauchutaras": "cauchutar",
    "cauchutarde": "cauchutar",
    "cauchutardes": "cauchutar",
    "cauchutare": "cauchutar",
    "cauchutarei": "cauchutar",
    "cauchutareis": "cauchutar",
    "cauchutarem": "cauchutar",
    "cauchutaremos": "cauchutar",
    "cauchutares": "cauchutar",
    "cauchutaria": "cauchutar",
    "cauchutariam": "cauchutar",
    "cauchutarias": "cauchutar",
    "cauchutarmo": "cauchutar",
    "cauchutarmos": "cauchutar",
    "cauchutará": "cauchutar",
    "cauchutarás": "cauchutar",
    "cauchutarão": "cauchutar",
    "cauchutaríamos": "cauchutar",
    "cauchutaríeis": "cauchutar",
    "cauchutas": "cauchutar",
    "cauchutasse": "cauchutar",
    "cauchutassem": "cauchutar",
    "cauchutasses": "cauchutar",
    "cauchutaste": "cauchutar",
    "cauchutastes": "cauchutar",
    "cauchutava": "cauchutar",
    "cauchutavam": "cauchutar",
    "cauchutavas": "cauchutar",
    "cauchute": "cauchutar",
    "cauchutei": "cauchutar",
    "cauchuteis": "cauchutar",
    "cauchutem": "cauchutar",
    "cauchutemo": "cauchutar",
    "cauchutemos": "cauchutar",
    "cauchutes": "cauchutar",
    "cauchuto": "cauchutar",
    "cauchutou": "cauchutar",
    "cauchutá": "cauchutar",
    "cauchutámo": "cauchutar",
    "cauchutámos": "cauchutar",
    "cauchutáramo": "cauchutar",
    "cauchutáramos": "cauchutar",
    "cauchutárei": "cauchutar",
    "cauchutáreis": "cauchutar",
    "cauchutásseis": "cauchutar",
    "cauchutássemos": "cauchutar",
    "cauchutávamo": "cauchutar",
    "cauchutávamos": "cauchutar",
    "cauchutávei": "cauchutar",
    "cauchutáveis": "cauchutar",
    "cauciona": "caucionar",
    "caucionada": "caucionar",
    "caucionadas": "caucionar",
    "caucionado": "caucionar",
    "caucionados": "caucionar",
    "caucionai": "caucionar",
    "caucionais": "caucionar",
    "caucionam": "caucionar",
    "caucionamentos": "caucionamento",
    "caucionamo": "caucionar",
    "caucionamos": "caucionar",
    "caucionando": "caucionar",
    "caucionantes": "caucionante",
    "caucionara": "caucionar",
    "caucionaram": "caucionar",
    "caucionaras": "caucionar",
    "caucionarde": "caucionar",
    "caucionardes": "caucionar",
    "caucionare": "caucionar",
    "caucionarei": "caucionar",
    "caucionareis": "caucionar",
    "caucionarem": "caucionar",
    "caucionaremos": "caucionar",
    "caucionares": "caucionar",
    "caucionaria": "caucionar",
    "caucionariam": "caucionar",
    "caucionarias": "caucionar",
    "caucionarmo": "caucionar",
    "caucionarmos": "caucionar",
    "caucionará": "caucionar",
    "caucionarás": "caucionar",
    "caucionarão": "caucionar",
    "caucionaríamos": "caucionar",
    "caucionaríeis": "caucionar",
    "caucionas": "caucionar",
    "caucionasse": "caucionar",
    "caucionassem": "caucionar",
    "caucionasses": "caucionar",
    "caucionaste": "caucionar",
    "caucionastes": "caucionar",
    "caucionava": "caucionar",
    "caucionavam": "caucionar",
    "caucionavas": "caucionar",
    "caucione": "caucionar",
    "caucionei": "caucionar",
    "caucioneis": "caucionar",
    "caucionem": "caucionar",
    "caucionemo": "caucionar",
    "caucionemos": "caucionar",
    "cauciones": "caucionar",
    "cauciono": "caucionar",
    "caucionou": "caucionar",
    "caucioná": "caucionar",
    "caucionámo": "caucionar",
    "caucionámos": "caucionar",
    "caucionáramo": "caucionar",
    "caucionáramos": "caucionar",
    "caucionárei": "caucionar",
    "caucionáreis": "caucionar",
    "caucionária": "caucionário",
    "caucionárias": "caucionário",
    "caucionários": "caucionário",
    "caucionásseis": "caucionar",
    "caucionássemos": "caucionar",
    "caucionávamo": "caucionar",
    "caucionávamos": "caucionar",
    "caucionávei": "caucionar",
    "caucionáveis": "caucionar",
    "caudais": "caudal",
    "caudalosa": "caudaloso",
    "caudalosas": "caudaloso",
    "caudalosidades": "caudalosidade",
    "caudalosos": "caudaloso",
    "caudas": "cauda",
    "caudata": "caudato",
    "caudatas": "caudato",
    "caudatos": "caudato",
    "caudatários": "caudatário",
    "caudeis": "caudel",
    "caudelarias": "caudelaria",
    "caudilha": "caudilhar",
    "caudilhada": "caudilhar",
    "caudilhadas": "caudilhar",
    "caudilhado": "caudilhar",
    "caudilhados": "caudilhar",
    "caudilhai": "caudilhar",
    "caudilhais": "caudilhar",
    "caudilham": "caudilhar",
    "caudilhamentos": "caudilhamento",
    "caudilhamo": "caudilhar",
    "caudilhamos": "caudilhar",
    "caudilhando": "caudilhar",
    "caudilhara": "caudilhar",
    "caudilharam": "caudilhar",
    "caudilharas": "caudilhar",
    "caudilharde": "caudilhar",
    "caudilhardes": "caudilhar",
    "caudilhare": "caudilhar",
    "caudilharei": "caudilhar",
    "caudilhareis": "caudilhar",
    "caudilharem": "caudilhar",
    "caudilharemos": "caudilhar",
    "caudilhares": "caudilhar",
    "caudilharia": "caudilhar",
    "caudilhariam": "caudilhar",
    "caudilharias": "caudilhar",
    "caudilharmo": "caudilhar",
    "caudilharmos": "caudilhar",
    "caudilhará": "caudilhar",
    "caudilharás": "caudilhar",
    "caudilharão": "caudilhar",
    "caudilharíamos": "caudilhar",
    "caudilharíeis": "caudilhar",
    "caudilhas": "caudilhar",
    "caudilhasse": "caudilhar",
    "caudilhassem": "caudilhar",
    "caudilhasses": "caudilhar",
    "caudilhaste": "caudilhar",
    "caudilhastes": "caudilhar",
    "caudilhava": "caudilhar",
    "caudilhavam": "caudilhar",
    "caudilhavas": "caudilhar",
    "caudilhe": "caudilhar",
    "caudilhei": "caudilhar",
    "caudilheira": "caudilheiro",
    "caudilheiras": "caudilheiro",
    "caudilheiros": "caudilheiro",
    "caudilheis": "caudilhar",
    "caudilhem": "caudilhar",
    "caudilhemo": "caudilhar",
    "caudilhemos": "caudilhar",
    "caudilhes": "caudilhar",
    "caudilhismos": "caudilhismo",
    "caudilho": "caudilhar",
    "caudilhos": "caudilho",
    "caudilhou": "caudilhar",
    "caudilhá": "caudilhar",
    "caudilhámo": "caudilhar",
    "caudilhámos": "caudilhar",
    "caudilháramo": "caudilhar",
    "caudilháramos": "caudilhar",
    "caudilhárei": "caudilhar",
    "caudilháreis": "caudilhar",
    "caudilhásseis": "caudilhar",
    "caudilhássemos": "caudilhar",
    "caudilhávamo": "caudilhar",
    "caudilhávamos": "caudilhar",
    "caudilhávei": "caudilhar",
    "caudilháveis": "caudilhar",
    "caudina": "caudino",
    "caudinas": "caudino",
    "caudinos": "caudino",
    "caudículos": "caudículo",
    "caudífera": "caudífero",
    "caudíferas": "caudífero",
    "caudíferos": "caudífero",
    "caudímana": "caudímano",
    "caudímanas": "caudímano",
    "caudímanos": "caudímano",
    "cauleosa": "cauleoso",
    "cauleosas": "cauleoso",
    "cauleosos": "cauleoso",
    "caules": "caule",
    "caulescentes": "caulescente",
    "caulescências": "caulescência",
    "caulicárpica": "caulicárpico",
    "caulicárpicas": "caulicárpico",
    "caulicárpicos": "caulicárpico",
    "caulifica": "caulificar",
    "caulificada": "caulificar",
    "caulificadas": "caulificar",
    "caulificado": "caulificar",
    "caulificados": "caulificar",
    "caulificais": "caulificar",
    "caulificam": "caulificar",
    "caulificamo": "caulificar",
    "caulificamos": "caulificar",
    "caulificando": "caulificar",
    "caulificara": "caulificar",
    "caulificaram": "caulificar",
    "caulificaras": "caulificar",
    "caulificardes": "caulificar",
    "caulificarei": "caulificar",
    "caulificareis": "caulificar",
    "caulificarem": "caulificar",
    "caulificaremos": "caulificar",
    "caulificares": "caulificar",
    "caulificaria": "caulificar",
    "caulificariam": "caulificar",
    "caulificarias": "caulificar",
    "caulificarmo": "caulificar",
    "caulificarmos": "caulificar",
    "caulificará": "caulificar",
    "caulificarás": "caulificar",
    "caulificarão": "caulificar",
    "caulificaríamos": "caulificar",
    "caulificaríeis": "caulificar",
    "caulificas": "caulificar",
    "caulificasse": "caulificar",
    "caulificassem": "caulificar",
    "caulificasses": "caulificar",
    "caulificaste": "caulificar",
    "caulificastes": "caulificar",
    "caulificava": "caulificar",
    "caulificavam": "caulificar",
    "caulificavas": "caulificar",
    "caulificações": "caulificação",
    "caulifico": "caulificar",
    "caulificou": "caulificar",
    "caulificámo": "caulificar",
    "caulificámos": "caulificar",
    "caulificáramo": "caulificar",
    "caulificáramos": "caulificar",
    "caulificáreis": "caulificar",
    "caulificásseis": "caulificar",
    "caulificássemos": "caulificar",
    "caulificávamo": "caulificar",
    "caulificávamos": "caulificar",
    "caulificáveis": "caulificar",
    "caulifique": "caulificar",
    "caulifiquei": "caulificar",
    "caulifiqueis": "caulificar",
    "caulifiquem": "caulificar",
    "caulifiquemos": "caulificar",
    "caulifiques": "caulificar",
    "cauliflora": "caulifloro",
    "caulifloras": "caulifloro",
    "caulifloros": "caulifloro",
    "caulinares": "caulinar",
    "caulinites": "caulinite",
    "cauliniza": "caulinizar",
    "caulinizada": "caulinizar",
    "caulinizadas": "caulinizar",
    "caulinizado": "caulinizar",
    "caulinizados": "caulinizar",
    "caulinizai": "caulinizar",
    "caulinizais": "caulinizar",
    "caulinizam": "caulinizar",
    "caulinizamo": "caulinizar",
    "caulinizamos": "caulinizar",
    "caulinizando": "caulinizar",
    "caulinizara": "caulinizar",
    "caulinizaram": "caulinizar",
    "caulinizaras": "caulinizar",
    "caulinizardes": "caulinizar",
    "caulinizarei": "caulinizar",
    "caulinizareis": "caulinizar",
    "caulinizarem": "caulinizar",
    "caulinizaremos": "caulinizar",
    "caulinizares": "caulinizar",
    "caulinizaria": "caulinizar",
    "caulinizariam": "caulinizar",
    "caulinizarias": "caulinizar",
    "caulinizarmo": "caulinizar",
    "caulinizarmos": "caulinizar",
    "caulinizará": "caulinizar",
    "caulinizarás": "caulinizar",
    "caulinizarão": "caulinizar",
    "caulinizaríamos": "caulinizar",
    "caulinizaríeis": "caulinizar",
    "caulinizas": "caulinizar",
    "caulinizasse": "caulinizar",
    "caulinizassem": "caulinizar",
    "caulinizasses": "caulinizar",
    "caulinizaste": "caulinizar",
    "caulinizastes": "caulinizar",
    "caulinizava": "caulinizar",
    "caulinizavam": "caulinizar",
    "caulinizavas": "caulinizar",
    "caulinizações": "caulinização",
    "caulinize": "caulinizar",
    "caulinizei": "caulinizar",
    "caulinizeis": "caulinizar",
    "caulinizem": "caulinizar",
    "caulinizemo": "caulinizar",
    "caulinizemos": "caulinizar",
    "caulinizes": "caulinizar",
    "caulinizo": "caulinizar",
    "caulinizou": "caulinizar",
    "caulinizámo": "caulinizar",
    "caulinizámos": "caulinizar",
    "caulinizáramo": "caulinizar",
    "caulinizáramos": "caulinizar",
    "caulinizáreis": "caulinizar",
    "caulinizásseis": "caulinizar",
    "caulinizássemos": "caulinizar",
    "caulinizávamo": "caulinizar",
    "caulinizávamos": "caulinizar",
    "caulinizáveis": "caulinizar",
    "caulinos": "caulino",
    "caulins": "caulim",
    "caulocarpos": "caulocarpo",
    "caulícolas": "caulícola",
    "caulículos": "caulículo",
    "caulífera": "caulífero",
    "caulíferas": "caulífero",
    "caulíferos": "caulífero",
    "caurina": "caurinar",
    "caurinada": "caurinar",
    "caurinadas": "caurinar",
    "caurinado": "caurinar",
    "caurinados": "caurinar",
    "caurinai": "caurinar",
    "caurinais": "caurinar",
    "caurinam": "caurinar",
    "caurinamo": "caurinar",
    "caurinamos": "caurinar",
    "caurinando": "caurinar",
    "caurinara": "caurinar",
    "caurinaram": "caurinar",
    "caurinaras": "caurinar",
    "caurinarde": "caurinar",
    "caurinardes": "caurinar",
    "caurinare": "caurinar",
    "caurinarei": "caurinar",
    "caurinareis": "caurinar",
    "caurinarem": "caurinar",
    "caurinaremos": "caurinar",
    "caurinares": "caurinar",
    "caurinaria": "caurinar",
    "caurinariam": "caurinar",
    "caurinarias": "caurinar",
    "caurinarmo": "caurinar",
    "caurinarmos": "caurinar",
    "caurinará": "caurinar",
    "caurinarás": "caurinar",
    "caurinarão": "caurinar",
    "caurinaríamos": "caurinar",
    "caurinaríeis": "caurinar",
    "caurinas": "caurinar",
    "caurinasse": "caurinar",
    "caurinassem": "caurinar",
    "caurinasses": "caurinar",
    "caurinaste": "caurinar",
    "caurinastes": "caurinar",
    "caurinava": "caurinar",
    "caurinavam": "caurinar",
    "caurinavas": "caurinar",
    "caurine": "caurinar",
    "caurinei": "caurinar",
    "caurineira": "caurineiro",
    "caurineiras": "caurineiro",
    "caurineiros": "caurineiro",
    "caurineis": "caurinar",
    "caurinem": "caurinar",
    "caurinemo": "caurinar",
    "caurinemos": "caurinar",
    "caurines": "caurinar",
    "caurino": "caurinar",
    "caurinou": "caurinar",
    "caurins": "caurim",
    "cauriná": "caurinar",
    "caurinámo": "caurinar",
    "caurinámos": "caurinar",
    "caurináramo": "caurinar",
    "caurináramos": "caurinar",
    "caurinárei": "caurinar",
    "caurináreis": "caurinar",
    "caurinásseis": "caurinar",
    "caurinássemos": "caurinar",
    "caurinávamo": "caurinar",
    "caurinávamos": "caurinar",
    "caurinávei": "caurinar",
    "caurináveis": "caurinar",
    "causa": "causar",
    "causada": "causar",
    "causadas": "causar",
    "causado": "causar",
    "causadora": "causador",
    "causadoras": "causador",
    "causadores": "causador",
    "causados": "causar",
    "causai": "causar",
    "causais": "causar",
    "causalidades": "causalidade",
    "causam": "causar",
    "causamo": "causar",
    "causamos": "causar",
    "causando": "causar",
    "causantes": "causante",
    "causara": "causar",
    "causaram": "causar",
    "causaras": "causar",
    "causarde": "causar",
    "causardes": "causar",
    "causare": "causar",
    "causarei": "causar",
    "causareis": "causar",
    "causarem": "causar",
    "causaremos": "causar",
    "causares": "causar",
    "causaria": "causar",
    "causariam": "causar",
    "causarias": "causar",
    "causarmo": "causar",
    "causarmos": "causar",
    "causará": "causar",
    "causarás": "causar",
    "causarão": "causar",
    "causaríamos": "causar",
    "causaríeis": "causar",
    "causas": "causar",
    "causasse": "causar",
    "causassem": "causar",
    "causasses": "causar",
    "causaste": "causar",
    "causastes": "causar",
    "causativa": "causativo",
    "causativas": "causativo",
    "causativos": "causativo",
    "causava": "causar",
    "causavam": "causar",
    "causavas": "causar",
    "cause": "causar",
    "causei": "causar",
    "causeis": "causar",
    "causem": "causar",
    "causemo": "causar",
    "causemos": "causar",
    "causes": "causar",
    "causo": "causar",
    "causou": "causar",
    "caustica": "causticar",
    "causticada": "causticar",
    "causticadas": "causticar",
    "causticado": "causticar",
    "causticados": "causticar",
    "causticais": "causticar",
    "causticam": "causticar",
    "causticamo": "causticar",
    "causticamos": "causticar",
    "causticando": "causticar",
    "causticantes": "causticante",
    "causticara": "causticar",
    "causticaram": "causticar",
    "causticaras": "causticar",
    "causticardes": "causticar",
    "causticarei": "causticar",
    "causticareis": "causticar",
    "causticarem": "causticar",
    "causticaremos": "causticar",
    "causticares": "causticar",
    "causticaria": "causticar",
    "causticariam": "causticar",
    "causticarias": "causticar",
    "causticarmo": "causticar",
    "causticarmos": "causticar",
    "causticará": "causticar",
    "causticarás": "causticar",
    "causticarão": "causticar",
    "causticaríamos": "causticar",
    "causticaríeis": "causticar",
    "causticas": "causticar",
    "causticasse": "causticar",
    "causticassem": "causticar",
    "causticasses": "causticar",
    "causticaste": "causticar",
    "causticastes": "causticar",
    "causticava": "causticar",
    "causticavam": "causticar",
    "causticavas": "causticar",
    "causticações": "causticação",
    "causticidades": "causticidade",
    "caustico": "causticar",
    "causticou": "causticar",
    "causticámo": "causticar",
    "causticámos": "causticar",
    "causticáramo": "causticar",
    "causticáramos": "causticar",
    "causticáreis": "causticar",
    "causticásseis": "causticar",
    "causticássemos": "causticar",
    "causticávamo": "causticar",
    "causticávamos": "causticar",
    "causticáveis": "causticar",
    "caustique": "causticar",
    "caustiquei": "causticar",
    "caustiqueis": "causticar",
    "caustiquem": "causticar",
    "caustiquemos": "causticar",
    "caustiques": "causticar",
    "caustobiólitos": "caustobiólito",
    "causá": "causar",
    "causámo": "causar",
    "causámos": "causar",
    "causáramo": "causar",
    "causáramos": "causar",
    "causárei": "causar",
    "causáreis": "causar",
    "causásseis": "causar",
    "causássemos": "causar",
    "causávamo": "causar",
    "causávamos": "causar",
    "causávei": "causar",
    "causáveis": "causar",
    "causídica": "causídico",
    "causídicas": "causídico",
    "causídicos": "causídico",
    "cauta": "cauto",
    "cautas": "cauto",
    "cautchus": "cautchu",
    "cautelares": "cautelar",
    "cautelas": "cautela",
    "cautelazinha": "cautela",
    "cautelazinhas": "cautela",
    "cautelazita": "cautela",
    "cautelazitas": "cautela",
    "cauteleira": "cauteleiro",
    "cauteleiras": "cauteleiro",
    "cauteleiros": "cauteleiro",
    "cautelinha": "cautela",
    "cautelinhas": "cautela",
    "cautelita": "cautela",
    "cautelitas": "cautela",
    "cautelosa": "cauteloso",
    "cautelosas": "cauteloso",
    "cautelosos": "cauteloso",
    "cauteriza": "cauterizar",
    "cauterizada": "cauterizar",
    "cauterizadas": "cauterizar",
    "cauterizado": "cauterizar",
    "cauterizadora": "cauterizador",
    "cauterizadoras": "cauterizador",
    "cauterizadores": "cauterizador",
    "cauterizados": "cauterizar",
    "cauterizai": "cauterizar",
    "cauterizais": "cauterizar",
    "cauterizam": "cauterizar",
    "cauterizamo": "cauterizar",
    "cauterizamos": "cauterizar",
    "cauterizando": "cauterizar",
    "cauterizantes": "cauterizante",
    "cauterizara": "cauterizar",
    "cauterizaram": "cauterizar",
    "cauterizaras": "cauterizar",
    "cauterizarde": "cauterizar",
    "cauterizardes": "cauterizar",
    "cauterizare": "cauterizar",
    "cauterizarei": "cauterizar",
    "cauterizareis": "cauterizar",
    "cauterizarem": "cauterizar",
    "cauterizaremos": "cauterizar",
    "cauterizares": "cauterizar",
    "cauterizaria": "cauterizar",
    "cauterizariam": "cauterizar",
    "cauterizarias": "cauterizar",
    "cauterizarmo": "cauterizar",
    "cauterizarmos": "cauterizar",
    "cauterizará": "cauterizar",
    "cauterizarás": "cauterizar",
    "cauterizarão": "cauterizar",
    "cauterizaríamos": "cauterizar",
    "cauterizaríeis": "cauterizar",
    "cauterizas": "cauterizar",
    "cauterizasse": "cauterizar",
    "cauterizassem": "cauterizar",
    "cauterizasses": "cauterizar",
    "cauterizaste": "cauterizar",
    "cauterizastes": "cauterizar",
    "cauterizava": "cauterizar",
    "cauterizavam": "cauterizar",
    "cauterizavas": "cauterizar",
    "cauterizações": "cauterização",
    "cauterize": "cauterizar",
    "cauterizei": "cauterizar",
    "cauterizeis": "cauterizar",
    "cauterizem": "cauterizar",
    "cauterizemo": "cauterizar",
    "cauterizemos": "cauterizar",
    "cauterizes": "cauterizar",
    "cauterizo": "cauterizar",
    "cauterizou": "cauterizar",
    "cauterizá": "cauterizar",
    "cauterizámo": "cauterizar",
    "cauterizámos": "cauterizar",
    "cauterizáramo": "cauterizar",
    "cauterizáramos": "cauterizar",
    "cauterizárei": "cauterizar",
    "cauterizáreis": "cauterizar",
    "cauterizásseis": "cauterizar",
    "cauterizássemos": "cauterizar",
    "cauterizávamo": "cauterizar",
    "cauterizávamos": "cauterizar",
    "cauterizávei": "cauterizar",
    "cauterizáveis": "cauterizar",
    "cautos": "cauto",
    "cautérios": "cautério",
    "cauãs": "cauã",
    "cauções": "caução",
    "cava": "cavo",
    "cavaca": "cavacar",
    "cavacada": "cavacar",
    "cavacadas": "cavacar",
    "cavacado": "cavacar",
    "cavacados": "cavacar",
    "cavacai": "cavacar",
    "cavacais": "cavacar",
    "cavacam": "cavacar",
    "cavacamo": "cavacar",
    "cavacamos": "cavacar",
    "cavacando": "cavacar",
    "cavacara": "cavacar",
    "cavacaram": "cavacar",
    "cavacaras": "cavacar",
    "cavacarde": "cavacar",
    "cavacardes": "cavacar",
    "cavacare": "cavacar",
    "cavacarei": "cavacar",
    "cavacareis": "cavacar",
    "cavacarem": "cavacar",
    "cavacaremos": "cavacar",
    "cavacares": "cavacar",
    "cavacaria": "cavacar",
    "cavacariam": "cavacar",
    "cavacarias": "cavacaria",
    "cavacarmo": "cavacar",
    "cavacarmos": "cavacar",
    "cavacará": "cavacar",
    "cavacarás": "cavacar",
    "cavacarão": "cavacar",
    "cavacaríamos": "cavacar",
    "cavacaríeis": "cavacar",
    "cavacas": "cavacar",
    "cavacasse": "cavacar",
    "cavacassem": "cavacar",
    "cavacasses": "cavacar",
    "cavacaste": "cavacar",
    "cavacastes": "cavacar",
    "cavacava": "cavacar",
    "cavacavam": "cavacar",
    "cavacavas": "cavacar",
    "cavaco": "cavacar",
    "cavacos": "cavaco",
    "cavacou": "cavacar",
    "cavacá": "cavacar",
    "cavacámo": "cavacar",
    "cavacámos": "cavacar",
    "cavacáramo": "cavacar",
    "cavacáramos": "cavacar",
    "cavacárei": "cavacar",
    "cavacáreis": "cavacar",
    "cavacásseis": "cavacar",
    "cavacássemos": "cavacar",
    "cavacávamo": "cavacar",
    "cavacávamos": "cavacar",
    "cavacávei": "cavacar",
    "cavacáveis": "cavacar",
    "cavacões": "cavacão",
    "cavada": "cavar",
    "cavadas": "cavar",
    "cavadelas": "cavadela",
    "cavadiça": "cavadiço",
    "cavadiças": "cavadiço",
    "cavadiços": "cavadiço",
    "cavado": "cavar",
    "cavadoras": "cavadora",
    "cavadores": "cavador",
    "cavados": "cavar",
    "cavaduras": "cavadura",
    "cavai": "cavar",
    "cavais": "cavar",
    "cavala": "cavalar",
    "cavalada": "cavalar",
    "cavaladas": "cavalar",
    "cavalado": "cavalar",
    "cavalados": "cavalar",
    "cavalagens": "cavalagem",
    "cavalai": "cavalar",
    "cavalais": "cavalar",
    "cavalam": "cavalar",
    "cavalamo": "cavalar",
    "cavalamos": "cavalar",
    "cavalando": "cavalar",
    "cavalara": "cavalar",
    "cavalaram": "cavalar",
    "cavalaras": "cavalar",
    "cavalardes": "cavalar",
    "cavalarei": "cavalar",
    "cavalareis": "cavalar",
    "cavalarem": "cavalar",
    "cavalaremos": "cavalar",
    "cavalares": "cavalar",
    "cavalaria": "cavalar",
    "cavalariam": "cavalar",
    "cavalarias": "cavalaria",
    "cavalariças": "cavalariça",
    "cavalariços": "cavalariço",
    "cavalarmo": "cavalar",
    "cavalarmos": "cavalar",
    "cavalará": "cavalar",
    "cavalarás": "cavalar",
    "cavalarão": "cavalar",
    "cavalaríamos": "cavalar",
    "cavalaríeis": "cavalar",
    "cavalas": "cavalar",
    "cavalasse": "cavalar",
    "cavalassem": "cavalar",
    "cavalasses": "cavalar",
    "cavalaste": "cavalar",
    "cavalastes": "cavalar",
    "cavalava": "cavalar",
    "cavalavam": "cavalar",
    "cavalavas": "cavalar",
    "cavale": "cavalar",
    "cavalei": "cavalar",
    "cavaleira": "cavaleiro",
    "cavaleirada": "cavaleirar",
    "cavaleiradas": "cavaleirar",
    "cavaleirado": "cavaleirar",
    "cavaleirados": "cavaleirar",
    "cavaleirai": "cavaleirar",
    "cavaleirais": "cavaleirar",
    "cavaleiram": "cavaleirar",
    "cavaleiramo": "cavaleirar",
    "cavaleiramos": "cavaleirar",
    "cavaleirando": "cavaleirar",
    "cavaleirara": "cavaleirar",
    "cavaleiraram": "cavaleirar",
    "cavaleiraras": "cavaleirar",
    "cavaleirardes": "cavaleirar",
    "cavaleirarei": "cavaleirar",
    "cavaleirareis": "cavaleirar",
    "cavaleirarem": "cavaleirar",
    "cavaleiraremos": "cavaleirar",
    "cavaleirares": "cavaleirar",
    "cavaleiraria": "cavaleirar",
    "cavaleirariam": "cavaleirar",
    "cavaleirarias": "cavaleirar",
    "cavaleirarmo": "cavaleirar",
    "cavaleirarmos": "cavaleirar",
    "cavaleirará": "cavaleirar",
    "cavaleirarás": "cavaleirar",
    "cavaleirarão": "cavaleirar",
    "cavaleiraríamos": "cavaleirar",
    "cavaleiraríeis": "cavaleirar",
    "cavaleiras": "cavaleiro",
    "cavaleirasse": "cavaleirar",
    "cavaleirassem": "cavaleirar",
    "cavaleirasses": "cavaleirar",
    "cavaleiraste": "cavaleirar",
    "cavaleirastes": "cavaleirar",
    "cavaleiratos": "cavaleirato",
    "cavaleirava": "cavaleirar",
    "cavaleiravam": "cavaleirar",
    "cavaleiravas": "cavaleirar",
    "cavaleire": "cavaleirar",
    "cavaleirei": "cavaleirar",
    "cavaleireis": "cavaleirar",
    "cavaleirem": "cavaleirar",
    "cavaleiremo": "cavaleirar",
    "cavaleiremos": "cavaleirar",
    "cavaleires": "cavaleirar",
    "cavaleiro": "cavaleirar",
    "cavaleiros": "cavaleiro",
    "cavaleirosa": "cavaleiroso",
    "cavaleirosas": "cavaleiroso",
    "cavaleirosos": "cavaleiroso",
    "cavaleirou": "cavaleirar",
    "cavaleirámo": "cavaleirar",
    "cavaleirámos": "cavaleirar",
    "cavaleiráramo": "cavaleirar",
    "cavaleiráramos": "cavaleirar",
    "cavaleiráreis": "cavaleirar",
    "cavaleirásseis": "cavaleirar",
    "cavaleirássemos": "cavaleirar",
    "cavaleirávamo": "cavaleirar",
    "cavaleirávamos": "cavaleirar",
    "cavaleiráveis": "cavaleirar",
    "cavaleis": "cavalar",
    "cavalem": "cavalar",
    "cavalemo": "cavalar",
    "cavalemos": "cavalar",
    "cavales": "cavalar",
    "cavaletas": "cavaleta",
    "cavaletes": "cavalete",
    "cavalga": "cavalgar",
    "cavalgada": "cavalgar",
    "cavalgadas": "cavalgar",
    "cavalgado": "cavalgar",
    "cavalgadora": "cavalgador",
    "cavalgadoras": "cavalgador",
    "cavalgadores": "cavalgador",
    "cavalgados": "cavalgar",
    "cavalgaduras": "cavalgadura",
    "cavalgai": "cavalgar",
    "cavalgais": "cavalgar",
    "cavalgam": "cavalgar",
    "cavalgamentos": "cavalgamento",
    "cavalgamo": "cavalgar",
    "cavalgamos": "cavalgar",
    "cavalgando": "cavalgar",
    "cavalgantes": "cavalgante",
    "cavalgara": "cavalgar",
    "cavalgaram": "cavalgar",
    "cavalgaras": "cavalgar",
    "cavalgardes": "cavalgar",
    "cavalgarei": "cavalgar",
    "cavalgareis": "cavalgar",
    "cavalgarem": "cavalgar",
    "cavalgaremos": "cavalgar",
    "cavalgares": "cavalgar",
    "cavalgaria": "cavalgar",
    "cavalgariam": "cavalgar",
    "cavalgarias": "cavalgar",
    "cavalgarmo": "cavalgar",
    "cavalgarmos": "cavalgar",
    "cavalgará": "cavalgar",
    "cavalgarás": "cavalgar",
    "cavalgarão": "cavalgar",
    "cavalgaríamos": "cavalgar",
    "cavalgaríeis": "cavalgar",
    "cavalgas": "cavalgar",
    "cavalgasse": "cavalgar",
    "cavalgassem": "cavalgar",
    "cavalgasses": "cavalgar",
    "cavalgaste": "cavalgar",
    "cavalgastes": "cavalgar",
    "cavalgatas": "cavalgata",
    "cavalgava": "cavalgar",
    "cavalgavam": "cavalgar",
    "cavalgavas": "cavalgar",
    "cavalgo": "cavalgar",
    "cavalgou": "cavalgar",
    "cavalgue": "cavalgar",
    "cavalguei": "cavalgar",
    "cavalgueis": "cavalgar",
    "cavalguem": "cavalgar",
    "cavalguemo": "cavalgar",
    "cavalguemos": "cavalgar",
    "cavalgues": "cavalgar",
    "cavalgámo": "cavalgar",
    "cavalgámos": "cavalgar",
    "cavalgáramo": "cavalgar",
    "cavalgáramos": "cavalgar",
    "cavalgáreis": "cavalgar",
    "cavalgásseis": "cavalgar",
    "cavalgássemos": "cavalgar",
    "cavalgávamo": "cavalgar",
    "cavalgávamos": "cavalgar",
    "cavalgáveis": "cavalgar",
    "cavalhadas": "cavalhada",
    "cavalheira": "cavalheiro",
    "cavalheiras": "cavalheiro",
    "cavalheiresca": "cavalheiresco",
    "cavalheirescas": "cavalheiresco",
    "cavalheirescos": "cavalheiresco",
    "cavalheirismos": "cavalheirismo",
    "cavalheiros": "cavalheiro",
    "cavalheirosa": "cavalheiroso",
    "cavalheirosas": "cavalheiroso",
    "cavalheirosos": "cavalheiroso",
    "cavalicoques": "cavalicoque",
    "cavalidades": "cavalidade",
    "cavalinhas": "cavalinha",
    "cavalinho": "cavalo",
    "cavalinhos": "cavalo",
    "cavalito": "cavalo",
    "cavalitos": "cavalo",
    "cavalo": "cavalar",
    "cavalona": "cavalão",
    "cavalonas": "cavalão",
    "cavalos": "cavalo",
    "cavalou": "cavalar",
    "cavalámo": "cavalar",
    "cavalámos": "cavalar",
    "cavaláramo": "cavalar",
    "cavaláramos": "cavalar",
    "cavaláreis": "cavalar",
    "cavalásseis": "cavalar",
    "cavalássemos": "cavalar",
    "cavalávamo": "cavalar",
    "cavalávamos": "cavalar",
    "cavaláveis": "cavalar",
    "cavalórios": "cavalório",
    "cavalões": "cavalão",
    "cavam": "cavar",
    "cavamo": "cavar",
    "cavamos": "cavar",
    "cavando": "cavar",
    "cavaneja": "cavanejo",
    "cavanejas": "cavanejo",
    "cavanejos": "cavanejo",
    "cavanhaques": "cavanhaque",
    "cavaque": "cavacar",
    "cavaqueada": "cavaquear",
    "cavaqueadas": "cavaquear",
    "cavaqueado": "cavaquear",
    "cavaqueadora": "cavaqueador",
    "cavaqueadoras": "cavaqueador",
    "cavaqueadores": "cavaqueador",
    "cavaqueados": "cavaquear",
    "cavaqueai": "cavaquear",
    "cavaqueais": "cavaquear",
    "cavaqueamo": "cavaquear",
    "cavaqueamos": "cavaquear",
    "cavaqueando": "cavaquear",
    "cavaqueara": "cavaquear",
    "cavaquearam": "cavaquear",
    "cavaquearas": "cavaquear",
    "cavaqueardes": "cavaquear",
    "cavaquearei": "cavaquear",
    "cavaqueareis": "cavaquear",
    "cavaquearem": "cavaquear",
    "cavaquearemos": "cavaquear",
    "cavaqueares": "cavaquear",
    "cavaquearia": "cavaquear",
    "cavaqueariam": "cavaquear",
    "cavaquearias": "cavaquear",
    "cavaquearmo": "cavaquear",
    "cavaquearmos": "cavaquear",
    "cavaqueará": "cavaquear",
    "cavaquearás": "cavaquear",
    "cavaquearão": "cavaquear",
    "cavaquearíamos": "cavaquear",
    "cavaquearíeis": "cavaquear",
    "cavaqueasse": "cavaquear",
    "cavaqueassem": "cavaquear",
    "cavaqueasses": "cavaquear",
    "cavaqueaste": "cavaquear",
    "cavaqueastes": "cavaquear",
    "cavaqueava": "cavaquear",
    "cavaqueavam": "cavaquear",
    "cavaqueavas": "cavaquear",
    "cavaqueei": "cavaquear",
    "cavaqueeis": "cavaquear",
    "cavaqueemo": "cavaquear",
    "cavaqueemos": "cavaquear",
    "cavaquei": "cavacar",
    "cavaqueia": "cavaquear",
    "cavaqueiam": "cavaquear",
    "cavaqueias": "cavaquear",
    "cavaqueie": "cavaquear",
    "cavaqueiem": "cavaquear",
    "cavaqueies": "cavaquear",
    "cavaqueio": "cavaquear",
    "cavaqueios": "cavaqueio",
    "cavaqueiras": "cavaqueira",
    "cavaqueis": "cavacar",
    "cavaquem": "cavacar",
    "cavaquemo": "cavacar",
    "cavaquemos": "cavacar",
    "cavaqueou": "cavaquear",
    "cavaques": "cavacar",
    "cavaqueámo": "cavaquear",
    "cavaqueámos": "cavaquear",
    "cavaqueáramo": "cavaquear",
    "cavaqueáramos": "cavaquear",
    "cavaqueáreis": "cavaquear",
    "cavaqueásseis": "cavaquear",
    "cavaqueássemos": "cavaquear",
    "cavaqueávamo": "cavaquear",
    "cavaqueávamos": "cavaquear",
    "cavaqueáveis": "cavaquear",
    "cavaquinha": "cavaca",
    "cavaquinhas": "cavaca",
    "cavaquinho": "cavaco",
    "cavaquinhos": "cavaquinho",
    "cavaquismos": "cavaquismo",
    "cavaquistas": "cavaquista",
    "cavaquita": "cavaca",
    "cavaquitas": "cavaca",
    "cavaquito": "cavaco",
    "cavaquitos": "cavaco",
    "cavara": "cavar",
    "cavaram": "cavar",
    "cavaras": "cavar",
    "cavarde": "cavar",
    "cavardes": "cavar",
    "cavare": "cavar",
    "cavarei": "cavar",
    "cavareis": "cavar",
    "cavarem": "cavar",
    "cavaremos": "cavar",
    "cavares": "cavar",
    "cavaria": "cavar",
    "cavariam": "cavar",
    "cavarias": "cavar",
    "cavarmo": "cavar",
    "cavarmos": "cavar",
    "cavará": "cavar",
    "cavarás": "cavar",
    "cavarão": "cavar",
    "cavaríamos": "cavar",
    "cavaríeis": "cavar",
    "cavas": "cavo",
    "cavasse": "cavar",
    "cavassem": "cavar",
    "cavasses": "cavar",
    "cavaste": "cavar",
    "cavastes": "cavar",
    "cavaterras": "cavaterra",
    "cavatinas": "cavatina",
    "cavava": "cavar",
    "cavavam": "cavar",
    "cavavas": "cavar",
    "cavações": "cavação",
    "cave": "cavar",
    "cavedais": "cavedal",
    "cavei": "cavar",
    "caveirada": "caveirado",
    "caveiradas": "caveirado",
    "caveirados": "caveirado",
    "caveiras": "caveira",
    "caveirosa": "caveiroso",
    "caveirosas": "caveiroso",
    "caveirosos": "caveiroso",
    "caveis": "cavar",
    "cavem": "cavar",
    "cavemo": "cavar",
    "cavemos": "cavar",
    "cavernais": "cavernal",
    "cavernames": "cavername",
    "cavernas": "caverna",
    "cavernosa": "cavernoso",
    "cavernosas": "cavernoso",
    "cavernosos": "cavernoso",
    "cavernícolaes": "cavernícola",
    "cavernícolas": "cavernícola",
    "caves": "cave",
    "cavetos": "caveto",
    "caviares": "caviar",
    "cavicórnea": "cavicórneo",
    "cavicórneas": "cavicórneo",
    "cavicórneos": "cavicórneo",
    "cavidades": "cavidade",
    "cavila": "cavilar",
    "cavilada": "cavilar",
    "caviladas": "cavilar",
    "cavilado": "cavilar",
    "caviladora": "cavilador",
    "caviladoras": "cavilador",
    "caviladores": "cavilador",
    "cavilados": "cavilar",
    "cavilai": "cavilar",
    "cavilais": "cavilar",
    "cavilam": "cavilar",
    "cavilamo": "cavilar",
    "cavilamos": "cavilar",
    "cavilando": "cavilar",
    "cavilara": "cavilar",
    "cavilaram": "cavilar",
    "cavilaras": "cavilar",
    "cavilardes": "cavilar",
    "cavilarei": "cavilar",
    "cavilareis": "cavilar",
    "cavilarem": "cavilar",
    "cavilaremos": "cavilar",
    "cavilares": "cavilar",
    "cavilaria": "cavilar",
    "cavilariam": "cavilar",
    "cavilarias": "cavilar",
    "cavilarmo": "cavilar",
    "cavilarmos": "cavilar",
    "cavilará": "cavilar",
    "cavilarás": "cavilar",
    "cavilarão": "cavilar",
    "cavilaríamos": "cavilar",
    "cavilaríeis": "cavilar",
    "cavilas": "cavilar",
    "cavilasse": "cavilar",
    "cavilassem": "cavilar",
    "cavilasses": "cavilar",
    "cavilaste": "cavilar",
    "cavilastes": "cavilar",
    "cavilava": "cavilar",
    "cavilavam": "cavilar",
    "cavilavas": "cavilar",
    "cavilações": "cavilação",
    "cavile": "cavilar",
    "cavilei": "cavilar",
    "cavileis": "cavilar",
    "cavilem": "cavilar",
    "cavilemo": "cavilar",
    "cavilemos": "cavilar",
    "caviles": "cavilar",
    "cavilha": "cavilhar",
    "cavilhada": "cavilhar",
    "cavilhadas": "cavilhar",
    "cavilhado": "cavilhar",
    "cavilhadora": "cavilhador",
    "cavilhadoras": "cavilhador",
    "cavilhadores": "cavilhador",
    "cavilhados": "cavilhar",
    "cavilhai": "cavilhar",
    "cavilhais": "cavilhar",
    "cavilham": "cavilhar",
    "cavilhamo": "cavilhar",
    "cavilhamos": "cavilhar",
    "cavilhando": "cavilhar",
    "cavilhara": "cavilhar",
    "cavilharam": "cavilhar",
    "cavilharas": "cavilhar",
    "cavilharde": "cavilhar",
    "cavilhardes": "cavilhar",
    "cavilhare": "cavilhar",
    "cavilharei": "cavilhar",
    "cavilhareis": "cavilhar",
    "cavilharem": "cavilhar",
    "cavilharemos": "cavilhar",
    "cavilhares": "cavilhar",
    "cavilharia": "cavilhar",
    "cavilhariam": "cavilhar",
    "cavilharias": "cavilhar",
    "cavilharmo": "cavilhar",
    "cavilharmos": "cavilhar",
    "cavilhará": "cavilhar",
    "cavilharás": "cavilhar",
    "cavilharão": "cavilhar",
    "cavilharíamos": "cavilhar",
    "cavilharíeis": "cavilhar",
    "cavilhas": "cavilhar",
    "cavilhasse": "cavilhar",
    "cavilhassem": "cavilhar",
    "cavilhasses": "cavilhar",
    "cavilhaste": "cavilhar",
    "cavilhastes": "cavilhar",
    "cavilhava": "cavilhar",
    "cavilhavam": "cavilhar",
    "cavilhavas": "cavilhar",
    "cavilhações": "cavilhação",
    "cavilhe": "cavilhar",
    "cavilhei": "cavilhar",
    "cavilheis": "cavilhar",
    "cavilhem": "cavilhar",
    "cavilhemo": "cavilhar",
    "cavilhemos": "cavilhar",
    "cavilhes": "cavilhar",
    "cavilho": "cavilhar",
    "cavilhou": "cavilhar",
    "cavilhá": "cavilhar",
    "cavilhámo": "cavilhar",
    "cavilhámos": "cavilhar",
    "cavilháramo": "cavilhar",
    "cavilháramos": "cavilhar",
    "cavilhárei": "cavilhar",
    "cavilháreis": "cavilhar",
    "cavilhásseis": "cavilhar",
    "cavilhássemos": "cavilhar",
    "cavilhávamo": "cavilhar",
    "cavilhávamos": "cavilhar",
    "cavilhávei": "cavilhar",
    "cavilháveis": "cavilhar",
    "cavilo": "cavilar",
    "cavilosa": "caviloso",
    "cavilosas": "caviloso",
    "cavilosos": "caviloso",
    "cavilou": "cavilar",
    "cavilámo": "cavilar",
    "cavilámos": "cavilar",
    "caviláramo": "cavilar",
    "caviláramos": "cavilar",
    "caviláreis": "cavilar",
    "cavilásseis": "cavilar",
    "cavilássemos": "cavilar",
    "cavilávamo": "cavilar",
    "cavilávamos": "cavilar",
    "caviláveis": "cavilar",
    "cavirrostra": "cavirrostro",
    "cavirrostras": "cavirrostro",
    "cavirrostros": "cavirrostro",
    "cavitações": "cavitação",
    "cavitária": "cavitário",
    "cavitárias": "cavitário",
    "cavitários": "cavitário",
    "caviás": "caviá",
    "caviídas": "caviída",
    "caviídea": "caviídeo",
    "caviídeas": "caviídeo",
    "caviídeos": "caviídeo",
    "cavo": "cavar",
    "cavos": "cavo",
    "cavou": "cavar",
    "cavouca": "cavoucar",
    "cavoucada": "cavoucar",
    "cavoucadas": "cavoucar",
    "cavoucado": "cavoucar",
    "cavoucados": "cavoucar",
    "cavoucai": "cavoucar",
    "cavoucais": "cavoucar",
    "cavoucam": "cavoucar",
    "cavoucamo": "cavoucar",
    "cavoucamos": "cavoucar",
    "cavoucando": "cavoucar",
    "cavoucara": "cavoucar",
    "cavoucaram": "cavoucar",
    "cavoucaras": "cavoucar",
    "cavoucarde": "cavoucar",
    "cavoucardes": "cavoucar",
    "cavoucare": "cavoucar",
    "cavoucarei": "cavoucar",
    "cavoucareis": "cavoucar",
    "cavoucarem": "cavoucar",
    "cavoucaremos": "cavoucar",
    "cavoucares": "cavoucar",
    "cavoucaria": "cavoucar",
    "cavoucariam": "cavoucar",
    "cavoucarias": "cavoucar",
    "cavoucarmo": "cavoucar",
    "cavoucarmos": "cavoucar",
    "cavoucará": "cavoucar",
    "cavoucarás": "cavoucar",
    "cavoucarão": "cavoucar",
    "cavoucaríamos": "cavoucar",
    "cavoucaríeis": "cavoucar",
    "cavoucas": "cavoucar",
    "cavoucasse": "cavoucar",
    "cavoucassem": "cavoucar",
    "cavoucasses": "cavoucar",
    "cavoucaste": "cavoucar",
    "cavoucastes": "cavoucar",
    "cavoucava": "cavoucar",
    "cavoucavam": "cavoucar",
    "cavoucavas": "cavoucar",
    "cavouco": "cavoucar",
    "cavoucos": "cavouco",
    "cavoucou": "cavoucar",
    "cavoucá": "cavoucar",
    "cavoucámo": "cavoucar",
    "cavoucámos": "cavoucar",
    "cavoucáramo": "cavoucar",
    "cavoucáramos": "cavoucar",
    "cavoucárei": "cavoucar",
    "cavoucáreis": "cavoucar",
    "cavoucásseis": "cavoucar",
    "cavoucássemos": "cavoucar",
    "cavoucávamo": "cavoucar",
    "cavoucávamos": "cavoucar",
    "cavoucávei": "cavoucar",
    "cavoucáveis": "cavoucar",
    "cavouque": "cavoucar",
    "cavouquei": "cavoucar",
    "cavouqueira": "cavouqueiro",
    "cavouqueiras": "cavouqueiro",
    "cavouqueiros": "cavouqueiro",
    "cavouqueis": "cavoucar",
    "cavouquem": "cavoucar",
    "cavouquemo": "cavoucar",
    "cavouquemos": "cavoucar",
    "cavouques": "cavoucar",
    "cavá": "cavar",
    "cavámo": "cavar",
    "cavámos": "cavar",
    "caváramo": "cavar",
    "caváramos": "cavar",
    "cavárei": "cavar",
    "caváreis": "cavar",
    "cavásseis": "cavar",
    "cavássemos": "cavar",
    "cavávamo": "cavar",
    "cavávamos": "cavar",
    "cavávei": "cavar",
    "caváveis": "cavar",
    "cavões": "cavão",
    "caxamolas": "caxamola",
    "caxas": "caxa",
    "caxemiras": "caxemira",
    "caxes": "caxe",
    "caxetas": "caxeta",
    "caxos": "caxo",
    "caxumbas": "caxumba",
    "caça": "caçar",
    "caçada": "caçar",
    "caçadas": "caçar",
    "caçadeira": "caçador",
    "caçadeiras": "caçador",
    "caçado": "caçar",
    "caçadora": "caçador",
    "caçadoras": "caçador",
    "caçadores": "caçador",
    "caçados": "caçar",
    "caçai": "caçar",
    "caçais": "caçar",
    "caçam": "caçar",
    "caçambas": "caçamba",
    "caçamo": "caçar",
    "caçamos": "caçar",
    "caçando": "caçar",
    "caçantes": "caçante",
    "caçapeiras": "caçapeira",
    "caçapos": "caçapo",
    "caçara": "caçar",
    "caçaram": "caçar",
    "caçaras": "caçar",
    "caçarde": "caçar",
    "caçardes": "caçar",
    "caçare": "caçar",
    "caçarei": "caçar",
    "caçareis": "caçar",
    "caçarem": "caçar",
    "caçaremos": "caçar",
    "caçares": "caçar",
    "caçaria": "caçar",
    "caçariam": "caçar",
    "caçarias": "caçar",
    "caçarmo": "caçar",
    "caçarmos": "caçar",
    "caçarolas": "caçarola",
    "caçará": "caçar",
    "caçarás": "caçar",
    "caçarão": "caçar",
    "caçaríamos": "caçar",
    "caçaríeis": "caçar",
    "caças": "caçar",
    "caçasse": "caçar",
    "caçassem": "caçar",
    "caçasses": "caçar",
    "caçaste": "caçar",
    "caçastes": "caçar",
    "caçava": "caçar",
    "caçavam": "caçar",
    "caçavas": "caçava",
    "caçaves": "caçave",
    "caço": "caçar",
    "caçoa": "caçoar",
    "caçoada": "caçoar",
    "caçoadas": "caçoar",
    "caçoado": "caçoar",
    "caçoadora": "caçoador",
    "caçoadoras": "caçoador",
    "caçoadores": "caçoador",
    "caçoados": "caçoar",
    "caçoai": "caçoar",
    "caçoais": "caçoar",
    "caçoam": "caçoar",
    "caçoamo": "caçoar",
    "caçoamos": "caçoar",
    "caçoando": "caçoar",
    "caçoara": "caçoar",
    "caçoaram": "caçoar",
    "caçoaras": "caçoar",
    "caçoarde": "caçoar",
    "caçoardes": "caçoar",
    "caçoare": "caçoar",
    "caçoarei": "caçoar",
    "caçoareis": "caçoar",
    "caçoarem": "caçoar",
    "caçoaremos": "caçoar",
    "caçoares": "caçoar",
    "caçoaria": "caçoar",
    "caçoariam": "caçoar",
    "caçoarias": "caçoaria",
    "caçoarmo": "caçoar",
    "caçoarmos": "caçoar",
    "caçoará": "caçoar",
    "caçoarás": "caçoar",
    "caçoarão": "caçoar",
    "caçoaríamos": "caçoar",
    "caçoaríeis": "caçoar",
    "caçoas": "caçoar",
    "caçoasse": "caçoar",
    "caçoassem": "caçoar",
    "caçoasses": "caçoar",
    "caçoaste": "caçoar",
    "caçoastes": "caçoar",
    "caçoava": "caçoar",
    "caçoavam": "caçoar",
    "caçoavas": "caçoar",
    "caçoe": "caçoar",
    "caçoei": "caçoar",
    "caçoeis": "caçoar",
    "caçoem": "caçoar",
    "caçoemo": "caçoar",
    "caçoemos": "caçoar",
    "caçoes": "caçoar",
    "caçoilas": "caçoila",
    "caçoilos": "caçoilo",
    "caçoistas": "caçoista",
    "caçoletas": "caçoleta",
    "caçoo": "caçoar",
    "caçoou": "caçoar",
    "caços": "caço",
    "caçou": "caçar",
    "caçouladas": "caçoulada",
    "caçoulas": "caçoula",
    "caçoulos": "caçoulo",
    "caçoá": "caçoar",
    "caçoámo": "caçoar",
    "caçoámos": "caçoar",
    "caçoáramo": "caçoar",
    "caçoáramos": "caçoar",
    "caçoárei": "caçoar",
    "caçoáreis": "caçoar",
    "caçoásseis": "caçoar",
    "caçoássemos": "caçoar",
    "caçoávamo": "caçoar",
    "caçoávamos": "caçoar",
    "caçoávei": "caçoar",
    "caçoáveis": "caçoar",
    "caçulas": "caçula",
    "caçurrenta": "caçurrento",
    "caçurrentas": "caçurrento",
    "caçurrentos": "caçurrento",
    "caçurros": "caçurro",
    "caçá": "caçar",
    "caçámo": "caçar",
    "caçámos": "caçar",
    "caçáramo": "caçar",
    "caçáramos": "caçar",
    "caçárei": "caçar",
    "caçáreis": "caçar",
    "caçásseis": "caçar",
    "caçássemos": "caçar",
    "caçávamo": "caçar",
    "caçávamos": "caçar",
    "caçávei": "caçar",
    "caçáveis": "caçar",
    "cações": "cação",
    "caí": "cair",
    "caía": "cair",
    "caíam": "cair",
    "caíamo": "cair",
    "caíamos": "cair",
    "caías": "cair",
    "caída": "cair",
    "caídas": "cair",
    "caído": "cair",
    "caídos": "cair",
    "caíeis": "cair",
    "caímo": "cair",
    "caímos": "cair",
    "caíques": "caíque",
    "caíra": "cair",
    "caíram": "cair",
    "caíramo": "cair",
    "caíramos": "cair",
    "caíras": "cair",
    "caíreis": "cair",
    "caírem": "cair",
    "caíres": "cair",
    "caís": "cair",
    "caísse": "cair",
    "caísseis": "cair",
    "caíssem": "cair",
    "caíssemos": "cair",
    "caísses": "cair",
    "caíste": "cair",
    "caístes": "cair",
    "caótica": "caótico",
    "caóticas": "caótico",
    "caóticos": "caótico",
    "caúnas": "caúna",
    "cc": "c",
    "ceada": "cear",
    "ceadas": "cear",
    "ceado": "cear",
    "ceados": "cear",
    "ceai": "cear",
    "ceais": "cear",
    "ceamo": "cear",
    "ceamos": "cear",
    "ceando": "cear",
    "ceara": "cear",
    "cearam": "cear",
    "cearas": "cear",
    "ceardes": "cear",
    "cearei": "cear",
    "ceareis": "cear",
    "cearem": "cear",
    "cearemos": "cear",
    "cearenses": "cearense",
    "ceares": "cear",
    "cearia": "cear",
    "ceariam": "cear",
    "cearias": "cear",
    "cearmo": "cear",
    "cearmos": "cear",
    "ceará": "cear",
    "cearás": "cear",
    "cearão": "cear",
    "cearíamos": "cear",
    "cearíeis": "cear",
    "ceasse": "cear",
    "ceassem": "cear",
    "ceasses": "cear",
    "ceaste": "cear",
    "ceastes": "cear",
    "ceatas": "ceata",
    "ceava": "cear",
    "ceavam": "cear",
    "ceavas": "cear",
    "cebocefálica": "cebocefálico",
    "cebocefálicas": "cebocefálico",
    "cebocefálicos": "cebocefálico",
    "cebocéfala": "cebocéfalo",
    "cebocéfalas": "cebocéfalo",
    "cebocéfalos": "cebocéfalo",
    "ceboladas": "cebolada",
    "cebolais": "cebolal",
    "cebolas": "cebola",
    "ceboleira": "ceboleiro",
    "ceboleiras": "ceboleiro",
    "ceboleiros": "ceboleiro",
    "cebolinha": "cebola",
    "cebolinhas": "cebolinha",
    "cebolinho": "cebolo",
    "cebolinhos": "cebolo",
    "cebolita": "cebola",
    "cebolitas": "cebola",
    "cebolito": "cebolo",
    "cebolitos": "cebolo",
    "cebolos": "cebolo",
    "cebolões": "cebolão",
    "cecais": "cecal",
    "ceceada": "cecear",
    "ceceadas": "cecear",
    "ceceado": "cecear",
    "ceceados": "cecear",
    "ceceaduras": "ceceadura",
    "ceceai": "cecear",
    "ceceais": "cecear",
    "ceceamo": "cecear",
    "ceceamos": "cecear",
    "ceceando": "cecear",
    "ceceara": "cecear",
    "cecearam": "cecear",
    "cecearas": "cecear",
    "ceceardes": "cecear",
    "cecearei": "cecear",
    "ceceareis": "cecear",
    "cecearem": "cecear",
    "cecearemos": "cecear",
    "ceceares": "cecear",
    "cecearia": "cecear",
    "ceceariam": "cecear",
    "cecearias": "cecear",
    "cecearmo": "cecear",
    "cecearmos": "cecear",
    "ceceará": "cecear",
    "cecearás": "cecear",
    "cecearão": "cecear",
    "cecearíamos": "cecear",
    "cecearíeis": "cecear",
    "ceceasse": "cecear",
    "ceceassem": "cecear",
    "ceceasses": "cecear",
    "ceceaste": "cecear",
    "ceceastes": "cecear",
    "ceceava": "cecear",
    "ceceavam": "cecear",
    "ceceavas": "cecear",
    "ceceei": "cecear",
    "ceceeis": "cecear",
    "ceceemo": "cecear",
    "ceceemos": "cecear",
    "ceceia": "cecear",
    "ceceiam": "cecear",
    "ceceias": "cecear",
    "ceceie": "cecear",
    "ceceiem": "cecear",
    "ceceies": "cecear",
    "ceceio": "cecear",
    "ceceios": "ceceio",
    "ceceiozinho": "ceceio",
    "ceceiozinhos": "ceceio",
    "ceceiozito": "ceceio",
    "ceceiozitos": "ceceio",
    "ceceosa": "ceceoso",
    "ceceosas": "ceceoso",
    "ceceosos": "ceceoso",
    "ceceou": "cecear",
    "ceceámo": "cecear",
    "ceceámos": "cecear",
    "ceceáramo": "cecear",
    "ceceáramos": "cecear",
    "ceceáreis": "cecear",
    "ceceásseis": "cecear",
    "ceceássemos": "cecear",
    "ceceávamo": "cecear",
    "ceceávamos": "cecear",
    "ceceáveis": "cecear",
    "cecocolostomias": "cecocolostomia",
    "cecografias": "cecografia",
    "cecográfica": "cecográfico",
    "cecográficas": "cecográfico",
    "cecográficos": "cecográfico",
    "cecos": "ceco",
    "cecotomias": "cecotomia",
    "cecotómica": "cecotómico",
    "cecotómicas": "cecotómico",
    "cecotómicos": "cecotómico",
    "cecéns": "cecém",
    "cecídias": "cecídia",
    "cecógrafos": "cecógrafo",
    "ceda": "ceder",
    "cedais": "ceder",
    "cedam": "ceder",
    "cedamo": "ceder",
    "cedamos": "ceder",
    "cedas": "ceder",
    "cede": "ceder",
    "cedei": "ceder",
    "cedeira": "cedeiro",
    "cedeiras": "cedeiro",
    "cedeiros": "cedeiro",
    "cedeis": "ceder",
    "cedem": "ceder",
    "cedemo": "ceder",
    "cedemos": "ceder",
    "cedendo": "ceder",
    "cedentes": "cedente",
    "cedera": "ceder",
    "cederam": "ceder",
    "cederas": "ceder",
    "cederdes": "ceder",
    "cederei": "ceder",
    "cedereis": "ceder",
    "cederem": "ceder",
    "cederemos": "ceder",
    "cederes": "ceder",
    "cederia": "ceder",
    "cederiam": "ceder",
    "cederias": "ceder",
    "cedermo": "ceder",
    "cedermos": "ceder",
    "cederá": "ceder",
    "cederás": "ceder",
    "cederão": "ceder",
    "cederíamos": "ceder",
    "cederíeis": "ceder",
    "cedes": "ceder",
    "cedesse": "ceder",
    "cedessem": "ceder",
    "cedesses": "ceder",
    "cedeste": "ceder",
    "cedestes": "ceder",
    "cedeu": "ceder",
    "cedi": "ceder",
    "cedia": "ceder",
    "cediam": "ceder",
    "cedias": "ceder",
    "cedida": "cedido",
    "cedidas": "cedido",
    "cedido": "ceder",
    "cedidos": "cedido",
    "cedilha": "cedilhar",
    "cedilhada": "cedilhar",
    "cedilhadas": "cedilhar",
    "cedilhado": "cedilhar",
    "cedilhados": "cedilhar",
    "cedilhai": "cedilhar",
    "cedilhais": "cedilhar",
    "cedilham": "cedilhar",
    "cedilhamo": "cedilhar",
    "cedilhamos": "cedilhar",
    "cedilhando": "cedilhar",
    "cedilhara": "cedilhar",
    "cedilharam": "cedilhar",
    "cedilharas": "cedilhar",
    "cedilharde": "cedilhar",
    "cedilhardes": "cedilhar",
    "cedilhare": "cedilhar",
    "cedilharei": "cedilhar",
    "cedilhareis": "cedilhar",
    "cedilharem": "cedilhar",
    "cedilharemos": "cedilhar",
    "cedilhares": "cedilhar",
    "cedilharia": "cedilhar",
    "cedilhariam": "cedilhar",
    "cedilharias": "cedilhar",
    "cedilharmo": "cedilhar",
    "cedilharmos": "cedilhar",
    "cedilhará": "cedilhar",
    "cedilharás": "cedilhar",
    "cedilharão": "cedilhar",
    "cedilharíamos": "cedilhar",
    "cedilharíeis": "cedilhar",
    "cedilhas": "cedilhar",
    "cedilhasse": "cedilhar",
    "cedilhassem": "cedilhar",
    "cedilhasses": "cedilhar",
    "cedilhaste": "cedilhar",
    "cedilhastes": "cedilhar",
    "cedilhava": "cedilhar",
    "cedilhavam": "cedilhar",
    "cedilhavas": "cedilhar",
    "cedilhe": "cedilhar",
    "cedilhei": "cedilhar",
    "cedilheis": "cedilhar",
    "cedilhem": "cedilhar",
    "cedilhemo": "cedilhar",
    "cedilhemos": "cedilhar",
    "cedilhes": "cedilhar",
    "cedilho": "cedilhar",
    "cedilhou": "cedilhar",
    "cedilhá": "cedilhar",
    "cedilhámo": "cedilhar",
    "cedilhámos": "cedilhar",
    "cedilháramo": "cedilhar",
    "cedilháramos": "cedilhar",
    "cedilhárei": "cedilhar",
    "cedilháreis": "cedilhar",
    "cedilhásseis": "cedilhar",
    "cedilhássemos": "cedilhar",
    "cedilhávamo": "cedilhar",
    "cedilhávamos": "cedilhar",
    "cedilhávei": "cedilhar",
    "cedilháveis": "cedilhar",
    "cedimentos": "cedimento",
    "cedinho": "cedo",
    "cedito": "cedo",
    "cediça": "cediço",
    "cediças": "cediço",
    "cediços": "cediço",
    "cedo": "ceder",
    "cedreleáceas": "cedreleácea",
    "cedrina": "cedrino",
    "cedrinas": "cedrino",
    "cedrinos": "cedrino",
    "cedritas": "cedrita",
    "cedros": "cedro",
    "cedrões": "cedrão",
    "cedências": "cedência",
    "cedêramo": "ceder",
    "cedêramos": "ceder",
    "cedêreis": "ceder",
    "cedêsseis": "ceder",
    "cedêssemos": "ceder",
    "cedíamo": "ceder",
    "cedíamos": "ceder",
    "cedíeis": "ceder",
    "cedíssimo": "cedo",
    "cedíveis": "cedível",
    "ceei": "cear",
    "ceeiros": "ceeiro",
    "ceeis": "cear",
    "ceemo": "cear",
    "ceemos": "cear",
    "cefalada": "cefalado",
    "cefaladas": "cefalado",
    "cefalados": "cefalado",
    "cefaleias": "cefaleia",
    "cefalgias": "cefalgia",
    "cefalites": "cefalite",
    "cefalocordados": "cefalocordado",
    "cefalometrias": "cefalometria",
    "cefalométrica": "cefalométrico",
    "cefalométricas": "cefalométrico",
    "cefalométricos": "cefalométrico",
    "cefalopóides": "cefalopóide",
    "cefalorraquidiana": "cefalorraquidiano",
    "cefalorraquidianas": "cefalorraquidiano",
    "cefalorraquidianos": "cefalorraquidiano",
    "cefalotomias": "cefalotomia",
    "cefalotóraxes": "cefalotórax",
    "cefalálgica": "cefalálgico",
    "cefalálgicas": "cefalálgico",
    "cefalálgicos": "cefalálgico",
    "cefalóides": "cefalóide",
    "cefalómetros": "cefalómetro",
    "cefalópodes": "cefalópode",
    "cefalótomos": "cefalótomo",
    "cefalões": "cefalão",
    "cefeidas": "cefeida",
    "cefos": "cefo",
    "cefálica": "cefálico",
    "cefálicas": "cefálico",
    "cefálicos": "cefálico",
    "cega": "cego",
    "cegada": "cegar",
    "cegadas": "cegar",
    "cegado": "cegar",
    "cegados": "cegar",
    "cegagens": "cegagem",
    "cegai": "cegar",
    "cegais": "cegar",
    "cegam": "cegar",
    "cegamo": "cegar",
    "cegamos": "cegar",
    "cegando": "cegar",
    "cegara": "cegar",
    "cegaram": "cegar",
    "cegaras": "cegar",
    "cegarde": "cegar",
    "cegardes": "cegar",
    "cegare": "cegar",
    "cegarei": "cegar",
    "cegareis": "cegar",
    "cegarem": "cegar",
    "cegaremos": "cegar",
    "cegares": "cegar",
    "cegaria": "cegar",
    "cegariam": "cegar",
    "cegarias": "cegar",
    "cegarmo": "cegar",
    "cegarmos": "cegar",
    "cegarregas": "cegarrega",
    "cegará": "cegar",
    "cegarás": "cegar",
    "cegarão": "cegar",
    "cegaríamos": "cegar",
    "cegaríeis": "cegar",
    "cegas": "cego",
    "cegasse": "cegar",
    "cegassem": "cegar",
    "cegasses": "cegar",
    "cegaste": "cegar",
    "cegastes": "cegar",
    "cegava": "cegar",
    "cegavam": "cegar",
    "cegavas": "cegar",
    "cego": "cegar",
    "cegonhas": "cegonha",
    "cegonhos": "cegonho",
    "cegonhões": "cegonhão",
    "cegos": "cego",
    "cegou": "cegar",
    "cegudes": "cegude",
    "cegue": "cegar",
    "ceguei": "cegar",
    "cegueiras": "cegueira",
    "cegueis": "cegar",
    "ceguem": "cegar",
    "ceguemo": "cegar",
    "ceguemos": "cegar",
    "cegues": "cegar",
    "ceguetas": "cegueta",
    "ceguinha": "cego",
    "ceguinhas": "cego",
    "ceguinho": "cego",
    "ceguinhos": "cego",
    "ceguita": "cego",
    "ceguitas": "cego",
    "ceguito": "cego",
    "ceguitos": "cego",
    "ceguíssima": "cego",
    "ceguíssimas": "cego",
    "ceguíssimo": "cego",
    "ceguíssimos": "cego",
    "cegá": "cegar",
    "cegámo": "cegar",
    "cegámos": "cegar",
    "cegáramo": "cegar",
    "cegáramos": "cegar",
    "cegárei": "cegar",
    "cegáreis": "cegar",
    "cegásseis": "cegar",
    "cegássemos": "cegar",
    "cegávamo": "cegar",
    "cegávamos": "cegar",
    "cegávei": "cegar",
    "cegáveis": "cegável",
    "ceia": "cear",
    "ceiam": "cear",
    "ceias": "ceia",
    "ceiazinha": "ceia",
    "ceiazinhas": "ceia",
    "ceiazita": "ceia",
    "ceiazitas": "ceia",
    "ceie": "cear",
    "ceiem": "cear",
    "ceies": "cear",
    "ceifa": "ceifar",
    "ceifada": "ceifar",
    "ceifadas": "ceifar",
    "ceifado": "ceifar",
    "ceifados": "ceifar",
    "ceifai": "ceifar",
    "ceifais": "ceifar",
    "ceifam": "ceifar",
    "ceifamo": "ceifar",
    "ceifamos": "ceifar",
    "ceifando": "ceifar",
    "ceifara": "ceifar",
    "ceifaram": "ceifar",
    "ceifaras": "ceifar",
    "ceifarde": "ceifar",
    "ceifardes": "ceifar",
    "ceifare": "ceifar",
    "ceifarei": "ceifar",
    "ceifareis": "ceifar",
    "ceifarem": "ceifar",
    "ceifaremos": "ceifar",
    "ceifares": "ceifar",
    "ceifaria": "ceifar",
    "ceifariam": "ceifar",
    "ceifarias": "ceifar",
    "ceifarmo": "ceifar",
    "ceifarmos": "ceifar",
    "ceifará": "ceifar",
    "ceifarás": "ceifar",
    "ceifarão": "ceifar",
    "ceifaríamos": "ceifar",
    "ceifaríeis": "ceifar",
    "ceifas": "ceifar",
    "ceifasse": "ceifar",
    "ceifassem": "ceifar",
    "ceifasses": "ceifar",
    "ceifaste": "ceifar",
    "ceifastes": "ceifar",
    "ceifava": "ceifar",
    "ceifavam": "ceifar",
    "ceifavas": "ceifar",
    "ceife": "ceifar",
    "ceifei": "ceifar",
    "ceifeira": "ceifeiro",
    "ceifeiras": "ceifeiro",
    "ceifeiros": "ceifeiro",
    "ceifeis": "ceifar",
    "ceifem": "ceifar",
    "ceifemo": "ceifar",
    "ceifemos": "ceifar",
    "ceifes": "ceifar",
    "ceifo": "ceifar",
    "ceifou": "ceifar",
    "ceifá": "ceifar",
    "ceifámo": "ceifar",
    "ceifámos": "ceifar",
    "ceifáramo": "ceifar",
    "ceifáramos": "ceifar",
    "ceifárei": "ceifar",
    "ceifáreis": "ceifar",
    "ceifásseis": "ceifar",
    "ceifássemos": "ceifar",
    "ceifávamo": "ceifar",
    "ceifávamos": "ceifar",
    "ceifávei": "ceifar",
    "ceifáveis": "ceifar",
    "ceifões": "ceifão",
    "ceio": "cear",
    "ceiotes": "ceiote",
    "ceitas": "ceita",
    "ceitis": "ceitil",
    "ceiva": "ceivar",
    "ceivada": "ceivar",
    "ceivadas": "ceivar",
    "ceivado": "ceivar",
    "ceivados": "ceivar",
    "ceivai": "ceivar",
    "ceivais": "ceivar",
    "ceivam": "ceivar",
    "ceivamo": "ceivar",
    "ceivamos": "ceivar",
    "ceivando": "ceivar",
    "ceivara": "ceivar",
    "ceivaram": "ceivar",
    "ceivaras": "ceivar",
    "ceivarde": "ceivar",
    "ceivardes": "ceivar",
    "ceivare": "ceivar",
    "ceivarei": "ceivar",
    "ceivareis": "ceivar",
    "ceivarem": "ceivar",
    "ceivaremos": "ceivar",
    "ceivares": "ceivar",
    "ceivaria": "ceivar",
    "ceivariam": "ceivar",
    "ceivarias": "ceivar",
    "ceivarmo": "ceivar",
    "ceivarmos": "ceivar",
    "ceivará": "ceivar",
    "ceivarás": "ceivar",
    "ceivarão": "ceivar",
    "ceivaríamos": "ceivar",
    "ceivaríeis": "ceivar",
    "ceivas": "ceivar",
    "ceivasse": "ceivar",
    "ceivassem": "ceivar",
    "ceivasses": "ceivar",
    "ceivaste": "ceivar",
    "ceivastes": "ceivar",
    "ceivava": "ceivar",
    "ceivavam": "ceivar",
    "ceivavas": "ceivar",
    "ceive": "ceivar",
    "ceivei": "ceivar",
    "ceiveis": "ceivar",
    "ceivem": "ceivar",
    "ceivemo": "ceivar",
    "ceivemos": "ceivar",
    "ceives": "ceive",
    "ceivo": "ceivar",
    "ceivou": "ceivar",
    "ceivá": "ceivar",
    "ceivámo": "ceivar",
    "ceivámos": "ceivar",
    "ceiváramo": "ceivar",
    "ceiváramos": "ceivar",
    "ceivárei": "ceivar",
    "ceiváreis": "ceivar",
    "ceivásseis": "ceivar",
    "ceivássemos": "ceivar",
    "ceivávamo": "ceivar",
    "ceivávamos": "ceivar",
    "ceivávei": "ceivar",
    "ceiváveis": "ceivar",
    "celacantos": "celacanto",
    "celadas": "celada",
    "celagens": "celagem",
    "celamins": "celamim",
    "celas": "cela",
    "celastráceas": "celastrácea",
    "celazinha": "cela",
    "celazinhas": "cela",
    "celazita": "cela",
    "celazitas": "cela",
    "celações": "celação",
    "celebra": "celebrar",
    "celebrada": "celebrar",
    "celebradas": "celebrar",
    "celebrado": "celebrar",
    "celebradora": "celebrador",
    "celebradoras": "celebrador",
    "celebradores": "celebrador",
    "celebrados": "celebrar",
    "celebrai": "celebrar",
    "celebrais": "celebrar",
    "celebram": "celebrar",
    "celebramo": "celebrar",
    "celebramos": "celebrar",
    "celebrando": "celebrar",
    "celebrantes": "celebrante",
    "celebrara": "celebrar",
    "celebraram": "celebrar",
    "celebraras": "celebrar",
    "celebrarde": "celebrar",
    "celebrardes": "celebrar",
    "celebrare": "celebrar",
    "celebrarei": "celebrar",
    "celebrareis": "celebrar",
    "celebrarem": "celebrar",
    "celebraremos": "celebrar",
    "celebrares": "celebrar",
    "celebraria": "celebrar",
    "celebrariam": "celebrar",
    "celebrarias": "celebrar",
    "celebrarmo": "celebrar",
    "celebrarmos": "celebrar",
    "celebrará": "celebrar",
    "celebrarás": "celebrar",
    "celebrarão": "celebrar",
    "celebraríamos": "celebrar",
    "celebraríeis": "celebrar",
    "celebras": "celebrar",
    "celebrasse": "celebrar",
    "celebrassem": "celebrar",
    "celebrasses": "celebrar",
    "celebraste": "celebrar",
    "celebrastes": "celebrar",
    "celebratória": "celebratório",
    "celebratórias": "celebratório",
    "celebratórios": "celebratório",
    "celebrava": "celebrar",
    "celebravam": "celebrar",
    "celebravas": "celebrar",
    "celebrações": "celebração",
    "celebre": "celebrar",
    "celebrei": "celebrar",
    "celebreiras": "celebreira",
    "celebreis": "celebrar",
    "celebrem": "celebrar",
    "celebremo": "celebrar",
    "celebremos": "celebrar",
    "celebres": "celebrar",
    "celebrezinha": "célebre",
    "celebrezinhas": "célebre",
    "celebrezinho": "célebre",
    "celebrezinhos": "célebre",
    "celebrezita": "célebre",
    "celebrezitas": "célebre",
    "celebrezito": "célebre",
    "celebrezitos": "célebre",
    "celebridades": "celebridade",
    "celebriza": "celebrizar",
    "celebrizada": "celebrizar",
    "celebrizadas": "celebrizar",
    "celebrizado": "celebrizar",
    "celebrizados": "celebrizar",
    "celebrizai": "celebrizar",
    "celebrizais": "celebrizar",
    "celebrizam": "celebrizar",
    "celebrizamo": "celebrizar",
    "celebrizamos": "celebrizar",
    "celebrizando": "celebrizar",
    "celebrizara": "celebrizar",
    "celebrizaram": "celebrizar",
    "celebrizaras": "celebrizar",
    "celebrizarde": "celebrizar",
    "celebrizardes": "celebrizar",
    "celebrizare": "celebrizar",
    "celebrizarei": "celebrizar",
    "celebrizareis": "celebrizar",
    "celebrizarem": "celebrizar",
    "celebrizaremos": "celebrizar",
    "celebrizares": "celebrizar",
    "celebrizaria": "celebrizar",
    "celebrizariam": "celebrizar",
    "celebrizarias": "celebrizar",
    "celebrizarmo": "celebrizar",
    "celebrizarmos": "celebrizar",
    "celebrizará": "celebrizar",
    "celebrizarás": "celebrizar",
    "celebrizarão": "celebrizar",
    "celebrizaríamos": "celebrizar",
    "celebrizaríeis": "celebrizar",
    "celebrizas": "celebrizar",
    "celebrizasse": "celebrizar",
    "celebrizassem": "celebrizar",
    "celebrizasses": "celebrizar",
    "celebrizaste": "celebrizar",
    "celebrizastes": "celebrizar",
    "celebrizava": "celebrizar",
    "celebrizavam": "celebrizar",
    "celebrizavas": "celebrizar",
    "celebrizações": "celebrização",
    "celebrize": "celebrizar",
    "celebrizei": "celebrizar",
    "celebrizeis": "celebrizar",
    "celebrizem": "celebrizar",
    "celebrizemo": "celebrizar",
    "celebrizemos": "celebrizar",
    "celebrizes": "celebrizar",
    "celebrizo": "celebrizar",
    "celebrizou": "celebrizar",
    "celebrizá": "celebrizar",
    "celebrizámo": "celebrizar",
    "celebrizámos": "celebrizar",
    "celebrizáramo": "celebrizar",
    "celebrizáramos": "celebrizar",
    "celebrizárei": "celebrizar",
    "celebrizáreis": "celebrizar",
    "celebrizásseis": "celebrizar",
    "celebrizássemos": "celebrizar",
    "celebrizávamo": "celebrizar",
    "celebrizávamos": "celebrizar",
    "celebrizávei": "celebrizar",
    "celebrizáveis": "celebrizar",
    "celebro": "celebrar",
    "celebrou": "celebrar",
    "celebrá": "celebrar",
    "celebrámo": "celebrar",
    "celebrámos": "celebrar",
    "celebráramo": "celebrar",
    "celebráramos": "celebrar",
    "celebrárei": "celebrar",
    "celebráreis": "celebrar",
    "celebrásseis": "celebrar",
    "celebrássemos": "celebrar",
    "celebrávamo": "celebrar",
    "celebrávamos": "celebrar",
    "celebrávei": "celebrar",
    "celebráveis": "celebrável",
    "celebérrima": "célebre",
    "celebérrimas": "célebre",
    "celebérrimo": "célebre",
    "celebérrimos": "célebre",
    "celeireira": "celeireiro",
    "celeireiras": "celeireiro",
    "celeireiros": "celeireiro",
    "celeiros": "celeiro",
    "celenterados": "celenterado",
    "celentérios": "celentério",
    "celerada": "celerado",
    "celeradas": "celerado",
    "celerados": "celerado",
    "celeridades": "celeridade",
    "celerígrada": "celerígrado",
    "celerígradas": "celerígrado",
    "celerígrados": "celerígrado",
    "celerímetros": "celerímetro",
    "celerípedes": "celerípede",
    "celestes": "celeste",
    "celestiais": "celestial",
    "celestina": "celestino",
    "celestinas": "celestino",
    "celestinos": "celestino",
    "celeuma": "celeumar",
    "celeumada": "celeumar",
    "celeumadas": "celeumar",
    "celeumado": "celeumar",
    "celeumados": "celeumar",
    "celeumai": "celeumar",
    "celeumais": "celeumar",
    "celeumam": "celeumar",
    "celeumamo": "celeumar",
    "celeumamos": "celeumar",
    "celeumando": "celeumar",
    "celeumara": "celeumar",
    "celeumaram": "celeumar",
    "celeumaras": "celeumar",
    "celeumardes": "celeumar",
    "celeumarei": "celeumar",
    "celeumareis": "celeumar",
    "celeumarem": "celeumar",
    "celeumaremos": "celeumar",
    "celeumares": "celeumar",
    "celeumaria": "celeumar",
    "celeumariam": "celeumar",
    "celeumarias": "celeumar",
    "celeumarmo": "celeumar",
    "celeumarmos": "celeumar",
    "celeumará": "celeumar",
    "celeumarás": "celeumar",
    "celeumarão": "celeumar",
    "celeumaríamos": "celeumar",
    "celeumaríeis": "celeumar",
    "celeumas": "celeumar",
    "celeumasse": "celeumar",
    "celeumassem": "celeumar",
    "celeumasses": "celeumar",
    "celeumaste": "celeumar",
    "celeumastes": "celeumar",
    "celeumava": "celeumar",
    "celeumavam": "celeumar",
    "celeumavas": "celeumar",
    "celeume": "celeumar",
    "celeumeada": "celeumear",
    "celeumeadas": "celeumear",
    "celeumeado": "celeumear",
    "celeumeados": "celeumear",
    "celeumeai": "celeumear",
    "celeumeais": "celeumear",
    "celeumeamo": "celeumear",
    "celeumeamos": "celeumear",
    "celeumeando": "celeumear",
    "celeumeara": "celeumear",
    "celeumearam": "celeumear",
    "celeumearas": "celeumear",
    "celeumeardes": "celeumear",
    "celeumearei": "celeumear",
    "celeumeareis": "celeumear",
    "celeumearem": "celeumear",
    "celeumearemos": "celeumear",
    "celeumeares": "celeumear",
    "celeumearia": "celeumear",
    "celeumeariam": "celeumear",
    "celeumearias": "celeumear",
    "celeumearmo": "celeumear",
    "celeumearmos": "celeumear",
    "celeumeará": "celeumear",
    "celeumearás": "celeumear",
    "celeumearão": "celeumear",
    "celeumearíamos": "celeumear",
    "celeumearíeis": "celeumear",
    "celeumeasse": "celeumear",
    "celeumeassem": "celeumear",
    "celeumeasses": "celeumear",
    "celeumeaste": "celeumear",
    "celeumeastes": "celeumear",
    "celeumeava": "celeumear",
    "celeumeavam": "celeumear",
    "celeumeavas": "celeumear",
    "celeumeei": "celeumear",
    "celeumeeis": "celeumear",
    "celeumeemo": "celeumear",
    "celeumeemos": "celeumear",
    "celeumei": "celeumar",
    "celeumeia": "celeumear",
    "celeumeiam": "celeumear",
    "celeumeias": "celeumear",
    "celeumeie": "celeumear",
    "celeumeiem": "celeumear",
    "celeumeies": "celeumear",
    "celeumeio": "celeumear",
    "celeumeis": "celeumar",
    "celeumem": "celeumar",
    "celeumemo": "celeumar",
    "celeumemos": "celeumar",
    "celeumeou": "celeumear",
    "celeumes": "celeumar",
    "celeumeámo": "celeumear",
    "celeumeámos": "celeumear",
    "celeumeáramo": "celeumear",
    "celeumeáramos": "celeumear",
    "celeumeáreis": "celeumear",
    "celeumeásseis": "celeumear",
    "celeumeássemos": "celeumear",
    "celeumeávamo": "celeumear",
    "celeumeávamos": "celeumear",
    "celeumeáveis": "celeumear",
    "celeumo": "celeumar",
    "celeumou": "celeumar",
    "celeumámo": "celeumar",
    "celeumámos": "celeumar",
    "celeumáramo": "celeumar",
    "celeumáramos": "celeumar",
    "celeumáreis": "celeumar",
    "celeumásseis": "celeumar",
    "celeumássemos": "celeumar",
    "celeumávamo": "celeumar",
    "celeumávamos": "celeumar",
    "celeumáveis": "celeumar",
    "celgas": "celga",
    "celhada": "celhado",
    "celhadas": "celhado",
    "celhados": "celhado",
    "celhas": "celha",
    "celheada": "celheado",
    "celheadas": "celheado",
    "celheados": "celheado",
    "celiadelfos": "celiadelfo",
    "celialgias": "celialgia",
    "celibatarismos": "celibatarismo",
    "celibatos": "celibato",
    "celibatária": "celibatário",
    "celibatárias": "celibatário",
    "celibatários": "celibatário",
    "celideias": "celideia",
    "celidografias": "celidografia",
    "celidográfica": "celidográfico",
    "celidográficas": "celidográfico",
    "celidográficos": "celidográfico",
    "celidónias": "celidónia",
    "celifica": "celificar",
    "celificada": "celificar",
    "celificadas": "celificar",
    "celificado": "celificar",
    "celificados": "celificar",
    "celificai": "celificar",
    "celificais": "celificar",
    "celificam": "celificar",
    "celificamo": "celificar",
    "celificamos": "celificar",
    "celificando": "celificar",
    "celificara": "celificar",
    "celificaram": "celificar",
    "celificaras": "celificar",
    "celificarde": "celificar",
    "celificardes": "celificar",
    "celificare": "celificar",
    "celificarei": "celificar",
    "celificareis": "celificar",
    "celificarem": "celificar",
    "celificaremos": "celificar",
    "celificares": "celificar",
    "celificaria": "celificar",
    "celificariam": "celificar",
    "celificarias": "celificar",
    "celificarmo": "celificar",
    "celificarmos": "celificar",
    "celificará": "celificar",
    "celificarás": "celificar",
    "celificarão": "celificar",
    "celificaríamos": "celificar",
    "celificaríeis": "celificar",
    "celificas": "celificar",
    "celificasse": "celificar",
    "celificassem": "celificar",
    "celificasses": "celificar",
    "celificaste": "celificar",
    "celificastes": "celificar",
    "celificava": "celificar",
    "celificavam": "celificar",
    "celificavas": "celificar",
    "celifico": "celificar",
    "celificou": "celificar",
    "celificá": "celificar",
    "celificámo": "celificar",
    "celificámos": "celificar",
    "celificáramo": "celificar",
    "celificáramos": "celificar",
    "celificárei": "celificar",
    "celificáreis": "celificar",
    "celificásseis": "celificar",
    "celificássemos": "celificar",
    "celificávamo": "celificar",
    "celificávamos": "celificar",
    "celificávei": "celificar",
    "celificáveis": "celificar",
    "celifique": "celificar",
    "celifiquei": "celificar",
    "celifiqueis": "celificar",
    "celifiquem": "celificar",
    "celifiquemo": "celificar",
    "celifiquemos": "celificar",
    "celifiques": "celificar",
    "celiotomias": "celiotomia",
    "celiotómica": "celiotómico",
    "celiotómicas": "celiotómico",
    "celiotómicos": "celiotómico",
    "celipotentes": "celipotente",
    "celiálgica": "celiálgico",
    "celiálgicas": "celiálgico",
    "celiálgicos": "celiálgico",
    "celofanes": "celofane",
    "celomada": "celomado",
    "celomadas": "celomado",
    "celomados": "celomado",
    "celomas": "celoma",
    "celoricenses": "celoricense",
    "celoricos": "celorico",
    "celsa": "celso",
    "celsas": "celso",
    "celsitudes": "celsitude",
    "celsos": "celso",
    "celtas": "celta",
    "celtibera": "celtibero",
    "celtiberas": "celtibero",
    "celtiberos": "celtibero",
    "celtidáceas": "celtidácea",
    "celtismos": "celtismo",
    "celulada": "celulado",
    "celuladas": "celulado",
    "celulados": "celulado",
    "celulares": "celular",
    "celulazinha": "célula",
    "celulazinhas": "célula",
    "celulazita": "célula",
    "celulazitas": "célula",
    "celuliformes": "celuliforme",
    "celulites": "celulite",
    "celulosa": "celuloso",
    "celulosas": "celuloso",
    "celuloses": "celulose",
    "celulosidades": "celulosidade",
    "celulosos": "celuloso",
    "celulífera": "celulífero",
    "celulíferas": "celulífero",
    "celulíferos": "celulífero",
    "celulífuga": "celulífugo",
    "celulífugas": "celulífugo",
    "celulífugos": "celulífugo",
    "celulípeta": "celulípeto",
    "celulípetas": "celulípeto",
    "celulípetos": "celulípeto",
    "celulóides": "celulóide",
    "celulósica": "celulósico",
    "celulósicas": "celulósico",
    "celulósicos": "celulósico",
    "celulótica": "celulótico",
    "celulóticas": "celulótico",
    "celulóticos": "celulótico",
    "celurossauros": "celurossauro",
    "celurossáurios": "celurossáurio",
    "celários": "celário",
    "celênteros": "celêntero",
    "celíaca": "celíaco",
    "celíacas": "celíaco",
    "celíacos": "celíaco",
    "celícolas": "celícola",
    "celífera": "celífero",
    "celíferas": "celífero",
    "celíferos": "celífero",
    "celíflua": "celífluo",
    "celífluas": "celífluo",
    "celífluos": "celífluo",
    "celígenas": "celígena",
    "celígera": "celígero",
    "celígeras": "celígero",
    "celígeros": "celígero",
    "celômatas": "celômata",
    "cementa": "cementar",
    "cementada": "cementar",
    "cementadas": "cementar",
    "cementado": "cementar",
    "cementadora": "cementador",
    "cementadoras": "cementador",
    "cementadores": "cementador",
    "cementados": "cementar",
    "cementai": "cementar",
    "cementais": "cementar",
    "cementam": "cementar",
    "cementamo": "cementar",
    "cementamos": "cementar",
    "cementando": "cementar",
    "cementara": "cementar",
    "cementaram": "cementar",
    "cementaras": "cementar",
    "cementarde": "cementar",
    "cementardes": "cementar",
    "cementare": "cementar",
    "cementarei": "cementar",
    "cementareis": "cementar",
    "cementarem": "cementar",
    "cementaremos": "cementar",
    "cementares": "cementar",
    "cementaria": "cementar",
    "cementariam": "cementar",
    "cementarias": "cementar",
    "cementarmo": "cementar",
    "cementarmos": "cementar",
    "cementará": "cementar",
    "cementarás": "cementar",
    "cementarão": "cementar",
    "cementaríamos": "cementar",
    "cementaríeis": "cementar",
    "cementas": "cementar",
    "cementasse": "cementar",
    "cementassem": "cementar",
    "cementasses": "cementar",
    "cementaste": "cementar",
    "cementastes": "cementar",
    "cementava": "cementar",
    "cementavam": "cementar",
    "cementavas": "cementar",
    "cementações": "cementação",
    "cemente": "cementar",
    "cementei": "cementar",
    "cementeis": "cementar",
    "cementem": "cementar",
    "cementemo": "cementar",
    "cementemos": "cementar",
    "cementes": "cementar",
    "cementites": "cementite",
    "cemento": "cementar",
    "cementos": "cemento",
    "cementou": "cementar",
    "cementá": "cementar",
    "cementámo": "cementar",
    "cementámos": "cementar",
    "cementáramo": "cementar",
    "cementáramos": "cementar",
    "cementárei": "cementar",
    "cementáreis": "cementar",
    "cementásseis": "cementar",
    "cementássemos": "cementar",
    "cementávamo": "cementar",
    "cementávamos": "cementar",
    "cementávei": "cementar",
    "cementáveis": "cementar",
    "cemiteriais": "cemiterial",
    "cemitérios": "cemitério",
    "cenagais": "cenagal",
    "cenagosa": "cenagoso",
    "cenagosas": "cenagoso",
    "cenagosos": "cenagoso",
    "cenas": "cena",
    "cenatória": "cenatório",
    "cenatórias": "cenatório",
    "cenatórios": "cenatório",
    "cenazinha": "cena",
    "cenazinhas": "cena",
    "cenazita": "cena",
    "cenazitas": "cena",
    "cendais": "cendal",
    "cendra": "cendrar",
    "cendrada": "cendrar",
    "cendradas": "cendrar",
    "cendrado": "cendrar",
    "cendrados": "cendrar",
    "cendrai": "cendrar",
    "cendrais": "cendrar",
    "cendram": "cendrar",
    "cendramo": "cendrar",
    "cendramos": "cendrar",
    "cendrando": "cendrar",
    "cendrara": "cendrar",
    "cendraram": "cendrar",
    "cendraras": "cendrar",
    "cendrarde": "cendrar",
    "cendrardes": "cendrar",
    "cendrare": "cendrar",
    "cendrarei": "cendrar",
    "cendrareis": "cendrar",
    "cendrarem": "cendrar",
    "cendraremos": "cendrar",
    "cendrares": "cendrar",
    "cendraria": "cendrar",
    "cendrariam": "cendrar",
    "cendrarias": "cendrar",
    "cendrarmo": "cendrar",
    "cendrarmos": "cendrar",
    "cendrará": "cendrar",
    "cendrarás": "cendrar",
    "cendrarão": "cendrar",
    "cendraríamos": "cendrar",
    "cendraríeis": "cendrar",
    "cendras": "cendrar",
    "cendrasse": "cendrar",
    "cendrassem": "cendrar",
    "cendrasses": "cendrar",
    "cendraste": "cendrar",
    "cendrastes": "cendrar",
    "cendrava": "cendrar",
    "cendravam": "cendrar",
    "cendravas": "cendrar",
    "cendre": "cendrar",
    "cendrei": "cendrar",
    "cendreis": "cendrar",
    "cendrem": "cendrar",
    "cendremo": "cendrar",
    "cendremos": "cendrar",
    "cendres": "cendrar",
    "cendro": "cendrar",
    "cendrou": "cendrar",
    "cendrá": "cendrar",
    "cendrámo": "cendrar",
    "cendrámos": "cendrar",
    "cendráramo": "cendrar",
    "cendráramos": "cendrar",
    "cendrárei": "cendrar",
    "cendráreis": "cendrar",
    "cendrásseis": "cendrar",
    "cendrássemos": "cendrar",
    "cendrávamo": "cendrar",
    "cendrávamos": "cendrar",
    "cendrávei": "cendrar",
    "cendráveis": "cendrar",
    "cenestesias": "cenestesia",
    "cenestesiopatas": "cenestesiopata",
    "cenestesiopatias": "cenestesiopatia",
    "cenestopatas": "cenestopata",
    "cenestopatias": "cenestopatia",
    "cenestopática": "cenestopático",
    "cenestopáticas": "cenestopático",
    "cenestopáticos": "cenestopático",
    "cenestésica": "cenestésico",
    "cenestésicas": "cenestésico",
    "cenestésicos": "cenestésico",
    "cenhos": "cenho",
    "cenhosa": "cenhoso",
    "cenhosas": "cenhoso",
    "cenhosos": "cenhoso",
    "cenismos": "cenismo",
    "cenobiarcas": "cenobiarca",
    "cenobioses": "cenobiose",
    "cenobismos": "cenobismo",
    "cenobitas": "cenobita",
    "cenobitismos": "cenobitismo",
    "cenobítica": "cenobítico",
    "cenobíticas": "cenobítico",
    "cenobíticos": "cenobítico",
    "cenofobias": "cenofobia",
    "cenofóbica": "cenofóbico",
    "cenofóbicas": "cenofóbico",
    "cenofóbicos": "cenofóbico",
    "cenografias": "cenografia",
    "cenográfica": "cenográfico",
    "cenográficas": "cenográfico",
    "cenográficos": "cenográfico",
    "cenoiras": "cenoira",
    "cenologias": "cenologia",
    "cenológica": "cenológico",
    "cenológicas": "cenológico",
    "cenológicos": "cenológico",
    "cenomaniana": "cenomaniano",
    "cenomanianas": "cenomaniano",
    "cenomanianos": "cenomaniano",
    "cenopégias": "cenopégia",
    "cenopégica": "cenopégico",
    "cenopégicas": "cenopégico",
    "cenopégicos": "cenopégico",
    "cenos": "ceno",
    "cenosa": "cenoso",
    "cenosas": "cenoso",
    "cenosidades": "cenosidade",
    "cenosos": "cenoso",
    "cenossarcos": "cenossarco",
    "cenotáfios": "cenotáfio",
    "cenouras": "cenoura",
    "cenourinha": "cenoura",
    "cenourinhas": "cenoura",
    "cenourita": "cenoura",
    "cenouritas": "cenoura",
    "cenozóica": "cenozóico",
    "cenozóicas": "cenozóico",
    "cenozóicos": "cenozóico",
    "cenradas": "cenrada",
    "cenras": "cenra",
    "cenreiras": "cenreira",
    "censatária": "censatário",
    "censatárias": "censatário",
    "censatários": "censatário",
    "censionária": "censionário",
    "censionárias": "censionário",
    "censionários": "censionário",
    "censitária": "censitário",
    "censitárias": "censitário",
    "censitários": "censitário",
    "censora": "censor",
    "censoras": "censor",
    "censores": "censor",
    "censos": "censo",
    "censuais": "censual",
    "censualistas": "censualista",
    "censura": "censurar",
    "censurada": "censurar",
    "censuradas": "censurar",
    "censurado": "censurar",
    "censuradora": "censurador",
    "censuradoras": "censurador",
    "censuradores": "censurador",
    "censurados": "censurar",
    "censurai": "censurar",
    "censurais": "censurar",
    "censuram": "censurar",
    "censuramo": "censurar",
    "censuramos": "censurar",
    "censurando": "censurar",
    "censurara": "censurar",
    "censuraram": "censurar",
    "censuraras": "censurar",
    "censurarde": "censurar",
    "censurardes": "censurar",
    "censurare": "censurar",
    "censurarei": "censurar",
    "censurareis": "censurar",
    "censurarem": "censurar",
    "censuraremos": "censurar",
    "censurares": "censurar",
    "censuraria": "censurar",
    "censurariam": "censurar",
    "censurarias": "censurar",
    "censurarmo": "censurar",
    "censurarmos": "censurar",
    "censurará": "censurar",
    "censurarás": "censurar",
    "censurarão": "censurar",
    "censuraríamos": "censurar",
    "censuraríeis": "censurar",
    "censuras": "censurar",
    "censurasse": "censurar",
    "censurassem": "censurar",
    "censurasses": "censurar",
    "censuraste": "censurar",
    "censurastes": "censurar",
    "censurava": "censurar",
    "censuravam": "censurar",
    "censuravas": "censurar",
    "censure": "censurar",
    "censurei": "censurar",
    "censureis": "censurar",
    "censurem": "censurar",
    "censuremo": "censurar",
    "censuremos": "censurar",
    "censures": "censurar",
    "censuro": "censurar",
    "censurou": "censurar",
    "censurá": "censurar",
    "censurámo": "censurar",
    "censurámos": "censurar",
    "censuráramo": "censurar",
    "censuráramos": "censurar",
    "censurárei": "censurar",
    "censuráreis": "censurar",
    "censurásseis": "censurar",
    "censurássemos": "censurar",
    "censurávamo": "censurar",
    "censurávamos": "censurar",
    "censurávei": "censurar",
    "censuráveis": "censurável",
    "censuária": "censuário",
    "censuárias": "censuário",
    "censuários": "censuário",
    "censuístas": "censuísta",
    "censítica": "censítico",
    "censíticas": "censítico",
    "censíticos": "censítico",
    "censória": "censório",
    "censórias": "censório",
    "censórios": "censório",
    "centafolhos": "centafolho",
    "centauros": "centauro",
    "centavos": "centavo",
    "centeais": "centeal",
    "centeeira": "centeeiro",
    "centeeiras": "centeeiro",
    "centeeiros": "centeeiro",
    "centeia": "centeio",
    "centeias": "centeio",
    "centeios": "centeio",
    "centelha": "centelhar",
    "centelhada": "centelhar",
    "centelhadas": "centelhar",
    "centelhado": "centelhar",
    "centelhados": "centelhar",
    "centelhai": "centelhar",
    "centelhais": "centelhar",
    "centelham": "centelhar",
    "centelhamo": "centelhar",
    "centelhamos": "centelhar",
    "centelhando": "centelhar",
    "centelhantes": "centelhante",
    "centelhara": "centelhar",
    "centelharam": "centelhar",
    "centelharas": "centelhar",
    "centelhardes": "centelhar",
    "centelharei": "centelhar",
    "centelhareis": "centelhar",
    "centelharem": "centelhar",
    "centelharemos": "centelhar",
    "centelhares": "centelhar",
    "centelharia": "centelhar",
    "centelhariam": "centelhar",
    "centelharias": "centelhar",
    "centelharmo": "centelhar",
    "centelharmos": "centelhar",
    "centelhará": "centelhar",
    "centelharás": "centelhar",
    "centelharão": "centelhar",
    "centelharíamos": "centelhar",
    "centelharíeis": "centelhar",
    "centelhas": "centelhar",
    "centelhasse": "centelhar",
    "centelhassem": "centelhar",
    "centelhasses": "centelhar",
    "centelhaste": "centelhar",
    "centelhastes": "centelhar",
    "centelhava": "centelhar",
    "centelhavam": "centelhar",
    "centelhavas": "centelhar",
    "centelhazinha": "centelha",
    "centelhazinhas": "centelha",
    "centelhazita": "centelha",
    "centelhazitas": "centelha",
    "centelhe": "centelhar",
    "centelhei": "centelhar",
    "centelheis": "centelhar",
    "centelhem": "centelhar",
    "centelhemo": "centelhar",
    "centelhemos": "centelhar",
    "centelhes": "centelhar",
    "centelho": "centelhar",
    "centelhou": "centelhar",
    "centelhámo": "centelhar",
    "centelhámos": "centelhar",
    "centelháramo": "centelhar",
    "centelháramos": "centelhar",
    "centelháreis": "centelhar",
    "centelhásseis": "centelhar",
    "centelhássemos": "centelhar",
    "centelhávamo": "centelhar",
    "centelhávamos": "centelhar",
    "centelháveis": "centelhar",
    "centenares": "centenar",
    "centenas": "centena",
    "centeninhos": "centeninho",
    "centenosa": "centenoso",
    "centenosas": "centenoso",
    "centenosos": "centenoso",
    "centenária": "centenário",
    "centenárias": "centenário",
    "centenários": "centenário",
    "centesimais": "centesimal",
    "centiares": "centiare",
    "centibares": "centibar",
    "centiculares": "centicular",
    "centifólia": "centifólio",
    "centifólias": "centifólio",
    "centifólios": "centifólio",
    "centigramas": "centigrama",
    "centilitros": "centilitro",
    "centineta": "centineto",
    "centinetas": "centineto",
    "centinetos": "centineto",
    "centinormais": "centinormal",
    "centis": "centil",
    "centisseculares": "centissecular",
    "centolas": "centola",
    "centopeias": "centopeia",
    "centopéias": "centopéia",
    "centos": "cento",
    "centra": "centrar",
    "centrada": "centrar",
    "centradas": "centrar",
    "centrado": "centrar",
    "centrados": "centrar",
    "centragens": "centragem",
    "centrai": "centrar",
    "centrais": "centrar",
    "centraizinhas": "central",
    "centraizinhos": "central",
    "centraizitas": "central",
    "centraizitos": "central",
    "centralidades": "centralidade",
    "centralismos": "centralismo",
    "centralistas": "centralista",
    "centraliza": "centralizar",
    "centralizada": "centralizar",
    "centralizadas": "centralizar",
    "centralizado": "centralizar",
    "centralizadora": "centralizador",
    "centralizadoras": "centralizador",
    "centralizadores": "centralizador",
    "centralizados": "centralizar",
    "centralizai": "centralizar",
    "centralizais": "centralizar",
    "centralizam": "centralizar",
    "centralizamo": "centralizar",
    "centralizamos": "centralizar",
    "centralizando": "centralizar",
    "centralizara": "centralizar",
    "centralizaram": "centralizar",
    "centralizaras": "centralizar",
    "centralizarde": "centralizar",
    "centralizardes": "centralizar",
    "centralizare": "centralizar",
    "centralizarei": "centralizar",
    "centralizareis": "centralizar",
    "centralizarem": "centralizar",
    "centralizaremos": "centralizar",
    "centralizares": "centralizar",
    "centralizaria": "centralizar",
    "centralizariam": "centralizar",
    "centralizarias": "centralizar",
    "centralizarmo": "centralizar",
    "centralizarmos": "centralizar",
    "centralizará": "centralizar",
    "centralizarás": "centralizar",
    "centralizarão": "centralizar",
    "centralizaríamos": "centralizar",
    "centralizaríeis": "centralizar",
    "centralizas": "centralizar",
    "centralizasse": "centralizar",
    "centralizassem": "centralizar",
    "centralizasses": "centralizar",
    "centralizaste": "centralizar",
    "centralizastes": "centralizar",
    "centralizava": "centralizar",
    "centralizavam": "centralizar",
    "centralizavas": "centralizar",
    "centralizações": "centralização",
    "centralize": "centralizar",
    "centralizei": "centralizar",
    "centralizeis": "centralizar",
    "centralizem": "centralizar",
    "centralizemo": "centralizar",
    "centralizemos": "centralizar",
    "centralizes": "centralizar",
    "centralizo": "centralizar",
    "centralizou": "centralizar",
    "centralizá": "centralizar",
    "centralizámo": "centralizar",
    "centralizámos": "centralizar",
    "centralizáramo": "centralizar",
    "centralizáramos": "centralizar",
    "centralizárei": "centralizar",
    "centralizáreis": "centralizar",
    "centralizásseis": "centralizar",
    "centralizássemos": "centralizar",
    "centralizávamo": "centralizar",
    "centralizávamos": "centralizar",
    "centralizávei": "centralizar",
    "centralizáveis": "centralizar",
    "centralzinha": "central",
    "centralzinho": "central",
    "centralzita": "central",
    "centralzito": "central",
    "centralíssima": "central",
    "centralíssimas": "central",
    "centralíssimo": "central",
    "centralíssimos": "central",
    "centram": "centrar",
    "centramo": "centrar",
    "centramos": "centrar",
    "centrando": "centrar",
    "centrara": "centrar",
    "centraram": "centrar",
    "centraras": "centrar",
    "centrarde": "centrar",
    "centrardes": "centrar",
    "centrare": "centrar",
    "centrarei": "centrar",
    "centrareis": "centrar",
    "centrarem": "centrar",
    "centraremos": "centrar",
    "centrares": "centrar",
    "centraria": "centrar",
    "centrariam": "centrar",
    "centrarias": "centrar",
    "centrarmo": "centrar",
    "centrarmos": "centrar",
    "centrará": "centrar",
    "centrarás": "centrar",
    "centrarão": "centrar",
    "centraríamos": "centrar",
    "centraríeis": "centrar",
    "centras": "centrar",
    "centrasse": "centrar",
    "centrassem": "centrar",
    "centrasses": "centrar",
    "centraste": "centrar",
    "centrastes": "centrar",
    "centrava": "centrar",
    "centravam": "centrar",
    "centravas": "centrar",
    "centre": "centrar",
    "centrei": "centrar",
    "centreis": "centrar",
    "centrem": "centrar",
    "centremo": "centrar",
    "centremos": "centrar",
    "centres": "centrar",
    "centrifuga": "centrifugar",
    "centrifugada": "centrifugar",
    "centrifugadas": "centrifugar",
    "centrifugado": "centrifugar",
    "centrifugadora": "centrifugador",
    "centrifugadoras": "centrifugadora",
    "centrifugadores": "centrifugador",
    "centrifugados": "centrifugar",
    "centrifugai": "centrifugar",
    "centrifugais": "centrifugar",
    "centrifugam": "centrifugar",
    "centrifugamo": "centrifugar",
    "centrifugamos": "centrifugar",
    "centrifugando": "centrifugar",
    "centrifugara": "centrifugar",
    "centrifugaram": "centrifugar",
    "centrifugaras": "centrifugar",
    "centrifugarde": "centrifugar",
    "centrifugardes": "centrifugar",
    "centrifugare": "centrifugar",
    "centrifugarei": "centrifugar",
    "centrifugareis": "centrifugar",
    "centrifugarem": "centrifugar",
    "centrifugaremos": "centrifugar",
    "centrifugares": "centrifugar",
    "centrifugaria": "centrifugar",
    "centrifugariam": "centrifugar",
    "centrifugarias": "centrifugar",
    "centrifugarmo": "centrifugar",
    "centrifugarmos": "centrifugar",
    "centrifugará": "centrifugar",
    "centrifugarás": "centrifugar",
    "centrifugarão": "centrifugar",
    "centrifugaríamos": "centrifugar",
    "centrifugaríeis": "centrifugar",
    "centrifugas": "centrifugar",
    "centrifugasse": "centrifugar",
    "centrifugassem": "centrifugar",
    "centrifugasses": "centrifugar",
    "centrifugaste": "centrifugar",
    "centrifugastes": "centrifugar",
    "centrifugava": "centrifugar",
    "centrifugavam": "centrifugar",
    "centrifugavas": "centrifugar",
    "centrifugações": "centrifugação",
    "centrifugo": "centrifugar",
    "centrifugou": "centrifugar",
    "centrifugue": "centrifugar",
    "centrifuguei": "centrifugar",
    "centrifugueis": "centrifugar",
    "centrifuguem": "centrifugar",
    "centrifuguemo": "centrifugar",
    "centrifuguemos": "centrifugar",
    "centrifugues": "centrifugar",
    "centrifugá": "centrifugar",
    "centrifugámo": "centrifugar",
    "centrifugámos": "centrifugar",
    "centrifugáramo": "centrifugar",
    "centrifugáramos": "centrifugar",
    "centrifugárei": "centrifugar",
    "centrifugáreis": "centrifugar",
    "centrifugásseis": "centrifugar",
    "centrifugássemos": "centrifugar",
    "centrifugávamo": "centrifugar",
    "centrifugávamos": "centrifugar",
    "centrifugávei": "centrifugar",
    "centrifugáveis": "centrifugar",
    "centrinho": "centro",
    "centrinhos": "centro",
    "centrismos": "centrismo",
    "centristas": "centrista",
    "centrito": "centro",
    "centritos": "centro",
    "centro": "centrar",
    "centrolécita": "centrolécito",
    "centrolécitas": "centrolécito",
    "centrolécitos": "centrolécito",
    "centromérica": "centromérico",
    "centroméricas": "centromérico",
    "centroméricos": "centromérico",
    "centros": "centro",
    "centrosferas": "centrosfera",
    "centrossomas": "centrossoma",
    "centrou": "centrar",
    "centrozinho": "centro",
    "centrozinhos": "centro",
    "centrozito": "centro",
    "centrozitos": "centro",
    "centrá": "centrar",
    "centrámo": "centrar",
    "centrámos": "centrar",
    "centráramo": "centrar",
    "centráramos": "centrar",
    "centrárei": "centrar",
    "centráreis": "centrar",
    "centrásseis": "centrar",
    "centrássemos": "centrar",
    "centrávamo": "centrar",
    "centrávamos": "centrar",
    "centrávei": "centrar",
    "centráveis": "centrar",
    "centrífuga": "centrífugo",
    "centrífugas": "centrífugo",
    "centrífugos": "centrífugo",
    "centríolos": "centríolo",
    "centrípeta": "centrípeto",
    "centrípetas": "centrípeto",
    "centrípetos": "centrípeto",
    "centrómeros": "centrómero",
    "centunvirados": "centunvirado",
    "centunvirais": "centunviral",
    "centunviratos": "centunvirato",
    "centuplica": "centuplicar",
    "centuplicada": "centuplicar",
    "centuplicadas": "centuplicar",
    "centuplicado": "centuplicar",
    "centuplicados": "centuplicar",
    "centuplicais": "centuplicar",
    "centuplicam": "centuplicar",
    "centuplicamo": "centuplicar",
    "centuplicamos": "centuplicar",
    "centuplicando": "centuplicar",
    "centuplicara": "centuplicar",
    "centuplicaram": "centuplicar",
    "centuplicaras": "centuplicar",
    "centuplicardes": "centuplicar",
    "centuplicarei": "centuplicar",
    "centuplicareis": "centuplicar",
    "centuplicarem": "centuplicar",
    "centuplicaremos": "centuplicar",
    "centuplicares": "centuplicar",
    "centuplicaria": "centuplicar",
    "centuplicariam": "centuplicar",
    "centuplicarias": "centuplicar",
    "centuplicarmo": "centuplicar",
    "centuplicarmos": "centuplicar",
    "centuplicará": "centuplicar",
    "centuplicarás": "centuplicar",
    "centuplicarão": "centuplicar",
    "centuplicaríamos": "centuplicar",
    "centuplicaríeis": "centuplicar",
    "centuplicas": "centuplicar",
    "centuplicasse": "centuplicar",
    "centuplicassem": "centuplicar",
    "centuplicasses": "centuplicar",
    "centuplicaste": "centuplicar",
    "centuplicastes": "centuplicar",
    "centuplicava": "centuplicar",
    "centuplicavam": "centuplicar",
    "centuplicavas": "centuplicar",
    "centuplico": "centuplicar",
    "centuplicou": "centuplicar",
    "centuplicámo": "centuplicar",
    "centuplicámos": "centuplicar",
    "centuplicáramo": "centuplicar",
    "centuplicáramos": "centuplicar",
    "centuplicáreis": "centuplicar",
    "centuplicásseis": "centuplicar",
    "centuplicássemos": "centuplicar",
    "centuplicávamo": "centuplicar",
    "centuplicávamos": "centuplicar",
    "centuplicáveis": "centuplicar",
    "centuplique": "centuplicar",
    "centupliquei": "centuplicar",
    "centupliqueis": "centuplicar",
    "centupliquem": "centuplicar",
    "centupliquemos": "centuplicar",
    "centupliques": "centuplicar",
    "centuriados": "centuriado",
    "centuriais": "centurial",
    "centuriatos": "centuriato",
    "centurionatos": "centurionato",
    "centuriónica": "centuriónico",
    "centuriónicas": "centuriónico",
    "centuriónicos": "centuriónico",
    "centuriões": "centurião",
    "centáurea": "centáureo",
    "centáureas": "centáureo",
    "centáureos": "centáureo",
    "centáurica": "centáurico",
    "centáuricas": "centáurico",
    "centáuricos": "centáurico",
    "centénios": "centénio",
    "centésima": "centésimo",
    "centésimas": "centésimo",
    "centésimos": "centésimo",
    "centígrada": "centígrado",
    "centígradas": "centígrado",
    "centígrados": "centígrado",
    "centímana": "centímano",
    "centímanas": "centímano",
    "centímanos": "centímano",
    "centímetros": "centímetro",
    "centípedas": "centípeda",
    "centípedes": "centípede",
    "centócula": "centóculo",
    "centóculas": "centóculo",
    "centóculos": "centóculo",
    "centões": "centão",
    "centúnviros": "centúnviro",
    "centúrias": "centúria",
    "centúrios": "centúrio",
    "cenáculos": "cenáculo",
    "cenária": "cenário",
    "cenárias": "cenário",
    "cenários": "cenário",
    "cenóbios": "cenóbio",
    "cenófoba": "cenófobo",
    "cenófobas": "cenófobo",
    "cenófobos": "cenófobo",
    "cenógrafa": "cenógrafo",
    "cenógrafas": "cenógrafo",
    "cenógrafos": "cenógrafo",
    "cenóloga": "cenólogo",
    "cenólogas": "cenólogo",
    "cenólogos": "cenólogo",
    "ceotes": "ceote",
    "ceou": "cear",
    "cepas": "cepa",
    "cepeiras": "cepeira",
    "cepilha": "cepilhar",
    "cepilhada": "cepilhar",
    "cepilhadas": "cepilhar",
    "cepilhado": "cepilhar",
    "cepilhados": "cepilhar",
    "cepilhai": "cepilhar",
    "cepilhais": "cepilhar",
    "cepilham": "cepilhar",
    "cepilhamo": "cepilhar",
    "cepilhamos": "cepilhar",
    "cepilhando": "cepilhar",
    "cepilhara": "cepilhar",
    "cepilharam": "cepilhar",
    "cepilharas": "cepilhar",
    "cepilharde": "cepilhar",
    "cepilhardes": "cepilhar",
    "cepilhare": "cepilhar",
    "cepilharei": "cepilhar",
    "cepilhareis": "cepilhar",
    "cepilharem": "cepilhar",
    "cepilharemos": "cepilhar",
    "cepilhares": "cepilhar",
    "cepilharia": "cepilhar",
    "cepilhariam": "cepilhar",
    "cepilharias": "cepilhar",
    "cepilharmo": "cepilhar",
    "cepilharmos": "cepilhar",
    "cepilhará": "cepilhar",
    "cepilharás": "cepilhar",
    "cepilharão": "cepilhar",
    "cepilharíamos": "cepilhar",
    "cepilharíeis": "cepilhar",
    "cepilhas": "cepilhar",
    "cepilhasse": "cepilhar",
    "cepilhassem": "cepilhar",
    "cepilhasses": "cepilhar",
    "cepilhaste": "cepilhar",
    "cepilhastes": "cepilhar",
    "cepilhava": "cepilhar",
    "cepilhavam": "cepilhar",
    "cepilhavas": "cepilhar",
    "cepilhe": "cepilhar",
    "cepilhei": "cepilhar",
    "cepilheis": "cepilhar",
    "cepilhem": "cepilhar",
    "cepilhemo": "cepilhar",
    "cepilhemos": "cepilhar",
    "cepilhes": "cepilhar",
    "cepilho": "cepilhar",
    "cepilhos": "cepilho",
    "cepilhou": "cepilhar",
    "cepilhá": "cepilhar",
    "cepilhámo": "cepilhar",
    "cepilhámos": "cepilhar",
    "cepilháramo": "cepilhar",
    "cepilháramos": "cepilhar",
    "cepilhárei": "cepilhar",
    "cepilháreis": "cepilhar",
    "cepilhásseis": "cepilhar",
    "cepilhássemos": "cepilhar",
    "cepilhávamo": "cepilhar",
    "cepilhávamos": "cepilhar",
    "cepilhávei": "cepilhar",
    "cepilháveis": "cepilhar",
    "cepos": "cepo",
    "cepticismos": "cepticismo",
    "ceptros": "ceptro",
    "ceptrífera": "ceptrífero",
    "ceptríferas": "ceptrífero",
    "ceptríferos": "ceptrífero",
    "ceptrígera": "ceptrígero",
    "ceptrígeras": "ceptrígero",
    "ceptrígeros": "ceptrígero",
    "cepuda": "cepudo",
    "cepudas": "cepudo",
    "cepudos": "cepudo",
    "cepácea": "cepáceo",
    "cepáceas": "cepáceo",
    "cepáceos": "cepáceo",
    "cera": "cerar",
    "cerada": "cerar",
    "ceradas": "cerar",
    "cerado": "cerar",
    "cerados": "cerar",
    "cerai": "cerar",
    "cerais": "cerar",
    "ceram": "cerar",
    "cerambicidas": "cerambicida",
    "cerambicídea": "cerambicídeo",
    "cerambicídeas": "cerambicídeo",
    "cerambicídeos": "cerambicídeo",
    "cerames": "cerame",
    "ceramistas": "ceramista",
    "ceramo": "cerar",
    "ceramografias": "ceramografia",
    "ceramográfica": "ceramográfico",
    "ceramográficas": "ceramográfico",
    "ceramográficos": "ceramográfico",
    "ceramos": "cerar",
    "ceramógrafa": "ceramógrafo",
    "ceramógrafas": "ceramógrafo",
    "ceramógrafos": "ceramógrafo",
    "cerando": "cerar",
    "cerara": "cerar",
    "ceraram": "cerar",
    "ceraras": "cerar",
    "cerarde": "cerar",
    "cerardes": "cerar",
    "cerare": "cerar",
    "cerarei": "cerar",
    "cerareis": "cerar",
    "cerarem": "cerar",
    "ceraremos": "cerar",
    "cerares": "cerar",
    "ceraria": "cerar",
    "cerariam": "cerar",
    "cerarias": "cerar",
    "cerarmo": "cerar",
    "cerarmos": "cerar",
    "cerará": "cerar",
    "cerarás": "cerar",
    "cerarão": "cerar",
    "ceraríamos": "cerar",
    "ceraríeis": "cerar",
    "ceras": "cerar",
    "cerasinas": "cerasina",
    "cerasse": "cerar",
    "cerassem": "cerar",
    "cerasses": "cerar",
    "cerastas": "cerasta",
    "ceraste": "cerar",
    "cerastes": "cerar",
    "ceratinas": "ceratina",
    "ceratites": "ceratite",
    "ceratitídea": "ceratitídeo",
    "ceratitídeas": "ceratitídeo",
    "ceratitídeos": "ceratitídeo",
    "ceratométrica": "ceratométrico",
    "ceratométricas": "ceratométrico",
    "ceratométricos": "ceratométrico",
    "ceratopsídea": "ceratopsídeo",
    "ceratopsídeas": "ceratopsídeo",
    "ceratopsídeos": "ceratopsídeo",
    "ceratos": "cerato",
    "ceratoscópica": "ceratoscópico",
    "ceratoscópicas": "ceratoscópico",
    "ceratoscópicos": "ceratoscópico",
    "ceratoscópios": "ceratoscópio",
    "ceratotomias": "ceratotomia",
    "ceratotómica": "ceratotómico",
    "ceratotómicas": "ceratotómico",
    "ceratotómicos": "ceratotómico",
    "ceratómetros": "ceratómetro",
    "ceratótomos": "ceratótomo",
    "ceraunites": "ceraunite",
    "ceraunográfica": "ceraunográfico",
    "ceraunográficas": "ceraunográfico",
    "ceraunográficos": "ceraunográfico",
    "ceraunométrica": "ceraunométrico",
    "ceraunométricas": "ceraunométrico",
    "ceraunométricos": "ceraunométrico",
    "ceraunoscopias": "ceraunoscopia",
    "ceraunoscópica": "ceraunoscópico",
    "ceraunoscópicas": "ceraunoscópico",
    "ceraunoscópicos": "ceraunoscópico",
    "ceraunógrafos": "ceraunógrafo",
    "ceraunómetros": "ceraunómetro",
    "cerava": "cerar",
    "ceravam": "cerar",
    "ceravas": "cerar",
    "cerca": "cercar",
    "cercada": "cercar",
    "cercadas": "cercar",
    "cercadeiras": "cercadeira",
    "cercado": "cercar",
    "cercadora": "cercador",
    "cercadoras": "cercador",
    "cercadores": "cercador",
    "cercados": "cercar",
    "cercaduras": "cercadura",
    "cercai": "cercar",
    "cercais": "cercar",
    "cercam": "cercar",
    "cercamo": "cercar",
    "cercamos": "cercar",
    "cercana": "cercano",
    "cercanas": "cercano",
    "cercando": "cercar",
    "cercanias": "cercania",
    "cercanos": "cercano",
    "cercantes": "cercante",
    "cercara": "cercar",
    "cercaram": "cercar",
    "cercaras": "cercar",
    "cercarde": "cercar",
    "cercardes": "cercar",
    "cercare": "cercar",
    "cercarei": "cercar",
    "cercareis": "cercar",
    "cercarem": "cercar",
    "cercaremos": "cercar",
    "cercares": "cercar",
    "cercaria": "cercar",
    "cercariam": "cercar",
    "cercarias": "cercar",
    "cercarmo": "cercar",
    "cercarmos": "cercar",
    "cercará": "cercar",
    "cercarás": "cercar",
    "cercarão": "cercar",
    "cercaríamos": "cercar",
    "cercaríeis": "cercar",
    "cercas": "cercar",
    "cercasse": "cercar",
    "cercassem": "cercar",
    "cercasses": "cercar",
    "cercaste": "cercar",
    "cercastes": "cercar",
    "cercava": "cercar",
    "cercavam": "cercar",
    "cercavas": "cercar",
    "cercazinha": "cerca",
    "cercazinhas": "cerca",
    "cercazita": "cerca",
    "cercazitas": "cerca",
    "cerceada": "cercear",
    "cerceadas": "cercear",
    "cerceado": "cercear",
    "cerceadora": "cerceador",
    "cerceadoras": "cerceador",
    "cerceadores": "cerceador",
    "cerceados": "cercear",
    "cerceaduras": "cerceadura",
    "cerceai": "cercear",
    "cerceais": "cercear",
    "cerceamentos": "cerceamento",
    "cerceamo": "cercear",
    "cerceamos": "cercear",
    "cerceando": "cercear",
    "cerceara": "cercear",
    "cercearam": "cercear",
    "cercearas": "cercear",
    "cercearde": "cercear",
    "cerceardes": "cercear",
    "cerceare": "cercear",
    "cercearei": "cercear",
    "cerceareis": "cercear",
    "cercearem": "cercear",
    "cercearemos": "cercear",
    "cerceares": "cercear",
    "cercearia": "cercear",
    "cerceariam": "cercear",
    "cercearias": "cercear",
    "cercearmo": "cercear",
    "cercearmos": "cercear",
    "cerceará": "cercear",
    "cercearás": "cercear",
    "cercearão": "cercear",
    "cercearíamos": "cercear",
    "cercearíeis": "cercear",
    "cerceasse": "cercear",
    "cerceassem": "cercear",
    "cerceasses": "cercear",
    "cerceaste": "cercear",
    "cerceastes": "cercear",
    "cerceava": "cercear",
    "cerceavam": "cercear",
    "cerceavas": "cercear",
    "cerceei": "cercear",
    "cerceeis": "cercear",
    "cerceemo": "cercear",
    "cerceemos": "cercear",
    "cerceia": "cercear",
    "cerceiam": "cercear",
    "cerceias": "cercear",
    "cerceie": "cercear",
    "cerceiem": "cercear",
    "cerceies": "cercear",
    "cerceio": "cercear",
    "cerceios": "cerceio",
    "cerceou": "cercear",
    "cerces": "cerce",
    "cercetas": "cerceta",
    "cerceá": "cercear",
    "cerceámo": "cercear",
    "cerceámos": "cercear",
    "cerceáramo": "cercear",
    "cerceáramos": "cercear",
    "cerceárei": "cercear",
    "cerceáreis": "cercear",
    "cerceásseis": "cercear",
    "cerceássemos": "cercear",
    "cerceávamo": "cercear",
    "cerceávamos": "cercear",
    "cerceávei": "cercear",
    "cerceáveis": "cercear",
    "cercilha": "cercilhar",
    "cercilhada": "cercilhar",
    "cercilhadas": "cercilhar",
    "cercilhado": "cercilhar",
    "cercilhados": "cercilhar",
    "cercilhai": "cercilhar",
    "cercilhais": "cercilhar",
    "cercilham": "cercilhar",
    "cercilhamo": "cercilhar",
    "cercilhamos": "cercilhar",
    "cercilhando": "cercilhar",
    "cercilhara": "cercilhar",
    "cercilharam": "cercilhar",
    "cercilharas": "cercilhar",
    "cercilharde": "cercilhar",
    "cercilhardes": "cercilhar",
    "cercilhare": "cercilhar",
    "cercilharei": "cercilhar",
    "cercilhareis": "cercilhar",
    "cercilharem": "cercilhar",
    "cercilharemos": "cercilhar",
    "cercilhares": "cercilhar",
    "cercilharia": "cercilhar",
    "cercilhariam": "cercilhar",
    "cercilharias": "cercilhar",
    "cercilharmo": "cercilhar",
    "cercilharmos": "cercilhar",
    "cercilhará": "cercilhar",
    "cercilharás": "cercilhar",
    "cercilharão": "cercilhar",
    "cercilharíamos": "cercilhar",
    "cercilharíeis": "cercilhar",
    "cercilhas": "cercilhar",
    "cercilhasse": "cercilhar",
    "cercilhassem": "cercilhar",
    "cercilhasses": "cercilhar",
    "cercilhaste": "cercilhar",
    "cercilhastes": "cercilhar",
    "cercilhava": "cercilhar",
    "cercilhavam": "cercilhar",
    "cercilhavas": "cercilhar",
    "cercilhe": "cercilhar",
    "cercilhei": "cercilhar",
    "cercilheis": "cercilhar",
    "cercilhem": "cercilhar",
    "cercilhemo": "cercilhar",
    "cercilhemos": "cercilhar",
    "cercilhes": "cercilhar",
    "cercilho": "cercilhar",
    "cercilhos": "cercilho",
    "cercilhou": "cercilhar",
    "cercilhá": "cercilhar",
    "cercilhámo": "cercilhar",
    "cercilhámos": "cercilhar",
    "cercilháramo": "cercilhar",
    "cercilháramos": "cercilhar",
    "cercilhárei": "cercilhar",
    "cercilháreis": "cercilhar",
    "cercilhásseis": "cercilhar",
    "cercilhássemos": "cercilhar",
    "cercilhávamo": "cercilhar",
    "cercilhávamos": "cercilhar",
    "cercilhávei": "cercilhar",
    "cercilháveis": "cercilhar",
    "cerco": "cercar",
    "cercopitecídea": "cercopitecídeo",
    "cercopitecídeas": "cercopitecídeo",
    "cercopitecídeos": "cercopitecídeo",
    "cercopitécidas": "cercopitécida",
    "cercos": "cerco",
    "cercou": "cercar",
    "cercá": "cercar",
    "cercámo": "cercar",
    "cercámos": "cercar",
    "cercáramo": "cercar",
    "cercáramos": "cercar",
    "cercárei": "cercar",
    "cercáreis": "cercar",
    "cercásseis": "cercar",
    "cercássemos": "cercar",
    "cercávamo": "cercar",
    "cercávamos": "cercar",
    "cercávei": "cercar",
    "cercáveis": "cercar",
    "cercã": "cercão",
    "cercãos": "cercão",
    "cercãs": "cercão",
    "cerdas": "cerda",
    "cerdeiras": "cerdeira",
    "cerdeirinha": "cerdeira",
    "cerdeirinhas": "cerdeira",
    "cerdeirita": "cerdeira",
    "cerdeiritas": "cerdeira",
    "cerdoeiros": "cerdoeiro",
    "cerdos": "cerdo",
    "cerdosa": "cerdoso",
    "cerdosas": "cerdoso",
    "cerdosos": "cerdoso",
    "cerdões": "cerdão",
    "cere": "cerar",
    "cereais": "cereal",
    "cerealiculturas": "cerealicultura",
    "cerealífera": "cerealífero",
    "cerealíferas": "cerealífero",
    "cerealíferos": "cerealífero",
    "cerebelares": "cerebelar",
    "cerebelites": "cerebelite",
    "cerebelos": "cerebelo",
    "cerebrais": "cerebral",
    "cerebraliza": "cerebralizar",
    "cerebralizada": "cerebralizar",
    "cerebralizadas": "cerebralizar",
    "cerebralizado": "cerebralizar",
    "cerebralizados": "cerebralizar",
    "cerebralizai": "cerebralizar",
    "cerebralizais": "cerebralizar",
    "cerebralizam": "cerebralizar",
    "cerebralizamo": "cerebralizar",
    "cerebralizamos": "cerebralizar",
    "cerebralizando": "cerebralizar",
    "cerebralizara": "cerebralizar",
    "cerebralizaram": "cerebralizar",
    "cerebralizaras": "cerebralizar",
    "cerebralizardes": "cerebralizar",
    "cerebralizarei": "cerebralizar",
    "cerebralizareis": "cerebralizar",
    "cerebralizarem": "cerebralizar",
    "cerebralizaremos": "cerebralizar",
    "cerebralizares": "cerebralizar",
    "cerebralizaria": "cerebralizar",
    "cerebralizariam": "cerebralizar",
    "cerebralizarias": "cerebralizar",
    "cerebralizarmo": "cerebralizar",
    "cerebralizarmos": "cerebralizar",
    "cerebralizará": "cerebralizar",
    "cerebralizarás": "cerebralizar",
    "cerebralizarão": "cerebralizar",
    "cerebralizaríamos": "cerebralizar",
    "cerebralizaríeis": "cerebralizar",
    "cerebralizas": "cerebralizar",
    "cerebralizasse": "cerebralizar",
    "cerebralizassem": "cerebralizar",
    "cerebralizasses": "cerebralizar",
    "cerebralizaste": "cerebralizar",
    "cerebralizastes": "cerebralizar",
    "cerebralizava": "cerebralizar",
    "cerebralizavam": "cerebralizar",
    "cerebralizavas": "cerebralizar",
    "cerebralize": "cerebralizar",
    "cerebralizei": "cerebralizar",
    "cerebralizeis": "cerebralizar",
    "cerebralizem": "cerebralizar",
    "cerebralizemo": "cerebralizar",
    "cerebralizemos": "cerebralizar",
    "cerebralizes": "cerebralizar",
    "cerebralizo": "cerebralizar",
    "cerebralizou": "cerebralizar",
    "cerebralizámo": "cerebralizar",
    "cerebralizámos": "cerebralizar",
    "cerebralizáramo": "cerebralizar",
    "cerebralizáramos": "cerebralizar",
    "cerebralizáreis": "cerebralizar",
    "cerebralizásseis": "cerebralizar",
    "cerebralizássemos": "cerebralizar",
    "cerebralizávamo": "cerebralizar",
    "cerebralizávamos": "cerebralizar",
    "cerebralizáveis": "cerebralizar",
    "cerebrastenias": "cerebrastenia",
    "cerebrações": "cerebração",
    "cerebrina": "cerebrino",
    "cerebrinas": "cerebrino",
    "cerebrinos": "cerebrino",
    "cerebrites": "cerebrite",
    "cerebropatas": "cerebropata",
    "cerebropatias": "cerebropatia",
    "cerebropática": "cerebropático",
    "cerebropáticas": "cerebropático",
    "cerebropáticos": "cerebropático",
    "cerebroscópica": "cerebroscópico",
    "cerebroscópicas": "cerebroscópico",
    "cerebroscópicos": "cerebroscópico",
    "cerebrospinais": "cerebrospinal",
    "cerebrovasculara": "cerebrovascular",
    "cerebrovascularas": "cerebrovascular",
    "cerebrovasculares": "cerebrovascular",
    "cerebrozinho": "cérebro",
    "cerebrozinhos": "cérebro",
    "cerebrozito": "cérebro",
    "cerebrozitos": "cérebro",
    "cerebróides": "cerebróide",
    "cerefolhos": "cerefolho",
    "cerefólios": "cerefólio",
    "cerei": "cerar",
    "cereis": "cerar",
    "cerejais": "cerejal",
    "cerejas": "cereja",
    "cerejeiras": "cerejeira",
    "cerejinha": "cereja",
    "cerejinhas": "cereja",
    "cerejinhos": "cerejinho",
    "cerejita": "cereja",
    "cerejitas": "cereja",
    "cerejos": "cerejo",
    "cerem": "cerar",
    "ceremo": "cerar",
    "ceremos": "cerar",
    "ceres": "cerar",
    "ceresinas": "ceresina",
    "ceresita": "ceresitar",
    "ceresitada": "ceresitar",
    "ceresitadas": "ceresitar",
    "ceresitado": "ceresitar",
    "ceresitados": "ceresitar",
    "ceresitai": "ceresitar",
    "ceresitais": "ceresitar",
    "ceresitam": "ceresitar",
    "ceresitamo": "ceresitar",
    "ceresitamos": "ceresitar",
    "ceresitando": "ceresitar",
    "ceresitara": "ceresitar",
    "ceresitaram": "ceresitar",
    "ceresitaras": "ceresitar",
    "ceresitarde": "ceresitar",
    "ceresitardes": "ceresitar",
    "ceresitare": "ceresitar",
    "ceresitarei": "ceresitar",
    "ceresitareis": "ceresitar",
    "ceresitarem": "ceresitar",
    "ceresitaremos": "ceresitar",
    "ceresitares": "ceresitar",
    "ceresitaria": "ceresitar",
    "ceresitariam": "ceresitar",
    "ceresitarias": "ceresitar",
    "ceresitarmo": "ceresitar",
    "ceresitarmos": "ceresitar",
    "ceresitará": "ceresitar",
    "ceresitarás": "ceresitar",
    "ceresitarão": "ceresitar",
    "ceresitaríamos": "ceresitar",
    "ceresitaríeis": "ceresitar",
    "ceresitas": "ceresitar",
    "ceresitasse": "ceresitar",
    "ceresitassem": "ceresitar",
    "ceresitasses": "ceresitar",
    "ceresitaste": "ceresitar",
    "ceresitastes": "ceresitar",
    "ceresitava": "ceresitar",
    "ceresitavam": "ceresitar",
    "ceresitavas": "ceresitar",
    "ceresite": "ceresitar",
    "ceresitei": "ceresitar",
    "ceresiteis": "ceresitar",
    "ceresitem": "ceresitar",
    "ceresitemo": "ceresitar",
    "ceresitemos": "ceresitar",
    "ceresites": "ceresite",
    "ceresito": "ceresitar",
    "ceresitou": "ceresitar",
    "ceresitá": "ceresitar",
    "ceresitámo": "ceresitar",
    "ceresitámos": "ceresitar",
    "ceresitáramo": "ceresitar",
    "ceresitáramos": "ceresitar",
    "ceresitárei": "ceresitar",
    "ceresitáreis": "ceresitar",
    "ceresitásseis": "ceresitar",
    "ceresitássemos": "ceresitar",
    "ceresitávamo": "ceresitar",
    "ceresitávamos": "ceresitar",
    "ceresitávei": "ceresitar",
    "ceresitáveis": "ceresitar",
    "cerezinas": "cerezina",
    "cerezinos": "cerezino",
    "ceriata": "ceriato",
    "ceriatas": "ceriato",
    "ceriatos": "ceriato",
    "cerieira": "cerieiro",
    "cerieiras": "cerieiro",
    "cerieiros": "cerieiro",
    "cerijos": "cerijo",
    "cerimonia": "cerimoniar",
    "cerimoniada": "cerimoniar",
    "cerimoniadas": "cerimoniar",
    "cerimoniado": "cerimoniar",
    "cerimoniados": "cerimoniar",
    "cerimoniai": "cerimoniar",
    "cerimoniais": "cerimoniar",
    "cerimoniam": "cerimoniar",
    "cerimoniamo": "cerimoniar",
    "cerimoniamos": "cerimoniar",
    "cerimoniando": "cerimoniar",
    "cerimoniara": "cerimoniar",
    "cerimoniaram": "cerimoniar",
    "cerimoniaras": "cerimoniar",
    "cerimoniarde": "cerimoniar",
    "cerimoniardes": "cerimoniar",
    "cerimoniare": "cerimoniar",
    "cerimoniarei": "cerimoniar",
    "cerimoniareis": "cerimoniar",
    "cerimoniarem": "cerimoniar",
    "cerimoniaremos": "cerimoniar",
    "cerimoniares": "cerimoniar",
    "cerimoniaria": "cerimoniar",
    "cerimoniariam": "cerimoniar",
    "cerimoniarias": "cerimoniar",
    "cerimoniarmo": "cerimoniar",
    "cerimoniarmos": "cerimoniar",
    "cerimoniará": "cerimoniar",
    "cerimoniarás": "cerimoniar",
    "cerimoniarão": "cerimoniar",
    "cerimoniaríamos": "cerimoniar",
    "cerimoniaríeis": "cerimoniar",
    "cerimonias": "cerimoniar",
    "cerimoniasse": "cerimoniar",
    "cerimoniassem": "cerimoniar",
    "cerimoniasses": "cerimoniar",
    "cerimoniaste": "cerimoniar",
    "cerimoniastes": "cerimoniar",
    "cerimoniava": "cerimoniar",
    "cerimoniavam": "cerimoniar",
    "cerimoniavas": "cerimoniar",
    "cerimonie": "cerimoniar",
    "cerimoniei": "cerimoniar",
    "cerimonieis": "cerimoniar",
    "cerimoniem": "cerimoniar",
    "cerimoniemo": "cerimoniar",
    "cerimoniemos": "cerimoniar",
    "cerimonies": "cerimoniar",
    "cerimonio": "cerimoniar",
    "cerimoniosa": "cerimonioso",
    "cerimoniosas": "cerimonioso",
    "cerimoniosos": "cerimonioso",
    "cerimoniou": "cerimoniar",
    "cerimoniá": "cerimoniar",
    "cerimoniámo": "cerimoniar",
    "cerimoniámos": "cerimoniar",
    "cerimoniáramo": "cerimoniar",
    "cerimoniáramos": "cerimoniar",
    "cerimoniárei": "cerimoniar",
    "cerimoniáreis": "cerimoniar",
    "cerimoniásseis": "cerimoniar",
    "cerimoniássemos": "cerimoniar",
    "cerimoniática": "cerimoniático",
    "cerimoniáticas": "cerimoniático",
    "cerimoniáticos": "cerimoniático",
    "cerimoniávamo": "cerimoniar",
    "cerimoniávamos": "cerimoniar",
    "cerimoniávei": "cerimoniar",
    "cerimoniáveis": "cerimoniar",
    "cerimónias": "cerimónia",
    "cerinas": "cerina",
    "ceringonha": "ceringonhar",
    "ceringonhada": "ceringonhar",
    "ceringonhadas": "ceringonhar",
    "ceringonhado": "ceringonhar",
    "ceringonhados": "ceringonhar",
    "ceringonhai": "ceringonhar",
    "ceringonhais": "ceringonhar",
    "ceringonham": "ceringonhar",
    "ceringonhamo": "ceringonhar",
    "ceringonhamos": "ceringonhar",
    "ceringonhando": "ceringonhar",
    "ceringonhara": "ceringonhar",
    "ceringonharam": "ceringonhar",
    "ceringonharas": "ceringonhar",
    "ceringonhardes": "ceringonhar",
    "ceringonharei": "ceringonhar",
    "ceringonhareis": "ceringonhar",
    "ceringonharem": "ceringonhar",
    "ceringonharemos": "ceringonhar",
    "ceringonhares": "ceringonhar",
    "ceringonharia": "ceringonhar",
    "ceringonhariam": "ceringonhar",
    "ceringonharias": "ceringonhar",
    "ceringonharmo": "ceringonhar",
    "ceringonharmos": "ceringonhar",
    "ceringonhará": "ceringonhar",
    "ceringonharás": "ceringonhar",
    "ceringonharão": "ceringonhar",
    "ceringonharíamos": "ceringonhar",
    "ceringonharíeis": "ceringonhar",
    "ceringonhas": "ceringonhar",
    "ceringonhasse": "ceringonhar",
    "ceringonhassem": "ceringonhar",
    "ceringonhasses": "ceringonhar",
    "ceringonhaste": "ceringonhar",
    "ceringonhastes": "ceringonhar",
    "ceringonhava": "ceringonhar",
    "ceringonhavam": "ceringonhar",
    "ceringonhavas": "ceringonhar",
    "ceringonhe": "ceringonhar",
    "ceringonhei": "ceringonhar",
    "ceringonheis": "ceringonhar",
    "ceringonhem": "ceringonhar",
    "ceringonhemo": "ceringonhar",
    "ceringonhemos": "ceringonhar",
    "ceringonhes": "ceringonhar",
    "ceringonho": "ceringonhar",
    "ceringonhou": "ceringonhar",
    "ceringonhámo": "ceringonhar",
    "ceringonhámos": "ceringonhar",
    "ceringonháramo": "ceringonhar",
    "ceringonháramos": "ceringonhar",
    "ceringonháreis": "ceringonhar",
    "ceringonhásseis": "ceringonhar",
    "ceringonhássemos": "ceringonhar",
    "ceringonhávamo": "ceringonhar",
    "ceringonhávamos": "ceringonhar",
    "ceringonháveis": "ceringonhar",
    "ceriosas": "ceriosa",
    "cerirrostra": "cerirrostro",
    "cerirrostras": "cerirrostro",
    "cerirrostros": "cerirrostro",
    "ceritas": "cerita",
    "cerites": "cerite",
    "ceritídea": "ceritídeo",
    "ceritídeas": "ceritídeo",
    "ceritídeos": "ceritídeo",
    "cerna": "cernar",
    "cernada": "cernar",
    "cernadas": "cernar",
    "cernado": "cernar",
    "cernados": "cernar",
    "cernai": "cernar",
    "cernais": "cernar",
    "cernam": "cernar",
    "cernamo": "cernar",
    "cernamos": "cernar",
    "cernando": "cernar",
    "cernara": "cernar",
    "cernaram": "cernar",
    "cernaras": "cernar",
    "cernarde": "cernar",
    "cernardes": "cernar",
    "cernare": "cernar",
    "cernarei": "cernar",
    "cernareis": "cernar",
    "cernarem": "cernar",
    "cernaremos": "cernar",
    "cernares": "cernar",
    "cernaria": "cernar",
    "cernariam": "cernar",
    "cernarias": "cernar",
    "cernarmo": "cernar",
    "cernarmos": "cernar",
    "cernará": "cernar",
    "cernarás": "cernar",
    "cernarão": "cernar",
    "cernaríamos": "cernar",
    "cernaríeis": "cernar",
    "cernas": "cernar",
    "cernasse": "cernar",
    "cernassem": "cernar",
    "cernasses": "cernar",
    "cernaste": "cernar",
    "cernastes": "cernar",
    "cernava": "cernar",
    "cernavam": "cernar",
    "cernavas": "cernar",
    "cerne": "cernir",
    "cernei": "cernar",
    "cerneira": "cerneiro",
    "cerneiras": "cerneiro",
    "cerneiros": "cerneiro",
    "cerneis": "cernar",
    "cernelhas": "cernelha",
    "cernem": "cernir",
    "cernemo": "cernar",
    "cernemos": "cernar",
    "cernes": "cernir",
    "cerni": "cernir",
    "cernia": "cernir",
    "cerniam": "cernir",
    "cernias": "cernir",
    "cernida": "cernir",
    "cernidas": "cernir",
    "cernideiras": "cernideira",
    "cernido": "cernir",
    "cernidos": "cernir",
    "cernimo": "cernir",
    "cernimos": "cernir",
    "cernindo": "cernir",
    "cernira": "cernir",
    "cerniram": "cernir",
    "cerniras": "cernir",
    "cernirdes": "cernir",
    "cernirei": "cernir",
    "cernireis": "cernir",
    "cernirem": "cernir",
    "cerniremos": "cernir",
    "cernires": "cernir",
    "cerniria": "cernir",
    "cerniriam": "cernir",
    "cernirias": "cernir",
    "cernirmo": "cernir",
    "cernirmos": "cernir",
    "cernirá": "cernir",
    "cernirás": "cernir",
    "cernirão": "cernir",
    "cerniríamos": "cernir",
    "cerniríeis": "cernir",
    "cernis": "cernir",
    "cernisse": "cernir",
    "cernissem": "cernir",
    "cernisses": "cernir",
    "cerniste": "cernir",
    "cernistes": "cernir",
    "cerniu": "cernir",
    "cerno": "cernar",
    "cernou": "cernar",
    "cerná": "cernar",
    "cernámo": "cernar",
    "cernámos": "cernar",
    "cernáramo": "cernar",
    "cernáramos": "cernar",
    "cernárei": "cernar",
    "cernáreis": "cernar",
    "cernásseis": "cernar",
    "cernássemos": "cernar",
    "cernávamo": "cernar",
    "cernávamos": "cernar",
    "cernávei": "cernar",
    "cernáveis": "cernar",
    "cerníamo": "cernir",
    "cerníamos": "cernir",
    "cerníeis": "cernir",
    "cerníramo": "cernir",
    "cerníramos": "cernir",
    "cerníreis": "cernir",
    "cernísseis": "cernir",
    "cerníssemos": "cernir",
    "cero": "cerar",
    "ceroferários": "ceroferário",
    "ceromancias": "ceromancia",
    "ceromantes": "ceromante",
    "ceromeles": "ceromel",
    "ceromântica": "ceromântico",
    "ceromânticas": "ceromântico",
    "ceromânticos": "ceromântico",
    "ceroméis": "ceromel",
    "ceroplástica": "ceroplástico",
    "ceroplásticas": "ceroplástico",
    "ceroplásticos": "ceroplástico",
    "cerosa": "ceroso",
    "cerosas": "ceroso",
    "cerosos": "ceroso",
    "cerotos": "ceroto",
    "cerou": "cerar",
    "ceroulas": "ceroula",
    "cerque": "cercar",
    "cerquei": "cercar",
    "cerqueira": "cerqueiro",
    "cerqueiras": "cerqueiro",
    "cerqueiros": "cerqueiro",
    "cerqueis": "cercar",
    "cerquem": "cercar",
    "cerquemo": "cercar",
    "cerquemos": "cercar",
    "cerques": "cercar",
    "cerquidos": "cerquido",
    "cerra": "cerrar",
    "cerrada": "cerrar",
    "cerradas": "cerrar",
    "cerrado": "cerrar",
    "cerradoiros": "cerradoiro",
    "cerrados": "cerrar",
    "cerradouros": "cerradouro",
    "cerraduras": "cerradura",
    "cerradíssima": "cerrado",
    "cerradíssimas": "cerrado",
    "cerradíssimo": "cerrado",
    "cerradíssimos": "cerrado",
    "cerradões": "cerradão",
    "cerrai": "cerrar",
    "cerrais": "cerrar",
    "cerram": "cerrar",
    "cerramentos": "cerramento",
    "cerramo": "cerrar",
    "cerramos": "cerrar",
    "cerrando": "cerrar",
    "cerrara": "cerrar",
    "cerraram": "cerrar",
    "cerraras": "cerrar",
    "cerrarde": "cerrar",
    "cerrardes": "cerrar",
    "cerrare": "cerrar",
    "cerrarei": "cerrar",
    "cerrareis": "cerrar",
    "cerrarem": "cerrar",
    "cerraremos": "cerrar",
    "cerrares": "cerrar",
    "cerraria": "cerrar",
    "cerrariam": "cerrar",
    "cerrarias": "cerrar",
    "cerrarmo": "cerrar",
    "cerrarmos": "cerrar",
    "cerrará": "cerrar",
    "cerrarás": "cerrar",
    "cerrarão": "cerrar",
    "cerraríamos": "cerrar",
    "cerraríeis": "cerrar",
    "cerras": "cerrar",
    "cerrasse": "cerrar",
    "cerrassem": "cerrar",
    "cerrasses": "cerrar",
    "cerraste": "cerrar",
    "cerrastes": "cerrar",
    "cerrava": "cerrar",
    "cerravam": "cerrar",
    "cerravas": "cerrar",
    "cerrações": "cerração",
    "cerre": "cerrar",
    "cerrei": "cerrar",
    "cerreis": "cerrar",
    "cerrem": "cerrar",
    "cerremo": "cerrar",
    "cerremos": "cerrar",
    "cerres": "cerrar",
    "cerrilhas": "cerrilha",
    "cerro": "cerrar",
    "cerros": "cerro",
    "cerrotes": "cerrote",
    "cerrou": "cerrar",
    "cerrá": "cerrar",
    "cerrámo": "cerrar",
    "cerrámos": "cerrar",
    "cerráramo": "cerrar",
    "cerráramos": "cerrar",
    "cerrárei": "cerrar",
    "cerráreis": "cerrar",
    "cerrásseis": "cerrar",
    "cerrássemos": "cerrar",
    "cerrávamo": "cerrar",
    "cerrávamos": "cerrar",
    "cerrávei": "cerrar",
    "cerráveis": "cerrar",
    "cersefis": "cersefi",
    "certa": "certo",
    "certada": "certar",
    "certadas": "certar",
    "certado": "certar",
    "certados": "certar",
    "certai": "certar",
    "certais": "certar",
    "certam": "certar",
    "certamees": "certame",
    "certamo": "certar",
    "certamos": "certar",
    "certando": "certar",
    "certara": "certar",
    "certaram": "certar",
    "certaras": "certar",
    "certardes": "certar",
    "certarei": "certar",
    "certareis": "certar",
    "certarem": "certar",
    "certaremos": "certar",
    "certares": "certar",
    "certaria": "certar",
    "certariam": "certar",
    "certarias": "certar",
    "certarmo": "certar",
    "certarmos": "certar",
    "certará": "certar",
    "certarás": "certar",
    "certarão": "certar",
    "certaríamos": "certar",
    "certaríeis": "certar",
    "certas": "certo",
    "certasse": "certar",
    "certassem": "certar",
    "certasses": "certar",
    "certaste": "certar",
    "certastes": "certar",
    "certava": "certar",
    "certavam": "certar",
    "certavas": "certar",
    "certe": "certar",
    "certei": "certar",
    "certeira": "certeiro",
    "certeiras": "certeiro",
    "certeiros": "certeiro",
    "certeis": "certar",
    "certem": "certar",
    "certemo": "certar",
    "certemos": "certar",
    "certes": "certar",
    "certezas": "certeza",
    "certezinha": "certeza",
    "certezinhas": "certeza",
    "certezita": "certeza",
    "certezitas": "certeza",
    "certidões": "certidão",
    "certifica": "certificar",
    "certificada": "certificar",
    "certificadas": "certificar",
    "certificado": "certificar",
    "certificadora": "certificador",
    "certificadoras": "certificador",
    "certificadores": "certificador",
    "certificados": "certificar",
    "certificais": "certificar",
    "certificam": "certificar",
    "certificamo": "certificar",
    "certificamos": "certificar",
    "certificando": "certificar",
    "certificantes": "certificante",
    "certificara": "certificar",
    "certificaram": "certificar",
    "certificaras": "certificar",
    "certificardes": "certificar",
    "certificarei": "certificar",
    "certificareis": "certificar",
    "certificarem": "certificar",
    "certificaremos": "certificar",
    "certificares": "certificar",
    "certificaria": "certificar",
    "certificariam": "certificar",
    "certificarias": "certificar",
    "certificarmo": "certificar",
    "certificarmos": "certificar",
    "certificará": "certificar",
    "certificarás": "certificar",
    "certificarão": "certificar",
    "certificaríamos": "certificar",
    "certificaríeis": "certificar",
    "certificas": "certificar",
    "certificasse": "certificar",
    "certificassem": "certificar",
    "certificasses": "certificar",
    "certificaste": "certificar",
    "certificastes": "certificar",
    "certificativa": "certificativo",
    "certificativas": "certificativo",
    "certificativos": "certificativo",
    "certificatória": "certificatório",
    "certificatórias": "certificatório",
    "certificatórios": "certificatório",
    "certificava": "certificar",
    "certificavam": "certificar",
    "certificavas": "certificar",
    "certificações": "certificação",
    "certifico": "certificar",
    "certificou": "certificar",
    "certificámo": "certificar",
    "certificámos": "certificar",
    "certificáramo": "certificar",
    "certificáramos": "certificar",
    "certificáreis": "certificar",
    "certificásseis": "certificar",
    "certificássemos": "certificar",
    "certificávamo": "certificar",
    "certificávamos": "certificar",
    "certificáveis": "certificar",
    "certifique": "certificar",
    "certifiquei": "certificar",
    "certifiqueis": "certificar",
    "certifiquem": "certificar",
    "certifiquemos": "certificar",
    "certifiques": "certificar",
    "certinha": "certo",
    "certinhas": "certo",
    "certinho": "certo",
    "certinhos": "certo",
    "certita": "certo",
    "certitas": "certo",
    "certito": "certo",
    "certitos": "certo",
    "certo": "certar",
    "certos": "certo",
    "certou": "certar",
    "certámo": "certar",
    "certámos": "certar",
    "certáramo": "certar",
    "certáramos": "certar",
    "certáreis": "certar",
    "certásseis": "certar",
    "certássemos": "certar",
    "certávamo": "certar",
    "certávamos": "certar",
    "certáveis": "certar",
    "certâmenes": "certâmen",
    "certíssima": "certo",
    "certíssimas": "certo",
    "certíssimo": "certo",
    "certíssimos": "certo",
    "cerudas": "ceruda",
    "cerudes": "cerude",
    "cerulicrinita": "cerulicrinito",
    "cerulicrinitas": "cerulicrinito",
    "cerulicrinitos": "cerulicrinito",
    "cerumes": "cerume",
    "ceruminosa": "ceruminoso",
    "ceruminosas": "ceruminoso",
    "ceruminosos": "ceruminoso",
    "cerusites": "cerusite",
    "cervais": "cerval",
    "cervantesca": "cervantesco",
    "cervantescas": "cervantesco",
    "cervantescos": "cervantesco",
    "cervantina": "cervantino",
    "cervantinas": "cervantino",
    "cervantinos": "cervantino",
    "cervata": "cervato",
    "cervatas": "cervato",
    "cervatos": "cervato",
    "cerveirenses": "cerveirense",
    "cerveja": "cervejar",
    "cervejada": "cervejar",
    "cervejadas": "cervejar",
    "cervejado": "cervejar",
    "cervejados": "cervejar",
    "cervejai": "cervejar",
    "cervejais": "cervejar",
    "cervejam": "cervejar",
    "cervejamo": "cervejar",
    "cervejamos": "cervejar",
    "cervejando": "cervejar",
    "cervejara": "cervejar",
    "cervejaram": "cervejar",
    "cervejaras": "cervejar",
    "cervejardes": "cervejar",
    "cervejarei": "cervejar",
    "cervejareis": "cervejar",
    "cervejarem": "cervejar",
    "cervejaremos": "cervejar",
    "cervejares": "cervejar",
    "cervejaria": "cervejar",
    "cervejariam": "cervejar",
    "cervejarias": "cervejaria",
    "cervejarmo": "cervejar",
    "cervejarmos": "cervejar",
    "cervejará": "cervejar",
    "cervejarás": "cervejar",
    "cervejarão": "cervejar",
    "cervejaríamos": "cervejar",
    "cervejaríeis": "cervejar",
    "cervejas": "cervejar",
    "cervejasse": "cervejar",
    "cervejassem": "cervejar",
    "cervejasses": "cervejar",
    "cervejaste": "cervejar",
    "cervejastes": "cervejar",
    "cervejava": "cervejar",
    "cervejavam": "cervejar",
    "cervejavas": "cervejar",
    "cerveje": "cervejar",
    "cervejei": "cervejar",
    "cervejeira": "cervejeiro",
    "cervejeiras": "cervejeiro",
    "cervejeiros": "cervejeiro",
    "cervejeis": "cervejar",
    "cervejem": "cervejar",
    "cervejemo": "cervejar",
    "cervejemos": "cervejar",
    "cervejes": "cervejar",
    "cervejinha": "cerveja",
    "cervejinhas": "cerveja",
    "cervejita": "cerveja",
    "cervejitas": "cerveja",
    "cervejo": "cervejar",
    "cervejolas": "cervejola",
    "cervejotas": "cervejota",
    "cervejou": "cervejar",
    "cervejámo": "cervejar",
    "cervejámos": "cervejar",
    "cervejáramo": "cervejar",
    "cervejáramos": "cervejar",
    "cervejáreis": "cervejar",
    "cervejásseis": "cervejar",
    "cervejássemos": "cervejar",
    "cervejávamo": "cervejar",
    "cervejávamos": "cervejar",
    "cervejáveis": "cervejar",
    "cervicais": "cervical",
    "cerviculada": "cerviculado",
    "cerviculadas": "cerviculado",
    "cerviculados": "cerviculado",
    "cervicórnea": "cervicórneo",
    "cervicórneas": "cervicórneo",
    "cervicórneos": "cervicórneo",
    "cervigueiras": "cervigueira",
    "cervilheiras": "cervilheira",
    "cervina": "cervino",
    "cervinas": "cervino",
    "cervinos": "cervino",
    "cervizes": "cerviz",
    "cervos": "cervo",
    "cervuns": "cervum",
    "cervídea": "cervídeo",
    "cervídeas": "cervídeo",
    "cervídeos": "cervídeo",
    "cerze": "cerzir",
    "cerzes": "cerzir",
    "cerzi": "cerzir",
    "cerzia": "cerzir",
    "cerziam": "cerzir",
    "cerzias": "cerzir",
    "cerzida": "cerzir",
    "cerzidas": "cerzir",
    "cerzideiras": "cerzideira",
    "cerzido": "cerzir",
    "cerzidos": "cerzir",
    "cerzimo": "cerzir",
    "cerzimos": "cerzir",
    "cerzindo": "cerzir",
    "cerzira": "cerzir",
    "cerziram": "cerzir",
    "cerziras": "cerzir",
    "cerzirde": "cerzir",
    "cerzirdes": "cerzir",
    "cerzire": "cerzir",
    "cerzirei": "cerzir",
    "cerzireis": "cerzir",
    "cerzirem": "cerzir",
    "cerziremos": "cerzir",
    "cerzires": "cerzir",
    "cerziria": "cerzir",
    "cerziriam": "cerzir",
    "cerzirias": "cerzir",
    "cerzirmo": "cerzir",
    "cerzirmos": "cerzir",
    "cerzirá": "cerzir",
    "cerzirás": "cerzir",
    "cerzirão": "cerzir",
    "cerziríamos": "cerzir",
    "cerziríeis": "cerzir",
    "cerzis": "cerzir",
    "cerzisse": "cerzir",
    "cerzissem": "cerzir",
    "cerzisses": "cerzir",
    "cerziste": "cerzir",
    "cerzistes": "cerzir",
    "cerziu": "cerzir",
    "cerzíamo": "cerzir",
    "cerzíamos": "cerzir",
    "cerzíei": "cerzir",
    "cerzíeis": "cerzir",
    "cerzíramo": "cerzir",
    "cerzíramos": "cerzir",
    "cerzírei": "cerzir",
    "cerzíreis": "cerzir",
    "cerzísseis": "cerzir",
    "cerzíssemos": "cerzir",
    "cerá": "cerar",
    "cerácea": "ceráceo",
    "ceráceas": "ceráceo",
    "ceráceos": "ceráceo",
    "cerámo": "cerar",
    "cerámos": "cerar",
    "ceráramo": "cerar",
    "ceráramos": "cerar",
    "cerárei": "cerar",
    "ceráreis": "cerar",
    "cerásseis": "cerar",
    "cerássemos": "cerar",
    "ceráunias": "ceráunia",
    "cerávamo": "cerar",
    "cerávamos": "cerar",
    "cerávei": "cerar",
    "ceráveis": "cerar",
    "cerâmcia": "cerâmcio",
    "cerâmcias": "cerâmcio",
    "cerâmcios": "cerâmcio",
    "cerâmica": "cerâmico",
    "cerâmicas": "cerâmico",
    "cerâmicos": "cerâmico",
    "cerífera": "cerífero",
    "ceríferas": "cerífero",
    "ceríferos": "cerífero",
    "ceróides": "ceróide",
    "ceróis": "cerol",
    "cerós": "ceró",
    "cerúlea": "cerúleo",
    "cerúleas": "cerúleo",
    "cerúleos": "cerúleo",
    "cerúmenes": "cerúmen",
    "cesariana": "cesariano",
    "cesarianas": "cesariano",
    "cesarianos": "cesariano",
    "cesarismos": "cesarismo",
    "cesaristas": "cesarista",
    "cespitosa": "cespitoso",
    "cespitosas": "cespitoso",
    "cespitosos": "cespitoso",
    "cessa": "cessar",
    "cessada": "cessar",
    "cessadas": "cessar",
    "cessado": "cessar",
    "cessados": "cessar",
    "cessai": "cessar",
    "cessais": "cessar",
    "cessam": "cessar",
    "cessamentos": "cessamento",
    "cessamo": "cessar",
    "cessamos": "cessar",
    "cessando": "cessar",
    "cessantes": "cessante",
    "cessara": "cessar",
    "cessaram": "cessar",
    "cessaras": "cessar",
    "cessarde": "cessar",
    "cessardes": "cessar",
    "cessare": "cessar",
    "cessarei": "cessar",
    "cessareis": "cessar",
    "cessarem": "cessar",
    "cessaremos": "cessar",
    "cessares": "cessar",
    "cessaria": "cessar",
    "cessariam": "cessar",
    "cessarias": "cessar",
    "cessarmo": "cessar",
    "cessarmos": "cessar",
    "cessará": "cessar",
    "cessarás": "cessar",
    "cessarão": "cessar",
    "cessaríamos": "cessar",
    "cessaríeis": "cessar",
    "cessas": "cessar",
    "cessasse": "cessar",
    "cessassem": "cessar",
    "cessasses": "cessar",
    "cessaste": "cessar",
    "cessastes": "cessar",
    "cessava": "cessar",
    "cessavam": "cessar",
    "cessavas": "cessar",
    "cessações": "cessação",
    "cesse": "cessar",
    "cessei": "cessar",
    "cesseis": "cessar",
    "cessem": "cessar",
    "cessemo": "cessar",
    "cessemos": "cessar",
    "cesses": "cessar",
    "cessibilidades": "cessibilidade",
    "cessionária": "cessionário",
    "cessionárias": "cessionário",
    "cessionários": "cessionário",
    "cesso": "cessar",
    "cessou": "cessar",
    "cessá": "cessar",
    "cessámo": "cessar",
    "cessámos": "cessar",
    "cessáramo": "cessar",
    "cessáramos": "cessar",
    "cessárei": "cessar",
    "cessáreis": "cessar",
    "cessásseis": "cessar",
    "cessássemos": "cessar",
    "cessávamo": "cessar",
    "cessávamos": "cessar",
    "cessávei": "cessar",
    "cessáveis": "cessar",
    "cessíveis": "cessível",
    "cessões": "cessão",
    "cestadas": "cestada",
    "cestarias": "cestaria",
    "cestas": "cesta",
    "cesteira": "cesteiro",
    "cesteiras": "cesteiro",
    "cesteiros": "cesteiro",
    "cestinha": "cesta",
    "cestinhas": "cesta",
    "cestinho": "cesto",
    "cestinhos": "cesto",
    "cestita": "cesta",
    "cestitas": "cesta",
    "cestito": "cesto",
    "cestitos": "cesto",
    "cestodes": "cestode",
    "cestos": "cesto",
    "cestros": "cestro",
    "cestóides": "cestóide",
    "cestões": "cestão",
    "cesura": "cesurar",
    "cesurada": "cesurar",
    "cesuradas": "cesurar",
    "cesurado": "cesurar",
    "cesurados": "cesurar",
    "cesurai": "cesurar",
    "cesurais": "cesurar",
    "cesuram": "cesurar",
    "cesuramo": "cesurar",
    "cesuramos": "cesurar",
    "cesurando": "cesurar",
    "cesurara": "cesurar",
    "cesuraram": "cesurar",
    "cesuraras": "cesurar",
    "cesurarde": "cesurar",
    "cesurardes": "cesurar",
    "cesurare": "cesurar",
    "cesurarei": "cesurar",
    "cesurareis": "cesurar",
    "cesurarem": "cesurar",
    "cesuraremos": "cesurar",
    "cesurares": "cesurar",
    "cesuraria": "cesurar",
    "cesurariam": "cesurar",
    "cesurarias": "cesurar",
    "cesurarmo": "cesurar",
    "cesurarmos": "cesurar",
    "cesurará": "cesurar",
    "cesurarás": "cesurar",
    "cesurarão": "cesurar",
    "cesuraríamos": "cesurar",
    "cesuraríeis": "cesurar",
    "cesuras": "cesurar",
    "cesurasse": "cesurar",
    "cesurassem": "cesurar",
    "cesurasses": "cesurar",
    "cesuraste": "cesurar",
    "cesurastes": "cesurar",
    "cesurava": "cesurar",
    "cesuravam": "cesurar",
    "cesuravas": "cesurar",
    "cesure": "cesurar",
    "cesurei": "cesurar",
    "cesureis": "cesurar",
    "cesurem": "cesurar",
    "cesuremo": "cesurar",
    "cesuremos": "cesurar",
    "cesures": "cesurar",
    "cesuro": "cesurar",
    "cesurou": "cesurar",
    "cesurá": "cesurar",
    "cesurámo": "cesurar",
    "cesurámos": "cesurar",
    "cesuráramo": "cesurar",
    "cesuráramos": "cesurar",
    "cesurárei": "cesurar",
    "cesuráreis": "cesurar",
    "cesurásseis": "cesurar",
    "cesurássemos": "cesurar",
    "cesurávamo": "cesurar",
    "cesurávamos": "cesurar",
    "cesurávei": "cesurar",
    "cesuráveis": "cesurar",
    "cesárea": "cesáreo",
    "cesáreas": "cesáreo",
    "cesáreos": "cesáreo",
    "cesárias": "cesária",
    "cetilhas": "cetilha",
    "cetinas": "cetina",
    "cetinetas": "cetineta",
    "cetinosa": "cetinoso",
    "cetinosas": "cetinoso",
    "cetinosos": "cetinoso",
    "cetins": "cetim",
    "cetonas": "cetona",
    "cetonemias": "cetonemia",
    "cetonémica": "cetonémico",
    "cetonémicas": "cetonémico",
    "cetonémicos": "cetonémico",
    "cetonúrias": "cetonúria",
    "cetonúrica": "cetonúrico",
    "cetonúricas": "cetonúrico",
    "cetonúricos": "cetonúrico",
    "cetoses": "cetose",
    "cetrarias": "cetraria",
    "cetras": "cetra",
    "cetreiros": "cetreiro",
    "cetácea": "cetáceo",
    "cetáceas": "cetáceo",
    "cetáceos": "cetáceo",
    "cetónica": "cetónico",
    "cetónicas": "cetónico",
    "cetónicos": "cetónico",
    "ceva": "cevar",
    "cevada": "cevar",
    "cevadais": "cevadal",
    "cevadarias": "cevadaria",
    "cevadas": "cevar",
    "cevadeiras": "cevadeira",
    "cevadeiros": "cevadeiro",
    "cevadilhas": "cevadilha",
    "cevadinhas": "cevadinha",
    "cevadiça": "cevadiço",
    "cevadiças": "cevadiço",
    "cevadiços": "cevadiço",
    "cevado": "cevar",
    "cevadoiros": "cevadoiro",
    "cevadora": "cevador",
    "cevadoras": "cevador",
    "cevadores": "cevador",
    "cevados": "cevar",
    "cevadouros": "cevadouro",
    "cevaduras": "cevadura",
    "cevagens": "cevagem",
    "cevai": "cevar",
    "cevais": "cevar",
    "cevam": "cevar",
    "cevamo": "cevar",
    "cevamos": "cevar",
    "cevanda": "cevando",
    "cevandas": "cevando",
    "cevando": "cevar",
    "cevandos": "cevando",
    "cevara": "cevar",
    "cevaram": "cevar",
    "cevaras": "cevar",
    "cevarde": "cevar",
    "cevardes": "cevar",
    "cevare": "cevar",
    "cevarei": "cevar",
    "cevareis": "cevar",
    "cevarem": "cevar",
    "cevaremos": "cevar",
    "cevares": "cevar",
    "cevaria": "cevar",
    "cevariam": "cevar",
    "cevarias": "cevar",
    "cevarmo": "cevar",
    "cevarmos": "cevar",
    "cevará": "cevar",
    "cevarás": "cevar",
    "cevarão": "cevar",
    "cevaríamos": "cevar",
    "cevaríeis": "cevar",
    "cevas": "cevar",
    "cevasse": "cevar",
    "cevassem": "cevar",
    "cevasses": "cevar",
    "cevaste": "cevar",
    "cevastes": "cevar",
    "cevatícia": "cevatício",
    "cevatícias": "cevatício",
    "cevatícios": "cevatício",
    "cevava": "cevar",
    "cevavam": "cevar",
    "cevavas": "cevar",
    "ceve": "cevar",
    "cevei": "cevar",
    "ceveiras": "ceveira",
    "ceveis": "cevar",
    "cevem": "cevar",
    "cevemo": "cevar",
    "cevemos": "cevar",
    "ceves": "cevar",
    "cevo": "cevar",
    "cevos": "cevo",
    "cevou": "cevar",
    "cevá": "cevar",
    "cevádica": "cevádico",
    "cevádicas": "cevádico",
    "cevádicos": "cevádico",
    "cevámo": "cevar",
    "cevámos": "cevar",
    "ceváramo": "cevar",
    "ceváramos": "cevar",
    "cevárei": "cevar",
    "ceváreis": "cevar",
    "cevásseis": "cevar",
    "cevássemos": "cevar",
    "cevávamo": "cevar",
    "cevávamos": "cevar",
    "cevávei": "cevar",
    "ceváveis": "cevar",
    "cevões": "cevão",
    "ceámo": "cear",
    "ceámos": "cear",
    "ceáramo": "cear",
    "ceáramos": "cear",
    "ceáreis": "cear",
    "ceásseis": "cear",
    "ceássemos": "cear",
    "ceávamo": "cear",
    "ceávamos": "cear",
    "ceáveis": "cear",
    "chabouca": "chabouco",
    "chaboucas": "chabouco",
    "chaboucos": "chabouco",
    "chabouqueira": "chabouqueiro",
    "chabouqueiras": "chabouqueiro",
    "chabouqueiros": "chabouqueiro",
    "chacais": "chacal",
    "chacareira": "chacareiro",
    "chacareiras": "chacareiro",
    "chacareiros": "chacareiro",
    "chacaréus": "chacaréu",
    "chace": "chaçar",
    "chacei": "chaçar",
    "chaceis": "chaçar",
    "chacem": "chaçar",
    "chacemo": "chaçar",
    "chacemos": "chaçar",
    "chaces": "chaçar",
    "chachadas": "chachada",
    "chacina": "chacinar",
    "chacinada": "chacinar",
    "chacinadas": "chacinar",
    "chacinado": "chacinar",
    "chacinadora": "chacinador",
    "chacinadoras": "chacinador",
    "chacinadores": "chacinador",
    "chacinados": "chacinar",
    "chacinai": "chacinar",
    "chacinais": "chacinar",
    "chacinam": "chacinar",
    "chacinamo": "chacinar",
    "chacinamos": "chacinar",
    "chacinando": "chacinar",
    "chacinara": "chacinar",
    "chacinaram": "chacinar",
    "chacinaras": "chacinar",
    "chacinarde": "chacinar",
    "chacinardes": "chacinar",
    "chacinare": "chacinar",
    "chacinarei": "chacinar",
    "chacinareis": "chacinar",
    "chacinarem": "chacinar",
    "chacinaremos": "chacinar",
    "chacinares": "chacinar",
    "chacinaria": "chacinar",
    "chacinariam": "chacinar",
    "chacinarias": "chacinar",
    "chacinarmo": "chacinar",
    "chacinarmos": "chacinar",
    "chacinará": "chacinar",
    "chacinarás": "chacinar",
    "chacinarão": "chacinar",
    "chacinaríamos": "chacinar",
    "chacinaríeis": "chacinar",
    "chacinas": "chacinar",
    "chacinasse": "chacinar",
    "chacinassem": "chacinar",
    "chacinasses": "chacinar",
    "chacinaste": "chacinar",
    "chacinastes": "chacinar",
    "chacinava": "chacinar",
    "chacinavam": "chacinar",
    "chacinavas": "chacinar",
    "chacine": "chacinar",
    "chacinei": "chacinar",
    "chacineiros": "chacineiro",
    "chacineis": "chacinar",
    "chacinem": "chacinar",
    "chacinemo": "chacinar",
    "chacinemos": "chacinar",
    "chacines": "chacinar",
    "chacino": "chacinar",
    "chacinou": "chacinar",
    "chaciná": "chacinar",
    "chacinámo": "chacinar",
    "chacinámos": "chacinar",
    "chacináramo": "chacinar",
    "chacináramos": "chacinar",
    "chacinárei": "chacinar",
    "chacináreis": "chacinar",
    "chacinásseis": "chacinar",
    "chacinássemos": "chacinar",
    "chacinávamo": "chacinar",
    "chacinávamos": "chacinar",
    "chacinávei": "chacinar",
    "chacináveis": "chacinar",
    "chacoalha": "chacoalhar",
    "chacoalhada": "chacoalhar",
    "chacoalhadas": "chacoalhar",
    "chacoalhado": "chacoalhar",
    "chacoalhados": "chacoalhar",
    "chacoalhai": "chacoalhar",
    "chacoalhais": "chacoalhar",
    "chacoalham": "chacoalhar",
    "chacoalhamo": "chacoalhar",
    "chacoalhamos": "chacoalhar",
    "chacoalhando": "chacoalhar",
    "chacoalhara": "chacoalhar",
    "chacoalharam": "chacoalhar",
    "chacoalharas": "chacoalhar",
    "chacoalharde": "chacoalhar",
    "chacoalhardes": "chacoalhar",
    "chacoalhare": "chacoalhar",
    "chacoalharei": "chacoalhar",
    "chacoalhareis": "chacoalhar",
    "chacoalharem": "chacoalhar",
    "chacoalharemos": "chacoalhar",
    "chacoalhares": "chacoalhar",
    "chacoalharia": "chacoalhar",
    "chacoalhariam": "chacoalhar",
    "chacoalharias": "chacoalhar",
    "chacoalharmo": "chacoalhar",
    "chacoalharmos": "chacoalhar",
    "chacoalhará": "chacoalhar",
    "chacoalharás": "chacoalhar",
    "chacoalharão": "chacoalhar",
    "chacoalharíamos": "chacoalhar",
    "chacoalharíeis": "chacoalhar",
    "chacoalhas": "chacoalhar",
    "chacoalhasse": "chacoalhar",
    "chacoalhassem": "chacoalhar",
    "chacoalhasses": "chacoalhar",
    "chacoalhaste": "chacoalhar",
    "chacoalhastes": "chacoalhar",
    "chacoalhava": "chacoalhar",
    "chacoalhavam": "chacoalhar",
    "chacoalhavas": "chacoalhar",
    "chacoalhe": "chacoalhar",
    "chacoalhei": "chacoalhar",
    "chacoalheis": "chacoalhar",
    "chacoalhem": "chacoalhar",
    "chacoalhemo": "chacoalhar",
    "chacoalhemos": "chacoalhar",
    "chacoalhes": "chacoalhar",
    "chacoalho": "chacoalhar",
    "chacoalhou": "chacoalhar",
    "chacoalhá": "chacoalhar",
    "chacoalhámo": "chacoalhar",
    "chacoalhámos": "chacoalhar",
    "chacoalháramo": "chacoalhar",
    "chacoalháramos": "chacoalhar",
    "chacoalhárei": "chacoalhar",
    "chacoalháreis": "chacoalhar",
    "chacoalhásseis": "chacoalhar",
    "chacoalhássemos": "chacoalhar",
    "chacoalhávamo": "chacoalhar",
    "chacoalhávamos": "chacoalhar",
    "chacoalhávei": "chacoalhar",
    "chacoalháveis": "chacoalhar",
    "chaconas": "chacona",
    "chacotas": "chacota",
    "chacoteada": "chacotear",
    "chacoteadas": "chacotear",
    "chacoteado": "chacotear",
    "chacoteadora": "chacoteador",
    "chacoteadoras": "chacoteador",
    "chacoteadores": "chacoteador",
    "chacoteados": "chacotear",
    "chacoteai": "chacotear",
    "chacoteais": "chacotear",
    "chacoteamo": "chacotear",
    "chacoteamos": "chacotear",
    "chacoteando": "chacotear",
    "chacoteara": "chacotear",
    "chacotearam": "chacotear",
    "chacotearas": "chacotear",
    "chacotearde": "chacotear",
    "chacoteardes": "chacotear",
    "chacoteare": "chacotear",
    "chacotearei": "chacotear",
    "chacoteareis": "chacotear",
    "chacotearem": "chacotear",
    "chacotearemos": "chacotear",
    "chacoteares": "chacotear",
    "chacotearia": "chacotear",
    "chacoteariam": "chacotear",
    "chacotearias": "chacotear",
    "chacotearmo": "chacotear",
    "chacotearmos": "chacotear",
    "chacoteará": "chacotear",
    "chacotearás": "chacotear",
    "chacotearão": "chacotear",
    "chacotearíamos": "chacotear",
    "chacotearíeis": "chacotear",
    "chacoteasse": "chacotear",
    "chacoteassem": "chacotear",
    "chacoteasses": "chacotear",
    "chacoteaste": "chacotear",
    "chacoteastes": "chacotear",
    "chacoteava": "chacotear",
    "chacoteavam": "chacotear",
    "chacoteavas": "chacotear",
    "chacoteações": "chacoteação",
    "chacoteei": "chacotear",
    "chacoteeis": "chacotear",
    "chacoteemo": "chacotear",
    "chacoteemos": "chacotear",
    "chacoteia": "chacotear",
    "chacoteiam": "chacotear",
    "chacoteias": "chacotear",
    "chacoteie": "chacotear",
    "chacoteiem": "chacotear",
    "chacoteies": "chacotear",
    "chacoteio": "chacotear",
    "chacoteou": "chacotear",
    "chacoteá": "chacotear",
    "chacoteámo": "chacotear",
    "chacoteámos": "chacotear",
    "chacoteáramo": "chacotear",
    "chacoteáramos": "chacotear",
    "chacoteárei": "chacotear",
    "chacoteáreis": "chacotear",
    "chacoteásseis": "chacotear",
    "chacoteássemos": "chacotear",
    "chacoteávamo": "chacotear",
    "chacoteávamos": "chacotear",
    "chacoteávei": "chacotear",
    "chacoteáveis": "chacotear",
    "chacras": "chacra",
    "chacurus": "chacuru",
    "chacóinas": "chacóina",
    "chadas": "chada",
    "chadeiros": "chadeiro",
    "chafaricas": "chafarica",
    "chafariqueiros": "chafariqueiro",
    "chafarizes": "chafariz",
    "chafarnicas": "chafarnica",
    "chafarricas": "chafarrica",
    "chafunda": "chafundar",
    "chafundada": "chafundar",
    "chafundadas": "chafundar",
    "chafundado": "chafundar",
    "chafundados": "chafundar",
    "chafundai": "chafundar",
    "chafundais": "chafundar",
    "chafundam": "chafundar",
    "chafundamo": "chafundar",
    "chafundamos": "chafundar",
    "chafundando": "chafundar",
    "chafundara": "chafundar",
    "chafundaram": "chafundar",
    "chafundaras": "chafundar",
    "chafundarde": "chafundar",
    "chafundardes": "chafundar",
    "chafundare": "chafundar",
    "chafundarei": "chafundar",
    "chafundareis": "chafundar",
    "chafundarem": "chafundar",
    "chafundaremos": "chafundar",
    "chafundares": "chafundar",
    "chafundaria": "chafundar",
    "chafundariam": "chafundar",
    "chafundarias": "chafundar",
    "chafundarmo": "chafundar",
    "chafundarmos": "chafundar",
    "chafundará": "chafundar",
    "chafundarás": "chafundar",
    "chafundarão": "chafundar",
    "chafundaríamos": "chafundar",
    "chafundaríeis": "chafundar",
    "chafundas": "chafundar",
    "chafundasse": "chafundar",
    "chafundassem": "chafundar",
    "chafundasses": "chafundar",
    "chafundaste": "chafundar",
    "chafundastes": "chafundar",
    "chafundava": "chafundar",
    "chafundavam": "chafundar",
    "chafundavas": "chafundar",
    "chafunde": "chafundar",
    "chafundei": "chafundar",
    "chafundeis": "chafundar",
    "chafundem": "chafundar",
    "chafundemo": "chafundar",
    "chafundemos": "chafundar",
    "chafundes": "chafundar",
    "chafundo": "chafundar",
    "chafundou": "chafundar",
    "chafundá": "chafundar",
    "chafundámo": "chafundar",
    "chafundámos": "chafundar",
    "chafundáramo": "chafundar",
    "chafundáramos": "chafundar",
    "chafundárei": "chafundar",
    "chafundáreis": "chafundar",
    "chafundásseis": "chafundar",
    "chafundássemos": "chafundar",
    "chafundávamo": "chafundar",
    "chafundávamos": "chafundar",
    "chafundávei": "chafundar",
    "chafundáveis": "chafundar",
    "chafurda": "chafurdar",
    "chafurdada": "chafurdar",
    "chafurdadas": "chafurdar",
    "chafurdado": "chafurdar",
    "chafurdados": "chafurdar",
    "chafurdai": "chafurdar",
    "chafurdais": "chafurdar",
    "chafurdam": "chafurdar",
    "chafurdamo": "chafurdar",
    "chafurdamos": "chafurdar",
    "chafurdando": "chafurdar",
    "chafurdara": "chafurdar",
    "chafurdaram": "chafurdar",
    "chafurdaras": "chafurdar",
    "chafurdarde": "chafurdar",
    "chafurdardes": "chafurdar",
    "chafurdare": "chafurdar",
    "chafurdarei": "chafurdar",
    "chafurdareis": "chafurdar",
    "chafurdarem": "chafurdar",
    "chafurdaremos": "chafurdar",
    "chafurdares": "chafurdar",
    "chafurdaria": "chafurdar",
    "chafurdariam": "chafurdar",
    "chafurdarias": "chafurdar",
    "chafurdarmo": "chafurdar",
    "chafurdarmos": "chafurdar",
    "chafurdará": "chafurdar",
    "chafurdarás": "chafurdar",
    "chafurdarão": "chafurdar",
    "chafurdaríamos": "chafurdar",
    "chafurdaríeis": "chafurdar",
    "chafurdas": "chafurdar",
    "chafurdasse": "chafurdar",
    "chafurdassem": "chafurdar",
    "chafurdasses": "chafurdar",
    "chafurdaste": "chafurdar",
    "chafurdastes": "chafurdar",
    "chafurdava": "chafurdar",
    "chafurdavam": "chafurdar",
    "chafurdavas": "chafurdar",
    "chafurde": "chafurdar",
    "chafurdei": "chafurdar",
    "chafurdeira": "chafurdeiro",
    "chafurdeiras": "chafurdeiro",
    "chafurdeiros": "chafurdeiro",
    "chafurdeis": "chafurdar",
    "chafurdem": "chafurdar",
    "chafurdemo": "chafurdar",
    "chafurdemos": "chafurdar",
    "chafurdes": "chafurdar",
    "chafurdices": "chafurdice",
    "chafurdo": "chafurdar",
    "chafurdos": "chafurdo",
    "chafurdou": "chafurdar",
    "chafurdá": "chafurdar",
    "chafurdámo": "chafurdar",
    "chafurdámos": "chafurdar",
    "chafurdáramo": "chafurdar",
    "chafurdáramos": "chafurdar",
    "chafurdárei": "chafurdar",
    "chafurdáreis": "chafurdar",
    "chafurdásseis": "chafurdar",
    "chafurdássemos": "chafurdar",
    "chafurdávamo": "chafurdar",
    "chafurdávamos": "chafurdar",
    "chafurdávei": "chafurdar",
    "chafurdáveis": "chafurdar",
    "chaga": "chagar",
    "chagada": "chagar",
    "chagadas": "chagar",
    "chagado": "chagar",
    "chagados": "chagar",
    "chagai": "chagar",
    "chagais": "chagar",
    "chagam": "chagar",
    "chagamo": "chagar",
    "chagamos": "chagar",
    "chagando": "chagar",
    "chagara": "chagar",
    "chagaram": "chagar",
    "chagaras": "chagar",
    "chagarde": "chagar",
    "chagardes": "chagar",
    "chagare": "chagar",
    "chagarei": "chagar",
    "chagareis": "chagar",
    "chagarem": "chagar",
    "chagaremos": "chagar",
    "chagares": "chagar",
    "chagaria": "chagar",
    "chagariam": "chagar",
    "chagarias": "chagar",
    "chagarmo": "chagar",
    "chagarmos": "chagar",
    "chagará": "chagar",
    "chagarás": "chagar",
    "chagarão": "chagar",
    "chagaríamos": "chagar",
    "chagaríeis": "chagar",
    "chagas": "chagar",
    "chagasse": "chagar",
    "chagassem": "chagar",
    "chagasses": "chagar",
    "chagaste": "chagar",
    "chagastes": "chagar",
    "chagava": "chagar",
    "chagavam": "chagar",
    "chagavas": "chagar",
    "chagazes": "chagaz",
    "chago": "chagar",
    "chagou": "chagar",
    "chagrins": "chagrim",
    "chagréns": "chagrém",
    "chaguarços": "chaguarço",
    "chague": "chagar",
    "chaguei": "chagar",
    "chagueiras": "chagueira",
    "chagueis": "chagar",
    "chaguem": "chagar",
    "chaguemo": "chagar",
    "chaguemos": "chagar",
    "chaguenta": "chaguento",
    "chaguentas": "chaguento",
    "chaguentos": "chaguento",
    "chagues": "chagar",
    "chagá": "chagar",
    "chagámo": "chagar",
    "chagámos": "chagar",
    "chagáramo": "chagar",
    "chagáramos": "chagar",
    "chagárei": "chagar",
    "chagáreis": "chagar",
    "chagásseis": "chagar",
    "chagássemos": "chagar",
    "chagávamo": "chagar",
    "chagávamos": "chagar",
    "chagávei": "chagar",
    "chagáveis": "chagar",
    "chaimites": "chaimite",
    "chala": "chalar",
    "chalaceada": "chalacear",
    "chalaceadas": "chalacear",
    "chalaceado": "chalacear",
    "chalaceadora": "chalaceador",
    "chalaceadoras": "chalaceador",
    "chalaceadores": "chalaceador",
    "chalaceados": "chalacear",
    "chalaceai": "chalacear",
    "chalaceais": "chalacear",
    "chalaceamo": "chalacear",
    "chalaceamos": "chalacear",
    "chalaceando": "chalacear",
    "chalaceara": "chalacear",
    "chalacearam": "chalacear",
    "chalacearas": "chalacear",
    "chalaceardes": "chalacear",
    "chalacearei": "chalacear",
    "chalaceareis": "chalacear",
    "chalacearem": "chalacear",
    "chalacearemos": "chalacear",
    "chalaceares": "chalacear",
    "chalacearia": "chalacear",
    "chalaceariam": "chalacear",
    "chalacearias": "chalacear",
    "chalacearmo": "chalacear",
    "chalacearmos": "chalacear",
    "chalaceará": "chalacear",
    "chalacearás": "chalacear",
    "chalacearão": "chalacear",
    "chalacearíamos": "chalacear",
    "chalacearíeis": "chalacear",
    "chalaceasse": "chalacear",
    "chalaceassem": "chalacear",
    "chalaceasses": "chalacear",
    "chalaceaste": "chalacear",
    "chalaceastes": "chalacear",
    "chalaceava": "chalacear",
    "chalaceavam": "chalacear",
    "chalaceavas": "chalacear",
    "chalaceei": "chalacear",
    "chalaceeis": "chalacear",
    "chalaceemo": "chalacear",
    "chalaceemos": "chalacear",
    "chalaceia": "chalacear",
    "chalaceiam": "chalacear",
    "chalaceias": "chalacear",
    "chalaceie": "chalacear",
    "chalaceiem": "chalacear",
    "chalaceies": "chalacear",
    "chalaceio": "chalacear",
    "chalaceira": "chalaceiro",
    "chalaceiras": "chalaceiro",
    "chalaceiros": "chalaceiro",
    "chalaceou": "chalacear",
    "chalaceámo": "chalacear",
    "chalaceámos": "chalacear",
    "chalaceáramo": "chalacear",
    "chalaceáramos": "chalacear",
    "chalaceáreis": "chalacear",
    "chalaceásseis": "chalacear",
    "chalaceássemos": "chalacear",
    "chalaceávamo": "chalacear",
    "chalaceávamos": "chalacear",
    "chalaceáveis": "chalacear",
    "chalacistas": "chalacista",
    "chalada": "chalar",
    "chaladas": "chalar",
    "chalado": "chalar",
    "chalados": "chalar",
    "chalai": "chalar",
    "chalais": "chalar",
    "chalam": "chalar",
    "chalamo": "chalar",
    "chalamos": "chalar",
    "chalando": "chalar",
    "chalandras": "chalandra",
    "chalara": "chalar",
    "chalaram": "chalar",
    "chalaras": "chalar",
    "chalardes": "chalar",
    "chalarei": "chalar",
    "chalareis": "chalar",
    "chalarem": "chalar",
    "chalaremos": "chalar",
    "chalares": "chalar",
    "chalaria": "chalar",
    "chalariam": "chalar",
    "chalarias": "chalar",
    "chalarmo": "chalar",
    "chalarmos": "chalar",
    "chalará": "chalar",
    "chalarás": "chalar",
    "chalarão": "chalar",
    "chalaríamos": "chalar",
    "chalaríeis": "chalar",
    "chalas": "chalar",
    "chalasse": "chalar",
    "chalassem": "chalar",
    "chalasses": "chalar",
    "chalaste": "chalar",
    "chalastes": "chalar",
    "chalava": "chalar",
    "chalavam": "chalar",
    "chalavas": "chalar",
    "chalaças": "chalaça",
    "chalaços": "chalaço",
    "chale": "chalar",
    "chalei": "chalar",
    "chaleira": "chaleirar",
    "chaleirada": "chaleirar",
    "chaleiradas": "chaleirar",
    "chaleirado": "chaleirar",
    "chaleirados": "chaleirar",
    "chaleirai": "chaleirar",
    "chaleirais": "chaleirar",
    "chaleiram": "chaleirar",
    "chaleiramo": "chaleirar",
    "chaleiramos": "chaleirar",
    "chaleirando": "chaleirar",
    "chaleirara": "chaleirar",
    "chaleiraram": "chaleirar",
    "chaleiraras": "chaleirar",
    "chaleirarde": "chaleirar",
    "chaleirardes": "chaleirar",
    "chaleirare": "chaleirar",
    "chaleirarei": "chaleirar",
    "chaleirareis": "chaleirar",
    "chaleirarem": "chaleirar",
    "chaleiraremos": "chaleirar",
    "chaleirares": "chaleirar",
    "chaleiraria": "chaleirar",
    "chaleirariam": "chaleirar",
    "chaleirarias": "chaleirar",
    "chaleirarmo": "chaleirar",
    "chaleirarmos": "chaleirar",
    "chaleirará": "chaleirar",
    "chaleirarás": "chaleirar",
    "chaleirarão": "chaleirar",
    "chaleiraríamos": "chaleirar",
    "chaleiraríeis": "chaleirar",
    "chaleiras": "chaleirar",
    "chaleirasse": "chaleirar",
    "chaleirassem": "chaleirar",
    "chaleirasses": "chaleirar",
    "chaleiraste": "chaleirar",
    "chaleirastes": "chaleirar",
    "chaleirava": "chaleirar",
    "chaleiravam": "chaleirar",
    "chaleiravas": "chaleirar",
    "chaleire": "chaleirar",
    "chaleirei": "chaleirar",
    "chaleireis": "chaleirar",
    "chaleirem": "chaleirar",
    "chaleiremo": "chaleirar",
    "chaleiremos": "chaleirar",
    "chaleires": "chaleirar",
    "chaleiro": "chaleirar",
    "chaleirou": "chaleirar",
    "chaleirá": "chaleirar",
    "chaleirámo": "chaleirar",
    "chaleirámos": "chaleirar",
    "chaleiráramo": "chaleirar",
    "chaleiráramos": "chaleirar",
    "chaleirárei": "chaleirar",
    "chaleiráreis": "chaleirar",
    "chaleirásseis": "chaleirar",
    "chaleirássemos": "chaleirar",
    "chaleirávamo": "chaleirar",
    "chaleirávamos": "chaleirar",
    "chaleirávei": "chaleirar",
    "chaleiráveis": "chaleirar",
    "chaleis": "chalar",
    "chalem": "chalar",
    "chalemo": "chalar",
    "chalemos": "chalar",
    "chales": "chalar",
    "chalezinho": "chalé",
    "chalezinhos": "chalé",
    "chalezito": "chalé",
    "chalezitos": "chalé",
    "challengers": "challenger",
    "chalo": "chalar",
    "chalotas": "chalota",
    "chalou": "chalar",
    "chalra": "chalrar",
    "chalrada": "chalrar",
    "chalradas": "chalrar",
    "chalrado": "chalrar",
    "chalrados": "chalrar",
    "chalrai": "chalrar",
    "chalrais": "chalrar",
    "chalram": "chalrar",
    "chalramo": "chalrar",
    "chalramos": "chalrar",
    "chalrando": "chalrar",
    "chalrara": "chalrar",
    "chalraram": "chalrar",
    "chalraras": "chalrar",
    "chalrardes": "chalrar",
    "chalrarei": "chalrar",
    "chalrareis": "chalrar",
    "chalrarem": "chalrar",
    "chalraremos": "chalrar",
    "chalrares": "chalrar",
    "chalraria": "chalrar",
    "chalrariam": "chalrar",
    "chalrarias": "chalrar",
    "chalrarmo": "chalrar",
    "chalrarmos": "chalrar",
    "chalrará": "chalrar",
    "chalrarás": "chalrar",
    "chalrarão": "chalrar",
    "chalraríamos": "chalrar",
    "chalraríeis": "chalrar",
    "chalras": "chalrar",
    "chalrasse": "chalrar",
    "chalrassem": "chalrar",
    "chalrasses": "chalrar",
    "chalraste": "chalrar",
    "chalrastes": "chalrar",
    "chalrava": "chalrar",
    "chalravam": "chalrar",
    "chalravas": "chalrar",
    "chalre": "chalrar",
    "chalreada": "chalrear",
    "chalreadas": "chalrear",
    "chalreado": "chalrear",
    "chalreadora": "chalreador",
    "chalreadoras": "chalreador",
    "chalreadores": "chalreador",
    "chalreados": "chalrear",
    "chalreaduras": "chalreadura",
    "chalreai": "chalrear",
    "chalreais": "chalrear",
    "chalreamo": "chalrear",
    "chalreamos": "chalrear",
    "chalreando": "chalrear",
    "chalreara": "chalrear",
    "chalrearam": "chalrear",
    "chalrearas": "chalrear",
    "chalreardes": "chalrear",
    "chalrearei": "chalrear",
    "chalreareis": "chalrear",
    "chalrearem": "chalrear",
    "chalrearemos": "chalrear",
    "chalreares": "chalrear",
    "chalrearia": "chalrear",
    "chalreariam": "chalrear",
    "chalrearias": "chalrear",
    "chalrearmo": "chalrear",
    "chalrearmos": "chalrear",
    "chalreará": "chalrear",
    "chalrearás": "chalrear",
    "chalrearão": "chalrear",
    "chalrearíamos": "chalrear",
    "chalrearíeis": "chalrear",
    "chalreasse": "chalrear",
    "chalreassem": "chalrear",
    "chalreasses": "chalrear",
    "chalreaste": "chalrear",
    "chalreastes": "chalrear",
    "chalreava": "chalrear",
    "chalreavam": "chalrear",
    "chalreavas": "chalrear",
    "chalreei": "chalrear",
    "chalreeis": "chalrear",
    "chalreemo": "chalrear",
    "chalreemos": "chalrear",
    "chalrei": "chalrar",
    "chalreia": "chalrear",
    "chalreiam": "chalrear",
    "chalreias": "chalrear",
    "chalreie": "chalrear",
    "chalreiem": "chalrear",
    "chalreies": "chalrear",
    "chalreio": "chalrear",
    "chalreios": "chalreio",
    "chalreis": "chalrar",
    "chalrem": "chalrar",
    "chalremo": "chalrar",
    "chalremos": "chalrar",
    "chalreou": "chalrear",
    "chalres": "chalrar",
    "chalretas": "chalreta",
    "chalreámo": "chalrear",
    "chalreámos": "chalrear",
    "chalreáramo": "chalrear",
    "chalreáramos": "chalrear",
    "chalreáreis": "chalrear",
    "chalreásseis": "chalrear",
    "chalreássemos": "chalrear",
    "chalreávamo": "chalrear",
    "chalreávamos": "chalrear",
    "chalreáveis": "chalrear",
    "chalro": "chalrar",
    "chalrotes": "chalrote",
    "chalrou": "chalrar",
    "chalrámo": "chalrar",
    "chalrámos": "chalrar",
    "chalráramo": "chalrar",
    "chalráramos": "chalrar",
    "chalráreis": "chalrar",
    "chalrásseis": "chalrar",
    "chalrássemos": "chalrar",
    "chalrávamo": "chalrar",
    "chalrávamos": "chalrar",
    "chalráveis": "chalrar",
    "chalrões": "chalrão",
    "chalupas": "chalupa",
    "chalámo": "chalar",
    "chalámos": "chalar",
    "chaláramo": "chalar",
    "chaláramos": "chalar",
    "chaláreis": "chalar",
    "chalásseis": "chalar",
    "chalássemos": "chalar",
    "chalávamo": "chalar",
    "chalávamos": "chalar",
    "chaláveis": "chalar",
    "chalés": "chalé",
    "chalões": "chalão",
    "chama": "chamar",
    "chamada": "chamar",
    "chamadas": "chamar",
    "chamado": "chamar",
    "chamadoiros": "chamadoiro",
    "chamadora": "chamador",
    "chamadoras": "chamador",
    "chamadores": "chamador",
    "chamados": "chamar",
    "chamadouros": "chamadouro",
    "chamai": "chamar",
    "chamais": "chamar",
    "chamalotes": "chamalote",
    "chamam": "chamar",
    "chamamentos": "chamamento",
    "chamamo": "chamar",
    "chamamos": "chamar",
    "chamando": "chamar",
    "chamara": "chamar",
    "chamaram": "chamar",
    "chamaras": "chamar",
    "chamarde": "chamar",
    "chamardes": "chamar",
    "chamare": "chamar",
    "chamarei": "chamar",
    "chamareis": "chamar",
    "chamarem": "chamar",
    "chamaremos": "chamar",
    "chamares": "chamar",
    "chamaria": "chamar",
    "chamariam": "chamar",
    "chamarias": "chamar",
    "chamarizes": "chamariz",
    "chamarmo": "chamar",
    "chamarmos": "chamar",
    "chamarras": "chamarra",
    "chamará": "chamar",
    "chamarás": "chamar",
    "chamarão": "chamar",
    "chamaríamos": "chamar",
    "chamaríeis": "chamar",
    "chamas": "chamar",
    "chamasse": "chamar",
    "chamassem": "chamar",
    "chamasses": "chamar",
    "chamaste": "chamar",
    "chamastes": "chamar",
    "chamativa": "chamativo",
    "chamativas": "chamativo",
    "chamativos": "chamativo",
    "chamava": "chamar",
    "chamavam": "chamar",
    "chamavas": "chamar",
    "chambaris": "chambaril",
    "chamboada": "chamboado",
    "chamboadas": "chamboado",
    "chamboados": "chamboado",
    "chambona": "chambão",
    "chambonas": "chambão",
    "chambos": "chambo",
    "chamboíces": "chamboíce",
    "chambra": "chambrar",
    "chambrada": "chambrar",
    "chambradas": "chambrar",
    "chambrado": "chambrar",
    "chambrados": "chambrar",
    "chambrai": "chambrar",
    "chambrais": "chambrar",
    "chambram": "chambrar",
    "chambramo": "chambrar",
    "chambramos": "chambrar",
    "chambrando": "chambrar",
    "chambrara": "chambrar",
    "chambraram": "chambrar",
    "chambraras": "chambrar",
    "chambrarde": "chambrar",
    "chambrardes": "chambrar",
    "chambrare": "chambrar",
    "chambrarei": "chambrar",
    "chambrareis": "chambrar",
    "chambrarem": "chambrar",
    "chambraremos": "chambrar",
    "chambrares": "chambrar",
    "chambraria": "chambrar",
    "chambrariam": "chambrar",
    "chambrarias": "chambrar",
    "chambrarmo": "chambrar",
    "chambrarmos": "chambrar",
    "chambrará": "chambrar",
    "chambrarás": "chambrar",
    "chambrarão": "chambrar",
    "chambraríamos": "chambrar",
    "chambraríeis": "chambrar",
    "chambras": "chambrar",
    "chambrasse": "chambrar",
    "chambrassem": "chambrar",
    "chambrasses": "chambrar",
    "chambraste": "chambrar",
    "chambrastes": "chambrar",
    "chambrava": "chambrar",
    "chambravam": "chambrar",
    "chambravas": "chambrar",
    "chambre": "chambrar",
    "chambrei": "chambrar",
    "chambreis": "chambrar",
    "chambrem": "chambrar",
    "chambremo": "chambrar",
    "chambremos": "chambrar",
    "chambres": "chambre",
    "chambriés": "chambrié",
    "chambro": "chambrar",
    "chambrou": "chambrar",
    "chambrá": "chambrar",
    "chambrámo": "chambrar",
    "chambrámos": "chambrar",
    "chambráramo": "chambrar",
    "chambráramos": "chambrar",
    "chambrárei": "chambrar",
    "chambráreis": "chambrar",
    "chambrásseis": "chambrar",
    "chambrássemos": "chambrar",
    "chambrávamo": "chambrar",
    "chambrávamos": "chambrar",
    "chambrávei": "chambrar",
    "chambráveis": "chambrar",
    "chambãs": "chambã",
    "chambões": "chambão",
    "chame": "chamar",
    "chamei": "chamar",
    "chameis": "chamar",
    "chameja": "chamejar",
    "chamejada": "chamejar",
    "chamejadas": "chamejar",
    "chamejado": "chamejar",
    "chamejados": "chamejar",
    "chamejai": "chamejar",
    "chamejais": "chamejar",
    "chamejam": "chamejar",
    "chamejamo": "chamejar",
    "chamejamos": "chamejar",
    "chamejando": "chamejar",
    "chamejantes": "chamejante",
    "chamejara": "chamejar",
    "chamejaram": "chamejar",
    "chamejaras": "chamejar",
    "chamejarde": "chamejar",
    "chamejardes": "chamejar",
    "chamejare": "chamejar",
    "chamejarei": "chamejar",
    "chamejareis": "chamejar",
    "chamejarem": "chamejar",
    "chamejaremos": "chamejar",
    "chamejares": "chamejar",
    "chamejaria": "chamejar",
    "chamejariam": "chamejar",
    "chamejarias": "chamejar",
    "chamejarmo": "chamejar",
    "chamejarmos": "chamejar",
    "chamejará": "chamejar",
    "chamejarás": "chamejar",
    "chamejarão": "chamejar",
    "chamejaríamos": "chamejar",
    "chamejaríeis": "chamejar",
    "chamejas": "chamejar",
    "chamejasse": "chamejar",
    "chamejassem": "chamejar",
    "chamejasses": "chamejar",
    "chamejaste": "chamejar",
    "chamejastes": "chamejar",
    "chamejava": "chamejar",
    "chamejavam": "chamejar",
    "chamejavas": "chamejar",
    "chameje": "chamejar",
    "chamejei": "chamejar",
    "chamejeis": "chamejar",
    "chamejem": "chamejar",
    "chamejemo": "chamejar",
    "chamejemos": "chamejar",
    "chamejes": "chamejar",
    "chamejo": "chamejar",
    "chamejou": "chamejar",
    "chamejá": "chamejar",
    "chamejámo": "chamejar",
    "chamejámos": "chamejar",
    "chamejáramo": "chamejar",
    "chamejáramos": "chamejar",
    "chamejárei": "chamejar",
    "chamejáreis": "chamejar",
    "chamejásseis": "chamejar",
    "chamejássemos": "chamejar",
    "chamejávamo": "chamejar",
    "chamejávamos": "chamejar",
    "chamejávei": "chamejar",
    "chamejáveis": "chamejar",
    "chamelotes": "chamelote",
    "chamem": "chamar",
    "chamemo": "chamar",
    "chamemos": "chamar",
    "chames": "chamar",
    "chamiceiros": "chamiceiro",
    "chaminés": "chaminé",
    "chamiças": "chamiça",
    "chamiços": "chamiço",
    "chamo": "chamar",
    "chamorra": "chamorro",
    "chamorras": "chamorro",
    "chamorros": "chamorro",
    "chamotins": "chamotim",
    "chamou": "chamar",
    "champagnes": "champagne",
    "champanhas": "champanha",
    "champanhes": "champanhe",
    "champanhiza": "champanhizar",
    "champanhizada": "champanhizar",
    "champanhizadas": "champanhizar",
    "champanhizado": "champanhizar",
    "champanhizados": "champanhizar",
    "champanhizai": "champanhizar",
    "champanhizais": "champanhizar",
    "champanhizam": "champanhizar",
    "champanhizamo": "champanhizar",
    "champanhizamos": "champanhizar",
    "champanhizando": "champanhizar",
    "champanhizara": "champanhizar",
    "champanhizaram": "champanhizar",
    "champanhizaras": "champanhizar",
    "champanhizarde": "champanhizar",
    "champanhizardes": "champanhizar",
    "champanhizare": "champanhizar",
    "champanhizarei": "champanhizar",
    "champanhizareis": "champanhizar",
    "champanhizarem": "champanhizar",
    "champanhizaremos": "champanhizar",
    "champanhizares": "champanhizar",
    "champanhizaria": "champanhizar",
    "champanhizariam": "champanhizar",
    "champanhizarias": "champanhizar",
    "champanhizarmo": "champanhizar",
    "champanhizarmos": "champanhizar",
    "champanhizará": "champanhizar",
    "champanhizarás": "champanhizar",
    "champanhizarão": "champanhizar",
    "champanhizaríamos": "champanhizar",
    "champanhizaríeis": "champanhizar",
    "champanhizas": "champanhizar",
    "champanhizasse": "champanhizar",
    "champanhizassem": "champanhizar",
    "champanhizasses": "champanhizar",
    "champanhizaste": "champanhizar",
    "champanhizastes": "champanhizar",
    "champanhizava": "champanhizar",
    "champanhizavam": "champanhizar",
    "champanhizavas": "champanhizar",
    "champanhize": "champanhizar",
    "champanhizei": "champanhizar",
    "champanhizeis": "champanhizar",
    "champanhizem": "champanhizar",
    "champanhizemo": "champanhizar",
    "champanhizemos": "champanhizar",
    "champanhizes": "champanhizar",
    "champanhizo": "champanhizar",
    "champanhizou": "champanhizar",
    "champanhizá": "champanhizar",
    "champanhizámo": "champanhizar",
    "champanhizámos": "champanhizar",
    "champanhizáramo": "champanhizar",
    "champanhizáramos": "champanhizar",
    "champanhizárei": "champanhizar",
    "champanhizáreis": "champanhizar",
    "champanhizásseis": "champanhizar",
    "champanhizássemos": "champanhizar",
    "champanhizávamo": "champanhizar",
    "champanhizávamos": "champanhizar",
    "champanhizávei": "champanhizar",
    "champanhizáveis": "champanhizar",
    "champes": "champe",
    "champis": "champil",
    "champôs": "champô",
    "chamusca": "chamuscar",
    "chamuscada": "chamuscar",
    "chamuscadas": "chamuscar",
    "chamuscadelas": "chamuscadela",
    "chamuscado": "chamuscar",
    "chamuscadoiros": "chamuscadoiro",
    "chamuscados": "chamuscar",
    "chamuscadouros": "chamuscadouro",
    "chamuscaduras": "chamuscadura",
    "chamuscai": "chamuscar",
    "chamuscais": "chamuscar",
    "chamuscam": "chamuscar",
    "chamuscamo": "chamuscar",
    "chamuscamos": "chamuscar",
    "chamuscando": "chamuscar",
    "chamuscara": "chamuscar",
    "chamuscaram": "chamuscar",
    "chamuscaras": "chamuscar",
    "chamuscarde": "chamuscar",
    "chamuscardes": "chamuscar",
    "chamuscare": "chamuscar",
    "chamuscarei": "chamuscar",
    "chamuscareis": "chamuscar",
    "chamuscarem": "chamuscar",
    "chamuscaremos": "chamuscar",
    "chamuscares": "chamuscar",
    "chamuscaria": "chamuscar",
    "chamuscariam": "chamuscar",
    "chamuscarias": "chamuscar",
    "chamuscarmo": "chamuscar",
    "chamuscarmos": "chamuscar",
    "chamuscará": "chamuscar",
    "chamuscarás": "chamuscar",
    "chamuscarão": "chamuscar",
    "chamuscaríamos": "chamuscar",
    "chamuscaríeis": "chamuscar",
    "chamuscas": "chamuscar",
    "chamuscasse": "chamuscar",
    "chamuscassem": "chamuscar",
    "chamuscasses": "chamuscar",
    "chamuscaste": "chamuscar",
    "chamuscastes": "chamuscar",
    "chamuscava": "chamuscar",
    "chamuscavam": "chamuscar",
    "chamuscavas": "chamuscar",
    "chamusco": "chamuscar",
    "chamuscos": "chamusco",
    "chamuscou": "chamuscar",
    "chamuscá": "chamuscar",
    "chamuscámo": "chamuscar",
    "chamuscámos": "chamuscar",
    "chamuscáramo": "chamuscar",
    "chamuscáramos": "chamuscar",
    "chamuscárei": "chamuscar",
    "chamuscáreis": "chamuscar",
    "chamuscásseis": "chamuscar",
    "chamuscássemos": "chamuscar",
    "chamuscávamo": "chamuscar",
    "chamuscávamos": "chamuscar",
    "chamuscávei": "chamuscar",
    "chamuscáveis": "chamuscável",
    "chamusque": "chamuscar",
    "chamusquei": "chamuscar",
    "chamusqueis": "chamuscar",
    "chamusquem": "chamuscar",
    "chamusquemo": "chamuscar",
    "chamusquemos": "chamuscar",
    "chamusques": "chamuscar",
    "chamuças": "chamuça",
    "chamá": "chamar",
    "chamámo": "chamar",
    "chamámos": "chamar",
    "chamáramo": "chamar",
    "chamáramos": "chamar",
    "chamárei": "chamar",
    "chamáreis": "chamar",
    "chamásseis": "chamar",
    "chamássemos": "chamar",
    "chamávamo": "chamar",
    "chamávamos": "chamar",
    "chamávei": "chamar",
    "chamáveis": "chamar",
    "chanatos": "chanato",
    "chancadas": "chancada",
    "chancas": "chanca",
    "chanceada": "chancear",
    "chanceadas": "chancear",
    "chanceado": "chancear",
    "chanceados": "chancear",
    "chanceai": "chancear",
    "chanceais": "chancear",
    "chanceamo": "chancear",
    "chanceamos": "chancear",
    "chanceando": "chancear",
    "chanceara": "chancear",
    "chancearam": "chancear",
    "chancearas": "chancear",
    "chanceardes": "chancear",
    "chancearei": "chancear",
    "chanceareis": "chancear",
    "chancearem": "chancear",
    "chancearemos": "chancear",
    "chanceares": "chancear",
    "chancearia": "chancear",
    "chanceariam": "chancear",
    "chancearias": "chancear",
    "chancearmo": "chancear",
    "chancearmos": "chancear",
    "chanceará": "chancear",
    "chancearás": "chancear",
    "chancearão": "chancear",
    "chancearíamos": "chancear",
    "chancearíeis": "chancear",
    "chanceasse": "chancear",
    "chanceassem": "chancear",
    "chanceasses": "chancear",
    "chanceaste": "chancear",
    "chanceastes": "chancear",
    "chanceava": "chancear",
    "chanceavam": "chancear",
    "chanceavas": "chancear",
    "chanceei": "chancear",
    "chanceeis": "chancear",
    "chanceemo": "chancear",
    "chanceemos": "chancear",
    "chanceia": "chancear",
    "chanceiam": "chancear",
    "chanceias": "chancear",
    "chanceie": "chancear",
    "chanceiem": "chancear",
    "chanceies": "chancear",
    "chanceio": "chancear",
    "chanceira": "chanceiro",
    "chanceiras": "chanceiro",
    "chanceiros": "chanceiro",
    "chancela": "chancelar",
    "chancelada": "chancelar",
    "chanceladas": "chancelar",
    "chancelado": "chancelar",
    "chancelados": "chancelar",
    "chancelai": "chancelar",
    "chancelais": "chancelar",
    "chancelam": "chancelar",
    "chancelamo": "chancelar",
    "chancelamos": "chancelar",
    "chancelando": "chancelar",
    "chancelara": "chancelar",
    "chancelaram": "chancelar",
    "chancelaras": "chancelar",
    "chancelarde": "chancelar",
    "chancelardes": "chancelar",
    "chancelare": "chancelar",
    "chancelarei": "chancelar",
    "chancelareis": "chancelar",
    "chancelarem": "chancelar",
    "chancelaremos": "chancelar",
    "chancelares": "chancelar",
    "chancelaria": "chancelar",
    "chancelariam": "chancelar",
    "chancelarias": "chancelaria",
    "chancelarmo": "chancelar",
    "chancelarmos": "chancelar",
    "chancelará": "chancelar",
    "chancelarás": "chancelar",
    "chancelarão": "chancelar",
    "chancelaríamos": "chancelar",
    "chancelaríeis": "chancelar",
    "chancelas": "chancelar",
    "chancelasse": "chancelar",
    "chancelassem": "chancelar",
    "chancelasses": "chancelar",
    "chancelaste": "chancelar",
    "chancelastes": "chancelar",
    "chancelava": "chancelar",
    "chancelavam": "chancelar",
    "chancelavas": "chancelar",
    "chancele": "chancelar",
    "chancelei": "chancelar",
    "chanceleis": "chancelar",
    "chancelem": "chancelar",
    "chancelemo": "chancelar",
    "chancelemos": "chancelar",
    "chanceleres": "chanceler",
    "chanceles": "chancelar",
    "chancelo": "chancelar",
    "chancelou": "chancelar",
    "chancelá": "chancelar",
    "chancelámo": "chancelar",
    "chancelámos": "chancelar",
    "chanceláramo": "chancelar",
    "chanceláramos": "chancelar",
    "chancelárei": "chancelar",
    "chanceláreis": "chancelar",
    "chancelásseis": "chancelar",
    "chancelássemos": "chancelar",
    "chancelávamo": "chancelar",
    "chancelávamos": "chancelar",
    "chancelávei": "chancelar",
    "chanceláveis": "chancelar",
    "chanceou": "chancear",
    "chances": "chance",
    "chanceámo": "chancear",
    "chanceámos": "chancear",
    "chanceáramo": "chancear",
    "chanceáramos": "chancear",
    "chanceáreis": "chancear",
    "chanceásseis": "chancear",
    "chanceássemos": "chancear",
    "chanceávamo": "chancear",
    "chanceávamos": "chancear",
    "chanceáveis": "chancear",
    "chancuda": "chancudo",
    "chancudas": "chancudo",
    "chancudos": "chancudo",
    "chanezas": "chaneza",
    "chanfalha": "chanfalhar",
    "chanfalhada": "chanfalhar",
    "chanfalhadas": "chanfalhar",
    "chanfalhado": "chanfalhar",
    "chanfalhados": "chanfalhar",
    "chanfalhai": "chanfalhar",
    "chanfalhais": "chanfalhar",
    "chanfalham": "chanfalhar",
    "chanfalhamo": "chanfalhar",
    "chanfalhamos": "chanfalhar",
    "chanfalhando": "chanfalhar",
    "chanfalhara": "chanfalhar",
    "chanfalharam": "chanfalhar",
    "chanfalharas": "chanfalhar",
    "chanfalhardes": "chanfalhar",
    "chanfalharei": "chanfalhar",
    "chanfalhareis": "chanfalhar",
    "chanfalharem": "chanfalhar",
    "chanfalharemos": "chanfalhar",
    "chanfalhares": "chanfalhar",
    "chanfalharia": "chanfalhar",
    "chanfalhariam": "chanfalhar",
    "chanfalharias": "chanfalhar",
    "chanfalharmo": "chanfalhar",
    "chanfalharmos": "chanfalhar",
    "chanfalhará": "chanfalhar",
    "chanfalharás": "chanfalhar",
    "chanfalharão": "chanfalhar",
    "chanfalharíamos": "chanfalhar",
    "chanfalharíeis": "chanfalhar",
    "chanfalhas": "chanfalhar",
    "chanfalhasse": "chanfalhar",
    "chanfalhassem": "chanfalhar",
    "chanfalhasses": "chanfalhar",
    "chanfalhaste": "chanfalhar",
    "chanfalhastes": "chanfalhar",
    "chanfalhava": "chanfalhar",
    "chanfalhavam": "chanfalhar",
    "chanfalhavas": "chanfalhar",
    "chanfalhe": "chanfalhar",
    "chanfalhei": "chanfalhar",
    "chanfalheis": "chanfalhar",
    "chanfalhem": "chanfalhar",
    "chanfalhemo": "chanfalhar",
    "chanfalhemos": "chanfalhar",
    "chanfalhes": "chanfalhar",
    "chanfalho": "chanfalhar",
    "chanfalhos": "chanfalho",
    "chanfalhou": "chanfalhar",
    "chanfalhámo": "chanfalhar",
    "chanfalhámos": "chanfalhar",
    "chanfalháramo": "chanfalhar",
    "chanfalháramos": "chanfalhar",
    "chanfalháreis": "chanfalhar",
    "chanfalhásseis": "chanfalhar",
    "chanfalhássemos": "chanfalhar",
    "chanfalhávamo": "chanfalhar",
    "chanfalhávamos": "chanfalhar",
    "chanfalháveis": "chanfalhar",
    "chanfalhões": "chanfalhão",
    "chanfanas": "chanfana",
    "chanfaneira": "chanfaneiro",
    "chanfaneiras": "chanfaneiro",
    "chanfaneiros": "chanfaneiro",
    "chanfra": "chanfrar",
    "chanfrada": "chanfrar",
    "chanfradas": "chanfrar",
    "chanfrado": "chanfrar",
    "chanfradores": "chanfrador",
    "chanfrados": "chanfrar",
    "chanfraduras": "chanfradura",
    "chanfrai": "chanfrar",
    "chanfrais": "chanfrar",
    "chanfram": "chanfrar",
    "chanframo": "chanfrar",
    "chanframos": "chanfrar",
    "chanfrando": "chanfrar",
    "chanfrara": "chanfrar",
    "chanfraram": "chanfrar",
    "chanfraras": "chanfrar",
    "chanfrarde": "chanfrar",
    "chanfrardes": "chanfrar",
    "chanfrare": "chanfrar",
    "chanfrarei": "chanfrar",
    "chanfrareis": "chanfrar",
    "chanfrarem": "chanfrar",
    "chanfraremos": "chanfrar",
    "chanfrares": "chanfrar",
    "chanfraria": "chanfrar",
    "chanfrariam": "chanfrar",
    "chanfrarias": "chanfrar",
    "chanfrarmo": "chanfrar",
    "chanfrarmos": "chanfrar",
    "chanfrará": "chanfrar",
    "chanfrarás": "chanfrar",
    "chanfrarão": "chanfrar",
    "chanfraríamos": "chanfrar",
    "chanfraríeis": "chanfrar",
    "chanfras": "chanfrar",
    "chanfrasse": "chanfrar",
    "chanfrassem": "chanfrar",
    "chanfrasses": "chanfrar",
    "chanfraste": "chanfrar",
    "chanfrastes": "chanfrar",
    "chanfrava": "chanfrar",
    "chanfravam": "chanfrar",
    "chanfravas": "chanfrar",
    "chanfre": "chanfrar",
    "chanfrei": "chanfrar",
    "chanfreis": "chanfrar",
    "chanfrem": "chanfrar",
    "chanfremo": "chanfrar",
    "chanfremos": "chanfrar",
    "chanfres": "chanfrar",
    "chanfro": "chanfrar",
    "chanfros": "chanfro",
    "chanfrou": "chanfrar",
    "chanfrá": "chanfrar",
    "chanfrámo": "chanfrar",
    "chanfrámos": "chanfrar",
    "chanfráramo": "chanfrar",
    "chanfráramos": "chanfrar",
    "chanfrárei": "chanfrar",
    "chanfráreis": "chanfrar",
    "chanfrásseis": "chanfrar",
    "chanfrássemos": "chanfrar",
    "chanfrávamo": "chanfrar",
    "chanfrávamos": "chanfrar",
    "chanfrávei": "chanfrar",
    "chanfráveis": "chanfrar",
    "chanqueada": "chanquear",
    "chanqueadas": "chanquear",
    "chanqueado": "chanquear",
    "chanqueados": "chanquear",
    "chanqueai": "chanquear",
    "chanqueais": "chanquear",
    "chanqueamo": "chanquear",
    "chanqueamos": "chanquear",
    "chanqueando": "chanquear",
    "chanqueara": "chanquear",
    "chanquearam": "chanquear",
    "chanquearas": "chanquear",
    "chanquearde": "chanquear",
    "chanqueardes": "chanquear",
    "chanqueare": "chanquear",
    "chanquearei": "chanquear",
    "chanqueareis": "chanquear",
    "chanquearem": "chanquear",
    "chanquearemos": "chanquear",
    "chanqueares": "chanquear",
    "chanquearia": "chanquear",
    "chanqueariam": "chanquear",
    "chanquearias": "chanquear",
    "chanquearmo": "chanquear",
    "chanquearmos": "chanquear",
    "chanqueará": "chanquear",
    "chanquearás": "chanquear",
    "chanquearão": "chanquear",
    "chanquearíamos": "chanquear",
    "chanquearíeis": "chanquear",
    "chanqueasse": "chanquear",
    "chanqueassem": "chanquear",
    "chanqueasses": "chanquear",
    "chanqueaste": "chanquear",
    "chanqueastes": "chanquear",
    "chanqueava": "chanquear",
    "chanqueavam": "chanquear",
    "chanqueavas": "chanquear",
    "chanqueei": "chanquear",
    "chanqueeis": "chanquear",
    "chanqueemo": "chanquear",
    "chanqueemos": "chanquear",
    "chanqueia": "chanquear",
    "chanqueiam": "chanquear",
    "chanqueias": "chanquear",
    "chanqueie": "chanquear",
    "chanqueiem": "chanquear",
    "chanqueies": "chanquear",
    "chanqueio": "chanquear",
    "chanqueira": "chanqueiro",
    "chanqueiras": "chanqueiro",
    "chanqueiros": "chanqueiro",
    "chanqueou": "chanquear",
    "chanquetas": "chanqueta",
    "chanqueá": "chanquear",
    "chanqueámo": "chanquear",
    "chanqueámos": "chanquear",
    "chanqueáramo": "chanquear",
    "chanqueáramos": "chanquear",
    "chanqueárei": "chanquear",
    "chanqueáreis": "chanquear",
    "chanqueásseis": "chanquear",
    "chanqueássemos": "chanquear",
    "chanqueávamo": "chanquear",
    "chanqueávamos": "chanquear",
    "chanqueávei": "chanquear",
    "chanqueáveis": "chanquear",
    "chanta": "chantar",
    "chantada": "chantar",
    "chantadas": "chantar",
    "chantado": "chantar",
    "chantados": "chantar",
    "chantaduras": "chantadura",
    "chantageada": "chantagear",
    "chantageadas": "chantagear",
    "chantageado": "chantagear",
    "chantageados": "chantagear",
    "chantageai": "chantagear",
    "chantageais": "chantagear",
    "chantageamo": "chantagear",
    "chantageamos": "chantagear",
    "chantageando": "chantagear",
    "chantageara": "chantagear",
    "chantagearam": "chantagear",
    "chantagearas": "chantagear",
    "chantagearde": "chantagear",
    "chantageardes": "chantagear",
    "chantageare": "chantagear",
    "chantagearei": "chantagear",
    "chantageareis": "chantagear",
    "chantagearem": "chantagear",
    "chantagearemos": "chantagear",
    "chantageares": "chantagear",
    "chantagearia": "chantagear",
    "chantageariam": "chantagear",
    "chantagearias": "chantagear",
    "chantagearmo": "chantagear",
    "chantagearmos": "chantagear",
    "chantageará": "chantagear",
    "chantagearás": "chantagear",
    "chantagearão": "chantagear",
    "chantagearíamos": "chantagear",
    "chantagearíeis": "chantagear",
    "chantageasse": "chantagear",
    "chantageassem": "chantagear",
    "chantageasses": "chantagear",
    "chantageaste": "chantagear",
    "chantageastes": "chantagear",
    "chantageava": "chantagear",
    "chantageavam": "chantagear",
    "chantageavas": "chantagear",
    "chantageei": "chantagear",
    "chantageeis": "chantagear",
    "chantageemo": "chantagear",
    "chantageemos": "chantagear",
    "chantageia": "chantagear",
    "chantageiam": "chantagear",
    "chantageias": "chantagear",
    "chantageie": "chantagear",
    "chantageiem": "chantagear",
    "chantageies": "chantagear",
    "chantageio": "chantagear",
    "chantagens": "chantagem",
    "chantageou": "chantagear",
    "chantageá": "chantagear",
    "chantageámo": "chantagear",
    "chantageámos": "chantagear",
    "chantageáramo": "chantagear",
    "chantageáramos": "chantagear",
    "chantageárei": "chantagear",
    "chantageáreis": "chantagear",
    "chantageásseis": "chantagear",
    "chantageássemos": "chantagear",
    "chantageávamo": "chantagear",
    "chantageávamos": "chantagear",
    "chantageávei": "chantagear",
    "chantageáveis": "chantageável",
    "chantagistas": "chantagista",
    "chantai": "chantar",
    "chantais": "chantar",
    "chantaja": "chantajar",
    "chantajada": "chantajar",
    "chantajadas": "chantajar",
    "chantajado": "chantajar",
    "chantajados": "chantajar",
    "chantajai": "chantajar",
    "chantajais": "chantajar",
    "chantajam": "chantajar",
    "chantajamo": "chantajar",
    "chantajamos": "chantajar",
    "chantajando": "chantajar",
    "chantajara": "chantajar",
    "chantajaram": "chantajar",
    "chantajaras": "chantajar",
    "chantajarde": "chantajar",
    "chantajardes": "chantajar",
    "chantajare": "chantajar",
    "chantajarei": "chantajar",
    "chantajareis": "chantajar",
    "chantajarem": "chantajar",
    "chantajaremos": "chantajar",
    "chantajares": "chantajar",
    "chantajaria": "chantajar",
    "chantajariam": "chantajar",
    "chantajarias": "chantajar",
    "chantajarmo": "chantajar",
    "chantajarmos": "chantajar",
    "chantajará": "chantajar",
    "chantajarás": "chantajar",
    "chantajarão": "chantajar",
    "chantajaríamos": "chantajar",
    "chantajaríeis": "chantajar",
    "chantajas": "chantajar",
    "chantajasse": "chantajar",
    "chantajassem": "chantajar",
    "chantajasses": "chantajar",
    "chantajaste": "chantajar",
    "chantajastes": "chantajar",
    "chantajava": "chantajar",
    "chantajavam": "chantajar",
    "chantajavas": "chantajar",
    "chantaje": "chantajar",
    "chantajei": "chantajar",
    "chantajeis": "chantajar",
    "chantajem": "chantajar",
    "chantajemo": "chantajar",
    "chantajemos": "chantajar",
    "chantajes": "chantajar",
    "chantajo": "chantajar",
    "chantajou": "chantajar",
    "chantajá": "chantajar",
    "chantajámo": "chantajar",
    "chantajámos": "chantajar",
    "chantajáramo": "chantajar",
    "chantajáramos": "chantajar",
    "chantajárei": "chantajar",
    "chantajáreis": "chantajar",
    "chantajásseis": "chantajar",
    "chantajássemos": "chantajar",
    "chantajávamo": "chantajar",
    "chantajávamos": "chantajar",
    "chantajávei": "chantajar",
    "chantajáveis": "chantajar",
    "chantam": "chantar",
    "chantamo": "chantar",
    "chantamos": "chantar",
    "chantando": "chantar",
    "chantara": "chantar",
    "chantaram": "chantar",
    "chantaras": "chantar",
    "chantarde": "chantar",
    "chantardes": "chantar",
    "chantare": "chantar",
    "chantarei": "chantar",
    "chantareis": "chantar",
    "chantarem": "chantar",
    "chantaremos": "chantar",
    "chantares": "chantar",
    "chantaria": "chantar",
    "chantariam": "chantar",
    "chantarias": "chantar",
    "chantarmo": "chantar",
    "chantarmos": "chantar",
    "chantará": "chantar",
    "chantarás": "chantar",
    "chantarão": "chantar",
    "chantaríamos": "chantar",
    "chantaríeis": "chantar",
    "chantas": "chantar",
    "chantasse": "chantar",
    "chantassem": "chantar",
    "chantasses": "chantar",
    "chantaste": "chantar",
    "chantastes": "chantar",
    "chantava": "chantar",
    "chantavam": "chantar",
    "chantavas": "chantar",
    "chante": "chantar",
    "chantei": "chantar",
    "chanteis": "chantel",
    "chantem": "chantar",
    "chantemo": "chantar",
    "chantemos": "chantar",
    "chantes": "chantar",
    "chanto": "chantar",
    "chantoeiras": "chantoeira",
    "chantou": "chantar",
    "chantrados": "chantrado",
    "chantres": "chantre",
    "chantrias": "chantria",
    "chantá": "chantar",
    "chantámo": "chantar",
    "chantámos": "chantar",
    "chantáramo": "chantar",
    "chantáramos": "chantar",
    "chantárei": "chantar",
    "chantáreis": "chantar",
    "chantásseis": "chantar",
    "chantássemos": "chantar",
    "chantávamo": "chantar",
    "chantávamos": "chantar",
    "chantávei": "chantar",
    "chantáveis": "chantar",
    "chantões": "chantão",
    "chançarinas": "chançarina",
    "chançaronas": "chançarona",
    "chanças": "chança",
    "chançuda": "chançudo",
    "chançudas": "chançudo",
    "chançudos": "chançudo",
    "chaníssima": "chão",
    "chaníssimas": "chão",
    "chaníssimo": "chão",
    "chaníssimos": "chão",
    "chapa": "chapar",
    "chapaceiros": "chapaceiro",
    "chapada": "chapar",
    "chapadas": "chapar",
    "chapadinha": "chapadinho",
    "chapadinhas": "chapadinho",
    "chapadinhos": "chapadinho",
    "chapado": "chapar",
    "chapados": "chapar",
    "chapadões": "chapadão",
    "chapai": "chapar",
    "chapais": "chapar",
    "chapam": "chapar",
    "chapamo": "chapar",
    "chapamos": "chapar",
    "chapando": "chapar",
    "chapara": "chapar",
    "chaparam": "chapar",
    "chaparas": "chapar",
    "chaparde": "chapar",
    "chapardes": "chapar",
    "chapare": "chapar",
    "chaparei": "chapar",
    "chapareis": "chapar",
    "chaparem": "chapar",
    "chaparemos": "chapar",
    "chapares": "chapar",
    "chaparia": "chapar",
    "chapariam": "chapar",
    "chaparias": "chaparia",
    "chaparmo": "chapar",
    "chaparmos": "chapar",
    "chaparrais": "chaparral",
    "chaparreiros": "chaparreiro",
    "chaparros": "chaparro",
    "chapará": "chapar",
    "chaparás": "chapar",
    "chaparão": "chapar",
    "chaparíamos": "chapar",
    "chaparíeis": "chapar",
    "chapas": "chapar",
    "chapasse": "chapar",
    "chapassem": "chapar",
    "chapasses": "chapar",
    "chapaste": "chapar",
    "chapastes": "chapar",
    "chapava": "chapar",
    "chapavam": "chapar",
    "chapavas": "chapar",
    "chapaçais": "chapaçal",
    "chape": "chapar",
    "chapeada": "chapear",
    "chapeadas": "chapear",
    "chapeado": "chapear",
    "chapeados": "chapear",
    "chapeai": "chapear",
    "chapeais": "chapear",
    "chapeamo": "chapear",
    "chapeamos": "chapear",
    "chapeando": "chapear",
    "chapeara": "chapear",
    "chapearam": "chapear",
    "chapearas": "chapear",
    "chapearde": "chapear",
    "chapeardes": "chapear",
    "chapeare": "chapear",
    "chapearei": "chapear",
    "chapeareis": "chapear",
    "chapearem": "chapear",
    "chapearemos": "chapear",
    "chapeares": "chapear",
    "chapearia": "chapear",
    "chapeariam": "chapear",
    "chapearias": "chapear",
    "chapearmo": "chapear",
    "chapearmos": "chapear",
    "chapeará": "chapear",
    "chapearás": "chapear",
    "chapearão": "chapear",
    "chapearíamos": "chapear",
    "chapearíeis": "chapear",
    "chapeasse": "chapear",
    "chapeassem": "chapear",
    "chapeasses": "chapear",
    "chapeaste": "chapear",
    "chapeastes": "chapear",
    "chapeava": "chapear",
    "chapeavam": "chapear",
    "chapeavas": "chapear",
    "chapeei": "chapear",
    "chapeeis": "chapear",
    "chapeemo": "chapear",
    "chapeemos": "chapear",
    "chapei": "chapar",
    "chapeia": "chapear",
    "chapeiam": "chapear",
    "chapeias": "chapear",
    "chapeie": "chapear",
    "chapeiem": "chapear",
    "chapeies": "chapear",
    "chapeio": "chapear",
    "chapeiradas": "chapeirada",
    "chapeirões": "chapeirão",
    "chapeis": "chapar",
    "chapeja": "chapejar",
    "chapejada": "chapejar",
    "chapejadas": "chapejar",
    "chapejado": "chapejar",
    "chapejados": "chapejar",
    "chapejai": "chapejar",
    "chapejais": "chapejar",
    "chapejam": "chapejar",
    "chapejamo": "chapejar",
    "chapejamos": "chapejar",
    "chapejando": "chapejar",
    "chapejara": "chapejar",
    "chapejaram": "chapejar",
    "chapejaras": "chapejar",
    "chapejardes": "chapejar",
    "chapejarei": "chapejar",
    "chapejareis": "chapejar",
    "chapejarem": "chapejar",
    "chapejaremos": "chapejar",
    "chapejares": "chapejar",
    "chapejaria": "chapejar",
    "chapejariam": "chapejar",
    "chapejarias": "chapejar",
    "chapejarmo": "chapejar",
    "chapejarmos": "chapejar",
    "chapejará": "chapejar",
    "chapejarás": "chapejar",
    "chapejarão": "chapejar",
    "chapejaríamos": "chapejar",
    "chapejaríeis": "chapejar",
    "chapejas": "chapejar",
    "chapejasse": "chapejar",
    "chapejassem": "chapejar",
    "chapejasses": "chapejar",
    "chapejaste": "chapejar",
    "chapejastes": "chapejar",
    "chapejava": "chapejar",
    "chapejavam": "chapejar",
    "chapejavas": "chapejar",
    "chapeje": "chapejar",
    "chapejei": "chapejar",
    "chapejeis": "chapejar",
    "chapejem": "chapejar",
    "chapejemo": "chapejar",
    "chapejemos": "chapejar",
    "chapejes": "chapejar",
    "chapejo": "chapejar",
    "chapejou": "chapejar",
    "chapejámo": "chapejar",
    "chapejámos": "chapejar",
    "chapejáramo": "chapejar",
    "chapejáramos": "chapejar",
    "chapejáreis": "chapejar",
    "chapejásseis": "chapejar",
    "chapejássemos": "chapejar",
    "chapejávamo": "chapejar",
    "chapejávamos": "chapejar",
    "chapejáveis": "chapejar",
    "chapeladas": "chapelada",
    "chapelarias": "chapelaria",
    "chapeleira": "chapeleiro",
    "chapeleiras": "chapeleiro",
    "chapeleiros": "chapeleiro",
    "chapeletas": "chapeleta",
    "chapeletes": "chapelete",
    "chapelinas": "chapelina",
    "chapelinho": "chapéu",
    "chapelinhos": "chapéu",
    "chapelito": "chapéu",
    "chapelitos": "chapéu",
    "chapelórios": "chapelório",
    "chapelões": "chapelão",
    "chapem": "chapar",
    "chapemo": "chapar",
    "chapemos": "chapar",
    "chapeou": "chapear",
    "chapes": "chape",
    "chapeuzinho": "chapéu",
    "chapeuzinhos": "chapéu",
    "chapeuzito": "chapéu",
    "chapeuzitos": "chapéu",
    "chapeá": "chapear",
    "chapeámo": "chapear",
    "chapeámos": "chapear",
    "chapeáramo": "chapear",
    "chapeáramos": "chapear",
    "chapeárei": "chapear",
    "chapeáreis": "chapear",
    "chapeásseis": "chapear",
    "chapeássemos": "chapear",
    "chapeávamo": "chapear",
    "chapeávamos": "chapear",
    "chapeávei": "chapear",
    "chapeáveis": "chapear",
    "chapice": "chapiçar",
    "chapicei": "chapiçar",
    "chapiceis": "chapiçar",
    "chapicem": "chapiçar",
    "chapicemo": "chapiçar",
    "chapicemos": "chapiçar",
    "chapices": "chapiçar",
    "chapina": "chapinar",
    "chapinada": "chapinar",
    "chapinadas": "chapinar",
    "chapinado": "chapinar",
    "chapinados": "chapinar",
    "chapinai": "chapinar",
    "chapinais": "chapinar",
    "chapinam": "chapinar",
    "chapinamo": "chapinar",
    "chapinamos": "chapinar",
    "chapinando": "chapinar",
    "chapinara": "chapinar",
    "chapinaram": "chapinar",
    "chapinaras": "chapinar",
    "chapinarde": "chapinar",
    "chapinardes": "chapinar",
    "chapinare": "chapinar",
    "chapinarei": "chapinar",
    "chapinareis": "chapinar",
    "chapinarem": "chapinar",
    "chapinaremos": "chapinar",
    "chapinares": "chapinar",
    "chapinaria": "chapinar",
    "chapinariam": "chapinar",
    "chapinarias": "chapinar",
    "chapinarmo": "chapinar",
    "chapinarmos": "chapinar",
    "chapinará": "chapinar",
    "chapinarás": "chapinar",
    "chapinarão": "chapinar",
    "chapinaríamos": "chapinar",
    "chapinaríeis": "chapinar",
    "chapinas": "chapinar",
    "chapinasse": "chapinar",
    "chapinassem": "chapinar",
    "chapinasses": "chapinar",
    "chapinaste": "chapinar",
    "chapinastes": "chapinar",
    "chapinava": "chapinar",
    "chapinavam": "chapinar",
    "chapinavas": "chapinar",
    "chapine": "chapinar",
    "chapinei": "chapinar",
    "chapineira": "chapineiro",
    "chapineiras": "chapineiro",
    "chapineiros": "chapineiro",
    "chapineis": "chapinar",
    "chapinem": "chapinar",
    "chapinemo": "chapinar",
    "chapinemos": "chapinar",
    "chapines": "chapinar",
    "chapinha": "chapinhar",
    "chapinhada": "chapinhar",
    "chapinhadas": "chapinhar",
    "chapinhado": "chapinhar",
    "chapinhados": "chapinhar",
    "chapinhai": "chapinhar",
    "chapinhais": "chapinhar",
    "chapinham": "chapinhar",
    "chapinhamo": "chapinhar",
    "chapinhamos": "chapinhar",
    "chapinhando": "chapinhar",
    "chapinhara": "chapinhar",
    "chapinharam": "chapinhar",
    "chapinharas": "chapinhar",
    "chapinhardes": "chapinhar",
    "chapinharei": "chapinhar",
    "chapinhareis": "chapinhar",
    "chapinharem": "chapinhar",
    "chapinharemos": "chapinhar",
    "chapinhares": "chapinhar",
    "chapinharia": "chapinhar",
    "chapinhariam": "chapinhar",
    "chapinharias": "chapinhar",
    "chapinharmo": "chapinhar",
    "chapinharmos": "chapinhar",
    "chapinhará": "chapinhar",
    "chapinharás": "chapinhar",
    "chapinharão": "chapinhar",
    "chapinharíamos": "chapinhar",
    "chapinharíeis": "chapinhar",
    "chapinhas": "chapinhar",
    "chapinhasse": "chapinhar",
    "chapinhassem": "chapinhar",
    "chapinhasses": "chapinhar",
    "chapinhaste": "chapinhar",
    "chapinhastes": "chapinhar",
    "chapinhava": "chapinhar",
    "chapinhavam": "chapinhar",
    "chapinhavas": "chapinhar",
    "chapinhe": "chapinhar",
    "chapinhei": "chapinhar",
    "chapinheiros": "chapinheiro",
    "chapinheis": "chapinhar",
    "chapinhem": "chapinhar",
    "chapinhemo": "chapinhar",
    "chapinhemos": "chapinhar",
    "chapinhes": "chapinhar",
    "chapinho": "chapinhar",
    "chapinhou": "chapinhar",
    "chapinhámo": "chapinhar",
    "chapinhámos": "chapinhar",
    "chapinháramo": "chapinhar",
    "chapinháramos": "chapinhar",
    "chapinháreis": "chapinhar",
    "chapinhásseis": "chapinhar",
    "chapinhássemos": "chapinhar",
    "chapinhávamo": "chapinhar",
    "chapinhávamos": "chapinhar",
    "chapinháveis": "chapinhar",
    "chapino": "chapinar",
    "chapinou": "chapinar",
    "chapins": "chapim",
    "chapiná": "chapinar",
    "chapinámo": "chapinar",
    "chapinámos": "chapinar",
    "chapináramo": "chapinar",
    "chapináramos": "chapinar",
    "chapinárei": "chapinar",
    "chapináreis": "chapinar",
    "chapinásseis": "chapinar",
    "chapinássemos": "chapinar",
    "chapinávamo": "chapinar",
    "chapinávamos": "chapinar",
    "chapinávei": "chapinar",
    "chapináveis": "chapinar",
    "chapisca": "chapiscar",
    "chapiscada": "chapiscar",
    "chapiscadas": "chapiscar",
    "chapiscado": "chapiscar",
    "chapiscados": "chapiscar",
    "chapiscai": "chapiscar",
    "chapiscais": "chapiscar",
    "chapiscam": "chapiscar",
    "chapiscamo": "chapiscar",
    "chapiscamos": "chapiscar",
    "chapiscando": "chapiscar",
    "chapiscara": "chapiscar",
    "chapiscaram": "chapiscar",
    "chapiscaras": "chapiscar",
    "chapiscarde": "chapiscar",
    "chapiscardes": "chapiscar",
    "chapiscare": "chapiscar",
    "chapiscarei": "chapiscar",
    "chapiscareis": "chapiscar",
    "chapiscarem": "chapiscar",
    "chapiscaremos": "chapiscar",
    "chapiscares": "chapiscar",
    "chapiscaria": "chapiscar",
    "chapiscariam": "chapiscar",
    "chapiscarias": "chapiscar",
    "chapiscarmo": "chapiscar",
    "chapiscarmos": "chapiscar",
    "chapiscará": "chapiscar",
    "chapiscarás": "chapiscar",
    "chapiscarão": "chapiscar",
    "chapiscaríamos": "chapiscar",
    "chapiscaríeis": "chapiscar",
    "chapiscas": "chapiscar",
    "chapiscasse": "chapiscar",
    "chapiscassem": "chapiscar",
    "chapiscasses": "chapiscar",
    "chapiscaste": "chapiscar",
    "chapiscastes": "chapiscar",
    "chapiscava": "chapiscar",
    "chapiscavam": "chapiscar",
    "chapiscavas": "chapiscar",
    "chapisco": "chapiscar",
    "chapiscos": "chapisco",
    "chapiscou": "chapiscar",
    "chapiscá": "chapiscar",
    "chapiscámo": "chapiscar",
    "chapiscámos": "chapiscar",
    "chapiscáramo": "chapiscar",
    "chapiscáramos": "chapiscar",
    "chapiscárei": "chapiscar",
    "chapiscáreis": "chapiscar",
    "chapiscásseis": "chapiscar",
    "chapiscássemos": "chapiscar",
    "chapiscávamo": "chapiscar",
    "chapiscávamos": "chapiscar",
    "chapiscávei": "chapiscar",
    "chapiscáveis": "chapiscar",
    "chapisque": "chapiscar",
    "chapisquei": "chapiscar",
    "chapisqueis": "chapiscar",
    "chapisquem": "chapiscar",
    "chapisquemo": "chapiscar",
    "chapisquemos": "chapiscar",
    "chapisques": "chapiscar",
    "chapita": "chapa",
    "chapitas": "chapa",
    "chapitéus": "chapitéu",
    "chapitôs": "chapitô",
    "chapiça": "chapiçar",
    "chapiçada": "chapiçar",
    "chapiçadas": "chapiçar",
    "chapiçado": "chapiçar",
    "chapiçados": "chapiçar",
    "chapiçai": "chapiçar",
    "chapiçais": "chapiçar",
    "chapiçam": "chapiçar",
    "chapiçamo": "chapiçar",
    "chapiçamos": "chapiçar",
    "chapiçando": "chapiçar",
    "chapiçara": "chapiçar",
    "chapiçaram": "chapiçar",
    "chapiçaras": "chapiçar",
    "chapiçarde": "chapiçar",
    "chapiçardes": "chapiçar",
    "chapiçare": "chapiçar",
    "chapiçarei": "chapiçar",
    "chapiçareis": "chapiçar",
    "chapiçarem": "chapiçar",
    "chapiçaremos": "chapiçar",
    "chapiçares": "chapiçar",
    "chapiçaria": "chapiçar",
    "chapiçariam": "chapiçar",
    "chapiçarias": "chapiçar",
    "chapiçarmo": "chapiçar",
    "chapiçarmos": "chapiçar",
    "chapiçará": "chapiçar",
    "chapiçarás": "chapiçar",
    "chapiçarão": "chapiçar",
    "chapiçaríamos": "chapiçar",
    "chapiçaríeis": "chapiçar",
    "chapiças": "chapiçar",
    "chapiçasse": "chapiçar",
    "chapiçassem": "chapiçar",
    "chapiçasses": "chapiçar",
    "chapiçaste": "chapiçar",
    "chapiçastes": "chapiçar",
    "chapiçava": "chapiçar",
    "chapiçavam": "chapiçar",
    "chapiçavas": "chapiçar",
    "chapiço": "chapiçar",
    "chapiçou": "chapiçar",
    "chapiçá": "chapiçar",
    "chapiçámo": "chapiçar",
    "chapiçámos": "chapiçar",
    "chapiçáramo": "chapiçar",
    "chapiçáramos": "chapiçar",
    "chapiçárei": "chapiçar",
    "chapiçáreis": "chapiçar",
    "chapiçásseis": "chapiçar",
    "chapiçássemos": "chapiçar",
    "chapiçávamo": "chapiçar",
    "chapiçávamos": "chapiçar",
    "chapiçávei": "chapiçar",
    "chapiçáveis": "chapiçar",
    "chapo": "chapar",
    "chapoda": "chapodar",
    "chapodada": "chapodar",
    "chapodadas": "chapodar",
    "chapodado": "chapodar",
    "chapodados": "chapodar",
    "chapodai": "chapodar",
    "chapodais": "chapodar",
    "chapodam": "chapodar",
    "chapodamo": "chapodar",
    "chapodamos": "chapodar",
    "chapodando": "chapodar",
    "chapodara": "chapodar",
    "chapodaram": "chapodar",
    "chapodaras": "chapodar",
    "chapodarde": "chapodar",
    "chapodardes": "chapodar",
    "chapodare": "chapodar",
    "chapodarei": "chapodar",
    "chapodareis": "chapodar",
    "chapodarem": "chapodar",
    "chapodaremos": "chapodar",
    "chapodares": "chapodar",
    "chapodaria": "chapodar",
    "chapodariam": "chapodar",
    "chapodarias": "chapodar",
    "chapodarmo": "chapodar",
    "chapodarmos": "chapodar",
    "chapodará": "chapodar",
    "chapodarás": "chapodar",
    "chapodarão": "chapodar",
    "chapodaríamos": "chapodar",
    "chapodaríeis": "chapodar",
    "chapodas": "chapodar",
    "chapodasse": "chapodar",
    "chapodassem": "chapodar",
    "chapodasses": "chapodar",
    "chapodaste": "chapodar",
    "chapodastes": "chapodar",
    "chapodava": "chapodar",
    "chapodavam": "chapodar",
    "chapodavas": "chapodar",
    "chapode": "chapodar",
    "chapodei": "chapodar",
    "chapodeis": "chapodar",
    "chapodem": "chapodar",
    "chapodemo": "chapodar",
    "chapodemos": "chapodar",
    "chapodes": "chapodar",
    "chapodo": "chapodar",
    "chapodou": "chapodar",
    "chapodá": "chapodar",
    "chapodámo": "chapodar",
    "chapodámos": "chapodar",
    "chapodáramo": "chapodar",
    "chapodáramos": "chapodar",
    "chapodárei": "chapodar",
    "chapodáreis": "chapodar",
    "chapodásseis": "chapodar",
    "chapodássemos": "chapodar",
    "chapodávamo": "chapodar",
    "chapodávamos": "chapodar",
    "chapodávei": "chapodar",
    "chapodáveis": "chapodar",
    "chapoiradas": "chapoirada",
    "chapota": "chapotar",
    "chapotada": "chapotar",
    "chapotadas": "chapotar",
    "chapotado": "chapotar",
    "chapotados": "chapotar",
    "chapotai": "chapotar",
    "chapotais": "chapotar",
    "chapotam": "chapotar",
    "chapotamentos": "chapotamento",
    "chapotamo": "chapotar",
    "chapotamos": "chapotar",
    "chapotando": "chapotar",
    "chapotara": "chapotar",
    "chapotaram": "chapotar",
    "chapotaras": "chapotar",
    "chapotarde": "chapotar",
    "chapotardes": "chapotar",
    "chapotare": "chapotar",
    "chapotarei": "chapotar",
    "chapotareis": "chapotar",
    "chapotarem": "chapotar",
    "chapotaremos": "chapotar",
    "chapotares": "chapotar",
    "chapotaria": "chapotar",
    "chapotariam": "chapotar",
    "chapotarias": "chapotar",
    "chapotarmo": "chapotar",
    "chapotarmos": "chapotar",
    "chapotará": "chapotar",
    "chapotarás": "chapotar",
    "chapotarão": "chapotar",
    "chapotaríamos": "chapotar",
    "chapotaríeis": "chapotar",
    "chapotas": "chapotar",
    "chapotasse": "chapotar",
    "chapotassem": "chapotar",
    "chapotasses": "chapotar",
    "chapotaste": "chapotar",
    "chapotastes": "chapotar",
    "chapotava": "chapotar",
    "chapotavam": "chapotar",
    "chapotavas": "chapotar",
    "chapote": "chapotar",
    "chapotei": "chapotar",
    "chapoteis": "chapotar",
    "chapotem": "chapotar",
    "chapotemo": "chapotar",
    "chapotemos": "chapotar",
    "chapotes": "chapotar",
    "chapoto": "chapotar",
    "chapotou": "chapotar",
    "chapotá": "chapotar",
    "chapotámo": "chapotar",
    "chapotámos": "chapotar",
    "chapotáramo": "chapotar",
    "chapotáramos": "chapotar",
    "chapotárei": "chapotar",
    "chapotáreis": "chapotar",
    "chapotásseis": "chapotar",
    "chapotássemos": "chapotar",
    "chapotávamo": "chapotar",
    "chapotávamos": "chapotar",
    "chapotávei": "chapotar",
    "chapotáveis": "chapotar",
    "chapou": "chapar",
    "chaprona": "chaprão",
    "chapronas": "chaprão",
    "chaprões": "chaprão",
    "chapuce": "chapuçar",
    "chapucei": "chapuçar",
    "chapuceis": "chapuçar",
    "chapucem": "chapuçar",
    "chapucemo": "chapuçar",
    "chapucemos": "chapuçar",
    "chapuces": "chapuçar",
    "chapuza": "chapuzar",
    "chapuzada": "chapuzar",
    "chapuzadas": "chapuzar",
    "chapuzado": "chapuzar",
    "chapuzados": "chapuzar",
    "chapuzai": "chapuzar",
    "chapuzais": "chapuzar",
    "chapuzam": "chapuzar",
    "chapuzamo": "chapuzar",
    "chapuzamos": "chapuzar",
    "chapuzando": "chapuzar",
    "chapuzara": "chapuzar",
    "chapuzaram": "chapuzar",
    "chapuzaras": "chapuzar",
    "chapuzarde": "chapuzar",
    "chapuzardes": "chapuzar",
    "chapuzare": "chapuzar",
    "chapuzarei": "chapuzar",
    "chapuzareis": "chapuzar",
    "chapuzarem": "chapuzar",
    "chapuzaremos": "chapuzar",
    "chapuzares": "chapuzar",
    "chapuzaria": "chapuzar",
    "chapuzariam": "chapuzar",
    "chapuzarias": "chapuzar",
    "chapuzarmo": "chapuzar",
    "chapuzarmos": "chapuzar",
    "chapuzará": "chapuzar",
    "chapuzarás": "chapuzar",
    "chapuzarão": "chapuzar",
    "chapuzaríamos": "chapuzar",
    "chapuzaríeis": "chapuzar",
    "chapuzas": "chapuzar",
    "chapuzasse": "chapuzar",
    "chapuzassem": "chapuzar",
    "chapuzasses": "chapuzar",
    "chapuzaste": "chapuzar",
    "chapuzastes": "chapuzar",
    "chapuzava": "chapuzar",
    "chapuzavam": "chapuzar",
    "chapuzavas": "chapuzar",
    "chapuze": "chapuzar",
    "chapuzei": "chapuzar",
    "chapuzeis": "chapuzar",
    "chapuzem": "chapuzar",
    "chapuzemo": "chapuzar",
    "chapuzemos": "chapuzar",
    "chapuzes": "chapuzar",
    "chapuzo": "chapuzar",
    "chapuzou": "chapuzar",
    "chapuzá": "chapuzar",
    "chapuzámo": "chapuzar",
    "chapuzámos": "chapuzar",
    "chapuzáramo": "chapuzar",
    "chapuzáramos": "chapuzar",
    "chapuzárei": "chapuzar",
    "chapuzáreis": "chapuzar",
    "chapuzásseis": "chapuzar",
    "chapuzássemos": "chapuzar",
    "chapuzávamo": "chapuzar",
    "chapuzávamos": "chapuzar",
    "chapuzávei": "chapuzar",
    "chapuzáveis": "chapuzar",
    "chapuça": "chapuçar",
    "chapuçada": "chapuçar",
    "chapuçadas": "chapuçar",
    "chapuçado": "chapuçar",
    "chapuçados": "chapuçar",
    "chapuçai": "chapuçar",
    "chapuçais": "chapuçar",
    "chapuçam": "chapuçar",
    "chapuçamo": "chapuçar",
    "chapuçamos": "chapuçar",
    "chapuçando": "chapuçar",
    "chapuçara": "chapuçar",
    "chapuçaram": "chapuçar",
    "chapuçaras": "chapuçar",
    "chapuçarde": "chapuçar",
    "chapuçardes": "chapuçar",
    "chapuçare": "chapuçar",
    "chapuçarei": "chapuçar",
    "chapuçareis": "chapuçar",
    "chapuçarem": "chapuçar",
    "chapuçaremos": "chapuçar",
    "chapuçares": "chapuçar",
    "chapuçaria": "chapuçar",
    "chapuçariam": "chapuçar",
    "chapuçarias": "chapuçar",
    "chapuçarmo": "chapuçar",
    "chapuçarmos": "chapuçar",
    "chapuçará": "chapuçar",
    "chapuçarás": "chapuçar",
    "chapuçarão": "chapuçar",
    "chapuçaríamos": "chapuçar",
    "chapuçaríeis": "chapuçar",
    "chapuças": "chapuçar",
    "chapuçasse": "chapuçar",
    "chapuçassem": "chapuçar",
    "chapuçasses": "chapuçar",
    "chapuçaste": "chapuçar",
    "chapuçastes": "chapuçar",
    "chapuçava": "chapuçar",
    "chapuçavam": "chapuçar",
    "chapuçavas": "chapuçar",
    "chapuço": "chapuçar",
    "chapuçou": "chapuçar",
    "chapuçá": "chapuçar",
    "chapuçámo": "chapuçar",
    "chapuçámos": "chapuçar",
    "chapuçáramo": "chapuçar",
    "chapuçáramos": "chapuçar",
    "chapuçárei": "chapuçar",
    "chapuçáreis": "chapuçar",
    "chapuçásseis": "chapuçar",
    "chapuçássemos": "chapuçar",
    "chapuçávamo": "chapuçar",
    "chapuçávamos": "chapuçar",
    "chapuçávei": "chapuçar",
    "chapuçáveis": "chapuçar",
    "chapá": "chapar",
    "chapámo": "chapar",
    "chapámos": "chapar",
    "chapáramo": "chapar",
    "chapáramos": "chapar",
    "chapárei": "chapar",
    "chapáreis": "chapar",
    "chapásseis": "chapar",
    "chapássemos": "chapar",
    "chapávamo": "chapar",
    "chapávamos": "chapar",
    "chapávei": "chapar",
    "chapáveis": "chapar",
    "chapéus": "chapéu",
    "chaquiças": "chaquiça",
    "charabascais": "charabascal",
    "charabascas": "charabasca",
    "charabascos": "charabasco",
    "charabasqueiros": "charabasqueiro",
    "charabilhanos": "charabilhano",
    "charabãs": "charabã",
    "charadas": "charada",
    "charadeada": "charadear",
    "charadeadas": "charadear",
    "charadeado": "charadear",
    "charadeados": "charadear",
    "charadeai": "charadear",
    "charadeais": "charadear",
    "charadeamo": "charadear",
    "charadeamos": "charadear",
    "charadeando": "charadear",
    "charadeara": "charadear",
    "charadearam": "charadear",
    "charadearas": "charadear",
    "charadeardes": "charadear",
    "charadearei": "charadear",
    "charadeareis": "charadear",
    "charadearem": "charadear",
    "charadearemos": "charadear",
    "charadeares": "charadear",
    "charadearia": "charadear",
    "charadeariam": "charadear",
    "charadearias": "charadear",
    "charadearmo": "charadear",
    "charadearmos": "charadear",
    "charadeará": "charadear",
    "charadearás": "charadear",
    "charadearão": "charadear",
    "charadearíamos": "charadear",
    "charadearíeis": "charadear",
    "charadeasse": "charadear",
    "charadeassem": "charadear",
    "charadeasses": "charadear",
    "charadeaste": "charadear",
    "charadeastes": "charadear",
    "charadeava": "charadear",
    "charadeavam": "charadear",
    "charadeavas": "charadear",
    "charadeei": "charadear",
    "charadeeis": "charadear",
    "charadeemo": "charadear",
    "charadeemos": "charadear",
    "charadeia": "charadear",
    "charadeiam": "charadear",
    "charadeias": "charadear",
    "charadeie": "charadear",
    "charadeiem": "charadear",
    "charadeies": "charadear",
    "charadeio": "charadear",
    "charadeou": "charadear",
    "charadeámo": "charadear",
    "charadeámos": "charadear",
    "charadeáramo": "charadear",
    "charadeáramos": "charadear",
    "charadeáreis": "charadear",
    "charadeásseis": "charadear",
    "charadeássemos": "charadear",
    "charadeávamo": "charadear",
    "charadeávamos": "charadear",
    "charadeáveis": "charadear",
    "charadicidas": "charadicida",
    "charadismos": "charadismo",
    "charadistas": "charadista",
    "charadomaníaca": "charadomaníaco",
    "charadomaníacas": "charadomaníaco",
    "charadomaníacos": "charadomaníaco",
    "charadística": "charadístico",
    "charadísticas": "charadístico",
    "charadísticos": "charadístico",
    "charambas": "charamba",
    "charamelas": "charamela",
    "charameleira": "charameleiro",
    "charameleiras": "charameleiro",
    "charameleiros": "charameleiro",
    "charangas": "charanga",
    "charangueira": "charangueiro",
    "charangueiras": "charangueiro",
    "charangueiros": "charangueiro",
    "charas": "chara",
    "charavascais": "charavascal",
    "charavascas": "charavasca",
    "charavascos": "charavasco",
    "charavasqueiros": "charavasqueiro",
    "charcas": "charca",
    "charcos": "charco",
    "charcosa": "charcoso",
    "charcosas": "charcoso",
    "charcosos": "charcoso",
    "charcozinho": "charco",
    "charcozinhos": "charco",
    "charcozito": "charco",
    "charcozitos": "charco",
    "charcutarias": "charcutaria",
    "charcuteira": "charcuteiro",
    "charcuteiras": "charcuteiro",
    "charcuteiros": "charcuteiro",
    "charivaris": "charivari",
    "charla": "charlar",
    "charlada": "charlar",
    "charladas": "charlar",
    "charlado": "charlar",
    "charladora": "charlador",
    "charladoras": "charlador",
    "charladores": "charlador",
    "charlados": "charlar",
    "charlai": "charlar",
    "charlais": "charlar",
    "charlam": "charlar",
    "charlamo": "charlar",
    "charlamos": "charlar",
    "charlando": "charlar",
    "charlara": "charlar",
    "charlaram": "charlar",
    "charlaras": "charlar",
    "charlardes": "charlar",
    "charlarei": "charlar",
    "charlareis": "charlar",
    "charlarem": "charlar",
    "charlaremos": "charlar",
    "charlares": "charlar",
    "charlaria": "charlar",
    "charlariam": "charlar",
    "charlarias": "charlar",
    "charlarmo": "charlar",
    "charlarmos": "charlar",
    "charlará": "charlar",
    "charlarás": "charlar",
    "charlarão": "charlar",
    "charlaríamos": "charlar",
    "charlaríeis": "charlar",
    "charlas": "charlar",
    "charlasse": "charlar",
    "charlassem": "charlar",
    "charlasses": "charlar",
    "charlaste": "charlar",
    "charlastes": "charlar",
    "charlatanarias": "charlatanaria",
    "charlataneada": "charlatanear",
    "charlataneadas": "charlatanear",
    "charlataneado": "charlatanear",
    "charlataneados": "charlatanear",
    "charlataneai": "charlatanear",
    "charlataneais": "charlatanear",
    "charlataneamo": "charlatanear",
    "charlataneamos": "charlatanear",
    "charlataneando": "charlatanear",
    "charlataneara": "charlatanear",
    "charlatanearam": "charlatanear",
    "charlatanearas": "charlatanear",
    "charlatanearde": "charlatanear",
    "charlataneardes": "charlatanear",
    "charlataneare": "charlatanear",
    "charlatanearei": "charlatanear",
    "charlataneareis": "charlatanear",
    "charlatanearem": "charlatanear",
    "charlatanearemos": "charlatanear",
    "charlataneares": "charlatanear",
    "charlatanearia": "charlatanear",
    "charlataneariam": "charlatanear",
    "charlatanearias": "charlatanear",
    "charlatanearmo": "charlatanear",
    "charlatanearmos": "charlatanear",
    "charlataneará": "charlatanear",
    "charlatanearás": "charlatanear",
    "charlatanearão": "charlatanear",
    "charlatanearíamos": "charlatanear",
    "charlatanearíeis": "charlatanear",
    "charlataneasse": "charlatanear",
    "charlataneassem": "charlatanear",
    "charlataneasses": "charlatanear",
    "charlataneaste": "charlatanear",
    "charlataneastes": "charlatanear",
    "charlataneava": "charlatanear",
    "charlataneavam": "charlatanear",
    "charlataneavas": "charlatanear",
    "charlataneei": "charlatanear",
    "charlataneeis": "charlatanear",
    "charlataneemo": "charlatanear",
    "charlataneemos": "charlatanear",
    "charlataneia": "charlatanear",
    "charlataneiam": "charlatanear",
    "charlataneias": "charlatanear",
    "charlataneie": "charlatanear",
    "charlataneiem": "charlatanear",
    "charlataneies": "charlatanear",
    "charlataneio": "charlatanear",
    "charlataneou": "charlatanear",
    "charlataneá": "charlatanear",
    "charlataneámo": "charlatanear",
    "charlataneámos": "charlatanear",
    "charlataneáramo": "charlatanear",
    "charlataneáramos": "charlatanear",
    "charlataneárei": "charlatanear",
    "charlataneáreis": "charlatanear",
    "charlataneásseis": "charlatanear",
    "charlataneássemos": "charlatanear",
    "charlataneávamo": "charlatanear",
    "charlataneávamos": "charlatanear",
    "charlataneávei": "charlatanear",
    "charlataneáveis": "charlatanear",
    "charlatanices": "charlatanice",
    "charlatanismos": "charlatanismo",
    "charlatarias": "charlataria",
    "charlateiras": "charlateira",
    "charlatona": "charlatão",
    "charlatonas": "charlatão",
    "charlatões": "charlatão",
    "charlava": "charlar",
    "charlavam": "charlar",
    "charlavas": "charlar",
    "charle": "charlar",
    "charlei": "charlar",
    "charleis": "charlar",
    "charlem": "charlar",
    "charlemo": "charlar",
    "charlemos": "charlar",
    "charles": "charlar",
    "charlo": "charlar",
    "charlotas": "charlota",
    "charlotes": "charlote",
    "charlou": "charlar",
    "charlámo": "charlar",
    "charlámos": "charlar",
    "charláramo": "charlar",
    "charláramos": "charlar",
    "charláreis": "charlar",
    "charlásseis": "charlar",
    "charlássemos": "charlar",
    "charlávamo": "charlar",
    "charlávamos": "charlar",
    "charláveis": "charlar",
    "charmes": "charme",
    "charmontiana": "charmontiano",
    "charmontianas": "charmontiano",
    "charmontianos": "charmontiano",
    "charmosa": "charmoso",
    "charmosas": "charmoso",
    "charmosos": "charmoso",
    "charmosíssima": "charmoso",
    "charmosíssimas": "charmoso",
    "charmosíssimo": "charmoso",
    "charmosíssimos": "charmoso",
    "charnecas": "charneca",
    "charnecos": "charneco",
    "charneiras": "charneira",
    "charnequeira": "charnequeiro",
    "charnequeiras": "charnequeiro",
    "charnequeiros": "charnequeiro",
    "charnequenha": "charnequenho",
    "charnequenhas": "charnequenho",
    "charnequenhos": "charnequenho",
    "charnoquitos": "charnoquito",
    "charoa": "charoar",
    "charoada": "charoar",
    "charoadas": "charoar",
    "charoado": "charoar",
    "charoados": "charoar",
    "charoai": "charoar",
    "charoais": "charoar",
    "charoam": "charoar",
    "charoamo": "charoar",
    "charoamos": "charoar",
    "charoando": "charoar",
    "charoara": "charoar",
    "charoaram": "charoar",
    "charoaras": "charoar",
    "charoarde": "charoar",
    "charoardes": "charoar",
    "charoare": "charoar",
    "charoarei": "charoar",
    "charoareis": "charoar",
    "charoarem": "charoar",
    "charoaremos": "charoar",
    "charoares": "charoar",
    "charoaria": "charoar",
    "charoariam": "charoar",
    "charoarias": "charoar",
    "charoarmo": "charoar",
    "charoarmos": "charoar",
    "charoará": "charoar",
    "charoarás": "charoar",
    "charoarão": "charoar",
    "charoaríamos": "charoar",
    "charoaríeis": "charoar",
    "charoas": "charoar",
    "charoasse": "charoar",
    "charoassem": "charoar",
    "charoasses": "charoar",
    "charoaste": "charoar",
    "charoastes": "charoar",
    "charoava": "charoar",
    "charoavam": "charoar",
    "charoavas": "charoar",
    "charoe": "charoar",
    "charoei": "charoar",
    "charoeis": "charoar",
    "charoem": "charoar",
    "charoemo": "charoar",
    "charoemos": "charoar",
    "charoes": "charoar",
    "charolas": "charola",
    "charoleira": "charoleiro",
    "charoleiras": "charoleiro",
    "charoleiros": "charoleiro",
    "charoo": "charoar",
    "charoou": "charoar",
    "charoá": "charoar",
    "charoámo": "charoar",
    "charoámos": "charoar",
    "charoáramo": "charoar",
    "charoáramos": "charoar",
    "charoárei": "charoar",
    "charoáreis": "charoar",
    "charoásseis": "charoar",
    "charoássemos": "charoar",
    "charoávamo": "charoar",
    "charoávamos": "charoar",
    "charoávei": "charoar",
    "charoáveis": "charoar",
    "charpas": "charpa",
    "charqueada": "charquear",
    "charqueadas": "charquear",
    "charqueado": "charquear",
    "charqueadora": "charqueador",
    "charqueadoras": "charqueador",
    "charqueadores": "charqueador",
    "charqueados": "charquear",
    "charqueai": "charquear",
    "charqueais": "charquear",
    "charqueamo": "charquear",
    "charqueamos": "charquear",
    "charqueando": "charquear",
    "charqueara": "charquear",
    "charquearam": "charquear",
    "charquearas": "charquear",
    "charquearde": "charquear",
    "charqueardes": "charquear",
    "charqueare": "charquear",
    "charquearei": "charquear",
    "charqueareis": "charquear",
    "charquearem": "charquear",
    "charquearemos": "charquear",
    "charqueares": "charquear",
    "charquearia": "charquear",
    "charqueariam": "charquear",
    "charquearias": "charquear",
    "charquearmo": "charquear",
    "charquearmos": "charquear",
    "charqueará": "charquear",
    "charquearás": "charquear",
    "charquearão": "charquear",
    "charquearíamos": "charquear",
    "charquearíeis": "charquear",
    "charqueasse": "charquear",
    "charqueassem": "charquear",
    "charqueasses": "charquear",
    "charqueaste": "charquear",
    "charqueastes": "charquear",
    "charqueava": "charquear",
    "charqueavam": "charquear",
    "charqueavas": "charquear",
    "charqueações": "charqueação",
    "charqueei": "charquear",
    "charqueeis": "charquear",
    "charqueemo": "charquear",
    "charqueemos": "charquear",
    "charqueia": "charquear",
    "charqueiam": "charquear",
    "charqueias": "charquear",
    "charqueie": "charquear",
    "charqueiem": "charquear",
    "charqueies": "charquear",
    "charqueio": "charquear",
    "charqueios": "charqueio",
    "charqueou": "charquear",
    "charques": "charque",
    "charqueá": "charquear",
    "charqueámo": "charquear",
    "charqueámos": "charquear",
    "charqueáramo": "charquear",
    "charqueáramos": "charquear",
    "charqueárei": "charquear",
    "charqueáreis": "charquear",
    "charqueásseis": "charquear",
    "charqueássemos": "charquear",
    "charqueávamo": "charquear",
    "charqueávamos": "charquear",
    "charqueávei": "charquear",
    "charqueáveis": "charquear",
    "charquinho": "charco",
    "charquinhos": "charco",
    "charquito": "charco",
    "charquitos": "charco",
    "charra": "charro",
    "charranas": "charrana",
    "charranos": "charrano",
    "charras": "charro",
    "charrasca": "charrasco",
    "charrascas": "charrasco",
    "charrascos": "charrasco",
    "charrasqueiras": "charrasqueira",
    "charravascais": "charravascal",
    "charrelas": "charrela",
    "charretes": "charrete",
    "charrinho": "charro",
    "charrinhos": "charro",
    "charrisca": "charriscar",
    "charriscada": "charriscar",
    "charriscadas": "charriscar",
    "charriscado": "charriscar",
    "charriscados": "charriscar",
    "charriscai": "charriscar",
    "charriscais": "charriscar",
    "charriscam": "charriscar",
    "charriscamo": "charriscar",
    "charriscamos": "charriscar",
    "charriscando": "charriscar",
    "charriscara": "charriscar",
    "charriscaram": "charriscar",
    "charriscaras": "charriscar",
    "charriscarde": "charriscar",
    "charriscardes": "charriscar",
    "charriscare": "charriscar",
    "charriscarei": "charriscar",
    "charriscareis": "charriscar",
    "charriscarem": "charriscar",
    "charriscaremos": "charriscar",
    "charriscares": "charriscar",
    "charriscaria": "charriscar",
    "charriscariam": "charriscar",
    "charriscarias": "charriscar",
    "charriscarmo": "charriscar",
    "charriscarmos": "charriscar",
    "charriscará": "charriscar",
    "charriscarás": "charriscar",
    "charriscarão": "charriscar",
    "charriscaríamos": "charriscar",
    "charriscaríeis": "charriscar",
    "charriscas": "charriscar",
    "charriscasse": "charriscar",
    "charriscassem": "charriscar",
    "charriscasses": "charriscar",
    "charriscaste": "charriscar",
    "charriscastes": "charriscar",
    "charriscava": "charriscar",
    "charriscavam": "charriscar",
    "charriscavas": "charriscar",
    "charrisco": "charriscar",
    "charriscou": "charriscar",
    "charriscá": "charriscar",
    "charriscámo": "charriscar",
    "charriscámos": "charriscar",
    "charriscáramo": "charriscar",
    "charriscáramos": "charriscar",
    "charriscárei": "charriscar",
    "charriscáreis": "charriscar",
    "charriscásseis": "charriscar",
    "charriscássemos": "charriscar",
    "charriscávamo": "charriscar",
    "charriscávamos": "charriscar",
    "charriscávei": "charriscar",
    "charriscáveis": "charriscar",
    "charrisque": "charriscar",
    "charrisquei": "charriscar",
    "charrisqueis": "charriscar",
    "charrisquem": "charriscar",
    "charrisquemo": "charriscar",
    "charrisquemos": "charriscar",
    "charrisques": "charriscar",
    "charrito": "charro",
    "charritos": "charro",
    "charros": "charro",
    "charrua": "charruar",
    "charruada": "charruar",
    "charruadas": "charruar",
    "charruadeiras": "charruadeira",
    "charruado": "charruar",
    "charruados": "charruar",
    "charruai": "charruar",
    "charruais": "charruar",
    "charruam": "charruar",
    "charruamo": "charruar",
    "charruamos": "charruar",
    "charruando": "charruar",
    "charruara": "charruar",
    "charruaram": "charruar",
    "charruaras": "charruar",
    "charruarde": "charruar",
    "charruardes": "charruar",
    "charruare": "charruar",
    "charruarei": "charruar",
    "charruareis": "charruar",
    "charruarem": "charruar",
    "charruaremos": "charruar",
    "charruares": "charruar",
    "charruaria": "charruar",
    "charruariam": "charruar",
    "charruarias": "charruar",
    "charruarmo": "charruar",
    "charruarmos": "charruar",
    "charruará": "charruar",
    "charruarás": "charruar",
    "charruarão": "charruar",
    "charruaríamos": "charruar",
    "charruaríeis": "charruar",
    "charruas": "charruar",
    "charruasse": "charruar",
    "charruassem": "charruar",
    "charruasses": "charruar",
    "charruaste": "charruar",
    "charruastes": "charruar",
    "charruava": "charruar",
    "charruavam": "charruar",
    "charruavas": "charruar",
    "charrue": "charruar",
    "charruecos": "charrueco",
    "charruei": "charruar",
    "charrueis": "charruar",
    "charruem": "charruar",
    "charruemo": "charruar",
    "charruemos": "charruar",
    "charrues": "charruar",
    "charruo": "charruar",
    "charruou": "charruar",
    "charruá": "charruar",
    "charruámo": "charruar",
    "charruámos": "charruar",
    "charruáramo": "charruar",
    "charruáramos": "charruar",
    "charruárei": "charruar",
    "charruáreis": "charruar",
    "charruásseis": "charruar",
    "charruássemos": "charruar",
    "charruávamo": "charruar",
    "charruávamos": "charruar",
    "charruávei": "charruar",
    "charruáveis": "charruar",
    "charteres": "charter",
    "charters": "charter",
    "charutarias": "charutaria",
    "charuteira": "charuteiro",
    "charuteiras": "charuteiro",
    "charuteiros": "charuteiro",
    "charutinho": "charuto",
    "charutinhos": "charuto",
    "charutito": "charuto",
    "charutitos": "charuto",
    "charutos": "charuto",
    "charões": "charão",
    "chascas": "chasca",
    "chascos": "chasco",
    "chaspas": "chaspa",
    "chasqueada": "chasquear",
    "chasqueadas": "chasquear",
    "chasqueado": "chasquear",
    "chasqueadora": "chasqueador",
    "chasqueadoras": "chasqueador",
    "chasqueadores": "chasqueador",
    "chasqueados": "chasquear",
    "chasqueai": "chasquear",
    "chasqueais": "chasquear",
    "chasqueamo": "chasquear",
    "chasqueamos": "chasquear",
    "chasqueando": "chasquear",
    "chasqueara": "chasquear",
    "chasquearam": "chasquear",
    "chasquearas": "chasquear",
    "chasquearde": "chasquear",
    "chasqueardes": "chasquear",
    "chasqueare": "chasquear",
    "chasquearei": "chasquear",
    "chasqueareis": "chasquear",
    "chasquearem": "chasquear",
    "chasquearemos": "chasquear",
    "chasqueares": "chasquear",
    "chasquearia": "chasquear",
    "chasqueariam": "chasquear",
    "chasquearias": "chasquear",
    "chasquearmo": "chasquear",
    "chasquearmos": "chasquear",
    "chasqueará": "chasquear",
    "chasquearás": "chasquear",
    "chasquearão": "chasquear",
    "chasquearíamos": "chasquear",
    "chasquearíeis": "chasquear",
    "chasqueasse": "chasquear",
    "chasqueassem": "chasquear",
    "chasqueasses": "chasquear",
    "chasqueaste": "chasquear",
    "chasqueastes": "chasquear",
    "chasqueava": "chasquear",
    "chasqueavam": "chasquear",
    "chasqueavas": "chasquear",
    "chasqueei": "chasquear",
    "chasqueeis": "chasquear",
    "chasqueemo": "chasquear",
    "chasqueemos": "chasquear",
    "chasqueia": "chasquear",
    "chasqueiam": "chasquear",
    "chasqueias": "chasquear",
    "chasqueie": "chasquear",
    "chasqueiem": "chasquear",
    "chasqueies": "chasquear",
    "chasqueio": "chasquear",
    "chasqueios": "chasqueio",
    "chasqueou": "chasquear",
    "chasqueá": "chasquear",
    "chasqueámo": "chasquear",
    "chasqueámos": "chasquear",
    "chasqueáramo": "chasquear",
    "chasqueáramos": "chasquear",
    "chasqueárei": "chasquear",
    "chasqueáreis": "chasquear",
    "chasqueásseis": "chasquear",
    "chasqueássemos": "chasquear",
    "chasqueávamo": "chasquear",
    "chasqueávamos": "chasquear",
    "chasqueávei": "chasquear",
    "chasqueáveis": "chasquear",
    "chasquilhos": "chasquilho",
    "chassis": "chassi",
    "chata": "chato",
    "chatas": "chato",
    "chatazinha": "chato",
    "chatazinhas": "chato",
    "chatazita": "chato",
    "chatazitas": "chato",
    "chateada": "chatear",
    "chateadas": "chatear",
    "chateado": "chatear",
    "chateados": "chatear",
    "chateadíssima": "chateado",
    "chateadíssimas": "chateado",
    "chateadíssimo": "chateado",
    "chateadíssimos": "chateado",
    "chateai": "chatear",
    "chateais": "chatear",
    "chateamentos": "chateamento",
    "chateamo": "chatear",
    "chateamos": "chatear",
    "chateando": "chatear",
    "chateara": "chatear",
    "chatearam": "chatear",
    "chatearas": "chatear",
    "chatearde": "chatear",
    "chateardes": "chatear",
    "chateare": "chatear",
    "chatearei": "chatear",
    "chateareis": "chatear",
    "chatearem": "chatear",
    "chatearemos": "chatear",
    "chateares": "chatear",
    "chatearia": "chatear",
    "chateariam": "chatear",
    "chatearias": "chatear",
    "chatearmo": "chatear",
    "chatearmos": "chatear",
    "chateará": "chatear",
    "chatearás": "chatear",
    "chatearão": "chatear",
    "chatearíamos": "chatear",
    "chatearíeis": "chatear",
    "chateasse": "chatear",
    "chateassem": "chatear",
    "chateasses": "chatear",
    "chateaste": "chatear",
    "chateastes": "chatear",
    "chateava": "chatear",
    "chateavam": "chatear",
    "chateavas": "chatear",
    "chateações": "chateação",
    "chateei": "chatear",
    "chateeis": "chatear",
    "chateemo": "chatear",
    "chateemos": "chatear",
    "chateia": "chatear",
    "chateiam": "chatear",
    "chateias": "chatear",
    "chateie": "chatear",
    "chateiem": "chatear",
    "chateies": "chatear",
    "chateio": "chatear",
    "chateiras": "chateira",
    "chateou": "chatear",
    "chatezas": "chateza",
    "chateá": "chatear",
    "chateámo": "chatear",
    "chateámos": "chatear",
    "chateáramo": "chatear",
    "chateáramos": "chatear",
    "chateárei": "chatear",
    "chateáreis": "chatear",
    "chateásseis": "chatear",
    "chateássemos": "chatear",
    "chateávamo": "chatear",
    "chateávamos": "chatear",
    "chateávei": "chatear",
    "chateáveis": "chatear",
    "chatices": "chatice",
    "chatinadora": "chatinador",
    "chatinadoras": "chatinador",
    "chatinadores": "chatinador",
    "chatins": "chatim",
    "chatos": "chato",
    "chatozinho": "chato",
    "chatozinhos": "chato",
    "chatozito": "chato",
    "chatozitos": "chato",
    "chaturas": "chatura",
    "chatíssima": "chato",
    "chatíssimas": "chato",
    "chatíssimo": "chato",
    "chatíssimos": "chato",
    "chaudeis": "chaudel",
    "chaus": "chau",
    "chauvinismos": "chauvinismo",
    "chauvinistas": "chauvinista",
    "chauzinho": "chau",
    "chauzinhos": "chau",
    "chauzito": "chau",
    "chauzitos": "chau",
    "chavarias": "chavaria",
    "chavasca": "chavasco",
    "chavascada": "chavascar",
    "chavascadas": "chavascar",
    "chavascado": "chavascar",
    "chavascados": "chavascar",
    "chavascai": "chavascar",
    "chavascais": "chavascar",
    "chavascam": "chavascar",
    "chavascamo": "chavascar",
    "chavascamos": "chavascar",
    "chavascando": "chavascar",
    "chavascara": "chavascar",
    "chavascaram": "chavascar",
    "chavascaras": "chavascar",
    "chavascarde": "chavascar",
    "chavascardes": "chavascar",
    "chavascare": "chavascar",
    "chavascarei": "chavascar",
    "chavascareis": "chavascar",
    "chavascarem": "chavascar",
    "chavascaremos": "chavascar",
    "chavascares": "chavascar",
    "chavascaria": "chavascar",
    "chavascariam": "chavascar",
    "chavascarias": "chavascar",
    "chavascarmo": "chavascar",
    "chavascarmos": "chavascar",
    "chavascará": "chavascar",
    "chavascarás": "chavascar",
    "chavascarão": "chavascar",
    "chavascaríamos": "chavascar",
    "chavascaríeis": "chavascar",
    "chavascas": "chavasco",
    "chavascasse": "chavascar",
    "chavascassem": "chavascar",
    "chavascasses": "chavascar",
    "chavascaste": "chavascar",
    "chavascastes": "chavascar",
    "chavascava": "chavascar",
    "chavascavam": "chavascar",
    "chavascavas": "chavascar",
    "chavasco": "chavascar",
    "chavascos": "chavasco",
    "chavascou": "chavascar",
    "chavascá": "chavascar",
    "chavascámo": "chavascar",
    "chavascámos": "chavascar",
    "chavascáramo": "chavascar",
    "chavascáramos": "chavascar",
    "chavascárei": "chavascar",
    "chavascáreis": "chavascar",
    "chavascásseis": "chavascar",
    "chavascássemos": "chavascar",
    "chavascávamo": "chavascar",
    "chavascávamos": "chavascar",
    "chavascávei": "chavascar",
    "chavascáveis": "chavascar",
    "chavasque": "chavascar",
    "chavasquei": "chavascar",
    "chavasqueiras": "chavasqueira",
    "chavasqueiros": "chavasqueiro",
    "chavasqueis": "chavascar",
    "chavasquem": "chavascar",
    "chavasquemo": "chavascar",
    "chavasquemos": "chavascar",
    "chavasques": "chavascar",
    "chavasquices": "chavasquice",
    "chaveira": "chaveiro",
    "chaveiras": "chaveiro",
    "chaveiros": "chaveiro",
    "chaveirões": "chaveirão",
    "chavelhais": "chavelhal",
    "chavelhas": "chavelha",
    "chavelhos": "chavelho",
    "chavelhuda": "chavelhudo",
    "chavelhudas": "chavelhudo",
    "chavelhudos": "chavelhudo",
    "chavelhões": "chavelhão",
    "chavenazinha": "chávena",
    "chavenazinhas": "chávena",
    "chavenazita": "chávena",
    "chavenazitas": "chávena",
    "chaveninha": "chávena",
    "chaveninhas": "chávena",
    "chavenita": "chávena",
    "chavenitas": "chávena",
    "chaves": "chave",
    "chaveta": "chavetar",
    "chavetada": "chavetar",
    "chavetadas": "chavetar",
    "chavetado": "chavetar",
    "chavetados": "chavetar",
    "chavetai": "chavetar",
    "chavetais": "chavetar",
    "chavetam": "chavetar",
    "chavetamo": "chavetar",
    "chavetamos": "chavetar",
    "chavetando": "chavetar",
    "chavetara": "chavetar",
    "chavetaram": "chavetar",
    "chavetaras": "chavetar",
    "chavetarde": "chavetar",
    "chavetardes": "chavetar",
    "chavetare": "chavetar",
    "chavetarei": "chavetar",
    "chavetareis": "chavetar",
    "chavetarem": "chavetar",
    "chavetaremos": "chavetar",
    "chavetares": "chavetar",
    "chavetaria": "chavetar",
    "chavetariam": "chavetar",
    "chavetarias": "chavetar",
    "chavetarmo": "chavetar",
    "chavetarmos": "chavetar",
    "chavetará": "chavetar",
    "chavetarás": "chavetar",
    "chavetarão": "chavetar",
    "chavetaríamos": "chavetar",
    "chavetaríeis": "chavetar",
    "chavetas": "chavetar",
    "chavetasse": "chavetar",
    "chavetassem": "chavetar",
    "chavetasses": "chavetar",
    "chavetaste": "chavetar",
    "chavetastes": "chavetar",
    "chavetava": "chavetar",
    "chavetavam": "chavetar",
    "chavetavas": "chavetar",
    "chavete": "chavetar",
    "chavetei": "chavetar",
    "chaveteis": "chavetar",
    "chavetem": "chavetar",
    "chavetemo": "chavetar",
    "chavetemos": "chavetar",
    "chavetes": "chavetar",
    "chaveto": "chavetar",
    "chavetou": "chavetar",
    "chavetá": "chavetar",
    "chavetámo": "chavetar",
    "chavetámos": "chavetar",
    "chavetáramo": "chavetar",
    "chavetáramos": "chavetar",
    "chavetárei": "chavetar",
    "chavetáreis": "chavetar",
    "chavetásseis": "chavetar",
    "chavetássemos": "chavetar",
    "chavetávamo": "chavetar",
    "chavetávamos": "chavetar",
    "chavetávei": "chavetar",
    "chavetáveis": "chavetar",
    "chavezinha": "chave",
    "chavezinhas": "chave",
    "chavezita": "chave",
    "chavezitas": "chave",
    "chaviana": "chaviano",
    "chavianas": "chaviano",
    "chavianos": "chaviano",
    "chavinha": "chave",
    "chavinhas": "chave",
    "chavita": "chave",
    "chavitas": "chave",
    "chavos": "chavo",
    "chavádegos": "chavádego",
    "chavões": "chavão",
    "chazadas": "chazada",
    "chazeira": "chazeiro",
    "chazeiras": "chazeiro",
    "chazeiros": "chazeiro",
    "chazinho": "chá",
    "chazinhos": "chá",
    "chazito": "chá",
    "chazitos": "chá",
    "chaça": "chaçar",
    "chaçada": "chaçar",
    "chaçadas": "chaçar",
    "chaçado": "chaçar",
    "chaçados": "chaçar",
    "chaçai": "chaçar",
    "chaçais": "chaçar",
    "chaçam": "chaçar",
    "chaçamo": "chaçar",
    "chaçamos": "chaçar",
    "chaçando": "chaçar",
    "chaçara": "chaçar",
    "chaçaram": "chaçar",
    "chaçaras": "chaçar",
    "chaçardes": "chaçar",
    "chaçarei": "chaçar",
    "chaçareis": "chaçar",
    "chaçarem": "chaçar",
    "chaçaremos": "chaçar",
    "chaçares": "chaçar",
    "chaçaria": "chaçar",
    "chaçariam": "chaçar",
    "chaçarias": "chaçar",
    "chaçarmo": "chaçar",
    "chaçarmos": "chaçar",
    "chaçará": "chaçar",
    "chaçarás": "chaçar",
    "chaçarão": "chaçar",
    "chaçaríamos": "chaçar",
    "chaçaríeis": "chaçar",
    "chaças": "chaçar",
    "chaçasse": "chaçar",
    "chaçassem": "chaçar",
    "chaçasses": "chaçar",
    "chaçaste": "chaçar",
    "chaçastes": "chaçar",
    "chaçava": "chaçar",
    "chaçavam": "chaçar",
    "chaçavas": "chaçar",
    "chaço": "chaçar",
    "chaços": "chaço",
    "chaçou": "chaçar",
    "chaçámo": "chaçar",
    "chaçámos": "chaçar",
    "chaçáramo": "chaçar",
    "chaçáramos": "chaçar",
    "chaçáreis": "chaçar",
    "chaçásseis": "chaçar",
    "chaçássemos": "chaçar",
    "chaçávamo": "chaçar",
    "chaçávamos": "chaçar",
    "chaçáveis": "chaçar",
    "cheadas": "cheada",
    "checa": "checo",
    "checada": "checar",
    "checadas": "checar",
    "checado": "checar",
    "checados": "checar",
    "checai": "checar",
    "checais": "checar",
    "checam": "checar",
    "checamo": "checar",
    "checamos": "checar",
    "checando": "checar",
    "checara": "checar",
    "checaram": "checar",
    "checaras": "checar",
    "checarde": "checar",
    "checardes": "checar",
    "checare": "checar",
    "checarei": "checar",
    "checareis": "checar",
    "checarem": "checar",
    "checaremos": "checar",
    "checares": "checar",
    "checaria": "checar",
    "checariam": "checar",
    "checarias": "checar",
    "checarmo": "checar",
    "checarmos": "checar",
    "checará": "checar",
    "checarás": "checar",
    "checarão": "checar",
    "checaríamos": "checar",
    "checaríeis": "checar",
    "checas": "checo",
    "checasse": "checar",
    "checassem": "checar",
    "checasses": "checar",
    "checaste": "checar",
    "checastes": "checar",
    "checava": "checar",
    "checavam": "checar",
    "checavas": "checar",
    "checo": "checar",
    "checos": "checo",
    "checoslovaca": "checoslovaco",
    "checoslovacas": "checoslovaco",
    "checoslovacos": "checoslovaco",
    "checou": "checar",
    "checá": "checar",
    "checámo": "checar",
    "checámos": "checar",
    "checáramo": "checar",
    "checáramos": "checar",
    "checárei": "checar",
    "checáreis": "checar",
    "checásseis": "checar",
    "checássemos": "checar",
    "checávamo": "checar",
    "checávamos": "checar",
    "checávei": "checar",
    "checáveis": "checar",
    "chedas": "cheda",
    "chedeiros": "chedeiro",
    "chedes": "chede",
    "chedites": "chedite",
    "chedres": "chedre",
    "chefa": "chefe",
    "chefas": "chefe",
    "chefaturas": "chefatura",
    "chefeca": "chefeco",
    "chefecas": "chefeco",
    "chefecos": "chefeco",
    "chefes": "chefe",
    "chefeta": "chefete",
    "chefetas": "chefete",
    "chefetes": "chefete",
    "chefezeca": "chefezeco",
    "chefezecas": "chefezeco",
    "chefezecos": "chefezeco",
    "chefia": "chefiar",
    "chefiada": "chefiar",
    "chefiadas": "chefiar",
    "chefiado": "chefiar",
    "chefiados": "chefiar",
    "chefiai": "chefiar",
    "chefiais": "chefiar",
    "chefiam": "chefiar",
    "chefiamo": "chefiar",
    "chefiamos": "chefiar",
    "chefiando": "chefiar",
    "chefiara": "chefiar",
    "chefiaram": "chefiar",
    "chefiaras": "chefiar",
    "chefiarde": "chefiar",
    "chefiardes": "chefiar",
    "chefiare": "chefiar",
    "chefiarei": "chefiar",
    "chefiareis": "chefiar",
    "chefiarem": "chefiar",
    "chefiaremos": "chefiar",
    "chefiares": "chefiar",
    "chefiaria": "chefiar",
    "chefiariam": "chefiar",
    "chefiarias": "chefiar",
    "chefiarmo": "chefiar",
    "chefiarmos": "chefiar",
    "chefiará": "chefiar",
    "chefiarás": "chefiar",
    "chefiarão": "chefiar",
    "chefiaríamos": "chefiar",
    "chefiaríeis": "chefiar",
    "chefias": "chefiar",
    "chefiasse": "chefiar",
    "chefiassem": "chefiar",
    "chefiasses": "chefiar",
    "chefiaste": "chefiar",
    "chefiastes": "chefiar",
    "chefiava": "chefiar",
    "chefiavam": "chefiar",
    "chefiavas": "chefiar",
    "chefie": "chefiar",
    "chefiei": "chefiar",
    "chefieis": "chefiar",
    "chefiem": "chefiar",
    "chefiemo": "chefiar",
    "chefiemos": "chefiar",
    "chefies": "chefiar",
    "chefio": "chefiar",
    "chefiou": "chefiar",
    "chefiá": "chefiar",
    "chefiámo": "chefiar",
    "chefiámos": "chefiar",
    "chefiáramo": "chefiar",
    "chefiáramos": "chefiar",
    "chefiárei": "chefiar",
    "chefiáreis": "chefiar",
    "chefiásseis": "chefiar",
    "chefiássemos": "chefiar",
    "chefiávamo": "chefiar",
    "chefiávamos": "chefiar",
    "chefiávei": "chefiar",
    "chefiáveis": "chefiável",
    "chefona": "chefão",
    "chefonas": "chefão",
    "chefões": "chefão",
    "chega": "chegar",
    "chegada": "chegar",
    "chegadas": "chegar",
    "chegadeiras": "chegadeira",
    "chegadelas": "chegadela",
    "chegadinha": "chegado",
    "chegadinhas": "chegado",
    "chegadinho": "chegado",
    "chegadinhos": "chegado",
    "chegadita": "chegado",
    "chegaditas": "chegado",
    "chegadito": "chegado",
    "chegaditos": "chegado",
    "chegadiça": "chegadiço",
    "chegadiças": "chegadiço",
    "chegadiços": "chegadiço",
    "chegado": "chegar",
    "chegadora": "chegador",
    "chegadoras": "chegador",
    "chegadores": "chegador",
    "chegados": "chegar",
    "chegadíssima": "chegado",
    "chegadíssimas": "chegado",
    "chegadíssimo": "chegado",
    "chegadíssimos": "chegado",
    "chegai": "chegar",
    "chegais": "chegar",
    "chegam": "chegar",
    "chegamentos": "chegamento",
    "chegamo": "chegar",
    "chegamos": "chegar",
    "chegando": "chegar",
    "chegantes": "chegante",
    "cheganços": "cheganço",
    "chegara": "chegar",
    "chegaram": "chegar",
    "chegaras": "chegar",
    "chegarde": "chegar",
    "chegardes": "chegar",
    "chegare": "chegar",
    "chegarei": "chegar",
    "chegareis": "chegar",
    "chegarem": "chegar",
    "chegaremos": "chegar",
    "chegares": "chegar",
    "chegaria": "chegar",
    "chegariam": "chegar",
    "chegarias": "chegar",
    "chegarmo": "chegar",
    "chegarmos": "chegar",
    "chegará": "chegar",
    "chegarás": "chegar",
    "chegarão": "chegar",
    "chegaríamos": "chegar",
    "chegaríeis": "chegar",
    "chegas": "chegar",
    "chegasse": "chegar",
    "chegassem": "chegar",
    "chegasses": "chegar",
    "chegaste": "chegar",
    "chegastes": "chegar",
    "chegava": "chegar",
    "chegavam": "chegar",
    "chegavas": "chegar",
    "chego": "chegar",
    "chegou": "chegar",
    "chegue": "chegar",
    "cheguei": "chegar",
    "chegueis": "chegar",
    "cheguem": "chegar",
    "cheguemo": "chegar",
    "cheguemos": "chegar",
    "chegues": "chegar",
    "chegá": "chegar",
    "chegámo": "chegar",
    "chegámos": "chegar",
    "chegáramo": "chegar",
    "chegáramos": "chegar",
    "chegárei": "chegar",
    "chegáreis": "chegar",
    "chegásseis": "chegar",
    "chegássemos": "chegar",
    "chegávamo": "chegar",
    "chegávamos": "chegar",
    "chegávei": "chegar",
    "chegáveis": "chegar",
    "cheia": "cheio",
    "cheias": "cheio",
    "cheides": "cheide",
    "cheiinha": "cheio",
    "cheiinhas": "cheio",
    "cheiinho": "cheio",
    "cheiinhos": "cheio",
    "cheiita": "cheio",
    "cheiitas": "cheio",
    "cheiito": "cheio",
    "cheiitos": "cheio",
    "cheios": "cheio",
    "cheira": "cheirar",
    "cheirada": "cheirar",
    "cheiradas": "cheirar",
    "cheirado": "cheirar",
    "cheirados": "cheirar",
    "cheirai": "cheirar",
    "cheirais": "cheirar",
    "cheiram": "cheirar",
    "cheiramo": "cheirar",
    "cheiramos": "cheirar",
    "cheirando": "cheirar",
    "cheirara": "cheirar",
    "cheiraram": "cheirar",
    "cheiraras": "cheirar",
    "cheirarde": "cheirar",
    "cheirardes": "cheirar",
    "cheirare": "cheirar",
    "cheirarei": "cheirar",
    "cheirareis": "cheirar",
    "cheirarem": "cheirar",
    "cheiraremos": "cheirar",
    "cheirares": "cheirar",
    "cheiraria": "cheirar",
    "cheirariam": "cheirar",
    "cheirarias": "cheirar",
    "cheirarmo": "cheirar",
    "cheirarmos": "cheirar",
    "cheirará": "cheirar",
    "cheirarás": "cheirar",
    "cheirarão": "cheirar",
    "cheiraríamos": "cheirar",
    "cheiraríeis": "cheirar",
    "cheiras": "cheirar",
    "cheirasse": "cheirar",
    "cheirassem": "cheirar",
    "cheirasses": "cheirar",
    "cheiraste": "cheirar",
    "cheirastes": "cheirar",
    "cheirava": "cheirar",
    "cheiravam": "cheirar",
    "cheiravas": "cheirar",
    "cheire": "cheirar",
    "cheirei": "cheirar",
    "cheireis": "cheirar",
    "cheirem": "cheirar",
    "cheiremo": "cheirar",
    "cheiremos": "cheirar",
    "cheires": "cheirar",
    "cheiretas": "cheireta",
    "cheiretes": "cheirete",
    "cheirica": "cheiricar",
    "cheiricada": "cheiricar",
    "cheiricadas": "cheiricar",
    "cheiricado": "cheiricar",
    "cheiricados": "cheiricar",
    "cheiricai": "cheiricar",
    "cheiricais": "cheiricar",
    "cheiricam": "cheiricar",
    "cheiricamo": "cheiricar",
    "cheiricamos": "cheiricar",
    "cheiricando": "cheiricar",
    "cheiricara": "cheiricar",
    "cheiricaram": "cheiricar",
    "cheiricaras": "cheiricar",
    "cheiricarde": "cheiricar",
    "cheiricardes": "cheiricar",
    "cheiricare": "cheiricar",
    "cheiricarei": "cheiricar",
    "cheiricareis": "cheiricar",
    "cheiricarem": "cheiricar",
    "cheiricaremos": "cheiricar",
    "cheiricares": "cheiricar",
    "cheiricaria": "cheiricar",
    "cheiricariam": "cheiricar",
    "cheiricarias": "cheiricar",
    "cheiricarmo": "cheiricar",
    "cheiricarmos": "cheiricar",
    "cheiricará": "cheiricar",
    "cheiricarás": "cheiricar",
    "cheiricarão": "cheiricar",
    "cheiricaríamos": "cheiricar",
    "cheiricaríeis": "cheiricar",
    "cheiricas": "cheiricar",
    "cheiricasse": "cheiricar",
    "cheiricassem": "cheiricar",
    "cheiricasses": "cheiricar",
    "cheiricaste": "cheiricar",
    "cheiricastes": "cheiricar",
    "cheiricava": "cheiricar",
    "cheiricavam": "cheiricar",
    "cheiricavas": "cheiricar",
    "cheirico": "cheiricar",
    "cheiricou": "cheiricar",
    "cheiricá": "cheiricar",
    "cheiricámo": "cheiricar",
    "cheiricámos": "cheiricar",
    "cheiricáramo": "cheiricar",
    "cheiricáramos": "cheiricar",
    "cheiricárei": "cheiricar",
    "cheiricáreis": "cheiricar",
    "cheiricásseis": "cheiricar",
    "cheiricássemos": "cheiricar",
    "cheiricávamo": "cheiricar",
    "cheiricávamos": "cheiricar",
    "cheiricávei": "cheiricar",
    "cheiricáveis": "cheiricar",
    "cheirinhas": "cheirinha",
    "cheirinho": "cheiro",
    "cheirinhos": "cheiro",
    "cheirique": "cheiricar",
    "cheiriquei": "cheiricar",
    "cheiriqueis": "cheiricar",
    "cheiriquem": "cheiricar",
    "cheiriquemo": "cheiricar",
    "cheiriquemos": "cheiricar",
    "cheiriques": "cheiricar",
    "cheirito": "cheiro",
    "cheiritos": "cheiro",
    "cheiro": "cheirar",
    "cheiros": "cheiro",
    "cheirosa": "cheiroso",
    "cheirosas": "cheiroso",
    "cheirosos": "cheiroso",
    "cheirou": "cheirar",
    "cheiruns": "cheirum",
    "cheirá": "cheirar",
    "cheirámo": "cheirar",
    "cheirámos": "cheirar",
    "cheiráramo": "cheirar",
    "cheiráramos": "cheirar",
    "cheirárei": "cheirar",
    "cheiráreis": "cheirar",
    "cheirásseis": "cheirar",
    "cheirássemos": "cheirar",
    "cheirávamo": "cheirar",
    "cheirávamos": "cheirar",
    "cheirávei": "cheirar",
    "cheiráveis": "cheirar",
    "cheiíssima": "cheio",
    "cheiíssimas": "cheio",
    "cheiíssimo": "cheio",
    "cheiíssimos": "cheio",
    "chelas": "chela",
    "cheldras": "cheldra",
    "cheleiras": "cheleira",
    "cheliques": "chelique",
    "chelpas": "chelpa",
    "chelpuda": "chelpudo",
    "chelpudas": "chelpudo",
    "chelpudos": "chelpudo",
    "cheminés": "cheminé",
    "chenas": "chena",
    "cheque": "checar",
    "chequei": "checar",
    "chequeis": "checar",
    "chequem": "checar",
    "chequemo": "checar",
    "chequemos": "checar",
    "cheques": "cheque",
    "cheringalha": "cheringalho",
    "cheringalhas": "cheringalho",
    "cheringalhos": "cheringalho",
    "cherivias": "cherivia",
    "chernes": "cherne",
    "cherovias": "cherovia",
    "chertes": "cherte",
    "cheruvias": "cheruvia",
    "chervas": "cherva",
    "chetas": "cheta",
    "cheviotes": "cheviote",
    "cheviotinas": "cheviotina",
    "chia": "chiar",
    "chiada": "chiar",
    "chiadas": "chiar",
    "chiadeiras": "chiadeira",
    "chiado": "chiar",
    "chiadoiros": "chiadoiro",
    "chiadora": "chiador",
    "chiadoras": "chiador",
    "chiadores": "chiador",
    "chiados": "chiar",
    "chiadouros": "chiadouro",
    "chiaduras": "chiadura",
    "chiai": "chiar",
    "chiais": "chiar",
    "chiam": "chiar",
    "chiamo": "chiar",
    "chiamos": "chiar",
    "chiando": "chiar",
    "chiantes": "chiante",
    "chiara": "chiar",
    "chiaram": "chiar",
    "chiaras": "chiar",
    "chiardes": "chiar",
    "chiarei": "chiar",
    "chiareis": "chiar",
    "chiarem": "chiar",
    "chiaremos": "chiar",
    "chiares": "chiar",
    "chiaria": "chiar",
    "chiariam": "chiar",
    "chiarias": "chiar",
    "chiarmo": "chiar",
    "chiarmos": "chiar",
    "chiará": "chiar",
    "chiarás": "chiar",
    "chiarão": "chiar",
    "chiaríamos": "chiar",
    "chiaríeis": "chiar",
    "chias": "chiar",
    "chiascos": "chiasco",
    "chiasse": "chiar",
    "chiassem": "chiar",
    "chiasses": "chiar",
    "chiaste": "chiar",
    "chiastes": "chiar",
    "chiava": "chiar",
    "chiavam": "chiar",
    "chiavas": "chiar",
    "chiba": "chibo",
    "chibada": "chibar",
    "chibadas": "chibar",
    "chibado": "chibar",
    "chibados": "chibar",
    "chibai": "chibar",
    "chibais": "chibar",
    "chibam": "chibar",
    "chibambas": "chibamba",
    "chibamo": "chibar",
    "chibamos": "chibar",
    "chibando": "chibar",
    "chibantarias": "chibantaria",
    "chibanteada": "chibantear",
    "chibanteadas": "chibantear",
    "chibanteado": "chibantear",
    "chibanteados": "chibantear",
    "chibanteai": "chibantear",
    "chibanteais": "chibantear",
    "chibanteamo": "chibantear",
    "chibanteamos": "chibantear",
    "chibanteando": "chibantear",
    "chibanteara": "chibantear",
    "chibantearam": "chibantear",
    "chibantearas": "chibantear",
    "chibanteardes": "chibantear",
    "chibantearei": "chibantear",
    "chibanteareis": "chibantear",
    "chibantearem": "chibantear",
    "chibantearemos": "chibantear",
    "chibanteares": "chibantear",
    "chibantearia": "chibantear",
    "chibanteariam": "chibantear",
    "chibantearias": "chibantear",
    "chibantearmo": "chibantear",
    "chibantearmos": "chibantear",
    "chibanteará": "chibantear",
    "chibantearás": "chibantear",
    "chibantearão": "chibantear",
    "chibantearíamos": "chibantear",
    "chibantearíeis": "chibantear",
    "chibanteasse": "chibantear",
    "chibanteassem": "chibantear",
    "chibanteasses": "chibantear",
    "chibanteaste": "chibantear",
    "chibanteastes": "chibantear",
    "chibanteava": "chibantear",
    "chibanteavam": "chibantear",
    "chibanteavas": "chibantear",
    "chibanteei": "chibantear",
    "chibanteeis": "chibantear",
    "chibanteemo": "chibantear",
    "chibanteemos": "chibantear",
    "chibanteia": "chibantear",
    "chibanteiam": "chibantear",
    "chibanteias": "chibantear",
    "chibanteie": "chibantear",
    "chibanteiem": "chibantear",
    "chibanteies": "chibantear",
    "chibanteio": "chibantear",
    "chibanteou": "chibantear",
    "chibantes": "chibante",
    "chibanteámo": "chibantear",
    "chibanteámos": "chibantear",
    "chibanteáramo": "chibantear",
    "chibanteáramos": "chibantear",
    "chibanteáreis": "chibantear",
    "chibanteásseis": "chibantear",
    "chibanteássemos": "chibantear",
    "chibanteávamo": "chibantear",
    "chibanteávamos": "chibantear",
    "chibanteáveis": "chibantear",
    "chibantices": "chibantice",
    "chibanças": "chibança",
    "chibara": "chibar",
    "chibaram": "chibar",
    "chibaras": "chibar",
    "chibardes": "chibar",
    "chibarei": "chibar",
    "chibareis": "chibar",
    "chibarem": "chibar",
    "chibaremos": "chibar",
    "chibares": "chibar",
    "chibaria": "chibar",
    "chibariam": "chibar",
    "chibarias": "chibar",
    "chibarmo": "chibar",
    "chibarmos": "chibar",
    "chibarra": "chibarro",
    "chibarradas": "chibarrada",
    "chibarras": "chibarro",
    "chibarros": "chibarro",
    "chibará": "chibar",
    "chibarás": "chibar",
    "chibarão": "chibar",
    "chibaríamos": "chibar",
    "chibaríeis": "chibar",
    "chibas": "chibo",
    "chibasse": "chibar",
    "chibassem": "chibar",
    "chibasses": "chibar",
    "chibaste": "chibar",
    "chibastes": "chibar",
    "chibata": "chibato",
    "chibatadas": "chibatada",
    "chibatas": "chibato",
    "chibatos": "chibato",
    "chibatões": "chibatão",
    "chibava": "chibar",
    "chibavam": "chibar",
    "chibavas": "chibar",
    "chibe": "chibar",
    "chibei": "chibar",
    "chibeira": "chibeiro",
    "chibeiras": "chibeiro",
    "chibeiros": "chibeiro",
    "chibeis": "chibar",
    "chibem": "chibar",
    "chibemo": "chibar",
    "chibemos": "chibar",
    "chibes": "chibar",
    "chibo": "chibar",
    "chibos": "chibo",
    "chibou": "chibar",
    "chibámo": "chibar",
    "chibámos": "chibar",
    "chibáramo": "chibar",
    "chibáramos": "chibar",
    "chibáreis": "chibar",
    "chibásseis": "chibar",
    "chibássemos": "chibar",
    "chibávamo": "chibar",
    "chibávamos": "chibar",
    "chibáveis": "chibar",
    "chibéus": "chibéu",
    "chica": "chico",
    "chicana": "chicanar",
    "chicanada": "chicanar",
    "chicanadas": "chicanar",
    "chicanado": "chicanar",
    "chicanados": "chicanar",
    "chicanai": "chicanar",
    "chicanais": "chicanar",
    "chicanam": "chicanar",
    "chicanamo": "chicanar",
    "chicanamos": "chicanar",
    "chicanando": "chicanar",
    "chicanara": "chicanar",
    "chicanaram": "chicanar",
    "chicanaras": "chicanar",
    "chicanardes": "chicanar",
    "chicanarei": "chicanar",
    "chicanareis": "chicanar",
    "chicanarem": "chicanar",
    "chicanaremos": "chicanar",
    "chicanares": "chicanar",
    "chicanaria": "chicanar",
    "chicanariam": "chicanar",
    "chicanarias": "chicanar",
    "chicanarmo": "chicanar",
    "chicanarmos": "chicanar",
    "chicanará": "chicanar",
    "chicanarás": "chicanar",
    "chicanarão": "chicanar",
    "chicanaríamos": "chicanar",
    "chicanaríeis": "chicanar",
    "chicanas": "chicanar",
    "chicanasse": "chicanar",
    "chicanassem": "chicanar",
    "chicanasses": "chicanar",
    "chicanaste": "chicanar",
    "chicanastes": "chicanar",
    "chicanava": "chicanar",
    "chicanavam": "chicanar",
    "chicanavas": "chicanar",
    "chicane": "chicanar",
    "chicanei": "chicanar",
    "chicaneira": "chicaneiro",
    "chicaneiras": "chicaneiro",
    "chicaneiros": "chicaneiro",
    "chicaneis": "chicanar",
    "chicanem": "chicanar",
    "chicanemo": "chicanar",
    "chicanemos": "chicanar",
    "chicanes": "chicanar",
    "chicano": "chicanar",
    "chicanou": "chicanar",
    "chicantes": "chicante",
    "chicanámo": "chicanar",
    "chicanámos": "chicanar",
    "chicanáramo": "chicanar",
    "chicanáramos": "chicanar",
    "chicanáreis": "chicanar",
    "chicanásseis": "chicanar",
    "chicanássemos": "chicanar",
    "chicanávamo": "chicanar",
    "chicanávamos": "chicanar",
    "chicanáveis": "chicanar",
    "chicarolas": "chicarola",
    "chicas": "chico",
    "chicha": "chichar",
    "chichada": "chichar",
    "chichadas": "chichar",
    "chichado": "chichar",
    "chichados": "chichar",
    "chichai": "chichar",
    "chichais": "chichar",
    "chicham": "chichar",
    "chichamo": "chichar",
    "chichamos": "chichar",
    "chichando": "chichar",
    "chichara": "chichar",
    "chicharam": "chichar",
    "chicharas": "chichar",
    "chicharavelha": "chicharavelho",
    "chicharavelhas": "chicharavelho",
    "chicharavelhos": "chicharavelho",
    "chicharde": "chichar",
    "chichardes": "chichar",
    "chichare": "chichar",
    "chicharei": "chichar",
    "chichareis": "chichar",
    "chicharem": "chichar",
    "chicharemos": "chichar",
    "chichares": "chichar",
    "chicharia": "chichar",
    "chichariam": "chichar",
    "chicharias": "chichar",
    "chicharmo": "chichar",
    "chicharmos": "chichar",
    "chicharros": "chicharro",
    "chichará": "chichar",
    "chicharás": "chichar",
    "chicharão": "chichar",
    "chicharíamos": "chichar",
    "chicharíeis": "chichar",
    "chichas": "chichar",
    "chichasse": "chichar",
    "chichassem": "chichar",
    "chichasses": "chichar",
    "chichaste": "chichar",
    "chichastes": "chichar",
    "chichava": "chichar",
    "chichavam": "chichar",
    "chichavas": "chichar",
    "chiche": "chichar",
    "chichei": "chichar",
    "chicheis": "chichar",
    "chichem": "chichar",
    "chichemo": "chichar",
    "chichemos": "chichar",
    "chiches": "chichar",
    "chichis": "chichi",
    "chichisbéus": "chichisbéu",
    "chichizinho": "chichi",
    "chichizinhos": "chichi",
    "chichizito": "chichi",
    "chichizitos": "chichi",
    "chichizões": "chichizão",
    "chicho": "chichar",
    "chichorrobia": "chichorrobio",
    "chichorrobiada": "chichorrobiar",
    "chichorrobiadas": "chichorrobiar",
    "chichorrobiado": "chichorrobiar",
    "chichorrobiados": "chichorrobiar",
    "chichorrobiai": "chichorrobiar",
    "chichorrobiais": "chichorrobiar",
    "chichorrobiam": "chichorrobiar",
    "chichorrobiamo": "chichorrobiar",
    "chichorrobiamos": "chichorrobiar",
    "chichorrobiando": "chichorrobiar",
    "chichorrobiara": "chichorrobiar",
    "chichorrobiaram": "chichorrobiar",
    "chichorrobiaras": "chichorrobiar",
    "chichorrobiardes": "chichorrobiar",
    "chichorrobiarei": "chichorrobiar",
    "chichorrobiareis": "chichorrobiar",
    "chichorrobiarem": "chichorrobiar",
    "chichorrobiaremos": "chichorrobiar",
    "chichorrobiares": "chichorrobiar",
    "chichorrobiaria": "chichorrobiar",
    "chichorrobiariam": "chichorrobiar",
    "chichorrobiarias": "chichorrobiar",
    "chichorrobiarmo": "chichorrobiar",
    "chichorrobiarmos": "chichorrobiar",
    "chichorrobiará": "chichorrobiar",
    "chichorrobiarás": "chichorrobiar",
    "chichorrobiarão": "chichorrobiar",
    "chichorrobiaríamos": "chichorrobiar",
    "chichorrobiaríeis": "chichorrobiar",
    "chichorrobias": "chichorrobio",
    "chichorrobiasse": "chichorrobiar",
    "chichorrobiassem": "chichorrobiar",
    "chichorrobiasses": "chichorrobiar",
    "chichorrobiaste": "chichorrobiar",
    "chichorrobiastes": "chichorrobiar",
    "chichorrobiava": "chichorrobiar",
    "chichorrobiavam": "chichorrobiar",
    "chichorrobiavas": "chichorrobiar",
    "chichorrobie": "chichorrobiar",
    "chichorrobiei": "chichorrobiar",
    "chichorrobieis": "chichorrobiar",
    "chichorrobiem": "chichorrobiar",
    "chichorrobiemo": "chichorrobiar",
    "chichorrobiemos": "chichorrobiar",
    "chichorrobies": "chichorrobiar",
    "chichorrobio": "chichorrobiar",
    "chichorrobios": "chichorrobio",
    "chichorrobiou": "chichorrobiar",
    "chichorrobiámo": "chichorrobiar",
    "chichorrobiámos": "chichorrobiar",
    "chichorrobiáramo": "chichorrobiar",
    "chichorrobiáramos": "chichorrobiar",
    "chichorrobiáreis": "chichorrobiar",
    "chichorrobiásseis": "chichorrobiar",
    "chichorrobiássemos": "chichorrobiar",
    "chichorrobiávamo": "chichorrobiar",
    "chichorrobiávamos": "chichorrobiar",
    "chichorrobiáveis": "chichorrobiar",
    "chichos": "chicho",
    "chichou": "chichar",
    "chichá": "chichar",
    "chichámo": "chichar",
    "chichámos": "chichar",
    "chicháramo": "chichar",
    "chicháramos": "chichar",
    "chichárei": "chichar",
    "chicháreis": "chichar",
    "chichásseis": "chichar",
    "chichássemos": "chichar",
    "chichávamo": "chichar",
    "chichávamos": "chichar",
    "chichávei": "chichar",
    "chicháveis": "chichar",
    "chicletes": "chiclete",
    "chicos": "chico",
    "chicotadas": "chicotada",
    "chicotadelas": "chicotadela",
    "chicoteada": "chicoteado",
    "chicoteadas": "chicoteado",
    "chicoteadora": "chicoteador",
    "chicoteadoras": "chicoteador",
    "chicoteadores": "chicoteador",
    "chicoteados": "chicoteado",
    "chicoteamentos": "chicoteamento",
    "chicotes": "chicote",
    "chicórias": "chicória",
    "chie": "chiar",
    "chiei": "chiar",
    "chieiras": "chieira",
    "chieirenta": "chieirento",
    "chieirentas": "chieirento",
    "chieirentos": "chieirento",
    "chieis": "chiar",
    "chiem": "chiar",
    "chiemo": "chiar",
    "chiemos": "chiar",
    "chies": "chiar",
    "chifarotes": "chifarote",
    "chifra": "chifrar",
    "chifrada": "chifrar",
    "chifradas": "chifrar",
    "chifradeiras": "chifradeira",
    "chifrado": "chifrar",
    "chifrados": "chifrar",
    "chifrai": "chifrar",
    "chifrais": "chifrar",
    "chifram": "chifrar",
    "chiframo": "chifrar",
    "chiframos": "chifrar",
    "chifrando": "chifrar",
    "chifrara": "chifrar",
    "chifraram": "chifrar",
    "chifraras": "chifrar",
    "chifrarde": "chifrar",
    "chifrardes": "chifrar",
    "chifrare": "chifrar",
    "chifrarei": "chifrar",
    "chifrareis": "chifrar",
    "chifrarem": "chifrar",
    "chifraremos": "chifrar",
    "chifrares": "chifrar",
    "chifraria": "chifrar",
    "chifrariam": "chifrar",
    "chifrarias": "chifrar",
    "chifrarmo": "chifrar",
    "chifrarmos": "chifrar",
    "chifrará": "chifrar",
    "chifrarás": "chifrar",
    "chifrarão": "chifrar",
    "chifraríamos": "chifrar",
    "chifraríeis": "chifrar",
    "chifras": "chifrar",
    "chifrasse": "chifrar",
    "chifrassem": "chifrar",
    "chifrasses": "chifrar",
    "chifraste": "chifrar",
    "chifrastes": "chifrar",
    "chifrava": "chifrar",
    "chifravam": "chifrar",
    "chifravas": "chifrar",
    "chifre": "chifrar",
    "chifrei": "chifrar",
    "chifreis": "chifrar",
    "chifrem": "chifrar",
    "chifremo": "chifrar",
    "chifremos": "chifrar",
    "chifres": "chifre",
    "chifro": "chifrar",
    "chifrou": "chifrar",
    "chifruda": "chifrudo",
    "chifrudas": "chifrudo",
    "chifrudos": "chifrudo",
    "chifrá": "chifrar",
    "chifrámo": "chifrar",
    "chifrámos": "chifrar",
    "chifráramo": "chifrar",
    "chifráramos": "chifrar",
    "chifrárei": "chifrar",
    "chifráreis": "chifrar",
    "chifrásseis": "chifrar",
    "chifrássemos": "chifrar",
    "chifrávamo": "chifrar",
    "chifrávamos": "chifrar",
    "chifrávei": "chifrar",
    "chifráveis": "chifrar",
    "chiitas": "chiita",
    "chilas": "chila",
    "chilena": "chileno",
    "chilenas": "chileno",
    "chilenos": "chileno",
    "chiles": "chile",
    "chilidos": "chilido",
    "chilindras": "chilindra",
    "chilindrós": "chilindró",
    "chiliques": "chilique",
    "chilondras": "chilondra",
    "chilra": "chilrar",
    "chilrada": "chilrar",
    "chilradas": "chilrar",
    "chilrado": "chilrar",
    "chilrados": "chilrar",
    "chilrai": "chilrar",
    "chilrais": "chilrar",
    "chilram": "chilrar",
    "chilramo": "chilrar",
    "chilramos": "chilrar",
    "chilrando": "chilrar",
    "chilrara": "chilrar",
    "chilraram": "chilrar",
    "chilraras": "chilrar",
    "chilrarde": "chilrar",
    "chilrardes": "chilrar",
    "chilrare": "chilrar",
    "chilrarei": "chilrar",
    "chilrareis": "chilrar",
    "chilrarem": "chilrar",
    "chilraremos": "chilrar",
    "chilrares": "chilrar",
    "chilraria": "chilrar",
    "chilrariam": "chilrar",
    "chilrarias": "chilrar",
    "chilrarmo": "chilrar",
    "chilrarmos": "chilrar",
    "chilrará": "chilrar",
    "chilrarás": "chilrar",
    "chilrarão": "chilrar",
    "chilraríamos": "chilrar",
    "chilraríeis": "chilrar",
    "chilras": "chilrar",
    "chilrasse": "chilrar",
    "chilrassem": "chilrar",
    "chilrasses": "chilrar",
    "chilraste": "chilrar",
    "chilrastes": "chilrar",
    "chilrava": "chilrar",
    "chilravam": "chilrar",
    "chilravas": "chilrar",
    "chilre": "chilrar",
    "chilreada": "chilrear",
    "chilreadas": "chilrear",
    "chilreado": "chilrear",
    "chilreadora": "chilreador",
    "chilreadoras": "chilreador",
    "chilreadores": "chilreador",
    "chilreados": "chilrear",
    "chilreai": "chilrear",
    "chilreais": "chilrear",
    "chilreamo": "chilrear",
    "chilreamos": "chilrear",
    "chilreando": "chilrear",
    "chilreantes": "chilreante",
    "chilreara": "chilrear",
    "chilrearam": "chilrear",
    "chilrearas": "chilrear",
    "chilrearde": "chilrear",
    "chilreardes": "chilrear",
    "chilreare": "chilrear",
    "chilrearei": "chilrear",
    "chilreareis": "chilrear",
    "chilrearem": "chilrear",
    "chilrearemos": "chilrear",
    "chilreares": "chilrear",
    "chilrearia": "chilrear",
    "chilreariam": "chilrear",
    "chilrearias": "chilrear",
    "chilrearmo": "chilrear",
    "chilrearmos": "chilrear",
    "chilreará": "chilrear",
    "chilrearás": "chilrear",
    "chilrearão": "chilrear",
    "chilrearíamos": "chilrear",
    "chilrearíeis": "chilrear",
    "chilreasse": "chilrear",
    "chilreassem": "chilrear",
    "chilreasses": "chilrear",
    "chilreaste": "chilrear",
    "chilreastes": "chilrear",
    "chilreava": "chilrear",
    "chilreavam": "chilrear",
    "chilreavas": "chilrear",
    "chilreei": "chilrear",
    "chilreeis": "chilrear",
    "chilreemo": "chilrear",
    "chilreemos": "chilrear",
    "chilrei": "chilrar",
    "chilreia": "chilrear",
    "chilreiam": "chilrear",
    "chilreias": "chilrear",
    "chilreie": "chilrear",
    "chilreiem": "chilrear",
    "chilreies": "chilrear",
    "chilreio": "chilrear",
    "chilreios": "chilreio",
    "chilreis": "chilrar",
    "chilrem": "chilrar",
    "chilremo": "chilrar",
    "chilremos": "chilrar",
    "chilreou": "chilrear",
    "chilres": "chilre",
    "chilretas": "chilreta",
    "chilreá": "chilrear",
    "chilreámo": "chilrear",
    "chilreámos": "chilrear",
    "chilreáramo": "chilrear",
    "chilreáramos": "chilrear",
    "chilreárei": "chilrear",
    "chilreáreis": "chilrear",
    "chilreásseis": "chilrear",
    "chilreássemos": "chilrear",
    "chilreávamo": "chilrear",
    "chilreávamos": "chilrear",
    "chilreávei": "chilrear",
    "chilreáveis": "chilrear",
    "chilro": "chilrar",
    "chilros": "chilro",
    "chilrou": "chilrar",
    "chilrá": "chilrar",
    "chilrámo": "chilrar",
    "chilrámos": "chilrar",
    "chilráramo": "chilrar",
    "chilráramos": "chilrar",
    "chilrárei": "chilrar",
    "chilráreis": "chilrar",
    "chilrásseis": "chilrar",
    "chilrássemos": "chilrar",
    "chilrávamo": "chilrar",
    "chilrávamos": "chilrar",
    "chilrávei": "chilrar",
    "chilráveis": "chilrar",
    "chimangos": "chimango",
    "chimarras": "chimarra",
    "chimarrões": "chimarrão",
    "chimpa": "chimpar",
    "chimpada": "chimpar",
    "chimpadas": "chimpar",
    "chimpado": "chimpar",
    "chimpados": "chimpar",
    "chimpai": "chimpar",
    "chimpais": "chimpar",
    "chimpam": "chimpar",
    "chimpamo": "chimpar",
    "chimpamos": "chimpar",
    "chimpando": "chimpar",
    "chimpanzés": "chimpanzé",
    "chimpara": "chimpar",
    "chimparam": "chimpar",
    "chimparas": "chimpar",
    "chimparde": "chimpar",
    "chimpardes": "chimpar",
    "chimpare": "chimpar",
    "chimparei": "chimpar",
    "chimpareis": "chimpar",
    "chimparem": "chimpar",
    "chimparemos": "chimpar",
    "chimpares": "chimpar",
    "chimparia": "chimpar",
    "chimpariam": "chimpar",
    "chimparias": "chimpar",
    "chimparmo": "chimpar",
    "chimparmos": "chimpar",
    "chimpará": "chimpar",
    "chimparás": "chimpar",
    "chimparão": "chimpar",
    "chimparíamos": "chimpar",
    "chimparíeis": "chimpar",
    "chimpas": "chimpar",
    "chimpasse": "chimpar",
    "chimpassem": "chimpar",
    "chimpasses": "chimpar",
    "chimpaste": "chimpar",
    "chimpastes": "chimpar",
    "chimpava": "chimpar",
    "chimpavam": "chimpar",
    "chimpavas": "chimpar",
    "chimpe": "chimpar",
    "chimpei": "chimpar",
    "chimpeis": "chimpar",
    "chimpem": "chimpar",
    "chimpemo": "chimpar",
    "chimpemos": "chimpar",
    "chimpes": "chimpar",
    "chimpo": "chimpar",
    "chimpou": "chimpar",
    "chimpá": "chimpar",
    "chimpámo": "chimpar",
    "chimpámos": "chimpar",
    "chimpáramo": "chimpar",
    "chimpáramos": "chimpar",
    "chimpárei": "chimpar",
    "chimpáreis": "chimpar",
    "chimpásseis": "chimpar",
    "chimpássemos": "chimpar",
    "chimpávamo": "chimpar",
    "chimpávamos": "chimpar",
    "chimpávei": "chimpar",
    "chimpáveis": "chimpar",
    "china": "chino",
    "chinada": "chinar",
    "chinadas": "chinar",
    "chinado": "chinar",
    "chinados": "chinar",
    "chinai": "chinar",
    "chinais": "chinar",
    "chinam": "chinar",
    "chinamo": "chinar",
    "chinamos": "chinar",
    "chinando": "chinar",
    "chinara": "chinar",
    "chinaram": "chinar",
    "chinaras": "chinar",
    "chinarde": "chinar",
    "chinardes": "chinar",
    "chinare": "chinar",
    "chinarei": "chinar",
    "chinareis": "chinar",
    "chinarem": "chinar",
    "chinaremos": "chinar",
    "chinares": "chinar",
    "chinaria": "chinar",
    "chinariam": "chinar",
    "chinarias": "chinar",
    "chinarmo": "chinar",
    "chinarmos": "chinar",
    "chinará": "chinar",
    "chinarás": "chinar",
    "chinarão": "chinar",
    "chinaríamos": "chinar",
    "chinaríeis": "chinar",
    "chinas": "chino",
    "chinasse": "chinar",
    "chinassem": "chinar",
    "chinasses": "chinar",
    "chinaste": "chinar",
    "chinastes": "chinar",
    "chinava": "chinar",
    "chinavam": "chinar",
    "chinavas": "chinar",
    "chinca": "chincar",
    "chincada": "chincar",
    "chincadas": "chincar",
    "chincadelas": "chincadela",
    "chincado": "chincar",
    "chincados": "chincar",
    "chincai": "chincar",
    "chincais": "chincar",
    "chincalhadas": "chincalhada",
    "chincalhações": "chincalhação",
    "chincalhões": "chincalhão",
    "chincam": "chincar",
    "chincamo": "chincar",
    "chincamos": "chincar",
    "chincando": "chincar",
    "chincara": "chincar",
    "chincaram": "chincar",
    "chincaras": "chincar",
    "chincarde": "chincar",
    "chincardes": "chincar",
    "chincare": "chincar",
    "chincarei": "chincar",
    "chincareis": "chincar",
    "chincarem": "chincar",
    "chincaremos": "chincar",
    "chincares": "chincar",
    "chincaria": "chincar",
    "chincariam": "chincar",
    "chincarias": "chincar",
    "chincarmo": "chincar",
    "chincarmos": "chincar",
    "chincará": "chincar",
    "chincarás": "chincar",
    "chincarão": "chincar",
    "chincaríamos": "chincar",
    "chincaríeis": "chincar",
    "chincas": "chincar",
    "chincasse": "chincar",
    "chincassem": "chincar",
    "chincasses": "chincar",
    "chincaste": "chincar",
    "chincastes": "chincar",
    "chincava": "chincar",
    "chincavam": "chincar",
    "chincavas": "chincar",
    "chinchafóis": "chinchafol",
    "chinchagens": "chinchagem",
    "chinchalarés": "chinchalaré",
    "chincharavelhos": "chincharavelho",
    "chinchas": "chincha",
    "chincheira": "chincheiro",
    "chincheiras": "chincheiro",
    "chincheiros": "chincheiro",
    "chinchilas": "chinchila",
    "chinchona": "chinchão",
    "chinchonas": "chinchona",
    "chinchorras": "chinchorra",
    "chinchorros": "chinchorro",
    "chinchos": "chincho",
    "chinchões": "chinchão",
    "chinclopés": "chinclopé",
    "chinco": "chincar",
    "chincou": "chincar",
    "chincras": "chincra",
    "chincá": "chincar",
    "chincámo": "chincar",
    "chincámos": "chincar",
    "chincáramo": "chincar",
    "chincáramos": "chincar",
    "chincárei": "chincar",
    "chincáreis": "chincar",
    "chincásseis": "chincar",
    "chincássemos": "chincar",
    "chincávamo": "chincar",
    "chincávamos": "chincar",
    "chincávei": "chincar",
    "chincáveis": "chincar",
    "chine": "chinar",
    "chinei": "chinar",
    "chineis": "chinar",
    "chineladas": "chinelada",
    "chinelas": "chinela",
    "chineleira": "chineleiro",
    "chineleiras": "chineleiro",
    "chineleiros": "chineleiro",
    "chinelinha": "chinela",
    "chinelinhas": "chinela",
    "chinelinho": "chinelo",
    "chinelinhos": "chinelo",
    "chinelita": "chinela",
    "chinelitas": "chinela",
    "chinelito": "chinelo",
    "chinelitos": "chinelo",
    "chinelos": "chinelo",
    "chinem": "chinar",
    "chinemo": "chinar",
    "chinemos": "chinar",
    "chines": "chinar",
    "chinesa": "chinês",
    "chinesadas": "chinesada",
    "chinesas": "chinês",
    "chineses": "chinês",
    "chinesices": "chinesice",
    "chinesismos": "chinesismo",
    "chinfrinadas": "chinfrinada",
    "chinfrineira": "chinfrineiro",
    "chinfrineiras": "chinfrineiro",
    "chinfrineiros": "chinfrineiro",
    "chinfrins": "chinfrim",
    "chinfrões": "chinfrão",
    "chinguiços": "chinguiço",
    "chininha": "chino",
    "chininhas": "chino",
    "chininho": "chino",
    "chininhos": "chino",
    "chinita": "chino",
    "chinitas": "chino",
    "chinito": "chino",
    "chinitos": "chino",
    "chino": "chinar",
    "chinocas": "chinoca",
    "chinos": "chino",
    "chinou": "chinar",
    "chinque": "chincar",
    "chinquei": "chincar",
    "chinqueis": "chincar",
    "chinquem": "chincar",
    "chinquemo": "chincar",
    "chinquemos": "chincar",
    "chinques": "chincar",
    "chinquilhos": "chinquilho",
    "chins": "chim",
    "chintzs": "chintz",
    "chiná": "chinar",
    "chinámo": "chinar",
    "chinámos": "chinar",
    "chináramo": "chinar",
    "chináramos": "chinar",
    "chinárei": "chinar",
    "chináreis": "chinar",
    "chinásseis": "chinar",
    "chinássemos": "chinar",
    "chinávamo": "chinar",
    "chinávamos": "chinar",
    "chinávei": "chinar",
    "chináveis": "chinar",
    "chinós": "chinó",
    "chio": "chiar",
    "chiolas": "chiola",
    "chiona": "chião",
    "chionas": "chião",
    "chios": "chio",
    "chiou": "chiar",
    "chipantes": "chipante",
    "chipes": "chipe",
    "chipos": "chipo",
    "chips": "chip",
    "chiqueiros": "chiqueiro",
    "chiqueis": "chiquel",
    "chiques": "chique",
    "chiquismos": "chiquismo",
    "chiquérrima": "chique",
    "chiquérrimas": "chique",
    "chiquérrimo": "chique",
    "chiquérrimos": "chique",
    "chiquíssima": "chique",
    "chiquíssimas": "chique",
    "chiquíssimo": "chique",
    "chiquíssimos": "chique",
    "chiretas": "chireta",
    "chirias": "chiria",
    "chirilas": "chirila",
    "chirimónias": "chirimónia",
    "chirinas": "chirina",
    "chirinolas": "chirinola",
    "chirivias": "chirivia",
    "chirria": "chirriar",
    "chirriada": "chirriar",
    "chirriadas": "chirriar",
    "chirriado": "chirriar",
    "chirriados": "chirriar",
    "chirriai": "chirriar",
    "chirriais": "chirriar",
    "chirriam": "chirriar",
    "chirriamo": "chirriar",
    "chirriamos": "chirriar",
    "chirriando": "chirriar",
    "chirriantes": "chirriante",
    "chirriara": "chirriar",
    "chirriaram": "chirriar",
    "chirriaras": "chirriar",
    "chirriardes": "chirriar",
    "chirriarei": "chirriar",
    "chirriareis": "chirriar",
    "chirriarem": "chirriar",
    "chirriaremos": "chirriar",
    "chirriares": "chirriar",
    "chirriaria": "chirriar",
    "chirriariam": "chirriar",
    "chirriarias": "chirriar",
    "chirriarmo": "chirriar",
    "chirriarmos": "chirriar",
    "chirriará": "chirriar",
    "chirriarás": "chirriar",
    "chirriarão": "chirriar",
    "chirriaríamos": "chirriar",
    "chirriaríeis": "chirriar",
    "chirrias": "chirriar",
    "chirriasse": "chirriar",
    "chirriassem": "chirriar",
    "chirriasses": "chirriar",
    "chirriaste": "chirriar",
    "chirriastes": "chirriar",
    "chirriava": "chirriar",
    "chirriavam": "chirriar",
    "chirriavas": "chirriar",
    "chirrie": "chirriar",
    "chirriei": "chirriar",
    "chirrieis": "chirriar",
    "chirriem": "chirriar",
    "chirriemo": "chirriar",
    "chirriemos": "chirriar",
    "chirries": "chirriar",
    "chirrio": "chirriar",
    "chirriou": "chirriar",
    "chirriámo": "chirriar",
    "chirriámos": "chirriar",
    "chirriáramo": "chirriar",
    "chirriáramos": "chirriar",
    "chirriáreis": "chirriar",
    "chirriásseis": "chirriar",
    "chirriássemos": "chirriar",
    "chirriávamo": "chirriar",
    "chirriávamos": "chirriar",
    "chirriáveis": "chirriar",
    "chirrobias": "chirrobia",
    "chis": "chi",
    "chisca": "chiscar",
    "chiscada": "chiscar",
    "chiscadas": "chiscar",
    "chiscado": "chiscar",
    "chiscados": "chiscar",
    "chiscai": "chiscar",
    "chiscais": "chiscar",
    "chiscam": "chiscar",
    "chiscamo": "chiscar",
    "chiscamos": "chiscar",
    "chiscando": "chiscar",
    "chiscara": "chiscar",
    "chiscaram": "chiscar",
    "chiscaras": "chiscar",
    "chiscarde": "chiscar",
    "chiscardes": "chiscar",
    "chiscare": "chiscar",
    "chiscarei": "chiscar",
    "chiscareis": "chiscar",
    "chiscarem": "chiscar",
    "chiscaremos": "chiscar",
    "chiscares": "chiscar",
    "chiscaria": "chiscar",
    "chiscariam": "chiscar",
    "chiscarias": "chiscar",
    "chiscarmo": "chiscar",
    "chiscarmos": "chiscar",
    "chiscará": "chiscar",
    "chiscarás": "chiscar",
    "chiscarão": "chiscar",
    "chiscaríamos": "chiscar",
    "chiscaríeis": "chiscar",
    "chiscas": "chiscar",
    "chiscasse": "chiscar",
    "chiscassem": "chiscar",
    "chiscasses": "chiscar",
    "chiscaste": "chiscar",
    "chiscastes": "chiscar",
    "chiscava": "chiscar",
    "chiscavam": "chiscar",
    "chiscavas": "chiscar",
    "chisco": "chiscar",
    "chiscos": "chisco",
    "chiscou": "chiscar",
    "chiscá": "chiscar",
    "chiscámo": "chiscar",
    "chiscámos": "chiscar",
    "chiscáramo": "chiscar",
    "chiscáramos": "chiscar",
    "chiscárei": "chiscar",
    "chiscáreis": "chiscar",
    "chiscásseis": "chiscar",
    "chiscássemos": "chiscar",
    "chiscávamo": "chiscar",
    "chiscávamos": "chiscar",
    "chiscávei": "chiscar",
    "chiscáveis": "chiscar",
    "chismes": "chisme",
    "chisna": "chisnar",
    "chisnada": "chisnar",
    "chisnadas": "chisnar",
    "chisnado": "chisnar",
    "chisnados": "chisnar",
    "chisnai": "chisnar",
    "chisnais": "chisnar",
    "chisnam": "chisnar",
    "chisnamo": "chisnar",
    "chisnamos": "chisnar",
    "chisnando": "chisnar",
    "chisnara": "chisnar",
    "chisnaram": "chisnar",
    "chisnaras": "chisnar",
    "chisnarde": "chisnar",
    "chisnardes": "chisnar",
    "chisnare": "chisnar",
    "chisnarei": "chisnar",
    "chisnareis": "chisnar",
    "chisnarem": "chisnar",
    "chisnaremos": "chisnar",
    "chisnares": "chisnar",
    "chisnaria": "chisnar",
    "chisnariam": "chisnar",
    "chisnarias": "chisnar",
    "chisnarmo": "chisnar",
    "chisnarmos": "chisnar",
    "chisnará": "chisnar",
    "chisnarás": "chisnar",
    "chisnarão": "chisnar",
    "chisnaríamos": "chisnar",
    "chisnaríeis": "chisnar",
    "chisnas": "chisnar",
    "chisnasse": "chisnar",
    "chisnassem": "chisnar",
    "chisnasses": "chisnar",
    "chisnaste": "chisnar",
    "chisnastes": "chisnar",
    "chisnava": "chisnar",
    "chisnavam": "chisnar",
    "chisnavas": "chisnar",
    "chisne": "chisnar",
    "chisnei": "chisnar",
    "chisneis": "chisnar",
    "chisnem": "chisnar",
    "chisnemo": "chisnar",
    "chisnemos": "chisnar",
    "chisnes": "chisnar",
    "chisno": "chisnar",
    "chisnou": "chisnar",
    "chisná": "chisnar",
    "chisnámo": "chisnar",
    "chisnámos": "chisnar",
    "chisnáramo": "chisnar",
    "chisnáramos": "chisnar",
    "chisnárei": "chisnar",
    "chisnáreis": "chisnar",
    "chisnásseis": "chisnar",
    "chisnássemos": "chisnar",
    "chisnávamo": "chisnar",
    "chisnávamos": "chisnar",
    "chisnávei": "chisnar",
    "chisnáveis": "chisnar",
    "chispalhadas": "chispalhada",
    "chispantes": "chispante",
    "chispas": "chispa",
    "chispes": "chispe",
    "chisque": "chiscar",
    "chisquei": "chiscar",
    "chisqueis": "chiscar",
    "chisquem": "chiscar",
    "chisquemo": "chiscar",
    "chisquemos": "chiscar",
    "chisques": "chiscar",
    "chistes": "chiste",
    "chistosa": "chistoso",
    "chistosas": "chistoso",
    "chistosos": "chistoso",
    "chitadas": "chitada",
    "chitarias": "chitaria",
    "chitas": "chita",
    "chitelhas": "chitelha",
    "chitões": "chitão",
    "chiámo": "chiar",
    "chiámos": "chiar",
    "chiáramo": "chiar",
    "chiáramos": "chiar",
    "chiáreis": "chiar",
    "chiásseis": "chiar",
    "chiássemos": "chiar",
    "chiávamo": "chiar",
    "chiávamos": "chiar",
    "chiáveis": "chiar",
    "chiços": "chiço",
    "chiões": "chião",
    "choca": "choco",
    "chocada": "chocar",
    "chocadas": "chocar",
    "chocadeiras": "chocadeira",
    "chocado": "chocar",
    "chocados": "chocar",
    "chocadíssima": "chocado",
    "chocadíssimas": "chocado",
    "chocadíssimo": "chocado",
    "chocadíssimos": "chocado",
    "chocagens": "chocagem",
    "chocai": "chocar",
    "chocais": "chocar",
    "chocalha": "chocalhar",
    "chocalhada": "chocalhar",
    "chocalhadas": "chocalhar",
    "chocalhado": "chocalhar",
    "chocalhados": "chocalhar",
    "chocalhai": "chocalhar",
    "chocalhais": "chocalhar",
    "chocalham": "chocalhar",
    "chocalhamo": "chocalhar",
    "chocalhamos": "chocalhar",
    "chocalhando": "chocalhar",
    "chocalhara": "chocalhar",
    "chocalharam": "chocalhar",
    "chocalharas": "chocalhar",
    "chocalharde": "chocalhar",
    "chocalhardes": "chocalhar",
    "chocalhare": "chocalhar",
    "chocalharei": "chocalhar",
    "chocalhareis": "chocalhar",
    "chocalharem": "chocalhar",
    "chocalharemos": "chocalhar",
    "chocalhares": "chocalhar",
    "chocalharia": "chocalhar",
    "chocalhariam": "chocalhar",
    "chocalharias": "chocalhar",
    "chocalharmo": "chocalhar",
    "chocalharmos": "chocalhar",
    "chocalhará": "chocalhar",
    "chocalharás": "chocalhar",
    "chocalharão": "chocalhar",
    "chocalharíamos": "chocalhar",
    "chocalharíeis": "chocalhar",
    "chocalhas": "chocalhar",
    "chocalhasse": "chocalhar",
    "chocalhassem": "chocalhar",
    "chocalhasses": "chocalhar",
    "chocalhaste": "chocalhar",
    "chocalhastes": "chocalhar",
    "chocalhava": "chocalhar",
    "chocalhavam": "chocalhar",
    "chocalhavas": "chocalhar",
    "chocalhe": "chocalhar",
    "chocalhei": "chocalhar",
    "chocalheira": "chocalheiro",
    "chocalheiras": "chocalheiro",
    "chocalheiros": "chocalheiro",
    "chocalheis": "chocalhar",
    "chocalhem": "chocalhar",
    "chocalhemo": "chocalhar",
    "chocalhemos": "chocalhar",
    "chocalhes": "chocalhar",
    "chocalhices": "chocalhice",
    "chocalho": "chocalhar",
    "chocalhos": "chocalho",
    "chocalhou": "chocalhar",
    "chocalhá": "chocalhar",
    "chocalhámo": "chocalhar",
    "chocalhámos": "chocalhar",
    "chocalháramo": "chocalhar",
    "chocalháramos": "chocalhar",
    "chocalhárei": "chocalhar",
    "chocalháreis": "chocalhar",
    "chocalhásseis": "chocalhar",
    "chocalhássemos": "chocalhar",
    "chocalhávamo": "chocalhar",
    "chocalhávamos": "chocalhar",
    "chocalhávei": "chocalhar",
    "chocalháveis": "chocalhar",
    "chocam": "chocar",
    "chocamo": "chocar",
    "chocamos": "chocar",
    "chocando": "chocar",
    "chocantes": "chocante",
    "chocara": "chocar",
    "chocaram": "chocar",
    "chocaras": "chocar",
    "chocarde": "chocar",
    "chocardes": "chocar",
    "chocare": "chocar",
    "chocarei": "chocar",
    "chocareis": "chocar",
    "chocarem": "chocar",
    "chocaremos": "chocar",
    "chocares": "chocar",
    "chocaria": "chocar",
    "chocariam": "chocar",
    "chocarias": "chocar",
    "chocarmo": "chocar",
    "chocarmos": "chocar",
    "chocarreada": "chocarrear",
    "chocarreadas": "chocarrear",
    "chocarreado": "chocarrear",
    "chocarreados": "chocarrear",
    "chocarreai": "chocarrear",
    "chocarreais": "chocarrear",
    "chocarreamo": "chocarrear",
    "chocarreamos": "chocarrear",
    "chocarreando": "chocarrear",
    "chocarreara": "chocarrear",
    "chocarrearam": "chocarrear",
    "chocarrearas": "chocarrear",
    "chocarreardes": "chocarrear",
    "chocarrearei": "chocarrear",
    "chocarreareis": "chocarrear",
    "chocarrearem": "chocarrear",
    "chocarrearemos": "chocarrear",
    "chocarreares": "chocarrear",
    "chocarrearia": "chocarrear",
    "chocarreariam": "chocarrear",
    "chocarrearias": "chocarrear",
    "chocarrearmo": "chocarrear",
    "chocarrearmos": "chocarrear",
    "chocarreará": "chocarrear",
    "chocarrearás": "chocarrear",
    "chocarrearão": "chocarrear",
    "chocarrearíamos": "chocarrear",
    "chocarrearíeis": "chocarrear",
    "chocarreasse": "chocarrear",
    "chocarreassem": "chocarrear",
    "chocarreasses": "chocarrear",
    "chocarreaste": "chocarrear",
    "chocarreastes": "chocarrear",
    "chocarreava": "chocarrear",
    "chocarreavam": "chocarrear",
    "chocarreavas": "chocarrear",
    "chocarreei": "chocarrear",
    "chocarreeis": "chocarrear",
    "chocarreemo": "chocarrear",
    "chocarreemos": "chocarrear",
    "chocarreia": "chocarrear",
    "chocarreiam": "chocarrear",
    "chocarreias": "chocarrear",
    "chocarreie": "chocarrear",
    "chocarreiem": "chocarrear",
    "chocarreies": "chocarrear",
    "chocarreio": "chocarrear",
    "chocarreira": "chocarreiro",
    "chocarreiras": "chocarreiro",
    "chocarreiros": "chocarreiro",
    "chocarreou": "chocarrear",
    "chocarreámo": "chocarrear",
    "chocarreámos": "chocarrear",
    "chocarreáramo": "chocarrear",
    "chocarreáramos": "chocarrear",
    "chocarreáreis": "chocarrear",
    "chocarreásseis": "chocarrear",
    "chocarreássemos": "chocarrear",
    "chocarreávamo": "chocarrear",
    "chocarreávamos": "chocarrear",
    "chocarreáveis": "chocarrear",
    "chocarrices": "chocarrice",
    "chocará": "chocar",
    "chocarás": "chocar",
    "chocarão": "chocar",
    "chocaríamos": "chocar",
    "chocaríeis": "chocar",
    "chocas": "choco",
    "chocasse": "chocar",
    "chocassem": "chocar",
    "chocasses": "chocar",
    "chocaste": "chocar",
    "chocastes": "chocar",
    "chocava": "chocar",
    "chocavam": "chocar",
    "chocavas": "chocar",
    "chocha": "chocho",
    "chochada": "chochar",
    "chochadas": "chochar",
    "chochado": "chochar",
    "chochados": "chochar",
    "chochai": "chochar",
    "chochais": "chochar",
    "chocham": "chochar",
    "chochamo": "chochar",
    "chochamos": "chochar",
    "chochando": "chochar",
    "chochara": "chochar",
    "chocharam": "chochar",
    "chocharas": "chochar",
    "chochardes": "chochar",
    "chocharei": "chochar",
    "chochareis": "chochar",
    "chocharem": "chochar",
    "chocharemos": "chochar",
    "chochares": "chochar",
    "chocharia": "chochar",
    "chochariam": "chochar",
    "chocharias": "chochar",
    "chocharmo": "chochar",
    "chocharmos": "chochar",
    "chochará": "chochar",
    "chocharás": "chochar",
    "chocharão": "chochar",
    "chocharíamos": "chochar",
    "chocharíeis": "chochar",
    "chochas": "chocho",
    "chochasse": "chochar",
    "chochassem": "chochar",
    "chochasses": "chochar",
    "chochaste": "chochar",
    "chochastes": "chochar",
    "chochava": "chochar",
    "chochavam": "chochar",
    "chochavas": "chochar",
    "chochazinha": "chocho",
    "chochazinhas": "chocho",
    "chochazita": "chocho",
    "chochazitas": "chocho",
    "choche": "chochar",
    "chochei": "chochar",
    "chocheis": "chochar",
    "chochem": "chochar",
    "chochemo": "chochar",
    "chochemos": "chochar",
    "choches": "chochar",
    "chochices": "chochice",
    "chochinhas": "chochinha",
    "chocho": "chochar",
    "chochos": "chocho",
    "chochou": "chochar",
    "chochozinho": "chocho",
    "chochozinhos": "chocho",
    "chochozito": "chocho",
    "chochozitos": "chocho",
    "chochámo": "chochar",
    "chochámos": "chochar",
    "chocháramo": "chochar",
    "chocháramos": "chochar",
    "chocháreis": "chochar",
    "chochásseis": "chochar",
    "chochássemos": "chochar",
    "chochávamo": "chochar",
    "chochávamos": "chochar",
    "chocháveis": "chochar",
    "chochíssima": "chocho",
    "chochíssimas": "chocho",
    "chochíssimo": "chocho",
    "chochíssimos": "chocho",
    "choco": "chocar",
    "chocolatarias": "chocolataria",
    "chocolateira": "chocolateiro",
    "chocolateiras": "chocolateiro",
    "chocolateiros": "chocolateiro",
    "chocolates": "chocolate",
    "chocolatezinho": "chocolate",
    "chocolatezinhos": "chocolate",
    "chocolatezito": "chocolate",
    "chocolatezitos": "chocolate",
    "chocolatinho": "chocolate",
    "chocolatinhos": "chocolate",
    "chocolatito": "chocolate",
    "chocolatitos": "chocolate",
    "chocos": "choco",
    "chocou": "chocar",
    "chocá": "chocar",
    "chocámo": "chocar",
    "chocámos": "chocar",
    "chocáramo": "chocar",
    "chocáramos": "chocar",
    "chocárei": "chocar",
    "chocáreis": "chocar",
    "chocásseis": "chocar",
    "chocássemos": "chocar",
    "chocávamo": "chocar",
    "chocávamos": "chocar",
    "chocávei": "chocar",
    "chocáveis": "chocar",
    "chofers": "chofer",
    "chofra": "chofrar",
    "chofrada": "chofrar",
    "chofradas": "chofrar",
    "chofrado": "chofrar",
    "chofrados": "chofrar",
    "chofrai": "chofrar",
    "chofrais": "chofrar",
    "chofram": "chofrar",
    "choframo": "chofrar",
    "choframos": "chofrar",
    "chofrando": "chofrar",
    "chofrara": "chofrar",
    "chofraram": "chofrar",
    "chofraras": "chofrar",
    "chofrarde": "chofrar",
    "chofrardes": "chofrar",
    "chofrare": "chofrar",
    "chofrarei": "chofrar",
    "chofrareis": "chofrar",
    "chofrarem": "chofrar",
    "chofraremos": "chofrar",
    "chofrares": "chofrar",
    "chofraria": "chofrar",
    "chofrariam": "chofrar",
    "chofrarias": "chofrar",
    "chofrarmo": "chofrar",
    "chofrarmos": "chofrar",
    "chofrará": "chofrar",
    "chofrarás": "chofrar",
    "chofrarão": "chofrar",
    "chofraríamos": "chofrar",
    "chofraríeis": "chofrar",
    "chofras": "chofrar",
    "chofrasse": "chofrar",
    "chofrassem": "chofrar",
    "chofrasses": "chofrar",
    "chofraste": "chofrar",
    "chofrastes": "chofrar",
    "chofrava": "chofrar",
    "chofravam": "chofrar",
    "chofravas": "chofrar",
    "chofre": "chofrar",
    "chofrei": "chofrar",
    "chofreira": "chofreiro",
    "chofreiras": "chofreiro",
    "chofreiros": "chofreiro",
    "chofreis": "chofrar",
    "chofrem": "chofrar",
    "chofremo": "chofrar",
    "chofremos": "chofrar",
    "chofres": "chofre",
    "chofristas": "chofrista",
    "chofro": "chofrar",
    "chofrou": "chofrar",
    "chofrá": "chofrar",
    "chofrámo": "chofrar",
    "chofrámos": "chofrar",
    "chofráramo": "chofrar",
    "chofráramos": "chofrar",
    "chofrárei": "chofrar",
    "chofráreis": "chofrar",
    "chofrásseis": "chofrar",
    "chofrássemos": "chofrar",
    "chofrávamo": "chofrar",
    "chofrávamos": "chofrar",
    "chofrávei": "chofrar",
    "chofráveis": "chofrar",
    "choinas": "choina",
    "chois": "choi",
    "cholas": "chola",
    "choldraboldras": "choldraboldra",
    "choldras": "choldra",
    "chona": "chonar",
    "chonada": "chonar",
    "chonadas": "chonar",
    "chonado": "chonar",
    "chonados": "chonar",
    "chonai": "chonar",
    "chonais": "chonar",
    "chonam": "chonar",
    "chonamo": "chonar",
    "chonamos": "chonar",
    "chonando": "chonar",
    "chonara": "chonar",
    "chonaram": "chonar",
    "chonaras": "chonar",
    "chonardes": "chonar",
    "chonarei": "chonar",
    "chonareis": "chonar",
    "chonarem": "chonar",
    "chonaremos": "chonar",
    "chonares": "chonar",
    "chonaria": "chonar",
    "chonariam": "chonar",
    "chonarias": "chonar",
    "chonarmo": "chonar",
    "chonarmos": "chonar",
    "chonará": "chonar",
    "chonarás": "chonar",
    "chonarão": "chonar",
    "chonaríamos": "chonar",
    "chonaríeis": "chonar",
    "chonas": "chonar",
    "chonasse": "chonar",
    "chonassem": "chonar",
    "chonasses": "chonar",
    "chonaste": "chonar",
    "chonastes": "chonar",
    "chonava": "chonar",
    "chonavam": "chonar",
    "chonavas": "chonar",
    "chone": "chonar",
    "chonei": "chonar",
    "choneis": "chonar",
    "chonem": "chonar",
    "chonemo": "chonar",
    "chonemos": "chonar",
    "chones": "chonar",
    "chono": "chonar",
    "chonou": "chonar",
    "chonámo": "chonar",
    "chonámos": "chonar",
    "chonáramo": "chonar",
    "chonáramos": "chonar",
    "chonáreis": "chonar",
    "chonásseis": "chonar",
    "chonássemos": "chonar",
    "chonávamo": "chonar",
    "chonávamos": "chonar",
    "chonáveis": "chonar",
    "chonões": "chonão",
    "chopes": "chope",
    "choque": "chocar",
    "choquei": "chocar",
    "choqueiros": "choqueiro",
    "choqueis": "chocar",
    "choquem": "chocar",
    "choquemo": "chocar",
    "choquemos": "chocar",
    "choquenta": "choquento",
    "choquentas": "choquento",
    "choquentos": "choquento",
    "choques": "choque",
    "choquices": "choquice",
    "choquilhas": "choquilha",
    "choquinho": "choco",
    "choquinhos": "choco",
    "choquito": "choco",
    "choquitos": "choco",
    "choquiços": "choquiço",
    "chora": "chorar",
    "chorada": "chorar",
    "choradas": "chorar",
    "choradazinha": "chorado",
    "choradazinhas": "chorado",
    "choradazita": "chorado",
    "choradazitas": "chorado",
    "choradeiras": "choradeira",
    "choradinhos": "choradinho",
    "chorado": "chorar",
    "chorados": "chorar",
    "choradozinho": "chorado",
    "choradozinhos": "chorado",
    "choradozito": "chorado",
    "choradozitos": "chorado",
    "choradíssima": "chorado",
    "choradíssimas": "chorado",
    "choradíssimo": "chorado",
    "choradíssimos": "chorado",
    "chorai": "chorar",
    "chorais": "chorar",
    "choram": "chorar",
    "choramiga": "choramigar",
    "choramigada": "choramigar",
    "choramigadas": "choramigar",
    "choramigado": "choramigar",
    "choramigados": "choramigar",
    "choramigai": "choramigar",
    "choramigais": "choramigar",
    "choramigam": "choramigar",
    "choramigamo": "choramigar",
    "choramigamos": "choramigar",
    "choramigando": "choramigar",
    "choramigara": "choramigar",
    "choramigaram": "choramigar",
    "choramigaras": "choramigar",
    "choramigardes": "choramigar",
    "choramigarei": "choramigar",
    "choramigareis": "choramigar",
    "choramigarem": "choramigar",
    "choramigaremos": "choramigar",
    "choramigares": "choramigar",
    "choramigaria": "choramigar",
    "choramigariam": "choramigar",
    "choramigarias": "choramigar",
    "choramigarmo": "choramigar",
    "choramigarmos": "choramigar",
    "choramigará": "choramigar",
    "choramigarás": "choramigar",
    "choramigarão": "choramigar",
    "choramigaríamos": "choramigar",
    "choramigaríeis": "choramigar",
    "choramigas": "choramigar",
    "choramigasse": "choramigar",
    "choramigassem": "choramigar",
    "choramigasses": "choramigar",
    "choramigaste": "choramigar",
    "choramigastes": "choramigar",
    "choramigava": "choramigar",
    "choramigavam": "choramigar",
    "choramigavas": "choramigar",
    "choramigo": "choramigar",
    "choramigou": "choramigar",
    "choramigue": "choramigar",
    "choramiguei": "choramigar",
    "choramigueis": "choramigar",
    "choramiguem": "choramigar",
    "choramiguemo": "choramigar",
    "choramiguemos": "choramigar",
    "choramigues": "choramigar",
    "choramigámo": "choramigar",
    "choramigámos": "choramigar",
    "choramigáramo": "choramigar",
    "choramigáramos": "choramigar",
    "choramigáreis": "choramigar",
    "choramigásseis": "choramigar",
    "choramigássemos": "choramigar",
    "choramigávamo": "choramigar",
    "choramigávamos": "choramigar",
    "choramigáveis": "choramigar",
    "choraminga": "choramingar",
    "choramingada": "choramingar",
    "choramingadas": "choramingar",
    "choramingado": "choramingar",
    "choramingadora": "choramingador",
    "choramingadoras": "choramingador",
    "choramingadores": "choramingador",
    "choramingados": "choramingar",
    "choramingai": "choramingar",
    "choramingais": "choramingar",
    "choramingam": "choramingar",
    "choramingamo": "choramingar",
    "choramingamos": "choramingar",
    "choramingando": "choramingar",
    "choramingara": "choramingar",
    "choramingaram": "choramingar",
    "choramingaras": "choramingar",
    "choramingarde": "choramingar",
    "choramingardes": "choramingar",
    "choramingare": "choramingar",
    "choramingarei": "choramingar",
    "choramingareis": "choramingar",
    "choramingarem": "choramingar",
    "choramingaremos": "choramingar",
    "choramingares": "choramingar",
    "choramingaria": "choramingar",
    "choramingariam": "choramingar",
    "choramingarias": "choramingar",
    "choramingarmo": "choramingar",
    "choramingarmos": "choramingar",
    "choramingará": "choramingar",
    "choramingarás": "choramingar",
    "choramingarão": "choramingar",
    "choramingaríamos": "choramingar",
    "choramingaríeis": "choramingar",
    "choramingas": "choramingar",
    "choramingasse": "choramingar",
    "choramingassem": "choramingar",
    "choramingasses": "choramingar",
    "choramingaste": "choramingar",
    "choramingastes": "choramingar",
    "choramingava": "choramingar",
    "choramingavam": "choramingar",
    "choramingavas": "choramingar",
    "choramingo": "choramingar",
    "choramingos": "choramingo",
    "choramingou": "choramingar",
    "choramingue": "choramingar",
    "choraminguei": "choramingar",
    "choramingueira": "choramingueiro",
    "choramingueiras": "choramingueiro",
    "choramingueiros": "choramingueiro",
    "choramingueis": "choramingar",
    "choraminguem": "choramingar",
    "choraminguemo": "choramingar",
    "choraminguemos": "choramingar",
    "choramingues": "choramingar",
    "choramingá": "choramingar",
    "choramingámo": "choramingar",
    "choramingámos": "choramingar",
    "choramingáramo": "choramingar",
    "choramingáramos": "choramingar",
    "choramingárei": "choramingar",
    "choramingáreis": "choramingar",
    "choramingásseis": "choramingar",
    "choramingássemos": "choramingar",
    "choramingávamo": "choramingar",
    "choramingávamos": "choramingar",
    "choramingávei": "choramingar",
    "choramingáveis": "choramingar",
    "choramo": "chorar",
    "choramos": "chorar",
    "chorando": "chorar",
    "chorara": "chorar",
    "choraram": "chorar",
    "choraras": "chorar",
    "chorarde": "chorar",
    "chorardes": "chorar",
    "chorare": "chorar",
    "chorarei": "chorar",
    "chorareis": "chorar",
    "chorarem": "chorar",
    "choraremos": "chorar",
    "chorares": "chorar",
    "choraria": "chorar",
    "chorariam": "chorar",
    "chorarias": "chorar",
    "chorarmo": "chorar",
    "chorarmos": "chorar",
    "chorará": "chorar",
    "chorarás": "chorar",
    "chorarão": "chorar",
    "choraríamos": "chorar",
    "choraríeis": "chorar",
    "choras": "chorar",
    "chorasse": "chorar",
    "chorassem": "chorar",
    "chorasses": "chorar",
    "choraste": "chorar",
    "chorastes": "chorar",
    "chorava": "chorar",
    "choravam": "chorar",
    "choravas": "chorar",
    "chore": "chorar",
    "chorei": "chorar",
    "choreis": "chorar",
    "chorem": "chorar",
    "choremo": "chorar",
    "choremos": "chorar",
    "chores": "chorar",
    "chorinas": "chorina",
    "chorinca": "chorincar",
    "chorincada": "chorincar",
    "chorincadas": "chorincar",
    "chorincado": "chorincar",
    "chorincados": "chorincar",
    "chorincais": "chorincar",
    "chorincam": "chorincar",
    "chorincamo": "chorincar",
    "chorincamos": "chorincar",
    "chorincando": "chorincar",
    "chorincara": "chorincar",
    "chorincaram": "chorincar",
    "chorincaras": "chorincar",
    "chorincardes": "chorincar",
    "chorincarei": "chorincar",
    "chorincareis": "chorincar",
    "chorincarem": "chorincar",
    "chorincaremos": "chorincar",
    "chorincares": "chorincar",
    "chorincaria": "chorincar",
    "chorincariam": "chorincar",
    "chorincarias": "chorincar",
    "chorincarmo": "chorincar",
    "chorincarmos": "chorincar",
    "chorincará": "chorincar",
    "chorincarás": "chorincar",
    "chorincarão": "chorincar",
    "chorincaríamos": "chorincar",
    "chorincaríeis": "chorincar",
    "chorincas": "chorincar",
    "chorincasse": "chorincar",
    "chorincassem": "chorincar",
    "chorincasses": "chorincar",
    "chorincaste": "chorincar",
    "chorincastes": "chorincar",
    "chorincava": "chorincar",
    "chorincavam": "chorincar",
    "chorincavas": "chorincar",
    "chorinco": "chorincar",
    "chorincou": "chorincar",
    "chorincámo": "chorincar",
    "chorincámos": "chorincar",
    "chorincáramo": "chorincar",
    "chorincáramos": "chorincar",
    "chorincáreis": "chorincar",
    "chorincásseis": "chorincar",
    "chorincássemos": "chorincar",
    "chorincávamo": "chorincar",
    "chorincávamos": "chorincar",
    "chorincáveis": "chorincar",
    "chorinho": "choro",
    "chorinhos": "choro",
    "chorinque": "chorincar",
    "chorinquei": "chorincar",
    "chorinqueis": "chorincar",
    "chorinquem": "chorincar",
    "chorinquemos": "chorincar",
    "chorinquenta": "chorinquento",
    "chorinquentas": "chorinquento",
    "chorinquentos": "chorinquento",
    "chorinques": "chorincar",
    "chorito": "choro",
    "choritos": "choro",
    "choro": "chorar",
    "chorona": "chorão",
    "choronas": "chorão",
    "choronazinha": "chorão",
    "choronazinhas": "chorão",
    "choronazita": "chorão",
    "choronazitas": "chorão",
    "choros": "choro",
    "chorosa": "choroso",
    "chorosas": "choroso",
    "chorosos": "choroso",
    "chorou": "chorar",
    "chorreiras": "chorreira",
    "chorreiros": "chorreiro",
    "chorrilha": "chorrilhar",
    "chorrilhada": "chorrilhar",
    "chorrilhadas": "chorrilhar",
    "chorrilhado": "chorrilhar",
    "chorrilhados": "chorrilhar",
    "chorrilhai": "chorrilhar",
    "chorrilhais": "chorrilhar",
    "chorrilham": "chorrilhar",
    "chorrilhamo": "chorrilhar",
    "chorrilhamos": "chorrilhar",
    "chorrilhando": "chorrilhar",
    "chorrilhara": "chorrilhar",
    "chorrilharam": "chorrilhar",
    "chorrilharas": "chorrilhar",
    "chorrilharde": "chorrilhar",
    "chorrilhardes": "chorrilhar",
    "chorrilhare": "chorrilhar",
    "chorrilharei": "chorrilhar",
    "chorrilhareis": "chorrilhar",
    "chorrilharem": "chorrilhar",
    "chorrilharemos": "chorrilhar",
    "chorrilhares": "chorrilhar",
    "chorrilharia": "chorrilhar",
    "chorrilhariam": "chorrilhar",
    "chorrilharias": "chorrilhar",
    "chorrilharmo": "chorrilhar",
    "chorrilharmos": "chorrilhar",
    "chorrilhará": "chorrilhar",
    "chorrilharás": "chorrilhar",
    "chorrilharão": "chorrilhar",
    "chorrilharíamos": "chorrilhar",
    "chorrilharíeis": "chorrilhar",
    "chorrilhas": "chorrilhar",
    "chorrilhasse": "chorrilhar",
    "chorrilhassem": "chorrilhar",
    "chorrilhasses": "chorrilhar",
    "chorrilhaste": "chorrilhar",
    "chorrilhastes": "chorrilhar",
    "chorrilhava": "chorrilhar",
    "chorrilhavam": "chorrilhar",
    "chorrilhavas": "chorrilhar",
    "chorrilhe": "chorrilhar",
    "chorrilhei": "chorrilhar",
    "chorrilheis": "chorrilhar",
    "chorrilhem": "chorrilhar",
    "chorrilhemo": "chorrilhar",
    "chorrilhemos": "chorrilhar",
    "chorrilhes": "chorrilhar",
    "chorrilho": "chorrilhar",
    "chorrilhos": "chorrilho",
    "chorrilhou": "chorrilhar",
    "chorrilhá": "chorrilhar",
    "chorrilhámo": "chorrilhar",
    "chorrilhámos": "chorrilhar",
    "chorrilháramo": "chorrilhar",
    "chorrilháramos": "chorrilhar",
    "chorrilhárei": "chorrilhar",
    "chorrilháreis": "chorrilhar",
    "chorrilhásseis": "chorrilhar",
    "chorrilhássemos": "chorrilhar",
    "chorrilhávamo": "chorrilhar",
    "chorrilhávamos": "chorrilhar",
    "chorrilhávei": "chorrilhar",
    "chorrilháveis": "chorrilhar",
    "chorrisca": "chorriscar",
    "chorriscada": "chorriscar",
    "chorriscadas": "chorriscar",
    "chorriscado": "chorriscar",
    "chorriscados": "chorriscar",
    "chorriscai": "chorriscar",
    "chorriscais": "chorriscar",
    "chorriscam": "chorriscar",
    "chorriscamo": "chorriscar",
    "chorriscamos": "chorriscar",
    "chorriscando": "chorriscar",
    "chorriscara": "chorriscar",
    "chorriscaram": "chorriscar",
    "chorriscaras": "chorriscar",
    "chorriscarde": "chorriscar",
    "chorriscardes": "chorriscar",
    "chorriscare": "chorriscar",
    "chorriscarei": "chorriscar",
    "chorriscareis": "chorriscar",
    "chorriscarem": "chorriscar",
    "chorriscaremos": "chorriscar",
    "chorriscares": "chorriscar",
    "chorriscaria": "chorriscar",
    "chorriscariam": "chorriscar",
    "chorriscarias": "chorriscar",
    "chorriscarmo": "chorriscar",
    "chorriscarmos": "chorriscar",
    "chorriscará": "chorriscar",
    "chorriscarás": "chorriscar",
    "chorriscarão": "chorriscar",
    "chorriscaríamos": "chorriscar",
    "chorriscaríeis": "chorriscar",
    "chorriscas": "chorriscar",
    "chorriscasse": "chorriscar",
    "chorriscassem": "chorriscar",
    "chorriscasses": "chorriscar",
    "chorriscaste": "chorriscar",
    "chorriscastes": "chorriscar",
    "chorriscava": "chorriscar",
    "chorriscavam": "chorriscar",
    "chorriscavas": "chorriscar",
    "chorrisco": "chorriscar",
    "chorriscou": "chorriscar",
    "chorriscá": "chorriscar",
    "chorriscámo": "chorriscar",
    "chorriscámos": "chorriscar",
    "chorriscáramo": "chorriscar",
    "chorriscáramos": "chorriscar",
    "chorriscárei": "chorriscar",
    "chorriscáreis": "chorriscar",
    "chorriscásseis": "chorriscar",
    "chorriscássemos": "chorriscar",
    "chorriscávamo": "chorriscar",
    "chorriscávamos": "chorriscar",
    "chorriscávei": "chorriscar",
    "chorriscáveis": "chorriscar",
    "chorrisque": "chorriscar",
    "chorrisquei": "chorriscar",
    "chorrisqueis": "chorriscar",
    "chorrisquem": "chorriscar",
    "chorrisquemo": "chorriscar",
    "chorrisquemos": "chorriscar",
    "chorrisques": "chorriscar",
    "choruda": "chorudo",
    "chorudas": "chorudo",
    "chorudos": "chorudo",
    "chorumenta": "chorumento",
    "chorumentas": "chorumento",
    "chorumentos": "chorumento",
    "chorumes": "chorume",
    "chorá": "chorar",
    "chorámo": "chorar",
    "chorámos": "chorar",
    "choráramo": "chorar",
    "choráramos": "chorar",
    "chorárei": "chorar",
    "choráreis": "chorar",
    "chorásseis": "chorar",
    "chorássemos": "chorar",
    "chorávamo": "chorar",
    "chorávamos": "chorar",
    "chorávei": "chorar",
    "choráveis": "chorar",
    "chorãozinho": "chorão",
    "chorãozito": "chorão",
    "chorões": "chorão",
    "chorõezinhos": "chorão",
    "chorõezitos": "chorão",
    "chouchas": "choucha",
    "choupa": "choupar",
    "choupada": "choupar",
    "choupadas": "choupar",
    "choupado": "choupar",
    "choupados": "choupar",
    "choupai": "choupar",
    "choupais": "choupar",
    "choupam": "choupar",
    "choupamo": "choupar",
    "choupamos": "choupar",
    "choupanas": "choupana",
    "choupando": "choupar",
    "choupaneira": "choupaneiro",
    "choupaneiras": "choupaneiro",
    "choupaneiros": "choupaneiro",
    "choupara": "choupar",
    "chouparam": "choupar",
    "chouparas": "choupar",
    "chouparde": "choupar",
    "choupardes": "choupar",
    "choupare": "choupar",
    "chouparei": "choupar",
    "choupareis": "choupar",
    "chouparem": "choupar",
    "chouparemos": "choupar",
    "choupares": "choupar",
    "chouparia": "choupar",
    "choupariam": "choupar",
    "chouparias": "choupar",
    "chouparmo": "choupar",
    "chouparmos": "choupar",
    "choupará": "choupar",
    "chouparás": "choupar",
    "chouparão": "choupar",
    "chouparíamos": "choupar",
    "chouparíeis": "choupar",
    "choupas": "choupar",
    "choupasse": "choupar",
    "choupassem": "choupar",
    "choupasses": "choupar",
    "choupaste": "choupar",
    "choupastes": "choupar",
    "choupava": "choupar",
    "choupavam": "choupar",
    "choupavas": "choupar",
    "choupe": "choupar",
    "choupei": "choupar",
    "choupeiros": "choupeiro",
    "choupeis": "choupar",
    "choupem": "choupar",
    "choupemo": "choupar",
    "choupemos": "choupar",
    "choupes": "choupar",
    "choupo": "choupar",
    "choupos": "choupo",
    "choupou": "choupar",
    "choupá": "choupar",
    "choupámo": "choupar",
    "choupámos": "choupar",
    "choupáramo": "choupar",
    "choupáramos": "choupar",
    "choupárei": "choupar",
    "choupáreis": "choupar",
    "choupásseis": "choupar",
    "choupássemos": "choupar",
    "choupávamo": "choupar",
    "choupávamos": "choupar",
    "choupávei": "choupar",
    "choupáveis": "choupar",
    "chouras": "choura",
    "chouriceira": "chouriceiro",
    "chouriceiras": "chouriceiro",
    "chouriceiros": "chouriceiro",
    "chouricinha": "chouriça",
    "chouricinhas": "chouriça",
    "chouricinho": "chouriço",
    "chouricinhos": "chouriço",
    "chouricita": "chouriça",
    "chouricitas": "chouriça",
    "chouricito": "chouriço",
    "chouricitos": "chouriço",
    "chouriçadas": "chouriçada",
    "chouriças": "chouriça",
    "chouriços": "chouriço",
    "chourições": "chourição",
    "chouréns": "chourém",
    "chousa": "chousar",
    "chousada": "chousar",
    "chousadas": "chousar",
    "chousado": "chousar",
    "chousados": "chousar",
    "chousai": "chousar",
    "chousais": "chousar",
    "chousam": "chousar",
    "chousamo": "chousar",
    "chousamos": "chousar",
    "chousando": "chousar",
    "chousara": "chousar",
    "chousaram": "chousar",
    "chousaras": "chousar",
    "chousarde": "chousar",
    "chousardes": "chousar",
    "chousare": "chousar",
    "chousarei": "chousar",
    "chousareis": "chousar",
    "chousarem": "chousar",
    "chousaremos": "chousar",
    "chousares": "chousar",
    "chousaria": "chousar",
    "chousariam": "chousar",
    "chousarias": "chousar",
    "chousarmo": "chousar",
    "chousarmos": "chousar",
    "chousará": "chousar",
    "chousarás": "chousar",
    "chousarão": "chousar",
    "chousaríamos": "chousar",
    "chousaríeis": "chousar",
    "chousas": "chousar",
    "chousasse": "chousar",
    "chousassem": "chousar",
    "chousasses": "chousar",
    "chousaste": "chousar",
    "chousastes": "chousar",
    "chousava": "chousar",
    "chousavam": "chousar",
    "chousavas": "chousar",
    "chouse": "chousar",
    "chousei": "chousar",
    "chouseiras": "chouseira",
    "chouseis": "chousar",
    "chousem": "chousar",
    "chousemo": "chousar",
    "chousemos": "chousar",
    "chouses": "chousar",
    "chouso": "chousar",
    "chousos": "chouso",
    "chousou": "chousar",
    "choussa": "choussar",
    "choussada": "choussar",
    "choussadas": "choussar",
    "choussado": "choussar",
    "choussados": "choussar",
    "choussai": "choussar",
    "choussais": "choussar",
    "choussam": "choussar",
    "choussamo": "choussar",
    "choussamos": "choussar",
    "choussando": "choussar",
    "choussara": "choussar",
    "choussaram": "choussar",
    "choussaras": "choussar",
    "choussarde": "choussar",
    "choussardes": "choussar",
    "choussare": "choussar",
    "choussarei": "choussar",
    "choussareis": "choussar",
    "choussarem": "choussar",
    "choussaremos": "choussar",
    "choussares": "choussar",
    "choussaria": "choussar",
    "choussariam": "choussar",
    "choussarias": "choussar",
    "choussarmo": "choussar",
    "choussarmos": "choussar",
    "choussará": "choussar",
    "choussarás": "choussar",
    "choussarão": "choussar",
    "choussaríamos": "choussar",
    "choussaríeis": "choussar",
    "choussas": "choussar",
    "choussasse": "choussar",
    "choussassem": "choussar",
    "choussasses": "choussar",
    "choussaste": "choussar",
    "choussastes": "choussar",
    "choussava": "choussar",
    "choussavam": "choussar",
    "choussavas": "choussar",
    "chousse": "choussar",
    "choussei": "choussar",
    "chousseiras": "chousseira",
    "chousseis": "choussar",
    "choussem": "choussar",
    "choussemo": "choussar",
    "choussemos": "choussar",
    "chousses": "choussar",
    "chousso": "choussar",
    "choussou": "choussar",
    "choussá": "choussar",
    "choussámo": "choussar",
    "choussámos": "choussar",
    "choussáramo": "choussar",
    "choussáramos": "choussar",
    "choussárei": "choussar",
    "choussáreis": "choussar",
    "choussásseis": "choussar",
    "choussássemos": "choussar",
    "choussávamo": "choussar",
    "choussávamos": "choussar",
    "choussávei": "choussar",
    "choussáveis": "choussar",
    "chousuras": "chousura",
    "chousá": "chousar",
    "chousámo": "chousar",
    "chousámos": "chousar",
    "chousáramo": "chousar",
    "chousáramos": "chousar",
    "chousárei": "chousar",
    "chousáreis": "chousar",
    "chousásseis": "chousar",
    "chousássemos": "chousar",
    "chousávamo": "chousar",
    "chousávamos": "chousar",
    "chousávei": "chousar",
    "chousáveis": "chousar",
    "chouta": "choutar",
    "choutada": "choutar",
    "choutadas": "choutar",
    "choutado": "choutar",
    "choutadora": "choutador",
    "choutadoras": "choutador",
    "choutadores": "choutador",
    "choutados": "choutar",
    "choutai": "choutar",
    "choutais": "choutar",
    "choutam": "choutar",
    "choutamo": "choutar",
    "choutamos": "choutar",
    "choutando": "choutar",
    "choutara": "choutar",
    "choutaram": "choutar",
    "choutaras": "choutar",
    "choutardes": "choutar",
    "choutarei": "choutar",
    "choutareis": "choutar",
    "choutarem": "choutar",
    "choutaremos": "choutar",
    "choutares": "choutar",
    "choutaria": "choutar",
    "choutariam": "choutar",
    "choutarias": "choutar",
    "choutarmo": "choutar",
    "choutarmos": "choutar",
    "choutará": "choutar",
    "choutarás": "choutar",
    "choutarão": "choutar",
    "choutaríamos": "choutar",
    "choutaríeis": "choutar",
    "choutas": "choutar",
    "choutasse": "choutar",
    "choutassem": "choutar",
    "choutasses": "choutar",
    "choutaste": "choutar",
    "choutastes": "choutar",
    "choutava": "choutar",
    "choutavam": "choutar",
    "choutavas": "choutar",
    "choute": "choutar",
    "chouteada": "choutear",
    "chouteadas": "choutear",
    "chouteado": "choutear",
    "chouteados": "choutear",
    "chouteai": "choutear",
    "chouteais": "choutear",
    "chouteamo": "choutear",
    "chouteamos": "choutear",
    "chouteando": "choutear",
    "chouteara": "choutear",
    "choutearam": "choutear",
    "choutearas": "choutear",
    "chouteardes": "choutear",
    "choutearei": "choutear",
    "chouteareis": "choutear",
    "choutearem": "choutear",
    "choutearemos": "choutear",
    "chouteares": "choutear",
    "choutearia": "choutear",
    "chouteariam": "choutear",
    "choutearias": "choutear",
    "choutearmo": "choutear",
    "choutearmos": "choutear",
    "chouteará": "choutear",
    "choutearás": "choutear",
    "choutearão": "choutear",
    "choutearíamos": "choutear",
    "choutearíeis": "choutear",
    "chouteasse": "choutear",
    "chouteassem": "choutear",
    "chouteasses": "choutear",
    "chouteaste": "choutear",
    "chouteastes": "choutear",
    "chouteava": "choutear",
    "chouteavam": "choutear",
    "chouteavas": "choutear",
    "chouteei": "choutear",
    "chouteeis": "choutear",
    "chouteemo": "choutear",
    "chouteemos": "choutear",
    "choutei": "choutar",
    "chouteia": "choutear",
    "chouteiam": "choutear",
    "chouteias": "choutear",
    "chouteie": "choutear",
    "chouteiem": "choutear",
    "chouteies": "choutear",
    "chouteio": "choutear",
    "chouteira": "chouteiro",
    "chouteiras": "chouteiro",
    "chouteiros": "chouteiro",
    "chouteis": "choutar",
    "choutem": "choutar",
    "choutemo": "choutar",
    "choutemos": "choutar",
    "chouteou": "choutear",
    "choutes": "choutar",
    "chouteámo": "choutear",
    "chouteámos": "choutear",
    "chouteáramo": "choutear",
    "chouteáramos": "choutear",
    "chouteáreis": "choutear",
    "chouteásseis": "choutear",
    "chouteássemos": "choutear",
    "chouteávamo": "choutear",
    "chouteávamos": "choutear",
    "chouteáveis": "choutear",
    "chouto": "choutar",
    "choutona": "choutão",
    "choutonas": "choutão",
    "choutos": "chouto",
    "choutou": "choutar",
    "choutámo": "choutar",
    "choutámos": "choutar",
    "choutáramo": "choutar",
    "choutáramos": "choutar",
    "choutáreis": "choutar",
    "choutásseis": "choutar",
    "choutássemos": "choutar",
    "choutávamo": "choutar",
    "choutávamos": "choutar",
    "choutáveis": "choutar",
    "choutões": "choutão",
    "chova": "chover",
    "chovam": "chover",
    "chove": "chover",
    "chovediça": "chovediço",
    "chovediças": "chovediço",
    "chovediços": "chovediço",
    "chovedora": "chovedor",
    "chovedoras": "chovedor",
    "chovedores": "chovedor",
    "chovem": "chover",
    "chovendo": "chover",
    "chovera": "chover",
    "choveram": "chover",
    "choverem": "chover",
    "choveria": "chover",
    "choveriam": "chover",
    "choverá": "chover",
    "choverão": "chover",
    "chovesse": "chover",
    "chovessem": "chover",
    "choveu": "chover",
    "chovia": "chover",
    "choviam": "chover",
    "chovida": "chovido",
    "chovidas": "chovido",
    "chovido": "chover",
    "chovidos": "chovido",
    "choças": "choça",
    "choços": "choço",
    "chuangas": "chuanga",
    "chucas": "chuca",
    "chuce": "chuçar",
    "chucei": "chuçar",
    "chuceis": "chuçar",
    "chucem": "chuçar",
    "chucemo": "chuçar",
    "chucemos": "chuçar",
    "chuces": "chuçar",
    "chucha": "chuchar",
    "chuchada": "chuchar",
    "chuchadas": "chuchar",
    "chuchadeiras": "chuchadeira",
    "chuchado": "chuchar",
    "chuchados": "chuchar",
    "chuchai": "chuchar",
    "chuchais": "chuchar",
    "chucham": "chuchar",
    "chuchamo": "chuchar",
    "chuchamos": "chuchar",
    "chuchando": "chuchar",
    "chuchara": "chuchar",
    "chucharam": "chuchar",
    "chucharas": "chuchar",
    "chucharde": "chuchar",
    "chuchardes": "chuchar",
    "chuchare": "chuchar",
    "chucharei": "chuchar",
    "chuchareis": "chuchar",
    "chucharem": "chuchar",
    "chucharemos": "chuchar",
    "chuchares": "chuchar",
    "chucharia": "chuchar",
    "chuchariam": "chuchar",
    "chucharias": "chuchar",
    "chucharmo": "chuchar",
    "chucharmos": "chuchar",
    "chucharrona": "chucharrão",
    "chucharronas": "chucharrão",
    "chucharrões": "chucharrão",
    "chuchará": "chuchar",
    "chucharás": "chuchar",
    "chucharão": "chuchar",
    "chucharíamos": "chuchar",
    "chucharíeis": "chuchar",
    "chuchas": "chuchar",
    "chuchasse": "chuchar",
    "chuchassem": "chuchar",
    "chuchasses": "chuchar",
    "chuchaste": "chuchar",
    "chuchastes": "chuchar",
    "chuchava": "chuchar",
    "chuchavam": "chuchar",
    "chuchavas": "chuchar",
    "chuche": "chuchar",
    "chuchei": "chuchar",
    "chucheis": "chuchar",
    "chuchem": "chuchar",
    "chuchemo": "chuchar",
    "chuchemos": "chuchar",
    "chuches": "chuchar",
    "chuchinha": "chucha",
    "chuchinhas": "chucha",
    "chuchita": "chucha",
    "chuchitas": "chucha",
    "chucho": "chuchar",
    "chuchos": "chucho",
    "chuchou": "chuchar",
    "chuchurreada": "chuchurrear",
    "chuchurreadas": "chuchurrear",
    "chuchurreado": "chuchurrear",
    "chuchurreados": "chuchurrear",
    "chuchurreai": "chuchurrear",
    "chuchurreais": "chuchurrear",
    "chuchurreamo": "chuchurrear",
    "chuchurreamos": "chuchurrear",
    "chuchurreando": "chuchurrear",
    "chuchurreara": "chuchurrear",
    "chuchurrearam": "chuchurrear",
    "chuchurrearas": "chuchurrear",
    "chuchurrearde": "chuchurrear",
    "chuchurreardes": "chuchurrear",
    "chuchurreare": "chuchurrear",
    "chuchurrearei": "chuchurrear",
    "chuchurreareis": "chuchurrear",
    "chuchurrearem": "chuchurrear",
    "chuchurrearemos": "chuchurrear",
    "chuchurreares": "chuchurrear",
    "chuchurrearia": "chuchurrear",
    "chuchurreariam": "chuchurrear",
    "chuchurrearias": "chuchurrear",
    "chuchurrearmo": "chuchurrear",
    "chuchurrearmos": "chuchurrear",
    "chuchurreará": "chuchurrear",
    "chuchurrearás": "chuchurrear",
    "chuchurrearão": "chuchurrear",
    "chuchurrearíamos": "chuchurrear",
    "chuchurrearíeis": "chuchurrear",
    "chuchurreasse": "chuchurrear",
    "chuchurreassem": "chuchurrear",
    "chuchurreasses": "chuchurrear",
    "chuchurreaste": "chuchurrear",
    "chuchurreastes": "chuchurrear",
    "chuchurreava": "chuchurrear",
    "chuchurreavam": "chuchurrear",
    "chuchurreavas": "chuchurrear",
    "chuchurreei": "chuchurrear",
    "chuchurreeis": "chuchurrear",
    "chuchurreemo": "chuchurrear",
    "chuchurreemos": "chuchurrear",
    "chuchurreia": "chuchurrear",
    "chuchurreiam": "chuchurrear",
    "chuchurreias": "chuchurrear",
    "chuchurreie": "chuchurrear",
    "chuchurreiem": "chuchurrear",
    "chuchurreies": "chuchurrear",
    "chuchurreio": "chuchurrear",
    "chuchurreios": "chuchurreio",
    "chuchurreou": "chuchurrear",
    "chuchurreá": "chuchurrear",
    "chuchurreámo": "chuchurrear",
    "chuchurreámos": "chuchurrear",
    "chuchurreáramo": "chuchurrear",
    "chuchurreáramos": "chuchurrear",
    "chuchurreárei": "chuchurrear",
    "chuchurreáreis": "chuchurrear",
    "chuchurreásseis": "chuchurrear",
    "chuchurreássemos": "chuchurrear",
    "chuchurreávamo": "chuchurrear",
    "chuchurreávamos": "chuchurrear",
    "chuchurreávei": "chuchurrear",
    "chuchurreáveis": "chuchurrear",
    "chuchurrubiada": "chuchurrubiado",
    "chuchurrubiadas": "chuchurrubiado",
    "chuchurrubiados": "chuchurrubiado",
    "chuchus": "chuchu",
    "chuchuzeiros": "chuchuzeiro",
    "chuchá": "chuchar",
    "chuchámo": "chuchar",
    "chuchámos": "chuchar",
    "chucháramo": "chuchar",
    "chucháramos": "chuchar",
    "chuchárei": "chuchar",
    "chucháreis": "chuchar",
    "chuchásseis": "chuchar",
    "chuchássemos": "chuchar",
    "chuchávamo": "chuchar",
    "chuchávamos": "chuchar",
    "chuchávei": "chuchar",
    "chucháveis": "chuchar",
    "chucrutes": "chucrute",
    "chufa": "chufar",
    "chufada": "chufar",
    "chufadas": "chufar",
    "chufado": "chufar",
    "chufados": "chufar",
    "chufai": "chufar",
    "chufais": "chufar",
    "chufam": "chufar",
    "chufamo": "chufar",
    "chufamos": "chufar",
    "chufando": "chufar",
    "chufara": "chufar",
    "chufaram": "chufar",
    "chufaras": "chufar",
    "chufarde": "chufar",
    "chufardes": "chufar",
    "chufare": "chufar",
    "chufarei": "chufar",
    "chufareis": "chufar",
    "chufarem": "chufar",
    "chufaremos": "chufar",
    "chufares": "chufar",
    "chufaria": "chufar",
    "chufariam": "chufar",
    "chufarias": "chufar",
    "chufarmo": "chufar",
    "chufarmos": "chufar",
    "chufará": "chufar",
    "chufarás": "chufar",
    "chufarão": "chufar",
    "chufaríamos": "chufar",
    "chufaríeis": "chufar",
    "chufas": "chufar",
    "chufasse": "chufar",
    "chufassem": "chufar",
    "chufasses": "chufar",
    "chufaste": "chufar",
    "chufastes": "chufar",
    "chufava": "chufar",
    "chufavam": "chufar",
    "chufavas": "chufar",
    "chufazinha": "chufa",
    "chufazinhas": "chufa",
    "chufazita": "chufa",
    "chufazitas": "chufa",
    "chufe": "chufar",
    "chufei": "chufar",
    "chufeis": "chufar",
    "chufem": "chufar",
    "chufemo": "chufar",
    "chufemos": "chufar",
    "chufes": "chufar",
    "chufinha": "chufa",
    "chufinhas": "chufa",
    "chufistas": "chufista",
    "chufita": "chufa",
    "chufitas": "chufa",
    "chufo": "chufar",
    "chufou": "chufar",
    "chufá": "chufar",
    "chufámo": "chufar",
    "chufámos": "chufar",
    "chufáramo": "chufar",
    "chufáramos": "chufar",
    "chufárei": "chufar",
    "chufáreis": "chufar",
    "chufásseis": "chufar",
    "chufássemos": "chufar",
    "chufávamo": "chufar",
    "chufávamos": "chufar",
    "chufávei": "chufar",
    "chufáveis": "chufar",
    "chuinhos": "chuinho",
    "chula": "chulo",
    "chulas": "chulo",
    "chuleios": "chuleio",
    "chulesca": "chulesco",
    "chulescas": "chulesco",
    "chulescos": "chulesco",
    "chulices": "chulice",
    "chulipas": "chulipa",
    "chulismos": "chulismo",
    "chulistas": "chulista",
    "chulos": "chulo",
    "chulés": "chulé",
    "chumace": "chumaçar",
    "chumacei": "chumaçar",
    "chumaceiras": "chumaceira",
    "chumaceis": "chumaçar",
    "chumacem": "chumaçar",
    "chumacemo": "chumaçar",
    "chumacemos": "chumaçar",
    "chumaces": "chumaçar",
    "chumacetes": "chumacete",
    "chumaça": "chumaçar",
    "chumaçada": "chumaçar",
    "chumaçadas": "chumaçar",
    "chumaçado": "chumaçar",
    "chumaçados": "chumaçar",
    "chumaçai": "chumaçar",
    "chumaçais": "chumaçar",
    "chumaçam": "chumaçar",
    "chumaçamo": "chumaçar",
    "chumaçamos": "chumaçar",
    "chumaçando": "chumaçar",
    "chumaçara": "chumaçar",
    "chumaçaram": "chumaçar",
    "chumaçaras": "chumaçar",
    "chumaçarde": "chumaçar",
    "chumaçardes": "chumaçar",
    "chumaçare": "chumaçar",
    "chumaçarei": "chumaçar",
    "chumaçareis": "chumaçar",
    "chumaçarem": "chumaçar",
    "chumaçaremos": "chumaçar",
    "chumaçares": "chumaçar",
    "chumaçaria": "chumaçar",
    "chumaçariam": "chumaçar",
    "chumaçarias": "chumaçar",
    "chumaçarmo": "chumaçar",
    "chumaçarmos": "chumaçar",
    "chumaçará": "chumaçar",
    "chumaçarás": "chumaçar",
    "chumaçarão": "chumaçar",
    "chumaçaríamos": "chumaçar",
    "chumaçaríeis": "chumaçar",
    "chumaças": "chumaçar",
    "chumaçasse": "chumaçar",
    "chumaçassem": "chumaçar",
    "chumaçasses": "chumaçar",
    "chumaçaste": "chumaçar",
    "chumaçastes": "chumaçar",
    "chumaçava": "chumaçar",
    "chumaçavam": "chumaçar",
    "chumaçavas": "chumaçar",
    "chumaço": "chumaçar",
    "chumaços": "chumaço",
    "chumaçou": "chumaçar",
    "chumaçá": "chumaçar",
    "chumaçámo": "chumaçar",
    "chumaçámos": "chumaçar",
    "chumaçáramo": "chumaçar",
    "chumaçáramos": "chumaçar",
    "chumaçárei": "chumaçar",
    "chumaçáreis": "chumaçar",
    "chumaçásseis": "chumaçar",
    "chumaçássemos": "chumaçar",
    "chumaçávamo": "chumaçar",
    "chumaçávamos": "chumaçar",
    "chumaçávei": "chumaçar",
    "chumaçáveis": "chumaçar",
    "chumba": "chumbar",
    "chumbada": "chumbar",
    "chumbadas": "chumbar",
    "chumbado": "chumbar",
    "chumbadoiros": "chumbadoiro",
    "chumbados": "chumbar",
    "chumbadouros": "chumbadouro",
    "chumbagens": "chumbagem",
    "chumbai": "chumbar",
    "chumbais": "chumbar",
    "chumbam": "chumbar",
    "chumbamo": "chumbar",
    "chumbamos": "chumbar",
    "chumbando": "chumbar",
    "chumbara": "chumbar",
    "chumbaram": "chumbar",
    "chumbaras": "chumbar",
    "chumbarde": "chumbar",
    "chumbardes": "chumbar",
    "chumbare": "chumbar",
    "chumbarei": "chumbar",
    "chumbareis": "chumbar",
    "chumbarem": "chumbar",
    "chumbaremos": "chumbar",
    "chumbares": "chumbar",
    "chumbaria": "chumbar",
    "chumbariam": "chumbar",
    "chumbarias": "chumbaria",
    "chumbarmo": "chumbar",
    "chumbarmos": "chumbar",
    "chumbará": "chumbar",
    "chumbarás": "chumbar",
    "chumbarão": "chumbar",
    "chumbaríamos": "chumbar",
    "chumbaríeis": "chumbar",
    "chumbas": "chumbar",
    "chumbasse": "chumbar",
    "chumbassem": "chumbar",
    "chumbasses": "chumbar",
    "chumbaste": "chumbar",
    "chumbastes": "chumbar",
    "chumbava": "chumbar",
    "chumbavam": "chumbar",
    "chumbavas": "chumbar",
    "chumbe": "chumbar",
    "chumbeada": "chumbear",
    "chumbeadas": "chumbear",
    "chumbeado": "chumbear",
    "chumbeados": "chumbear",
    "chumbeai": "chumbear",
    "chumbeais": "chumbear",
    "chumbeamo": "chumbear",
    "chumbeamos": "chumbear",
    "chumbeando": "chumbear",
    "chumbeara": "chumbear",
    "chumbearam": "chumbear",
    "chumbearas": "chumbear",
    "chumbearde": "chumbear",
    "chumbeardes": "chumbear",
    "chumbeare": "chumbear",
    "chumbearei": "chumbear",
    "chumbeareis": "chumbear",
    "chumbearem": "chumbear",
    "chumbearemos": "chumbear",
    "chumbeares": "chumbear",
    "chumbearia": "chumbear",
    "chumbeariam": "chumbear",
    "chumbearias": "chumbear",
    "chumbearmo": "chumbear",
    "chumbearmos": "chumbear",
    "chumbeará": "chumbear",
    "chumbearás": "chumbear",
    "chumbearão": "chumbear",
    "chumbearíamos": "chumbear",
    "chumbearíeis": "chumbear",
    "chumbeasse": "chumbear",
    "chumbeassem": "chumbear",
    "chumbeasses": "chumbear",
    "chumbeaste": "chumbear",
    "chumbeastes": "chumbear",
    "chumbeava": "chumbear",
    "chumbeavam": "chumbear",
    "chumbeavas": "chumbear",
    "chumbeei": "chumbear",
    "chumbeeis": "chumbear",
    "chumbeemo": "chumbear",
    "chumbeemos": "chumbear",
    "chumbei": "chumbar",
    "chumbeia": "chumbear",
    "chumbeiam": "chumbear",
    "chumbeias": "chumbear",
    "chumbeie": "chumbear",
    "chumbeiem": "chumbear",
    "chumbeies": "chumbear",
    "chumbeio": "chumbear",
    "chumbeiras": "chumbeira",
    "chumbeis": "chumbar",
    "chumbem": "chumbar",
    "chumbemo": "chumbar",
    "chumbemos": "chumbar",
    "chumbeou": "chumbear",
    "chumbes": "chumbar",
    "chumbeá": "chumbear",
    "chumbeámo": "chumbear",
    "chumbeámos": "chumbear",
    "chumbeáramo": "chumbear",
    "chumbeáramos": "chumbear",
    "chumbeárei": "chumbear",
    "chumbeáreis": "chumbear",
    "chumbeásseis": "chumbear",
    "chumbeássemos": "chumbear",
    "chumbeávamo": "chumbear",
    "chumbeávamos": "chumbear",
    "chumbeávei": "chumbear",
    "chumbeáveis": "chumbear",
    "chumbinho": "chumbo",
    "chumbinhos": "chumbo",
    "chumbito": "chumbo",
    "chumbitos": "chumbo",
    "chumbo": "chumbar",
    "chumbos": "chumbo",
    "chumbou": "chumbar",
    "chumbá": "chumbar",
    "chumbámo": "chumbar",
    "chumbámos": "chumbar",
    "chumbáramo": "chumbar",
    "chumbáramos": "chumbar",
    "chumbárei": "chumbar",
    "chumbáreis": "chumbar",
    "chumbásseis": "chumbar",
    "chumbássemos": "chumbar",
    "chumbávamo": "chumbar",
    "chumbávamos": "chumbar",
    "chumbávei": "chumbar",
    "chumbáveis": "chumbável",
    "chumeada": "chumear",
    "chumeadas": "chumear",
    "chumeado": "chumear",
    "chumeados": "chumear",
    "chumeai": "chumear",
    "chumeais": "chumear",
    "chumeamo": "chumear",
    "chumeamos": "chumear",
    "chumeando": "chumear",
    "chumeara": "chumear",
    "chumearam": "chumear",
    "chumearas": "chumear",
    "chumearde": "chumear",
    "chumeardes": "chumear",
    "chumeare": "chumear",
    "chumearei": "chumear",
    "chumeareis": "chumear",
    "chumearem": "chumear",
    "chumearemos": "chumear",
    "chumeares": "chumear",
    "chumearia": "chumear",
    "chumeariam": "chumear",
    "chumearias": "chumear",
    "chumearmo": "chumear",
    "chumearmos": "chumear",
    "chumeará": "chumear",
    "chumearás": "chumear",
    "chumearão": "chumear",
    "chumearíamos": "chumear",
    "chumearíeis": "chumear",
    "chumeasse": "chumear",
    "chumeassem": "chumear",
    "chumeasses": "chumear",
    "chumeaste": "chumear",
    "chumeastes": "chumear",
    "chumeava": "chumear",
    "chumeavam": "chumear",
    "chumeavas": "chumear",
    "chumecos": "chumeco",
    "chumeei": "chumear",
    "chumeeis": "chumear",
    "chumeemo": "chumear",
    "chumeemos": "chumear",
    "chumeia": "chumear",
    "chumeiam": "chumear",
    "chumeias": "chumear",
    "chumeie": "chumear",
    "chumeiem": "chumear",
    "chumeies": "chumear",
    "chumeio": "chumear",
    "chumelas": "chumela",
    "chumeou": "chumear",
    "chumeá": "chumear",
    "chumeámo": "chumear",
    "chumeámos": "chumear",
    "chumeáramo": "chumear",
    "chumeáramos": "chumear",
    "chumeárei": "chumear",
    "chumeáreis": "chumear",
    "chumeásseis": "chumear",
    "chumeássemos": "chumear",
    "chumeávamo": "chumear",
    "chumeávamos": "chumear",
    "chumeávei": "chumear",
    "chumeáveis": "chumear",
    "chumiços": "chumiço",
    "chunambos": "chunambo",
    "chunames": "chuname",
    "chunas": "chuna",
    "chupa": "chupar",
    "chupada": "chupar",
    "chupadas": "chupar",
    "chupadazinha": "chupado",
    "chupadazinhas": "chupado",
    "chupadazita": "chupado",
    "chupadazitas": "chupado",
    "chupadeiras": "chupadeira",
    "chupadelas": "chupadela",
    "chupadinha": "chupado",
    "chupadinhas": "chupado",
    "chupadinho": "chupado",
    "chupadinhos": "chupado",
    "chupadita": "chupado",
    "chupaditas": "chupado",
    "chupadito": "chupado",
    "chupaditos": "chupado",
    "chupado": "chupar",
    "chupadoiros": "chupadoiro",
    "chupadora": "chupador",
    "chupadoras": "chupador",
    "chupadores": "chupador",
    "chupados": "chupar",
    "chupadouros": "chupadouro",
    "chupadozinho": "chupado",
    "chupadozinhos": "chupado",
    "chupadozito": "chupado",
    "chupadozitos": "chupado",
    "chupaduras": "chupadura",
    "chupadíssima": "chupado",
    "chupadíssimas": "chupado",
    "chupadíssimo": "chupado",
    "chupadíssimos": "chupado",
    "chupai": "chupar",
    "chupais": "chupar",
    "chupam": "chupar",
    "chupamentos": "chupamento",
    "chupamo": "chupar",
    "chupamos": "chupar",
    "chupando": "chupar",
    "chupara": "chupar",
    "chuparam": "chupar",
    "chuparas": "chupar",
    "chuparde": "chupar",
    "chupardes": "chupar",
    "chupare": "chupar",
    "chuparei": "chupar",
    "chupareis": "chupar",
    "chuparem": "chupar",
    "chuparemos": "chupar",
    "chupares": "chupar",
    "chuparia": "chupar",
    "chupariam": "chupar",
    "chuparias": "chupar",
    "chuparmo": "chupar",
    "chuparmos": "chupar",
    "chupará": "chupar",
    "chuparás": "chupar",
    "chuparão": "chupar",
    "chuparíamos": "chupar",
    "chuparíeis": "chupar",
    "chupas": "chupar",
    "chupasse": "chupar",
    "chupassem": "chupar",
    "chupasses": "chupar",
    "chupaste": "chupar",
    "chupastes": "chupar",
    "chupava": "chupar",
    "chupavam": "chupar",
    "chupavas": "chupar",
    "chupe": "chupar",
    "chupei": "chupar",
    "chupeis": "chupar",
    "chupem": "chupar",
    "chupemo": "chupar",
    "chupemos": "chupar",
    "chupes": "chupar",
    "chupetas": "chupeta",
    "chupetinha": "chupeta",
    "chupetinhas": "chupeta",
    "chupetita": "chupeta",
    "chupetitas": "chupeta",
    "chupins": "chupim",
    "chupistas": "chupista",
    "chupita": "chupitar",
    "chupitada": "chupitar",
    "chupitadas": "chupitar",
    "chupitado": "chupitar",
    "chupitados": "chupitar",
    "chupitai": "chupitar",
    "chupitais": "chupitar",
    "chupitam": "chupitar",
    "chupitamo": "chupitar",
    "chupitamos": "chupitar",
    "chupitando": "chupitar",
    "chupitara": "chupitar",
    "chupitaram": "chupitar",
    "chupitaras": "chupitar",
    "chupitarde": "chupitar",
    "chupitardes": "chupitar",
    "chupitare": "chupitar",
    "chupitarei": "chupitar",
    "chupitareis": "chupitar",
    "chupitarem": "chupitar",
    "chupitaremos": "chupitar",
    "chupitares": "chupitar",
    "chupitaria": "chupitar",
    "chupitariam": "chupitar",
    "chupitarias": "chupitar",
    "chupitarmo": "chupitar",
    "chupitarmos": "chupitar",
    "chupitará": "chupitar",
    "chupitarás": "chupitar",
    "chupitarão": "chupitar",
    "chupitaríamos": "chupitar",
    "chupitaríeis": "chupitar",
    "chupitas": "chupitar",
    "chupitasse": "chupitar",
    "chupitassem": "chupitar",
    "chupitasses": "chupitar",
    "chupitaste": "chupitar",
    "chupitastes": "chupitar",
    "chupitava": "chupitar",
    "chupitavam": "chupitar",
    "chupitavas": "chupitar",
    "chupite": "chupitar",
    "chupitei": "chupitar",
    "chupiteis": "chupitar",
    "chupitem": "chupitar",
    "chupitemo": "chupitar",
    "chupitemos": "chupitar",
    "chupites": "chupitar",
    "chupito": "chupitar",
    "chupitou": "chupitar",
    "chupitá": "chupitar",
    "chupitámo": "chupitar",
    "chupitámos": "chupitar",
    "chupitáramo": "chupitar",
    "chupitáramos": "chupitar",
    "chupitárei": "chupitar",
    "chupitáreis": "chupitar",
    "chupitásseis": "chupitar",
    "chupitássemos": "chupitar",
    "chupitávamo": "chupitar",
    "chupitávamos": "chupitar",
    "chupitávei": "chupitar",
    "chupitáveis": "chupitar",
    "chupo": "chupar",
    "chupona": "chupão",
    "chuponas": "chupão",
    "chupou": "chupar",
    "chupá": "chupar",
    "chupámo": "chupar",
    "chupámos": "chupar",
    "chupáramo": "chupar",
    "chupáramos": "chupar",
    "chupárei": "chupar",
    "chupáreis": "chupar",
    "chupásseis": "chupar",
    "chupássemos": "chupar",
    "chupávamo": "chupar",
    "chupávamos": "chupar",
    "chupávei": "chupar",
    "chupáveis": "chupar",
    "chupões": "chupão",
    "churda": "churdo",
    "churdas": "churdo",
    "churdos": "churdo",
    "churetas": "chureta",
    "churmas": "churma",
    "churra": "churro",
    "churras": "churro",
    "churrascadas": "churrascada",
    "churrascarias": "churrascaria",
    "churrascos": "churrasco",
    "churrasqueada": "churrasquear",
    "churrasqueadas": "churrasquear",
    "churrasqueado": "churrasquear",
    "churrasqueados": "churrasquear",
    "churrasqueai": "churrasquear",
    "churrasqueais": "churrasquear",
    "churrasqueamo": "churrasquear",
    "churrasqueamos": "churrasquear",
    "churrasqueando": "churrasquear",
    "churrasqueara": "churrasquear",
    "churrasquearam": "churrasquear",
    "churrasquearas": "churrasquear",
    "churrasqueardes": "churrasquear",
    "churrasquearei": "churrasquear",
    "churrasqueareis": "churrasquear",
    "churrasquearem": "churrasquear",
    "churrasquearemos": "churrasquear",
    "churrasqueares": "churrasquear",
    "churrasquearia": "churrasquear",
    "churrasqueariam": "churrasquear",
    "churrasquearias": "churrasquear",
    "churrasquearmo": "churrasquear",
    "churrasquearmos": "churrasquear",
    "churrasqueará": "churrasquear",
    "churrasquearás": "churrasquear",
    "churrasquearão": "churrasquear",
    "churrasquearíamos": "churrasquear",
    "churrasquearíeis": "churrasquear",
    "churrasqueasse": "churrasquear",
    "churrasqueassem": "churrasquear",
    "churrasqueasses": "churrasquear",
    "churrasqueaste": "churrasquear",
    "churrasqueastes": "churrasquear",
    "churrasqueava": "churrasquear",
    "churrasqueavam": "churrasquear",
    "churrasqueavas": "churrasquear",
    "churrasqueei": "churrasquear",
    "churrasqueeis": "churrasquear",
    "churrasqueemo": "churrasquear",
    "churrasqueemos": "churrasquear",
    "churrasqueia": "churrasquear",
    "churrasqueiam": "churrasquear",
    "churrasqueias": "churrasquear",
    "churrasqueie": "churrasquear",
    "churrasqueiem": "churrasquear",
    "churrasqueies": "churrasquear",
    "churrasqueio": "churrasquear",
    "churrasqueiras": "churrasqueira",
    "churrasqueou": "churrasquear",
    "churrasqueámo": "churrasquear",
    "churrasqueámos": "churrasquear",
    "churrasqueáramo": "churrasquear",
    "churrasqueáramos": "churrasquear",
    "churrasqueáreis": "churrasquear",
    "churrasqueásseis": "churrasquear",
    "churrasqueássemos": "churrasquear",
    "churrasqueávamo": "churrasquear",
    "churrasqueávamos": "churrasquear",
    "churrasqueáveis": "churrasquear",
    "churrasquinho": "churrasco",
    "churrasquinhos": "churrasco",
    "churrasquito": "churrasco",
    "churrasquitos": "churrasco",
    "churrecas": "churreca",
    "churriões": "churrião",
    "churros": "churro",
    "chusma": "chusmar",
    "chusmada": "chusmar",
    "chusmadas": "chusmar",
    "chusmado": "chusmar",
    "chusmados": "chusmar",
    "chusmai": "chusmar",
    "chusmais": "chusmar",
    "chusmam": "chusmar",
    "chusmamo": "chusmar",
    "chusmamos": "chusmar",
    "chusmando": "chusmar",
    "chusmara": "chusmar",
    "chusmaram": "chusmar",
    "chusmaras": "chusmar",
    "chusmarde": "chusmar",
    "chusmardes": "chusmar",
    "chusmare": "chusmar",
    "chusmarei": "chusmar",
    "chusmareis": "chusmar",
    "chusmarem": "chusmar",
    "chusmaremos": "chusmar",
    "chusmares": "chusmar",
    "chusmaria": "chusmar",
    "chusmariam": "chusmar",
    "chusmarias": "chusmar",
    "chusmarmo": "chusmar",
    "chusmarmos": "chusmar",
    "chusmará": "chusmar",
    "chusmarás": "chusmar",
    "chusmarão": "chusmar",
    "chusmaríamos": "chusmar",
    "chusmaríeis": "chusmar",
    "chusmas": "chusmar",
    "chusmasse": "chusmar",
    "chusmassem": "chusmar",
    "chusmasses": "chusmar",
    "chusmaste": "chusmar",
    "chusmastes": "chusmar",
    "chusmava": "chusmar",
    "chusmavam": "chusmar",
    "chusmavas": "chusmar",
    "chusme": "chusmar",
    "chusmei": "chusmar",
    "chusmeis": "chusmar",
    "chusmem": "chusmar",
    "chusmemo": "chusmar",
    "chusmemos": "chusmar",
    "chusmes": "chusmar",
    "chusmo": "chusmar",
    "chusmou": "chusmar",
    "chusmá": "chusmar",
    "chusmámo": "chusmar",
    "chusmámos": "chusmar",
    "chusmáramo": "chusmar",
    "chusmáramos": "chusmar",
    "chusmárei": "chusmar",
    "chusmáreis": "chusmar",
    "chusmásseis": "chusmar",
    "chusmássemos": "chusmar",
    "chusmávamo": "chusmar",
    "chusmávamos": "chusmar",
    "chusmávei": "chusmar",
    "chusmáveis": "chusmar",
    "chuta": "chutar",
    "chutada": "chutar",
    "chutadas": "chutar",
    "chutado": "chutar",
    "chutadora": "chutador",
    "chutadoras": "chutador",
    "chutadores": "chutador",
    "chutados": "chutar",
    "chutai": "chutar",
    "chutais": "chutar",
    "chutam": "chutar",
    "chutamo": "chutar",
    "chutamos": "chutar",
    "chutando": "chutar",
    "chutara": "chutar",
    "chutaram": "chutar",
    "chutaras": "chutar",
    "chutarde": "chutar",
    "chutardes": "chutar",
    "chutare": "chutar",
    "chutarei": "chutar",
    "chutareis": "chutar",
    "chutarem": "chutar",
    "chutaremos": "chutar",
    "chutares": "chutar",
    "chutaria": "chutar",
    "chutariam": "chutar",
    "chutarias": "chutar",
    "chutarmo": "chutar",
    "chutarmos": "chutar",
    "chutará": "chutar",
    "chutarás": "chutar",
    "chutarão": "chutar",
    "chutaríamos": "chutar",
    "chutaríeis": "chutar",
    "chutas": "chutar",
    "chutasse": "chutar",
    "chutassem": "chutar",
    "chutasses": "chutar",
    "chutaste": "chutar",
    "chutastes": "chutar",
    "chutava": "chutar",
    "chutavam": "chutar",
    "chutavas": "chutar",
    "chute": "chutar",
    "chutei": "chutar",
    "chuteiras": "chuteira",
    "chuteis": "chutar",
    "chutem": "chutar",
    "chutemo": "chutar",
    "chutemos": "chutar",
    "chutes": "chutar",
    "chutinho": "chuto",
    "chutinhos": "chuto",
    "chutito": "chuto",
    "chutitos": "chuto",
    "chuto": "chutar",
    "chutos": "chuto",
    "chutou": "chutar",
    "chuts": "chut",
    "chutá": "chutar",
    "chutámo": "chutar",
    "chutámos": "chutar",
    "chutáramo": "chutar",
    "chutáramos": "chutar",
    "chutárei": "chutar",
    "chutáreis": "chutar",
    "chutásseis": "chutar",
    "chutássemos": "chutar",
    "chutávamo": "chutar",
    "chutávamos": "chutar",
    "chutávei": "chutar",
    "chutáveis": "chutar",
    "chuvadas": "chuvada",
    "chuvaradas": "chuvarada",
    "chuvas": "chuva",
    "chuveiradas": "chuveirada",
    "chuveiros": "chuveiro",
    "chuvinha": "chuvinhar",
    "chuvinhada": "chuvinhar",
    "chuvinhadas": "chuvinhar",
    "chuvinhado": "chuvinhar",
    "chuvinhados": "chuvinhar",
    "chuvinhai": "chuvinhar",
    "chuvinhais": "chuvinhar",
    "chuvinham": "chuvinhar",
    "chuvinhamo": "chuvinhar",
    "chuvinhamos": "chuvinhar",
    "chuvinhando": "chuvinhar",
    "chuvinhara": "chuvinhar",
    "chuvinharam": "chuvinhar",
    "chuvinharas": "chuvinhar",
    "chuvinhardes": "chuvinhar",
    "chuvinharei": "chuvinhar",
    "chuvinhareis": "chuvinhar",
    "chuvinharem": "chuvinhar",
    "chuvinharemos": "chuvinhar",
    "chuvinhares": "chuvinhar",
    "chuvinharia": "chuvinhar",
    "chuvinhariam": "chuvinhar",
    "chuvinharias": "chuvinhar",
    "chuvinharmo": "chuvinhar",
    "chuvinharmos": "chuvinhar",
    "chuvinhará": "chuvinhar",
    "chuvinharás": "chuvinhar",
    "chuvinharão": "chuvinhar",
    "chuvinharíamos": "chuvinhar",
    "chuvinharíeis": "chuvinhar",
    "chuvinhas": "chuvinhar",
    "chuvinhasse": "chuvinhar",
    "chuvinhassem": "chuvinhar",
    "chuvinhasses": "chuvinhar",
    "chuvinhaste": "chuvinhar",
    "chuvinhastes": "chuvinhar",
    "chuvinhava": "chuvinhar",
    "chuvinhavam": "chuvinhar",
    "chuvinhavas": "chuvinhar",
    "chuvinhe": "chuvinhar",
    "chuvinhei": "chuvinhar",
    "chuvinheis": "chuvinhar",
    "chuvinhem": "chuvinhar",
    "chuvinhemo": "chuvinhar",
    "chuvinhemos": "chuvinhar",
    "chuvinhes": "chuvinhar",
    "chuvinho": "chuvinhar",
    "chuvinhou": "chuvinhar",
    "chuvinhámo": "chuvinhar",
    "chuvinhámos": "chuvinhar",
    "chuvinháramo": "chuvinhar",
    "chuvinháramos": "chuvinhar",
    "chuvinháreis": "chuvinhar",
    "chuvinhásseis": "chuvinhar",
    "chuvinhássemos": "chuvinhar",
    "chuvinhávamo": "chuvinhar",
    "chuvinhávamos": "chuvinhar",
    "chuvinháveis": "chuvinhar",
    "chuvisca": "chuviscar",
    "chuviscada": "chuviscar",
    "chuviscadas": "chuviscar",
    "chuviscado": "chuviscar",
    "chuviscados": "chuviscar",
    "chuviscais": "chuviscar",
    "chuviscam": "chuviscar",
    "chuviscamo": "chuviscar",
    "chuviscamos": "chuviscar",
    "chuviscando": "chuviscar",
    "chuviscara": "chuviscar",
    "chuviscaram": "chuviscar",
    "chuviscaras": "chuviscar",
    "chuviscardes": "chuviscar",
    "chuviscarei": "chuviscar",
    "chuviscareis": "chuviscar",
    "chuviscarem": "chuviscar",
    "chuviscaremos": "chuviscar",
    "chuviscares": "chuviscar",
    "chuviscaria": "chuviscar",
    "chuviscariam": "chuviscar",
    "chuviscarias": "chuviscar",
    "chuviscarmo": "chuviscar",
    "chuviscarmos": "chuviscar",
    "chuviscará": "chuviscar",
    "chuviscarás": "chuviscar",
    "chuviscarão": "chuviscar",
    "chuviscaríamos": "chuviscar",
    "chuviscaríeis": "chuviscar",
    "chuviscas": "chuviscar",
    "chuviscasse": "chuviscar",
    "chuviscassem": "chuviscar",
    "chuviscasses": "chuviscar",
    "chuviscaste": "chuviscar",
    "chuviscastes": "chuviscar",
    "chuviscava": "chuviscar",
    "chuviscavam": "chuviscar",
    "chuviscavas": "chuviscar",
    "chuvisco": "chuviscar",
    "chuviscos": "chuvisco",
    "chuviscosa": "chuviscoso",
    "chuviscosas": "chuviscoso",
    "chuviscosos": "chuviscoso",
    "chuviscou": "chuviscar",
    "chuviscámo": "chuviscar",
    "chuviscámos": "chuviscar",
    "chuviscáramo": "chuviscar",
    "chuviscáramos": "chuviscar",
    "chuviscáreis": "chuviscar",
    "chuviscásseis": "chuviscar",
    "chuviscássemos": "chuviscar",
    "chuviscávamo": "chuviscar",
    "chuviscávamos": "chuviscar",
    "chuviscáveis": "chuviscar",
    "chuvisque": "chuviscar",
    "chuvisquei": "chuviscar",
    "chuvisqueiros": "chuvisqueiro",
    "chuvisqueis": "chuviscar",
    "chuvisquem": "chuviscar",
    "chuvisquemos": "chuviscar",
    "chuvisques": "chuviscar",
    "chuvita": "chuva",
    "chuvitas": "chuva",
    "chuvosa": "chuvoso",
    "chuvosas": "chuvoso",
    "chuvosos": "chuvoso",
    "chuça": "chuçar",
    "chuçada": "chuçar",
    "chuçadas": "chuçar",
    "chuçado": "chuçar",
    "chuçados": "chuçar",
    "chuçai": "chuçar",
    "chuçais": "chuçar",
    "chuçam": "chuçar",
    "chuçamo": "chuçar",
    "chuçamos": "chuçar",
    "chuçando": "chuçar",
    "chuçara": "chuçar",
    "chuçaram": "chuçar",
    "chuçaras": "chuçar",
    "chuçarde": "chuçar",
    "chuçardes": "chuçar",
    "chuçare": "chuçar",
    "chuçarei": "chuçar",
    "chuçareis": "chuçar",
    "chuçarem": "chuçar",
    "chuçaremos": "chuçar",
    "chuçares": "chuçar",
    "chuçaria": "chuçar",
    "chuçariam": "chuçar",
    "chuçarias": "chuçar",
    "chuçarmo": "chuçar",
    "chuçarmos": "chuçar",
    "chuçará": "chuçar",
    "chuçarás": "chuçar",
    "chuçarão": "chuçar",
    "chuçaríamos": "chuçar",
    "chuçaríeis": "chuçar",
    "chuças": "chuçar",
    "chuçasse": "chuçar",
    "chuçassem": "chuçar",
    "chuçasses": "chuçar",
    "chuçaste": "chuçar",
    "chuçastes": "chuçar",
    "chuçava": "chuçar",
    "chuçavam": "chuçar",
    "chuçavas": "chuçar",
    "chuço": "chuçar",
    "chuços": "chuço",
    "chuçou": "chuçar",
    "chuçá": "chuçar",
    "chuçámo": "chuçar",
    "chuçámos": "chuçar",
    "chuçáramo": "chuçar",
    "chuçáramos": "chuçar",
    "chuçárei": "chuçar",
    "chuçáreis": "chuçar",
    "chuçásseis": "chuçar",
    "chuçássemos": "chuçar",
    "chuçávamo": "chuçar",
    "chuçávamos": "chuçar",
    "chuçávei": "chuçar",
    "chuçáveis": "chuçar",
    "chués": "chué",
    "chácaras": "chácara",
    "chás": "chá",
    "chávenas": "chávena",
    "chã": "chão",
    "chãos": "chão",
    "chãs": "chão",
    "chícharos": "chícharo",
    "chúmbeas": "chúmbea",
    "chúmeas": "chúmea",
    "cia": "ciar",
    "ciada": "ciar",
    "ciadas": "ciar",
    "ciado": "ciar",
    "ciados": "ciar",
    "ciai": "ciar",
    "ciais": "ciar",
    "ciam": "ciar",
    "ciamo": "ciar",
    "ciamos": "ciar",
    "ciamóides": "ciamóide",
    "cianamidas": "cianamida",
    "cianatos": "cianato",
    "ciando": "ciar",
    "cianetos": "cianeto",
    "cianirrostra": "cianirrostro",
    "cianirrostras": "cianirrostro",
    "cianirrostros": "cianirrostro",
    "cianismos": "cianismo",
    "cianites": "cianite",
    "cianocéfala": "cianocéfalo",
    "cianocéfalas": "cianocéfalo",
    "cianocéfalos": "cianocéfalo",
    "cianodermias": "cianodermia",
    "cianodérmica": "cianodérmico",
    "cianodérmicas": "cianodérmico",
    "cianodérmicos": "cianodérmico",
    "cianofícea": "cianofíceo",
    "cianofíceas": "cianofíceo",
    "cianofíceos": "cianofíceo",
    "cianogénica": "cianogénico",
    "cianogénicas": "cianogénico",
    "cianogénicos": "cianogénico",
    "cianogénios": "cianogénio",
    "cianometrias": "cianometria",
    "cianométrica": "cianométrico",
    "cianométricas": "cianométrico",
    "cianométricos": "cianométrico",
    "cianopatas": "cianopata",
    "cianopatias": "cianopatia",
    "cianopteros": "cianoptero",
    "cianopática": "cianopático",
    "cianopáticas": "cianopático",
    "cianopáticos": "cianopático",
    "cianos": "ciano",
    "cianoses": "cianose",
    "cianídrica": "cianídrico",
    "cianídricas": "cianídrico",
    "cianídricos": "cianídrico",
    "cianípedes": "cianípede",
    "cianófitas": "cianófita",
    "cianóides": "cianóide",
    "cianómetros": "cianómetro",
    "cianópodes": "cianópode",
    "cianóptera": "cianóptero",
    "cianópteras": "cianóptero",
    "cianópteros": "cianóptero",
    "cianúrias": "cianúria",
    "cianúrica": "cianúrico",
    "cianúricas": "cianúrico",
    "cianúricos": "cianúrico",
    "ciara": "ciar",
    "ciaram": "ciar",
    "ciaras": "ciar",
    "ciardes": "ciar",
    "ciarei": "ciar",
    "ciareis": "ciar",
    "ciarem": "ciar",
    "ciaremos": "ciar",
    "ciares": "ciar",
    "ciaria": "ciar",
    "ciariam": "ciar",
    "ciarias": "ciar",
    "ciarmo": "ciar",
    "ciarmos": "ciar",
    "ciará": "ciar",
    "ciarás": "ciar",
    "ciarão": "ciar",
    "ciaríamos": "ciar",
    "ciaríeis": "ciar",
    "cias": "ciar",
    "ciasse": "ciar",
    "ciassem": "ciar",
    "ciasses": "ciar",
    "ciaste": "ciar",
    "ciastes": "ciar",
    "ciatiformes": "ciatiforme",
    "ciatóides": "ciatóide",
    "ciava": "ciar",
    "ciavam": "ciar",
    "ciavas": "ciar",
    "ciba": "cibar",
    "cibada": "cibar",
    "cibadas": "cibar",
    "cibado": "cibar",
    "cibados": "cibar",
    "cibai": "cibar",
    "cibais": "cibar",
    "cibalhos": "cibalho",
    "cibam": "cibar",
    "cibamo": "cibar",
    "cibamos": "cibar",
    "cibando": "cibar",
    "cibara": "cibar",
    "cibaram": "cibar",
    "cibaras": "cibar",
    "cibarde": "cibar",
    "cibardes": "cibar",
    "cibare": "cibar",
    "cibarei": "cibar",
    "cibareis": "cibar",
    "cibarem": "cibar",
    "cibaremos": "cibar",
    "cibares": "cibar",
    "cibaria": "cibar",
    "cibariam": "cibar",
    "cibarias": "cibar",
    "cibarmo": "cibar",
    "cibarmos": "cibar",
    "cibará": "cibar",
    "cibarás": "cibar",
    "cibarão": "cibar",
    "cibaríamos": "cibar",
    "cibaríeis": "cibar",
    "cibas": "cibar",
    "cibasse": "cibar",
    "cibassem": "cibar",
    "cibasses": "cibar",
    "cibaste": "cibar",
    "cibastes": "cibar",
    "cibatos": "cibato",
    "cibava": "cibar",
    "cibavam": "cibar",
    "cibavas": "cibar",
    "cibe": "cibar",
    "cibei": "cibar",
    "cibeis": "cibar",
    "cibem": "cibar",
    "cibemo": "cibar",
    "cibemos": "cibar",
    "cibercafés": "cibercafé",
    "ciberespaços": "ciberespaço",
    "cibernautas": "cibernauta",
    "ciberneticistas": "ciberneticista",
    "cibernética": "cibernético",
    "cibernéticas": "cibernético",
    "cibernéticos": "cibernético",
    "cibes": "cibar",
    "cibo": "cibar",
    "cibos": "cibo",
    "cibou": "cibar",
    "cibá": "cibar",
    "cibámo": "cibar",
    "cibámos": "cibar",
    "cibáramo": "cibar",
    "cibáramos": "cibar",
    "cibárei": "cibar",
    "cibáreis": "cibar",
    "cibários": "cibário",
    "cibásseis": "cibar",
    "cibássemos": "cibar",
    "cibávamo": "cibar",
    "cibávamos": "cibar",
    "cibávei": "cibar",
    "cibáveis": "cibar",
    "cibórios": "cibório",
    "cicadales": "cicadale",
    "cicadácea": "cicadáceo",
    "cicadáceas": "cicadáceo",
    "cicadáceos": "cicadáceo",
    "cicadária": "cicadário",
    "cicadárias": "cicadário",
    "cicadários": "cicadário",
    "cicadídea": "cicadídeo",
    "cicadídeas": "cicadídeo",
    "cicadídeos": "cicadídeo",
    "cicalhas": "cicalha",
    "cicas": "cica",
    "cicateira": "cicateiro",
    "cicateiras": "cicateiro",
    "cicateiros": "cicateiro",
    "cicatejana": "cicatejano",
    "cicatejanas": "cicatejano",
    "cicatejanos": "cicatejano",
    "cicatices": "cicatice",
    "cicatriciais": "cicatricial",
    "cicatriza": "cicatrizar",
    "cicatrizada": "cicatrizar",
    "cicatrizadas": "cicatrizar",
    "cicatrizado": "cicatrizar",
    "cicatrizados": "cicatrizar",
    "cicatrizai": "cicatrizar",
    "cicatrizais": "cicatrizar",
    "cicatrizam": "cicatrizar",
    "cicatrizamo": "cicatrizar",
    "cicatrizamos": "cicatrizar",
    "cicatrizando": "cicatrizar",
    "cicatrizantes": "cicatrizante",
    "cicatrizara": "cicatrizar",
    "cicatrizaram": "cicatrizar",
    "cicatrizaras": "cicatrizar",
    "cicatrizarde": "cicatrizar",
    "cicatrizardes": "cicatrizar",
    "cicatrizare": "cicatrizar",
    "cicatrizarei": "cicatrizar",
    "cicatrizareis": "cicatrizar",
    "cicatrizarem": "cicatrizar",
    "cicatrizaremos": "cicatrizar",
    "cicatrizares": "cicatrizar",
    "cicatrizaria": "cicatrizar",
    "cicatrizariam": "cicatrizar",
    "cicatrizarias": "cicatrizar",
    "cicatrizarmo": "cicatrizar",
    "cicatrizarmos": "cicatrizar",
    "cicatrizará": "cicatrizar",
    "cicatrizarás": "cicatrizar",
    "cicatrizarão": "cicatrizar",
    "cicatrizaríamos": "cicatrizar",
    "cicatrizaríeis": "cicatrizar",
    "cicatrizas": "cicatrizar",
    "cicatrizasse": "cicatrizar",
    "cicatrizassem": "cicatrizar",
    "cicatrizasses": "cicatrizar",
    "cicatrizaste": "cicatrizar",
    "cicatrizastes": "cicatrizar",
    "cicatrizava": "cicatrizar",
    "cicatrizavam": "cicatrizar",
    "cicatrizavas": "cicatrizar",
    "cicatrizações": "cicatrização",
    "cicatrize": "cicatrizar",
    "cicatrizei": "cicatrizar",
    "cicatrizeis": "cicatrizar",
    "cicatrizem": "cicatrizar",
    "cicatrizemo": "cicatrizar",
    "cicatrizemos": "cicatrizar",
    "cicatrizes": "cicatrizar",
    "cicatrizo": "cicatrizar",
    "cicatrizou": "cicatrizar",
    "cicatrizá": "cicatrizar",
    "cicatrizámo": "cicatrizar",
    "cicatrizámos": "cicatrizar",
    "cicatrizáramo": "cicatrizar",
    "cicatrizáramos": "cicatrizar",
    "cicatrizárei": "cicatrizar",
    "cicatrizáreis": "cicatrizar",
    "cicatrizásseis": "cicatrizar",
    "cicatrizássemos": "cicatrizar",
    "cicatrizávamo": "cicatrizar",
    "cicatrizávamos": "cicatrizar",
    "cicatrizávei": "cicatrizar",
    "cicatrizáveis": "cicatrizável",
    "cicatrículas": "cicatrícula",
    "cicerones": "cicerone",
    "ciceroniana": "ciceroniano",
    "ciceronianas": "ciceroniano",
    "ciceronianismos": "ciceronianismo",
    "ciceronianos": "ciceroniano",
    "cicia": "ciciar",
    "ciciada": "ciciar",
    "ciciadas": "ciciar",
    "ciciado": "ciciar",
    "ciciados": "ciciar",
    "ciciai": "ciciar",
    "ciciais": "ciciar",
    "ciciam": "ciciar",
    "ciciamentos": "ciciamento",
    "ciciamo": "ciciar",
    "ciciamos": "ciciar",
    "ciciando": "ciciar",
    "ciciantes": "ciciante",
    "ciciara": "ciciar",
    "ciciaram": "ciciar",
    "ciciaras": "ciciar",
    "ciciarde": "ciciar",
    "ciciardes": "ciciar",
    "ciciare": "ciciar",
    "ciciarei": "ciciar",
    "ciciareis": "ciciar",
    "ciciarem": "ciciar",
    "ciciaremos": "ciciar",
    "ciciares": "ciciar",
    "ciciaria": "ciciar",
    "ciciariam": "ciciar",
    "ciciarias": "ciciar",
    "ciciarmo": "ciciar",
    "ciciarmos": "ciciar",
    "ciciará": "ciciar",
    "ciciarás": "ciciar",
    "ciciarão": "ciciar",
    "ciciaríamos": "ciciar",
    "ciciaríeis": "ciciar",
    "cicias": "ciciar",
    "ciciasse": "ciciar",
    "ciciassem": "ciciar",
    "ciciasses": "ciciar",
    "ciciaste": "ciciar",
    "ciciastes": "ciciar",
    "ciciava": "ciciar",
    "ciciavam": "ciciar",
    "ciciavas": "ciciar",
    "cicie": "ciciar",
    "ciciei": "ciciar",
    "cicieis": "ciciar",
    "ciciem": "ciciar",
    "ciciemo": "ciciar",
    "ciciemos": "ciciar",
    "cicies": "ciciar",
    "cicio": "ciciar",
    "cicios": "cicio",
    "ciciosa": "cicioso",
    "ciciosas": "cicioso",
    "ciciosos": "cicioso",
    "ciciou": "ciciar",
    "ciciá": "ciciar",
    "ciciámo": "ciciar",
    "ciciámos": "ciciar",
    "ciciáramo": "ciciar",
    "ciciáramos": "ciciar",
    "ciciárei": "ciciar",
    "ciciáreis": "ciciar",
    "ciciásseis": "ciciar",
    "ciciássemos": "ciciar",
    "ciciávamo": "ciciar",
    "ciciávamos": "ciciar",
    "ciciávei": "ciciar",
    "ciciáveis": "ciciar",
    "ciclamina": "ciclamino",
    "ciclaminas": "ciclamino",
    "ciclaminos": "ciclamino",
    "ciclamores": "ciclamor",
    "ciclamínea": "ciclamíneo",
    "ciclamíneas": "ciclamíneo",
    "ciclamíneos": "ciclamíneo",
    "ciclatões": "ciclatão",
    "ciclismos": "ciclismo",
    "ciclistas": "ciclista",
    "ciclizações": "ciclização",
    "ciclofrenias": "ciclofrenia",
    "ciclofrénica": "ciclofrénico",
    "ciclofrénicas": "ciclofrénico",
    "ciclofrénicos": "ciclofrénico",
    "cicloidais": "cicloidal",
    "cicloidias": "cicloidia",
    "ciclometrias": "ciclometria",
    "ciclomotores": "ciclomotor",
    "ciclomotoristas": "ciclomotorista",
    "ciclométrica": "ciclométrico",
    "ciclométricas": "ciclométrico",
    "ciclométricos": "ciclométrico",
    "ciclonais": "ciclonal",
    "ciclones": "ciclone",
    "cicloniídea": "cicloniídeo",
    "cicloniídeas": "cicloniídeo",
    "cicloniídeos": "cicloniídeo",
    "cicloníidas": "cicloníida",
    "ciclopes": "ciclope",
    "ciclos": "ciclo",
    "cicloscópica": "cicloscópico",
    "cicloscópicas": "cicloscópico",
    "cicloscópicos": "cicloscópico",
    "cicloscópios": "cicloscópio",
    "cicloses": "ciclose",
    "ciclostómica": "ciclostómico",
    "ciclostómicas": "ciclostómico",
    "ciclostómicos": "ciclostómico",
    "ciclotimias": "ciclotimia",
    "ciclotrões": "ciclotrão",
    "ciclotímica": "ciclotímico",
    "ciclotímicas": "ciclotímico",
    "ciclotímicos": "ciclotímico",
    "ciclóides": "ciclóide",
    "ciclónica": "ciclónico",
    "ciclónicas": "ciclónico",
    "ciclónicos": "ciclónico",
    "ciclópea": "ciclópeo",
    "ciclópeas": "ciclópeo",
    "ciclópeos": "ciclópeo",
    "ciclópica": "ciclópico",
    "ciclópicas": "ciclópico",
    "ciclópicos": "ciclópico",
    "ciclósica": "ciclósico",
    "ciclósicas": "ciclósico",
    "ciclósicos": "ciclósico",
    "ciclóstomos": "ciclóstomo",
    "cicnóides": "cicnóide",
    "ciconiídas": "ciconiída",
    "ciconiídeas": "ciconiídea",
    "cicutas": "cicuta",
    "cicutinas": "cicutina",
    "cicádidas": "cicádida",
    "cicêndias": "cicêndia",
    "cidadanias": "cidadania",
    "cidadelas": "cidadela",
    "cidadelhas": "cidadelha",
    "cidades": "cidade",
    "cidadezinha": "cidade",
    "cidadezinhas": "cidade",
    "cidadezita": "cidade",
    "cidadezitas": "cidade",
    "cidadã": "cidadão",
    "cidadãos": "cidadão",
    "cidadãs": "cidadão",
    "cidradas": "cidrada",
    "cidrais": "cidral",
    "cidras": "cidra",
    "cidreiras": "cidreira",
    "cidrões": "cidrão",
    "cie": "ciar",
    "ciei": "ciar",
    "cieiros": "cieiro",
    "cieis": "ciar",
    "ciem": "ciar",
    "ciemo": "ciar",
    "ciemos": "ciar",
    "cientes": "ciente",
    "cientismos": "cientismo",
    "cientistas": "cientista",
    "científica": "científico",
    "científicas": "científico",
    "científicos": "científico",
    "cies": "ciar",
    "cifa": "cifar",
    "cifada": "cifar",
    "cifadas": "cifar",
    "cifado": "cifar",
    "cifados": "cifar",
    "cifai": "cifar",
    "cifais": "cifar",
    "cifam": "cifar",
    "cifamo": "cifar",
    "cifamos": "cifar",
    "cifando": "cifar",
    "cifara": "cifar",
    "cifaram": "cifar",
    "cifaras": "cifar",
    "cifarde": "cifar",
    "cifardes": "cifar",
    "cifare": "cifar",
    "cifarei": "cifar",
    "cifareis": "cifar",
    "cifarem": "cifar",
    "cifaremos": "cifar",
    "cifares": "cifar",
    "cifaria": "cifar",
    "cifariam": "cifar",
    "cifarias": "cifar",
    "cifarmo": "cifar",
    "cifarmos": "cifar",
    "cifará": "cifar",
    "cifarás": "cifar",
    "cifarão": "cifar",
    "cifaríamos": "cifar",
    "cifaríeis": "cifar",
    "cifas": "cifar",
    "cifasse": "cifar",
    "cifassem": "cifar",
    "cifasses": "cifar",
    "cifaste": "cifar",
    "cifastes": "cifar",
    "cifava": "cifar",
    "cifavam": "cifar",
    "cifavas": "cifar",
    "cife": "cifar",
    "cifei": "cifar",
    "cifeis": "cifar",
    "cifem": "cifar",
    "cifemo": "cifar",
    "cifemos": "cifar",
    "cifes": "cifar",
    "cifistomas": "cifistoma",
    "cifo": "cifar",
    "cifonismos": "cifonismo",
    "cifoses": "cifose",
    "cifou": "cifar",
    "cifozoária": "cifozoário",
    "cifozoárias": "cifozoário",
    "cifozoários": "cifozoário",
    "cifra": "cifrar",
    "cifrada": "cifrar",
    "cifradas": "cifrar",
    "cifrado": "cifrar",
    "cifrados": "cifrar",
    "cifrai": "cifrar",
    "cifrais": "cifrar",
    "cifram": "cifrar",
    "ciframo": "cifrar",
    "ciframos": "cifrar",
    "cifrando": "cifrar",
    "cifrantes": "cifrante",
    "cifrara": "cifrar",
    "cifraram": "cifrar",
    "cifraras": "cifrar",
    "cifrarde": "cifrar",
    "cifrardes": "cifrar",
    "cifrare": "cifrar",
    "cifrarei": "cifrar",
    "cifrareis": "cifrar",
    "cifrarem": "cifrar",
    "cifraremos": "cifrar",
    "cifrares": "cifrar",
    "cifraria": "cifrar",
    "cifrariam": "cifrar",
    "cifrarias": "cifrar",
    "cifrarmo": "cifrar",
    "cifrarmos": "cifrar",
    "cifrará": "cifrar",
    "cifrarás": "cifrar",
    "cifrarão": "cifrar",
    "cifraríamos": "cifrar",
    "cifraríeis": "cifrar",
    "cifras": "cifrar",
    "cifrasse": "cifrar",
    "cifrassem": "cifrar",
    "cifrasses": "cifrar",
    "cifraste": "cifrar",
    "cifrastes": "cifrar",
    "cifrava": "cifrar",
    "cifravam": "cifrar",
    "cifravas": "cifrar",
    "cifre": "cifrar",
    "cifrei": "cifrar",
    "cifreis": "cifrar",
    "cifrem": "cifrar",
    "cifremo": "cifrar",
    "cifremos": "cifrar",
    "cifres": "cifrar",
    "cifro": "cifrar",
    "cifrou": "cifrar",
    "cifrá": "cifrar",
    "cifrámo": "cifrar",
    "cifrámos": "cifrar",
    "cifráramo": "cifrar",
    "cifráramos": "cifrar",
    "cifrárei": "cifrar",
    "cifráreis": "cifrar",
    "cifrásseis": "cifrar",
    "cifrássemos": "cifrar",
    "cifrávamo": "cifrar",
    "cifrávamos": "cifrar",
    "cifrávei": "cifrar",
    "cifráveis": "cifrar",
    "cifrões": "cifrão",
    "cifá": "cifar",
    "cifámo": "cifar",
    "cifámos": "cifar",
    "cifáramo": "cifar",
    "cifáramos": "cifar",
    "cifárei": "cifar",
    "cifáreis": "cifar",
    "cifásseis": "cifar",
    "cifássemos": "cifar",
    "cifávamo": "cifar",
    "cifávamos": "cifar",
    "cifávei": "cifar",
    "cifáveis": "cifar",
    "cifótica": "cifótico",
    "cifóticas": "cifótico",
    "cifóticos": "cifótico",
    "cigalhos": "cigalho",
    "cigana": "cigano",
    "ciganadas": "ciganada",
    "ciganagens": "ciganagem",
    "ciganarias": "ciganaria",
    "ciganas": "cigano",
    "ciganices": "ciganice",
    "ciganinha": "cigano",
    "ciganinhas": "cigano",
    "ciganinho": "cigano",
    "ciganinhos": "cigano",
    "ciganita": "cigano",
    "ciganitas": "cigano",
    "ciganito": "cigano",
    "ciganitos": "cigano",
    "ciganos": "cigano",
    "cigarra": "cigarrar",
    "cigarrada": "cigarrar",
    "cigarradas": "cigarrar",
    "cigarrado": "cigarrar",
    "cigarrados": "cigarrar",
    "cigarrai": "cigarrar",
    "cigarrais": "cigarrar",
    "cigarram": "cigarrar",
    "cigarramo": "cigarrar",
    "cigarramos": "cigarrar",
    "cigarrando": "cigarrar",
    "cigarrara": "cigarrar",
    "cigarraram": "cigarrar",
    "cigarraras": "cigarrar",
    "cigarrardes": "cigarrar",
    "cigarrarei": "cigarrar",
    "cigarrareis": "cigarrar",
    "cigarrarem": "cigarrar",
    "cigarraremos": "cigarrar",
    "cigarrares": "cigarrar",
    "cigarraria": "cigarrar",
    "cigarrariam": "cigarrar",
    "cigarrarias": "cigarrar",
    "cigarrarmo": "cigarrar",
    "cigarrarmos": "cigarrar",
    "cigarrará": "cigarrar",
    "cigarrarás": "cigarrar",
    "cigarrarão": "cigarrar",
    "cigarraríamos": "cigarrar",
    "cigarraríeis": "cigarrar",
    "cigarras": "cigarrar",
    "cigarrasse": "cigarrar",
    "cigarrassem": "cigarrar",
    "cigarrasses": "cigarrar",
    "cigarraste": "cigarrar",
    "cigarrastes": "cigarrar",
    "cigarrava": "cigarrar",
    "cigarravam": "cigarrar",
    "cigarravas": "cigarrar",
    "cigarre": "cigarrar",
    "cigarreada": "cigarrear",
    "cigarreadas": "cigarrear",
    "cigarreado": "cigarrear",
    "cigarreados": "cigarrear",
    "cigarreai": "cigarrear",
    "cigarreais": "cigarrear",
    "cigarreamo": "cigarrear",
    "cigarreamos": "cigarrear",
    "cigarreando": "cigarrear",
    "cigarreara": "cigarrear",
    "cigarrearam": "cigarrear",
    "cigarrearas": "cigarrear",
    "cigarreardes": "cigarrear",
    "cigarrearei": "cigarrear",
    "cigarreareis": "cigarrear",
    "cigarrearem": "cigarrear",
    "cigarrearemos": "cigarrear",
    "cigarreares": "cigarrear",
    "cigarrearia": "cigarrear",
    "cigarreariam": "cigarrear",
    "cigarrearias": "cigarrear",
    "cigarrearmo": "cigarrear",
    "cigarrearmos": "cigarrear",
    "cigarreará": "cigarrear",
    "cigarrearás": "cigarrear",
    "cigarrearão": "cigarrear",
    "cigarrearíamos": "cigarrear",
    "cigarrearíeis": "cigarrear",
    "cigarreasse": "cigarrear",
    "cigarreassem": "cigarrear",
    "cigarreasses": "cigarrear",
    "cigarreaste": "cigarrear",
    "cigarreastes": "cigarrear",
    "cigarreava": "cigarrear",
    "cigarreavam": "cigarrear",
    "cigarreavas": "cigarrear",
    "cigarreei": "cigarrear",
    "cigarreeis": "cigarrear",
    "cigarreemo": "cigarrear",
    "cigarreemos": "cigarrear",
    "cigarrei": "cigarrar",
    "cigarreia": "cigarrear",
    "cigarreiam": "cigarrear",
    "cigarreias": "cigarrear",
    "cigarreie": "cigarrear",
    "cigarreiem": "cigarrear",
    "cigarreies": "cigarrear",
    "cigarreio": "cigarrear",
    "cigarreira": "cigarreiro",
    "cigarreiras": "cigarreiro",
    "cigarreiros": "cigarreiro",
    "cigarreis": "cigarrar",
    "cigarrem": "cigarrar",
    "cigarremo": "cigarrar",
    "cigarremos": "cigarrar",
    "cigarreou": "cigarrear",
    "cigarres": "cigarrar",
    "cigarreámo": "cigarrear",
    "cigarreámos": "cigarrear",
    "cigarreáramo": "cigarrear",
    "cigarreáramos": "cigarrear",
    "cigarreáreis": "cigarrear",
    "cigarreásseis": "cigarrear",
    "cigarreássemos": "cigarrear",
    "cigarreávamo": "cigarrear",
    "cigarreávamos": "cigarrear",
    "cigarreáveis": "cigarrear",
    "cigarrilhas": "cigarrilha",
    "cigarrinha": "cigarra",
    "cigarrinhas": "cigarra",
    "cigarrinho": "cigarro",
    "cigarrinhos": "cigarro",
    "cigarristas": "cigarrista",
    "cigarrita": "cigarra",
    "cigarritas": "cigarra",
    "cigarrito": "cigarro",
    "cigarritos": "cigarro",
    "cigarro": "cigarrar",
    "cigarros": "cigarro",
    "cigarrou": "cigarrar",
    "cigarrámo": "cigarrar",
    "cigarrámos": "cigarrar",
    "cigarráramo": "cigarrar",
    "cigarráramos": "cigarrar",
    "cigarráreis": "cigarrar",
    "cigarrásseis": "cigarrar",
    "cigarrássemos": "cigarrar",
    "cigarrávamo": "cigarrar",
    "cigarrávamos": "cigarrar",
    "cigarráveis": "cigarrar",
    "cigerões": "cigerão",
    "cigudes": "cigude",
    "ciicunstantes": "ciicunstante",
    "ciladas": "cilada",
    "ciladeada": "ciladear",
    "ciladeadas": "ciladear",
    "ciladeado": "ciladear",
    "ciladeados": "ciladear",
    "ciladeai": "ciladear",
    "ciladeais": "ciladear",
    "ciladeamo": "ciladear",
    "ciladeamos": "ciladear",
    "ciladeando": "ciladear",
    "ciladeara": "ciladear",
    "ciladearam": "ciladear",
    "ciladearas": "ciladear",
    "ciladearde": "ciladear",
    "ciladeardes": "ciladear",
    "ciladeare": "ciladear",
    "ciladearei": "ciladear",
    "ciladeareis": "ciladear",
    "ciladearem": "ciladear",
    "ciladearemos": "ciladear",
    "ciladeares": "ciladear",
    "ciladearia": "ciladear",
    "ciladeariam": "ciladear",
    "ciladearias": "ciladear",
    "ciladearmo": "ciladear",
    "ciladearmos": "ciladear",
    "ciladeará": "ciladear",
    "ciladearás": "ciladear",
    "ciladearão": "ciladear",
    "ciladearíamos": "ciladear",
    "ciladearíeis": "ciladear",
    "ciladeasse": "ciladear",
    "ciladeassem": "ciladear",
    "ciladeasses": "ciladear",
    "ciladeaste": "ciladear",
    "ciladeastes": "ciladear",
    "ciladeava": "ciladear",
    "ciladeavam": "ciladear",
    "ciladeavas": "ciladear",
    "ciladeei": "ciladear",
    "ciladeeis": "ciladear",
    "ciladeemo": "ciladear",
    "ciladeemos": "ciladear",
    "ciladeia": "ciladear",
    "ciladeiam": "ciladear",
    "ciladeias": "ciladear",
    "ciladeie": "ciladear",
    "ciladeiem": "ciladear",
    "ciladeies": "ciladear",
    "ciladeio": "ciladear",
    "ciladeou": "ciladear",
    "ciladeá": "ciladear",
    "ciladeámo": "ciladear",
    "ciladeámos": "ciladear",
    "ciladeáramo": "ciladear",
    "ciladeáramos": "ciladear",
    "ciladeárei": "ciladear",
    "ciladeáreis": "ciladear",
    "ciladeásseis": "ciladear",
    "ciladeássemos": "ciladear",
    "ciladeávamo": "ciladear",
    "ciladeávamos": "ciladear",
    "ciladeávei": "ciladear",
    "ciladeáveis": "ciladear",
    "cilarínea": "cilaríneo",
    "cilaríneas": "cilaríneo",
    "cilaríneos": "cilaríneo",
    "cilas": "cila",
    "cilhadoiros": "cilhadoiro",
    "cilhadouros": "cilhadouro",
    "cilhas": "cilha",
    "cilhões": "cilhão",
    "ciliada": "ciliado",
    "ciliadas": "ciliado",
    "ciliados": "ciliado",
    "ciliares": "ciliar",
    "cilicia": "ciliciar",
    "ciliciada": "ciliciar",
    "ciliciadas": "ciliciar",
    "ciliciado": "ciliciar",
    "ciliciados": "ciliciar",
    "ciliciai": "ciliciar",
    "ciliciais": "ciliciar",
    "ciliciam": "ciliciar",
    "ciliciamo": "ciliciar",
    "ciliciamos": "ciliciar",
    "ciliciando": "ciliciar",
    "ciliciara": "ciliciar",
    "ciliciaram": "ciliciar",
    "ciliciaras": "ciliciar",
    "ciliciarde": "ciliciar",
    "ciliciardes": "ciliciar",
    "ciliciare": "ciliciar",
    "ciliciarei": "ciliciar",
    "ciliciareis": "ciliciar",
    "ciliciarem": "ciliciar",
    "ciliciaremos": "ciliciar",
    "ciliciares": "ciliciar",
    "ciliciaria": "ciliciar",
    "ciliciariam": "ciliciar",
    "ciliciarias": "ciliciar",
    "ciliciarmo": "ciliciar",
    "ciliciarmos": "ciliciar",
    "ciliciará": "ciliciar",
    "ciliciarás": "ciliciar",
    "ciliciarão": "ciliciar",
    "ciliciaríamos": "ciliciar",
    "ciliciaríeis": "ciliciar",
    "cilicias": "ciliciar",
    "ciliciasse": "ciliciar",
    "ciliciassem": "ciliciar",
    "ciliciasses": "ciliciar",
    "ciliciaste": "ciliciar",
    "ciliciastes": "ciliciar",
    "ciliciava": "ciliciar",
    "ciliciavam": "ciliciar",
    "ciliciavas": "ciliciar",
    "cilicie": "ciliciar",
    "ciliciei": "ciliciar",
    "cilicieis": "ciliciar",
    "ciliciem": "ciliciar",
    "ciliciemo": "ciliciar",
    "ciliciemos": "ciliciar",
    "cilicienses": "ciliciense",
    "cilicies": "ciliciar",
    "cilicio": "ciliciar",
    "ciliciou": "ciliciar",
    "ciliciá": "ciliciar",
    "ciliciámo": "ciliciar",
    "ciliciámos": "ciliciar",
    "ciliciáramo": "ciliciar",
    "ciliciáramos": "ciliciar",
    "ciliciárei": "ciliciar",
    "ciliciáreis": "ciliciar",
    "ciliciásseis": "ciliciar",
    "ciliciássemos": "ciliciar",
    "ciliciávamo": "ciliciar",
    "ciliciávamos": "ciliciar",
    "ciliciávei": "ciliciar",
    "ciliciáveis": "ciliciar",
    "cilienses": "ciliense",
    "ciliformes": "ciliforme",
    "cilindra": "cilindrar",
    "cilindrada": "cilindrar",
    "cilindradas": "cilindrar",
    "cilindrado": "cilindrar",
    "cilindrados": "cilindrar",
    "cilindragens": "cilindragem",
    "cilindrai": "cilindrar",
    "cilindrais": "cilindrar",
    "cilindram": "cilindrar",
    "cilindramo": "cilindrar",
    "cilindramos": "cilindrar",
    "cilindrando": "cilindrar",
    "cilindrara": "cilindrar",
    "cilindraram": "cilindrar",
    "cilindraras": "cilindrar",
    "cilindrarde": "cilindrar",
    "cilindrardes": "cilindrar",
    "cilindrare": "cilindrar",
    "cilindrarei": "cilindrar",
    "cilindrareis": "cilindrar",
    "cilindrarem": "cilindrar",
    "cilindraremos": "cilindrar",
    "cilindrares": "cilindrar",
    "cilindraria": "cilindrar",
    "cilindrariam": "cilindrar",
    "cilindrarias": "cilindrar",
    "cilindrarmo": "cilindrar",
    "cilindrarmos": "cilindrar",
    "cilindrará": "cilindrar",
    "cilindrarás": "cilindrar",
    "cilindrarão": "cilindrar",
    "cilindraríamos": "cilindrar",
    "cilindraríeis": "cilindrar",
    "cilindras": "cilindrar",
    "cilindrasse": "cilindrar",
    "cilindrassem": "cilindrar",
    "cilindrasses": "cilindrar",
    "cilindraste": "cilindrar",
    "cilindrastes": "cilindrar",
    "cilindrava": "cilindrar",
    "cilindravam": "cilindrar",
    "cilindravas": "cilindrar",
    "cilindre": "cilindrar",
    "cilindrei": "cilindrar",
    "cilindreis": "cilindrar",
    "cilindrem": "cilindrar",
    "cilindremo": "cilindrar",
    "cilindremos": "cilindrar",
    "cilindres": "cilindrar",
    "cilindricidades": "cilindricidade",
    "cilindriformes": "cilindriforme",
    "cilindro": "cilindrar",
    "cilindrocéfala": "cilindrocéfalo",
    "cilindrocéfalas": "cilindrocéfalo",
    "cilindrocéfalos": "cilindrocéfalo",
    "cilindrométrica": "cilindrométrico",
    "cilindrométricas": "cilindrométrico",
    "cilindrométricos": "cilindrométrico",
    "cilindros": "cilindro",
    "cilindrou": "cilindrar",
    "cilindrá": "cilindrar",
    "cilindrámo": "cilindrar",
    "cilindrámos": "cilindrar",
    "cilindráramo": "cilindrar",
    "cilindráramos": "cilindrar",
    "cilindrárei": "cilindrar",
    "cilindráreis": "cilindrar",
    "cilindrásseis": "cilindrar",
    "cilindrássemos": "cilindrar",
    "cilindrávamo": "cilindrar",
    "cilindrávamos": "cilindrar",
    "cilindrávei": "cilindrar",
    "cilindráveis": "cilindrável",
    "cilindróides": "cilindróide",
    "ciliobranquiada": "ciliobranquiado",
    "ciliobranquiadas": "ciliobranquiado",
    "ciliobranquiados": "ciliobranquiado",
    "cilitas": "cilita",
    "ciliógrada": "ciliógrado",
    "ciliógradas": "ciliógrado",
    "ciliógrados": "ciliógrado",
    "cilícia": "cilício",
    "cilícias": "cilício",
    "cilícios": "cilício",
    "cilídea": "cilídeo",
    "cilídeas": "cilídeo",
    "cilídeos": "cilídeo",
    "cilífera": "cilífero",
    "cilíferas": "cilífero",
    "cilíferos": "cilífero",
    "cilígera": "cilígero",
    "cilígeras": "cilígero",
    "cilígeros": "cilígero",
    "cilíndrica": "cilíndrico",
    "cilíndricas": "cilíndrico",
    "cilíndricos": "cilíndrico",
    "cilíolos": "cilíolo",
    "cilítica": "cilítico",
    "cilíticas": "cilítico",
    "cilíticos": "cilítico",
    "cimalhas": "cimalha",
    "cimas": "cima",
    "cimbres": "cimbre",
    "cimbros": "cimbro",
    "cimeira": "cimeiro",
    "cimeiras": "cimeiro",
    "cimeiros": "cimeiro",
    "cimenta": "cimentar",
    "cimentada": "cimentar",
    "cimentadas": "cimentar",
    "cimentado": "cimentar",
    "cimentados": "cimentar",
    "cimentai": "cimentar",
    "cimentais": "cimentar",
    "cimentam": "cimentar",
    "cimentamo": "cimentar",
    "cimentamos": "cimentar",
    "cimentando": "cimentar",
    "cimentara": "cimentar",
    "cimentaram": "cimentar",
    "cimentaras": "cimentar",
    "cimentarde": "cimentar",
    "cimentardes": "cimentar",
    "cimentare": "cimentar",
    "cimentarei": "cimentar",
    "cimentareis": "cimentar",
    "cimentarem": "cimentar",
    "cimentaremos": "cimentar",
    "cimentares": "cimentar",
    "cimentaria": "cimentar",
    "cimentariam": "cimentar",
    "cimentarias": "cimentar",
    "cimentarmo": "cimentar",
    "cimentarmos": "cimentar",
    "cimentará": "cimentar",
    "cimentarás": "cimentar",
    "cimentarão": "cimentar",
    "cimentaríamos": "cimentar",
    "cimentaríeis": "cimentar",
    "cimentas": "cimentar",
    "cimentasse": "cimentar",
    "cimentassem": "cimentar",
    "cimentasses": "cimentar",
    "cimentaste": "cimentar",
    "cimentastes": "cimentar",
    "cimentava": "cimentar",
    "cimentavam": "cimentar",
    "cimentavas": "cimentar",
    "cimentações": "cimentação",
    "cimente": "cimentar",
    "cimentei": "cimentar",
    "cimenteiras": "cimenteira",
    "cimenteis": "cimentar",
    "cimentem": "cimentar",
    "cimentemo": "cimentar",
    "cimentemos": "cimentar",
    "cimentes": "cimentar",
    "cimento": "cimentar",
    "cimentos": "cimento",
    "cimentou": "cimentar",
    "cimentá": "cimentar",
    "cimentámo": "cimentar",
    "cimentámos": "cimentar",
    "cimentáramo": "cimentar",
    "cimentáramos": "cimentar",
    "cimentárei": "cimentar",
    "cimentáreis": "cimentar",
    "cimentásseis": "cimentar",
    "cimentássemos": "cimentar",
    "cimentávamo": "cimentar",
    "cimentávamos": "cimentar",
    "cimentávei": "cimentar",
    "cimentáveis": "cimentável",
    "cimitarras": "cimitarra",
    "cimografias": "cimografia",
    "cimos": "cimo",
    "cimácios": "cimácio",
    "cimélios": "cimélio",
    "ciméria": "cimério",
    "cimérias": "cimério",
    "cimérios": "cimério",
    "cimógrafos": "cimógrafo",
    "cinabres": "cinabre",
    "cinabrina": "cinabrino",
    "cinabrinas": "cinabrino",
    "cinabrinos": "cinabrino",
    "cinacantas": "cinacanta",
    "cinamomos": "cinamomo",
    "cinantropa": "cinantropo",
    "cinantropas": "cinantropo",
    "cinantropias": "cinantropia",
    "cinantropos": "cinantropo",
    "cinantrópica": "cinantrópico",
    "cinantrópicas": "cinantrópico",
    "cinantrópicos": "cinantrópico",
    "cinarinas": "cinarina",
    "cinarácea": "cinaráceo",
    "cinaráceas": "cinaráceo",
    "cinaráceos": "cinaráceo",
    "cinca": "cincar",
    "cincada": "cincar",
    "cincadas": "cincar",
    "cincado": "cincar",
    "cincados": "cincar",
    "cincais": "cincar",
    "cincam": "cincar",
    "cincamo": "cincar",
    "cincamos": "cincar",
    "cincando": "cincar",
    "cincara": "cincar",
    "cincaram": "cincar",
    "cincaras": "cincar",
    "cincardes": "cincar",
    "cincarei": "cincar",
    "cincareis": "cincar",
    "cincarem": "cincar",
    "cincaremos": "cincar",
    "cincares": "cincar",
    "cincaria": "cincar",
    "cincariam": "cincar",
    "cincarias": "cincar",
    "cincarmo": "cincar",
    "cincarmos": "cincar",
    "cincará": "cincar",
    "cincarás": "cincar",
    "cincarão": "cincar",
    "cincaríamos": "cincar",
    "cincaríeis": "cincar",
    "cincas": "cincar",
    "cincasse": "cincar",
    "cincassem": "cincar",
    "cincasses": "cincar",
    "cincaste": "cincar",
    "cincastes": "cincar",
    "cincava": "cincar",
    "cincavam": "cincar",
    "cincavas": "cincar",
    "cinceiros": "cinceiro",
    "cincha": "cinchar",
    "cinchada": "cinchar",
    "cinchadas": "cinchar",
    "cinchado": "cinchar",
    "cinchados": "cinchar",
    "cinchai": "cinchar",
    "cinchais": "cinchar",
    "cincham": "cinchar",
    "cinchamo": "cinchar",
    "cinchamos": "cinchar",
    "cinchando": "cinchar",
    "cinchara": "cinchar",
    "cincharam": "cinchar",
    "cincharas": "cinchar",
    "cincharde": "cinchar",
    "cinchardes": "cinchar",
    "cinchare": "cinchar",
    "cincharei": "cinchar",
    "cinchareis": "cinchar",
    "cincharem": "cinchar",
    "cincharemos": "cinchar",
    "cinchares": "cinchar",
    "cincharia": "cinchar",
    "cinchariam": "cinchar",
    "cincharias": "cinchar",
    "cincharmo": "cinchar",
    "cincharmos": "cinchar",
    "cinchará": "cinchar",
    "cincharás": "cinchar",
    "cincharão": "cinchar",
    "cincharíamos": "cinchar",
    "cincharíeis": "cinchar",
    "cinchas": "cinchar",
    "cinchasse": "cinchar",
    "cinchassem": "cinchar",
    "cinchasses": "cinchar",
    "cinchaste": "cinchar",
    "cinchastes": "cinchar",
    "cinchava": "cinchar",
    "cinchavam": "cinchar",
    "cinchavas": "cinchar",
    "cinche": "cinchar",
    "cinchei": "cinchar",
    "cincheis": "cinchar",
    "cinchem": "cinchar",
    "cinchemo": "cinchar",
    "cinchemos": "cinchar",
    "cinches": "cinchar",
    "cincho": "cinchar",
    "cinchoninas": "cinchonina",
    "cinchos": "cincho",
    "cinchou": "cinchar",
    "cinchá": "cinchar",
    "cinchámo": "cinchar",
    "cinchámos": "cinchar",
    "cincháramo": "cinchar",
    "cincháramos": "cinchar",
    "cinchárei": "cinchar",
    "cincháreis": "cinchar",
    "cinchásseis": "cinchar",
    "cinchássemos": "cinchar",
    "cinchávamo": "cinchar",
    "cinchávamos": "cinchar",
    "cinchávei": "cinchar",
    "cincháveis": "cinchar",
    "cinchónias": "cinchónia",
    "cinco": "cincar",
    "cincou": "cincar",
    "cincámo": "cincar",
    "cincámos": "cincar",
    "cincáramo": "cincar",
    "cincáramos": "cincar",
    "cincáreis": "cincar",
    "cincásseis": "cincar",
    "cincássemos": "cincar",
    "cincávamo": "cincar",
    "cincávamos": "cincar",
    "cincáveis": "cincar",
    "cinda": "cindir",
    "cindais": "cindir",
    "cindam": "cindir",
    "cindamo": "cindir",
    "cindamos": "cindir",
    "cindas": "cindir",
    "cinde": "cindir",
    "cindem": "cindir",
    "cindes": "cindir",
    "cindi": "cindir",
    "cindia": "cindir",
    "cindiam": "cindir",
    "cindias": "cindir",
    "cindida": "cindir",
    "cindidas": "cindir",
    "cindido": "cindir",
    "cindidos": "cindir",
    "cindimo": "cindir",
    "cindimos": "cindir",
    "cindindo": "cindir",
    "cindira": "cindir",
    "cindiram": "cindir",
    "cindiras": "cindir",
    "cindirde": "cindir",
    "cindirdes": "cindir",
    "cindire": "cindir",
    "cindirei": "cindir",
    "cindireis": "cindir",
    "cindirem": "cindir",
    "cindiremos": "cindir",
    "cindires": "cindir",
    "cindiria": "cindir",
    "cindiriam": "cindir",
    "cindirias": "cindir",
    "cindirmo": "cindir",
    "cindirmos": "cindir",
    "cindirá": "cindir",
    "cindirás": "cindir",
    "cindirão": "cindir",
    "cindiríamos": "cindir",
    "cindiríeis": "cindir",
    "cindis": "cindir",
    "cindisse": "cindir",
    "cindissem": "cindir",
    "cindisses": "cindir",
    "cindiste": "cindir",
    "cindistes": "cindir",
    "cindiu": "cindir",
    "cindo": "cindir",
    "cindíamo": "cindir",
    "cindíamos": "cindir",
    "cindíei": "cindir",
    "cindíeis": "cindir",
    "cindíramo": "cindir",
    "cindíramos": "cindir",
    "cindírei": "cindir",
    "cindíreis": "cindir",
    "cindísseis": "cindir",
    "cindíssemos": "cindir",
    "cindíveis": "cindível",
    "cineastas": "cineasta",
    "cineclubes": "cineclube",
    "cinefilias": "cinefilia",
    "cinegética": "cinegético",
    "cinegéticas": "cinegético",
    "cinegéticos": "cinegético",
    "cinemas": "cinema",
    "cinemascópica": "cinemascópico",
    "cinemascópicas": "cinemascópico",
    "cinemascópicos": "cinemascópico",
    "cinemascópios": "cinemascópio",
    "cinematecas": "cinemateca",
    "cinematografa": "cinematografar",
    "cinematografada": "cinematografar",
    "cinematografadas": "cinematografar",
    "cinematografado": "cinematografar",
    "cinematografados": "cinematografar",
    "cinematografai": "cinematografar",
    "cinematografais": "cinematografar",
    "cinematografam": "cinematografar",
    "cinematografamo": "cinematografar",
    "cinematografamos": "cinematografar",
    "cinematografando": "cinematografar",
    "cinematografara": "cinematografar",
    "cinematografaram": "cinematografar",
    "cinematografaras": "cinematografar",
    "cinematografarde": "cinematografar",
    "cinematografardes": "cinematografar",
    "cinematografare": "cinematografar",
    "cinematografarei": "cinematografar",
    "cinematografareis": "cinematografar",
    "cinematografarem": "cinematografar",
    "cinematografaremos": "cinematografar",
    "cinematografares": "cinematografar",
    "cinematografaria": "cinematografar",
    "cinematografariam": "cinematografar",
    "cinematografarias": "cinematografar",
    "cinematografarmo": "cinematografar",
    "cinematografarmos": "cinematografar",
    "cinematografará": "cinematografar",
    "cinematografarás": "cinematografar",
    "cinematografarão": "cinematografar",
    "cinematografaríamos": "cinematografar",
    "cinematografaríeis": "cinematografar",
    "cinematografas": "cinematografar",
    "cinematografasse": "cinematografar",
    "cinematografassem": "cinematografar",
    "cinematografasses": "cinematografar",
    "cinematografaste": "cinematografar",
    "cinematografastes": "cinematografar",
    "cinematografava": "cinematografar",
    "cinematografavam": "cinematografar",
    "cinematografavas": "cinematografar",
    "cinematografe": "cinematografar",
    "cinematografei": "cinematografar",
    "cinematografeis": "cinematografar",
    "cinematografem": "cinematografar",
    "cinematografemo": "cinematografar",
    "cinematografemos": "cinematografar",
    "cinematografes": "cinematografar",
    "cinematografias": "cinematografia",
    "cinematografo": "cinematografar",
    "cinematografou": "cinematografar",
    "cinematografá": "cinematografar",
    "cinematografámo": "cinematografar",
    "cinematografámos": "cinematografar",
    "cinematografáramo": "cinematografar",
    "cinematografáramos": "cinematografar",
    "cinematografárei": "cinematografar",
    "cinematografáreis": "cinematografar",
    "cinematografásseis": "cinematografar",
    "cinematografássemos": "cinematografar",
    "cinematografávamo": "cinematografar",
    "cinematografávamos": "cinematografar",
    "cinematografávei": "cinematografar",
    "cinematografáveis": "cinematografar",
    "cinematográfica": "cinematográfico",
    "cinematográficas": "cinematográfico",
    "cinematográficos": "cinematográfico",
    "cinematoscópica": "cinematoscópico",
    "cinematoscópicas": "cinematoscópico",
    "cinematoscópicos": "cinematoscópico",
    "cinematoscópios": "cinematoscópio",
    "cinematógrafos": "cinematógrafo",
    "cinemeira": "cinemeiro",
    "cinemeiras": "cinemeiro",
    "cinemeiros": "cinemeiro",
    "cinemoscópios": "cinemoscópio",
    "cinemática": "cinemático",
    "cinemáticas": "cinemático",
    "cinemáticos": "cinemático",
    "cinerada": "cinerado",
    "cineradas": "cinerado",
    "cinerados": "cinerado",
    "cineramas": "cinerama",
    "cinerações": "cineração",
    "cineriformes": "cineriforme",
    "cineritos": "cinerito",
    "cinerária": "cinerário",
    "cinerárias": "cinerário",
    "cinerários": "cinerário",
    "cinerícia": "cinerício",
    "cinerícias": "cinerício",
    "cinerícios": "cinerício",
    "cines": "cine",
    "cinescopias": "cinescopia",
    "cinescópica": "cinescópico",
    "cinescópicas": "cinescópico",
    "cinescópicos": "cinescópico",
    "cinestesias": "cinestesia",
    "cinestásica": "cinestásico",
    "cinestásicas": "cinestásico",
    "cinestásicos": "cinestásico",
    "cineteatros": "cineteatro",
    "cinetofones": "cinetofone",
    "cinetofónica": "cinetofónico",
    "cinetofónicas": "cinetofónico",
    "cinetofónicos": "cinetofónico",
    "cinetoscópica": "cinetoscópico",
    "cinetoscópicas": "cinetoscópico",
    "cinetoscópicos": "cinetoscópico",
    "cinetoscópios": "cinetoscópio",
    "cingalesa": "cingalês",
    "cingalesas": "cingalês",
    "cingaleses": "cingalês",
    "cinge": "cingir",
    "cingeis": "cingel",
    "cingeladas": "cingelada",
    "cingeleira": "cingeleiro",
    "cingeleiras": "cingeleiro",
    "cingeleiros": "cingeleiro",
    "cingem": "cingir",
    "cinges": "cingir",
    "cingi": "cingir",
    "cingia": "cingir",
    "cingiam": "cingir",
    "cingias": "cingir",
    "cingida": "cingir",
    "cingidas": "cingir",
    "cingideiras": "cingideira",
    "cingido": "cingir",
    "cingidoiros": "cingidoiro",
    "cingidos": "cingir",
    "cingidouros": "cingidouro",
    "cingimo": "cingir",
    "cingimos": "cingir",
    "cingindo": "cingir",
    "cingira": "cingir",
    "cingiram": "cingir",
    "cingiras": "cingir",
    "cingirde": "cingir",
    "cingirdes": "cingir",
    "cingire": "cingir",
    "cingirei": "cingir",
    "cingireis": "cingir",
    "cingirem": "cingir",
    "cingiremos": "cingir",
    "cingires": "cingir",
    "cingiria": "cingir",
    "cingiriam": "cingir",
    "cingirias": "cingir",
    "cingirmo": "cingir",
    "cingirmos": "cingir",
    "cingirá": "cingir",
    "cingirás": "cingir",
    "cingirão": "cingir",
    "cingiríamos": "cingir",
    "cingiríeis": "cingir",
    "cingis": "cingir",
    "cingisse": "cingir",
    "cingissem": "cingir",
    "cingisses": "cingir",
    "cingiste": "cingir",
    "cingistes": "cingir",
    "cingiu": "cingir",
    "cingíamo": "cingir",
    "cingíamos": "cingir",
    "cingíei": "cingir",
    "cingíeis": "cingir",
    "cingíramo": "cingir",
    "cingíramos": "cingir",
    "cingírei": "cingir",
    "cingíreis": "cingir",
    "cingísseis": "cingir",
    "cingíssemos": "cingir",
    "cinipidea": "cinipideo",
    "cinipideas": "cinipideo",
    "cinipideos": "cinipideo",
    "cinipídeos": "cinipídeo",
    "cinismos": "cinismo",
    "cinja": "cingir",
    "cinjais": "cingir",
    "cinjam": "cingir",
    "cinjamo": "cingir",
    "cinjamos": "cingir",
    "cinjas": "cingir",
    "cinjo": "cingir",
    "cinocéfala": "cinocéfalo",
    "cinocéfalas": "cinocéfalo",
    "cinocéfalos": "cinocéfalo",
    "cinofagias": "cinofagia",
    "cinofilias": "cinofilia",
    "cinofobias": "cinofobia",
    "cinoglossas": "cinoglossa",
    "cinografias": "cinografia",
    "cinográfica": "cinográfico",
    "cinográficas": "cinográfico",
    "cinográficos": "cinográfico",
    "cinomorfa": "cinomorfo",
    "cinomorfas": "cinomorfo",
    "cinomorfos": "cinomorfo",
    "cinorexias": "cinorexia",
    "cinoréxica": "cinoréxico",
    "cinoréxicas": "cinoréxico",
    "cinoréxicos": "cinoréxico",
    "cinosura": "cinosuro",
    "cinosuras": "cinosuro",
    "cinosuros": "cinosuro",
    "cinque": "cincar",
    "cinquei": "cincar",
    "cinqueira": "cinqueiro",
    "cinqueiras": "cinqueiro",
    "cinqueiros": "cinqueiro",
    "cinqueis": "cincar",
    "cinquem": "cincar",
    "cinquemos": "cincar",
    "cinquenas": "cinquena",
    "cinquentenários": "cinquentenário",
    "cinquenterária": "cinquenterário",
    "cinquenterárias": "cinquenterário",
    "cinquenterários": "cinquenterário",
    "cinquentona": "cinquentão",
    "cinquentonas": "cinquentão",
    "cinquentões": "cinquentão",
    "cinques": "cincar",
    "cinquinhos": "cinquinho",
    "cintada": "cintado",
    "cintadas": "cintado",
    "cintadora": "cintador",
    "cintadoras": "cintador",
    "cintadores": "cintador",
    "cintados": "cintado",
    "cintas": "cinta",
    "cinteiros": "cinteiro",
    "cinteis": "cintel",
    "cintila": "cintilar",
    "cintilada": "cintilar",
    "cintiladas": "cintilar",
    "cintilado": "cintilar",
    "cintiladora": "cintilador",
    "cintiladoras": "cintilador",
    "cintiladores": "cintilador",
    "cintilados": "cintilar",
    "cintilai": "cintilar",
    "cintilais": "cintilar",
    "cintilam": "cintilar",
    "cintilamo": "cintilar",
    "cintilamos": "cintilar",
    "cintilando": "cintilar",
    "cintilantes": "cintilante",
    "cintilara": "cintilar",
    "cintilaram": "cintilar",
    "cintilaras": "cintilar",
    "cintilarde": "cintilar",
    "cintilardes": "cintilar",
    "cintilare": "cintilar",
    "cintilarei": "cintilar",
    "cintilareis": "cintilar",
    "cintilarem": "cintilar",
    "cintilaremos": "cintilar",
    "cintilares": "cintilar",
    "cintilaria": "cintilar",
    "cintilariam": "cintilar",
    "cintilarias": "cintilar",
    "cintilarmo": "cintilar",
    "cintilarmos": "cintilar",
    "cintilará": "cintilar",
    "cintilarás": "cintilar",
    "cintilarão": "cintilar",
    "cintilaríamos": "cintilar",
    "cintilaríeis": "cintilar",
    "cintilas": "cintilar",
    "cintilasse": "cintilar",
    "cintilassem": "cintilar",
    "cintilasses": "cintilar",
    "cintilaste": "cintilar",
    "cintilastes": "cintilar",
    "cintilava": "cintilar",
    "cintilavam": "cintilar",
    "cintilavas": "cintilar",
    "cintilações": "cintilação",
    "cintile": "cintilar",
    "cintilei": "cintilar",
    "cintileis": "cintilar",
    "cintilem": "cintilar",
    "cintilemo": "cintilar",
    "cintilemos": "cintilar",
    "cintiles": "cintilar",
    "cintilhos": "cintilho",
    "cintilo": "cintilar",
    "cintilou": "cintilar",
    "cintilá": "cintilar",
    "cintilámo": "cintilar",
    "cintilámos": "cintilar",
    "cintiláramo": "cintilar",
    "cintiláramos": "cintilar",
    "cintilárei": "cintilar",
    "cintiláreis": "cintilar",
    "cintilásseis": "cintilar",
    "cintilássemos": "cintilar",
    "cintilávamo": "cintilar",
    "cintilávamos": "cintilar",
    "cintilávei": "cintilar",
    "cintiláveis": "cintilar",
    "cintinha": "cinta",
    "cintinhas": "cinta",
    "cintinho": "cinto",
    "cintinhos": "cinto",
    "cintita": "cinta",
    "cintitas": "cinta",
    "cintito": "cinto",
    "cintitos": "cinto",
    "cintos": "cinto",
    "cinturada": "cinturado",
    "cinturadas": "cinturado",
    "cinturados": "cinturado",
    "cinturas": "cintura",
    "cinturinha": "cintura",
    "cinturinhas": "cintura",
    "cinturita": "cintura",
    "cinturitas": "cintura",
    "cinturões": "cinturão",
    "cinza": "cinzar",
    "cinzada": "cinzar",
    "cinzadas": "cinzar",
    "cinzado": "cinzar",
    "cinzados": "cinzar",
    "cinzai": "cinzar",
    "cinzais": "cinzar",
    "cinzam": "cinzar",
    "cinzamo": "cinzar",
    "cinzamos": "cinzar",
    "cinzando": "cinzar",
    "cinzara": "cinzar",
    "cinzaram": "cinzar",
    "cinzaras": "cinzar",
    "cinzarde": "cinzar",
    "cinzardes": "cinzar",
    "cinzare": "cinzar",
    "cinzarei": "cinzar",
    "cinzareis": "cinzar",
    "cinzarem": "cinzar",
    "cinzaremos": "cinzar",
    "cinzares": "cinzar",
    "cinzaria": "cinzar",
    "cinzariam": "cinzar",
    "cinzarias": "cinzar",
    "cinzarmo": "cinzar",
    "cinzarmos": "cinzar",
    "cinzará": "cinzar",
    "cinzarás": "cinzar",
    "cinzarão": "cinzar",
    "cinzaríamos": "cinzar",
    "cinzaríeis": "cinzar",
    "cinzas": "cinzar",
    "cinzasse": "cinzar",
    "cinzassem": "cinzar",
    "cinzasses": "cinzar",
    "cinzaste": "cinzar",
    "cinzastes": "cinzar",
    "cinzava": "cinzar",
    "cinzavam": "cinzar",
    "cinzavas": "cinzar",
    "cinze": "cinzar",
    "cinzei": "cinzar",
    "cinzeirinho": "cinzeiro",
    "cinzeirinhos": "cinzeiro",
    "cinzeirito": "cinzeiro",
    "cinzeiritos": "cinzeiro",
    "cinzeiros": "cinzeiro",
    "cinzeis": "cinzar",
    "cinzela": "cinzelar",
    "cinzelada": "cinzelar",
    "cinzeladas": "cinzelar",
    "cinzelado": "cinzelar",
    "cinzeladora": "cinzelador",
    "cinzeladoras": "cinzelador",
    "cinzeladores": "cinzelador",
    "cinzelados": "cinzelar",
    "cinzeladuras": "cinzeladura",
    "cinzelagens": "cinzelagem",
    "cinzelai": "cinzelar",
    "cinzelais": "cinzelar",
    "cinzelam": "cinzelar",
    "cinzelamentos": "cinzelamento",
    "cinzelamo": "cinzelar",
    "cinzelamos": "cinzelar",
    "cinzelando": "cinzelar",
    "cinzelara": "cinzelar",
    "cinzelaram": "cinzelar",
    "cinzelaras": "cinzelar",
    "cinzelarde": "cinzelar",
    "cinzelardes": "cinzelar",
    "cinzelare": "cinzelar",
    "cinzelarei": "cinzelar",
    "cinzelareis": "cinzelar",
    "cinzelarem": "cinzelar",
    "cinzelaremos": "cinzelar",
    "cinzelares": "cinzelar",
    "cinzelaria": "cinzelar",
    "cinzelariam": "cinzelar",
    "cinzelarias": "cinzelar",
    "cinzelarmo": "cinzelar",
    "cinzelarmos": "cinzelar",
    "cinzelará": "cinzelar",
    "cinzelarás": "cinzelar",
    "cinzelarão": "cinzelar",
    "cinzelaríamos": "cinzelar",
    "cinzelaríeis": "cinzelar",
    "cinzelas": "cinzelar",
    "cinzelasse": "cinzelar",
    "cinzelassem": "cinzelar",
    "cinzelasses": "cinzelar",
    "cinzelaste": "cinzelar",
    "cinzelastes": "cinzelar",
    "cinzelava": "cinzelar",
    "cinzelavam": "cinzelar",
    "cinzelavas": "cinzelar",
    "cinzele": "cinzelar",
    "cinzelei": "cinzelar",
    "cinzeleis": "cinzelar",
    "cinzelem": "cinzelar",
    "cinzelemo": "cinzelar",
    "cinzelemos": "cinzelar",
    "cinzeles": "cinzelar",
    "cinzelo": "cinzelar",
    "cinzelou": "cinzelar",
    "cinzelá": "cinzelar",
    "cinzelámo": "cinzelar",
    "cinzelámos": "cinzelar",
    "cinzeláramo": "cinzelar",
    "cinzeláramos": "cinzelar",
    "cinzelárei": "cinzelar",
    "cinzeláreis": "cinzelar",
    "cinzelásseis": "cinzelar",
    "cinzelássemos": "cinzelar",
    "cinzelávamo": "cinzelar",
    "cinzelávamos": "cinzelar",
    "cinzelávei": "cinzelar",
    "cinzeláveis": "cinzelar",
    "cinzem": "cinzar",
    "cinzemo": "cinzar",
    "cinzemos": "cinzar",
    "cinzenta": "cinzento",
    "cinzentas": "cinzento",
    "cinzentinho": "cinzento",
    "cinzentinhos": "cinzento",
    "cinzentismos": "cinzentismo",
    "cinzentito": "cinzento",
    "cinzentitos": "cinzento",
    "cinzentona": "cinzentão",
    "cinzentonas": "cinzentão",
    "cinzentos": "cinzento",
    "cinzentões": "cinzentão",
    "cinzes": "cinzar",
    "cinzo": "cinzar",
    "cinzou": "cinzar",
    "cinzá": "cinzar",
    "cinzámo": "cinzar",
    "cinzámos": "cinzar",
    "cinzáramo": "cinzar",
    "cinzáramos": "cinzar",
    "cinzárei": "cinzar",
    "cinzáreis": "cinzar",
    "cinzásseis": "cinzar",
    "cinzássemos": "cinzar",
    "cinzávamo": "cinzar",
    "cinzávamos": "cinzar",
    "cinzávei": "cinzar",
    "cinzáveis": "cinzar",
    "cinzéis": "cinzel",
    "cinábrios": "cinábrio",
    "cinéfila": "cinéfilo",
    "cinéfilas": "cinéfilo",
    "cinéfilos": "cinéfilo",
    "cinéria": "cinério",
    "cinérias": "cinério",
    "cinérios": "cinério",
    "cinética": "cinético",
    "cinéticas": "cinético",
    "cinéticos": "cinético",
    "cinípidas": "cinípida",
    "cinófaga": "cinófago",
    "cinófagas": "cinófago",
    "cinófagos": "cinófago",
    "cinófila": "cinófilo",
    "cinófilas": "cinófilo",
    "cinófilos": "cinófilo",
    "cinófoba": "cinófobo",
    "cinófobas": "cinófobo",
    "cinófobos": "cinófobo",
    "cio": "ciar",
    "ciobas": "cioba",
    "ciografias": "ciografia",
    "ciográfica": "ciográfico",
    "ciográficas": "ciográfico",
    "ciográficos": "ciográfico",
    "cios": "cio",
    "ciosa": "cioso",
    "ciosas": "cioso",
    "ciosos": "cioso",
    "ciou": "ciar",
    "ciperácea": "ciperáceo",
    "ciperáceas": "ciperáceo",
    "ciperáceos": "ciperáceo",
    "cipoadas": "cipoada",
    "cipoais": "cipoal",
    "cipolinos": "cipolino",
    "cipos": "cipo",
    "ciprestais": "ciprestal",
    "ciprestes": "cipreste",
    "cipridofobias": "cipridofobia",
    "cipridofábica": "cipridofábico",
    "cipridofábicas": "cipridofábico",
    "cipridofábicos": "cipridofábico",
    "cipridologias": "cipridologia",
    "cipridológica": "cipridológico",
    "cipridológicas": "cipridológico",
    "cipridológicos": "cipridológico",
    "cipridófoba": "cipridófobo",
    "cipridófobas": "cipridófobo",
    "cipridófobos": "cipridófobo",
    "cipridóloga": "cipridólogo",
    "cipridólogas": "cipridólogo",
    "cipridólogos": "cipridólogo",
    "ciprinos": "ciprino",
    "ciprinídea": "ciprinídeo",
    "ciprinídeas": "ciprinídeo",
    "ciprinídeos": "ciprinídeo",
    "cipriotas": "cipriota",
    "ciprínidas": "ciprínida",
    "cipselídea": "cipselídeo",
    "cipselídeas": "cipselídeo",
    "cipselídeos": "cipselídeo",
    "cipsélidas": "cipsélida",
    "cipós": "cipó",
    "cirandada": "cirandado",
    "cirandadas": "cirandado",
    "cirandados": "cirandado",
    "cirandagens": "cirandagem",
    "cirandas": "ciranda",
    "cirandeiras": "cirandeira",
    "cirandinha": "ciranda",
    "cirandinhas": "ciranda",
    "cirandita": "ciranda",
    "ciranditas": "ciranda",
    "circassiana": "circassiano",
    "circassianas": "circassiano",
    "circassianos": "circassiano",
    "circenses": "circense",
    "circia": "circiar",
    "circiada": "circiar",
    "circiadas": "circiar",
    "circiadelas": "circiadela",
    "circiado": "circiar",
    "circiados": "circiar",
    "circiai": "circiar",
    "circiais": "circiar",
    "circiam": "circiar",
    "circiamo": "circiar",
    "circiamos": "circiar",
    "circiando": "circiar",
    "circiara": "circiar",
    "circiaram": "circiar",
    "circiaras": "circiar",
    "circiarde": "circiar",
    "circiardes": "circiar",
    "circiare": "circiar",
    "circiarei": "circiar",
    "circiareis": "circiar",
    "circiarem": "circiar",
    "circiaremos": "circiar",
    "circiares": "circiar",
    "circiaria": "circiar",
    "circiariam": "circiar",
    "circiarias": "circiar",
    "circiarmo": "circiar",
    "circiarmos": "circiar",
    "circiará": "circiar",
    "circiarás": "circiar",
    "circiarão": "circiar",
    "circiaríamos": "circiar",
    "circiaríeis": "circiar",
    "circias": "circiar",
    "circiasse": "circiar",
    "circiassem": "circiar",
    "circiasses": "circiar",
    "circiaste": "circiar",
    "circiastes": "circiar",
    "circiava": "circiar",
    "circiavam": "circiar",
    "circiavas": "circiar",
    "circie": "circiar",
    "circiei": "circiar",
    "circieis": "circiar",
    "circiem": "circiar",
    "circiemo": "circiar",
    "circiemos": "circiar",
    "circies": "circiar",
    "circinada": "circinado",
    "circinadas": "circinado",
    "circinados": "circinado",
    "circinais": "circinal",
    "circio": "circiar",
    "circiou": "circiar",
    "circiá": "circiar",
    "circiámo": "circiar",
    "circiámos": "circiar",
    "circiáramo": "circiar",
    "circiáramos": "circiar",
    "circiárei": "circiar",
    "circiáreis": "circiar",
    "circiásseis": "circiar",
    "circiássemos": "circiar",
    "circiávamo": "circiar",
    "circiávamos": "circiar",
    "circiávei": "circiar",
    "circiáveis": "circiar",
    "circos": "circo",
    "circuita": "circuitar",
    "circuitada": "circuitar",
    "circuitadas": "circuitar",
    "circuitado": "circuitar",
    "circuitados": "circuitar",
    "circuitai": "circuitar",
    "circuitais": "circuitar",
    "circuitam": "circuitar",
    "circuitamo": "circuitar",
    "circuitamos": "circuitar",
    "circuitando": "circuitar",
    "circuitara": "circuitar",
    "circuitaram": "circuitar",
    "circuitaras": "circuitar",
    "circuitarde": "circuitar",
    "circuitardes": "circuitar",
    "circuitare": "circuitar",
    "circuitarei": "circuitar",
    "circuitareis": "circuitar",
    "circuitarem": "circuitar",
    "circuitaremos": "circuitar",
    "circuitares": "circuitar",
    "circuitaria": "circuitar",
    "circuitariam": "circuitar",
    "circuitarias": "circuitar",
    "circuitarmo": "circuitar",
    "circuitarmos": "circuitar",
    "circuitará": "circuitar",
    "circuitarás": "circuitar",
    "circuitarão": "circuitar",
    "circuitaríamos": "circuitar",
    "circuitaríeis": "circuitar",
    "circuitas": "circuitar",
    "circuitasse": "circuitar",
    "circuitassem": "circuitar",
    "circuitasses": "circuitar",
    "circuitaste": "circuitar",
    "circuitastes": "circuitar",
    "circuitava": "circuitar",
    "circuitavam": "circuitar",
    "circuitavas": "circuitar",
    "circuite": "circuitar",
    "circuitei": "circuitar",
    "circuiteis": "circuitar",
    "circuitem": "circuitar",
    "circuitemo": "circuitar",
    "circuitemos": "circuitar",
    "circuites": "circuitar",
    "circuito": "circuitar",
    "circuitos": "circuito",
    "circuitou": "circuitar",
    "circuitá": "circuitar",
    "circuitámo": "circuitar",
    "circuitámos": "circuitar",
    "circuitáramo": "circuitar",
    "circuitáramos": "circuitar",
    "circuitárei": "circuitar",
    "circuitáreis": "circuitar",
    "circuitásseis": "circuitar",
    "circuitássemos": "circuitar",
    "circuitávamo": "circuitar",
    "circuitávamos": "circuitar",
    "circuitávei": "circuitar",
    "circuitáveis": "circuitar",
    "circuições": "circuição",
    "circula": "circular",
    "circulada": "circular",
    "circuladas": "circular",
    "circulado": "circular",
    "circuladora": "circulador",
    "circuladoras": "circulador",
    "circuladores": "circulador",
    "circulados": "circular",
    "circulai": "circular",
    "circulais": "circular",
    "circulam": "circular",
    "circulamo": "circular",
    "circulamos": "circular",
    "circulando": "circular",
    "circulantes": "circulante",
    "circulara": "circular",
    "circularam": "circular",
    "circularas": "circular",
    "circulardes": "circular",
    "circularei": "circular",
    "circulareis": "circular",
    "circularem": "circular",
    "circularemos": "circular",
    "circulares": "circular",
    "circularia": "circular",
    "circulariam": "circular",
    "circularias": "circular",
    "circularidades": "circularidade",
    "circularmo": "circular",
    "circularmos": "circular",
    "circulará": "circular",
    "circularás": "circular",
    "circularão": "circular",
    "circularíamos": "circular",
    "circularíeis": "circular",
    "circulas": "circular",
    "circulasse": "circular",
    "circulassem": "circular",
    "circulasses": "circular",
    "circulaste": "circular",
    "circulastes": "circular",
    "circulatória": "circulatório",
    "circulatórias": "circulatório",
    "circulatórios": "circulatório",
    "circulava": "circular",
    "circulavam": "circular",
    "circulavas": "circular",
    "circulações": "circulação",
    "circule": "circular",
    "circulei": "circular",
    "circuleis": "circular",
    "circulem": "circular",
    "circulemo": "circular",
    "circulemos": "circular",
    "circules": "circular",
    "circulo": "circular",
    "circulou": "circular",
    "circulámo": "circular",
    "circulámos": "circular",
    "circuláramo": "circular",
    "circuláramos": "circular",
    "circuláreis": "circular",
    "circulásseis": "circular",
    "circulássemos": "circular",
    "circulávamo": "circular",
    "circulávamos": "circular",
    "circuláveis": "circular",
    "circumpolares": "circumpolar",
    "circuncentros": "circuncentro",
    "circuncidada": "circuncidado",
    "circuncidadas": "circuncidado",
    "circuncidados": "circuncidado",
    "circuncidantes": "circuncidante",
    "circuncisa": "circunciso",
    "circuncisas": "circunciso",
    "circuncisos": "circunciso",
    "circuncisões": "circuncisão",
    "circunda": "circundar",
    "circundada": "circundar",
    "circundadas": "circundar",
    "circundado": "circundar",
    "circundados": "circundar",
    "circundai": "circundar",
    "circundais": "circundar",
    "circundam": "circundar",
    "circundamo": "circundar",
    "circundamos": "circundar",
    "circundando": "circundar",
    "circundantes": "circundante",
    "circundara": "circundar",
    "circundaram": "circundar",
    "circundaras": "circundar",
    "circundarde": "circundar",
    "circundardes": "circundar",
    "circundare": "circundar",
    "circundarei": "circundar",
    "circundareis": "circundar",
    "circundarem": "circundar",
    "circundaremos": "circundar",
    "circundares": "circundar",
    "circundaria": "circundar",
    "circundariam": "circundar",
    "circundarias": "circundar",
    "circundarmo": "circundar",
    "circundarmos": "circundar",
    "circundará": "circundar",
    "circundarás": "circundar",
    "circundarão": "circundar",
    "circundaríamos": "circundar",
    "circundaríeis": "circundar",
    "circundas": "circundar",
    "circundasse": "circundar",
    "circundassem": "circundar",
    "circundasses": "circundar",
    "circundaste": "circundar",
    "circundastes": "circundar",
    "circundava": "circundar",
    "circundavam": "circundar",
    "circundavas": "circundar",
    "circundações": "circundação",
    "circunde": "circundar",
    "circundei": "circundar",
    "circundeis": "circundar",
    "circundem": "circundar",
    "circundemo": "circundar",
    "circundemos": "circundar",
    "circundes": "circundar",
    "circundo": "circundar",
    "circundou": "circundar",
    "circunduta": "circunduto",
    "circundutas": "circunduto",
    "circundutos": "circunduto",
    "circunduções": "circundução",
    "circundá": "circundar",
    "circundámo": "circundar",
    "circundámos": "circundar",
    "circundáramo": "circundar",
    "circundáramos": "circundar",
    "circundárei": "circundar",
    "circundáreis": "circundar",
    "circundásseis": "circundar",
    "circundássemos": "circundar",
    "circundávamo": "circundar",
    "circundávamos": "circundar",
    "circundávei": "circundar",
    "circundáveis": "circundar",
    "circunferenciais": "circunferencial",
    "circunferentes": "circunferente",
    "circunferências": "circunferência",
    "circunflexa": "circunflexo",
    "circunflexas": "circunflexo",
    "circunflexos": "circunflexo",
    "circunflexões": "circunflexão",
    "circunfluentes": "circunfluente",
    "circunfluências": "circunfluência",
    "circunfunda": "circunfundir",
    "circunfundais": "circunfundir",
    "circunfundam": "circunfundir",
    "circunfundamo": "circunfundir",
    "circunfundamos": "circunfundir",
    "circunfundas": "circunfundir",
    "circunfunde": "circunfundir",
    "circunfundem": "circunfundir",
    "circunfundes": "circunfundir",
    "circunfundi": "circunfundir",
    "circunfundia": "circunfundir",
    "circunfundiam": "circunfundir",
    "circunfundias": "circunfundir",
    "circunfundida": "circunfundir",
    "circunfundidas": "circunfundir",
    "circunfundido": "circunfundir",
    "circunfundidos": "circunfundir",
    "circunfundimo": "circunfundir",
    "circunfundimos": "circunfundir",
    "circunfundindo": "circunfundir",
    "circunfundira": "circunfundir",
    "circunfundiram": "circunfundir",
    "circunfundiras": "circunfundir",
    "circunfundirde": "circunfundir",
    "circunfundirdes": "circunfundir",
    "circunfundire": "circunfundir",
    "circunfundirei": "circunfundir",
    "circunfundireis": "circunfundir",
    "circunfundirem": "circunfundir",
    "circunfundiremos": "circunfundir",
    "circunfundires": "circunfundir",
    "circunfundiria": "circunfundir",
    "circunfundiriam": "circunfundir",
    "circunfundirias": "circunfundir",
    "circunfundirmo": "circunfundir",
    "circunfundirmos": "circunfundir",
    "circunfundirá": "circunfundir",
    "circunfundirás": "circunfundir",
    "circunfundirão": "circunfundir",
    "circunfundiríamos": "circunfundir",
    "circunfundiríeis": "circunfundir",
    "circunfundis": "circunfundir",
    "circunfundisse": "circunfundir",
    "circunfundissem": "circunfundir",
    "circunfundisses": "circunfundir",
    "circunfundiste": "circunfundir",
    "circunfundistes": "circunfundir",
    "circunfundiu": "circunfundir",
    "circunfundo": "circunfundir",
    "circunfundíamo": "circunfundir",
    "circunfundíamos": "circunfundir",
    "circunfundíei": "circunfundir",
    "circunfundíeis": "circunfundir",
    "circunfundíramo": "circunfundir",
    "circunfundíramos": "circunfundir",
    "circunfundírei": "circunfundir",
    "circunfundíreis": "circunfundir",
    "circunfundísseis": "circunfundir",
    "circunfundíssemos": "circunfundir",
    "circunfusões": "circunfusão",
    "circunjacentes": "circunjacente",
    "circunjacências": "circunjacência",
    "circunlocuções": "circunlocução",
    "circunlóquios": "circunlóquio",
    "circunroda": "circunrodar",
    "circunrodada": "circunrodar",
    "circunrodadas": "circunrodar",
    "circunrodado": "circunrodar",
    "circunrodados": "circunrodar",
    "circunrodai": "circunrodar",
    "circunrodais": "circunrodar",
    "circunrodam": "circunrodar",
    "circunrodamo": "circunrodar",
    "circunrodamos": "circunrodar",
    "circunrodando": "circunrodar",
    "circunrodara": "circunrodar",
    "circunrodaram": "circunrodar",
    "circunrodaras": "circunrodar",
    "circunrodardes": "circunrodar",
    "circunrodarei": "circunrodar",
    "circunrodareis": "circunrodar",
    "circunrodarem": "circunrodar",
    "circunrodaremos": "circunrodar",
    "circunrodares": "circunrodar",
    "circunrodaria": "circunrodar",
    "circunrodariam": "circunrodar",
    "circunrodarias": "circunrodar",
    "circunrodarmo": "circunrodar",
    "circunrodarmos": "circunrodar",
    "circunrodará": "circunrodar",
    "circunrodarás": "circunrodar",
    "circunrodarão": "circunrodar",
    "circunrodaríamos": "circunrodar",
    "circunrodaríeis": "circunrodar",
    "circunrodas": "circunrodar",
    "circunrodasse": "circunrodar",
    "circunrodassem": "circunrodar",
    "circunrodasses": "circunrodar",
    "circunrodaste": "circunrodar",
    "circunrodastes": "circunrodar",
    "circunrodava": "circunrodar",
    "circunrodavam": "circunrodar",
    "circunrodavas": "circunrodar",
    "circunrode": "circunrodar",
    "circunrodei": "circunrodar",
    "circunrodeis": "circunrodar",
    "circunrodem": "circunrodar",
    "circunrodemo": "circunrodar",
    "circunrodemos": "circunrodar",
    "circunrodes": "circunrodar",
    "circunrodo": "circunrodar",
    "circunrodou": "circunrodar",
    "circunrodámo": "circunrodar",
    "circunrodámos": "circunrodar",
    "circunrodáramo": "circunrodar",
    "circunrodáramos": "circunrodar",
    "circunrodáreis": "circunrodar",
    "circunrodásseis": "circunrodar",
    "circunrodássemos": "circunrodar",
    "circunrodávamo": "circunrodar",
    "circunrodávamos": "circunrodar",
    "circunrodáveis": "circunrodar",
    "circunscreva": "circunscrever",
    "circunscrevais": "circunscrever",
    "circunscrevam": "circunscrever",
    "circunscrevamo": "circunscrever",
    "circunscrevamos": "circunscrever",
    "circunscrevas": "circunscrever",
    "circunscreve": "circunscrever",
    "circunscrevei": "circunscrever",
    "circunscreveis": "circunscrever",
    "circunscrevem": "circunscrever",
    "circunscrevemo": "circunscrever",
    "circunscrevemos": "circunscrever",
    "circunscrevendo": "circunscrever",
    "circunscrevera": "circunscrever",
    "circunscreveram": "circunscrever",
    "circunscreveras": "circunscrever",
    "circunscreverde": "circunscrever",
    "circunscreverdes": "circunscrever",
    "circunscrevere": "circunscrever",
    "circunscreverei": "circunscrever",
    "circunscrevereis": "circunscrever",
    "circunscreverem": "circunscrever",
    "circunscreveremos": "circunscrever",
    "circunscreveres": "circunscrever",
    "circunscreveria": "circunscrever",
    "circunscreveriam": "circunscrever",
    "circunscreverias": "circunscrever",
    "circunscrevermo": "circunscrever",
    "circunscrevermos": "circunscrever",
    "circunscreverá": "circunscrever",
    "circunscreverás": "circunscrever",
    "circunscreverão": "circunscrever",
    "circunscreveríamos": "circunscrever",
    "circunscreveríeis": "circunscrever",
    "circunscreves": "circunscrever",
    "circunscrevesse": "circunscrever",
    "circunscrevessem": "circunscrever",
    "circunscrevesses": "circunscrever",
    "circunscreveste": "circunscrever",
    "circunscrevestes": "circunscrever",
    "circunscreveu": "circunscrever",
    "circunscrevi": "circunscrever",
    "circunscrevia": "circunscrever",
    "circunscreviam": "circunscrever",
    "circunscrevias": "circunscrever",
    "circunscrevo": "circunscrever",
    "circunscrevê": "circunscrever",
    "circunscrevêramo": "circunscrever",
    "circunscrevêramos": "circunscrever",
    "circunscrevêrei": "circunscrever",
    "circunscrevêreis": "circunscrever",
    "circunscrevêsseis": "circunscrever",
    "circunscrevêssemos": "circunscrever",
    "circunscrevíamo": "circunscrever",
    "circunscrevíamos": "circunscrever",
    "circunscrevíei": "circunscrever",
    "circunscrevíeis": "circunscrever",
    "circunscricionais": "circunscricional",
    "circunscrita": "circunscrito",
    "circunscritas": "circunscrito",
    "circunscritiva": "circunscritivo",
    "circunscritivas": "circunscritivo",
    "circunscritivos": "circunscritivo",
    "circunscrito": "circunscrever",
    "circunscritos": "circunscrito",
    "circunscritíveis": "circunscritível",
    "circunscrições": "circunscrição",
    "circunsessões": "circunsessão",
    "circunsona": "circunsonar",
    "circunsonada": "circunsonar",
    "circunsonadas": "circunsonar",
    "circunsonado": "circunsonar",
    "circunsonados": "circunsonar",
    "circunsonai": "circunsonar",
    "circunsonais": "circunsonar",
    "circunsonam": "circunsonar",
    "circunsonamo": "circunsonar",
    "circunsonamos": "circunsonar",
    "circunsonando": "circunsonar",
    "circunsonara": "circunsonar",
    "circunsonaram": "circunsonar",
    "circunsonaras": "circunsonar",
    "circunsonardes": "circunsonar",
    "circunsonarei": "circunsonar",
    "circunsonareis": "circunsonar",
    "circunsonarem": "circunsonar",
    "circunsonaremos": "circunsonar",
    "circunsonares": "circunsonar",
    "circunsonaria": "circunsonar",
    "circunsonariam": "circunsonar",
    "circunsonarias": "circunsonar",
    "circunsonarmo": "circunsonar",
    "circunsonarmos": "circunsonar",
    "circunsonará": "circunsonar",
    "circunsonarás": "circunsonar",
    "circunsonarão": "circunsonar",
    "circunsonaríamos": "circunsonar",
    "circunsonaríeis": "circunsonar",
    "circunsonas": "circunsonar",
    "circunsonasse": "circunsonar",
    "circunsonassem": "circunsonar",
    "circunsonasses": "circunsonar",
    "circunsonaste": "circunsonar",
    "circunsonastes": "circunsonar",
    "circunsonava": "circunsonar",
    "circunsonavam": "circunsonar",
    "circunsonavas": "circunsonar",
    "circunsone": "circunsonar",
    "circunsonei": "circunsonar",
    "circunsoneis": "circunsonar",
    "circunsonem": "circunsonar",
    "circunsonemo": "circunsonar",
    "circunsonemos": "circunsonar",
    "circunsones": "circunsonar",
    "circunsono": "circunsonar",
    "circunsonou": "circunsonar",
    "circunsonámo": "circunsonar",
    "circunsonámos": "circunsonar",
    "circunsonáramo": "circunsonar",
    "circunsonáramos": "circunsonar",
    "circunsonáreis": "circunsonar",
    "circunsonásseis": "circunsonar",
    "circunsonássemos": "circunsonar",
    "circunsonávamo": "circunsonar",
    "circunsonávamos": "circunsonar",
    "circunsonáveis": "circunsonar",
    "circunspecta": "circunspecto",
    "circunspectas": "circunspecto",
    "circunspectos": "circunspecto",
    "circunspecções": "circunspecção",
    "circunsta": "circunstar",
    "circunstada": "circunstar",
    "circunstadas": "circunstar",
    "circunstado": "circunstar",
    "circunstados": "circunstar",
    "circunstai": "circunstar",
    "circunstais": "circunstar",
    "circunstam": "circunstar",
    "circunstamo": "circunstar",
    "circunstamos": "circunstar",
    "circunstanciada": "circunstanciado",
    "circunstanciadas": "circunstanciado",
    "circunstanciados": "circunstanciado",
    "circunstanciais": "circunstancial",
    "circunstando": "circunstar",
    "circunstantes": "circunstante",
    "circunstara": "circunstar",
    "circunstaram": "circunstar",
    "circunstaras": "circunstar",
    "circunstardes": "circunstar",
    "circunstarei": "circunstar",
    "circunstareis": "circunstar",
    "circunstarem": "circunstar",
    "circunstaremos": "circunstar",
    "circunstares": "circunstar",
    "circunstaria": "circunstar",
    "circunstariam": "circunstar",
    "circunstarias": "circunstar",
    "circunstarmo": "circunstar",
    "circunstarmos": "circunstar",
    "circunstará": "circunstar",
    "circunstarás": "circunstar",
    "circunstarão": "circunstar",
    "circunstaríamos": "circunstar",
    "circunstaríeis": "circunstar",
    "circunstas": "circunstar",
    "circunstasse": "circunstar",
    "circunstassem": "circunstar",
    "circunstasses": "circunstar",
    "circunstaste": "circunstar",
    "circunstastes": "circunstar",
    "circunstava": "circunstar",
    "circunstavam": "circunstar",
    "circunstavas": "circunstar",
    "circunste": "circunstar",
    "circunstei": "circunstar",
    "circunsteis": "circunstar",
    "circunstem": "circunstar",
    "circunstemo": "circunstar",
    "circunstemos": "circunstar",
    "circunstes": "circunstar",
    "circunsto": "circunstar",
    "circunstou": "circunstar",
    "circunstámo": "circunstar",
    "circunstámos": "circunstar",
    "circunstáramo": "circunstar",
    "circunstáramos": "circunstar",
    "circunstáreis": "circunstar",
    "circunstásseis": "circunstar",
    "circunstássemos": "circunstar",
    "circunstávamo": "circunstar",
    "circunstávamos": "circunstar",
    "circunstáveis": "circunstar",
    "circunstâncias": "circunstância",
    "circuntorna": "circuntornar",
    "circuntornada": "circuntornar",
    "circuntornadas": "circuntornar",
    "circuntornado": "circuntornar",
    "circuntornados": "circuntornar",
    "circuntornai": "circuntornar",
    "circuntornais": "circuntornar",
    "circuntornam": "circuntornar",
    "circuntornamo": "circuntornar",
    "circuntornamos": "circuntornar",
    "circuntornando": "circuntornar",
    "circuntornara": "circuntornar",
    "circuntornaram": "circuntornar",
    "circuntornaras": "circuntornar",
    "circuntornarde": "circuntornar",
    "circuntornardes": "circuntornar",
    "circuntornare": "circuntornar",
    "circuntornarei": "circuntornar",
    "circuntornareis": "circuntornar",
    "circuntornarem": "circuntornar",
    "circuntornaremos": "circuntornar",
    "circuntornares": "circuntornar",
    "circuntornaria": "circuntornar",
    "circuntornariam": "circuntornar",
    "circuntornarias": "circuntornar",
    "circuntornarmo": "circuntornar",
    "circuntornarmos": "circuntornar",
    "circuntornará": "circuntornar",
    "circuntornarás": "circuntornar",
    "circuntornarão": "circuntornar",
    "circuntornaríamos": "circuntornar",
    "circuntornaríeis": "circuntornar",
    "circuntornas": "circuntornar",
    "circuntornasse": "circuntornar",
    "circuntornassem": "circuntornar",
    "circuntornasses": "circuntornar",
    "circuntornaste": "circuntornar",
    "circuntornastes": "circuntornar",
    "circuntornava": "circuntornar",
    "circuntornavam": "circuntornar",
    "circuntornavas": "circuntornar",
    "circuntorne": "circuntornar",
    "circuntornei": "circuntornar",
    "circuntorneis": "circuntornar",
    "circuntornem": "circuntornar",
    "circuntornemo": "circuntornar",
    "circuntornemos": "circuntornar",
    "circuntornes": "circuntornar",
    "circuntorno": "circuntornar",
    "circuntornou": "circuntornar",
    "circuntorná": "circuntornar",
    "circuntornámo": "circuntornar",
    "circuntornámos": "circuntornar",
    "circuntornáramo": "circuntornar",
    "circuntornáramos": "circuntornar",
    "circuntornárei": "circuntornar",
    "circuntornáreis": "circuntornar",
    "circuntornásseis": "circuntornar",
    "circuntornássemos": "circuntornar",
    "circuntornávamo": "circuntornar",
    "circuntornávamos": "circuntornar",
    "circuntornávei": "circuntornar",
    "circuntornáveis": "circuntornar",
    "circunvagantes": "circunvagante",
    "circunvala": "circunvalar",
    "circunvalada": "circunvalar",
    "circunvaladas": "circunvalar",
    "circunvalado": "circunvalar",
    "circunvalados": "circunvalar",
    "circunvalai": "circunvalar",
    "circunvalais": "circunvalar",
    "circunvalam": "circunvalar",
    "circunvalamo": "circunvalar",
    "circunvalamos": "circunvalar",
    "circunvalando": "circunvalar",
    "circunvalara": "circunvalar",
    "circunvalaram": "circunvalar",
    "circunvalaras": "circunvalar",
    "circunvalarde": "circunvalar",
    "circunvalardes": "circunvalar",
    "circunvalare": "circunvalar",
    "circunvalarei": "circunvalar",
    "circunvalareis": "circunvalar",
    "circunvalarem": "circunvalar",
    "circunvalaremos": "circunvalar",
    "circunvalares": "circunvalar",
    "circunvalaria": "circunvalar",
    "circunvalariam": "circunvalar",
    "circunvalarias": "circunvalar",
    "circunvalarmo": "circunvalar",
    "circunvalarmos": "circunvalar",
    "circunvalará": "circunvalar",
    "circunvalarás": "circunvalar",
    "circunvalarão": "circunvalar",
    "circunvalaríamos": "circunvalar",
    "circunvalaríeis": "circunvalar",
    "circunvalas": "circunvalar",
    "circunvalasse": "circunvalar",
    "circunvalassem": "circunvalar",
    "circunvalasses": "circunvalar",
    "circunvalaste": "circunvalar",
    "circunvalastes": "circunvalar",
    "circunvalava": "circunvalar",
    "circunvalavam": "circunvalar",
    "circunvalavas": "circunvalar",
    "circunvalações": "circunvalação",
    "circunvale": "circunvalar",
    "circunvalei": "circunvalar",
    "circunvaleis": "circunvalar",
    "circunvalem": "circunvalar",
    "circunvalemo": "circunvalar",
    "circunvalemos": "circunvalar",
    "circunvales": "circunvalar",
    "circunvalo": "circunvalar",
    "circunvalou": "circunvalar",
    "circunvalá": "circunvalar",
    "circunvalámo": "circunvalar",
    "circunvalámos": "circunvalar",
    "circunvaláramo": "circunvalar",
    "circunvaláramos": "circunvalar",
    "circunvalárei": "circunvalar",
    "circunvaláreis": "circunvalar",
    "circunvalásseis": "circunvalar",
    "circunvalássemos": "circunvalar",
    "circunvalávamo": "circunvalar",
    "circunvalávamos": "circunvalar",
    "circunvalávei": "circunvalar",
    "circunvaláveis": "circunvalar",
    "circunvede": "circunver",
    "circunvedes": "circunver",
    "circunveja": "circunver",
    "circunvejais": "circunver",
    "circunvejam": "circunver",
    "circunvejamo": "circunver",
    "circunvejamos": "circunver",
    "circunvejas": "circunver",
    "circunvejo": "circunver",
    "circunvemo": "circunver",
    "circunvemos": "circunver",
    "circunvendo": "circunver",
    "circunverde": "circunver",
    "circunverdes": "circunver",
    "circunvere": "circunver",
    "circunverei": "circunver",
    "circunvereis": "circunver",
    "circunverem": "circunver",
    "circunveremos": "circunver",
    "circunveres": "circunver",
    "circunveria": "circunver",
    "circunveriam": "circunver",
    "circunverias": "circunver",
    "circunvermo": "circunver",
    "circunvermos": "circunver",
    "circunverá": "circunver",
    "circunverás": "circunver",
    "circunverão": "circunver",
    "circunveríamos": "circunver",
    "circunveríeis": "circunver",
    "circunvi": "circunver",
    "circunvia": "circunver",
    "circunviam": "circunver",
    "circunvias": "circunver",
    "circunvimo": "circunver",
    "circunvimos": "circunver",
    "circunvir": "circunver",
    "circunvira": "circunver",
    "circunviram": "circunver",
    "circunviras": "circunver",
    "circunvirdes": "circunver",
    "circunvirem": "circunver",
    "circunvires": "circunver",
    "circunvirmos": "circunver",
    "circunvisse": "circunver",
    "circunvissem": "circunver",
    "circunvisses": "circunver",
    "circunvista": "circunver",
    "circunvistas": "circunver",
    "circunviste": "circunver",
    "circunvistes": "circunver",
    "circunvisto": "circunver",
    "circunvistos": "circunver",
    "circunviu": "circunver",
    "circunvizinha": "circunvizinho",
    "circunvizinhanças": "circunvizinhança",
    "circunvizinhas": "circunvizinho",
    "circunvizinhos": "circunvizinho",
    "circunvoa": "circunvoar",
    "circunvoada": "circunvoar",
    "circunvoadas": "circunvoar",
    "circunvoado": "circunvoar",
    "circunvoados": "circunvoar",
    "circunvoai": "circunvoar",
    "circunvoais": "circunvoar",
    "circunvoam": "circunvoar",
    "circunvoamo": "circunvoar",
    "circunvoamos": "circunvoar",
    "circunvoando": "circunvoar",
    "circunvoara": "circunvoar",
    "circunvoaram": "circunvoar",
    "circunvoaras": "circunvoar",
    "circunvoarde": "circunvoar",
    "circunvoardes": "circunvoar",
    "circunvoare": "circunvoar",
    "circunvoarei": "circunvoar",
    "circunvoareis": "circunvoar",
    "circunvoarem": "circunvoar",
    "circunvoaremos": "circunvoar",
    "circunvoares": "circunvoar",
    "circunvoaria": "circunvoar",
    "circunvoariam": "circunvoar",
    "circunvoarias": "circunvoar",
    "circunvoarmo": "circunvoar",
    "circunvoarmos": "circunvoar",
    "circunvoará": "circunvoar",
    "circunvoarás": "circunvoar",
    "circunvoarão": "circunvoar",
    "circunvoaríamos": "circunvoar",
    "circunvoaríeis": "circunvoar",
    "circunvoas": "circunvoar",
    "circunvoasse": "circunvoar",
    "circunvoassem": "circunvoar",
    "circunvoasses": "circunvoar",
    "circunvoaste": "circunvoar",
    "circunvoastes": "circunvoar",
    "circunvoava": "circunvoar",
    "circunvoavam": "circunvoar",
    "circunvoavas": "circunvoar",
    "circunvoe": "circunvoar",
    "circunvoei": "circunvoar",
    "circunvoeis": "circunvoar",
    "circunvoem": "circunvoar",
    "circunvoemo": "circunvoar",
    "circunvoemos": "circunvoar",
    "circunvoes": "circunvoar",
    "circunvolucionária": "circunvolucionário",
    "circunvolucionárias": "circunvolucionário",
    "circunvolucionários": "circunvolucionário",
    "circunvoluções": "circunvolução",
    "circunvolva": "circunvolver",
    "circunvolvais": "circunvolver",
    "circunvolvam": "circunvolver",
    "circunvolvamo": "circunvolver",
    "circunvolvamos": "circunvolver",
    "circunvolvas": "circunvolver",
    "circunvolve": "circunvolver",
    "circunvolvei": "circunvolver",
    "circunvolveis": "circunvolver",
    "circunvolvem": "circunvolver",
    "circunvolvemo": "circunvolver",
    "circunvolvemos": "circunvolver",
    "circunvolvendo": "circunvolver",
    "circunvolvera": "circunvolver",
    "circunvolveram": "circunvolver",
    "circunvolveras": "circunvolver",
    "circunvolverde": "circunvolver",
    "circunvolverdes": "circunvolver",
    "circunvolvere": "circunvolver",
    "circunvolverei": "circunvolver",
    "circunvolvereis": "circunvolver",
    "circunvolverem": "circunvolver",
    "circunvolveremos": "circunvolver",
    "circunvolveres": "circunvolver",
    "circunvolveria": "circunvolver",
    "circunvolveriam": "circunvolver",
    "circunvolverias": "circunvolver",
    "circunvolvermo": "circunvolver",
    "circunvolvermos": "circunvolver",
    "circunvolverá": "circunvolver",
    "circunvolverás": "circunvolver",
    "circunvolverão": "circunvolver",
    "circunvolveríamos": "circunvolver",
    "circunvolveríeis": "circunvolver",
    "circunvolves": "circunvolver",
    "circunvolvesse": "circunvolver",
    "circunvolvessem": "circunvolver",
    "circunvolvesses": "circunvolver",
    "circunvolveste": "circunvolver",
    "circunvolvestes": "circunvolver",
    "circunvolveu": "circunvolver",
    "circunvolvi": "circunvolver",
    "circunvolvia": "circunvolver",
    "circunvolviam": "circunvolver",
    "circunvolvias": "circunvolver",
    "circunvolvida": "circunvolver",
    "circunvolvidas": "circunvolver",
    "circunvolvido": "circunvolver",
    "circunvolvidos": "circunvolver",
    "circunvolvo": "circunvolver",
    "circunvolvê": "circunvolver",
    "circunvolvêramo": "circunvolver",
    "circunvolvêramos": "circunvolver",
    "circunvolvêrei": "circunvolver",
    "circunvolvêreis": "circunvolver",
    "circunvolvêsseis": "circunvolver",
    "circunvolvêssemos": "circunvolver",
    "circunvolvíamo": "circunvolver",
    "circunvolvíamos": "circunvolver",
    "circunvolvíei": "circunvolver",
    "circunvolvíeis": "circunvolver",
    "circunvoo": "circunvoar",
    "circunvoou": "circunvoar",
    "circunvoá": "circunvoar",
    "circunvoámo": "circunvoar",
    "circunvoámos": "circunvoar",
    "circunvoáramo": "circunvoar",
    "circunvoáramos": "circunvoar",
    "circunvoárei": "circunvoar",
    "circunvoáreis": "circunvoar",
    "circunvoásseis": "circunvoar",
    "circunvoássemos": "circunvoar",
    "circunvoávamo": "circunvoar",
    "circunvoávamos": "circunvoar",
    "circunvoávei": "circunvoar",
    "circunvoáveis": "circunvoar",
    "circunvê": "circunver",
    "circunvêem": "circunver",
    "circunvês": "circunver",
    "circunvíamo": "circunver",
    "circunvíamos": "circunver",
    "circunvíei": "circunver",
    "circunvíeis": "circunver",
    "circunvíramo": "circunver",
    "circunvíramos": "circunver",
    "circunvírei": "circunver",
    "circunvíreis": "circunver",
    "circunvísseis": "circunver",
    "circunvíssemos": "circunver",
    "cirenaica": "cirenaico",
    "cirenaicas": "cirenaico",
    "cirenaicos": "cirenaico",
    "cireneia": "cireneu",
    "cireneias": "cireneu",
    "cireneus": "cireneu",
    "cireneísmos": "cireneísmo",
    "ciriais": "cirial",
    "cirieiros": "cirieiro",
    "ciriologias": "ciriologia",
    "ciriológica": "ciriológico",
    "ciriológicas": "ciriológico",
    "ciriológicos": "ciriológico",
    "cirióloga": "ciriólogo",
    "ciriólogas": "ciriólogo",
    "ciriólogos": "ciriólogo",
    "cirna": "cernir",
    "cirnais": "cernir",
    "cirnam": "cernir",
    "cirnamo": "cernir",
    "cirnamos": "cernir",
    "cirnas": "cernir",
    "cirno": "cernir",
    "cirpos": "cirpo",
    "cirros": "cirro",
    "cirrosa": "cirroso",
    "cirrosas": "cirroso",
    "cirroses": "cirrose",
    "cirrosidades": "cirrosidade",
    "cirrosos": "cirroso",
    "cirrípedes": "cirrípede",
    "cirrósica": "cirrósico",
    "cirrósicas": "cirrósico",
    "cirrósicos": "cirrósico",
    "cirsotomias": "cirsotomia",
    "cirsotómica": "cirsotómico",
    "cirsotómicas": "cirsotómico",
    "cirsotómicos": "cirsotómico",
    "cirtometrias": "cirtometria",
    "cirtométrica": "cirtométrico",
    "cirtométricas": "cirtométrico",
    "cirtométricos": "cirtométrico",
    "cirurgias": "cirurgia",
    "cirurgiã": "cirurgião",
    "cirurgiãos": "cirurgião",
    "cirurgiãs": "cirurgião",
    "cirurgiões": "cirurgião",
    "cirza": "cerzir",
    "cirzais": "cerzir",
    "cirzam": "cerzir",
    "cirzamo": "cerzir",
    "cirzamos": "cerzir",
    "cirzas": "cerzir",
    "cirze": "cerzir",
    "cirzem": "cerzir",
    "cirzes": "cerzir",
    "cirzo": "cerzir",
    "cirílica": "cirílico",
    "cirílicas": "cirílico",
    "cirílicos": "cirílico",
    "cirúrgica": "cirúrgico",
    "cirúrgicas": "cirúrgico",
    "cirúrgicos": "cirúrgico",
    "cisalha": "cisalhar",
    "cisalhada": "cisalhar",
    "cisalhadas": "cisalhar",
    "cisalhado": "cisalhar",
    "cisalhados": "cisalhar",
    "cisalhai": "cisalhar",
    "cisalhais": "cisalhar",
    "cisalham": "cisalhar",
    "cisalhamentos": "cisalhamento",
    "cisalhamo": "cisalhar",
    "cisalhamos": "cisalhar",
    "cisalhando": "cisalhar",
    "cisalhara": "cisalhar",
    "cisalharam": "cisalhar",
    "cisalharas": "cisalhar",
    "cisalharde": "cisalhar",
    "cisalhardes": "cisalhar",
    "cisalhare": "cisalhar",
    "cisalharei": "cisalhar",
    "cisalhareis": "cisalhar",
    "cisalharem": "cisalhar",
    "cisalharemos": "cisalhar",
    "cisalhares": "cisalhar",
    "cisalharia": "cisalhar",
    "cisalhariam": "cisalhar",
    "cisalharias": "cisalhar",
    "cisalharmo": "cisalhar",
    "cisalharmos": "cisalhar",
    "cisalhará": "cisalhar",
    "cisalharás": "cisalhar",
    "cisalharão": "cisalhar",
    "cisalharíamos": "cisalhar",
    "cisalharíeis": "cisalhar",
    "cisalhas": "cisalhar",
    "cisalhasse": "cisalhar",
    "cisalhassem": "cisalhar",
    "cisalhasses": "cisalhar",
    "cisalhaste": "cisalhar",
    "cisalhastes": "cisalhar",
    "cisalhava": "cisalhar",
    "cisalhavam": "cisalhar",
    "cisalhavas": "cisalhar",
    "cisalhe": "cisalhar",
    "cisalhei": "cisalhar",
    "cisalheis": "cisalhar",
    "cisalhem": "cisalhar",
    "cisalhemo": "cisalhar",
    "cisalhemos": "cisalhar",
    "cisalhes": "cisalhar",
    "cisalho": "cisalhar",
    "cisalhou": "cisalhar",
    "cisalhá": "cisalhar",
    "cisalhámo": "cisalhar",
    "cisalhámos": "cisalhar",
    "cisalháramo": "cisalhar",
    "cisalháramos": "cisalhar",
    "cisalhárei": "cisalhar",
    "cisalháreis": "cisalhar",
    "cisalhásseis": "cisalhar",
    "cisalhássemos": "cisalhar",
    "cisalhávamo": "cisalhar",
    "cisalhávamos": "cisalhar",
    "cisalhávei": "cisalhar",
    "cisalháveis": "cisalhar",
    "cisalpina": "cisalpino",
    "cisalpinas": "cisalpino",
    "cisalpinos": "cisalpino",
    "cisatlaântica": "cisatlaântico",
    "cisatlaânticas": "cisatlaântico",
    "cisatlaânticos": "cisatlaântico",
    "cisbordos": "cisbordo",
    "cisca": "ciscar",
    "ciscada": "ciscar",
    "ciscadas": "ciscar",
    "ciscado": "ciscar",
    "ciscadores": "ciscador",
    "ciscados": "ciscar",
    "ciscai": "ciscar",
    "ciscais": "ciscar",
    "ciscalhagens": "ciscalhagem",
    "ciscalhos": "ciscalho",
    "ciscam": "ciscar",
    "ciscamo": "ciscar",
    "ciscamos": "ciscar",
    "ciscando": "ciscar",
    "ciscara": "ciscar",
    "ciscaram": "ciscar",
    "ciscaras": "ciscar",
    "ciscarde": "ciscar",
    "ciscardes": "ciscar",
    "ciscare": "ciscar",
    "ciscarei": "ciscar",
    "ciscareis": "ciscar",
    "ciscarem": "ciscar",
    "ciscaremos": "ciscar",
    "ciscares": "ciscar",
    "ciscaria": "ciscar",
    "ciscariam": "ciscar",
    "ciscarias": "ciscar",
    "ciscarmo": "ciscar",
    "ciscarmos": "ciscar",
    "ciscará": "ciscar",
    "ciscarás": "ciscar",
    "ciscarão": "ciscar",
    "ciscaríamos": "ciscar",
    "ciscaríeis": "ciscar",
    "ciscas": "ciscar",
    "ciscasse": "ciscar",
    "ciscassem": "ciscar",
    "ciscasses": "ciscar",
    "ciscaste": "ciscar",
    "ciscastes": "ciscar",
    "ciscava": "ciscar",
    "ciscavam": "ciscar",
    "ciscavas": "ciscar",
    "cisco": "ciscar",
    "ciscos": "cisco",
    "ciscou": "ciscar",
    "ciscá": "ciscar",
    "ciscámo": "ciscar",
    "ciscámos": "ciscar",
    "ciscáramo": "ciscar",
    "ciscáramos": "ciscar",
    "ciscárei": "ciscar",
    "ciscáreis": "ciscar",
    "ciscásseis": "ciscar",
    "ciscássemos": "ciscar",
    "ciscávamo": "ciscar",
    "ciscávamos": "ciscar",
    "ciscávei": "ciscar",
    "ciscáveis": "ciscar",
    "cisdanubiana": "cisdanubiano",
    "cisdanubianas": "cisdanubiano",
    "cisdanubianos": "cisdanubiano",
    "ciseis": "cisel",
    "cisgangética": "cisgangético",
    "cisgangéticas": "cisgangético",
    "cisgangéticos": "cisgangético",
    "cisjurana": "cisjurano",
    "cisjuranas": "cisjurano",
    "cisjuranos": "cisjurano",
    "cisma": "cismar",
    "cismada": "cismar",
    "cismadas": "cismar",
    "cismado": "cismar",
    "cismadora": "cismador",
    "cismadoras": "cismador",
    "cismadores": "cismador",
    "cismados": "cismar",
    "cismai": "cismar",
    "cismais": "cismar",
    "cismam": "cismar",
    "cismamo": "cismar",
    "cismamos": "cismar",
    "cismando": "cismar",
    "cismara": "cismar",
    "cismaram": "cismar",
    "cismaras": "cismar",
    "cismarde": "cismar",
    "cismardes": "cismar",
    "cismare": "cismar",
    "cismarei": "cismar",
    "cismareis": "cismar",
    "cismarem": "cismar",
    "cismaremos": "cismar",
    "cismares": "cismar",
    "cismaria": "cismar",
    "cismariam": "cismar",
    "cismarias": "cismar",
    "cismarmo": "cismar",
    "cismarmos": "cismar",
    "cismará": "cismar",
    "cismarás": "cismar",
    "cismarão": "cismar",
    "cismaríamos": "cismar",
    "cismaríeis": "cismar",
    "cismas": "cismar",
    "cismasse": "cismar",
    "cismassem": "cismar",
    "cismasses": "cismar",
    "cismaste": "cismar",
    "cismastes": "cismar",
    "cismava": "cismar",
    "cismavam": "cismar",
    "cismavas": "cismar",
    "cisme": "cismar",
    "cismei": "cismar",
    "cismeis": "cismar",
    "cismem": "cismar",
    "cismemo": "cismar",
    "cismemos": "cismar",
    "cismes": "cismar",
    "cismo": "cismar",
    "cismontana": "cismontano",
    "cismontanas": "cismontano",
    "cismontanos": "cismontano",
    "cismou": "cismar",
    "cismá": "cismar",
    "cismámo": "cismar",
    "cismámos": "cismar",
    "cismáramo": "cismar",
    "cismáramos": "cismar",
    "cismárei": "cismar",
    "cismáreis": "cismar",
    "cismásseis": "cismar",
    "cismássemos": "cismar",
    "cismática": "cismático",
    "cismáticas": "cismático",
    "cismáticos": "cismático",
    "cismávamo": "cismar",
    "cismávamos": "cismar",
    "cismávei": "cismar",
    "cismáveis": "cismar",
    "cisnes": "cisne",
    "cispadana": "cispadano",
    "cispadanas": "cispadano",
    "cispadanos": "cispadano",
    "cisque": "ciscar",
    "cisquei": "ciscar",
    "cisqueiros": "cisqueiro",
    "cisqueis": "ciscar",
    "cisquem": "ciscar",
    "cisquemo": "ciscar",
    "cisquemos": "ciscar",
    "cisques": "ciscar",
    "cisrenana": "cisrenano",
    "cisrenanas": "cisrenano",
    "cisrenanos": "cisrenano",
    "cissiparidades": "cissiparidade",
    "cissuras": "cissura",
    "cissípara": "cissíparo",
    "cissíparas": "cissíparo",
    "cissíparos": "cissíparo",
    "cissões": "cissão",
    "cistagana": "cistagano",
    "cistaganas": "cistagano",
    "cistaganos": "cistagano",
    "cistalgias": "cistalgia",
    "cistas": "cista",
    "cistectomias": "cistectomia",
    "cistectómica": "cistectómico",
    "cistectómicas": "cistectómico",
    "cistectómicos": "cistectómico",
    "cistercienses": "cisterciense",
    "cisternas": "cisterna",
    "cisticercos": "cisticerco",
    "cisticercoses": "cisticercose",
    "cisticercóides": "cisticercóide",
    "cisticercósica": "cisticercósico",
    "cisticercósicas": "cisticercósico",
    "cisticercósicos": "cisticercósico",
    "cisticotomias": "cisticotomia",
    "cisticotómica": "cisticotómico",
    "cisticotómicas": "cisticotómico",
    "cisticotómicos": "cisticotómico",
    "cistinas": "cistina",
    "cistites": "cistite",
    "cistocarpos": "cistocarpo",
    "cistocárpica": "cistocárpico",
    "cistocárpicas": "cistocárpico",
    "cistocárpicos": "cistocárpico",
    "cistos": "cisto",
    "cistoscópias": "cistoscópia",
    "cistoscópica": "cistoscópico",
    "cistoscópicas": "cistoscópico",
    "cistoscópicos": "cistoscópico",
    "cistoscópios": "cistoscópio",
    "cistotomias": "cistotomia",
    "cistotómica": "cistotómico",
    "cistotómicas": "cistotómico",
    "cistotómicos": "cistotómico",
    "cistácea": "cistáceo",
    "cistáceas": "cistáceo",
    "cistáceos": "cistáceo",
    "cistálgica": "cistálgico",
    "cistálgicas": "cistálgico",
    "cistálgicos": "cistálgico",
    "cistínea": "cistíneo",
    "cistíneas": "cistíneo",
    "cistíneos": "cistíneo",
    "cistóides": "cistóide",
    "cistólitos": "cistólito",
    "cistótoma": "cistótomo",
    "cistótomas": "cistótomo",
    "cistótomos": "cistótomo",
    "cisões": "cisão",
    "cita": "citar",
    "citada": "citar",
    "citadas": "citar",
    "citadina": "citadino",
    "citadinas": "citadino",
    "citadinos": "citadino",
    "citado": "citar",
    "citadora": "citador",
    "citadoras": "citador",
    "citadores": "citador",
    "citados": "citar",
    "citai": "citar",
    "citais": "citar",
    "citam": "citar",
    "citamo": "citar",
    "citamos": "citar",
    "citando": "citar",
    "citantes": "citante",
    "citara": "citar",
    "citaram": "citar",
    "citaras": "citara",
    "citarde": "citar",
    "citardes": "citar",
    "citare": "citar",
    "citaredos": "citaredo",
    "citarei": "citar",
    "citareis": "citar",
    "citarem": "citar",
    "citaremos": "citar",
    "citares": "citar",
    "citaria": "citar",
    "citariam": "citar",
    "citarias": "citar",
    "citaristas": "citarista",
    "citarmo": "citar",
    "citarmos": "citar",
    "citará": "citar",
    "citarás": "citar",
    "citarão": "citar",
    "citaríamos": "citar",
    "citaríeis": "citar",
    "citas": "citar",
    "citasse": "citar",
    "citassem": "citar",
    "citasses": "citar",
    "citaste": "citar",
    "citastes": "citar",
    "citatória": "citatório",
    "citatórias": "citatório",
    "citatórios": "citatório",
    "citava": "citar",
    "citavam": "citar",
    "citavas": "citar",
    "citações": "citação",
    "cite": "citar",
    "citei": "citar",
    "citeis": "citar",
    "citem": "citar",
    "citemo": "citar",
    "citemos": "citar",
    "citeriores": "citerior",
    "cites": "cite",
    "citinácea": "citináceo",
    "citináceas": "citináceo",
    "citináceos": "citináceo",
    "cito": "citar",
    "citocineses": "citocinese",
    "citocinésica": "citocinésico",
    "citocinésicas": "citocinésico",
    "citocinésicos": "citocinésico",
    "citodiagnósticos": "citodiagnóstico",
    "citofaringes": "citofaringe",
    "citofaríngica": "citofaríngico",
    "citofaríngicas": "citofaríngico",
    "citofaríngicos": "citofaríngico",
    "citogenias": "citogenia",
    "citogenética": "citogenético",
    "citogenéticas": "citogenético",
    "citogenéticos": "citogenético",
    "citogéneses": "citogénese",
    "citogénica": "citogénico",
    "citogénicas": "citogénico",
    "citogénicos": "citogénico",
    "citologias": "citologia",
    "citologistas": "citologista",
    "citológica": "citológico",
    "citológicas": "citológico",
    "citológicos": "citológico",
    "citoplasmas": "citoplasma",
    "citoplasmática": "citoplasmático",
    "citoplasmáticas": "citoplasmático",
    "citoplasmáticos": "citoplasmático",
    "citostómica": "citostómico",
    "citostómicas": "citostómico",
    "citostómicos": "citostómico",
    "citotes": "citote",
    "citou": "citar",
    "citrarias": "citraria",
    "citratos": "citrato",
    "citreira": "citreiro",
    "citreiras": "citreiro",
    "citreiros": "citreiro",
    "citricultora": "citricultor",
    "citricultoras": "citricultor",
    "citricultores": "citricultor",
    "citriculturas": "citricultura",
    "citrina": "citrino",
    "citrinas": "citrino",
    "citrinos": "citrino",
    "citronelas": "citronela",
    "citros": "citro",
    "citrácea": "citráceo",
    "citráceas": "citráceo",
    "citráceos": "citráceo",
    "citá": "citar",
    "citámo": "citar",
    "citámos": "citar",
    "citáramo": "citar",
    "citáramos": "citar",
    "citárei": "citar",
    "citáreis": "citar",
    "citásseis": "citar",
    "citássemos": "citar",
    "citávamo": "citar",
    "citávamos": "citar",
    "citávei": "citar",
    "citáveis": "citável",
    "citânias": "citânia",
    "citéria": "citério",
    "citérias": "citério",
    "citérios": "citério",
    "citóides": "citóide",
    "citóloga": "citólogo",
    "citólogas": "citólogo",
    "citólogos": "citólogo",
    "citóstomas": "citóstoma",
    "ciuma": "ciumar",
    "ciumada": "ciumar",
    "ciumadas": "ciumar",
    "ciumado": "ciumar",
    "ciumados": "ciumar",
    "ciumai": "ciumar",
    "ciumais": "ciumar",
    "ciumam": "ciumar",
    "ciumamo": "ciumar",
    "ciumamos": "ciumar",
    "ciumando": "ciumar",
    "ciumara": "ciumar",
    "ciumaram": "ciumar",
    "ciumaras": "ciumar",
    "ciumardes": "ciumar",
    "ciumarei": "ciumar",
    "ciumareis": "ciumar",
    "ciumarem": "ciumar",
    "ciumaremos": "ciumar",
    "ciumares": "ciumar",
    "ciumaria": "ciumar",
    "ciumariam": "ciumar",
    "ciumarias": "ciumaria",
    "ciumarmo": "ciumar",
    "ciumarmos": "ciumar",
    "ciumará": "ciumar",
    "ciumarás": "ciumar",
    "ciumarão": "ciumar",
    "ciumaríamos": "ciumar",
    "ciumaríeis": "ciumar",
    "ciumas": "ciumar",
    "ciumasse": "ciumar",
    "ciumassem": "ciumar",
    "ciumasses": "ciumar",
    "ciumaste": "ciumar",
    "ciumastes": "ciumar",
    "ciumava": "ciumar",
    "ciumavam": "ciumar",
    "ciumavas": "ciumar",
    "ciume": "ciumar",
    "ciumei": "ciumar",
    "ciumeiras": "ciumeira",
    "ciumeis": "ciumar",
    "ciumem": "ciumar",
    "ciumemo": "ciumar",
    "ciumemos": "ciumar",
    "ciumenta": "ciumento",
    "ciumentas": "ciumento",
    "ciumentos": "ciumento",
    "ciumes": "ciumar",
    "ciumo": "ciumar",
    "ciumou": "ciumar",
    "ciumámo": "ciumar",
    "ciumámos": "ciumar",
    "ciumáramo": "ciumar",
    "ciumáramos": "ciumar",
    "ciumáreis": "ciumar",
    "ciumásseis": "ciumar",
    "ciumássemos": "ciumar",
    "ciumávamo": "ciumar",
    "ciumávamos": "ciumar",
    "ciumáveis": "ciumar",
    "civetas": "civeta",
    "cividades": "cividade",
    "civilidades": "civilidade",
    "civilismos": "civilismo",
    "civilistas": "civilista",
    "civiliza": "civilizar",
    "civilizacionais": "civilizacional",
    "civilizada": "civilizar",
    "civilizadas": "civilizar",
    "civilizado": "civilizar",
    "civilizadora": "civilizador",
    "civilizadoras": "civilizador",
    "civilizadores": "civilizador",
    "civilizados": "civilizar",
    "civilizai": "civilizar",
    "civilizais": "civilizar",
    "civilizam": "civilizar",
    "civilizamo": "civilizar",
    "civilizamos": "civilizar",
    "civilizando": "civilizar",
    "civilizara": "civilizar",
    "civilizaram": "civilizar",
    "civilizaras": "civilizar",
    "civilizarde": "civilizar",
    "civilizardes": "civilizar",
    "civilizare": "civilizar",
    "civilizarei": "civilizar",
    "civilizareis": "civilizar",
    "civilizarem": "civilizar",
    "civilizaremos": "civilizar",
    "civilizares": "civilizar",
    "civilizaria": "civilizar",
    "civilizariam": "civilizar",
    "civilizarias": "civilizar",
    "civilizarmo": "civilizar",
    "civilizarmos": "civilizar",
    "civilizará": "civilizar",
    "civilizarás": "civilizar",
    "civilizarão": "civilizar",
    "civilizaríamos": "civilizar",
    "civilizaríeis": "civilizar",
    "civilizas": "civilizar",
    "civilizasse": "civilizar",
    "civilizassem": "civilizar",
    "civilizasses": "civilizar",
    "civilizaste": "civilizar",
    "civilizastes": "civilizar",
    "civilizava": "civilizar",
    "civilizavam": "civilizar",
    "civilizavas": "civilizar",
    "civilizações": "civilização",
    "civilize": "civilizar",
    "civilizei": "civilizar",
    "civilizeis": "civilizar",
    "civilizem": "civilizar",
    "civilizemo": "civilizar",
    "civilizemos": "civilizar",
    "civilizes": "civilizar",
    "civilizo": "civilizar",
    "civilizou": "civilizar",
    "civilizá": "civilizar",
    "civilizámo": "civilizar",
    "civilizámos": "civilizar",
    "civilizáramo": "civilizar",
    "civilizáramos": "civilizar",
    "civilizárei": "civilizar",
    "civilizáreis": "civilizar",
    "civilizásseis": "civilizar",
    "civilizássemos": "civilizar",
    "civilizávamo": "civilizar",
    "civilizávamos": "civilizar",
    "civilizávei": "civilizar",
    "civilizáveis": "civilizável",
    "civis": "civil",
    "civismos": "civismo",
    "cizirões": "cizirão",
    "cizânias": "cizânia",
    "ciámo": "ciar",
    "ciámos": "ciar",
    "ciáramo": "ciar",
    "ciáramos": "ciar",
    "ciáreis": "ciar",
    "ciásseis": "ciar",
    "ciássemos": "ciar",
    "ciática": "ciático",
    "ciáticas": "ciático",
    "ciáticos": "ciático",
    "ciávamo": "ciar",
    "ciávamos": "ciar",
    "ciáveis": "ciar",
    "ciânica": "ciânico",
    "ciânicas": "ciânico",
    "ciânicos": "ciânico",
    "ciências": "ciência",
    "cióptica": "cióptico",
    "ciópticas": "cióptico",
    "ciópticos": "cióptico",
    "ciões": "cião",
    "ciúmes": "ciúme",
    "cladódios": "cladódio",
    "clama": "clamar",
    "clamada": "clamar",
    "clamadas": "clamar",
    "clamado": "clamar",
    "clamadora": "clamador",
    "clamadoras": "clamador",
    "clamadores": "clamador",
    "clamados": "clamar",
    "clamai": "clamar",
    "clamais": "clamar",
    "clamam": "clamar",
    "clamamo": "clamar",
    "clamamos": "clamar",
    "clamando": "clamar",
    "clamantes": "clamante",
    "clamara": "clamar",
    "clamaram": "clamar",
    "clamaras": "clamar",
    "clamardes": "clamar",
    "clamarei": "clamar",
    "clamareis": "clamar",
    "clamarem": "clamar",
    "clamaremos": "clamar",
    "clamares": "clamar",
    "clamaria": "clamar",
    "clamariam": "clamar",
    "clamarias": "clamar",
    "clamarmo": "clamar",
    "clamarmos": "clamar",
    "clamará": "clamar",
    "clamarás": "clamar",
    "clamarão": "clamar",
    "clamaríamos": "clamar",
    "clamaríeis": "clamar",
    "clamas": "clamar",
    "clamasse": "clamar",
    "clamassem": "clamar",
    "clamasses": "clamar",
    "clamaste": "clamar",
    "clamastes": "clamar",
    "clamava": "clamar",
    "clamavam": "clamar",
    "clamavas": "clamar",
    "clamações": "clamação",
    "clame": "clamar",
    "clamei": "clamar",
    "clameis": "clamar",
    "clamem": "clamar",
    "clamemo": "clamar",
    "clamemos": "clamar",
    "clames": "clamar",
    "clamidomonas": "clamidomona",
    "claminomónades": "claminomónade",
    "clamitosa": "clamitoso",
    "clamitosas": "clamitoso",
    "clamitosos": "clamitoso",
    "clamo": "clamar",
    "clamores": "clamor",
    "clamorosa": "clamoroso",
    "clamorosas": "clamoroso",
    "clamorosos": "clamoroso",
    "clamou": "clamar",
    "clamámo": "clamar",
    "clamámos": "clamar",
    "clamáramo": "clamar",
    "clamáramos": "clamar",
    "clamáreis": "clamar",
    "clamásseis": "clamar",
    "clamássemos": "clamar",
    "clamávamo": "clamar",
    "clamávamos": "clamar",
    "clamáveis": "clamável",
    "clandestina": "clandestino",
    "clandestinas": "clandestino",
    "clandestinidades": "clandestinidade",
    "clandestinos": "clandestino",
    "clangores": "clangor",
    "clangorosa": "clangoroso",
    "clangorosas": "clangoroso",
    "clangorosos": "clangoroso",
    "clanguistas": "clanguista",
    "claques": "claque",
    "claquetes": "claquete",
    "claquistas": "claquista",
    "clara": "claro",
    "clarabelas": "clarabela",
    "clarabóias": "clarabóia",
    "claras": "claro",
    "claravalenses": "claravalense",
    "clareada": "clarear",
    "clareadas": "clarear",
    "clareado": "clarear",
    "clareados": "clarear",
    "clareai": "clarear",
    "clareais": "clarear",
    "clareamo": "clarear",
    "clareamos": "clarear",
    "clareando": "clarear",
    "clareara": "clarear",
    "clarearam": "clarear",
    "clarearas": "clarear",
    "clarearde": "clarear",
    "clareardes": "clarear",
    "clareare": "clarear",
    "clarearei": "clarear",
    "clareareis": "clarear",
    "clarearem": "clarear",
    "clarearemos": "clarear",
    "clareares": "clarear",
    "clarearia": "clarear",
    "clareariam": "clarear",
    "clarearias": "clarear",
    "clarearmo": "clarear",
    "clarearmos": "clarear",
    "clareará": "clarear",
    "clarearás": "clarear",
    "clarearão": "clarear",
    "clarearíamos": "clarear",
    "clarearíeis": "clarear",
    "clareasse": "clarear",
    "clareassem": "clarear",
    "clareasses": "clarear",
    "clareaste": "clarear",
    "clareastes": "clarear",
    "clareava": "clarear",
    "clareavam": "clarear",
    "clareavas": "clarear",
    "clareações": "clareação",
    "clareei": "clarear",
    "clareeis": "clarear",
    "clareemo": "clarear",
    "clareemos": "clarear",
    "clareia": "clarear",
    "clareiam": "clarear",
    "clareias": "clarear",
    "clareie": "clarear",
    "clareiem": "clarear",
    "clareies": "clarear",
    "clareio": "clarear",
    "clareiras": "clareira",
    "clareja": "clarejar",
    "clarejada": "clarejar",
    "clarejadas": "clarejar",
    "clarejado": "clarejar",
    "clarejados": "clarejar",
    "clarejai": "clarejar",
    "clarejais": "clarejar",
    "clarejam": "clarejar",
    "clarejamo": "clarejar",
    "clarejamos": "clarejar",
    "clarejando": "clarejar",
    "clarejara": "clarejar",
    "clarejaram": "clarejar",
    "clarejaras": "clarejar",
    "clarejarde": "clarejar",
    "clarejardes": "clarejar",
    "clarejare": "clarejar",
    "clarejarei": "clarejar",
    "clarejareis": "clarejar",
    "clarejarem": "clarejar",
    "clarejaremos": "clarejar",
    "clarejares": "clarejar",
    "clarejaria": "clarejar",
    "clarejariam": "clarejar",
    "clarejarias": "clarejar",
    "clarejarmo": "clarejar",
    "clarejarmos": "clarejar",
    "clarejará": "clarejar",
    "clarejarás": "clarejar",
    "clarejarão": "clarejar",
    "clarejaríamos": "clarejar",
    "clarejaríeis": "clarejar",
    "clarejas": "clarejar",
    "clarejasse": "clarejar",
    "clarejassem": "clarejar",
    "clarejasses": "clarejar",
    "clarejaste": "clarejar",
    "clarejastes": "clarejar",
    "clarejava": "clarejar",
    "clarejavam": "clarejar",
    "clarejavas": "clarejar",
    "clareje": "clarejar",
    "clarejei": "clarejar",
    "clarejeis": "clarejar",
    "clarejem": "clarejar",
    "clarejemo": "clarejar",
    "clarejemos": "clarejar",
    "clarejes": "clarejar",
    "clarejo": "clarejar",
    "clarejou": "clarejar",
    "clarejá": "clarejar",
    "clarejámo": "clarejar",
    "clarejámos": "clarejar",
    "clarejáramo": "clarejar",
    "clarejáramos": "clarejar",
    "clarejárei": "clarejar",
    "clarejáreis": "clarejar",
    "clarejásseis": "clarejar",
    "clarejássemos": "clarejar",
    "clarejávamo": "clarejar",
    "clarejávamos": "clarejar",
    "clarejávei": "clarejar",
    "clarejáveis": "clarejar",
    "clareou": "clarear",
    "claretes": "clarete",
    "clarezas": "clareza",
    "clareá": "clarear",
    "clareámo": "clarear",
    "clareámos": "clarear",
    "clareáramo": "clarear",
    "clareáramos": "clarear",
    "clareárei": "clarear",
    "clareáreis": "clarear",
    "clareásseis": "clarear",
    "clareássemos": "clarear",
    "clareávamo": "clarear",
    "clareávamos": "clarear",
    "clareávei": "clarear",
    "clareáveis": "clarear",
    "claridades": "claridade",
    "clarifica": "clarificar",
    "clarificada": "clarificar",
    "clarificadas": "clarificar",
    "clarificado": "clarificar",
    "clarificadora": "clarificador",
    "clarificadoras": "clarificador",
    "clarificadores": "clarificador",
    "clarificados": "clarificar",
    "clarificai": "clarificar",
    "clarificais": "clarificar",
    "clarificam": "clarificar",
    "clarificamo": "clarificar",
    "clarificamos": "clarificar",
    "clarificando": "clarificar",
    "clarificara": "clarificar",
    "clarificaram": "clarificar",
    "clarificaras": "clarificar",
    "clarificarde": "clarificar",
    "clarificardes": "clarificar",
    "clarificare": "clarificar",
    "clarificarei": "clarificar",
    "clarificareis": "clarificar",
    "clarificarem": "clarificar",
    "clarificaremos": "clarificar",
    "clarificares": "clarificar",
    "clarificaria": "clarificar",
    "clarificariam": "clarificar",
    "clarificarias": "clarificar",
    "clarificarmo": "clarificar",
    "clarificarmos": "clarificar",
    "clarificará": "clarificar",
    "clarificarás": "clarificar",
    "clarificarão": "clarificar",
    "clarificaríamos": "clarificar",
    "clarificaríeis": "clarificar",
    "clarificas": "clarificar",
    "clarificasse": "clarificar",
    "clarificassem": "clarificar",
    "clarificasses": "clarificar",
    "clarificaste": "clarificar",
    "clarificastes": "clarificar",
    "clarificativa": "clarificativo",
    "clarificativas": "clarificativo",
    "clarificativos": "clarificativo",
    "clarificava": "clarificar",
    "clarificavam": "clarificar",
    "clarificavas": "clarificar",
    "clarificações": "clarificação",
    "clarifico": "clarificar",
    "clarificou": "clarificar",
    "clarificá": "clarificar",
    "clarificámo": "clarificar",
    "clarificámos": "clarificar",
    "clarificáramo": "clarificar",
    "clarificáramos": "clarificar",
    "clarificárei": "clarificar",
    "clarificáreis": "clarificar",
    "clarificásseis": "clarificar",
    "clarificássemos": "clarificar",
    "clarificávamo": "clarificar",
    "clarificávamos": "clarificar",
    "clarificávei": "clarificar",
    "clarificáveis": "clarificável",
    "clarifique": "clarificar",
    "clarifiquei": "clarificar",
    "clarifiqueis": "clarificar",
    "clarifiquem": "clarificar",
    "clarifiquemo": "clarificar",
    "clarifiquemos": "clarificar",
    "clarifiques": "clarificar",
    "clarimostra": "clarimostrar",
    "clarimostrada": "clarimostrar",
    "clarimostradas": "clarimostrar",
    "clarimostrado": "clarimostrar",
    "clarimostrados": "clarimostrar",
    "clarimostrai": "clarimostrar",
    "clarimostrais": "clarimostrar",
    "clarimostram": "clarimostrar",
    "clarimostramo": "clarimostrar",
    "clarimostramos": "clarimostrar",
    "clarimostrando": "clarimostrar",
    "clarimostrara": "clarimostrar",
    "clarimostraram": "clarimostrar",
    "clarimostraras": "clarimostrar",
    "clarimostrarde": "clarimostrar",
    "clarimostrardes": "clarimostrar",
    "clarimostrare": "clarimostrar",
    "clarimostrarei": "clarimostrar",
    "clarimostrareis": "clarimostrar",
    "clarimostrarem": "clarimostrar",
    "clarimostraremos": "clarimostrar",
    "clarimostrares": "clarimostrar",
    "clarimostraria": "clarimostrar",
    "clarimostrariam": "clarimostrar",
    "clarimostrarias": "clarimostrar",
    "clarimostrarmo": "clarimostrar",
    "clarimostrarmos": "clarimostrar",
    "clarimostrará": "clarimostrar",
    "clarimostrarás": "clarimostrar",
    "clarimostrarão": "clarimostrar",
    "clarimostraríamos": "clarimostrar",
    "clarimostraríeis": "clarimostrar",
    "clarimostras": "clarimostrar",
    "clarimostrasse": "clarimostrar",
    "clarimostrassem": "clarimostrar",
    "clarimostrasses": "clarimostrar",
    "clarimostraste": "clarimostrar",
    "clarimostrastes": "clarimostrar",
    "clarimostrava": "clarimostrar",
    "clarimostravam": "clarimostrar",
    "clarimostravas": "clarimostrar",
    "clarimostre": "clarimostrar",
    "clarimostrei": "clarimostrar",
    "clarimostreis": "clarimostrar",
    "clarimostrem": "clarimostrar",
    "clarimostremo": "clarimostrar",
    "clarimostremos": "clarimostrar",
    "clarimostres": "clarimostrar",
    "clarimostro": "clarimostrar",
    "clarimostrou": "clarimostrar",
    "clarimostrá": "clarimostrar",
    "clarimostrámo": "clarimostrar",
    "clarimostrámos": "clarimostrar",
    "clarimostráramo": "clarimostrar",
    "clarimostráramos": "clarimostrar",
    "clarimostrárei": "clarimostrar",
    "clarimostráreis": "clarimostrar",
    "clarimostrásseis": "clarimostrar",
    "clarimostrássemos": "clarimostrar",
    "clarimostrávamo": "clarimostrar",
    "clarimostrávamos": "clarimostrar",
    "clarimostrávei": "clarimostrar",
    "clarimostráveis": "clarimostrar",
    "clarinadas": "clarinada",
    "clarinetes": "clarinete",
    "clarinha": "claro",
    "clarinhas": "claro",
    "clarinho": "claro",
    "clarinhos": "claro",
    "clarins": "clarim",
    "clariofones": "clariofone",
    "clariofónica": "clariofónico",
    "clariofónicas": "clariofónico",
    "clariofónicos": "clariofónico",
    "clarissas": "clarissa",
    "claristas": "clarista",
    "clarita": "claro",
    "claritas": "claro",
    "clarito": "claro",
    "claritos": "claro",
    "clarividentes": "clarividente",
    "clarividências": "clarividência",
    "claros": "claro",
    "clarãozinho": "clarão",
    "clarãozito": "clarão",
    "claríssima": "claro",
    "claríssimas": "claro",
    "claríssimo": "claro",
    "claríssimos": "claro",
    "claríssona": "claríssono",
    "claríssonas": "claríssono",
    "claríssonos": "claríssono",
    "clarões": "clarão",
    "clarõezinhos": "clarão",
    "clarõezitos": "clarão",
    "classes": "classe",
    "classicismos": "classicismo",
    "classicistas": "classicista",
    "classicizantes": "classicizante",
    "classifica": "classificar",
    "classificada": "classificar",
    "classificadas": "classificar",
    "classificado": "classificar",
    "classificadora": "classificador",
    "classificadoras": "classificadora",
    "classificadores": "classificador",
    "classificados": "classificar",
    "classificai": "classificar",
    "classificais": "classificar",
    "classificam": "classificar",
    "classificamo": "classificar",
    "classificamos": "classificar",
    "classificando": "classificar",
    "classificara": "classificar",
    "classificaram": "classificar",
    "classificaras": "classificar",
    "classificarde": "classificar",
    "classificardes": "classificar",
    "classificare": "classificar",
    "classificarei": "classificar",
    "classificareis": "classificar",
    "classificarem": "classificar",
    "classificaremos": "classificar",
    "classificares": "classificar",
    "classificaria": "classificar",
    "classificariam": "classificar",
    "classificarias": "classificar",
    "classificarmo": "classificar",
    "classificarmos": "classificar",
    "classificará": "classificar",
    "classificarás": "classificar",
    "classificarão": "classificar",
    "classificaríamos": "classificar",
    "classificaríeis": "classificar",
    "classificas": "classificar",
    "classificasse": "classificar",
    "classificassem": "classificar",
    "classificasses": "classificar",
    "classificaste": "classificar",
    "classificastes": "classificar",
    "classificativa": "classificativo",
    "classificativas": "classificativo",
    "classificativos": "classificativo",
    "classificatórias": "classificatória",
    "classificava": "classificar",
    "classificavam": "classificar",
    "classificavas": "classificar",
    "classificações": "classificação",
    "classifico": "classificar",
    "classificou": "classificar",
    "classificá": "classificar",
    "classificámo": "classificar",
    "classificámos": "classificar",
    "classificáramo": "classificar",
    "classificáramos": "classificar",
    "classificárei": "classificar",
    "classificáreis": "classificar",
    "classificásseis": "classificar",
    "classificássemos": "classificar",
    "classificávamo": "classificar",
    "classificávamos": "classificar",
    "classificávei": "classificar",
    "classificáveis": "classificável",
    "classifique": "classificar",
    "classifiquei": "classificar",
    "classifiqueis": "classificar",
    "classifiquem": "classificar",
    "classifiquemo": "classificar",
    "classifiquemos": "classificar",
    "classifiques": "classificar",
    "classistas": "classista",
    "clastomanias": "clastomania",
    "clastomaníaca": "clastomaníaco",
    "clastomaníacas": "clastomaníaco",
    "clastomaníacos": "clastomaníaco",
    "clastos": "clasto",
    "clastómana": "clastómano",
    "clastómanas": "clastómano",
    "clastómanos": "clastómano",
    "claudica": "claudicar",
    "claudicada": "claudicar",
    "claudicadas": "claudicar",
    "claudicado": "claudicar",
    "claudicados": "claudicar",
    "claudicais": "claudicar",
    "claudicam": "claudicar",
    "claudicamo": "claudicar",
    "claudicamos": "claudicar",
    "claudicando": "claudicar",
    "claudicantes": "claudicante",
    "claudicara": "claudicar",
    "claudicaram": "claudicar",
    "claudicaras": "claudicar",
    "claudicardes": "claudicar",
    "claudicarei": "claudicar",
    "claudicareis": "claudicar",
    "claudicarem": "claudicar",
    "claudicaremos": "claudicar",
    "claudicares": "claudicar",
    "claudicaria": "claudicar",
    "claudicariam": "claudicar",
    "claudicarias": "claudicar",
    "claudicarmo": "claudicar",
    "claudicarmos": "claudicar",
    "claudicará": "claudicar",
    "claudicarás": "claudicar",
    "claudicarão": "claudicar",
    "claudicaríamos": "claudicar",
    "claudicaríeis": "claudicar",
    "claudicas": "claudicar",
    "claudicasse": "claudicar",
    "claudicassem": "claudicar",
    "claudicasses": "claudicar",
    "claudicaste": "claudicar",
    "claudicastes": "claudicar",
    "claudicava": "claudicar",
    "claudicavam": "claudicar",
    "claudicavas": "claudicar",
    "claudicações": "claudicação",
    "claudico": "claudicar",
    "claudicou": "claudicar",
    "claudicámo": "claudicar",
    "claudicámos": "claudicar",
    "claudicáramo": "claudicar",
    "claudicáramos": "claudicar",
    "claudicáreis": "claudicar",
    "claudicásseis": "claudicar",
    "claudicássemos": "claudicar",
    "claudicávamo": "claudicar",
    "claudicávamos": "claudicar",
    "claudicáveis": "claudicar",
    "claudique": "claudicar",
    "claudiquei": "claudicar",
    "claudiqueis": "claudicar",
    "claudiquem": "claudicar",
    "claudiquemos": "claudicar",
    "claudiques": "claudicar",
    "claustra": "claustrar",
    "claustrada": "claustrar",
    "claustradas": "claustrar",
    "claustrado": "claustrar",
    "claustrados": "claustrar",
    "claustrai": "claustrar",
    "claustrais": "claustrar",
    "claustralidades": "claustralidade",
    "claustram": "claustrar",
    "claustramo": "claustrar",
    "claustramos": "claustrar",
    "claustrando": "claustrar",
    "claustrara": "claustrar",
    "claustraram": "claustrar",
    "claustraras": "claustrar",
    "claustrarde": "claustrar",
    "claustrardes": "claustrar",
    "claustrare": "claustrar",
    "claustrarei": "claustrar",
    "claustrareis": "claustrar",
    "claustrarem": "claustrar",
    "claustraremos": "claustrar",
    "claustrares": "claustrar",
    "claustraria": "claustrar",
    "claustrariam": "claustrar",
    "claustrarias": "claustrar",
    "claustrarmo": "claustrar",
    "claustrarmos": "claustrar",
    "claustrará": "claustrar",
    "claustrarás": "claustrar",
    "claustrarão": "claustrar",
    "claustraríamos": "claustrar",
    "claustraríeis": "claustrar",
    "claustras": "claustrar",
    "claustrasse": "claustrar",
    "claustrassem": "claustrar",
    "claustrasses": "claustrar",
    "claustraste": "claustrar",
    "claustrastes": "claustrar",
    "claustrava": "claustrar",
    "claustravam": "claustrar",
    "claustravas": "claustrar",
    "claustre": "claustrar",
    "claustrei": "claustrar",
    "claustreis": "claustrar",
    "claustrem": "claustrar",
    "claustremo": "claustrar",
    "claustremos": "claustrar",
    "claustres": "claustrar",
    "claustro": "claustrar",
    "claustrofobias": "claustrofobia",
    "claustrofóbica": "claustrofóbico",
    "claustrofóbicas": "claustrofóbico",
    "claustrofóbicos": "claustrofóbico",
    "claustromanias": "claustromania",
    "claustromaníaca": "claustromaníaco",
    "claustromaníacas": "claustromaníaco",
    "claustromaníacos": "claustromaníaco",
    "claustros": "claustro",
    "claustrou": "claustrar",
    "claustrá": "claustrar",
    "claustrámo": "claustrar",
    "claustrámos": "claustrar",
    "claustráramo": "claustrar",
    "claustráramos": "claustrar",
    "claustrárei": "claustrar",
    "claustráreis": "claustrar",
    "claustrásseis": "claustrar",
    "claustrássemos": "claustrar",
    "claustrávamo": "claustrar",
    "claustrávamos": "claustrar",
    "claustrávei": "claustrar",
    "claustráveis": "claustrar",
    "claustrófoba": "claustrófobo",
    "claustrófobas": "claustrófobo",
    "claustrófobos": "claustrófobo",
    "claustrómana": "claustrómano",
    "claustrómanas": "claustrómano",
    "claustrómanos": "claustrómano",
    "clausula": "clausular",
    "clausulada": "clausular",
    "clausuladas": "clausular",
    "clausulado": "clausular",
    "clausulados": "clausular",
    "clausulai": "clausular",
    "clausulais": "clausular",
    "clausulam": "clausular",
    "clausulamo": "clausular",
    "clausulamos": "clausular",
    "clausulando": "clausular",
    "clausulara": "clausular",
    "clausularam": "clausular",
    "clausularas": "clausular",
    "clausularde": "clausular",
    "clausulardes": "clausular",
    "clausulare": "clausular",
    "clausularei": "clausular",
    "clausulareis": "clausular",
    "clausularem": "clausular",
    "clausularemos": "clausular",
    "clausulares": "clausular",
    "clausularia": "clausular",
    "clausulariam": "clausular",
    "clausularias": "clausular",
    "clausularmo": "clausular",
    "clausularmos": "clausular",
    "clausulará": "clausular",
    "clausularás": "clausular",
    "clausularão": "clausular",
    "clausularíamos": "clausular",
    "clausularíeis": "clausular",
    "clausulas": "clausular",
    "clausulasse": "clausular",
    "clausulassem": "clausular",
    "clausulasses": "clausular",
    "clausulaste": "clausular",
    "clausulastes": "clausular",
    "clausulava": "clausular",
    "clausulavam": "clausular",
    "clausulavas": "clausular",
    "clausule": "clausular",
    "clausulei": "clausular",
    "clausuleis": "clausular",
    "clausulem": "clausular",
    "clausulemo": "clausular",
    "clausulemos": "clausular",
    "clausules": "clausular",
    "clausulo": "clausular",
    "clausulou": "clausular",
    "clausulá": "clausular",
    "clausulámo": "clausular",
    "clausulámos": "clausular",
    "clausuláramo": "clausular",
    "clausuláramos": "clausular",
    "clausulárei": "clausular",
    "clausuláreis": "clausular",
    "clausulásseis": "clausular",
    "clausulássemos": "clausular",
    "clausulávamo": "clausular",
    "clausulávamos": "clausular",
    "clausulávei": "clausular",
    "clausuláveis": "clausular",
    "clausura": "clausurar",
    "clausurada": "clausurar",
    "clausuradas": "clausurar",
    "clausurado": "clausurar",
    "clausurados": "clausurar",
    "clausurai": "clausurar",
    "clausurais": "clausurar",
    "clausuram": "clausurar",
    "clausuramo": "clausurar",
    "clausuramos": "clausurar",
    "clausurando": "clausurar",
    "clausurara": "clausurar",
    "clausuraram": "clausurar",
    "clausuraras": "clausurar",
    "clausurarde": "clausurar",
    "clausurardes": "clausurar",
    "clausurare": "clausurar",
    "clausurarei": "clausurar",
    "clausurareis": "clausurar",
    "clausurarem": "clausurar",
    "clausuraremos": "clausurar",
    "clausurares": "clausurar",
    "clausuraria": "clausurar",
    "clausurariam": "clausurar",
    "clausurarias": "clausurar",
    "clausurarmo": "clausurar",
    "clausurarmos": "clausurar",
    "clausurará": "clausurar",
    "clausurarás": "clausurar",
    "clausurarão": "clausurar",
    "clausuraríamos": "clausurar",
    "clausuraríeis": "clausurar",
    "clausuras": "clausurar",
    "clausurasse": "clausurar",
    "clausurassem": "clausurar",
    "clausurasses": "clausurar",
    "clausuraste": "clausurar",
    "clausurastes": "clausurar",
    "clausurava": "clausurar",
    "clausuravam": "clausurar",
    "clausuravas": "clausurar",
    "clausure": "clausurar",
    "clausurei": "clausurar",
    "clausureis": "clausurar",
    "clausurem": "clausurar",
    "clausuremo": "clausurar",
    "clausuremos": "clausurar",
    "clausures": "clausurar",
    "clausuro": "clausurar",
    "clausurou": "clausurar",
    "clausurá": "clausurar",
    "clausurámo": "clausurar",
    "clausurámos": "clausurar",
    "clausuráramo": "clausurar",
    "clausuráramos": "clausurar",
    "clausurárei": "clausurar",
    "clausuráreis": "clausurar",
    "clausurásseis": "clausurar",
    "clausurássemos": "clausurar",
    "clausurávamo": "clausurar",
    "clausurávamos": "clausurar",
    "clausurávei": "clausurar",
    "clausuráveis": "clausurar",
    "clavarias": "clavaria",
    "clavas": "clava",
    "clavecinistas": "clavecinista",
    "clavecinos": "clavecino",
    "claveiros": "claveiro",
    "claves": "clave",
    "clavicordionistas": "clavicordionista",
    "claviculada": "claviculado",
    "claviculadas": "claviculado",
    "claviculados": "claviculado",
    "claviculares": "clavicular",
    "claviculários": "claviculário",
    "clavicímbalos": "clavicímbalo",
    "clavicórdios": "clavicórdio",
    "clavicórnea": "clavicórneo",
    "clavicórneas": "clavicórneo",
    "clavicórneos": "clavicórneo",
    "clavifoliada": "clavifoliado",
    "clavifoliadas": "clavifoliado",
    "clavifoliados": "clavifoliado",
    "claviformes": "claviforme",
    "clavijas": "clavija",
    "clavinas": "clavina",
    "clavineiros": "clavineiro",
    "claviórgões": "claviórgão",
    "clavários": "clavário",
    "clavículas": "clavícula",
    "clavígera": "clavígero",
    "clavígeras": "clavígero",
    "clavígeros": "clavígero",
    "cledomântica": "cledomântico",
    "cledomânticas": "cledomântico",
    "cledomânticos": "cledomântico",
    "cleftas": "clefta",
    "cleistogama": "cleistogamo",
    "cleistogamas": "cleistogamo",
    "cleistogamias": "cleistogamia",
    "cleistogamos": "cleistogamo",
    "cleistogâmica": "cleistogâmico",
    "cleistogâmicas": "cleistogâmico",
    "cleistogâmicos": "cleistogâmico",
    "clematites": "clematite",
    "clemencia": "clemenciar",
    "clemenciada": "clemenciar",
    "clemenciadas": "clemenciar",
    "clemenciado": "clemenciar",
    "clemenciados": "clemenciar",
    "clemenciai": "clemenciar",
    "clemenciais": "clemenciar",
    "clemenciam": "clemenciar",
    "clemenciamo": "clemenciar",
    "clemenciamos": "clemenciar",
    "clemenciando": "clemenciar",
    "clemenciara": "clemenciar",
    "clemenciaram": "clemenciar",
    "clemenciaras": "clemenciar",
    "clemenciarde": "clemenciar",
    "clemenciardes": "clemenciar",
    "clemenciare": "clemenciar",
    "clemenciarei": "clemenciar",
    "clemenciareis": "clemenciar",
    "clemenciarem": "clemenciar",
    "clemenciaremos": "clemenciar",
    "clemenciares": "clemenciar",
    "clemenciaria": "clemenciar",
    "clemenciariam": "clemenciar",
    "clemenciarias": "clemenciar",
    "clemenciarmo": "clemenciar",
    "clemenciarmos": "clemenciar",
    "clemenciará": "clemenciar",
    "clemenciarás": "clemenciar",
    "clemenciarão": "clemenciar",
    "clemenciaríamos": "clemenciar",
    "clemenciaríeis": "clemenciar",
    "clemencias": "clemenciar",
    "clemenciasse": "clemenciar",
    "clemenciassem": "clemenciar",
    "clemenciasses": "clemenciar",
    "clemenciaste": "clemenciar",
    "clemenciastes": "clemenciar",
    "clemenciava": "clemenciar",
    "clemenciavam": "clemenciar",
    "clemenciavas": "clemenciar",
    "clemencie": "clemenciar",
    "clemenciei": "clemenciar",
    "clemencieis": "clemenciar",
    "clemenciem": "clemenciar",
    "clemenciemo": "clemenciar",
    "clemenciemos": "clemenciar",
    "clemencies": "clemenciar",
    "clemencio": "clemenciar",
    "clemenciou": "clemenciar",
    "clemenciá": "clemenciar",
    "clemenciámo": "clemenciar",
    "clemenciámos": "clemenciar",
    "clemenciáramo": "clemenciar",
    "clemenciáramos": "clemenciar",
    "clemenciárei": "clemenciar",
    "clemenciáreis": "clemenciar",
    "clemenciásseis": "clemenciar",
    "clemenciássemos": "clemenciar",
    "clemenciávamo": "clemenciar",
    "clemenciávamos": "clemenciar",
    "clemenciávei": "clemenciar",
    "clemenciáveis": "clemenciar",
    "clementes": "clemente",
    "clementinas": "clementina",
    "clemências": "clemência",
    "cleopatriza": "cleopatrizar",
    "cleopatrizada": "cleopatrizar",
    "cleopatrizadas": "cleopatrizar",
    "cleopatrizado": "cleopatrizar",
    "cleopatrizados": "cleopatrizar",
    "cleopatrizai": "cleopatrizar",
    "cleopatrizais": "cleopatrizar",
    "cleopatrizam": "cleopatrizar",
    "cleopatrizamo": "cleopatrizar",
    "cleopatrizamos": "cleopatrizar",
    "cleopatrizando": "cleopatrizar",
    "cleopatrizara": "cleopatrizar",
    "cleopatrizaram": "cleopatrizar",
    "cleopatrizaras": "cleopatrizar",
    "cleopatrizarde": "cleopatrizar",
    "cleopatrizardes": "cleopatrizar",
    "cleopatrizare": "cleopatrizar",
    "cleopatrizarei": "cleopatrizar",
    "cleopatrizareis": "cleopatrizar",
    "cleopatrizarem": "cleopatrizar",
    "cleopatrizaremos": "cleopatrizar",
    "cleopatrizares": "cleopatrizar",
    "cleopatrizaria": "cleopatrizar",
    "cleopatrizariam": "cleopatrizar",
    "cleopatrizarias": "cleopatrizar",
    "cleopatrizarmo": "cleopatrizar",
    "cleopatrizarmos": "cleopatrizar",
    "cleopatrizará": "cleopatrizar",
    "cleopatrizarás": "cleopatrizar",
    "cleopatrizarão": "cleopatrizar",
    "cleopatrizaríamos": "cleopatrizar",
    "cleopatrizaríeis": "cleopatrizar",
    "cleopatrizas": "cleopatrizar",
    "cleopatrizasse": "cleopatrizar",
    "cleopatrizassem": "cleopatrizar",
    "cleopatrizasses": "cleopatrizar",
    "cleopatrizaste": "cleopatrizar",
    "cleopatrizastes": "cleopatrizar",
    "cleopatrizava": "cleopatrizar",
    "cleopatrizavam": "cleopatrizar",
    "cleopatrizavas": "cleopatrizar",
    "cleopatrize": "cleopatrizar",
    "cleopatrizei": "cleopatrizar",
    "cleopatrizeis": "cleopatrizar",
    "cleopatrizem": "cleopatrizar",
    "cleopatrizemo": "cleopatrizar",
    "cleopatrizemos": "cleopatrizar",
    "cleopatrizes": "cleopatrizar",
    "cleopatrizo": "cleopatrizar",
    "cleopatrizou": "cleopatrizar",
    "cleopatrizá": "cleopatrizar",
    "cleopatrizámo": "cleopatrizar",
    "cleopatrizámos": "cleopatrizar",
    "cleopatrizáramo": "cleopatrizar",
    "cleopatrizáramos": "cleopatrizar",
    "cleopatrizárei": "cleopatrizar",
    "cleopatrizáreis": "cleopatrizar",
    "cleopatrizásseis": "cleopatrizar",
    "cleopatrizássemos": "cleopatrizar",
    "cleopatrizávamo": "cleopatrizar",
    "cleopatrizávamos": "cleopatrizar",
    "cleopatrizávei": "cleopatrizar",
    "cleopatrizáveis": "cleopatrizar",
    "clepsidras": "clepsidra",
    "cleptofobias": "cleptofobia",
    "cleptofóbica": "cleptofóbico",
    "cleptofóbicas": "cleptofóbico",
    "cleptofóbicos": "cleptofóbico",
    "cleptomanias": "cleptomania",
    "cleptomaníaca": "cleptomaníaco",
    "cleptomaníacas": "cleptomaníaco",
    "cleptomaníacos": "cleptomaníaco",
    "cleptófoba": "cleptófobo",
    "cleptófobas": "cleptófobo",
    "cleptófobos": "cleptófobo",
    "cleptómana": "cleptómano",
    "cleptómanas": "cleptómano",
    "cleptómanos": "cleptómano",
    "cleresias": "cleresia",
    "clerestórios": "clerestório",
    "clericais": "clerical",
    "clericalismos": "clericalismo",
    "clericalistas": "clericalista",
    "clericaliza": "clericalizar",
    "clericalizada": "clericalizar",
    "clericalizadas": "clericalizar",
    "clericalizado": "clericalizar",
    "clericalizados": "clericalizar",
    "clericalizai": "clericalizar",
    "clericalizais": "clericalizar",
    "clericalizam": "clericalizar",
    "clericalizamo": "clericalizar",
    "clericalizamos": "clericalizar",
    "clericalizando": "clericalizar",
    "clericalizara": "clericalizar",
    "clericalizaram": "clericalizar",
    "clericalizaras": "clericalizar",
    "clericalizarde": "clericalizar",
    "clericalizardes": "clericalizar",
    "clericalizare": "clericalizar",
    "clericalizarei": "clericalizar",
    "clericalizareis": "clericalizar",
    "clericalizarem": "clericalizar",
    "clericalizaremos": "clericalizar",
    "clericalizares": "clericalizar",
    "clericalizaria": "clericalizar",
    "clericalizariam": "clericalizar",
    "clericalizarias": "clericalizar",
    "clericalizarmo": "clericalizar",
    "clericalizarmos": "clericalizar",
    "clericalizará": "clericalizar",
    "clericalizarás": "clericalizar",
    "clericalizarão": "clericalizar",
    "clericalizaríamos": "clericalizar",
    "clericalizaríeis": "clericalizar",
    "clericalizas": "clericalizar",
    "clericalizasse": "clericalizar",
    "clericalizassem": "clericalizar",
    "clericalizasses": "clericalizar",
    "clericalizaste": "clericalizar",
    "clericalizastes": "clericalizar",
    "clericalizava": "clericalizar",
    "clericalizavam": "clericalizar",
    "clericalizavas": "clericalizar",
    "clericalize": "clericalizar",
    "clericalizei": "clericalizar",
    "clericalizeis": "clericalizar",
    "clericalizem": "clericalizar",
    "clericalizemo": "clericalizar",
    "clericalizemos": "clericalizar",
    "clericalizes": "clericalizar",
    "clericalizo": "clericalizar",
    "clericalizou": "clericalizar",
    "clericalizá": "clericalizar",
    "clericalizámo": "clericalizar",
    "clericalizámos": "clericalizar",
    "clericalizáramo": "clericalizar",
    "clericalizáramos": "clericalizar",
    "clericalizárei": "clericalizar",
    "clericalizáreis": "clericalizar",
    "clericalizásseis": "clericalizar",
    "clericalizássemos": "clericalizar",
    "clericalizávamo": "clericalizar",
    "clericalizávamos": "clericalizar",
    "clericalizávei": "clericalizar",
    "clericalizáveis": "clericalizar",
    "clericatos": "clericato",
    "clerocracias": "clerocracia",
    "clerocratas": "clerocrata",
    "clerocrática": "clerocrático",
    "clerocráticas": "clerocrático",
    "clerocráticos": "clerocrático",
    "clerofobias": "clerofobia",
    "clerofóbica": "clerofóbico",
    "clerofóbicas": "clerofóbico",
    "clerofóbicos": "clerofóbico",
    "cleromancias": "cleromancia",
    "cleromantes": "cleromante",
    "cleros": "clero",
    "clerófoba": "clerófobo",
    "clerófobas": "clerófobo",
    "clerófobos": "clerófobo",
    "clica": "clicar",
    "clicada": "clicar",
    "clicadas": "clicar",
    "clicado": "clicar",
    "clicados": "clicar",
    "clicai": "clicar",
    "clicais": "clicar",
    "clicam": "clicar",
    "clicamo": "clicar",
    "clicamos": "clicar",
    "clicando": "clicar",
    "clicara": "clicar",
    "clicaram": "clicar",
    "clicaras": "clicar",
    "clicarde": "clicar",
    "clicardes": "clicar",
    "clicare": "clicar",
    "clicarei": "clicar",
    "clicareis": "clicar",
    "clicarem": "clicar",
    "clicaremos": "clicar",
    "clicares": "clicar",
    "clicaria": "clicar",
    "clicariam": "clicar",
    "clicarias": "clicar",
    "clicarmo": "clicar",
    "clicarmos": "clicar",
    "clicará": "clicar",
    "clicarás": "clicar",
    "clicarão": "clicar",
    "clicaríamos": "clicar",
    "clicaríeis": "clicar",
    "clicas": "clicar",
    "clicasse": "clicar",
    "clicassem": "clicar",
    "clicasses": "clicar",
    "clicaste": "clicar",
    "clicastes": "clicar",
    "clicava": "clicar",
    "clicavam": "clicar",
    "clicavas": "clicar",
    "clichés": "cliché",
    "clico": "clicar",
    "clicou": "clicar",
    "clicá": "clicar",
    "clicámo": "clicar",
    "clicámos": "clicar",
    "clicáramo": "clicar",
    "clicáramos": "clicar",
    "clicárei": "clicar",
    "clicáreis": "clicar",
    "clicásseis": "clicar",
    "clicássemos": "clicar",
    "clicávamo": "clicar",
    "clicávamos": "clicar",
    "clicávei": "clicar",
    "clicáveis": "clicar",
    "clidográfica": "clidográfico",
    "clidográficas": "clidográfico",
    "clidográficos": "clidográfico",
    "clidomancias": "clidomancia",
    "clidomantes": "clidomante",
    "clidomântica": "clidomântico",
    "clidomânticas": "clidomântico",
    "clidomânticos": "clidomântico",
    "clidonografias": "clidonografia",
    "clidonógrafos": "clidonógrafo",
    "clidoscopias": "clidoscopia",
    "clidoscópia": "clidoscópio",
    "clidoscópias": "clidoscópio",
    "clidoscópios": "clidoscópio",
    "clidotomias": "clidotomia",
    "clidotómica": "clidotómico",
    "clidotómicas": "clidotómico",
    "clidotómicos": "clidotómico",
    "clientelas": "clientela",
    "clientelismos": "clientelismo",
    "clientes": "cliente",
    "climactérica": "climactérico",
    "climactéricas": "climactérico",
    "climactéricos": "climactérico",
    "climas": "clima",
    "climaterapêutica": "climaterapêutico",
    "climaterapêuticas": "climaterapêutico",
    "climaterapêuticos": "climaterapêutico",
    "climaterápica": "climaterápico",
    "climaterápicas": "climaterápico",
    "climaterápicos": "climaterápico",
    "climatiza": "climatizar",
    "climatizada": "climatizar",
    "climatizadas": "climatizar",
    "climatizado": "climatizar",
    "climatizados": "climatizar",
    "climatizai": "climatizar",
    "climatizais": "climatizar",
    "climatizam": "climatizar",
    "climatizamo": "climatizar",
    "climatizamos": "climatizar",
    "climatizando": "climatizar",
    "climatizara": "climatizar",
    "climatizaram": "climatizar",
    "climatizaras": "climatizar",
    "climatizarde": "climatizar",
    "climatizardes": "climatizar",
    "climatizare": "climatizar",
    "climatizarei": "climatizar",
    "climatizareis": "climatizar",
    "climatizarem": "climatizar",
    "climatizaremos": "climatizar",
    "climatizares": "climatizar",
    "climatizaria": "climatizar",
    "climatizariam": "climatizar",
    "climatizarias": "climatizar",
    "climatizarmo": "climatizar",
    "climatizarmos": "climatizar",
    "climatizará": "climatizar",
    "climatizarás": "climatizar",
    "climatizarão": "climatizar",
    "climatizaríamos": "climatizar",
    "climatizaríeis": "climatizar",
    "climatizas": "climatizar",
    "climatizasse": "climatizar",
    "climatizassem": "climatizar",
    "climatizasses": "climatizar",
    "climatizaste": "climatizar",
    "climatizastes": "climatizar",
    "climatizava": "climatizar",
    "climatizavam": "climatizar",
    "climatizavas": "climatizar",
    "climatizações": "climatização",
    "climatize": "climatizar",
    "climatizei": "climatizar",
    "climatizeis": "climatizar",
    "climatizem": "climatizar",
    "climatizemo": "climatizar",
    "climatizemos": "climatizar",
    "climatizes": "climatizar",
    "climatizo": "climatizar",
    "climatizou": "climatizar",
    "climatizá": "climatizar",
    "climatizámo": "climatizar",
    "climatizámos": "climatizar",
    "climatizáramo": "climatizar",
    "climatizáramos": "climatizar",
    "climatizárei": "climatizar",
    "climatizáreis": "climatizar",
    "climatizásseis": "climatizar",
    "climatizássemos": "climatizar",
    "climatizávamo": "climatizar",
    "climatizávamos": "climatizar",
    "climatizávei": "climatizar",
    "climatizáveis": "climatizar",
    "climatologias": "climatologia",
    "climatologistas": "climatologista",
    "climatológica": "climatológico",
    "climatológicas": "climatológico",
    "climatológicos": "climatológico",
    "climatoterapeutas": "climatoterapeuta",
    "climatoterapêutica": "climatoterapêutico",
    "climatoterapêuticas": "climatoterapêutico",
    "climatoterapêuticos": "climatoterapêutico",
    "climatoterápica": "climatoterápico",
    "climatoterápicas": "climatoterápico",
    "climatoterápicos": "climatoterápico",
    "climatérica": "climatérico",
    "climatéricas": "climatérico",
    "climatéricos": "climatérico",
    "climatérios": "climatério",
    "climatóloga": "climatólogo",
    "climatólogas": "climatólogo",
    "climatólogos": "climatólogo",
    "climaxes": "climax",
    "climenídea": "climenídeo",
    "climenídeas": "climenídeo",
    "climenídeos": "climenídeo",
    "climática": "climático",
    "climáticas": "climático",
    "climáticos": "climático",
    "clinas": "clina",
    "clinica": "clinicar",
    "clinicada": "clinicar",
    "clinicadas": "clinicar",
    "clinicado": "clinicar",
    "clinicados": "clinicar",
    "clinicai": "clinicar",
    "clinicais": "clinicar",
    "clinicam": "clinicar",
    "clinicamo": "clinicar",
    "clinicamos": "clinicar",
    "clinicando": "clinicar",
    "clinicara": "clinicar",
    "clinicaram": "clinicar",
    "clinicaras": "clinicar",
    "clinicarde": "clinicar",
    "clinicardes": "clinicar",
    "clinicare": "clinicar",
    "clinicarei": "clinicar",
    "clinicareis": "clinicar",
    "clinicarem": "clinicar",
    "clinicaremos": "clinicar",
    "clinicares": "clinicar",
    "clinicaria": "clinicar",
    "clinicariam": "clinicar",
    "clinicarias": "clinicar",
    "clinicarmo": "clinicar",
    "clinicarmos": "clinicar",
    "clinicará": "clinicar",
    "clinicarás": "clinicar",
    "clinicarão": "clinicar",
    "clinicaríamos": "clinicar",
    "clinicaríeis": "clinicar",
    "clinicas": "clinicar",
    "clinicasse": "clinicar",
    "clinicassem": "clinicar",
    "clinicasses": "clinicar",
    "clinicaste": "clinicar",
    "clinicastes": "clinicar",
    "clinicava": "clinicar",
    "clinicavam": "clinicar",
    "clinicavas": "clinicar",
    "clinico": "clinicar",
    "clinicou": "clinicar",
    "clinicá": "clinicar",
    "clinicámo": "clinicar",
    "clinicámos": "clinicar",
    "clinicáramo": "clinicar",
    "clinicáramos": "clinicar",
    "clinicárei": "clinicar",
    "clinicáreis": "clinicar",
    "clinicásseis": "clinicar",
    "clinicássemos": "clinicar",
    "clinicávamo": "clinicar",
    "clinicávamos": "clinicar",
    "clinicávei": "clinicar",
    "clinicáveis": "clinicar",
    "clinique": "clinicar",
    "cliniquei": "clinicar",
    "cliniqueis": "clinicar",
    "cliniquem": "clinicar",
    "cliniquemo": "clinicar",
    "cliniquemos": "clinicar",
    "cliniques": "clinicar",
    "clinocefalias": "clinocefalia",
    "clinocefálica": "clinocefálico",
    "clinocefálicas": "clinocefálico",
    "clinocefálicos": "clinocefálico",
    "clinocéfala": "clinocéfalo",
    "clinocéfalas": "clinocéfalo",
    "clinocéfalos": "clinocéfalo",
    "clinodactilias": "clinodactilia",
    "clinodiagonais": "clinodiagonal",
    "clinodomas": "clinodoma",
    "clinodáctila": "clinodáctilo",
    "clinodáctilas": "clinodáctilo",
    "clinodáctilos": "clinodáctilo",
    "clinomanias": "clinomania",
    "clinomaníaca": "clinomaníaco",
    "clinomaníacas": "clinomaníaco",
    "clinomaníacos": "clinomaníaco",
    "clinometrias": "clinometria",
    "clinométrica": "clinométrico",
    "clinométricas": "clinométrico",
    "clinométricos": "clinométrico",
    "clinopinacóides": "clinopinacóide",
    "clinopódios": "clinopódio",
    "clinoterapeutas": "clinoterapeuta",
    "clinoterapias": "clinoterapia",
    "clinoterapêutica": "clinoterapêutico",
    "clinoterapêuticas": "clinoterapêutico",
    "clinoterapêuticos": "clinoterapêutico",
    "clinoterápica": "clinoterápico",
    "clinoterápicas": "clinoterápico",
    "clinoterápicos": "clinoterápico",
    "clinámenes": "clinámen",
    "clinómana": "clinómano",
    "clinómanas": "clinómano",
    "clinómanos": "clinómano",
    "clinómetros": "clinómetro",
    "clipes": "clipe",
    "clique": "clicar",
    "cliquei": "clicar",
    "cliqueis": "clicar",
    "cliquem": "clicar",
    "cliquemo": "clicar",
    "cliquemos": "clicar",
    "cliques": "clique",
    "clises": "clise",
    "clisteres": "clister",
    "clisteriza": "clisterizar",
    "clisterizada": "clisterizar",
    "clisterizadas": "clisterizar",
    "clisterizado": "clisterizar",
    "clisterizados": "clisterizar",
    "clisterizai": "clisterizar",
    "clisterizais": "clisterizar",
    "clisterizam": "clisterizar",
    "clisterizamo": "clisterizar",
    "clisterizamos": "clisterizar",
    "clisterizando": "clisterizar",
    "clisterizara": "clisterizar",
    "clisterizaram": "clisterizar",
    "clisterizaras": "clisterizar",
    "clisterizarde": "clisterizar",
    "clisterizardes": "clisterizar",
    "clisterizare": "clisterizar",
    "clisterizarei": "clisterizar",
    "clisterizareis": "clisterizar",
    "clisterizarem": "clisterizar",
    "clisterizaremos": "clisterizar",
    "clisterizares": "clisterizar",
    "clisterizaria": "clisterizar",
    "clisterizariam": "clisterizar",
    "clisterizarias": "clisterizar",
    "clisterizarmo": "clisterizar",
    "clisterizarmos": "clisterizar",
    "clisterizará": "clisterizar",
    "clisterizarás": "clisterizar",
    "clisterizarão": "clisterizar",
    "clisterizaríamos": "clisterizar",
    "clisterizaríeis": "clisterizar",
    "clisterizas": "clisterizar",
    "clisterizasse": "clisterizar",
    "clisterizassem": "clisterizar",
    "clisterizasses": "clisterizar",
    "clisterizaste": "clisterizar",
    "clisterizastes": "clisterizar",
    "clisterizava": "clisterizar",
    "clisterizavam": "clisterizar",
    "clisterizavas": "clisterizar",
    "clisterizações": "clisterização",
    "clisterize": "clisterizar",
    "clisterizei": "clisterizar",
    "clisterizeis": "clisterizar",
    "clisterizem": "clisterizar",
    "clisterizemo": "clisterizar",
    "clisterizemos": "clisterizar",
    "clisterizes": "clisterizar",
    "clisterizo": "clisterizar",
    "clisterizou": "clisterizar",
    "clisterizá": "clisterizar",
    "clisterizámo": "clisterizar",
    "clisterizámos": "clisterizar",
    "clisterizáramo": "clisterizar",
    "clisterizáramos": "clisterizar",
    "clisterizárei": "clisterizar",
    "clisterizáreis": "clisterizar",
    "clisterizásseis": "clisterizar",
    "clisterizássemos": "clisterizar",
    "clisterizávamo": "clisterizar",
    "clisterizávamos": "clisterizar",
    "clisterizávei": "clisterizar",
    "clisterizáveis": "clisterizar",
    "clistogamias": "clistogamia",
    "clistogâmica": "clistogâmico",
    "clistogâmicas": "clistogâmico",
    "clistogâmicos": "clistogâmico",
    "clistrões": "clistrão",
    "clistógama": "clistógamo",
    "clistógamas": "clistógamo",
    "clistógamos": "clistógamo",
    "clitelada": "clitelado",
    "cliteladas": "clitelado",
    "clitelados": "clitelado",
    "clitelos": "clitelo",
    "clitoridismos": "clitoridismo",
    "clitoritomias": "clitoritomia",
    "clitoritómica": "clitoritómico",
    "clitoritómicas": "clitoritómico",
    "clitoritómicos": "clitoritómico",
    "clitórides": "clitóride",
    "cliva": "clivar",
    "clivada": "clivar",
    "clivadas": "clivar",
    "clivado": "clivar",
    "clivados": "clivar",
    "clivagens": "clivagem",
    "clivai": "clivar",
    "clivais": "clivar",
    "clivam": "clivar",
    "clivamo": "clivar",
    "clivamos": "clivar",
    "clivando": "clivar",
    "clivara": "clivar",
    "clivaram": "clivar",
    "clivaras": "clivar",
    "clivarde": "clivar",
    "clivardes": "clivar",
    "clivare": "clivar",
    "clivarei": "clivar",
    "clivareis": "clivar",
    "clivarem": "clivar",
    "clivaremos": "clivar",
    "clivares": "clivar",
    "clivaria": "clivar",
    "clivariam": "clivar",
    "clivarias": "clivar",
    "clivarmo": "clivar",
    "clivarmos": "clivar",
    "clivará": "clivar",
    "clivarás": "clivar",
    "clivarão": "clivar",
    "clivaríamos": "clivar",
    "clivaríeis": "clivar",
    "clivas": "clivar",
    "clivasse": "clivar",
    "clivassem": "clivar",
    "clivasses": "clivar",
    "clivaste": "clivar",
    "clivastes": "clivar",
    "clivava": "clivar",
    "clivavam": "clivar",
    "clivavas": "clivar",
    "clive": "clivar",
    "clivei": "clivar",
    "cliveis": "clivar",
    "clivem": "clivar",
    "clivemo": "clivar",
    "clivemos": "clivar",
    "clives": "clivar",
    "clivo": "clivar",
    "clivos": "clivo",
    "clivosa": "clivoso",
    "clivosas": "clivoso",
    "clivosos": "clivoso",
    "clivou": "clivar",
    "clivá": "clivar",
    "clivámo": "clivar",
    "clivámos": "clivar",
    "cliváramo": "clivar",
    "cliváramos": "clivar",
    "clivárei": "clivar",
    "cliváreis": "clivar",
    "clivásseis": "clivar",
    "clivássemos": "clivar",
    "clivávamo": "clivar",
    "clivávamos": "clivar",
    "clivávei": "clivar",
    "cliváveis": "clivar",
    "cloacais": "cloacal",
    "cloacas": "cloaca",
    "cloacina": "cloacino",
    "cloacinas": "cloacino",
    "cloacinos": "cloacino",
    "cloacários": "cloacário",
    "clona": "clonar",
    "clonada": "clonar",
    "clonadas": "clonar",
    "clonado": "clonar",
    "clonados": "clonar",
    "clonagens": "clonagem",
    "clonai": "clonar",
    "clonais": "clonar",
    "clonam": "clonar",
    "clonamo": "clonar",
    "clonamos": "clonar",
    "clonando": "clonar",
    "clonara": "clonar",
    "clonaram": "clonar",
    "clonaras": "clonar",
    "clonarde": "clonar",
    "clonardes": "clonar",
    "clonare": "clonar",
    "clonarei": "clonar",
    "clonareis": "clonar",
    "clonarem": "clonar",
    "clonaremos": "clonar",
    "clonares": "clonar",
    "clonaria": "clonar",
    "clonariam": "clonar",
    "clonarias": "clonar",
    "clonarmo": "clonar",
    "clonarmos": "clonar",
    "clonará": "clonar",
    "clonarás": "clonar",
    "clonarão": "clonar",
    "clonaríamos": "clonar",
    "clonaríeis": "clonar",
    "clonas": "clonar",
    "clonasse": "clonar",
    "clonassem": "clonar",
    "clonasses": "clonar",
    "clonaste": "clonar",
    "clonastes": "clonar",
    "clonava": "clonar",
    "clonavam": "clonar",
    "clonavas": "clonar",
    "clone": "clonar",
    "clonei": "clonar",
    "cloneis": "clonar",
    "clonem": "clonar",
    "clonemo": "clonar",
    "clonemos": "clonar",
    "clones": "clone",
    "clono": "clonar",
    "clonou": "clonar",
    "cloná": "clonar",
    "clonámo": "clonar",
    "clonámos": "clonar",
    "clonáramo": "clonar",
    "clonáramos": "clonar",
    "clonárei": "clonar",
    "clonáreis": "clonar",
    "clonásseis": "clonar",
    "clonássemos": "clonar",
    "clonávamo": "clonar",
    "clonávamos": "clonar",
    "clonávei": "clonar",
    "clonáveis": "clonar",
    "clorada": "clorado",
    "cloradas": "clorado",
    "clorados": "clorado",
    "cloragens": "cloragem",
    "clorais": "cloral",
    "cloratos": "clorato",
    "cloremias": "cloremia",
    "cloretos": "cloreto",
    "cloridratos": "cloridrato",
    "clorocarbonizações": "clorocarbonização",
    "clorofilas": "clorofila",
    "clorofilina": "clorofilino",
    "clorofilinas": "clorofilino",
    "clorofilinos": "clorofilino",
    "cloroformiza": "cloroformizar",
    "cloroformizada": "cloroformizar",
    "cloroformizadas": "cloroformizar",
    "cloroformizado": "cloroformizar",
    "cloroformizados": "cloroformizar",
    "cloroformizai": "cloroformizar",
    "cloroformizais": "cloroformizar",
    "cloroformizam": "cloroformizar",
    "cloroformizamo": "cloroformizar",
    "cloroformizamos": "cloroformizar",
    "cloroformizando": "cloroformizar",
    "cloroformizara": "cloroformizar",
    "cloroformizaram": "cloroformizar",
    "cloroformizaras": "cloroformizar",
    "cloroformizarde": "cloroformizar",
    "cloroformizardes": "cloroformizar",
    "cloroformizare": "cloroformizar",
    "cloroformizarei": "cloroformizar",
    "cloroformizareis": "cloroformizar",
    "cloroformizarem": "cloroformizar",
    "cloroformizaremos": "cloroformizar",
    "cloroformizares": "cloroformizar",
    "cloroformizaria": "cloroformizar",
    "cloroformizariam": "cloroformizar",
    "cloroformizarias": "cloroformizar",
    "cloroformizarmo": "cloroformizar",
    "cloroformizarmos": "cloroformizar",
    "cloroformizará": "cloroformizar",
    "cloroformizarás": "cloroformizar",
    "cloroformizarão": "cloroformizar",
    "cloroformizaríamos": "cloroformizar",
    "cloroformizaríeis": "cloroformizar",
    "cloroformizas": "cloroformizar",
    "cloroformizasse": "cloroformizar",
    "cloroformizassem": "cloroformizar",
    "cloroformizasses": "cloroformizar",
    "cloroformizaste": "cloroformizar",
    "cloroformizastes": "cloroformizar",
    "cloroformizava": "cloroformizar",
    "cloroformizavam": "cloroformizar",
    "cloroformizavas": "cloroformizar",
    "cloroformize": "cloroformizar",
    "cloroformizei": "cloroformizar",
    "cloroformizeis": "cloroformizar",
    "cloroformizem": "cloroformizar",
    "cloroformizemo": "cloroformizar",
    "cloroformizemos": "cloroformizar",
    "cloroformizes": "cloroformizar",
    "cloroformizo": "cloroformizar",
    "cloroformizou": "cloroformizar",
    "cloroformizá": "cloroformizar",
    "cloroformizámo": "cloroformizar",
    "cloroformizámos": "cloroformizar",
    "cloroformizáramo": "cloroformizar",
    "cloroformizáramos": "cloroformizar",
    "cloroformizárei": "cloroformizar",
    "cloroformizáreis": "cloroformizar",
    "cloroformizásseis": "cloroformizar",
    "cloroformizássemos": "cloroformizar",
    "cloroformizávamo": "cloroformizar",
    "cloroformizávamos": "cloroformizar",
    "cloroformizávei": "cloroformizar",
    "cloroformizáveis": "cloroformizar",
    "cloroformições": "cloroformição",
    "clorofícea": "clorofíceo",
    "clorofíceas": "clorofíceo",
    "clorofíceos": "clorofíceo",
    "clorofíces": "clorofíce",
    "clorofórmica": "clorofórmico",
    "clorofórmicas": "clorofórmico",
    "clorofórmicos": "clorofórmico",
    "clorofórmios": "clorofórmio",
    "cloroleucitos": "cloroleucito",
    "cloromicetinas": "cloromicetina",
    "cloroplastas": "cloroplasta",
    "cloroplastídea": "cloroplastídeo",
    "cloroplastídeas": "cloroplastídeo",
    "cloroplastídeos": "cloroplastídeo",
    "cloroplástica": "cloroplástico",
    "cloroplásticas": "cloroplástico",
    "cloroplásticos": "cloroplástico",
    "cloros": "cloro",
    "cloroses": "clorose",
    "clorénica": "clorénico",
    "clorénicas": "clorénico",
    "clorénicos": "clorénico",
    "clorídrica": "clorídrico",
    "clorídricas": "clorídrico",
    "clorídricos": "clorídrico",
    "clorótica": "clorótico",
    "cloróticas": "clorótico",
    "cloróticos": "clorótico",
    "clubes": "clube",
    "clubistas": "clubista",
    "clubística": "clubístico",
    "clubísticas": "clubístico",
    "clubísticos": "clubístico",
    "clupeias": "clupeia",
    "clupeidas": "clupeida",
    "clupeídea": "clupeídeo",
    "clupeídeas": "clupeídeo",
    "clupeídeos": "clupeídeo",
    "clusiácea": "clusiáceo",
    "clusiáceas": "clusiáceo",
    "clusiáceos": "clusiáceo",
    "clássica": "clássico",
    "clássicas": "clássico",
    "clássicos": "clássico",
    "clástases": "clástase",
    "clástica": "clástico",
    "clásticas": "clástico",
    "clásticos": "clástico",
    "cláusulas": "cláusula",
    "cláxones": "cláxon",
    "cláxons": "cláxon",
    "clâmides": "clâmide",
    "clãs": "clã",
    "clérigos": "clérigo",
    "clínica": "clínico",
    "clínicas": "clínico",
    "clínicos": "clínico",
    "clíticos": "clítico",
    "clórica": "clórico",
    "clóricas": "clórico",
    "clóricos": "clórico",
    "cnemalgias": "cnemalgia",
    "cnemálgica": "cnemálgico",
    "cnemálgicas": "cnemálgico",
    "cnemálgicos": "cnemálgico",
    "cnidoblástica": "cnidoblástico",
    "cnidoblásticas": "cnidoblástico",
    "cnidoblásticos": "cnidoblástico",
    "cnidocilíaca": "cnidocilíaco",
    "cnidocilíacas": "cnidocilíaco",
    "cnidocilíacos": "cnidocilíaco",
    "cnidocílios": "cnidocílio",
    "cnidoplastos": "cnidoplasto",
    "cnidoses": "cnidose",
    "cnidária": "cnidário",
    "cnidárias": "cnidário",
    "cnidários": "cnidário",
    "cnidótica": "cnidótico",
    "cnidóticas": "cnidótico",
    "cnidóticos": "cnidótico",
    "cnémides": "cnémide",
    "coabita": "coabitar",
    "coabitada": "coabitar",
    "coabitadas": "coabitar",
    "coabitado": "coabitar",
    "coabitadora": "coabitador",
    "coabitadoras": "coabitador",
    "coabitadores": "coabitador",
    "coabitados": "coabitar",
    "coabitai": "coabitar",
    "coabitais": "coabitar",
    "coabitam": "coabitar",
    "coabitamo": "coabitar",
    "coabitamos": "coabitar",
    "coabitando": "coabitar",
    "coabitantes": "coabitante",
    "coabitara": "coabitar",
    "coabitaram": "coabitar",
    "coabitaras": "coabitar",
    "coabitardes": "coabitar",
    "coabitarei": "coabitar",
    "coabitareis": "coabitar",
    "coabitarem": "coabitar",
    "coabitaremos": "coabitar",
    "coabitares": "coabitar",
    "coabitaria": "coabitar",
    "coabitariam": "coabitar",
    "coabitarias": "coabitar",
    "coabitarmo": "coabitar",
    "coabitarmos": "coabitar",
    "coabitará": "coabitar",
    "coabitarás": "coabitar",
    "coabitarão": "coabitar",
    "coabitaríamos": "coabitar",
    "coabitaríeis": "coabitar",
    "coabitas": "coabitar",
    "coabitasse": "coabitar",
    "coabitassem": "coabitar",
    "coabitasses": "coabitar",
    "coabitaste": "coabitar",
    "coabitastes": "coabitar",
    "coabitava": "coabitar",
    "coabitavam": "coabitar",
    "coabitavas": "coabitar",
    "coabitações": "coabitação",
    "coabite": "coabitar",
    "coabitei": "coabitar",
    "coabiteis": "coabitar",
    "coabitem": "coabitar",
    "coabitemo": "coabitar",
    "coabitemos": "coabitar",
    "coabites": "coabitar",
    "coabito": "coabitar",
    "coabitou": "coabitar",
    "coabitámo": "coabitar",
    "coabitámos": "coabitar",
    "coabitáramo": "coabitar",
    "coabitáramos": "coabitar",
    "coabitáreis": "coabitar",
    "coabitásseis": "coabitar",
    "coabitássemos": "coabitar",
    "coabitávamo": "coabitar",
    "coabitávamos": "coabitar",
    "coabitáveis": "coabitar",
    "coacervações": "coacervação",
    "coacta": "coacto",
    "coactada": "coactar",
    "coactadas": "coactar",
    "coactado": "coactar",
    "coactados": "coactar",
    "coactai": "coactar",
    "coactais": "coactar",
    "coactam": "coactar",
    "coactamo": "coactar",
    "coactamos": "coactar",
    "coactando": "coactar",
    "coactara": "coactar",
    "coactaram": "coactar",
    "coactaras": "coactar",
    "coactarde": "coactar",
    "coactardes": "coactar",
    "coactare": "coactar",
    "coactarei": "coactar",
    "coactareis": "coactar",
    "coactarem": "coactar",
    "coactaremos": "coactar",
    "coactares": "coactar",
    "coactaria": "coactar",
    "coactariam": "coactar",
    "coactarias": "coactar",
    "coactarmo": "coactar",
    "coactarmos": "coactar",
    "coactará": "coactar",
    "coactarás": "coactar",
    "coactarão": "coactar",
    "coactaríamos": "coactar",
    "coactaríeis": "coactar",
    "coactas": "coacto",
    "coactasse": "coactar",
    "coactassem": "coactar",
    "coactasses": "coactar",
    "coactaste": "coactar",
    "coactastes": "coactar",
    "coactava": "coactar",
    "coactavam": "coactar",
    "coactavas": "coactar",
    "coacte": "coactar",
    "coactei": "coactar",
    "coacteis": "coactar",
    "coactem": "coactar",
    "coactemo": "coactar",
    "coactemos": "coactar",
    "coactes": "coactar",
    "coactiva": "coactivo",
    "coactivas": "coactivo",
    "coactivos": "coactivo",
    "coacto": "coactar",
    "coactora": "coactor",
    "coactoras": "coactor",
    "coactores": "coactor",
    "coactos": "coacto",
    "coactou": "coactar",
    "coactá": "coactar",
    "coactámo": "coactar",
    "coactámos": "coactar",
    "coactáramo": "coactar",
    "coactáramos": "coactar",
    "coactárei": "coactar",
    "coactáreis": "coactar",
    "coactásseis": "coactar",
    "coactássemos": "coactar",
    "coactávamo": "coactar",
    "coactávamos": "coactar",
    "coactávei": "coactar",
    "coactáveis": "coactar",
    "coacções": "coacção",
    "coada": "coar",
    "coadapta": "coadaptar",
    "coadaptada": "coadaptar",
    "coadaptadas": "coadaptar",
    "coadaptado": "coadaptar",
    "coadaptadora": "coadaptador",
    "coadaptadoras": "coadaptador",
    "coadaptadores": "coadaptador",
    "coadaptados": "coadaptar",
    "coadaptai": "coadaptar",
    "coadaptais": "coadaptar",
    "coadaptam": "coadaptar",
    "coadaptamo": "coadaptar",
    "coadaptamos": "coadaptar",
    "coadaptando": "coadaptar",
    "coadaptara": "coadaptar",
    "coadaptaram": "coadaptar",
    "coadaptaras": "coadaptar",
    "coadaptarde": "coadaptar",
    "coadaptardes": "coadaptar",
    "coadaptare": "coadaptar",
    "coadaptarei": "coadaptar",
    "coadaptareis": "coadaptar",
    "coadaptarem": "coadaptar",
    "coadaptaremos": "coadaptar",
    "coadaptares": "coadaptar",
    "coadaptaria": "coadaptar",
    "coadaptariam": "coadaptar",
    "coadaptarias": "coadaptar",
    "coadaptarmo": "coadaptar",
    "coadaptarmos": "coadaptar",
    "coadaptará": "coadaptar",
    "coadaptarás": "coadaptar",
    "coadaptarão": "coadaptar",
    "coadaptaríamos": "coadaptar",
    "coadaptaríeis": "coadaptar",
    "coadaptas": "coadaptar",
    "coadaptasse": "coadaptar",
    "coadaptassem": "coadaptar",
    "coadaptasses": "coadaptar",
    "coadaptaste": "coadaptar",
    "coadaptastes": "coadaptar",
    "coadaptava": "coadaptar",
    "coadaptavam": "coadaptar",
    "coadaptavas": "coadaptar",
    "coadapte": "coadaptar",
    "coadaptei": "coadaptar",
    "coadapteis": "coadaptar",
    "coadaptem": "coadaptar",
    "coadaptemo": "coadaptar",
    "coadaptemos": "coadaptar",
    "coadaptes": "coadaptar",
    "coadapto": "coadaptar",
    "coadaptou": "coadaptar",
    "coadaptá": "coadaptar",
    "coadaptámo": "coadaptar",
    "coadaptámos": "coadaptar",
    "coadaptáramo": "coadaptar",
    "coadaptáramos": "coadaptar",
    "coadaptárei": "coadaptar",
    "coadaptáreis": "coadaptar",
    "coadaptásseis": "coadaptar",
    "coadaptássemos": "coadaptar",
    "coadaptávamo": "coadaptar",
    "coadaptávamos": "coadaptar",
    "coadaptávei": "coadaptar",
    "coadaptáveis": "coadaptar",
    "coadas": "coar",
    "coadjutora": "coadjutor",
    "coadjutoras": "coadjutor",
    "coadjutores": "coadjutor",
    "coadjutorias": "coadjutoria",
    "coadjuva": "coadjuvar",
    "coadjuvada": "coadjuvar",
    "coadjuvadas": "coadjuvar",
    "coadjuvado": "coadjuvar",
    "coadjuvadora": "coadjuvador",
    "coadjuvadoras": "coadjuvador",
    "coadjuvadores": "coadjuvador",
    "coadjuvados": "coadjuvar",
    "coadjuvai": "coadjuvar",
    "coadjuvais": "coadjuvar",
    "coadjuvam": "coadjuvar",
    "coadjuvamo": "coadjuvar",
    "coadjuvamos": "coadjuvar",
    "coadjuvando": "coadjuvar",
    "coadjuvantes": "coadjuvante",
    "coadjuvara": "coadjuvar",
    "coadjuvaram": "coadjuvar",
    "coadjuvaras": "coadjuvar",
    "coadjuvarde": "coadjuvar",
    "coadjuvardes": "coadjuvar",
    "coadjuvare": "coadjuvar",
    "coadjuvarei": "coadjuvar",
    "coadjuvareis": "coadjuvar",
    "coadjuvarem": "coadjuvar",
    "coadjuvaremos": "coadjuvar",
    "coadjuvares": "coadjuvar",
    "coadjuvaria": "coadjuvar",
    "coadjuvariam": "coadjuvar",
    "coadjuvarias": "coadjuvar",
    "coadjuvarmo": "coadjuvar",
    "coadjuvarmos": "coadjuvar",
    "coadjuvará": "coadjuvar",
    "coadjuvarás": "coadjuvar",
    "coadjuvarão": "coadjuvar",
    "coadjuvaríamos": "coadjuvar",
    "coadjuvaríeis": "coadjuvar",
    "coadjuvas": "coadjuvar",
    "coadjuvasse": "coadjuvar",
    "coadjuvassem": "coadjuvar",
    "coadjuvasses": "coadjuvar",
    "coadjuvaste": "coadjuvar",
    "coadjuvastes": "coadjuvar",
    "coadjuvava": "coadjuvar",
    "coadjuvavam": "coadjuvar",
    "coadjuvavas": "coadjuvar",
    "coadjuvações": "coadjuvação",
    "coadjuve": "coadjuvar",
    "coadjuvei": "coadjuvar",
    "coadjuveis": "coadjuvar",
    "coadjuvem": "coadjuvar",
    "coadjuvemo": "coadjuvar",
    "coadjuvemos": "coadjuvar",
    "coadjuves": "coadjuvar",
    "coadjuvo": "coadjuvar",
    "coadjuvou": "coadjuvar",
    "coadjuvá": "coadjuvar",
    "coadjuvámo": "coadjuvar",
    "coadjuvámos": "coadjuvar",
    "coadjuváramo": "coadjuvar",
    "coadjuváramos": "coadjuvar",
    "coadjuvárei": "coadjuvar",
    "coadjuváreis": "coadjuvar",
    "coadjuvásseis": "coadjuvar",
    "coadjuvássemos": "coadjuvar",
    "coadjuvávamo": "coadjuvar",
    "coadjuvávamos": "coadjuvar",
    "coadjuvávei": "coadjuvar",
    "coadjuváveis": "coadjuvar",
    "coado": "coar",
    "coadoiros": "coadoiro",
    "coadora": "coador",
    "coadoras": "coador",
    "coadores": "coador",
    "coados": "coar",
    "coadouros": "coadouro",
    "coadquira": "coadquirir",
    "coadquirais": "coadquirir",
    "coadquiram": "coadquirir",
    "coadquiramo": "coadquirir",
    "coadquiramos": "coadquirir",
    "coadquiras": "coadquirir",
    "coadquire": "coadquirir",
    "coadquirem": "coadquirir",
    "coadquirentes": "coadquirente",
    "coadquires": "coadquirir",
    "coadquiri": "coadquirir",
    "coadquiria": "coadquirir",
    "coadquiriam": "coadquirir",
    "coadquirias": "coadquirir",
    "coadquirida": "coadquirir",
    "coadquiridas": "coadquirir",
    "coadquirido": "coadquirir",
    "coadquiridos": "coadquirir",
    "coadquirimo": "coadquirir",
    "coadquirimos": "coadquirir",
    "coadquirindo": "coadquirir",
    "coadquirira": "coadquirir",
    "coadquiriram": "coadquirir",
    "coadquiriras": "coadquirir",
    "coadquirirde": "coadquirir",
    "coadquirirdes": "coadquirir",
    "coadquirire": "coadquirir",
    "coadquirirei": "coadquirir",
    "coadquirireis": "coadquirir",
    "coadquirirem": "coadquirir",
    "coadquiriremos": "coadquirir",
    "coadquirires": "coadquirir",
    "coadquiriria": "coadquirir",
    "coadquiririam": "coadquirir",
    "coadquiririas": "coadquirir",
    "coadquirirmo": "coadquirir",
    "coadquirirmos": "coadquirir",
    "coadquirirá": "coadquirir",
    "coadquirirás": "coadquirir",
    "coadquirirão": "coadquirir",
    "coadquiriríamos": "coadquirir",
    "coadquiriríeis": "coadquirir",
    "coadquiris": "coadquirir",
    "coadquirisse": "coadquirir",
    "coadquirissem": "coadquirir",
    "coadquirisses": "coadquirir",
    "coadquiriste": "coadquirir",
    "coadquiristes": "coadquirir",
    "coadquiriu": "coadquirir",
    "coadquirições": "coadquirição",
    "coadquiro": "coadquirir",
    "coadquiríamo": "coadquirir",
    "coadquiríamos": "coadquirir",
    "coadquiríei": "coadquirir",
    "coadquiríeis": "coadquirir",
    "coadquiríramo": "coadquirir",
    "coadquiríramos": "coadquirir",
    "coadquirírei": "coadquirir",
    "coadquiríreis": "coadquirir",
    "coadquirísseis": "coadquirir",
    "coadquiríssemos": "coadquirir",
    "coaduna": "coadunar",
    "coadunabilidades": "coadunabilidade",
    "coadunada": "coadunar",
    "coadunadas": "coadunar",
    "coadunado": "coadunar",
    "coadunados": "coadunar",
    "coadunai": "coadunar",
    "coadunais": "coadunar",
    "coadunam": "coadunar",
    "coadunamo": "coadunar",
    "coadunamos": "coadunar",
    "coadunando": "coadunar",
    "coadunara": "coadunar",
    "coadunaram": "coadunar",
    "coadunaras": "coadunar",
    "coadunarde": "coadunar",
    "coadunardes": "coadunar",
    "coadunare": "coadunar",
    "coadunarei": "coadunar",
    "coadunareis": "coadunar",
    "coadunarem": "coadunar",
    "coadunaremos": "coadunar",
    "coadunares": "coadunar",
    "coadunaria": "coadunar",
    "coadunariam": "coadunar",
    "coadunarias": "coadunar",
    "coadunarmo": "coadunar",
    "coadunarmos": "coadunar",
    "coadunará": "coadunar",
    "coadunarás": "coadunar",
    "coadunarão": "coadunar",
    "coadunaríamos": "coadunar",
    "coadunaríeis": "coadunar",
    "coadunas": "coadunar",
    "coadunasse": "coadunar",
    "coadunassem": "coadunar",
    "coadunasses": "coadunar",
    "coadunaste": "coadunar",
    "coadunastes": "coadunar",
    "coadunava": "coadunar",
    "coadunavam": "coadunar",
    "coadunavas": "coadunar",
    "coadunações": "coadunação",
    "coadune": "coadunar",
    "coadunei": "coadunar",
    "coaduneis": "coadunar",
    "coadunem": "coadunar",
    "coadunemo": "coadunar",
    "coadunemos": "coadunar",
    "coadunes": "coadunar",
    "coaduno": "coadunar",
    "coadunou": "coadunar",
    "coaduná": "coadunar",
    "coadunámo": "coadunar",
    "coadunámos": "coadunar",
    "coadunáramo": "coadunar",
    "coadunáramos": "coadunar",
    "coadunárei": "coadunar",
    "coadunáreis": "coadunar",
    "coadunásseis": "coadunar",
    "coadunássemos": "coadunar",
    "coadunávamo": "coadunar",
    "coadunávamos": "coadunar",
    "coadunávei": "coadunar",
    "coadunáveis": "coadunável",
    "coaduras": "coadura",
    "coage": "coagir",
    "coagem": "coagir",
    "coages": "coagir",
    "coagi": "coagir",
    "coagia": "coagir",
    "coagiam": "coagir",
    "coagias": "coagir",
    "coagida": "coagir",
    "coagidas": "coagir",
    "coagido": "coagir",
    "coagidos": "coagir",
    "coagimo": "coagir",
    "coagimos": "coagir",
    "coagindo": "coagir",
    "coagira": "coagir",
    "coagiram": "coagir",
    "coagiras": "coagir",
    "coagirde": "coagir",
    "coagirdes": "coagir",
    "coagire": "coagir",
    "coagirei": "coagir",
    "coagireis": "coagir",
    "coagirem": "coagir",
    "coagiremos": "coagir",
    "coagires": "coagir",
    "coagiria": "coagir",
    "coagiriam": "coagir",
    "coagirias": "coagir",
    "coagirmo": "coagir",
    "coagirmos": "coagir",
    "coagirá": "coagir",
    "coagirás": "coagir",
    "coagirão": "coagir",
    "coagiríamos": "coagir",
    "coagiríeis": "coagir",
    "coagis": "coagir",
    "coagisse": "coagir",
    "coagissem": "coagir",
    "coagisses": "coagir",
    "coagiste": "coagir",
    "coagistes": "coagir",
    "coagiu": "coagir",
    "coagmenta": "coagmentar",
    "coagmentada": "coagmentar",
    "coagmentadas": "coagmentar",
    "coagmentado": "coagmentar",
    "coagmentados": "coagmentar",
    "coagmentai": "coagmentar",
    "coagmentais": "coagmentar",
    "coagmentam": "coagmentar",
    "coagmentamo": "coagmentar",
    "coagmentamos": "coagmentar",
    "coagmentando": "coagmentar",
    "coagmentara": "coagmentar",
    "coagmentaram": "coagmentar",
    "coagmentaras": "coagmentar",
    "coagmentarde": "coagmentar",
    "coagmentardes": "coagmentar",
    "coagmentare": "coagmentar",
    "coagmentarei": "coagmentar",
    "coagmentareis": "coagmentar",
    "coagmentarem": "coagmentar",
    "coagmentaremos": "coagmentar",
    "coagmentares": "coagmentar",
    "coagmentaria": "coagmentar",
    "coagmentariam": "coagmentar",
    "coagmentarias": "coagmentar",
    "coagmentarmo": "coagmentar",
    "coagmentarmos": "coagmentar",
    "coagmentará": "coagmentar",
    "coagmentarás": "coagmentar",
    "coagmentarão": "coagmentar",
    "coagmentaríamos": "coagmentar",
    "coagmentaríeis": "coagmentar",
    "coagmentas": "coagmentar",
    "coagmentasse": "coagmentar",
    "coagmentassem": "coagmentar",
    "coagmentasses": "coagmentar",
    "coagmentaste": "coagmentar",
    "coagmentastes": "coagmentar",
    "coagmentava": "coagmentar",
    "coagmentavam": "coagmentar",
    "coagmentavas": "coagmentar",
    "coagmentações": "coagmentação",
    "coagmente": "coagmentar",
    "coagmentei": "coagmentar",
    "coagmenteis": "coagmentar",
    "coagmentem": "coagmentar",
    "coagmentemo": "coagmentar",
    "coagmentemos": "coagmentar",
    "coagmentes": "coagmentar",
    "coagmento": "coagmentar",
    "coagmentou": "coagmentar",
    "coagmentá": "coagmentar",
    "coagmentámo": "coagmentar",
    "coagmentámos": "coagmentar",
    "coagmentáramo": "coagmentar",
    "coagmentáramos": "coagmentar",
    "coagmentárei": "coagmentar",
    "coagmentáreis": "coagmentar",
    "coagmentásseis": "coagmentar",
    "coagmentássemos": "coagmentar",
    "coagmentávamo": "coagmentar",
    "coagmentávamos": "coagmentar",
    "coagmentávei": "coagmentar",
    "coagmentáveis": "coagmentar",
    "coagula": "coagular",
    "coagulabilidades": "coagulabilidade",
    "coagulada": "coagular",
    "coaguladas": "coagular",
    "coagulado": "coagular",
    "coaguladora": "coagulador",
    "coaguladoras": "coagulador",
    "coaguladores": "coagulador",
    "coagulados": "coagular",
    "coagulai": "coagular",
    "coagulais": "coagular",
    "coagulam": "coagular",
    "coagulamo": "coagular",
    "coagulamos": "coagular",
    "coagulando": "coagular",
    "coagulantes": "coagulante",
    "coagulara": "coagular",
    "coagularam": "coagular",
    "coagularas": "coagular",
    "coagularde": "coagular",
    "coagulardes": "coagular",
    "coagulare": "coagular",
    "coagularei": "coagular",
    "coagulareis": "coagular",
    "coagularem": "coagular",
    "coagularemos": "coagular",
    "coagulares": "coagular",
    "coagularia": "coagular",
    "coagulariam": "coagular",
    "coagularias": "coagular",
    "coagularmo": "coagular",
    "coagularmos": "coagular",
    "coagulará": "coagular",
    "coagularás": "coagular",
    "coagularão": "coagular",
    "coagularíamos": "coagular",
    "coagularíeis": "coagular",
    "coagulas": "coagular",
    "coagulasse": "coagular",
    "coagulassem": "coagular",
    "coagulasses": "coagular",
    "coagulaste": "coagular",
    "coagulastes": "coagular",
    "coagulava": "coagular",
    "coagulavam": "coagular",
    "coagulavas": "coagular",
    "coagulações": "coagulação",
    "coagule": "coagular",
    "coagulei": "coagular",
    "coaguleis": "coagular",
    "coagulem": "coagular",
    "coagulemo": "coagular",
    "coagulemos": "coagular",
    "coagules": "coagular",
    "coagulo": "coagular",
    "coagulou": "coagular",
    "coagulá": "coagular",
    "coagulámo": "coagular",
    "coagulámos": "coagular",
    "coaguláramo": "coagular",
    "coaguláramos": "coagular",
    "coagulárei": "coagular",
    "coaguláreis": "coagular",
    "coagulásseis": "coagular",
    "coagulássemos": "coagular",
    "coagulávamo": "coagular",
    "coagulávamos": "coagular",
    "coagulávei": "coagular",
    "coaguláveis": "coagulável",
    "coagíamo": "coagir",
    "coagíamos": "coagir",
    "coagíei": "coagir",
    "coagíeis": "coagir",
    "coagíramo": "coagir",
    "coagíramos": "coagir",
    "coagírei": "coagir",
    "coagíreis": "coagir",
    "coagísseis": "coagir",
    "coagíssemos": "coagir",
    "coai": "coar",
    "coais": "coar",
    "coaja": "coagir",
    "coajais": "coagir",
    "coajam": "coagir",
    "coajamo": "coagir",
    "coajamos": "coagir",
    "coajas": "coagir",
    "coajo": "coagir",
    "coalas": "coala",
    "coalesce": "coalescer",
    "coalescei": "coalescer",
    "coalesceis": "coalescer",
    "coalescem": "coalescer",
    "coalescemo": "coalescer",
    "coalescemos": "coalescer",
    "coalescendo": "coalescer",
    "coalescentes": "coalescente",
    "coalescera": "coalescer",
    "coalesceram": "coalescer",
    "coalesceras": "coalescer",
    "coalescerde": "coalescer",
    "coalescerdes": "coalescer",
    "coalescere": "coalescer",
    "coalescerei": "coalescer",
    "coalescereis": "coalescer",
    "coalescerem": "coalescer",
    "coalesceremos": "coalescer",
    "coalesceres": "coalescer",
    "coalesceria": "coalescer",
    "coalesceriam": "coalescer",
    "coalescerias": "coalescer",
    "coalescermo": "coalescer",
    "coalescermos": "coalescer",
    "coalescerá": "coalescer",
    "coalescerás": "coalescer",
    "coalescerão": "coalescer",
    "coalesceríamos": "coalescer",
    "coalesceríeis": "coalescer",
    "coalesces": "coalescer",
    "coalescesse": "coalescer",
    "coalescessem": "coalescer",
    "coalescesses": "coalescer",
    "coalesceste": "coalescer",
    "coalescestes": "coalescer",
    "coalesceu": "coalescer",
    "coalesci": "coalescer",
    "coalescia": "coalescer",
    "coalesciam": "coalescer",
    "coalescias": "coalescer",
    "coalescida": "coalescer",
    "coalescidas": "coalescer",
    "coalescido": "coalescer",
    "coalescidos": "coalescer",
    "coalescê": "coalescer",
    "coalescências": "coalescência",
    "coalescêramo": "coalescer",
    "coalescêramos": "coalescer",
    "coalescêrei": "coalescer",
    "coalescêreis": "coalescer",
    "coalescêsseis": "coalescer",
    "coalescêssemos": "coalescer",
    "coalescíamo": "coalescer",
    "coalescíamos": "coalescer",
    "coalescíei": "coalescer",
    "coalescíeis": "coalescer",
    "coalesça": "coalescer",
    "coalesçais": "coalescer",
    "coalesçam": "coalescer",
    "coalesçamo": "coalescer",
    "coalesçamos": "coalescer",
    "coalesças": "coalescer",
    "coalesço": "coalescer",
    "coalha": "coalhar",
    "coalhada": "coalhar",
    "coalhadas": "coalhar",
    "coalhado": "coalhar",
    "coalhadoiros": "coalhadoiro",
    "coalhados": "coalhar",
    "coalhadouros": "coalhadouro",
    "coalhaduras": "coalhadura",
    "coalhai": "coalhar",
    "coalhais": "coalhar",
    "coalham": "coalhar",
    "coalhamentos": "coalhamento",
    "coalhamo": "coalhar",
    "coalhamos": "coalhar",
    "coalhando": "coalhar",
    "coalhara": "coalhar",
    "coalharam": "coalhar",
    "coalharas": "coalhar",
    "coalharde": "coalhar",
    "coalhardes": "coalhar",
    "coalhare": "coalhar",
    "coalharei": "coalhar",
    "coalhareis": "coalhar",
    "coalharem": "coalhar",
    "coalharemos": "coalhar",
    "coalhares": "coalhar",
    "coalharia": "coalhar",
    "coalhariam": "coalhar",
    "coalharias": "coalhar",
    "coalharmo": "coalhar",
    "coalharmos": "coalhar",
    "coalhará": "coalhar",
    "coalharás": "coalhar",
    "coalharão": "coalhar",
    "coalharíamos": "coalhar",
    "coalharíeis": "coalhar",
    "coalhas": "coalhar",
    "coalhasse": "coalhar",
    "coalhassem": "coalhar",
    "coalhasses": "coalhar",
    "coalhaste": "coalhar",
    "coalhastes": "coalhar",
    "coalhava": "coalhar",
    "coalhavam": "coalhar",
    "coalhavas": "coalhar",
    "coalhe": "coalhar",
    "coalhei": "coalhar",
    "coalheiras": "coalheira",
    "coalheis": "coalhar",
    "coalhem": "coalhar",
    "coalhemo": "coalhar",
    "coalhemos": "coalhar",
    "coalhes": "coalhar",
    "coalho": "coalhar",
    "coalhos": "coalho",
    "coalhou": "coalhar",
    "coalhá": "coalhar",
    "coalhámo": "coalhar",
    "coalhámos": "coalhar",
    "coalháramo": "coalhar",
    "coalháramos": "coalhar",
    "coalhárei": "coalhar",
    "coalháreis": "coalhar",
    "coalhásseis": "coalhar",
    "coalhássemos": "coalhar",
    "coalhávamo": "coalhar",
    "coalhávamos": "coalhar",
    "coalhávei": "coalhar",
    "coalháveis": "coalhar",
    "coaliza": "coalizar",
    "coalizada": "coalizar",
    "coalizadas": "coalizar",
    "coalizado": "coalizar",
    "coalizados": "coalizar",
    "coalizai": "coalizar",
    "coalizais": "coalizar",
    "coalizam": "coalizar",
    "coalizamo": "coalizar",
    "coalizamos": "coalizar",
    "coalizando": "coalizar",
    "coalizara": "coalizar",
    "coalizaram": "coalizar",
    "coalizaras": "coalizar",
    "coalizarde": "coalizar",
    "coalizardes": "coalizar",
    "coalizare": "coalizar",
    "coalizarei": "coalizar",
    "coalizareis": "coalizar",
    "coalizarem": "coalizar",
    "coalizaremos": "coalizar",
    "coalizares": "coalizar",
    "coalizaria": "coalizar",
    "coalizariam": "coalizar",
    "coalizarias": "coalizar",
    "coalizarmo": "coalizar",
    "coalizarmos": "coalizar",
    "coalizará": "coalizar",
    "coalizarás": "coalizar",
    "coalizarão": "coalizar",
    "coalizaríamos": "coalizar",
    "coalizaríeis": "coalizar",
    "coalizas": "coalizar",
    "coalizasse": "coalizar",
    "coalizassem": "coalizar",
    "coalizasses": "coalizar",
    "coalizaste": "coalizar",
    "coalizastes": "coalizar",
    "coalizava": "coalizar",
    "coalizavam": "coalizar",
    "coalizavas": "coalizar",
    "coalizações": "coalização",
    "coalize": "coalizar",
    "coalizei": "coalizar",
    "coalizeis": "coalizar",
    "coalizem": "coalizar",
    "coalizemo": "coalizar",
    "coalizemos": "coalizar",
    "coalizes": "coalizar",
    "coalizo": "coalizar",
    "coalizou": "coalizar",
    "coalizá": "coalizar",
    "coalizámo": "coalizar",
    "coalizámos": "coalizar",
    "coalizáramo": "coalizar",
    "coalizáramos": "coalizar",
    "coalizárei": "coalizar",
    "coalizáreis": "coalizar",
    "coalizásseis": "coalizar",
    "coalizássemos": "coalizar",
    "coalizávamo": "coalizar",
    "coalizávamos": "coalizar",
    "coalizávei": "coalizar",
    "coalizáveis": "coalizar",
    "coam": "coar",
    "coamo": "coar",
    "coamos": "coar",
    "coando": "coar",
    "coandús": "coandú",
    "coanha": "coanhar",
    "coanhada": "coanhar",
    "coanhadas": "coanhar",
    "coanhado": "coanhar",
    "coanhados": "coanhar",
    "coanhai": "coanhar",
    "coanhais": "coanhar",
    "coanham": "coanhar",
    "coanhamo": "coanhar",
    "coanhamos": "coanhar",
    "coanhando": "coanhar",
    "coanhara": "coanhar",
    "coanharam": "coanhar",
    "coanharas": "coanhar",
    "coanharde": "coanhar",
    "coanhardes": "coanhar",
    "coanhare": "coanhar",
    "coanharei": "coanhar",
    "coanhareis": "coanhar",
    "coanharem": "coanhar",
    "coanharemos": "coanhar",
    "coanhares": "coanhar",
    "coanharia": "coanhar",
    "coanhariam": "coanhar",
    "coanharias": "coanhar",
    "coanharmo": "coanhar",
    "coanharmos": "coanhar",
    "coanhará": "coanhar",
    "coanharás": "coanhar",
    "coanharão": "coanhar",
    "coanharíamos": "coanhar",
    "coanharíeis": "coanhar",
    "coanhas": "coanhar",
    "coanhasse": "coanhar",
    "coanhassem": "coanhar",
    "coanhasses": "coanhar",
    "coanhaste": "coanhar",
    "coanhastes": "coanhar",
    "coanhava": "coanhar",
    "coanhavam": "coanhar",
    "coanhavas": "coanhar",
    "coanhe": "coanhar",
    "coanhei": "coanhar",
    "coanheis": "coanhar",
    "coanhem": "coanhar",
    "coanhemo": "coanhar",
    "coanhemos": "coanhar",
    "coanhes": "coanhar",
    "coanho": "coanhar",
    "coanhos": "coanho",
    "coanhou": "coanhar",
    "coanhá": "coanhar",
    "coanhámo": "coanhar",
    "coanhámos": "coanhar",
    "coanháramo": "coanhar",
    "coanháramos": "coanhar",
    "coanhárei": "coanhar",
    "coanháreis": "coanhar",
    "coanhásseis": "coanhar",
    "coanhássemos": "coanhar",
    "coanhávamo": "coanhar",
    "coanhávamos": "coanhar",
    "coanhávei": "coanhar",
    "coanháveis": "coanhar",
    "coapta": "coaptar",
    "coaptada": "coaptar",
    "coaptadas": "coaptar",
    "coaptado": "coaptar",
    "coaptados": "coaptar",
    "coaptai": "coaptar",
    "coaptais": "coaptar",
    "coaptam": "coaptar",
    "coaptamo": "coaptar",
    "coaptamos": "coaptar",
    "coaptando": "coaptar",
    "coaptara": "coaptar",
    "coaptaram": "coaptar",
    "coaptaras": "coaptar",
    "coaptarde": "coaptar",
    "coaptardes": "coaptar",
    "coaptare": "coaptar",
    "coaptarei": "coaptar",
    "coaptareis": "coaptar",
    "coaptarem": "coaptar",
    "coaptaremos": "coaptar",
    "coaptares": "coaptar",
    "coaptaria": "coaptar",
    "coaptariam": "coaptar",
    "coaptarias": "coaptar",
    "coaptarmo": "coaptar",
    "coaptarmos": "coaptar",
    "coaptará": "coaptar",
    "coaptarás": "coaptar",
    "coaptarão": "coaptar",
    "coaptaríamos": "coaptar",
    "coaptaríeis": "coaptar",
    "coaptas": "coaptar",
    "coaptasse": "coaptar",
    "coaptassem": "coaptar",
    "coaptasses": "coaptar",
    "coaptaste": "coaptar",
    "coaptastes": "coaptar",
    "coaptava": "coaptar",
    "coaptavam": "coaptar",
    "coaptavas": "coaptar",
    "coaptações": "coaptação",
    "coapte": "coaptar",
    "coaptei": "coaptar",
    "coapteis": "coaptar",
    "coaptem": "coaptar",
    "coaptemo": "coaptar",
    "coaptemos": "coaptar",
    "coaptes": "coaptar",
    "coaptidões": "coaptidão",
    "coapto": "coaptar",
    "coaptou": "coaptar",
    "coaptá": "coaptar",
    "coaptámo": "coaptar",
    "coaptámos": "coaptar",
    "coaptáramo": "coaptar",
    "coaptáramos": "coaptar",
    "coaptárei": "coaptar",
    "coaptáreis": "coaptar",
    "coaptásseis": "coaptar",
    "coaptássemos": "coaptar",
    "coaptávamo": "coaptar",
    "coaptávamos": "coaptar",
    "coaptávei": "coaptar",
    "coaptáveis": "coaptar",
    "coaquisições": "coaquisição",
    "coara": "coar",
    "coaram": "coar",
    "coaras": "coar",
    "coarcta": "coarctar",
    "coarctada": "coarctar",
    "coarctadas": "coarctar",
    "coarctado": "coarctar",
    "coarctados": "coarctar",
    "coarctai": "coarctar",
    "coarctais": "coarctar",
    "coarctam": "coarctar",
    "coarctamo": "coarctar",
    "coarctamos": "coarctar",
    "coarctando": "coarctar",
    "coarctara": "coarctar",
    "coarctaram": "coarctar",
    "coarctaras": "coarctar",
    "coarctarde": "coarctar",
    "coarctardes": "coarctar",
    "coarctare": "coarctar",
    "coarctarei": "coarctar",
    "coarctareis": "coarctar",
    "coarctarem": "coarctar",
    "coarctaremos": "coarctar",
    "coarctares": "coarctar",
    "coarctaria": "coarctar",
    "coarctariam": "coarctar",
    "coarctarias": "coarctar",
    "coarctarmo": "coarctar",
    "coarctarmos": "coarctar",
    "coarctará": "coarctar",
    "coarctarás": "coarctar",
    "coarctarão": "coarctar",
    "coarctaríamos": "coarctar",
    "coarctaríeis": "coarctar",
    "coarctas": "coarctar",
    "coarctasse": "coarctar",
    "coarctassem": "coarctar",
    "coarctasses": "coarctar",
    "coarctaste": "coarctar",
    "coarctastes": "coarctar",
    "coarctava": "coarctar",
    "coarctavam": "coarctar",
    "coarctavas": "coarctar",
    "coarctações": "coarctação",
    "coarcte": "coarctar",
    "coarctei": "coarctar",
    "coarcteis": "coarctar",
    "coarctem": "coarctar",
    "coarctemo": "coarctar",
    "coarctemos": "coarctar",
    "coarctes": "coarctar",
    "coarcto": "coarctar",
    "coarctou": "coarctar",
    "coarctá": "coarctar",
    "coarctámo": "coarctar",
    "coarctámos": "coarctar",
    "coarctáramo": "coarctar",
    "coarctáramos": "coarctar",
    "coarctárei": "coarctar",
    "coarctáreis": "coarctar",
    "coarctásseis": "coarctar",
    "coarctássemos": "coarctar",
    "coarctávamo": "coarctar",
    "coarctávamos": "coarctar",
    "coarctávei": "coarctar",
    "coarctáveis": "coarctar",
    "coarde": "coar",
    "coardes": "coar",
    "coare": "coar",
    "coarei": "coar",
    "coareis": "coar",
    "coarem": "coar",
    "coaremos": "coar",
    "coares": "coar",
    "coaria": "coar",
    "coariam": "coar",
    "coarias": "coar",
    "coarmo": "coar",
    "coarmos": "coar",
    "coartada": "coartado",
    "coartadas": "coartado",
    "coartados": "coartado",
    "coará": "coar",
    "coarás": "coar",
    "coarão": "coar",
    "coaríamos": "coar",
    "coaríeis": "coar",
    "coasse": "coar",
    "coassem": "coar",
    "coasses": "coar",
    "coaste": "coar",
    "coastes": "coar",
    "coatis": "coati",
    "coatás": "coatá",
    "coava": "coar",
    "coavam": "coar",
    "coavas": "coar",
    "coaxa": "coaxar",
    "coaxada": "coaxar",
    "coaxadas": "coaxar",
    "coaxado": "coaxar",
    "coaxados": "coaxar",
    "coaxai": "coaxar",
    "coaxais": "coaxar",
    "coaxam": "coaxar",
    "coaxamo": "coaxar",
    "coaxamos": "coaxar",
    "coaxando": "coaxar",
    "coaxantes": "coaxante",
    "coaxara": "coaxar",
    "coaxaram": "coaxar",
    "coaxaras": "coaxar",
    "coaxardes": "coaxar",
    "coaxarei": "coaxar",
    "coaxareis": "coaxar",
    "coaxarem": "coaxar",
    "coaxaremos": "coaxar",
    "coaxares": "coaxar",
    "coaxaria": "coaxar",
    "coaxariam": "coaxar",
    "coaxarias": "coaxar",
    "coaxarmo": "coaxar",
    "coaxarmos": "coaxar",
    "coaxará": "coaxar",
    "coaxarás": "coaxar",
    "coaxarão": "coaxar",
    "coaxaríamos": "coaxar",
    "coaxaríeis": "coaxar",
    "coaxas": "coaxar",
    "coaxasse": "coaxar",
    "coaxassem": "coaxar",
    "coaxasses": "coaxar",
    "coaxaste": "coaxar",
    "coaxastes": "coaxar",
    "coaxava": "coaxar",
    "coaxavam": "coaxar",
    "coaxavas": "coaxar",
    "coaxações": "coaxação",
    "coaxe": "coaxar",
    "coaxei": "coaxar",
    "coaxeis": "coaxar",
    "coaxem": "coaxar",
    "coaxemo": "coaxar",
    "coaxemos": "coaxar",
    "coaxes": "coaxar",
    "coaxiais": "coaxial",
    "coaxo": "coaxar",
    "coaxos": "coaxo",
    "coaxou": "coaxar",
    "coaxámo": "coaxar",
    "coaxámos": "coaxar",
    "coaxáramo": "coaxar",
    "coaxáramos": "coaxar",
    "coaxáreis": "coaxar",
    "coaxásseis": "coaxar",
    "coaxássemos": "coaxar",
    "coaxávamo": "coaxar",
    "coaxávamos": "coaxar",
    "coaxáveis": "coaxar",
    "cobaias": "cobaia",
    "cobaios": "cobaio",
    "cobaltagens": "cobaltagem",
    "cobaltites": "cobaltite",
    "cobaltiza": "cobaltizar",
    "cobaltizada": "cobaltizar",
    "cobaltizadas": "cobaltizar",
    "cobaltizado": "cobaltizar",
    "cobaltizados": "cobaltizar",
    "cobaltizagens": "cobaltizagem",
    "cobaltizai": "cobaltizar",
    "cobaltizais": "cobaltizar",
    "cobaltizam": "cobaltizar",
    "cobaltizamo": "cobaltizar",
    "cobaltizamos": "cobaltizar",
    "cobaltizando": "cobaltizar",
    "cobaltizara": "cobaltizar",
    "cobaltizaram": "cobaltizar",
    "cobaltizaras": "cobaltizar",
    "cobaltizarde": "cobaltizar",
    "cobaltizardes": "cobaltizar",
    "cobaltizare": "cobaltizar",
    "cobaltizarei": "cobaltizar",
    "cobaltizareis": "cobaltizar",
    "cobaltizarem": "cobaltizar",
    "cobaltizaremos": "cobaltizar",
    "cobaltizares": "cobaltizar",
    "cobaltizaria": "cobaltizar",
    "cobaltizariam": "cobaltizar",
    "cobaltizarias": "cobaltizar",
    "cobaltizarmo": "cobaltizar",
    "cobaltizarmos": "cobaltizar",
    "cobaltizará": "cobaltizar",
    "cobaltizarás": "cobaltizar",
    "cobaltizarão": "cobaltizar",
    "cobaltizaríamos": "cobaltizar",
    "cobaltizaríeis": "cobaltizar",
    "cobaltizas": "cobaltizar",
    "cobaltizasse": "cobaltizar",
    "cobaltizassem": "cobaltizar",
    "cobaltizasses": "cobaltizar",
    "cobaltizaste": "cobaltizar",
    "cobaltizastes": "cobaltizar",
    "cobaltizava": "cobaltizar",
    "cobaltizavam": "cobaltizar",
    "cobaltizavas": "cobaltizar",
    "cobaltize": "cobaltizar",
    "cobaltizei": "cobaltizar",
    "cobaltizeis": "cobaltizar",
    "cobaltizem": "cobaltizar",
    "cobaltizemo": "cobaltizar",
    "cobaltizemos": "cobaltizar",
    "cobaltizes": "cobaltizar",
    "cobaltizo": "cobaltizar",
    "cobaltizou": "cobaltizar",
    "cobaltizá": "cobaltizar",
    "cobaltizámo": "cobaltizar",
    "cobaltizámos": "cobaltizar",
    "cobaltizáramo": "cobaltizar",
    "cobaltizáramos": "cobaltizar",
    "cobaltizárei": "cobaltizar",
    "cobaltizáreis": "cobaltizar",
    "cobaltizásseis": "cobaltizar",
    "cobaltizássemos": "cobaltizar",
    "cobaltizávamo": "cobaltizar",
    "cobaltizávamos": "cobaltizar",
    "cobaltizávei": "cobaltizar",
    "cobaltizáveis": "cobaltizar",
    "cobaltos": "cobalto",
    "cobaltoterapias": "cobaltoterapia",
    "cobaltoterapistas": "cobaltoterapista",
    "cobaltoterapêutas": "cobaltoterapêuta",
    "cobaltoterapêutica": "cobaltoterapêutico",
    "cobaltoterapêuticas": "cobaltoterapêutico",
    "cobaltoterapêuticos": "cobaltoterapêutico",
    "cobaltoterápica": "cobaltoterápico",
    "cobaltoterápicas": "cobaltoterápico",
    "cobaltoterápicos": "cobaltoterápico",
    "cobaltífera": "cobaltífero",
    "cobaltíferas": "cobaltífero",
    "cobaltíferos": "cobaltífero",
    "cobardes": "cobarde",
    "cobardias": "cobardia",
    "cobardices": "cobardice",
    "coberta": "cobrir",
    "cobertalhos": "cobertalho",
    "cobertas": "cobrir",
    "cobertelhas": "cobertelha",
    "coberto": "cobrir",
    "cobertores": "cobertor",
    "cobertos": "cobrir",
    "cobertouras": "cobertoura",
    "coberturas": "cobertura",
    "cobice": "cobiçar",
    "cobicei": "cobiçar",
    "cobiceis": "cobiçar",
    "cobicem": "cobiçar",
    "cobicemo": "cobiçar",
    "cobicemos": "cobiçar",
    "cobices": "cobiçar",
    "cobiça": "cobiçar",
    "cobiçada": "cobiçar",
    "cobiçadas": "cobiçar",
    "cobiçado": "cobiçar",
    "cobiçadora": "cobiçador",
    "cobiçadoras": "cobiçador",
    "cobiçadores": "cobiçador",
    "cobiçados": "cobiçar",
    "cobiçai": "cobiçar",
    "cobiçais": "cobiçar",
    "cobiçam": "cobiçar",
    "cobiçamo": "cobiçar",
    "cobiçamos": "cobiçar",
    "cobiçando": "cobiçar",
    "cobiçantes": "cobiçante",
    "cobiçara": "cobiçar",
    "cobiçaram": "cobiçar",
    "cobiçaras": "cobiçar",
    "cobiçarde": "cobiçar",
    "cobiçardes": "cobiçar",
    "cobiçare": "cobiçar",
    "cobiçarei": "cobiçar",
    "cobiçareis": "cobiçar",
    "cobiçarem": "cobiçar",
    "cobiçaremos": "cobiçar",
    "cobiçares": "cobiçar",
    "cobiçaria": "cobiçar",
    "cobiçariam": "cobiçar",
    "cobiçarias": "cobiçar",
    "cobiçarmo": "cobiçar",
    "cobiçarmos": "cobiçar",
    "cobiçará": "cobiçar",
    "cobiçarás": "cobiçar",
    "cobiçarão": "cobiçar",
    "cobiçaríamos": "cobiçar",
    "cobiçaríeis": "cobiçar",
    "cobiças": "cobiçar",
    "cobiçasse": "cobiçar",
    "cobiçassem": "cobiçar",
    "cobiçasses": "cobiçar",
    "cobiçaste": "cobiçar",
    "cobiçastes": "cobiçar",
    "cobiçava": "cobiçar",
    "cobiçavam": "cobiçar",
    "cobiçavas": "cobiçar",
    "cobiço": "cobiçar",
    "cobiçosa": "cobiçoso",
    "cobiçosas": "cobiçoso",
    "cobiçosos": "cobiçoso",
    "cobiçou": "cobiçar",
    "cobiçá": "cobiçar",
    "cobiçámo": "cobiçar",
    "cobiçámos": "cobiçar",
    "cobiçáramo": "cobiçar",
    "cobiçáramos": "cobiçar",
    "cobiçárei": "cobiçar",
    "cobiçáreis": "cobiçar",
    "cobiçásseis": "cobiçar",
    "cobiçássemos": "cobiçar",
    "cobiçávamo": "cobiçar",
    "cobiçávamos": "cobiçar",
    "cobiçávei": "cobiçar",
    "cobiçáveis": "cobiçável",
    "cobiões": "cobião",
    "coblenciana": "coblenciano",
    "coblencianas": "coblenciano",
    "coblencianos": "coblenciano",
    "coboiadas": "coboiada",
    "cobra": "cobrar",
    "cobrada": "cobrar",
    "cobradas": "cobrar",
    "cobrado": "cobrar",
    "cobradora": "cobrador",
    "cobradoras": "cobrador",
    "cobradores": "cobrador",
    "cobrados": "cobrar",
    "cobradouros": "cobradouro",
    "cobrai": "cobrar",
    "cobrais": "cobrar",
    "cobram": "cobrar",
    "cobramo": "cobrar",
    "cobramos": "cobrar",
    "cobrancistas": "cobrancista",
    "cobrando": "cobrar",
    "cobranças": "cobrança",
    "cobrara": "cobrar",
    "cobraram": "cobrar",
    "cobraras": "cobrar",
    "cobrarde": "cobrar",
    "cobrardes": "cobrar",
    "cobrare": "cobrar",
    "cobrarei": "cobrar",
    "cobrareis": "cobrar",
    "cobrarem": "cobrar",
    "cobraremos": "cobrar",
    "cobrares": "cobrar",
    "cobraria": "cobrar",
    "cobrariam": "cobrar",
    "cobrarias": "cobrar",
    "cobrarmo": "cobrar",
    "cobrarmos": "cobrar",
    "cobrará": "cobrar",
    "cobrarás": "cobrar",
    "cobrarão": "cobrar",
    "cobraríamos": "cobrar",
    "cobraríeis": "cobrar",
    "cobras": "cobrar",
    "cobrasse": "cobrar",
    "cobrassem": "cobrar",
    "cobrasses": "cobrar",
    "cobraste": "cobrar",
    "cobrastes": "cobrar",
    "cobrava": "cobrar",
    "cobravam": "cobrar",
    "cobravas": "cobrar",
    "cobrazonas": "cobrazona",
    "cobre": "cobrir",
    "cobreada": "cobrear",
    "cobreadas": "cobrear",
    "cobreado": "cobrear",
    "cobreados": "cobrear",
    "cobreagens": "cobreagem",
    "cobreai": "cobrear",
    "cobreais": "cobrear",
    "cobreamo": "cobrear",
    "cobreamos": "cobrear",
    "cobreando": "cobrear",
    "cobreara": "cobrear",
    "cobrearam": "cobrear",
    "cobrearas": "cobrear",
    "cobrearde": "cobrear",
    "cobreardes": "cobrear",
    "cobreare": "cobrear",
    "cobrearei": "cobrear",
    "cobreareis": "cobrear",
    "cobrearem": "cobrear",
    "cobrearemos": "cobrear",
    "cobreares": "cobrear",
    "cobrearia": "cobrear",
    "cobreariam": "cobrear",
    "cobrearias": "cobrear",
    "cobrearmo": "cobrear",
    "cobrearmos": "cobrear",
    "cobreará": "cobrear",
    "cobrearás": "cobrear",
    "cobrearão": "cobrear",
    "cobrearíamos": "cobrear",
    "cobrearíeis": "cobrear",
    "cobreasse": "cobrear",
    "cobreassem": "cobrear",
    "cobreasses": "cobrear",
    "cobreaste": "cobrear",
    "cobreastes": "cobrear",
    "cobreava": "cobrear",
    "cobreavam": "cobrear",
    "cobreavas": "cobrear",
    "cobreei": "cobrear",
    "cobreeis": "cobrear",
    "cobreemo": "cobrear",
    "cobreemos": "cobrear",
    "cobrei": "cobrar",
    "cobreia": "cobrear",
    "cobreiam": "cobrear",
    "cobreias": "cobrear",
    "cobreie": "cobrear",
    "cobreiem": "cobrear",
    "cobreies": "cobrear",
    "cobreio": "cobrear",
    "cobreiras": "cobreira",
    "cobreis": "cobrar",
    "cobreja": "cobrejar",
    "cobrejada": "cobrejar",
    "cobrejadas": "cobrejar",
    "cobrejado": "cobrejar",
    "cobrejados": "cobrejar",
    "cobrejai": "cobrejar",
    "cobrejais": "cobrejar",
    "cobrejam": "cobrejar",
    "cobrejamo": "cobrejar",
    "cobrejamos": "cobrejar",
    "cobrejando": "cobrejar",
    "cobrejara": "cobrejar",
    "cobrejaram": "cobrejar",
    "cobrejaras": "cobrejar",
    "cobrejarde": "cobrejar",
    "cobrejardes": "cobrejar",
    "cobrejare": "cobrejar",
    "cobrejarei": "cobrejar",
    "cobrejareis": "cobrejar",
    "cobrejarem": "cobrejar",
    "cobrejaremos": "cobrejar",
    "cobrejares": "cobrejar",
    "cobrejaria": "cobrejar",
    "cobrejariam": "cobrejar",
    "cobrejarias": "cobrejar",
    "cobrejarmo": "cobrejar",
    "cobrejarmos": "cobrejar",
    "cobrejará": "cobrejar",
    "cobrejarás": "cobrejar",
    "cobrejarão": "cobrejar",
    "cobrejaríamos": "cobrejar",
    "cobrejaríeis": "cobrejar",
    "cobrejas": "cobrejar",
    "cobrejasse": "cobrejar",
    "cobrejassem": "cobrejar",
    "cobrejasses": "cobrejar",
    "cobrejaste": "cobrejar",
    "cobrejastes": "cobrejar",
    "cobrejava": "cobrejar",
    "cobrejavam": "cobrejar",
    "cobrejavas": "cobrejar",
    "cobreje": "cobrejar",
    "cobrejei": "cobrejar",
    "cobrejeis": "cobrejar",
    "cobrejem": "cobrejar",
    "cobrejemo": "cobrejar",
    "cobrejemos": "cobrejar",
    "cobrejes": "cobrejar",
    "cobrejo": "cobrejar",
    "cobrejou": "cobrejar",
    "cobrejá": "cobrejar",
    "cobrejámo": "cobrejar",
    "cobrejámos": "cobrejar",
    "cobrejáramo": "cobrejar",
    "cobrejáramos": "cobrejar",
    "cobrejárei": "cobrejar",
    "cobrejáreis": "cobrejar",
    "cobrejásseis": "cobrejar",
    "cobrejássemos": "cobrejar",
    "cobrejávamo": "cobrejar",
    "cobrejávamos": "cobrejar",
    "cobrejávei": "cobrejar",
    "cobrejáveis": "cobrejar",
    "cobrejões": "cobrejão",
    "cobrelos": "cobrelo",
    "cobrem": "cobrir",
    "cobremo": "cobrar",
    "cobremos": "cobrar",
    "cobreou": "cobrear",
    "cobres": "cobrir",
    "cobreá": "cobrear",
    "cobreámo": "cobrear",
    "cobreámos": "cobrear",
    "cobreáramo": "cobrear",
    "cobreáramos": "cobrear",
    "cobreárei": "cobrear",
    "cobreáreis": "cobrear",
    "cobreásseis": "cobrear",
    "cobreássemos": "cobrear",
    "cobreávamo": "cobrear",
    "cobreávamos": "cobrear",
    "cobreávei": "cobrear",
    "cobreáveis": "cobrear",
    "cobri": "cobrir",
    "cobria": "cobrir",
    "cobriam": "cobrir",
    "cobrias": "cobrir",
    "cobrida": "cobrir",
    "cobridas": "cobrir",
    "cobrido": "cobrir",
    "cobridora": "cobridor",
    "cobridoras": "cobridor",
    "cobridores": "cobridor",
    "cobridos": "cobrir",
    "cobrilhas": "cobrilha",
    "cobrimentos": "cobrimento",
    "cobrimo": "cobrir",
    "cobrimos": "cobrir",
    "cobrindo": "cobrir",
    "cobrinha": "cobra",
    "cobrinhas": "cobra",
    "cobrira": "cobrir",
    "cobriram": "cobrir",
    "cobriras": "cobrir",
    "cobrirde": "cobrir",
    "cobrirdes": "cobrir",
    "cobrire": "cobrir",
    "cobrirei": "cobrir",
    "cobrireis": "cobrir",
    "cobrirem": "cobrir",
    "cobriremos": "cobrir",
    "cobrires": "cobrir",
    "cobriria": "cobrir",
    "cobririam": "cobrir",
    "cobririas": "cobrir",
    "cobrirmo": "cobrir",
    "cobrirmos": "cobrir",
    "cobrirá": "cobrir",
    "cobrirás": "cobrir",
    "cobrirão": "cobrir",
    "cobriríamos": "cobrir",
    "cobriríeis": "cobrir",
    "cobris": "cobrir",
    "cobrisse": "cobrir",
    "cobrissem": "cobrir",
    "cobrisses": "cobrir",
    "cobriste": "cobrir",
    "cobristes": "cobrir",
    "cobrita": "cobra",
    "cobritas": "cobra",
    "cobriu": "cobrir",
    "cobrições": "cobrição",
    "cobro": "cobrar",
    "cobros": "cobro",
    "cobrou": "cobrar",
    "cobrá": "cobrar",
    "cobrámo": "cobrar",
    "cobrámos": "cobrar",
    "cobráramo": "cobrar",
    "cobráramos": "cobrar",
    "cobrárei": "cobrar",
    "cobráreis": "cobrar",
    "cobrásseis": "cobrar",
    "cobrássemos": "cobrar",
    "cobrávamo": "cobrar",
    "cobrávamos": "cobrar",
    "cobrávei": "cobrar",
    "cobráveis": "cobrável",
    "cobríamo": "cobrir",
    "cobríamos": "cobrir",
    "cobríei": "cobrir",
    "cobríeis": "cobrir",
    "cobríramo": "cobrir",
    "cobríramos": "cobrir",
    "cobrírei": "cobrir",
    "cobríreis": "cobrir",
    "cobrísseis": "cobrir",
    "cobríssemos": "cobrir",
    "cobrões": "cobrão",
    "cobáltica": "cobáltico",
    "cobálticas": "cobáltico",
    "cobálticos": "cobáltico",
    "coca": "cocar",
    "cocada": "cocar",
    "cocadas": "cocar",
    "cocado": "cocar",
    "cocados": "cocar",
    "cocai": "cocar",
    "cocainismos": "cocainismo",
    "cocainiza": "cocainizar",
    "cocainizada": "cocainizar",
    "cocainizadas": "cocainizar",
    "cocainizado": "cocainizar",
    "cocainizados": "cocainizar",
    "cocainizai": "cocainizar",
    "cocainizais": "cocainizar",
    "cocainizam": "cocainizar",
    "cocainizamo": "cocainizar",
    "cocainizamos": "cocainizar",
    "cocainizando": "cocainizar",
    "cocainizara": "cocainizar",
    "cocainizaram": "cocainizar",
    "cocainizaras": "cocainizar",
    "cocainizarde": "cocainizar",
    "cocainizardes": "cocainizar",
    "cocainizare": "cocainizar",
    "cocainizarei": "cocainizar",
    "cocainizareis": "cocainizar",
    "cocainizarem": "cocainizar",
    "cocainizaremos": "cocainizar",
    "cocainizares": "cocainizar",
    "cocainizaria": "cocainizar",
    "cocainizariam": "cocainizar",
    "cocainizarias": "cocainizar",
    "cocainizarmo": "cocainizar",
    "cocainizarmos": "cocainizar",
    "cocainizará": "cocainizar",
    "cocainizarás": "cocainizar",
    "cocainizarão": "cocainizar",
    "cocainizaríamos": "cocainizar",
    "cocainizaríeis": "cocainizar",
    "cocainizas": "cocainizar",
    "cocainizasse": "cocainizar",
    "cocainizassem": "cocainizar",
    "cocainizasses": "cocainizar",
    "cocainizaste": "cocainizar",
    "cocainizastes": "cocainizar",
    "cocainizava": "cocainizar",
    "cocainizavam": "cocainizar",
    "cocainizavas": "cocainizar",
    "cocainizações": "cocainização",
    "cocainize": "cocainizar",
    "cocainizei": "cocainizar",
    "cocainizeis": "cocainizar",
    "cocainizem": "cocainizar",
    "cocainizemo": "cocainizar",
    "cocainizemos": "cocainizar",
    "cocainizes": "cocainizar",
    "cocainizo": "cocainizar",
    "cocainizou": "cocainizar",
    "cocainizá": "cocainizar",
    "cocainizámo": "cocainizar",
    "cocainizámos": "cocainizar",
    "cocainizáramo": "cocainizar",
    "cocainizáramos": "cocainizar",
    "cocainizárei": "cocainizar",
    "cocainizáreis": "cocainizar",
    "cocainizásseis": "cocainizar",
    "cocainizássemos": "cocainizar",
    "cocainizávamo": "cocainizar",
    "cocainizávamos": "cocainizar",
    "cocainizávei": "cocainizar",
    "cocainizáveis": "cocainizar",
    "cocainomanias": "cocainomania",
    "cocainomaníaca": "cocainomaníaco",
    "cocainomaníacas": "cocainomaníaco",
    "cocainomaníacos": "cocainomaníaco",
    "cocainómana": "cocainómano",
    "cocainómanas": "cocainómano",
    "cocainómanos": "cocainómano",
    "cocais": "cocar",
    "cocam": "cocar",
    "cocamo": "cocar",
    "cocamos": "cocar",
    "cocando": "cocar",
    "cocanhas": "cocanha",
    "cocara": "cocar",
    "cocaram": "cocar",
    "cocaras": "cocar",
    "cocarde": "cocar",
    "cocardes": "cocar",
    "cocare": "cocar",
    "cocarei": "cocar",
    "cocareis": "cocar",
    "cocarem": "cocar",
    "cocaremos": "cocar",
    "cocares": "cocar",
    "cocaria": "cocar",
    "cocariam": "cocar",
    "cocarias": "cocar",
    "cocarmo": "cocar",
    "cocarmos": "cocar",
    "cocará": "cocar",
    "cocarás": "cocar",
    "cocarão": "cocar",
    "cocaríamos": "cocar",
    "cocaríeis": "cocar",
    "cocas": "cocar",
    "cocasse": "cocar",
    "cocassem": "cocar",
    "cocasses": "cocar",
    "cocaste": "cocar",
    "cocastes": "cocar",
    "cocava": "cocar",
    "cocavam": "cocar",
    "cocavas": "cocar",
    "cocaínas": "cocaína",
    "coccientes": "cocciente",
    "coccigeana": "coccigeano",
    "coccigeanas": "coccigeano",
    "coccigeanos": "coccigeano",
    "cocciges": "coccige",
    "coccigodinias": "coccigodinia",
    "coccigotomias": "coccigotomia",
    "coccigotómica": "coccigotómico",
    "coccigotómicas": "coccigotómico",
    "coccigotómicos": "coccigotómico",
    "coccinelídea": "coccinelídeo",
    "coccinelídeas": "coccinelídeo",
    "coccinelídeos": "coccinelídeo",
    "coccídea": "coccídeo",
    "coccídeas": "coccídeo",
    "coccídeos": "coccídeo",
    "coccígea": "coccígeo",
    "coccígeas": "coccígeo",
    "coccígeos": "coccígeo",
    "coce": "coçar",
    "cocega": "cocegar",
    "cocegada": "cocegar",
    "cocegadas": "cocegar",
    "cocegado": "cocegar",
    "cocegados": "cocegar",
    "cocegai": "cocegar",
    "cocegais": "cocegar",
    "cocegam": "cocegar",
    "cocegamo": "cocegar",
    "cocegamos": "cocegar",
    "cocegando": "cocegar",
    "cocegantes": "cocegante",
    "cocegara": "cocegar",
    "cocegaram": "cocegar",
    "cocegaras": "cocegar",
    "cocegarde": "cocegar",
    "cocegardes": "cocegar",
    "cocegare": "cocegar",
    "cocegarei": "cocegar",
    "cocegareis": "cocegar",
    "cocegarem": "cocegar",
    "cocegaremos": "cocegar",
    "cocegares": "cocegar",
    "cocegaria": "cocegar",
    "cocegariam": "cocegar",
    "cocegarias": "cocegar",
    "cocegarmo": "cocegar",
    "cocegarmos": "cocegar",
    "cocegará": "cocegar",
    "cocegarás": "cocegar",
    "cocegarão": "cocegar",
    "cocegaríamos": "cocegar",
    "cocegaríeis": "cocegar",
    "cocegas": "cocegar",
    "cocegasse": "cocegar",
    "cocegassem": "cocegar",
    "cocegasses": "cocegar",
    "cocegaste": "cocegar",
    "cocegastes": "cocegar",
    "cocegava": "cocegar",
    "cocegavam": "cocegar",
    "cocegavas": "cocegar",
    "cocego": "cocegar",
    "cocegou": "cocegar",
    "cocegue": "cocegar",
    "coceguei": "cocegar",
    "cocegueis": "cocegar",
    "coceguem": "cocegar",
    "coceguemo": "cocegar",
    "coceguemos": "cocegar",
    "coceguenta": "coceguento",
    "coceguentas": "coceguento",
    "coceguentos": "coceguento",
    "cocegues": "cocegar",
    "cocegá": "cocegar",
    "cocegámo": "cocegar",
    "cocegámos": "cocegar",
    "cocegáramo": "cocegar",
    "cocegáramos": "cocegar",
    "cocegárei": "cocegar",
    "cocegáreis": "cocegar",
    "cocegásseis": "cocegar",
    "cocegássemos": "cocegar",
    "cocegávamo": "cocegar",
    "cocegávamos": "cocegar",
    "cocegávei": "cocegar",
    "cocegáveis": "cocegar",
    "cocei": "coçar",
    "coceiras": "coceira",
    "coceis": "coçar",
    "cocem": "coçar",
    "cocemo": "coçar",
    "cocemos": "coçar",
    "cocertadora": "cocertador",
    "cocertadoras": "cocertador",
    "cocertadores": "cocertador",
    "coces": "coçar",
    "cocha": "cochar",
    "cochada": "cochar",
    "cochadas": "cochar",
    "cochado": "cochar",
    "cochados": "cochar",
    "cochai": "cochar",
    "cochais": "cochar",
    "cocham": "cochar",
    "cochamo": "cochar",
    "cochamos": "cochar",
    "cochando": "cochar",
    "cochara": "cochar",
    "cocharam": "cochar",
    "cocharas": "cochar",
    "cocharde": "cochar",
    "cochardes": "cochar",
    "cochare": "cochar",
    "cocharei": "cochar",
    "cochareis": "cochar",
    "cocharem": "cochar",
    "cocharemos": "cochar",
    "cochares": "cochar",
    "cocharia": "cochar",
    "cochariam": "cochar",
    "cocharias": "cochar",
    "cocharmo": "cochar",
    "cocharmos": "cochar",
    "cocharradas": "cocharrada",
    "cocharras": "cocharra",
    "cocharros": "cocharro",
    "cochará": "cochar",
    "cocharás": "cochar",
    "cocharão": "cochar",
    "cocharíamos": "cochar",
    "cocharíeis": "cochar",
    "cochas": "cochar",
    "cochasse": "cochar",
    "cochassem": "cochar",
    "cochasses": "cochar",
    "cochaste": "cochar",
    "cochastes": "cochar",
    "cochava": "cochar",
    "cochavam": "cochar",
    "cochavas": "cochar",
    "coche": "cochar",
    "cochei": "cochar",
    "cocheirais": "cocheiral",
    "cocheiras": "cocheira",
    "cocheiros": "cocheiro",
    "cocheis": "cochar",
    "cochem": "cochar",
    "cochemo": "cochar",
    "cochemos": "cochar",
    "cochenilhas": "cochenilha",
    "coches": "coche",
    "cochicha": "cochichar",
    "cochichada": "cochichar",
    "cochichadas": "cochichar",
    "cochichado": "cochichar",
    "cochichadora": "cochichador",
    "cochichadoras": "cochichador",
    "cochichadores": "cochichador",
    "cochichados": "cochichar",
    "cochichai": "cochichar",
    "cochichais": "cochichar",
    "cochicham": "cochichar",
    "cochichamo": "cochichar",
    "cochichamos": "cochichar",
    "cochichando": "cochichar",
    "cochichara": "cochichar",
    "cochicharam": "cochichar",
    "cochicharas": "cochichar",
    "cochicharde": "cochichar",
    "cochichardes": "cochichar",
    "cochichare": "cochichar",
    "cochicharei": "cochichar",
    "cochichareis": "cochichar",
    "cochicharem": "cochichar",
    "cochicharemos": "cochichar",
    "cochichares": "cochichar",
    "cochicharia": "cochichar",
    "cochichariam": "cochichar",
    "cochicharias": "cochichar",
    "cochicharmo": "cochichar",
    "cochicharmos": "cochichar",
    "cochichará": "cochichar",
    "cochicharás": "cochichar",
    "cochicharão": "cochichar",
    "cochicharíamos": "cochichar",
    "cochicharíeis": "cochichar",
    "cochichas": "cochichar",
    "cochichasse": "cochichar",
    "cochichassem": "cochichar",
    "cochichasses": "cochichar",
    "cochichaste": "cochichar",
    "cochichastes": "cochichar",
    "cochichava": "cochichar",
    "cochichavam": "cochichar",
    "cochichavas": "cochichar",
    "cochiche": "cochichar",
    "cochichei": "cochichar",
    "cochicheios": "cochicheio",
    "cochicheis": "cochichar",
    "cochichem": "cochichar",
    "cochichemo": "cochichar",
    "cochichemos": "cochichar",
    "cochiches": "cochichar",
    "cochicho": "cochichar",
    "cochicholos": "cochicholo",
    "cochichos": "cochicho",
    "cochichou": "cochichar",
    "cochichá": "cochichar",
    "cochichámo": "cochichar",
    "cochichámos": "cochichar",
    "cochicháramo": "cochichar",
    "cochicháramos": "cochichar",
    "cochichárei": "cochichar",
    "cochicháreis": "cochichar",
    "cochichásseis": "cochichar",
    "cochichássemos": "cochichar",
    "cochichávamo": "cochichar",
    "cochichávamos": "cochichar",
    "cochichávei": "cochichar",
    "cochicháveis": "cochichar",
    "cochila": "cochilar",
    "cochilada": "cochilar",
    "cochiladas": "cochilar",
    "cochilado": "cochilar",
    "cochilados": "cochilar",
    "cochilai": "cochilar",
    "cochilais": "cochilar",
    "cochilam": "cochilar",
    "cochilamo": "cochilar",
    "cochilamos": "cochilar",
    "cochilando": "cochilar",
    "cochilara": "cochilar",
    "cochilaram": "cochilar",
    "cochilaras": "cochilar",
    "cochilardes": "cochilar",
    "cochilarei": "cochilar",
    "cochilareis": "cochilar",
    "cochilarem": "cochilar",
    "cochilaremos": "cochilar",
    "cochilares": "cochilar",
    "cochilaria": "cochilar",
    "cochilariam": "cochilar",
    "cochilarias": "cochilar",
    "cochilarmo": "cochilar",
    "cochilarmos": "cochilar",
    "cochilará": "cochilar",
    "cochilarás": "cochilar",
    "cochilarão": "cochilar",
    "cochilaríamos": "cochilar",
    "cochilaríeis": "cochilar",
    "cochilas": "cochilar",
    "cochilasse": "cochilar",
    "cochilassem": "cochilar",
    "cochilasses": "cochilar",
    "cochilaste": "cochilar",
    "cochilastes": "cochilar",
    "cochilava": "cochilar",
    "cochilavam": "cochilar",
    "cochilavas": "cochilar",
    "cochile": "cochilar",
    "cochilei": "cochilar",
    "cochileis": "cochilar",
    "cochilem": "cochilar",
    "cochilemo": "cochilar",
    "cochilemos": "cochilar",
    "cochiles": "cochilar",
    "cochilo": "cochilar",
    "cochilos": "cochilo",
    "cochilou": "cochilar",
    "cochilámo": "cochilar",
    "cochilámos": "cochilar",
    "cochiláramo": "cochilar",
    "cochiláramos": "cochilar",
    "cochiláreis": "cochilar",
    "cochilásseis": "cochilar",
    "cochilássemos": "cochilar",
    "cochilávamo": "cochilar",
    "cochilávamos": "cochilar",
    "cochiláveis": "cochilar",
    "cochina": "cochinar",
    "cochinada": "cochinar",
    "cochinadas": "cochinar",
    "cochinado": "cochinar",
    "cochinados": "cochinar",
    "cochinai": "cochinar",
    "cochinais": "cochinar",
    "cochinam": "cochinar",
    "cochinamo": "cochinar",
    "cochinamos": "cochinar",
    "cochinando": "cochinar",
    "cochinara": "cochinar",
    "cochinaram": "cochinar",
    "cochinaras": "cochinar",
    "cochinardes": "cochinar",
    "cochinarei": "cochinar",
    "cochinareis": "cochinar",
    "cochinarem": "cochinar",
    "cochinaremos": "cochinar",
    "cochinares": "cochinar",
    "cochinaria": "cochinar",
    "cochinariam": "cochinar",
    "cochinarias": "cochinar",
    "cochinarmo": "cochinar",
    "cochinarmos": "cochinar",
    "cochinará": "cochinar",
    "cochinarás": "cochinar",
    "cochinarão": "cochinar",
    "cochinaríamos": "cochinar",
    "cochinaríeis": "cochinar",
    "cochinas": "cochinar",
    "cochinasse": "cochinar",
    "cochinassem": "cochinar",
    "cochinasses": "cochinar",
    "cochinaste": "cochinar",
    "cochinastes": "cochinar",
    "cochinava": "cochinar",
    "cochinavam": "cochinar",
    "cochinavas": "cochinar",
    "cochinchina": "cochinchino",
    "cochinchinas": "cochinchino",
    "cochinchinos": "cochinchino",
    "cochine": "cochinar",
    "cochinei": "cochinar",
    "cochineis": "cochinar",
    "cochinem": "cochinar",
    "cochinemo": "cochinar",
    "cochinemos": "cochinar",
    "cochines": "cochinar",
    "cochinilhas": "cochinilha",
    "cochino": "cochinar",
    "cochinos": "cochino",
    "cochinou": "cochinar",
    "cochinámo": "cochinar",
    "cochinámos": "cochinar",
    "cochináramo": "cochinar",
    "cochináramos": "cochinar",
    "cochináreis": "cochinar",
    "cochinásseis": "cochinar",
    "cochinássemos": "cochinar",
    "cochinávamo": "cochinar",
    "cochinávamos": "cochinar",
    "cochináveis": "cochinar",
    "cocho": "cochar",
    "cochonilhas": "cochonilha",
    "cochos": "cocho",
    "cochou": "cochar",
    "cochovelhos": "cochovelho",
    "cochá": "cochar",
    "cochámo": "cochar",
    "cochámos": "cochar",
    "cocháramo": "cochar",
    "cocháramos": "cochar",
    "cochárei": "cochar",
    "cocháreis": "cochar",
    "cochásseis": "cochar",
    "cochássemos": "cochar",
    "cochávamo": "cochar",
    "cochávamos": "cochar",
    "cochávei": "cochar",
    "cocháveis": "cochar",
    "cockpits": "cockpit",
    "cocktails": "cocktail",
    "cocleariformes": "cocleariforme",
    "cocleiformes": "cocleiforme",
    "cocleárias": "cocleária",
    "coco": "cocar",
    "cococleares": "cococlear",
    "coconotes": "coconote",
    "cocorococós": "cocorococó",
    "cocorocotes": "cocorocote",
    "cocorocós": "cocorocó",
    "cocos": "cocus",
    "cocotas": "cocota",
    "cocotes": "cocote",
    "cocou": "cocar",
    "cocta": "cocto",
    "coctas": "cocto",
    "coctos": "cocto",
    "cocurutas": "cocuruta",
    "cocurutos": "cocuruto",
    "cocá": "cocar",
    "cocámo": "cocar",
    "cocámos": "cocar",
    "cocáramo": "cocar",
    "cocáramos": "cocar",
    "cocárei": "cocar",
    "cocáreis": "cocar",
    "cocásseis": "cocar",
    "cocássemos": "cocar",
    "cocávamo": "cocar",
    "cocávamos": "cocar",
    "cocávei": "cocar",
    "cocáveis": "cocar",
    "cocções": "cocção",
    "cocós": "cocó",
    "cocões": "cocão",
    "codaminas": "codamina",
    "codas": "coda",
    "codeada": "codear",
    "codeadas": "codear",
    "codeado": "codear",
    "codeados": "codear",
    "codeai": "codear",
    "codeais": "codear",
    "codeamo": "codear",
    "codeamos": "codear",
    "codeando": "codear",
    "codeara": "codear",
    "codearam": "codear",
    "codearas": "codear",
    "codeardes": "codear",
    "codearei": "codear",
    "codeareis": "codear",
    "codearem": "codear",
    "codearemos": "codear",
    "codeares": "codear",
    "codearia": "codear",
    "codeariam": "codear",
    "codearias": "codear",
    "codearmo": "codear",
    "codearmos": "codear",
    "codeará": "codear",
    "codearás": "codear",
    "codearão": "codear",
    "codearíamos": "codear",
    "codearíeis": "codear",
    "codeasse": "codear",
    "codeassem": "codear",
    "codeasses": "codear",
    "codeaste": "codear",
    "codeastes": "codear",
    "codeava": "codear",
    "codeavam": "codear",
    "codeavas": "codear",
    "codeazinha": "côdea",
    "codeazinhas": "côdea",
    "codeazita": "côdea",
    "codeazitas": "côdea",
    "codeei": "codear",
    "codeeis": "codear",
    "codeemo": "codear",
    "codeemos": "codear",
    "codeia": "codear",
    "codeiam": "codear",
    "codeias": "codear",
    "codeie": "codear",
    "codeiem": "codear",
    "codeies": "codear",
    "codeio": "codear",
    "codeja": "codejar",
    "codejada": "codejar",
    "codejadas": "codejar",
    "codejado": "codejar",
    "codejados": "codejar",
    "codejai": "codejar",
    "codejais": "codejar",
    "codejam": "codejar",
    "codejamo": "codejar",
    "codejamos": "codejar",
    "codejando": "codejar",
    "codejara": "codejar",
    "codejaram": "codejar",
    "codejaras": "codejar",
    "codejardes": "codejar",
    "codejarei": "codejar",
    "codejareis": "codejar",
    "codejarem": "codejar",
    "codejaremos": "codejar",
    "codejares": "codejar",
    "codejaria": "codejar",
    "codejariam": "codejar",
    "codejarias": "codejar",
    "codejarmo": "codejar",
    "codejarmos": "codejar",
    "codejará": "codejar",
    "codejarás": "codejar",
    "codejarão": "codejar",
    "codejaríamos": "codejar",
    "codejaríeis": "codejar",
    "codejas": "codejar",
    "codejasse": "codejar",
    "codejassem": "codejar",
    "codejasses": "codejar",
    "codejaste": "codejar",
    "codejastes": "codejar",
    "codejava": "codejar",
    "codejavam": "codejar",
    "codejavas": "codejar",
    "codeje": "codejar",
    "codejei": "codejar",
    "codejeis": "codejar",
    "codejem": "codejar",
    "codejemo": "codejar",
    "codejemos": "codejar",
    "codejes": "codejar",
    "codejo": "codejar",
    "codejou": "codejar",
    "codejámo": "codejar",
    "codejámos": "codejar",
    "codejáramo": "codejar",
    "codejáramos": "codejar",
    "codejáreis": "codejar",
    "codejásseis": "codejar",
    "codejássemos": "codejar",
    "codejávamo": "codejar",
    "codejávamos": "codejar",
    "codejáveis": "codejar",
    "codeou": "codear",
    "codessais": "codessal",
    "codesseiras": "codesseira",
    "codessos": "codesso",
    "codeámo": "codear",
    "codeámos": "codear",
    "codeáramo": "codear",
    "codeáramos": "codear",
    "codeáreis": "codear",
    "codeásseis": "codear",
    "codeássemos": "codear",
    "codeávamo": "codear",
    "codeávamos": "codear",
    "codeáveis": "codear",
    "codeínas": "codeína",
    "codeões": "codeão",
    "codeúda": "codeúdo",
    "codeúdas": "codeúdo",
    "codeúdos": "codeúdo",
    "codicilares": "codicilar",
    "codicilos": "codicilo",
    "codifica": "codificar",
    "codificada": "codificar",
    "codificadas": "codificar",
    "codificado": "codificar",
    "codificadora": "codificador",
    "codificadoras": "codificador",
    "codificadores": "codificador",
    "codificados": "codificar",
    "codificai": "codificar",
    "codificais": "codificar",
    "codificam": "codificar",
    "codificamo": "codificar",
    "codificamos": "codificar",
    "codificando": "codificar",
    "codificara": "codificar",
    "codificaram": "codificar",
    "codificaras": "codificar",
    "codificarde": "codificar",
    "codificardes": "codificar",
    "codificare": "codificar",
    "codificarei": "codificar",
    "codificareis": "codificar",
    "codificarem": "codificar",
    "codificaremos": "codificar",
    "codificares": "codificar",
    "codificaria": "codificar",
    "codificariam": "codificar",
    "codificarias": "codificar",
    "codificarmo": "codificar",
    "codificarmos": "codificar",
    "codificará": "codificar",
    "codificarás": "codificar",
    "codificarão": "codificar",
    "codificaríamos": "codificar",
    "codificaríeis": "codificar",
    "codificas": "codificar",
    "codificasse": "codificar",
    "codificassem": "codificar",
    "codificasses": "codificar",
    "codificaste": "codificar",
    "codificastes": "codificar",
    "codificava": "codificar",
    "codificavam": "codificar",
    "codificavas": "codificar",
    "codificações": "codificação",
    "codifico": "codificar",
    "codificou": "codificar",
    "codificá": "codificar",
    "codificámo": "codificar",
    "codificámos": "codificar",
    "codificáramo": "codificar",
    "codificáramos": "codificar",
    "codificárei": "codificar",
    "codificáreis": "codificar",
    "codificásseis": "codificar",
    "codificássemos": "codificar",
    "codificávamo": "codificar",
    "codificávamos": "codificar",
    "codificávei": "codificar",
    "codificáveis": "codificar",
    "codifique": "codificar",
    "codifiquei": "codificar",
    "codifiqueis": "codificar",
    "codifiquem": "codificar",
    "codifiquemo": "codificar",
    "codifiquemos": "codificar",
    "codifiques": "codificar",
    "codilha": "codilhar",
    "codilhada": "codilhar",
    "codilhadas": "codilhar",
    "codilhado": "codilhar",
    "codilhados": "codilhar",
    "codilhai": "codilhar",
    "codilhais": "codilhar",
    "codilham": "codilhar",
    "codilhamo": "codilhar",
    "codilhamos": "codilhar",
    "codilhando": "codilhar",
    "codilhara": "codilhar",
    "codilharam": "codilhar",
    "codilharas": "codilhar",
    "codilharde": "codilhar",
    "codilhardes": "codilhar",
    "codilhare": "codilhar",
    "codilharei": "codilhar",
    "codilhareis": "codilhar",
    "codilharem": "codilhar",
    "codilharemos": "codilhar",
    "codilhares": "codilhar",
    "codilharia": "codilhar",
    "codilhariam": "codilhar",
    "codilharias": "codilhar",
    "codilharmo": "codilhar",
    "codilharmos": "codilhar",
    "codilhará": "codilhar",
    "codilharás": "codilhar",
    "codilharão": "codilhar",
    "codilharíamos": "codilhar",
    "codilharíeis": "codilhar",
    "codilhas": "codilhar",
    "codilhasse": "codilhar",
    "codilhassem": "codilhar",
    "codilhasses": "codilhar",
    "codilhaste": "codilhar",
    "codilhastes": "codilhar",
    "codilhava": "codilhar",
    "codilhavam": "codilhar",
    "codilhavas": "codilhar",
    "codilhe": "codilhar",
    "codilhei": "codilhar",
    "codilheis": "codilhar",
    "codilhem": "codilhar",
    "codilhemo": "codilhar",
    "codilhemos": "codilhar",
    "codilhes": "codilhar",
    "codilho": "codilhar",
    "codilhos": "codilho",
    "codilhou": "codilhar",
    "codilhá": "codilhar",
    "codilhámo": "codilhar",
    "codilhámos": "codilhar",
    "codilháramo": "codilhar",
    "codilháramos": "codilhar",
    "codilhárei": "codilhar",
    "codilháreis": "codilhar",
    "codilhásseis": "codilhar",
    "codilhássemos": "codilhar",
    "codilhávamo": "codilhar",
    "codilhávamos": "codilhar",
    "codilhávei": "codilhar",
    "codilháveis": "codilhar",
    "codofones": "codofone",
    "codornas": "codorna",
    "codornizes": "codorniz",
    "codornizões": "codornizão",
    "codornos": "codorno",
    "codos": "codo",
    "codórios": "codório",
    "coe": "coar",
    "coectânea": "coectâneo",
    "coectâneas": "coectâneo",
    "coectâneos": "coectâneo",
    "coeduca": "coeducar",
    "coeducada": "coeducar",
    "coeducadas": "coeducar",
    "coeducado": "coeducar",
    "coeducados": "coeducar",
    "coeducai": "coeducar",
    "coeducais": "coeducar",
    "coeducam": "coeducar",
    "coeducamo": "coeducar",
    "coeducamos": "coeducar",
    "coeducando": "coeducar",
    "coeducara": "coeducar",
    "coeducaram": "coeducar",
    "coeducaras": "coeducar",
    "coeducarde": "coeducar",
    "coeducardes": "coeducar",
    "coeducare": "coeducar",
    "coeducarei": "coeducar",
    "coeducareis": "coeducar",
    "coeducarem": "coeducar",
    "coeducaremos": "coeducar",
    "coeducares": "coeducar",
    "coeducaria": "coeducar",
    "coeducariam": "coeducar",
    "coeducarias": "coeducar",
    "coeducarmo": "coeducar",
    "coeducarmos": "coeducar",
    "coeducará": "coeducar",
    "coeducarás": "coeducar",
    "coeducarão": "coeducar",
    "coeducaríamos": "coeducar",
    "coeducaríeis": "coeducar",
    "coeducas": "coeducar",
    "coeducasse": "coeducar",
    "coeducassem": "coeducar",
    "coeducasses": "coeducar",
    "coeducaste": "coeducar",
    "coeducastes": "coeducar",
    "coeducava": "coeducar",
    "coeducavam": "coeducar",
    "coeducavas": "coeducar",
    "coeducações": "coeducação",
    "coeduco": "coeducar",
    "coeducou": "coeducar",
    "coeducá": "coeducar",
    "coeducámo": "coeducar",
    "coeducámos": "coeducar",
    "coeducáramo": "coeducar",
    "coeducáramos": "coeducar",
    "coeducárei": "coeducar",
    "coeducáreis": "coeducar",
    "coeducásseis": "coeducar",
    "coeducássemos": "coeducar",
    "coeducávamo": "coeducar",
    "coeducávamos": "coeducar",
    "coeducávei": "coeducar",
    "coeducáveis": "coeducar",
    "coeduque": "coeducar",
    "coeduquei": "coeducar",
    "coeduqueis": "coeducar",
    "coeduquem": "coeducar",
    "coeduquemo": "coeducar",
    "coeduquemos": "coeducar",
    "coeduques": "coeducar",
    "coeficientes": "coeficiente",
    "coeficiências": "coeficiência",
    "coei": "coar",
    "coeis": "coar",
    "coelha": "coelho",
    "coelhadas": "coelhada",
    "coelhas": "coelho",
    "coelheiras": "coelheira",
    "coelheiros": "coelheiro",
    "coelhinha": "coelho",
    "coelhinhas": "coelho",
    "coelhinho": "coelho",
    "coelhinhos": "coelho",
    "coelhita": "coelho",
    "coelhitas": "coelho",
    "coelhito": "coelho",
    "coelhitos": "coelho",
    "coelhos": "coelho",
    "coem": "coar",
    "coemo": "coar",
    "coemos": "coar",
    "coempções": "coempção",
    "coentradas": "coentrada",
    "coentrais": "coentral",
    "coentros": "coentro",
    "coequações": "coequação",
    "coercibilidades": "coercibilidade",
    "coercimetrias": "coercimetria",
    "coercitiva": "coercitivo",
    "coercitivas": "coercitivo",
    "coercitividades": "coercitividade",
    "coercitivos": "coercitivo",
    "coerciva": "coercivo",
    "coercivas": "coercivo",
    "coercivos": "coercivo",
    "coercímetros": "coercímetro",
    "coere": "coerir",
    "coerem": "coerir",
    "coerentes": "coerente",
    "coeres": "coerir",
    "coeri": "coerir",
    "coeria": "coerir",
    "coeriam": "coerir",
    "coerias": "coerir",
    "coerida": "coerir",
    "coeridas": "coerir",
    "coerido": "coerir",
    "coeridos": "coerir",
    "coerimo": "coerir",
    "coerimos": "coerir",
    "coerindo": "coerir",
    "coerira": "coerir",
    "coeriram": "coerir",
    "coeriras": "coerir",
    "coerirde": "coerir",
    "coerirdes": "coerir",
    "coerire": "coerir",
    "coerirei": "coerir",
    "coerireis": "coerir",
    "coerirem": "coerir",
    "coeriremos": "coerir",
    "coerires": "coerir",
    "coeriria": "coerir",
    "coeririam": "coerir",
    "coeririas": "coerir",
    "coerirmo": "coerir",
    "coerirmos": "coerir",
    "coerirá": "coerir",
    "coerirás": "coerir",
    "coerirão": "coerir",
    "coeriríamos": "coerir",
    "coeriríeis": "coerir",
    "coeris": "coerir",
    "coerisse": "coerir",
    "coerissem": "coerir",
    "coerisses": "coerir",
    "coeriste": "coerir",
    "coeristes": "coerir",
    "coeriu": "coerir",
    "coerções": "coerção",
    "coerências": "coerência",
    "coeríamo": "coerir",
    "coeríamos": "coerir",
    "coeríei": "coerir",
    "coeríeis": "coerir",
    "coeríramo": "coerir",
    "coeríramos": "coerir",
    "coerírei": "coerir",
    "coeríreis": "coerir",
    "coerísseis": "coerir",
    "coeríssemos": "coerir",
    "coes": "coar",
    "coesa": "coeso",
    "coesas": "coeso",
    "coesiva": "coesivo",
    "coesivas": "coesivo",
    "coesivos": "coesivo",
    "coesora": "coesor",
    "coesoras": "coesor",
    "coesores": "coesor",
    "coesos": "coeso",
    "coessenciais": "coessencial",
    "coessências": "coessência",
    "coestenda": "coestender",
    "coestendais": "coestender",
    "coestendam": "coestender",
    "coestendamo": "coestender",
    "coestendamos": "coestender",
    "coestendas": "coestender",
    "coestende": "coestender",
    "coestendei": "coestender",
    "coestendeis": "coestender",
    "coestendem": "coestender",
    "coestendemo": "coestender",
    "coestendemos": "coestender",
    "coestendendo": "coestender",
    "coestendera": "coestender",
    "coestenderam": "coestender",
    "coestenderas": "coestender",
    "coestenderde": "coestender",
    "coestenderdes": "coestender",
    "coestendere": "coestender",
    "coestenderei": "coestender",
    "coestendereis": "coestender",
    "coestenderem": "coestender",
    "coestenderemos": "coestender",
    "coestenderes": "coestender",
    "coestenderia": "coestender",
    "coestenderiam": "coestender",
    "coestenderias": "coestender",
    "coestendermo": "coestender",
    "coestendermos": "coestender",
    "coestenderá": "coestender",
    "coestenderás": "coestender",
    "coestenderão": "coestender",
    "coestenderíamos": "coestender",
    "coestenderíeis": "coestender",
    "coestendes": "coestender",
    "coestendesse": "coestender",
    "coestendessem": "coestender",
    "coestendesses": "coestender",
    "coestendeste": "coestender",
    "coestendestes": "coestender",
    "coestendeu": "coestender",
    "coestendi": "coestender",
    "coestendia": "coestender",
    "coestendiam": "coestender",
    "coestendias": "coestender",
    "coestendida": "coestender",
    "coestendidas": "coestender",
    "coestendido": "coestender",
    "coestendidos": "coestender",
    "coestendo": "coestender",
    "coestendê": "coestender",
    "coestendêramo": "coestender",
    "coestendêramos": "coestender",
    "coestendêrei": "coestender",
    "coestendêreis": "coestender",
    "coestendêsseis": "coestender",
    "coestendêssemos": "coestender",
    "coestendíamo": "coestender",
    "coestendíamos": "coestender",
    "coestendíei": "coestender",
    "coestendíeis": "coestender",
    "coesões": "coesão",
    "coetaneidades": "coetaneidade",
    "coeva": "coevo",
    "coevas": "coevo",
    "coevidades": "coevidade",
    "coevos": "coevo",
    "coexista": "coexistir",
    "coexistais": "coexistir",
    "coexistam": "coexistir",
    "coexistamo": "coexistir",
    "coexistamos": "coexistir",
    "coexistas": "coexistir",
    "coexiste": "coexistir",
    "coexistem": "coexistir",
    "coexistentes": "coexistente",
    "coexistes": "coexistir",
    "coexisti": "coexistir",
    "coexistia": "coexistir",
    "coexistiam": "coexistir",
    "coexistias": "coexistir",
    "coexistida": "coexistir",
    "coexistidas": "coexistir",
    "coexistido": "coexistir",
    "coexistidos": "coexistir",
    "coexistimo": "coexistir",
    "coexistimos": "coexistir",
    "coexistindo": "coexistir",
    "coexistira": "coexistir",
    "coexistiram": "coexistir",
    "coexistiras": "coexistir",
    "coexistirdes": "coexistir",
    "coexistirei": "coexistir",
    "coexistireis": "coexistir",
    "coexistirem": "coexistir",
    "coexistiremos": "coexistir",
    "coexistires": "coexistir",
    "coexistiria": "coexistir",
    "coexistiriam": "coexistir",
    "coexistirias": "coexistir",
    "coexistirmo": "coexistir",
    "coexistirmos": "coexistir",
    "coexistirá": "coexistir",
    "coexistirás": "coexistir",
    "coexistirão": "coexistir",
    "coexistiríamos": "coexistir",
    "coexistiríeis": "coexistir",
    "coexistis": "coexistir",
    "coexistisse": "coexistir",
    "coexistissem": "coexistir",
    "coexistisses": "coexistir",
    "coexististe": "coexistir",
    "coexististes": "coexistir",
    "coexistiu": "coexistir",
    "coexisto": "coexistir",
    "coexistências": "coexistência",
    "coexistíamo": "coexistir",
    "coexistíamos": "coexistir",
    "coexistíeis": "coexistir",
    "coexistíramo": "coexistir",
    "coexistíramos": "coexistir",
    "coexistíreis": "coexistir",
    "coexistísseis": "coexistir",
    "coexistíssemos": "coexistir",
    "cofia": "cofiar",
    "cofiada": "cofiar",
    "cofiadas": "cofiar",
    "cofiado": "cofiar",
    "cofiados": "cofiar",
    "cofiai": "cofiar",
    "cofiais": "cofiar",
    "cofiam": "cofiar",
    "cofiamo": "cofiar",
    "cofiamos": "cofiar",
    "cofiando": "cofiar",
    "cofiara": "cofiar",
    "cofiaram": "cofiar",
    "cofiaras": "cofiar",
    "cofiarde": "cofiar",
    "cofiardes": "cofiar",
    "cofiare": "cofiar",
    "cofiarei": "cofiar",
    "cofiareis": "cofiar",
    "cofiarem": "cofiar",
    "cofiaremos": "cofiar",
    "cofiares": "cofiar",
    "cofiaria": "cofiar",
    "cofiariam": "cofiar",
    "cofiarias": "cofiar",
    "cofiarmo": "cofiar",
    "cofiarmos": "cofiar",
    "cofiará": "cofiar",
    "cofiarás": "cofiar",
    "cofiarão": "cofiar",
    "cofiaríamos": "cofiar",
    "cofiaríeis": "cofiar",
    "cofias": "cofiar",
    "cofiasse": "cofiar",
    "cofiassem": "cofiar",
    "cofiasses": "cofiar",
    "cofiaste": "cofiar",
    "cofiastes": "cofiar",
    "cofiava": "cofiar",
    "cofiavam": "cofiar",
    "cofiavas": "cofiar",
    "cofie": "cofiar",
    "cofiei": "cofiar",
    "cofieis": "cofiar",
    "cofiem": "cofiar",
    "cofiemo": "cofiar",
    "cofiemos": "cofiar",
    "cofies": "cofiar",
    "cofinhos": "cofinho",
    "cofio": "cofiar",
    "cofiou": "cofiar",
    "cofiá": "cofiar",
    "cofiámo": "cofiar",
    "cofiámos": "cofiar",
    "cofiáramo": "cofiar",
    "cofiáramos": "cofiar",
    "cofiárei": "cofiar",
    "cofiáreis": "cofiar",
    "cofiásseis": "cofiar",
    "cofiássemos": "cofiar",
    "cofiávamo": "cofiar",
    "cofiávamos": "cofiar",
    "cofiávei": "cofiar",
    "cofiáveis": "cofiar",
    "cofos": "cofo",
    "cofoses": "cofose",
    "cofragens": "cofragem",
    "cofres": "cofre",
    "cofrezinho": "cofre",
    "cofrezinhos": "cofre",
    "cofrezito": "cofre",
    "cofrezitos": "cofre",
    "cofrezões": "cofrezão",
    "cogita": "cogitar",
    "cogitabunda": "cogitabundo",
    "cogitabundas": "cogitabundo",
    "cogitabundos": "cogitabundo",
    "cogitada": "cogitar",
    "cogitadas": "cogitar",
    "cogitado": "cogitar",
    "cogitados": "cogitar",
    "cogitai": "cogitar",
    "cogitais": "cogitar",
    "cogitam": "cogitar",
    "cogitamo": "cogitar",
    "cogitamos": "cogitar",
    "cogitando": "cogitar",
    "cogitara": "cogitar",
    "cogitaram": "cogitar",
    "cogitaras": "cogitar",
    "cogitarde": "cogitar",
    "cogitardes": "cogitar",
    "cogitare": "cogitar",
    "cogitarei": "cogitar",
    "cogitareis": "cogitar",
    "cogitarem": "cogitar",
    "cogitaremos": "cogitar",
    "cogitares": "cogitar",
    "cogitaria": "cogitar",
    "cogitariam": "cogitar",
    "cogitarias": "cogitar",
    "cogitarmo": "cogitar",
    "cogitarmos": "cogitar",
    "cogitará": "cogitar",
    "cogitarás": "cogitar",
    "cogitarão": "cogitar",
    "cogitaríamos": "cogitar",
    "cogitaríeis": "cogitar",
    "cogitas": "cogitar",
    "cogitasse": "cogitar",
    "cogitassem": "cogitar",
    "cogitasses": "cogitar",
    "cogitaste": "cogitar",
    "cogitastes": "cogitar",
    "cogitativa": "cogitativo",
    "cogitativas": "cogitativo",
    "cogitativos": "cogitativo",
    "cogitava": "cogitar",
    "cogitavam": "cogitar",
    "cogitavas": "cogitar",
    "cogitações": "cogitação",
    "cogite": "cogitar",
    "cogitei": "cogitar",
    "cogiteis": "cogitar",
    "cogitem": "cogitar",
    "cogitemo": "cogitar",
    "cogitemos": "cogitar",
    "cogites": "cogitar",
    "cogito": "cogitar",
    "cogitou": "cogitar",
    "cogitá": "cogitar",
    "cogitámo": "cogitar",
    "cogitámos": "cogitar",
    "cogitáramo": "cogitar",
    "cogitáramos": "cogitar",
    "cogitárei": "cogitar",
    "cogitáreis": "cogitar",
    "cogitásseis": "cogitar",
    "cogitássemos": "cogitar",
    "cogitávamo": "cogitar",
    "cogitávamos": "cogitar",
    "cogitávei": "cogitar",
    "cogitáveis": "cogitar",
    "cognacs": "cognac",
    "cognada": "cognado",
    "cognadas": "cognado",
    "cognados": "cognado",
    "cognata": "cognato",
    "cognatas": "cognato",
    "cognatos": "cognato",
    "cognações": "cognação",
    "cognitiva": "cognitivo",
    "cognitivas": "cognitivo",
    "cognitivos": "cognitivo",
    "cognições": "cognição",
    "cognomes": "cognome",
    "cognomina": "cognominar",
    "cognominada": "cognominar",
    "cognominadas": "cognominar",
    "cognominado": "cognominar",
    "cognominados": "cognominar",
    "cognominai": "cognominar",
    "cognominais": "cognominar",
    "cognominam": "cognominar",
    "cognominamo": "cognominar",
    "cognominamos": "cognominar",
    "cognominando": "cognominar",
    "cognominara": "cognominar",
    "cognominaram": "cognominar",
    "cognominaras": "cognominar",
    "cognominarde": "cognominar",
    "cognominardes": "cognominar",
    "cognominare": "cognominar",
    "cognominarei": "cognominar",
    "cognominareis": "cognominar",
    "cognominarem": "cognominar",
    "cognominaremos": "cognominar",
    "cognominares": "cognominar",
    "cognominaria": "cognominar",
    "cognominariam": "cognominar",
    "cognominarias": "cognominar",
    "cognominarmo": "cognominar",
    "cognominarmos": "cognominar",
    "cognominará": "cognominar",
    "cognominarás": "cognominar",
    "cognominarão": "cognominar",
    "cognominaríamos": "cognominar",
    "cognominaríeis": "cognominar",
    "cognominas": "cognominar",
    "cognominasse": "cognominar",
    "cognominassem": "cognominar",
    "cognominasses": "cognominar",
    "cognominaste": "cognominar",
    "cognominastes": "cognominar",
    "cognominava": "cognominar",
    "cognominavam": "cognominar",
    "cognominavas": "cognominar",
    "cognominações": "cognominação",
    "cognomine": "cognominar",
    "cognominei": "cognominar",
    "cognomineis": "cognominar",
    "cognominem": "cognominar",
    "cognominemo": "cognominar",
    "cognominemos": "cognominar",
    "cognomines": "cognominar",
    "cognomino": "cognominar",
    "cognominou": "cognominar",
    "cognominá": "cognominar",
    "cognominámo": "cognominar",
    "cognominámos": "cognominar",
    "cognomináramo": "cognominar",
    "cognomináramos": "cognominar",
    "cognominárei": "cognominar",
    "cognomináreis": "cognominar",
    "cognominásseis": "cognominar",
    "cognominássemos": "cognominar",
    "cognominávamo": "cognominar",
    "cognominávamos": "cognominar",
    "cognominávei": "cognominar",
    "cognomináveis": "cognominar",
    "cognoscibilidades": "cognoscibilidade",
    "cognoscitiva": "cognoscitivo",
    "cognoscitivas": "cognoscitivo",
    "cognoscitivos": "cognoscitivo",
    "cognoscíveis": "cognoscível",
    "cognática": "cognático",
    "cognáticas": "cognático",
    "cognáticos": "cognático",
    "cogoilos": "cogoilo",
    "cogombrais": "cogombral",
    "cogombros": "cogombro",
    "cogotes": "cogote",
    "cogula": "cogular",
    "cogulada": "cogular",
    "coguladas": "cogular",
    "cogulado": "cogular",
    "cogulados": "cogular",
    "cogulai": "cogular",
    "cogulais": "cogular",
    "cogulam": "cogular",
    "cogulamo": "cogular",
    "cogulamos": "cogular",
    "cogulando": "cogular",
    "cogulara": "cogular",
    "cogularam": "cogular",
    "cogularas": "cogular",
    "cogularde": "cogular",
    "cogulardes": "cogular",
    "cogulare": "cogular",
    "cogularei": "cogular",
    "cogulareis": "cogular",
    "cogularem": "cogular",
    "cogularemos": "cogular",
    "cogulares": "cogular",
    "cogularia": "cogular",
    "cogulariam": "cogular",
    "cogularias": "cogular",
    "cogularmo": "cogular",
    "cogularmos": "cogular",
    "cogulará": "cogular",
    "cogularás": "cogular",
    "cogularão": "cogular",
    "cogularíamos": "cogular",
    "cogularíeis": "cogular",
    "cogulas": "cogular",
    "cogulasse": "cogular",
    "cogulassem": "cogular",
    "cogulasses": "cogular",
    "cogulaste": "cogular",
    "cogulastes": "cogular",
    "cogulava": "cogular",
    "cogulavam": "cogular",
    "cogulavas": "cogular",
    "cogule": "cogular",
    "cogulei": "cogular",
    "coguleis": "cogular",
    "cogulem": "cogular",
    "cogulemo": "cogular",
    "cogulemos": "cogular",
    "cogules": "cogular",
    "cogulhos": "cogulho",
    "cogulo": "cogular",
    "cogulos": "cogulo",
    "cogulou": "cogular",
    "cogulá": "cogular",
    "cogulámo": "cogular",
    "cogulámos": "cogular",
    "coguláramo": "cogular",
    "coguláramos": "cogular",
    "cogulárei": "cogular",
    "coguláreis": "cogular",
    "cogulásseis": "cogular",
    "cogulássemos": "cogular",
    "cogulávamo": "cogular",
    "cogulávamos": "cogular",
    "cogulávei": "cogular",
    "coguláveis": "cogular",
    "cogumelos": "cogumelo",
    "coibais": "coibir",
    "coibamo": "coibir",
    "coibamos": "coibir",
    "coibi": "coibir",
    "coibia": "coibir",
    "coibiam": "coibir",
    "coibias": "coibir",
    "coibida": "coibir",
    "coibidas": "coibir",
    "coibido": "coibir",
    "coibidos": "coibir",
    "coibidíssima": "coibido",
    "coibidíssimas": "coibido",
    "coibidíssimo": "coibido",
    "coibidíssimos": "coibido",
    "coibimo": "coibir",
    "coibimos": "coibir",
    "coibindo": "coibir",
    "coibira": "coibir",
    "coibiram": "coibir",
    "coibiras": "coibir",
    "coibirde": "coibir",
    "coibirdes": "coibir",
    "coibire": "coibir",
    "coibirei": "coibir",
    "coibireis": "coibir",
    "coibirem": "coibir",
    "coibiremos": "coibir",
    "coibires": "coibir",
    "coibiria": "coibir",
    "coibiriam": "coibir",
    "coibirias": "coibir",
    "coibirmo": "coibir",
    "coibirmos": "coibir",
    "coibirá": "coibir",
    "coibirás": "coibir",
    "coibirão": "coibir",
    "coibiríamos": "coibir",
    "coibiríeis": "coibir",
    "coibis": "coibir",
    "coibisse": "coibir",
    "coibissem": "coibir",
    "coibisses": "coibir",
    "coibiste": "coibir",
    "coibistes": "coibir",
    "coibiu": "coibir",
    "coibições": "coibição",
    "coibíamo": "coibir",
    "coibíamos": "coibir",
    "coibíei": "coibir",
    "coibíeis": "coibir",
    "coibíramo": "coibir",
    "coibíramos": "coibir",
    "coibírei": "coibir",
    "coibíreis": "coibir",
    "coibísseis": "coibir",
    "coibíssemos": "coibir",
    "coiceada": "coicear",
    "coiceadas": "coicear",
    "coiceado": "coicear",
    "coiceados": "coicear",
    "coiceai": "coicear",
    "coiceais": "coicear",
    "coiceamo": "coicear",
    "coiceamos": "coicear",
    "coiceando": "coicear",
    "coiceara": "coicear",
    "coicearam": "coicear",
    "coicearas": "coicear",
    "coiceardes": "coicear",
    "coicearei": "coicear",
    "coiceareis": "coicear",
    "coicearem": "coicear",
    "coicearemos": "coicear",
    "coiceares": "coicear",
    "coicearia": "coicear",
    "coiceariam": "coicear",
    "coicearias": "coicear",
    "coicearmo": "coicear",
    "coicearmos": "coicear",
    "coiceará": "coicear",
    "coicearás": "coicear",
    "coicearão": "coicear",
    "coicearíamos": "coicear",
    "coicearíeis": "coicear",
    "coiceasse": "coicear",
    "coiceassem": "coicear",
    "coiceasses": "coicear",
    "coiceaste": "coicear",
    "coiceastes": "coicear",
    "coiceava": "coicear",
    "coiceavam": "coicear",
    "coiceavas": "coicear",
    "coiceei": "coicear",
    "coiceeis": "coicear",
    "coiceemo": "coicear",
    "coiceemos": "coicear",
    "coiceia": "coicear",
    "coiceiam": "coicear",
    "coiceias": "coicear",
    "coiceie": "coicear",
    "coiceiem": "coicear",
    "coiceies": "coicear",
    "coiceio": "coicear",
    "coiceiras": "coiceira",
    "coiceou": "coicear",
    "coices": "coice",
    "coiceámo": "coicear",
    "coiceámos": "coicear",
    "coiceáramo": "coicear",
    "coiceáramos": "coicear",
    "coiceáreis": "coicear",
    "coiceásseis": "coicear",
    "coiceássemos": "coicear",
    "coiceávamo": "coicear",
    "coiceávamos": "coicear",
    "coiceáveis": "coicear",
    "coifa": "coifar",
    "coifada": "coifar",
    "coifadas": "coifar",
    "coifado": "coifar",
    "coifados": "coifar",
    "coifai": "coifar",
    "coifais": "coifar",
    "coifam": "coifar",
    "coifamo": "coifar",
    "coifamos": "coifar",
    "coifando": "coifar",
    "coifara": "coifar",
    "coifaram": "coifar",
    "coifaras": "coifar",
    "coifarde": "coifar",
    "coifardes": "coifar",
    "coifare": "coifar",
    "coifarei": "coifar",
    "coifareis": "coifar",
    "coifarem": "coifar",
    "coifaremos": "coifar",
    "coifares": "coifar",
    "coifaria": "coifar",
    "coifariam": "coifar",
    "coifarias": "coifar",
    "coifarmo": "coifar",
    "coifarmos": "coifar",
    "coifará": "coifar",
    "coifarás": "coifar",
    "coifarão": "coifar",
    "coifaríamos": "coifar",
    "coifaríeis": "coifar",
    "coifas": "coifar",
    "coifasse": "coifar",
    "coifassem": "coifar",
    "coifasses": "coifar",
    "coifaste": "coifar",
    "coifastes": "coifar",
    "coifava": "coifar",
    "coifavam": "coifar",
    "coifavas": "coifar",
    "coife": "coifar",
    "coifei": "coifar",
    "coifeis": "coifar",
    "coifem": "coifar",
    "coifemo": "coifar",
    "coifemos": "coifar",
    "coifes": "coifar",
    "coifo": "coifar",
    "coifou": "coifar",
    "coifá": "coifar",
    "coifámo": "coifar",
    "coifámos": "coifar",
    "coifáramo": "coifar",
    "coifáramos": "coifar",
    "coifárei": "coifar",
    "coifáreis": "coifar",
    "coifásseis": "coifar",
    "coifássemos": "coifar",
    "coifávamo": "coifar",
    "coifávamos": "coifar",
    "coifávei": "coifar",
    "coifáveis": "coifar",
    "coima": "coimar",
    "coimada": "coimar",
    "coimadas": "coimar",
    "coimado": "coimar",
    "coimadora": "coimador",
    "coimadoras": "coimador",
    "coimadores": "coimador",
    "coimados": "coimar",
    "coimai": "coimar",
    "coimais": "coimar",
    "coimam": "coimar",
    "coimamo": "coimar",
    "coimamos": "coimar",
    "coimando": "coimar",
    "coimara": "coimar",
    "coimaram": "coimar",
    "coimaras": "coimar",
    "coimarde": "coimar",
    "coimardes": "coimar",
    "coimare": "coimar",
    "coimarei": "coimar",
    "coimareis": "coimar",
    "coimarem": "coimar",
    "coimaremos": "coimar",
    "coimares": "coimar",
    "coimaria": "coimar",
    "coimariam": "coimar",
    "coimarias": "coimar",
    "coimarmo": "coimar",
    "coimarmos": "coimar",
    "coimará": "coimar",
    "coimarás": "coimar",
    "coimarão": "coimar",
    "coimaríamos": "coimar",
    "coimaríeis": "coimar",
    "coimas": "coimar",
    "coimasse": "coimar",
    "coimassem": "coimar",
    "coimasses": "coimar",
    "coimaste": "coimar",
    "coimastes": "coimar",
    "coimava": "coimar",
    "coimavam": "coimar",
    "coimavas": "coimar",
    "coimbrenses": "coimbrense",
    "coimbrã": "coimbrão",
    "coimbrãs": "coimbrão",
    "coimbrões": "coimbrão",
    "coime": "coimar",
    "coimei": "coimar",
    "coimeira": "coimeiro",
    "coimeiras": "coimeiro",
    "coimeiros": "coimeiro",
    "coimeis": "coimar",
    "coimem": "coimar",
    "coimemo": "coimar",
    "coimemos": "coimar",
    "coimes": "coimar",
    "coimo": "coimar",
    "coimou": "coimar",
    "coimá": "coimar",
    "coimámo": "coimar",
    "coimámos": "coimar",
    "coimáramo": "coimar",
    "coimáramos": "coimar",
    "coimárei": "coimar",
    "coimáreis": "coimar",
    "coimásseis": "coimar",
    "coimássemos": "coimar",
    "coimávamo": "coimar",
    "coimávamos": "coimar",
    "coimávei": "coimar",
    "coimáveis": "coimável",
    "coina": "coinar",
    "coinada": "coinar",
    "coinadas": "coinar",
    "coinado": "coinar",
    "coinados": "coinar",
    "coinai": "coinar",
    "coinais": "coinar",
    "coinam": "coinar",
    "coinamo": "coinar",
    "coinamos": "coinar",
    "coinando": "coinar",
    "coinara": "coinar",
    "coinaram": "coinar",
    "coinaras": "coinar",
    "coinarde": "coinar",
    "coinardes": "coinar",
    "coinare": "coinar",
    "coinarei": "coinar",
    "coinareis": "coinar",
    "coinarem": "coinar",
    "coinaremos": "coinar",
    "coinares": "coinar",
    "coinaria": "coinar",
    "coinariam": "coinar",
    "coinarias": "coinar",
    "coinarmo": "coinar",
    "coinarmos": "coinar",
    "coinará": "coinar",
    "coinarás": "coinar",
    "coinarão": "coinar",
    "coinaríamos": "coinar",
    "coinaríeis": "coinar",
    "coinas": "coinar",
    "coinasse": "coinar",
    "coinassem": "coinar",
    "coinasses": "coinar",
    "coinaste": "coinar",
    "coinastes": "coinar",
    "coinava": "coinar",
    "coinavam": "coinar",
    "coinavas": "coinar",
    "coincida": "coincidir",
    "coincidais": "coincidir",
    "coincidam": "coincidir",
    "coincidamo": "coincidir",
    "coincidamos": "coincidir",
    "coincidas": "coincidir",
    "coincide": "coincidir",
    "coincidem": "coincidir",
    "coincidentes": "coincidente",
    "coincides": "coincidir",
    "coincidi": "coincidir",
    "coincidia": "coincidir",
    "coincidiam": "coincidir",
    "coincidias": "coincidir",
    "coincidida": "coincidir",
    "coincididas": "coincidir",
    "coincidido": "coincidir",
    "coincididos": "coincidir",
    "coincidimo": "coincidir",
    "coincidimos": "coincidir",
    "coincidindo": "coincidir",
    "coincidira": "coincidir",
    "coincidiram": "coincidir",
    "coincidiras": "coincidir",
    "coincidirdes": "coincidir",
    "coincidirei": "coincidir",
    "coincidireis": "coincidir",
    "coincidirem": "coincidir",
    "coincidiremos": "coincidir",
    "coincidires": "coincidir",
    "coincidiria": "coincidir",
    "coincidiriam": "coincidir",
    "coincidirias": "coincidir",
    "coincidirmo": "coincidir",
    "coincidirmos": "coincidir",
    "coincidirá": "coincidir",
    "coincidirás": "coincidir",
    "coincidirão": "coincidir",
    "coincidiríamos": "coincidir",
    "coincidiríeis": "coincidir",
    "coincidis": "coincidir",
    "coincidisse": "coincidir",
    "coincidissem": "coincidir",
    "coincidisses": "coincidir",
    "coincidiste": "coincidir",
    "coincidistes": "coincidir",
    "coincidiu": "coincidir",
    "coincido": "coincidir",
    "coincidências": "coincidência",
    "coincidíamo": "coincidir",
    "coincidíamos": "coincidir",
    "coincidíeis": "coincidir",
    "coincidíramo": "coincidir",
    "coincidíramos": "coincidir",
    "coincidíreis": "coincidir",
    "coincidísseis": "coincidir",
    "coincidíssemos": "coincidir",
    "coincidíveis": "coincidível",
    "coindica": "coindicar",
    "coindicada": "coindicar",
    "coindicadas": "coindicar",
    "coindicado": "coindicar",
    "coindicados": "coindicar",
    "coindicai": "coindicar",
    "coindicais": "coindicar",
    "coindicam": "coindicar",
    "coindicamo": "coindicar",
    "coindicamos": "coindicar",
    "coindicando": "coindicar",
    "coindicantes": "coindicante",
    "coindicara": "coindicar",
    "coindicaram": "coindicar",
    "coindicaras": "coindicar",
    "coindicarde": "coindicar",
    "coindicardes": "coindicar",
    "coindicare": "coindicar",
    "coindicarei": "coindicar",
    "coindicareis": "coindicar",
    "coindicarem": "coindicar",
    "coindicaremos": "coindicar",
    "coindicares": "coindicar",
    "coindicaria": "coindicar",
    "coindicariam": "coindicar",
    "coindicarias": "coindicar",
    "coindicarmo": "coindicar",
    "coindicarmos": "coindicar",
    "coindicará": "coindicar",
    "coindicarás": "coindicar",
    "coindicarão": "coindicar",
    "coindicaríamos": "coindicar",
    "coindicaríeis": "coindicar",
    "coindicas": "coindicar",
    "coindicasse": "coindicar",
    "coindicassem": "coindicar",
    "coindicasses": "coindicar",
    "coindicaste": "coindicar",
    "coindicastes": "coindicar",
    "coindicava": "coindicar",
    "coindicavam": "coindicar",
    "coindicavas": "coindicar",
    "coindicações": "coindicação",
    "coindico": "coindicar",
    "coindicou": "coindicar",
    "coindicá": "coindicar",
    "coindicámo": "coindicar",
    "coindicámos": "coindicar",
    "coindicáramo": "coindicar",
    "coindicáramos": "coindicar",
    "coindicárei": "coindicar",
    "coindicáreis": "coindicar",
    "coindicásseis": "coindicar",
    "coindicássemos": "coindicar",
    "coindicávamo": "coindicar",
    "coindicávamos": "coindicar",
    "coindicávei": "coindicar",
    "coindicáveis": "coindicar",
    "coindique": "coindicar",
    "coindiquei": "coindicar",
    "coindiqueis": "coindicar",
    "coindiquem": "coindicar",
    "coindiquemo": "coindicar",
    "coindiquemos": "coindicar",
    "coindiques": "coindicar",
    "coine": "coinar",
    "coinei": "coinar",
    "coineis": "coinar",
    "coinem": "coinar",
    "coinemo": "coinar",
    "coinemos": "coinar",
    "coines": "coinar",
    "coino": "coinar",
    "coinou": "coinar",
    "coinquina": "coinquinar",
    "coinquinada": "coinquinar",
    "coinquinadas": "coinquinar",
    "coinquinado": "coinquinar",
    "coinquinados": "coinquinar",
    "coinquinai": "coinquinar",
    "coinquinais": "coinquinar",
    "coinquinam": "coinquinar",
    "coinquinamo": "coinquinar",
    "coinquinamos": "coinquinar",
    "coinquinando": "coinquinar",
    "coinquinara": "coinquinar",
    "coinquinaram": "coinquinar",
    "coinquinaras": "coinquinar",
    "coinquinarde": "coinquinar",
    "coinquinardes": "coinquinar",
    "coinquinare": "coinquinar",
    "coinquinarei": "coinquinar",
    "coinquinareis": "coinquinar",
    "coinquinarem": "coinquinar",
    "coinquinaremos": "coinquinar",
    "coinquinares": "coinquinar",
    "coinquinaria": "coinquinar",
    "coinquinariam": "coinquinar",
    "coinquinarias": "coinquinar",
    "coinquinarmo": "coinquinar",
    "coinquinarmos": "coinquinar",
    "coinquinará": "coinquinar",
    "coinquinarás": "coinquinar",
    "coinquinarão": "coinquinar",
    "coinquinaríamos": "coinquinar",
    "coinquinaríeis": "coinquinar",
    "coinquinas": "coinquinar",
    "coinquinasse": "coinquinar",
    "coinquinassem": "coinquinar",
    "coinquinasses": "coinquinar",
    "coinquinaste": "coinquinar",
    "coinquinastes": "coinquinar",
    "coinquinava": "coinquinar",
    "coinquinavam": "coinquinar",
    "coinquinavas": "coinquinar",
    "coinquine": "coinquinar",
    "coinquinei": "coinquinar",
    "coinquineis": "coinquinar",
    "coinquinem": "coinquinar",
    "coinquinemo": "coinquinar",
    "coinquinemos": "coinquinar",
    "coinquines": "coinquinar",
    "coinquino": "coinquinar",
    "coinquinou": "coinquinar",
    "coinquiná": "coinquinar",
    "coinquinámo": "coinquinar",
    "coinquinámos": "coinquinar",
    "coinquináramo": "coinquinar",
    "coinquináramos": "coinquinar",
    "coinquinárei": "coinquinar",
    "coinquináreis": "coinquinar",
    "coinquinásseis": "coinquinar",
    "coinquinássemos": "coinquinar",
    "coinquinávamo": "coinquinar",
    "coinquinávamos": "coinquinar",
    "coinquinávei": "coinquinar",
    "coinquináveis": "coinquinar",
    "coins": "coim",
    "coiná": "coinar",
    "coinámo": "coinar",
    "coinámos": "coinar",
    "coináramo": "coinar",
    "coináramos": "coinar",
    "coinárei": "coinar",
    "coináreis": "coinar",
    "coinásseis": "coinar",
    "coinássemos": "coinar",
    "coinávamo": "coinar",
    "coinávamos": "coinar",
    "coinávei": "coinar",
    "coináveis": "coinar",
    "coinés": "coiné",
    "coios": "coio",
    "coiotes": "coiote",
    "coipilos": "coipilo",
    "coiquinhos": "coiquinho",
    "coira": "coerir",
    "coirace": "coiraçar",
    "coiracei": "coiraçar",
    "coiraceiros": "coiraceiro",
    "coiraceis": "coiraçar",
    "coiracem": "coiraçar",
    "coiracemo": "coiraçar",
    "coiracemos": "coiraçar",
    "coiraces": "coiraçar",
    "coiracha": "coiracho",
    "coirachas": "coiracho",
    "coirachos": "coiracho",
    "coirais": "coerir",
    "coiram": "coerir",
    "coiramas": "coirama",
    "coiramo": "coerir",
    "coiramos": "coerir",
    "coiras": "coira",
    "coiratas": "coirata",
    "coiratos": "coirato",
    "coiraça": "coiraçar",
    "coiraçada": "coiraçar",
    "coiraçadas": "coiraçar",
    "coiraçado": "coiraçar",
    "coiraçados": "coiraçar",
    "coiraçai": "coiraçar",
    "coiraçais": "coiraçar",
    "coiraçam": "coiraçar",
    "coiraçamo": "coiraçar",
    "coiraçamos": "coiraçar",
    "coiraçando": "coiraçar",
    "coiraçara": "coiraçar",
    "coiraçaram": "coiraçar",
    "coiraçaras": "coiraçar",
    "coiraçarde": "coiraçar",
    "coiraçardes": "coiraçar",
    "coiraçare": "coiraçar",
    "coiraçarei": "coiraçar",
    "coiraçareis": "coiraçar",
    "coiraçarem": "coiraçar",
    "coiraçaremos": "coiraçar",
    "coiraçares": "coiraçar",
    "coiraçaria": "coiraçar",
    "coiraçariam": "coiraçar",
    "coiraçarias": "coiraçar",
    "coiraçarmo": "coiraçar",
    "coiraçarmos": "coiraçar",
    "coiraçará": "coiraçar",
    "coiraçarás": "coiraçar",
    "coiraçarão": "coiraçar",
    "coiraçaríamos": "coiraçar",
    "coiraçaríeis": "coiraçar",
    "coiraças": "coiraçar",
    "coiraçasse": "coiraçar",
    "coiraçassem": "coiraçar",
    "coiraçasses": "coiraçar",
    "coiraçaste": "coiraçar",
    "coiraçastes": "coiraçar",
    "coiraçava": "coiraçar",
    "coiraçavam": "coiraçar",
    "coiraçavas": "coiraçar",
    "coiraço": "coiraçar",
    "coiraçou": "coiraçar",
    "coiraçá": "coiraçar",
    "coiraçámo": "coiraçar",
    "coiraçámos": "coiraçar",
    "coiraçáramo": "coiraçar",
    "coiraçáramos": "coiraçar",
    "coiraçárei": "coiraçar",
    "coiraçáreis": "coiraçar",
    "coiraçásseis": "coiraçar",
    "coiraçássemos": "coiraçar",
    "coiraçávamo": "coiraçar",
    "coiraçávamos": "coiraçar",
    "coiraçávei": "coiraçar",
    "coiraçáveis": "coiraçar",
    "coireiros": "coireiro",
    "coirelada": "coirelado",
    "coireladas": "coirelado",
    "coirelados": "coirelado",
    "coirelas": "coirela",
    "coireleiros": "coireleiro",
    "coirmã": "coirmão",
    "coirmãos": "coirmão",
    "coirmãs": "coirmão",
    "coiro": "coerir",
    "coiros": "coiro",
    "coirões": "coirão",
    "coisadas": "coisada",
    "coisas": "coisa",
    "coisifica": "coisificar",
    "coisificada": "coisificar",
    "coisificadas": "coisificar",
    "coisificado": "coisificar",
    "coisificados": "coisificar",
    "coisificai": "coisificar",
    "coisificais": "coisificar",
    "coisificam": "coisificar",
    "coisificamo": "coisificar",
    "coisificamos": "coisificar",
    "coisificando": "coisificar",
    "coisificara": "coisificar",
    "coisificaram": "coisificar",
    "coisificaras": "coisificar",
    "coisificarde": "coisificar",
    "coisificardes": "coisificar",
    "coisificare": "coisificar",
    "coisificarei": "coisificar",
    "coisificareis": "coisificar",
    "coisificarem": "coisificar",
    "coisificaremos": "coisificar",
    "coisificares": "coisificar",
    "coisificaria": "coisificar",
    "coisificariam": "coisificar",
    "coisificarias": "coisificar",
    "coisificarmo": "coisificar",
    "coisificarmos": "coisificar",
    "coisificará": "coisificar",
    "coisificarás": "coisificar",
    "coisificarão": "coisificar",
    "coisificaríamos": "coisificar",
    "coisificaríeis": "coisificar",
    "coisificas": "coisificar",
    "coisificasse": "coisificar",
    "coisificassem": "coisificar",
    "coisificasses": "coisificar",
    "coisificaste": "coisificar",
    "coisificastes": "coisificar",
    "coisificava": "coisificar",
    "coisificavam": "coisificar",
    "coisificavas": "coisificar",
    "coisificações": "coisificação",
    "coisifico": "coisificar",
    "coisificou": "coisificar",
    "coisificá": "coisificar",
    "coisificámo": "coisificar",
    "coisificámos": "coisificar",
    "coisificáramo": "coisificar",
    "coisificáramos": "coisificar",
    "coisificárei": "coisificar",
    "coisificáreis": "coisificar",
    "coisificásseis": "coisificar",
    "coisificássemos": "coisificar",
    "coisificávamo": "coisificar",
    "coisificávamos": "coisificar",
    "coisificávei": "coisificar",
    "coisificáveis": "coisificar",
    "coisifique": "coisificar",
    "coisifiquei": "coisificar",
    "coisifiqueis": "coisificar",
    "coisifiquem": "coisificar",
    "coisifiquemo": "coisificar",
    "coisifiquemos": "coisificar",
    "coisifiques": "coisificar",
    "coisinha": "coisa",
    "coisinhas": "coisa",
    "coisita": "coisa",
    "coisitas": "coisa",
    "coisos": "coiso",
    "coita": "coitar",
    "coitada": "coitar",
    "coitadas": "coitar",
    "coitadinha": "coitado",
    "coitadinhas": "coitado",
    "coitadinho": "coitado",
    "coitadinhos": "coitado",
    "coitadita": "coitado",
    "coitaditas": "coitado",
    "coitadito": "coitado",
    "coitaditos": "coitado",
    "coitado": "coitar",
    "coitados": "coitar",
    "coitadíssima": "coitado",
    "coitadíssimas": "coitado",
    "coitadíssimo": "coitado",
    "coitadíssimos": "coitado",
    "coitai": "coitar",
    "coitais": "coitar",
    "coitam": "coitar",
    "coitamentos": "coitamento",
    "coitamo": "coitar",
    "coitamos": "coitar",
    "coitando": "coitar",
    "coitara": "coitar",
    "coitaram": "coitar",
    "coitaras": "coitar",
    "coitarde": "coitar",
    "coitardes": "coitar",
    "coitare": "coitar",
    "coitarei": "coitar",
    "coitareis": "coitar",
    "coitarem": "coitar",
    "coitaremos": "coitar",
    "coitares": "coitar",
    "coitaria": "coitar",
    "coitariam": "coitar",
    "coitarias": "coitaria",
    "coitarmo": "coitar",
    "coitarmos": "coitar",
    "coitará": "coitar",
    "coitarás": "coitar",
    "coitarão": "coitar",
    "coitaríamos": "coitar",
    "coitaríeis": "coitar",
    "coitas": "coitar",
    "coitasse": "coitar",
    "coitassem": "coitar",
    "coitasses": "coitar",
    "coitaste": "coitar",
    "coitastes": "coitar",
    "coitava": "coitar",
    "coitavam": "coitar",
    "coitavas": "coitar",
    "coite": "coitar",
    "coitei": "coitar",
    "coiteiros": "coiteiro",
    "coiteis": "coitar",
    "coitelhos": "coitelho",
    "coitem": "coitar",
    "coitemo": "coitar",
    "coitemos": "coitar",
    "coites": "coitar",
    "coito": "coitar",
    "coitos": "coito",
    "coitou": "coitar",
    "coitá": "coitar",
    "coitámo": "coitar",
    "coitámos": "coitar",
    "coitáramo": "coitar",
    "coitáramos": "coitar",
    "coitárei": "coitar",
    "coitáreis": "coitar",
    "coitásseis": "coitar",
    "coitássemos": "coitar",
    "coitávamo": "coitar",
    "coitávamos": "coitar",
    "coitávei": "coitar",
    "coitáveis": "coitar",
    "coiçoeiras": "coiçoeira",
    "coiós": "coió",
    "cola": "colar",
    "colabescentes": "colabescente",
    "colabora": "colaborar",
    "colaboracionismos": "colaboracionismo",
    "colaboracionistas": "colaboracionista",
    "colaborada": "colaborar",
    "colaboradas": "colaborar",
    "colaborado": "colaborar",
    "colaboradora": "colaborador",
    "colaboradoras": "colaborador",
    "colaboradores": "colaborador",
    "colaborados": "colaborar",
    "colaborai": "colaborar",
    "colaborais": "colaborar",
    "colaboram": "colaborar",
    "colaboramo": "colaborar",
    "colaboramos": "colaborar",
    "colaborando": "colaborar",
    "colaborantes": "colaborante",
    "colaborara": "colaborar",
    "colaboraram": "colaborar",
    "colaboraras": "colaborar",
    "colaborardes": "colaborar",
    "colaborarei": "colaborar",
    "colaborareis": "colaborar",
    "colaborarem": "colaborar",
    "colaboraremos": "colaborar",
    "colaborares": "colaborar",
    "colaboraria": "colaborar",
    "colaborariam": "colaborar",
    "colaborarias": "colaborar",
    "colaborarmo": "colaborar",
    "colaborarmos": "colaborar",
    "colaborará": "colaborar",
    "colaborarás": "colaborar",
    "colaborarão": "colaborar",
    "colaboraríamos": "colaborar",
    "colaboraríeis": "colaborar",
    "colaboras": "colaborar",
    "colaborasse": "colaborar",
    "colaborassem": "colaborar",
    "colaborasses": "colaborar",
    "colaboraste": "colaborar",
    "colaborastes": "colaborar",
    "colaborava": "colaborar",
    "colaboravam": "colaborar",
    "colaboravas": "colaborar",
    "colaborações": "colaboração",
    "colabore": "colaborar",
    "colaborei": "colaborar",
    "colaboreis": "colaborar",
    "colaborem": "colaborar",
    "colaboremo": "colaborar",
    "colaboremos": "colaborar",
    "colabores": "colaborar",
    "colaboro": "colaborar",
    "colaborou": "colaborar",
    "colaborámo": "colaborar",
    "colaborámos": "colaborar",
    "colaboráramo": "colaborar",
    "colaboráramos": "colaborar",
    "colaboráreis": "colaborar",
    "colaborásseis": "colaborar",
    "colaborássemos": "colaborar",
    "colaborávamo": "colaborar",
    "colaborávamos": "colaborar",
    "colaboráveis": "colaborar",
    "colacias": "colacia",
    "colaciona": "colacionar",
    "colacionada": "colacionar",
    "colacionadas": "colacionar",
    "colacionado": "colacionar",
    "colacionados": "colacionar",
    "colacionai": "colacionar",
    "colacionais": "colacionar",
    "colacionam": "colacionar",
    "colacionamo": "colacionar",
    "colacionamos": "colacionar",
    "colacionando": "colacionar",
    "colacionara": "colacionar",
    "colacionaram": "colacionar",
    "colacionaras": "colacionar",
    "colacionarde": "colacionar",
    "colacionardes": "colacionar",
    "colacionare": "colacionar",
    "colacionarei": "colacionar",
    "colacionareis": "colacionar",
    "colacionarem": "colacionar",
    "colacionaremos": "colacionar",
    "colacionares": "colacionar",
    "colacionaria": "colacionar",
    "colacionariam": "colacionar",
    "colacionarias": "colacionar",
    "colacionarmo": "colacionar",
    "colacionarmos": "colacionar",
    "colacionará": "colacionar",
    "colacionarás": "colacionar",
    "colacionarão": "colacionar",
    "colacionaríamos": "colacionar",
    "colacionaríeis": "colacionar",
    "colacionas": "colacionar",
    "colacionasse": "colacionar",
    "colacionassem": "colacionar",
    "colacionasses": "colacionar",
    "colacionaste": "colacionar",
    "colacionastes": "colacionar",
    "colacionava": "colacionar",
    "colacionavam": "colacionar",
    "colacionavas": "colacionar",
    "colacione": "colacionar",
    "colacionei": "colacionar",
    "colacioneis": "colacionar",
    "colacionem": "colacionar",
    "colacionemo": "colacionar",
    "colacionemos": "colacionar",
    "colaciones": "colacionar",
    "colaciono": "colacionar",
    "colacionou": "colacionar",
    "colacioná": "colacionar",
    "colacionámo": "colacionar",
    "colacionámos": "colacionar",
    "colacionáramo": "colacionar",
    "colacionáramos": "colacionar",
    "colacionárei": "colacionar",
    "colacionáreis": "colacionar",
    "colacionásseis": "colacionar",
    "colacionássemos": "colacionar",
    "colacionávamo": "colacionar",
    "colacionávamos": "colacionar",
    "colacionávei": "colacionar",
    "colacionáveis": "colacionar",
    "colada": "colar",
    "coladas": "colar",
    "colado": "colar",
    "coladores": "colador",
    "colados": "colar",
    "colagens": "colagem",
    "colagoga": "colagogo",
    "colagogas": "colagogo",
    "colagogos": "colagogo",
    "colagógica": "colagógico",
    "colagógicas": "colagógico",
    "colagógicos": "colagógico",
    "colai": "colar",
    "colais": "colar",
    "colalgias": "colalgia",
    "colam": "colar",
    "colamo": "colar",
    "colamos": "colar",
    "colando": "colar",
    "colantes": "colante",
    "colapsos": "colapso",
    "colara": "colar",
    "colaram": "colar",
    "colaras": "colar",
    "colarde": "colar",
    "colardes": "colar",
    "colare": "colar",
    "colarei": "colar",
    "colareis": "colar",
    "colarejas": "colareja",
    "colarem": "colar",
    "colaremos": "colar",
    "colares": "colar",
    "colaretes": "colarete",
    "colargóis": "colargol",
    "colaria": "colar",
    "colariam": "colar",
    "colarias": "colar",
    "colarinhos": "colarinho",
    "colarmo": "colar",
    "colarmos": "colar",
    "colará": "colar",
    "colarás": "colar",
    "colarão": "colar",
    "colaríamos": "colar",
    "colaríeis": "colar",
    "colas": "colar",
    "colasse": "colar",
    "colassem": "colar",
    "colasses": "colar",
    "colaste": "colar",
    "colastes": "colar",
    "colaterais": "colateral",
    "colateralidades": "colateralidade",
    "colativa": "colativo",
    "colativas": "colativo",
    "colativos": "colativo",
    "colatora": "colator",
    "colatoras": "colator",
    "colatores": "colator",
    "colatários": "colatário",
    "colatória": "colatório",
    "colatórias": "colatório",
    "colatórios": "colatório",
    "colava": "colar",
    "colavam": "colar",
    "colavas": "colar",
    "colaça": "colaço",
    "colaças": "colaço",
    "colaços": "colaço",
    "colações": "colação",
    "colchas": "colcha",
    "colcheias": "colcheia",
    "colcheiros": "colcheiro",
    "colchetas": "colcheta",
    "colcheteada": "colchetear",
    "colcheteadas": "colchetear",
    "colcheteado": "colchetear",
    "colcheteados": "colchetear",
    "colcheteai": "colchetear",
    "colcheteais": "colchetear",
    "colcheteamo": "colchetear",
    "colcheteamos": "colchetear",
    "colcheteando": "colchetear",
    "colcheteara": "colchetear",
    "colchetearam": "colchetear",
    "colchetearas": "colchetear",
    "colchetearde": "colchetear",
    "colcheteardes": "colchetear",
    "colcheteare": "colchetear",
    "colchetearei": "colchetear",
    "colcheteareis": "colchetear",
    "colchetearem": "colchetear",
    "colchetearemos": "colchetear",
    "colcheteares": "colchetear",
    "colchetearia": "colchetear",
    "colcheteariam": "colchetear",
    "colchetearias": "colchetear",
    "colchetearmo": "colchetear",
    "colchetearmos": "colchetear",
    "colcheteará": "colchetear",
    "colchetearás": "colchetear",
    "colchetearão": "colchetear",
    "colchetearíamos": "colchetear",
    "colchetearíeis": "colchetear",
    "colcheteasse": "colchetear",
    "colcheteassem": "colchetear",
    "colcheteasses": "colchetear",
    "colcheteaste": "colchetear",
    "colcheteastes": "colchetear",
    "colcheteava": "colchetear",
    "colcheteavam": "colchetear",
    "colcheteavas": "colchetear",
    "colcheteei": "colchetear",
    "colcheteeis": "colchetear",
    "colcheteemo": "colchetear",
    "colcheteemos": "colchetear",
    "colcheteia": "colchetear",
    "colcheteiam": "colchetear",
    "colcheteias": "colchetear",
    "colcheteie": "colchetear",
    "colcheteiem": "colchetear",
    "colcheteies": "colchetear",
    "colcheteio": "colchetear",
    "colcheteou": "colchetear",
    "colchetes": "colchete",
    "colcheteá": "colchetear",
    "colcheteámo": "colchetear",
    "colcheteámos": "colchetear",
    "colcheteáramo": "colchetear",
    "colcheteáramos": "colchetear",
    "colcheteárei": "colchetear",
    "colcheteáreis": "colchetear",
    "colcheteásseis": "colchetear",
    "colcheteássemos": "colchetear",
    "colcheteávamo": "colchetear",
    "colcheteávamos": "colchetear",
    "colcheteávei": "colchetear",
    "colcheteáveis": "colchetear",
    "colchoa": "colchoar",
    "colchoada": "colchoar",
    "colchoadas": "colchoar",
    "colchoado": "colchoar",
    "colchoados": "colchoar",
    "colchoai": "colchoar",
    "colchoais": "colchoar",
    "colchoam": "colchoar",
    "colchoamo": "colchoar",
    "colchoamos": "colchoar",
    "colchoando": "colchoar",
    "colchoara": "colchoar",
    "colchoaram": "colchoar",
    "colchoaras": "colchoar",
    "colchoarde": "colchoar",
    "colchoardes": "colchoar",
    "colchoare": "colchoar",
    "colchoarei": "colchoar",
    "colchoareis": "colchoar",
    "colchoarem": "colchoar",
    "colchoaremos": "colchoar",
    "colchoares": "colchoar",
    "colchoaria": "colchoar",
    "colchoariam": "colchoar",
    "colchoarias": "colchoaria",
    "colchoarmo": "colchoar",
    "colchoarmos": "colchoar",
    "colchoará": "colchoar",
    "colchoarás": "colchoar",
    "colchoarão": "colchoar",
    "colchoaríamos": "colchoar",
    "colchoaríeis": "colchoar",
    "colchoas": "colchoar",
    "colchoasse": "colchoar",
    "colchoassem": "colchoar",
    "colchoasses": "colchoar",
    "colchoaste": "colchoar",
    "colchoastes": "colchoar",
    "colchoava": "colchoar",
    "colchoavam": "colchoar",
    "colchoavas": "colchoar",
    "colchoe": "colchoar",
    "colchoei": "colchoar",
    "colchoeiros": "colchoeiro",
    "colchoeis": "colchoar",
    "colchoem": "colchoar",
    "colchoemo": "colchoar",
    "colchoemos": "colchoar",
    "colchoes": "colchoar",
    "colchoo": "colchoar",
    "colchoou": "colchoar",
    "colchoá": "colchoar",
    "colchoámo": "colchoar",
    "colchoámos": "colchoar",
    "colchoáramo": "colchoar",
    "colchoáramos": "colchoar",
    "colchoárei": "colchoar",
    "colchoáreis": "colchoar",
    "colchoásseis": "colchoar",
    "colchoássemos": "colchoar",
    "colchoávamo": "colchoar",
    "colchoávamos": "colchoar",
    "colchoávei": "colchoar",
    "colchoáveis": "colchoar",
    "colchões": "colchão",
    "coldres": "coldre",
    "cole": "colar",
    "coleada": "colear",
    "coleadas": "colear",
    "coleado": "colear",
    "coleados": "colear",
    "coleai": "colear",
    "coleais": "colear",
    "coleamentos": "coleamento",
    "coleamo": "colear",
    "coleamos": "colear",
    "coleando": "colear",
    "coleantes": "coleante",
    "coleara": "colear",
    "colearam": "colear",
    "colearas": "colear",
    "coleardes": "colear",
    "colearei": "colear",
    "coleareis": "colear",
    "colearem": "colear",
    "colearemos": "colear",
    "coleares": "colear",
    "colearia": "colear",
    "coleariam": "colear",
    "colearias": "colear",
    "colearmo": "colear",
    "colearmos": "colear",
    "coleará": "colear",
    "colearás": "colear",
    "colearão": "colear",
    "colearíamos": "colear",
    "colearíeis": "colear",
    "coleasse": "colear",
    "coleassem": "colear",
    "coleasses": "colear",
    "coleaste": "colear",
    "coleastes": "colear",
    "coleava": "colear",
    "coleavam": "colear",
    "coleavas": "colear",
    "colecciona": "coleccionar",
    "coleccionada": "coleccionar",
    "coleccionadas": "coleccionar",
    "coleccionado": "coleccionar",
    "coleccionadora": "coleccionador",
    "coleccionadoras": "coleccionador",
    "coleccionadores": "coleccionador",
    "coleccionados": "coleccionar",
    "coleccionai": "coleccionar",
    "coleccionais": "coleccionar",
    "coleccionam": "coleccionar",
    "coleccionamo": "coleccionar",
    "coleccionamos": "coleccionar",
    "coleccionando": "coleccionar",
    "coleccionara": "coleccionar",
    "coleccionaram": "coleccionar",
    "coleccionaras": "coleccionar",
    "coleccionarde": "coleccionar",
    "coleccionardes": "coleccionar",
    "coleccionare": "coleccionar",
    "coleccionarei": "coleccionar",
    "coleccionareis": "coleccionar",
    "coleccionarem": "coleccionar",
    "coleccionaremos": "coleccionar",
    "coleccionares": "coleccionar",
    "coleccionaria": "coleccionar",
    "coleccionariam": "coleccionar",
    "coleccionarias": "coleccionar",
    "coleccionarmo": "coleccionar",
    "coleccionarmos": "coleccionar",
    "coleccionará": "coleccionar",
    "coleccionarás": "coleccionar",
    "coleccionarão": "coleccionar",
    "coleccionaríamos": "coleccionar",
    "coleccionaríeis": "coleccionar",
    "coleccionas": "coleccionar",
    "coleccionasse": "coleccionar",
    "coleccionassem": "coleccionar",
    "coleccionasses": "coleccionar",
    "coleccionaste": "coleccionar",
    "coleccionastes": "coleccionar",
    "coleccionava": "coleccionar",
    "coleccionavam": "coleccionar",
    "coleccionavas": "coleccionar",
    "coleccionações": "coleccionação",
    "coleccione": "coleccionar",
    "coleccionei": "coleccionar",
    "coleccioneis": "coleccionar",
    "coleccionem": "coleccionar",
    "coleccionemo": "coleccionar",
    "coleccionemos": "coleccionar",
    "colecciones": "coleccionar",
    "coleccionismos": "coleccionismo",
    "coleccionistas": "coleccionista",
    "colecciono": "coleccionar",
    "coleccionou": "coleccionar",
    "coleccioná": "coleccionar",
    "coleccionámo": "coleccionar",
    "coleccionámos": "coleccionar",
    "coleccionáramo": "coleccionar",
    "coleccionáramos": "coleccionar",
    "coleccionárei": "coleccionar",
    "coleccionáreis": "coleccionar",
    "coleccionásseis": "coleccionar",
    "coleccionássemos": "coleccionar",
    "coleccionávamo": "coleccionar",
    "coleccionávamos": "coleccionar",
    "coleccionávei": "coleccionar",
    "coleccionáveis": "coleccionável",
    "colecistes": "coleciste",
    "colecistites": "colecistite",
    "colecta": "colectar",
    "colectada": "colectar",
    "colectadas": "colectar",
    "colectado": "colectar",
    "colectados": "colectar",
    "colectai": "colectar",
    "colectais": "colectar",
    "colectam": "colectar",
    "colectamo": "colectar",
    "colectamos": "colectar",
    "colectando": "colectar",
    "colectara": "colectar",
    "colectaram": "colectar",
    "colectaras": "colectar",
    "colectarde": "colectar",
    "colectardes": "colectar",
    "colectare": "colectar",
    "colectarei": "colectar",
    "colectareis": "colectar",
    "colectarem": "colectar",
    "colectaremos": "colectar",
    "colectares": "colectar",
    "colectaria": "colectar",
    "colectariam": "colectar",
    "colectarias": "colectar",
    "colectarmo": "colectar",
    "colectarmos": "colectar",
    "colectará": "colectar",
    "colectarás": "colectar",
    "colectarão": "colectar",
    "colectaríamos": "colectar",
    "colectaríeis": "colectar",
    "colectas": "colectar",
    "colectasse": "colectar",
    "colectassem": "colectar",
    "colectasses": "colectar",
    "colectaste": "colectar",
    "colectastes": "colectar",
    "colectava": "colectar",
    "colectavam": "colectar",
    "colectavas": "colectar",
    "colecte": "colectar",
    "colectei": "colectar",
    "colecteis": "colectar",
    "colectem": "colectar",
    "colectemo": "colectar",
    "colectemos": "colectar",
    "colectes": "colectar",
    "colectiva": "colectivo",
    "colectivas": "colectivo",
    "colectividades": "colectividade",
    "colectivismos": "colectivismo",
    "colectivistas": "colectivista",
    "colectivizações": "colectivização",
    "colectivos": "colectivo",
    "colecto": "colectar",
    "colectomias": "colectomia",
    "colectora": "colector",
    "colectoras": "colector",
    "colectores": "colector",
    "colectorias": "colectoria",
    "colectou": "colectar",
    "colectá": "colectar",
    "colectámo": "colectar",
    "colectámos": "colectar",
    "colectáramo": "colectar",
    "colectáramos": "colectar",
    "colectárei": "colectar",
    "colectáreis": "colectar",
    "colectária": "colectário",
    "colectárias": "colectário",
    "colectários": "colectário",
    "colectásseis": "colectar",
    "colectássemos": "colectar",
    "colectávamo": "colectar",
    "colectávamos": "colectar",
    "colectávei": "colectar",
    "colectáveis": "colectável",
    "colectânea": "colectâneo",
    "colectâneas": "colectâneo",
    "colectâneos": "colectâneo",
    "colecções": "colecção",
    "coledoquites": "coledoquite",
    "coleei": "colear",
    "coleeis": "colear",
    "coleemo": "colear",
    "coleemos": "colear",
    "colegas": "colega",
    "colegiais": "colegial",
    "colegiaturas": "colegiatura",
    "colegu": "colega",
    "coleguismos": "coleguismo",
    "colegus": "colega",
    "colei": "colar",
    "coleia": "colear",
    "coleiam": "colear",
    "coleias": "colear",
    "coleie": "colear",
    "coleiem": "colear",
    "coleies": "colear",
    "coleio": "colear",
    "coleios": "coleio",
    "coleirada": "coleirado",
    "coleiradas": "coleirado",
    "coleirados": "coleirado",
    "coleiras": "coleira",
    "coleirinha": "coleira",
    "coleirinhas": "coleira",
    "coleirinho": "coleiro",
    "coleirinhos": "coleiro",
    "coleirita": "coleira",
    "coleiritas": "coleira",
    "coleirito": "coleiro",
    "coleiritos": "coleiro",
    "coleiros": "coleiro",
    "coleirozinho": "coleiro",
    "coleirozinhos": "coleiro",
    "coleirozito": "coleiro",
    "coleirozitos": "coleiro",
    "coleis": "colar",
    "colelitomias": "colelitomia",
    "colem": "colar",
    "colemias": "colemia",
    "colemo": "colar",
    "colemos": "colar",
    "coleoderma": "coleodermo",
    "coleodermas": "coleodermo",
    "coleodermos": "coleodermo",
    "coleorrizas": "coleorriza",
    "coleou": "colear",
    "coleriformes": "coleriforme",
    "colerinas": "colerina",
    "colerética": "colerético",
    "coleréticas": "colerético",
    "coleréticos": "colerético",
    "colerínica": "colerínico",
    "colerínicas": "colerínico",
    "colerínicos": "colerínico",
    "coles": "colar",
    "colesteróis": "colesterol",
    "coleteiros": "coleteiro",
    "coletes": "colete",
    "coleámo": "colear",
    "coleámos": "colear",
    "coleáramo": "colear",
    "coleáramos": "colear",
    "coleáreis": "colear",
    "coleásseis": "colear",
    "coleássemos": "colear",
    "coleávamo": "colear",
    "coleávamos": "colear",
    "coleáveis": "colear",
    "coleóptera": "coleóptero",
    "coleópteras": "coleóptero",
    "coleópteros": "coleóptero",
    "colga": "colgar",
    "colgada": "colgar",
    "colgadas": "colgar",
    "colgado": "colgar",
    "colgados": "colgar",
    "colgaduras": "colgadura",
    "colgai": "colgar",
    "colgais": "colgar",
    "colgam": "colgar",
    "colgamo": "colgar",
    "colgamos": "colgar",
    "colgando": "colgar",
    "colgara": "colgar",
    "colgaram": "colgar",
    "colgaras": "colgar",
    "colgarde": "colgar",
    "colgardes": "colgar",
    "colgare": "colgar",
    "colgarei": "colgar",
    "colgareis": "colgar",
    "colgarem": "colgar",
    "colgaremos": "colgar",
    "colgares": "colgar",
    "colgaria": "colgar",
    "colgariam": "colgar",
    "colgarias": "colgar",
    "colgarmo": "colgar",
    "colgarmos": "colgar",
    "colgará": "colgar",
    "colgarás": "colgar",
    "colgarão": "colgar",
    "colgaríamos": "colgar",
    "colgaríeis": "colgar",
    "colgas": "colgar",
    "colgasse": "colgar",
    "colgassem": "colgar",
    "colgasses": "colgar",
    "colgaste": "colgar",
    "colgastes": "colgar",
    "colgava": "colgar",
    "colgavam": "colgar",
    "colgavas": "colgar",
    "colgo": "colgar",
    "colgou": "colgar",
    "colgue": "colgar",
    "colguei": "colgar",
    "colgueis": "colgar",
    "colguem": "colgar",
    "colguemo": "colgar",
    "colguemos": "colgar",
    "colgues": "colgar",
    "colgá": "colgar",
    "colgámo": "colgar",
    "colgámos": "colgar",
    "colgáramo": "colgar",
    "colgáramos": "colgar",
    "colgárei": "colgar",
    "colgáreis": "colgar",
    "colgásseis": "colgar",
    "colgássemos": "colgar",
    "colgávamo": "colgar",
    "colgávamos": "colgar",
    "colgávei": "colgar",
    "colgáveis": "colgar",
    "colha": "colher",
    "colhadas": "colhada",
    "colhais": "colher",
    "colham": "colher",
    "colhamo": "colher",
    "colhamos": "colher",
    "colhas": "colher",
    "colhe": "colher",
    "colhedeiras": "colhedeira",
    "colhedora": "colhedor",
    "colhedoras": "colhedor",
    "colhedores": "colhedor",
    "colhei": "colher",
    "colheis": "colher",
    "colheitas": "colheita",
    "colhem": "colher",
    "colhemo": "colher",
    "colhemos": "colher",
    "colhendo": "colher",
    "colhera": "colher",
    "colheradas": "colherada",
    "colheram": "colher",
    "colheras": "colher",
    "colherde": "colher",
    "colherdes": "colher",
    "colhere": "colher",
    "colherei": "colher",
    "colhereiros": "colhereiro",
    "colhereis": "colher",
    "colherem": "colher",
    "colheremos": "colher",
    "colheres": "colher",
    "colheretes": "colherete",
    "colheria": "colher",
    "colheriam": "colher",
    "colherias": "colher",
    "colherinha": "colher",
    "colherinhas": "colher",
    "colherins": "colherim",
    "colheris": "colheril",
    "colherita": "colher",
    "colheritas": "colher",
    "colhermo": "colher",
    "colhermos": "colher",
    "colherá": "colher",
    "colherás": "colher",
    "colherão": "colher",
    "colheríamos": "colher",
    "colheríeis": "colher",
    "colherões": "colherão",
    "colhes": "colher",
    "colhesse": "colher",
    "colhessem": "colher",
    "colhesses": "colher",
    "colheste": "colher",
    "colhestes": "colher",
    "colheu": "colher",
    "colhi": "colher",
    "colhia": "colher",
    "colhiam": "colher",
    "colhias": "colher",
    "colhida": "colhido",
    "colhidas": "colhido",
    "colhido": "colher",
    "colhidos": "colhido",
    "colhimentos": "colhimento",
    "colho": "colher",
    "colhê": "colher",
    "colhêramo": "colher",
    "colhêramos": "colher",
    "colhêrei": "colher",
    "colhêreis": "colher",
    "colhêsseis": "colher",
    "colhêssemos": "colher",
    "colhíamo": "colher",
    "colhíamos": "colher",
    "colhíei": "colher",
    "colhíeis": "colher",
    "colhões": "colhão",
    "coliambos": "coliambo",
    "colibacilos": "colibacilo",
    "colibaciloses": "colibacilose",
    "colibris": "colibri",
    "colicativa": "colicativo",
    "colicativas": "colicativo",
    "colicativos": "colicativo",
    "colida": "colidir",
    "colidais": "colidir",
    "colidam": "colidir",
    "colidamo": "colidir",
    "colidamos": "colidir",
    "colidas": "colidir",
    "colide": "colidir",
    "colidem": "colidir",
    "colides": "colidir",
    "colidi": "colidir",
    "colidia": "colidir",
    "colidiam": "colidir",
    "colidias": "colidir",
    "colidida": "colidir",
    "colididas": "colidir",
    "colidido": "colidir",
    "colididos": "colidir",
    "colidimo": "colidir",
    "colidimos": "colidir",
    "colidindo": "colidir",
    "colidira": "colidir",
    "colidiram": "colidir",
    "colidiras": "colidir",
    "colidirdes": "colidir",
    "colidirei": "colidir",
    "colidireis": "colidir",
    "colidirem": "colidir",
    "colidiremos": "colidir",
    "colidires": "colidir",
    "colidiria": "colidir",
    "colidiriam": "colidir",
    "colidirias": "colidir",
    "colidirmo": "colidir",
    "colidirmos": "colidir",
    "colidirá": "colidir",
    "colidirás": "colidir",
    "colidirão": "colidir",
    "colidiríamos": "colidir",
    "colidiríeis": "colidir",
    "colidis": "colidir",
    "colidisse": "colidir",
    "colidissem": "colidir",
    "colidisses": "colidir",
    "colidiste": "colidir",
    "colidistes": "colidir",
    "colidiu": "colidir",
    "colido": "colidir",
    "colidíamo": "colidir",
    "colidíamos": "colidir",
    "colidíeis": "colidir",
    "colidíramo": "colidir",
    "colidíramos": "colidir",
    "colidíreis": "colidir",
    "colidísseis": "colidir",
    "colidíssemos": "colidir",
    "coliformes": "coliforme",
    "coliga": "coligar",
    "coligada": "coligar",
    "coligadas": "coligar",
    "coligado": "coligar",
    "coligados": "coligar",
    "coligai": "coligar",
    "coligais": "coligar",
    "coligam": "coligar",
    "coligamo": "coligar",
    "coligamos": "coligar",
    "coligando": "coligar",
    "coligara": "coligar",
    "coligaram": "coligar",
    "coligaras": "coligar",
    "coligarde": "coligar",
    "coligardes": "coligar",
    "coligare": "coligar",
    "coligarei": "coligar",
    "coligareis": "coligar",
    "coligarem": "coligar",
    "coligaremos": "coligar",
    "coligares": "coligar",
    "coligaria": "coligar",
    "coligariam": "coligar",
    "coligarias": "coligar",
    "coligarmo": "coligar",
    "coligarmos": "coligar",
    "coligará": "coligar",
    "coligarás": "coligar",
    "coligarão": "coligar",
    "coligaríamos": "coligar",
    "coligaríeis": "coligar",
    "coligas": "coligar",
    "coligasse": "coligar",
    "coligassem": "coligar",
    "coligasses": "coligar",
    "coligaste": "coligar",
    "coligastes": "coligar",
    "coligativa": "coligativo",
    "coligativas": "coligativo",
    "coligativos": "coligativo",
    "coligava": "coligar",
    "coligavam": "coligar",
    "coligavas": "coligar",
    "coligações": "coligação",
    "colige": "coligir",
    "coligem": "coligir",
    "coliges": "coligir",
    "coligi": "coligir",
    "coligia": "coligir",
    "coligiam": "coligir",
    "coligias": "coligir",
    "coligida": "coligir",
    "coligidas": "coligir",
    "coligido": "coligir",
    "coligidos": "coligir",
    "coligimo": "coligir",
    "coligimos": "coligir",
    "coligindo": "coligir",
    "coligira": "coligir",
    "coligiram": "coligir",
    "coligiras": "coligir",
    "coligirde": "coligir",
    "coligirdes": "coligir",
    "coligire": "coligir",
    "coligirei": "coligir",
    "coligireis": "coligir",
    "coligirem": "coligir",
    "coligiremos": "coligir",
    "coligires": "coligir",
    "coligiria": "coligir",
    "coligiriam": "coligir",
    "coligirias": "coligir",
    "coligirmo": "coligir",
    "coligirmos": "coligir",
    "coligirá": "coligir",
    "coligirás": "coligir",
    "coligirão": "coligir",
    "coligiríamos": "coligir",
    "coligiríeis": "coligir",
    "coligis": "coligir",
    "coligisse": "coligir",
    "coligissem": "coligir",
    "coligisses": "coligir",
    "coligiste": "coligir",
    "coligistes": "coligir",
    "coligiu": "coligir",
    "coligo": "coligar",
    "coligou": "coligar",
    "coligue": "coligar",
    "coliguei": "coligar",
    "coligueis": "coligar",
    "coliguem": "coligar",
    "coliguemo": "coligar",
    "coliguemos": "coligar",
    "coligues": "coligar",
    "coligá": "coligar",
    "coligámo": "coligar",
    "coligámos": "coligar",
    "coligáramo": "coligar",
    "coligáramos": "coligar",
    "coligárei": "coligar",
    "coligáreis": "coligar",
    "coligásseis": "coligar",
    "coligássemos": "coligar",
    "coligávamo": "coligar",
    "coligávamos": "coligar",
    "coligávei": "coligar",
    "coligáveis": "coligar",
    "coligíamo": "coligir",
    "coligíamos": "coligir",
    "coligíei": "coligir",
    "coligíeis": "coligir",
    "coligíramo": "coligir",
    "coligíramos": "coligir",
    "coligírei": "coligir",
    "coligíreis": "coligir",
    "coligísseis": "coligir",
    "coligíssemos": "coligir",
    "colija": "coligir",
    "colijais": "coligir",
    "colijam": "coligir",
    "colijamo": "coligir",
    "colijamos": "coligir",
    "colijas": "coligir",
    "colijo": "coligir",
    "colima": "colimar",
    "colimada": "colimar",
    "colimadas": "colimar",
    "colimado": "colimar",
    "colimadora": "colimador",
    "colimadoras": "colimador",
    "colimadores": "colimador",
    "colimados": "colimar",
    "colimai": "colimar",
    "colimais": "colimar",
    "colimam": "colimar",
    "colimamo": "colimar",
    "colimamos": "colimar",
    "colimando": "colimar",
    "colimara": "colimar",
    "colimaram": "colimar",
    "colimaras": "colimar",
    "colimarde": "colimar",
    "colimardes": "colimar",
    "colimare": "colimar",
    "colimarei": "colimar",
    "colimareis": "colimar",
    "colimarem": "colimar",
    "colimaremos": "colimar",
    "colimares": "colimar",
    "colimaria": "colimar",
    "colimariam": "colimar",
    "colimarias": "colimar",
    "colimarmo": "colimar",
    "colimarmos": "colimar",
    "colimará": "colimar",
    "colimarás": "colimar",
    "colimarão": "colimar",
    "colimaríamos": "colimar",
    "colimaríeis": "colimar",
    "colimas": "colimar",
    "colimasse": "colimar",
    "colimassem": "colimar",
    "colimasses": "colimar",
    "colimaste": "colimar",
    "colimastes": "colimar",
    "colimava": "colimar",
    "colimavam": "colimar",
    "colimavas": "colimar",
    "colimações": "colimação",
    "colimbidas": "colimbida",
    "colimbídea": "colimbídeo",
    "colimbídeas": "colimbídeo",
    "colimbídeos": "colimbídeo",
    "colime": "colimar",
    "colimei": "colimar",
    "colimeis": "colimar",
    "colimem": "colimar",
    "colimemo": "colimar",
    "colimemos": "colimar",
    "colimes": "colimar",
    "colimita": "colimitar",
    "colimitada": "colimitar",
    "colimitadas": "colimitar",
    "colimitado": "colimitar",
    "colimitados": "colimitar",
    "colimitai": "colimitar",
    "colimitais": "colimitar",
    "colimitam": "colimitar",
    "colimitamo": "colimitar",
    "colimitamos": "colimitar",
    "colimitando": "colimitar",
    "colimitara": "colimitar",
    "colimitaram": "colimitar",
    "colimitaras": "colimitar",
    "colimitarde": "colimitar",
    "colimitardes": "colimitar",
    "colimitare": "colimitar",
    "colimitarei": "colimitar",
    "colimitareis": "colimitar",
    "colimitarem": "colimitar",
    "colimitaremos": "colimitar",
    "colimitares": "colimitar",
    "colimitaria": "colimitar",
    "colimitariam": "colimitar",
    "colimitarias": "colimitar",
    "colimitarmo": "colimitar",
    "colimitarmos": "colimitar",
    "colimitará": "colimitar",
    "colimitarás": "colimitar",
    "colimitarão": "colimitar",
    "colimitaríamos": "colimitar",
    "colimitaríeis": "colimitar",
    "colimitas": "colimitar",
    "colimitasse": "colimitar",
    "colimitassem": "colimitar",
    "colimitasses": "colimitar",
    "colimitaste": "colimitar",
    "colimitastes": "colimitar",
    "colimitava": "colimitar",
    "colimitavam": "colimitar",
    "colimitavas": "colimitar",
    "colimitações": "colimitação",
    "colimite": "colimitar",
    "colimitei": "colimitar",
    "colimiteis": "colimitar",
    "colimitem": "colimitar",
    "colimitemo": "colimitar",
    "colimitemos": "colimitar",
    "colimites": "colimitar",
    "colimito": "colimitar",
    "colimitou": "colimitar",
    "colimitá": "colimitar",
    "colimitámo": "colimitar",
    "colimitámos": "colimitar",
    "colimitáramo": "colimitar",
    "colimitáramos": "colimitar",
    "colimitárei": "colimitar",
    "colimitáreis": "colimitar",
    "colimitásseis": "colimitar",
    "colimitássemos": "colimitar",
    "colimitávamo": "colimitar",
    "colimitávamos": "colimitar",
    "colimitávei": "colimitar",
    "colimitáveis": "colimitar",
    "colimo": "colimar",
    "colimou": "colimar",
    "colimá": "colimar",
    "colimámo": "colimar",
    "colimámos": "colimar",
    "colimáramo": "colimar",
    "colimáramos": "colimar",
    "colimárei": "colimar",
    "colimáreis": "colimar",
    "colimásseis": "colimar",
    "colimássemos": "colimar",
    "colimávamo": "colimar",
    "colimávamos": "colimar",
    "colimávei": "colimar",
    "colimáveis": "colimar",
    "colinas": "colina",
    "colineares": "colinear",
    "colineações": "colineação",
    "colinho": "colo",
    "colinhos": "colo",
    "colinosa": "colinoso",
    "colinosas": "colinoso",
    "colinosos": "colinoso",
    "coliqua": "coliquar",
    "coliquada": "coliquar",
    "coliquadas": "coliquar",
    "coliquado": "coliquar",
    "coliquados": "coliquar",
    "coliquai": "coliquar",
    "coliquais": "coliquar",
    "coliquam": "coliquar",
    "coliquamo": "coliquar",
    "coliquamos": "coliquar",
    "coliquando": "coliquar",
    "coliquantes": "coliquante",
    "coliquara": "coliquar",
    "coliquaram": "coliquar",
    "coliquaras": "coliquar",
    "coliquarde": "coliquar",
    "coliquardes": "coliquar",
    "coliquare": "coliquar",
    "coliquarei": "coliquar",
    "coliquareis": "coliquar",
    "coliquarem": "coliquar",
    "coliquaremos": "coliquar",
    "coliquares": "coliquar",
    "coliquaria": "coliquar",
    "coliquariam": "coliquar",
    "coliquarias": "coliquar",
    "coliquarmo": "coliquar",
    "coliquarmos": "coliquar",
    "coliquará": "coliquar",
    "coliquarás": "coliquar",
    "coliquarão": "coliquar",
    "coliquaríamos": "coliquar",
    "coliquaríeis": "coliquar",
    "coliquas": "coliquar",
    "coliquasse": "coliquar",
    "coliquassem": "coliquar",
    "coliquasses": "coliquar",
    "coliquaste": "coliquar",
    "coliquastes": "coliquar",
    "coliquava": "coliquar",
    "coliquavam": "coliquar",
    "coliquavas": "coliquar",
    "coliquações": "coliquação",
    "coliquei": "coliquar",
    "coliqueis": "coliquar",
    "coliquemo": "coliquar",
    "coliquemos": "coliquar",
    "coliques": "coliquar",
    "coliquo": "coliquar",
    "coliquou": "coliquar",
    "coliquá": "coliquar",
    "coliquámo": "coliquar",
    "coliquámos": "coliquar",
    "coliquáramo": "coliquar",
    "coliquáramos": "coliquar",
    "coliquárei": "coliquar",
    "coliquáreis": "coliquar",
    "coliquásseis": "coliquar",
    "coliquássemos": "coliquar",
    "coliquávamo": "coliquar",
    "coliquávamos": "coliquar",
    "coliquávei": "coliquar",
    "coliquáveis": "coliquar",
    "coliqúe": "coliquar",
    "coliqúem": "coliquar",
    "coliqúes": "coliquar",
    "coliseus": "coliseu",
    "colisões": "colisão",
    "colites": "colite",
    "colito": "colo",
    "colitos": "colo",
    "coliâmbica": "coliâmbico",
    "coliâmbicas": "coliâmbico",
    "coliâmbicos": "coliâmbico",
    "collants": "collant",
    "colma": "colmar",
    "colmace": "colmaçar",
    "colmacei": "colmaçar",
    "colmaceis": "colmaçar",
    "colmacem": "colmaçar",
    "colmacemo": "colmaçar",
    "colmacemos": "colmaçar",
    "colmaces": "colmaçar",
    "colmada": "colmar",
    "colmadas": "colmar",
    "colmado": "colmar",
    "colmados": "colmar",
    "colmagens": "colmagem",
    "colmai": "colmar",
    "colmais": "colmar",
    "colmam": "colmar",
    "colmamo": "colmar",
    "colmamos": "colmar",
    "colmando": "colmar",
    "colmara": "colmar",
    "colmaram": "colmar",
    "colmaras": "colmar",
    "colmarde": "colmar",
    "colmardes": "colmar",
    "colmare": "colmar",
    "colmarei": "colmar",
    "colmareis": "colmar",
    "colmarem": "colmar",
    "colmaremos": "colmar",
    "colmares": "colmar",
    "colmaria": "colmar",
    "colmariam": "colmar",
    "colmarias": "colmar",
    "colmarmo": "colmar",
    "colmarmos": "colmar",
    "colmará": "colmar",
    "colmarás": "colmar",
    "colmarão": "colmar",
    "colmaríamos": "colmar",
    "colmaríeis": "colmar",
    "colmas": "colmar",
    "colmasse": "colmar",
    "colmassem": "colmar",
    "colmasses": "colmar",
    "colmaste": "colmar",
    "colmastes": "colmar",
    "colmata": "colmatar",
    "colmatada": "colmatar",
    "colmatadas": "colmatar",
    "colmatado": "colmatar",
    "colmatados": "colmatar",
    "colmatagens": "colmatagem",
    "colmatai": "colmatar",
    "colmatais": "colmatar",
    "colmatam": "colmatar",
    "colmatamo": "colmatar",
    "colmatamos": "colmatar",
    "colmatando": "colmatar",
    "colmatara": "colmatar",
    "colmataram": "colmatar",
    "colmataras": "colmatar",
    "colmatarde": "colmatar",
    "colmatardes": "colmatar",
    "colmatare": "colmatar",
    "colmatarei": "colmatar",
    "colmatareis": "colmatar",
    "colmatarem": "colmatar",
    "colmataremos": "colmatar",
    "colmatares": "colmatar",
    "colmataria": "colmatar",
    "colmatariam": "colmatar",
    "colmatarias": "colmatar",
    "colmatarmo": "colmatar",
    "colmatarmos": "colmatar",
    "colmatará": "colmatar",
    "colmatarás": "colmatar",
    "colmatarão": "colmatar",
    "colmataríamos": "colmatar",
    "colmataríeis": "colmatar",
    "colmatas": "colmatar",
    "colmatasse": "colmatar",
    "colmatassem": "colmatar",
    "colmatasses": "colmatar",
    "colmataste": "colmatar",
    "colmatastes": "colmatar",
    "colmatava": "colmatar",
    "colmatavam": "colmatar",
    "colmatavas": "colmatar",
    "colmate": "colmatar",
    "colmatei": "colmatar",
    "colmateis": "colmatar",
    "colmatem": "colmatar",
    "colmatemo": "colmatar",
    "colmatemos": "colmatar",
    "colmates": "colmatar",
    "colmato": "colmatar",
    "colmatou": "colmatar",
    "colmatá": "colmatar",
    "colmatámo": "colmatar",
    "colmatámos": "colmatar",
    "colmatáramo": "colmatar",
    "colmatáramos": "colmatar",
    "colmatárei": "colmatar",
    "colmatáreis": "colmatar",
    "colmatásseis": "colmatar",
    "colmatássemos": "colmatar",
    "colmatávamo": "colmatar",
    "colmatávamos": "colmatar",
    "colmatávei": "colmatar",
    "colmatáveis": "colmatar",
    "colmava": "colmar",
    "colmavam": "colmar",
    "colmavas": "colmar",
    "colmaça": "colmaço",
    "colmaçada": "colmaçar",
    "colmaçadas": "colmaçar",
    "colmaçado": "colmaçar",
    "colmaçados": "colmaçar",
    "colmaçai": "colmaçar",
    "colmaçais": "colmaçar",
    "colmaçam": "colmaçar",
    "colmaçamo": "colmaçar",
    "colmaçamos": "colmaçar",
    "colmaçando": "colmaçar",
    "colmaçara": "colmaçar",
    "colmaçaram": "colmaçar",
    "colmaçaras": "colmaçar",
    "colmaçarde": "colmaçar",
    "colmaçardes": "colmaçar",
    "colmaçare": "colmaçar",
    "colmaçarei": "colmaçar",
    "colmaçareis": "colmaçar",
    "colmaçarem": "colmaçar",
    "colmaçaremos": "colmaçar",
    "colmaçares": "colmaçar",
    "colmaçaria": "colmaçar",
    "colmaçariam": "colmaçar",
    "colmaçarias": "colmaçar",
    "colmaçarmo": "colmaçar",
    "colmaçarmos": "colmaçar",
    "colmaçará": "colmaçar",
    "colmaçarás": "colmaçar",
    "colmaçarão": "colmaçar",
    "colmaçaríamos": "colmaçar",
    "colmaçaríeis": "colmaçar",
    "colmaças": "colmaço",
    "colmaçasse": "colmaçar",
    "colmaçassem": "colmaçar",
    "colmaçasses": "colmaçar",
    "colmaçaste": "colmaçar",
    "colmaçastes": "colmaçar",
    "colmaçava": "colmaçar",
    "colmaçavam": "colmaçar",
    "colmaçavas": "colmaçar",
    "colmaço": "colmaçar",
    "colmaços": "colmaço",
    "colmaçou": "colmaçar",
    "colmaçá": "colmaçar",
    "colmaçámo": "colmaçar",
    "colmaçámos": "colmaçar",
    "colmaçáramo": "colmaçar",
    "colmaçáramos": "colmaçar",
    "colmaçárei": "colmaçar",
    "colmaçáreis": "colmaçar",
    "colmaçásseis": "colmaçar",
    "colmaçássemos": "colmaçar",
    "colmaçávamo": "colmaçar",
    "colmaçávamos": "colmaçar",
    "colmaçávei": "colmaçar",
    "colmaçáveis": "colmaçar",
    "colme": "colmar",
    "colmeais": "colmeal",
    "colmeeiros": "colmeeiro",
    "colmei": "colmar",
    "colmeias": "colmeia",
    "colmeiformes": "colmeiforme",
    "colmeis": "colmar",
    "colmem": "colmar",
    "colmemo": "colmar",
    "colmemos": "colmar",
    "colmes": "colmar",
    "colmilhos": "colmilho",
    "colmilhosa": "colmilhoso",
    "colmilhosas": "colmilhoso",
    "colmilhosos": "colmilhoso",
    "colmilhuda": "colmilhudo",
    "colmilhudas": "colmilhudo",
    "colmilhudos": "colmilhudo",
    "colmo": "colmar",
    "colmos": "colmo",
    "colmou": "colmar",
    "colmá": "colmar",
    "colmámo": "colmar",
    "colmámos": "colmar",
    "colmáramo": "colmar",
    "colmáramos": "colmar",
    "colmárei": "colmar",
    "colmáreis": "colmar",
    "colmásseis": "colmar",
    "colmássemos": "colmar",
    "colmávamo": "colmar",
    "colmávamos": "colmar",
    "colmávei": "colmar",
    "colmáveis": "colmar",
    "colméias": "colméia",
    "colmífera": "colmífero",
    "colmíferas": "colmífero",
    "colmíferos": "colmífero",
    "colo": "colar",
    "coloca": "colocar",
    "colocada": "colocar",
    "colocadas": "colocar",
    "colocado": "colocar",
    "colocadora": "colocador",
    "colocadoras": "colocador",
    "colocadores": "colocador",
    "colocados": "colocar",
    "colocai": "colocar",
    "colocais": "colocar",
    "colocam": "colocar",
    "colocamo": "colocar",
    "colocamos": "colocar",
    "colocando": "colocar",
    "colocara": "colocar",
    "colocaram": "colocar",
    "colocaras": "colocar",
    "colocarde": "colocar",
    "colocardes": "colocar",
    "colocare": "colocar",
    "colocarei": "colocar",
    "colocareis": "colocar",
    "colocarem": "colocar",
    "colocaremos": "colocar",
    "colocares": "colocar",
    "colocaria": "colocar",
    "colocariam": "colocar",
    "colocarias": "colocar",
    "colocarmo": "colocar",
    "colocarmos": "colocar",
    "colocará": "colocar",
    "colocarás": "colocar",
    "colocarão": "colocar",
    "colocaríamos": "colocar",
    "colocaríeis": "colocar",
    "colocas": "colocar",
    "colocasse": "colocar",
    "colocassem": "colocar",
    "colocasses": "colocar",
    "colocaste": "colocar",
    "colocastes": "colocar",
    "colocava": "colocar",
    "colocavam": "colocar",
    "colocavas": "colocar",
    "colocações": "colocação",
    "coloco": "colocar",
    "colocou": "colocar",
    "colocutora": "colocutor",
    "colocutoras": "colocutor",
    "colocutores": "colocutor",
    "colocá": "colocar",
    "colocámo": "colocar",
    "colocámos": "colocar",
    "colocáramo": "colocar",
    "colocáramos": "colocar",
    "colocárei": "colocar",
    "colocáreis": "colocar",
    "colocásias": "colocásia",
    "colocásseis": "colocar",
    "colocássemos": "colocar",
    "colocávamo": "colocar",
    "colocávamos": "colocar",
    "colocávei": "colocar",
    "colocáveis": "colocar",
    "colocíntidas": "colocíntida",
    "colocíntides": "colocíntide",
    "colofanites": "colofanite",
    "colofónias": "colofónia",
    "colofões": "colofão",
    "coloidais": "coloidal",
    "colomba": "colombo",
    "colombas": "colombo",
    "colombiana": "colombiano",
    "colombianas": "colombiano",
    "colombianos": "colombiano",
    "colombina": "colombino",
    "colombinas": "colombino",
    "colombinos": "colombino",
    "colombos": "colombo",
    "colombros": "colombro",
    "colonatos": "colonato",
    "colondros": "colondro",
    "coloniais": "colonial",
    "colonialismos": "colonialismo",
    "colonialistas": "colonialista",
    "colonistas": "colonista",
    "coloniza": "colonizar",
    "colonizada": "colonizar",
    "colonizadas": "colonizar",
    "colonizado": "colonizar",
    "colonizadora": "colonizador",
    "colonizadoras": "colonizador",
    "colonizadores": "colonizador",
    "colonizados": "colonizar",
    "colonizai": "colonizar",
    "colonizais": "colonizar",
    "colonizam": "colonizar",
    "colonizamo": "colonizar",
    "colonizamos": "colonizar",
    "colonizando": "colonizar",
    "colonizara": "colonizar",
    "colonizaram": "colonizar",
    "colonizaras": "colonizar",
    "colonizarde": "colonizar",
    "colonizardes": "colonizar",
    "colonizare": "colonizar",
    "colonizarei": "colonizar",
    "colonizareis": "colonizar",
    "colonizarem": "colonizar",
    "colonizaremos": "colonizar",
    "colonizares": "colonizar",
    "colonizaria": "colonizar",
    "colonizariam": "colonizar",
    "colonizarias": "colonizar",
    "colonizarmo": "colonizar",
    "colonizarmos": "colonizar",
    "colonizará": "colonizar",
    "colonizarás": "colonizar",
    "colonizarão": "colonizar",
    "colonizaríamos": "colonizar",
    "colonizaríeis": "colonizar",
    "colonizas": "colonizar",
    "colonizasse": "colonizar",
    "colonizassem": "colonizar",
    "colonizasses": "colonizar",
    "colonizaste": "colonizar",
    "colonizastes": "colonizar",
    "colonizava": "colonizar",
    "colonizavam": "colonizar",
    "colonizavas": "colonizar",
    "colonizações": "colonização",
    "colonize": "colonizar",
    "colonizei": "colonizar",
    "colonizeis": "colonizar",
    "colonizem": "colonizar",
    "colonizemo": "colonizar",
    "colonizemos": "colonizar",
    "colonizes": "colonizar",
    "colonizo": "colonizar",
    "colonizou": "colonizar",
    "colonizá": "colonizar",
    "colonizámo": "colonizar",
    "colonizámos": "colonizar",
    "colonizáramo": "colonizar",
    "colonizáramos": "colonizar",
    "colonizárei": "colonizar",
    "colonizáreis": "colonizar",
    "colonizásseis": "colonizar",
    "colonizássemos": "colonizar",
    "colonizávamo": "colonizar",
    "colonizávamos": "colonizar",
    "colonizávei": "colonizar",
    "colonizáveis": "colonizável",
    "colonos": "colono",
    "coloque": "colocar",
    "coloquei": "colocar",
    "coloqueis": "colocar",
    "coloquem": "colocar",
    "coloquemo": "colocar",
    "coloquemos": "colocar",
    "coloques": "colocar",
    "coloquiais": "coloquial",
    "colora": "colorar",
    "colorada": "colorar",
    "coloradas": "colorar",
    "colorado": "colorar",
    "colorados": "colorar",
    "colorai": "colorar",
    "colorais": "colorar",
    "coloram": "colorar",
    "coloramo": "colorar",
    "coloramos": "colorar",
    "colorando": "colorar",
    "colorantes": "colorante",
    "colorara": "colorar",
    "coloraram": "colorar",
    "coloraras": "colorar",
    "colorarde": "colorar",
    "colorardes": "colorar",
    "colorare": "colorar",
    "colorarei": "colorar",
    "colorareis": "colorar",
    "colorarem": "colorar",
    "coloraremos": "colorar",
    "colorares": "colorar",
    "coloraria": "colorar",
    "colorariam": "colorar",
    "colorarias": "colorar",
    "colorarmo": "colorar",
    "colorarmos": "colorar",
    "colorará": "colorar",
    "colorarás": "colorar",
    "colorarão": "colorar",
    "coloraríamos": "colorar",
    "coloraríeis": "colorar",
    "coloras": "colorar",
    "colorasse": "colorar",
    "colorassem": "colorar",
    "colorasses": "colorar",
    "coloraste": "colorar",
    "colorastes": "colorar",
    "coloraus": "colorau",
    "colorava": "colorar",
    "coloravam": "colorar",
    "coloravas": "colorar",
    "colorações": "coloração",
    "colore": "colorir",
    "coloreada": "colorear",
    "coloreadas": "colorear",
    "coloreado": "colorear",
    "coloreados": "colorear",
    "coloreai": "colorear",
    "coloreais": "colorear",
    "coloreamo": "colorear",
    "coloreamos": "colorear",
    "coloreando": "colorear",
    "coloreara": "colorear",
    "colorearam": "colorear",
    "colorearas": "colorear",
    "colorearde": "colorear",
    "coloreardes": "colorear",
    "coloreare": "colorear",
    "colorearei": "colorear",
    "coloreareis": "colorear",
    "colorearem": "colorear",
    "colorearemos": "colorear",
    "coloreares": "colorear",
    "colorearia": "colorear",
    "coloreariam": "colorear",
    "colorearias": "colorear",
    "colorearmo": "colorear",
    "colorearmos": "colorear",
    "coloreará": "colorear",
    "colorearás": "colorear",
    "colorearão": "colorear",
    "colorearíamos": "colorear",
    "colorearíeis": "colorear",
    "coloreasse": "colorear",
    "coloreassem": "colorear",
    "coloreasses": "colorear",
    "coloreaste": "colorear",
    "coloreastes": "colorear",
    "coloreava": "colorear",
    "coloreavam": "colorear",
    "coloreavas": "colorear",
    "coloreei": "colorear",
    "coloreeis": "colorear",
    "coloreemo": "colorear",
    "coloreemos": "colorear",
    "colorei": "colorar",
    "coloreia": "colorear",
    "coloreiam": "colorear",
    "coloreias": "colorear",
    "coloreie": "colorear",
    "coloreiem": "colorear",
    "coloreies": "colorear",
    "coloreio": "colorear",
    "coloreis": "colorar",
    "colorem": "colorir",
    "coloremo": "colorar",
    "coloremos": "colorar",
    "coloreou": "colorear",
    "colores": "colorir",
    "coloreá": "colorear",
    "coloreámo": "colorear",
    "coloreámos": "colorear",
    "coloreáramo": "colorear",
    "coloreáramos": "colorear",
    "coloreárei": "colorear",
    "coloreáreis": "colorear",
    "coloreásseis": "colorear",
    "coloreássemos": "colorear",
    "coloreávamo": "colorear",
    "coloreávamos": "colorear",
    "coloreávei": "colorear",
    "coloreáveis": "colorear",
    "colori": "colorir",
    "coloria": "colorir",
    "coloriam": "colorir",
    "colorias": "colorir",
    "colorida": "colorir",
    "coloridas": "colorir",
    "colorido": "colorir",
    "coloridos": "colorir",
    "colorimetrias": "colorimetria",
    "colorimo": "colorir",
    "colorimos": "colorir",
    "colorindo": "colorir",
    "colorira": "colorir",
    "coloriram": "colorir",
    "coloriras": "colorir",
    "colorirde": "colorir",
    "colorirdes": "colorir",
    "colorire": "colorir",
    "colorirei": "colorir",
    "colorireis": "colorir",
    "colorirem": "colorir",
    "coloriremos": "colorir",
    "colorires": "colorir",
    "coloriria": "colorir",
    "coloririam": "colorir",
    "coloririas": "colorir",
    "colorirmo": "colorir",
    "colorirmos": "colorir",
    "colorirá": "colorir",
    "colorirás": "colorir",
    "colorirão": "colorir",
    "coloriríamos": "colorir",
    "coloriríeis": "colorir",
    "coloris": "colorir",
    "coloriscópios": "coloriscópio",
    "colorisse": "colorir",
    "colorissem": "colorir",
    "colorisses": "colorir",
    "coloristas": "colorista",
    "coloriste": "colorir",
    "coloristes": "colorir",
    "coloriu": "colorir",
    "coloriza": "colorizar",
    "colorizada": "colorizar",
    "colorizadas": "colorizar",
    "colorizado": "colorizar",
    "colorizados": "colorizar",
    "colorizai": "colorizar",
    "colorizais": "colorizar",
    "colorizam": "colorizar",
    "colorizamo": "colorizar",
    "colorizamos": "colorizar",
    "colorizando": "colorizar",
    "colorizara": "colorizar",
    "colorizaram": "colorizar",
    "colorizaras": "colorizar",
    "colorizarde": "colorizar",
    "colorizardes": "colorizar",
    "colorizare": "colorizar",
    "colorizarei": "colorizar",
    "colorizareis": "colorizar",
    "colorizarem": "colorizar",
    "colorizaremos": "colorizar",
    "colorizares": "colorizar",
    "colorizaria": "colorizar",
    "colorizariam": "colorizar",
    "colorizarias": "colorizar",
    "colorizarmo": "colorizar",
    "colorizarmos": "colorizar",
    "colorizará": "colorizar",
    "colorizarás": "colorizar",
    "colorizarão": "colorizar",
    "colorizaríamos": "colorizar",
    "colorizaríeis": "colorizar",
    "colorizas": "colorizar",
    "colorizasse": "colorizar",
    "colorizassem": "colorizar",
    "colorizasses": "colorizar",
    "colorizaste": "colorizar",
    "colorizastes": "colorizar",
    "colorizava": "colorizar",
    "colorizavam": "colorizar",
    "colorizavas": "colorizar",
    "colorizações": "colorização",
    "colorize": "colorizar",
    "colorizei": "colorizar",
    "colorizeis": "colorizar",
    "colorizem": "colorizar",
    "colorizemo": "colorizar",
    "colorizemos": "colorizar",
    "colorizes": "colorizar",
    "colorizo": "colorizar",
    "colorizou": "colorizar",
    "colorizá": "colorizar",
    "colorizámo": "colorizar",
    "colorizámos": "colorizar",
    "colorizáramo": "colorizar",
    "colorizáramos": "colorizar",
    "colorizárei": "colorizar",
    "colorizáreis": "colorizar",
    "colorizásseis": "colorizar",
    "colorizássemos": "colorizar",
    "colorizávamo": "colorizar",
    "colorizávamos": "colorizar",
    "colorizávei": "colorizar",
    "colorizáveis": "colorizar",
    "coloro": "colorar",
    "colorométrica": "colorométrico",
    "colorométricas": "colorométrico",
    "colorométricos": "colorométrico",
    "coloroscópica": "coloroscópico",
    "coloroscópicas": "coloroscópico",
    "coloroscópicos": "coloroscópico",
    "colorou": "colorar",
    "colorá": "colorar",
    "colorámo": "colorar",
    "colorámos": "colorar",
    "coloráramo": "colorar",
    "coloráramos": "colorar",
    "colorárei": "colorar",
    "coloráreis": "colorar",
    "colorásseis": "colorar",
    "colorássemos": "colorar",
    "colorávamo": "colorar",
    "colorávamos": "colorar",
    "colorávei": "colorar",
    "coloráveis": "colorar",
    "coloríamo": "colorir",
    "coloríamos": "colorir",
    "coloríei": "colorir",
    "coloríeis": "colorir",
    "colorífica": "colorífico",
    "coloríficas": "colorífico",
    "coloríficos": "colorífico",
    "colorímetros": "colorímetro",
    "coloríramo": "colorir",
    "coloríramos": "colorir",
    "colorírei": "colorir",
    "coloríreis": "colorir",
    "colorísseis": "colorir",
    "coloríssemos": "colorir",
    "colos": "colo",
    "colossais": "colossal",
    "colossalidades": "colossalidade",
    "colossos": "colosso",
    "colostrais": "colostral",
    "colostrações": "colostração",
    "colostros": "colostro",
    "colotipias": "colotipia",
    "colotípica": "colotípico",
    "colotípicas": "colotípico",
    "colotípicos": "colotípico",
    "colou": "colar",
    "colouros": "colouro",
    "colpites": "colpite",
    "colporragias": "colporragia",
    "colporrágica": "colporrágico",
    "colporrágicas": "colporrágico",
    "colporrágicos": "colporrágico",
    "colposcopias": "colposcopia",
    "colposcópica": "colposcópico",
    "colposcópicas": "colposcópico",
    "colposcópicos": "colposcópico",
    "colposcópios": "colposcópio",
    "colpotomias": "colpotomia",
    "colpotómica": "colpotómico",
    "colpotómicas": "colpotómico",
    "colpotómicos": "colpotómico",
    "colquicinas": "colquicina",
    "coltariza": "coltarizar",
    "coltarizada": "coltarizar",
    "coltarizadas": "coltarizar",
    "coltarizado": "coltarizar",
    "coltarizados": "coltarizar",
    "coltarizai": "coltarizar",
    "coltarizais": "coltarizar",
    "coltarizam": "coltarizar",
    "coltarizamo": "coltarizar",
    "coltarizamos": "coltarizar",
    "coltarizando": "coltarizar",
    "coltarizara": "coltarizar",
    "coltarizaram": "coltarizar",
    "coltarizaras": "coltarizar",
    "coltarizarde": "coltarizar",
    "coltarizardes": "coltarizar",
    "coltarizare": "coltarizar",
    "coltarizarei": "coltarizar",
    "coltarizareis": "coltarizar",
    "coltarizarem": "coltarizar",
    "coltarizaremos": "coltarizar",
    "coltarizares": "coltarizar",
    "coltarizaria": "coltarizar",
    "coltarizariam": "coltarizar",
    "coltarizarias": "coltarizar",
    "coltarizarmo": "coltarizar",
    "coltarizarmos": "coltarizar",
    "coltarizará": "coltarizar",
    "coltarizarás": "coltarizar",
    "coltarizarão": "coltarizar",
    "coltarizaríamos": "coltarizar",
    "coltarizaríeis": "coltarizar",
    "coltarizas": "coltarizar",
    "coltarizasse": "coltarizar",
    "coltarizassem": "coltarizar",
    "coltarizasses": "coltarizar",
    "coltarizaste": "coltarizar",
    "coltarizastes": "coltarizar",
    "coltarizava": "coltarizar",
    "coltarizavam": "coltarizar",
    "coltarizavas": "coltarizar",
    "coltarizações": "coltarização",
    "coltarize": "coltarizar",
    "coltarizei": "coltarizar",
    "coltarizeis": "coltarizar",
    "coltarizem": "coltarizar",
    "coltarizemo": "coltarizar",
    "coltarizemos": "coltarizar",
    "coltarizes": "coltarizar",
    "coltarizo": "coltarizar",
    "coltarizou": "coltarizar",
    "coltarizá": "coltarizar",
    "coltarizámo": "coltarizar",
    "coltarizámos": "coltarizar",
    "coltarizáramo": "coltarizar",
    "coltarizáramos": "coltarizar",
    "coltarizárei": "coltarizar",
    "coltarizáreis": "coltarizar",
    "coltarizásseis": "coltarizar",
    "coltarizássemos": "coltarizar",
    "coltarizávamo": "coltarizar",
    "coltarizávamos": "coltarizar",
    "coltarizávei": "coltarizar",
    "coltarizáveis": "coltarizar",
    "colubreada": "colubreado",
    "colubreadas": "colubreado",
    "colubreados": "colubreado",
    "colubreantes": "colubreante",
    "colubreja": "colubrejar",
    "colubrejada": "colubrejar",
    "colubrejadas": "colubrejar",
    "colubrejado": "colubrejar",
    "colubrejados": "colubrejar",
    "colubrejai": "colubrejar",
    "colubrejais": "colubrejar",
    "colubrejam": "colubrejar",
    "colubrejamo": "colubrejar",
    "colubrejamos": "colubrejar",
    "colubrejando": "colubrejar",
    "colubrejara": "colubrejar",
    "colubrejaram": "colubrejar",
    "colubrejaras": "colubrejar",
    "colubrejardes": "colubrejar",
    "colubrejarei": "colubrejar",
    "colubrejareis": "colubrejar",
    "colubrejarem": "colubrejar",
    "colubrejaremos": "colubrejar",
    "colubrejares": "colubrejar",
    "colubrejaria": "colubrejar",
    "colubrejariam": "colubrejar",
    "colubrejarias": "colubrejar",
    "colubrejarmo": "colubrejar",
    "colubrejarmos": "colubrejar",
    "colubrejará": "colubrejar",
    "colubrejarás": "colubrejar",
    "colubrejarão": "colubrejar",
    "colubrejaríamos": "colubrejar",
    "colubrejaríeis": "colubrejar",
    "colubrejas": "colubrejar",
    "colubrejasse": "colubrejar",
    "colubrejassem": "colubrejar",
    "colubrejasses": "colubrejar",
    "colubrejaste": "colubrejar",
    "colubrejastes": "colubrejar",
    "colubrejava": "colubrejar",
    "colubrejavam": "colubrejar",
    "colubrejavas": "colubrejar",
    "colubreje": "colubrejar",
    "colubrejei": "colubrejar",
    "colubrejeis": "colubrejar",
    "colubrejem": "colubrejar",
    "colubrejemo": "colubrejar",
    "colubrejemos": "colubrejar",
    "colubrejes": "colubrejar",
    "colubrejo": "colubrejar",
    "colubrejou": "colubrejar",
    "colubrejámo": "colubrejar",
    "colubrejámos": "colubrejar",
    "colubrejáramo": "colubrejar",
    "colubrejáramos": "colubrejar",
    "colubrejáreis": "colubrejar",
    "colubrejásseis": "colubrejar",
    "colubrejássemos": "colubrejar",
    "colubrejávamo": "colubrejar",
    "colubrejávamos": "colubrejar",
    "colubrejáveis": "colubrejar",
    "colubrina": "colubrino",
    "colubrinas": "colubrino",
    "colubrinos": "colubrino",
    "colubrídea": "colubrídeo",
    "colubrídeas": "colubrídeo",
    "colubrídeos": "colubrídeo",
    "coluda": "coludir",
    "coludais": "coludir",
    "coludam": "coludir",
    "coludamo": "coludir",
    "coludamos": "coludir",
    "coludas": "coludir",
    "colude": "coludir",
    "coludem": "coludir",
    "coludes": "coludir",
    "coludi": "coludir",
    "coludia": "coludir",
    "coludiam": "coludir",
    "coludias": "coludir",
    "coludida": "coludir",
    "coludidas": "coludir",
    "coludido": "coludir",
    "coludidos": "coludir",
    "coludimo": "coludir",
    "coludimos": "coludir",
    "coludindo": "coludir",
    "coludira": "coludir",
    "coludiram": "coludir",
    "coludiras": "coludir",
    "coludirdes": "coludir",
    "coludirei": "coludir",
    "coludireis": "coludir",
    "coludirem": "coludir",
    "coludiremos": "coludir",
    "coludires": "coludir",
    "coludiria": "coludir",
    "coludiriam": "coludir",
    "coludirias": "coludir",
    "coludirmo": "coludir",
    "coludirmos": "coludir",
    "coludirá": "coludir",
    "coludirás": "coludir",
    "coludirão": "coludir",
    "coludiríamos": "coludir",
    "coludiríeis": "coludir",
    "coludis": "coludir",
    "coludisse": "coludir",
    "coludissem": "coludir",
    "coludisses": "coludir",
    "coludiste": "coludir",
    "coludistes": "coludir",
    "coludiu": "coludir",
    "coludo": "coludir",
    "coludíamo": "coludir",
    "coludíamos": "coludir",
    "coludíeis": "coludir",
    "coludíramo": "coludir",
    "coludíramos": "coludir",
    "coludíreis": "coludir",
    "coludísseis": "coludir",
    "coludíssemos": "coludir",
    "columbina": "columbino",
    "columbinas": "columbino",
    "columbinos": "columbino",
    "columbofilias": "columbofilia",
    "columbofílica": "columbofílico",
    "columbofílicas": "columbofílico",
    "columbofílicos": "columbofílico",
    "columbários": "columbário",
    "columbídea": "columbídeo",
    "columbídeas": "columbídeo",
    "columbídeos": "columbídeo",
    "columbófila": "columbófilo",
    "columbófilas": "columbófilo",
    "columbófilos": "columbófilo",
    "colunares": "colunar",
    "colunas": "coluna",
    "colunatas": "colunata",
    "colunelos": "colunelo",
    "colunetas": "coluneta",
    "coluninha": "coluna",
    "coluninhas": "coluna",
    "colunistas": "colunista",
    "colunita": "coluna",
    "colunitas": "coluna",
    "colunizáveis": "colunizável",
    "colunária": "colunário",
    "colunárias": "colunário",
    "colunários": "colunário",
    "colunáveis": "colunável",
    "colura": "colorir",
    "colurais": "colorir",
    "coluram": "colorir",
    "coluramo": "colorir",
    "coluramos": "colorir",
    "coluras": "colorir",
    "coluro": "colorir",
    "colusória": "colusório",
    "colusórias": "colusório",
    "colusórios": "colusório",
    "colusões": "colusão",
    "colutórios": "colutório",
    "coluviões": "coluvião",
    "colzas": "colza",
    "colá": "colar",
    "colámo": "colar",
    "colámos": "colar",
    "coláramo": "colar",
    "coláramos": "colar",
    "colárei": "colar",
    "coláreis": "colar",
    "colásseis": "colar",
    "colássemos": "colar",
    "colávamo": "colar",
    "colávamos": "colar",
    "colávei": "colar",
    "coláveis": "colável",
    "colédocos": "colédoco",
    "colégios": "colégio",
    "colélitos": "colélito",
    "colérica": "colérico",
    "coléricas": "colérico",
    "coléricos": "colérico",
    "colênquimas": "colênquima",
    "colífera": "colífero",
    "colíferas": "colífero",
    "colíferos": "colífero",
    "colímbidas": "colímbida",
    "colírios": "colírio",
    "colódios": "colódio",
    "colóides": "colóide",
    "colónias": "colónia",
    "colóquios": "colóquio",
    "colômbia": "colômbio",
    "colômbias": "colômbio",
    "colômbios": "colômbio",
    "colúbridas": "colúbrida",
    "colúmbidas": "colúmbida",
    "colúmbios": "colúmbio",
    "coma": "comer",
    "comadres": "comadre",
    "comadresca": "comadresco",
    "comadrescas": "comadresco",
    "comadrescos": "comadresco",
    "comadrices": "comadrice",
    "comadrios": "comadrio",
    "comais": "comer",
    "comam": "comer",
    "comamo": "comer",
    "comamos": "comer",
    "comanches": "comanche",
    "comanda": "comandar",
    "comandada": "comandar",
    "comandadas": "comandar",
    "comandado": "comandar",
    "comandados": "comandar",
    "comandai": "comandar",
    "comandais": "comandar",
    "comandam": "comandar",
    "comandamo": "comandar",
    "comandamos": "comandar",
    "comandando": "comandar",
    "comandantes": "comandante",
    "comandara": "comandar",
    "comandaram": "comandar",
    "comandaras": "comandar",
    "comandarde": "comandar",
    "comandardes": "comandar",
    "comandare": "comandar",
    "comandarei": "comandar",
    "comandareis": "comandar",
    "comandarem": "comandar",
    "comandaremos": "comandar",
    "comandares": "comandar",
    "comandaria": "comandar",
    "comandariam": "comandar",
    "comandarias": "comandar",
    "comandarmo": "comandar",
    "comandarmos": "comandar",
    "comandará": "comandar",
    "comandarás": "comandar",
    "comandarão": "comandar",
    "comandaríamos": "comandar",
    "comandaríeis": "comandar",
    "comandas": "comandar",
    "comandasse": "comandar",
    "comandassem": "comandar",
    "comandasses": "comandar",
    "comandaste": "comandar",
    "comandastes": "comandar",
    "comandava": "comandar",
    "comandavam": "comandar",
    "comandavas": "comandar",
    "comande": "comandar",
    "comandei": "comandar",
    "comandeis": "comandar",
    "comandem": "comandar",
    "comandemo": "comandar",
    "comandemos": "comandar",
    "comandes": "comandar",
    "comandidata": "comandidato",
    "comandidatas": "comandidato",
    "comandidatos": "comandidato",
    "comandita": "comanditar",
    "comanditada": "comanditar",
    "comanditadas": "comanditar",
    "comanditado": "comanditar",
    "comanditados": "comanditar",
    "comanditai": "comanditar",
    "comanditais": "comanditar",
    "comanditam": "comanditar",
    "comanditamo": "comanditar",
    "comanditamos": "comanditar",
    "comanditando": "comanditar",
    "comanditara": "comanditar",
    "comanditaram": "comanditar",
    "comanditaras": "comanditar",
    "comanditarde": "comanditar",
    "comanditardes": "comanditar",
    "comanditare": "comanditar",
    "comanditarei": "comanditar",
    "comanditareis": "comanditar",
    "comanditarem": "comanditar",
    "comanditaremos": "comanditar",
    "comanditares": "comanditar",
    "comanditaria": "comanditar",
    "comanditariam": "comanditar",
    "comanditarias": "comanditar",
    "comanditarmo": "comanditar",
    "comanditarmos": "comanditar",
    "comanditará": "comanditar",
    "comanditarás": "comanditar",
    "comanditarão": "comanditar",
    "comanditaríamos": "comanditar",
    "comanditaríeis": "comanditar",
    "comanditas": "comanditar",
    "comanditasse": "comanditar",
    "comanditassem": "comanditar",
    "comanditasses": "comanditar",
    "comanditaste": "comanditar",
    "comanditastes": "comanditar",
    "comanditava": "comanditar",
    "comanditavam": "comanditar",
    "comanditavas": "comanditar",
    "comandite": "comanditar",
    "comanditei": "comanditar",
    "comanditeis": "comanditar",
    "comanditem": "comanditar",
    "comanditemo": "comanditar",
    "comanditemos": "comanditar",
    "comandites": "comanditar",
    "comandito": "comanditar",
    "comanditou": "comanditar",
    "comanditá": "comanditar",
    "comanditámo": "comanditar",
    "comanditámos": "comanditar",
    "comanditáramo": "comanditar",
    "comanditáramos": "comanditar",
    "comanditárei": "comanditar",
    "comanditáreis": "comanditar",
    "comanditária": "comanditário",
    "comanditárias": "comanditário",
    "comanditários": "comanditário",
    "comanditásseis": "comanditar",
    "comanditássemos": "comanditar",
    "comanditávamo": "comanditar",
    "comanditávamos": "comanditar",
    "comanditávei": "comanditar",
    "comanditáveis": "comanditar",
    "comando": "comandar",
    "comandos": "comando",
    "comandou": "comandar",
    "comandá": "comandar",
    "comandámo": "comandar",
    "comandámos": "comandar",
    "comandáramo": "comandar",
    "comandáramos": "comandar",
    "comandárei": "comandar",
    "comandáreis": "comandar",
    "comandásseis": "comandar",
    "comandássemos": "comandar",
    "comandávamo": "comandar",
    "comandávamos": "comandar",
    "comandávei": "comandar",
    "comandáveis": "comandar",
    "comarca": "comarcar",
    "comarcada": "comarcar",
    "comarcadas": "comarcar",
    "comarcado": "comarcar",
    "comarcados": "comarcar",
    "comarcais": "comarcar",
    "comarcam": "comarcar",
    "comarcamo": "comarcar",
    "comarcamos": "comarcar",
    "comarcando": "comarcar",
    "comarcara": "comarcar",
    "comarcaram": "comarcar",
    "comarcaras": "comarcar",
    "comarcardes": "comarcar",
    "comarcarei": "comarcar",
    "comarcareis": "comarcar",
    "comarcarem": "comarcar",
    "comarcaremos": "comarcar",
    "comarcares": "comarcar",
    "comarcaria": "comarcar",
    "comarcariam": "comarcar",
    "comarcarias": "comarcar",
    "comarcarmo": "comarcar",
    "comarcarmos": "comarcar",
    "comarcará": "comarcar",
    "comarcarás": "comarcar",
    "comarcarão": "comarcar",
    "comarcaríamos": "comarcar",
    "comarcaríeis": "comarcar",
    "comarcas": "comarcar",
    "comarcasse": "comarcar",
    "comarcassem": "comarcar",
    "comarcasses": "comarcar",
    "comarcaste": "comarcar",
    "comarcastes": "comarcar",
    "comarcava": "comarcar",
    "comarcavam": "comarcar",
    "comarcavas": "comarcar",
    "comarco": "comarcar",
    "comarcou": "comarcar",
    "comarcámo": "comarcar",
    "comarcámos": "comarcar",
    "comarcáramo": "comarcar",
    "comarcáramos": "comarcar",
    "comarcáreis": "comarcar",
    "comarcásseis": "comarcar",
    "comarcássemos": "comarcar",
    "comarcávamo": "comarcar",
    "comarcávamos": "comarcar",
    "comarcáveis": "comarcar",
    "comarcã": "comarcão",
    "comarcãos": "comarcão",
    "comarcãs": "comarcão",
    "comarque": "comarcar",
    "comarquei": "comarcar",
    "comarqueira": "comarqueiro",
    "comarqueiras": "comarqueiro",
    "comarqueiros": "comarqueiro",
    "comarqueis": "comarcar",
    "comarquem": "comarcar",
    "comarquemos": "comarcar",
    "comarques": "comarcar",
    "comas": "comer",
    "comatosa": "comatoso",
    "comatosas": "comatoso",
    "comatosos": "comatoso",
    "comatulídea": "comatulídeo",
    "comatulídeas": "comatulídeo",
    "comatulídeos": "comatulídeo",
    "comatúlidas": "comatúlida",
    "combala": "combalir",
    "combalais": "combalir",
    "combalam": "combalir",
    "combalamo": "combalir",
    "combalamos": "combalir",
    "combalas": "combalir",
    "combale": "combalir",
    "combalem": "combalir",
    "combales": "combalir",
    "combali": "combalir",
    "combalia": "combalir",
    "combaliam": "combalir",
    "combalias": "combalir",
    "combalida": "combalir",
    "combalidas": "combalir",
    "combalido": "combalir",
    "combalidos": "combalir",
    "combalimo": "combalir",
    "combalimos": "combalir",
    "combalindo": "combalir",
    "combalira": "combalir",
    "combaliram": "combalir",
    "combaliras": "combalir",
    "combalirde": "combalir",
    "combalirdes": "combalir",
    "combalire": "combalir",
    "combalirei": "combalir",
    "combalireis": "combalir",
    "combalirem": "combalir",
    "combaliremos": "combalir",
    "combalires": "combalir",
    "combaliria": "combalir",
    "combaliriam": "combalir",
    "combalirias": "combalir",
    "combalirmo": "combalir",
    "combalirmos": "combalir",
    "combalirá": "combalir",
    "combalirás": "combalir",
    "combalirão": "combalir",
    "combaliríamos": "combalir",
    "combaliríeis": "combalir",
    "combalis": "combalir",
    "combalisse": "combalir",
    "combalissem": "combalir",
    "combalisses": "combalir",
    "combaliste": "combalir",
    "combalistes": "combalir",
    "combaliu": "combalir",
    "combalo": "combalir",
    "combalíamo": "combalir",
    "combalíamos": "combalir",
    "combalíei": "combalir",
    "combalíeis": "combalir",
    "combalíramo": "combalir",
    "combalíramos": "combalir",
    "combalírei": "combalir",
    "combalíreis": "combalir",
    "combalísseis": "combalir",
    "combalíssemos": "combalir",
    "combarins": "combarim",
    "combas": "comba",
    "combata": "combater",
    "combatais": "combater",
    "combatam": "combater",
    "combatamo": "combater",
    "combatamos": "combater",
    "combatarias": "combataria",
    "combatas": "combater",
    "combate": "combater",
    "combatei": "combater",
    "combateis": "combater",
    "combatem": "combater",
    "combatemo": "combater",
    "combatemos": "combater",
    "combatendo": "combater",
    "combatentes": "combatente",
    "combatera": "combater",
    "combateram": "combater",
    "combateras": "combater",
    "combaterdes": "combater",
    "combaterei": "combater",
    "combatereis": "combater",
    "combaterem": "combater",
    "combateremos": "combater",
    "combateres": "combater",
    "combateria": "combater",
    "combateriam": "combater",
    "combaterias": "combater",
    "combatermo": "combater",
    "combatermos": "combater",
    "combaterá": "combater",
    "combaterás": "combater",
    "combaterão": "combater",
    "combateríamos": "combater",
    "combateríeis": "combater",
    "combates": "combater",
    "combatesse": "combater",
    "combatessem": "combater",
    "combatesses": "combater",
    "combateste": "combater",
    "combatestes": "combater",
    "combateu": "combater",
    "combati": "combater",
    "combatia": "combater",
    "combatiam": "combater",
    "combatias": "combater",
    "combatida": "combatido",
    "combatidas": "combatido",
    "combatido": "combater",
    "combatidos": "combatido",
    "combativa": "combativo",
    "combativas": "combativo",
    "combatividades": "combatividade",
    "combativos": "combativo",
    "combato": "combater",
    "combatêramo": "combater",
    "combatêramos": "combater",
    "combatêreis": "combater",
    "combatêsseis": "combater",
    "combatêssemos": "combater",
    "combatíamo": "combater",
    "combatíamos": "combater",
    "combatíeis": "combater",
    "combatíveis": "combatível",
    "combina": "combinar",
    "combinada": "combinar",
    "combinadas": "combinar",
    "combinado": "combinar",
    "combinadora": "combinador",
    "combinadoras": "combinador",
    "combinadores": "combinador",
    "combinados": "combinar",
    "combinai": "combinar",
    "combinais": "combinar",
    "combinam": "combinar",
    "combinamo": "combinar",
    "combinamos": "combinar",
    "combinando": "combinar",
    "combinara": "combinar",
    "combinaram": "combinar",
    "combinaras": "combinar",
    "combinarde": "combinar",
    "combinardes": "combinar",
    "combinare": "combinar",
    "combinarei": "combinar",
    "combinareis": "combinar",
    "combinarem": "combinar",
    "combinaremos": "combinar",
    "combinares": "combinar",
    "combinaria": "combinar",
    "combinariam": "combinar",
    "combinarias": "combinar",
    "combinarmo": "combinar",
    "combinarmos": "combinar",
    "combinará": "combinar",
    "combinarás": "combinar",
    "combinarão": "combinar",
    "combinaríamos": "combinar",
    "combinaríeis": "combinar",
    "combinas": "combinar",
    "combinasse": "combinar",
    "combinassem": "combinar",
    "combinasses": "combinar",
    "combinaste": "combinar",
    "combinastes": "combinar",
    "combinatória": "combinatório",
    "combinatórias": "combinatório",
    "combinatórios": "combinatório",
    "combinava": "combinar",
    "combinavam": "combinar",
    "combinavas": "combinar",
    "combinações": "combinação",
    "combine": "combinar",
    "combinei": "combinar",
    "combineis": "combinar",
    "combinem": "combinar",
    "combinemo": "combinar",
    "combinemos": "combinar",
    "combines": "combinar",
    "combino": "combinar",
    "combinou": "combinar",
    "combiná": "combinar",
    "combinámo": "combinar",
    "combinámos": "combinar",
    "combináramo": "combinar",
    "combináramos": "combinar",
    "combinárei": "combinar",
    "combináreis": "combinar",
    "combinásseis": "combinar",
    "combinássemos": "combinar",
    "combinávamo": "combinar",
    "combinávamos": "combinar",
    "combinávei": "combinar",
    "combináveis": "combinável",
    "comboia": "comboiar",
    "comboiada": "comboiar",
    "comboiadas": "comboiar",
    "comboiado": "comboiar",
    "comboiados": "comboiar",
    "comboiai": "comboiar",
    "comboiais": "comboiar",
    "comboiam": "comboiar",
    "comboiamentos": "comboiamento",
    "comboiamo": "comboiar",
    "comboiamos": "comboiar",
    "comboiando": "comboiar",
    "comboiara": "comboiar",
    "comboiaram": "comboiar",
    "comboiaras": "comboiar",
    "comboiarde": "comboiar",
    "comboiardes": "comboiar",
    "comboiare": "comboiar",
    "comboiarei": "comboiar",
    "comboiareis": "comboiar",
    "comboiarem": "comboiar",
    "comboiaremos": "comboiar",
    "comboiares": "comboiar",
    "comboiaria": "comboiar",
    "comboiariam": "comboiar",
    "comboiarias": "comboiar",
    "comboiarmo": "comboiar",
    "comboiarmos": "comboiar",
    "comboiará": "comboiar",
    "comboiarás": "comboiar",
    "comboiarão": "comboiar",
    "comboiaríamos": "comboiar",
    "comboiaríeis": "comboiar",
    "comboias": "comboiar",
    "comboiasse": "comboiar",
    "comboiassem": "comboiar",
    "comboiasses": "comboiar",
    "comboiaste": "comboiar",
    "comboiastes": "comboiar",
    "comboiava": "comboiar",
    "comboiavam": "comboiar",
    "comboiavas": "comboiar",
    "comboie": "comboiar",
    "comboiei": "comboiar",
    "comboieira": "comboieiro",
    "comboieiras": "comboieiro",
    "comboieiros": "comboieiro",
    "comboieis": "comboiar",
    "comboiem": "comboiar",
    "comboiemo": "comboiar",
    "comboiemos": "comboiar",
    "comboies": "comboiar",
    "comboio": "comboiar",
    "comboios": "comboio",
    "comboiou": "comboiar",
    "comboiá": "comboiar",
    "comboiámo": "comboiar",
    "comboiámos": "comboiar",
    "comboiáramo": "comboiar",
    "comboiáramos": "comboiar",
    "comboiárei": "comboiar",
    "comboiáreis": "comboiar",
    "comboiásseis": "comboiar",
    "comboiássemos": "comboiar",
    "comboiávamo": "comboiar",
    "comboiávamos": "comboiar",
    "comboiávei": "comboiar",
    "comboiáveis": "comboiar",
    "combonas": "combona",
    "comborçarias": "comborçaria",
    "comborças": "comborça",
    "comborços": "comborço",
    "combretácea": "combretáceo",
    "combretáceas": "combretáceo",
    "combretáceos": "combretáceo",
    "combros": "combro",
    "combura": "comburir",
    "comburais": "comburir",
    "comburam": "comburir",
    "comburamo": "comburir",
    "comburamos": "comburir",
    "comburas": "comburir",
    "combure": "comburir",
    "comburem": "comburir",
    "comburentes": "comburente",
    "combures": "comburir",
    "comburi": "comburir",
    "comburia": "comburir",
    "comburiam": "comburir",
    "comburias": "comburir",
    "comburida": "comburir",
    "comburidas": "comburir",
    "comburido": "comburir",
    "comburidos": "comburir",
    "comburimo": "comburir",
    "comburimos": "comburir",
    "comburindo": "comburir",
    "comburira": "comburir",
    "comburiram": "comburir",
    "comburiras": "comburir",
    "comburirde": "comburir",
    "comburirdes": "comburir",
    "comburire": "comburir",
    "comburirei": "comburir",
    "comburireis": "comburir",
    "comburirem": "comburir",
    "comburiremos": "comburir",
    "comburires": "comburir",
    "comburiria": "comburir",
    "combuririam": "comburir",
    "comburirias": "comburir",
    "comburirmo": "comburir",
    "comburirmos": "comburir",
    "comburirá": "comburir",
    "comburirás": "comburir",
    "comburirão": "comburir",
    "comburiríamos": "comburir",
    "comburiríeis": "comburir",
    "comburis": "comburir",
    "comburisse": "comburir",
    "comburissem": "comburir",
    "comburisses": "comburir",
    "comburiste": "comburir",
    "comburistes": "comburir",
    "comburiu": "comburir",
    "comburo": "comburir",
    "comburíamo": "comburir",
    "comburíamos": "comburir",
    "comburíei": "comburir",
    "comburíeis": "comburir",
    "comburíramo": "comburir",
    "comburíramos": "comburir",
    "comburírei": "comburir",
    "comburíreis": "comburir",
    "comburísseis": "comburir",
    "comburíssemos": "comburir",
    "combusta": "combusto",
    "combustas": "combusto",
    "combustibilidades": "combustibilidade",
    "combustiva": "combustivo",
    "combustivas": "combustivo",
    "combustivos": "combustivo",
    "combustora": "combustor",
    "combustoras": "combustor",
    "combustores": "combustor",
    "combustos": "combusto",
    "combustíveis": "combustível",
    "combustões": "combustão",
    "come": "comer",
    "comece": "começar",
    "comecei": "começar",
    "comeceis": "começar",
    "comecem": "começar",
    "comecemo": "começar",
    "comecemos": "começar",
    "comeces": "começar",
    "comede": "comedir",
    "comedeiras": "comedeira",
    "comedelas": "comedela",
    "comedem": "comedir",
    "comedes": "comedir",
    "comedi": "comedir",
    "comedia": "comedir",
    "comediam": "comedir",
    "comediantes": "comediante",
    "comedias": "comedir",
    "comedida": "comedir",
    "comedidas": "comedir",
    "comedido": "comedir",
    "comedidos": "comedir",
    "comedidíssima": "comedido",
    "comedidíssimas": "comedido",
    "comedidíssimo": "comedido",
    "comedidíssimos": "comedido",
    "comedimentos": "comedimento",
    "comedimo": "comedir",
    "comedimos": "comedir",
    "comedindo": "comedir",
    "comediográfica": "comediográfico",
    "comediográficas": "comediográfico",
    "comediográficos": "comediográfico",
    "comedira": "comedir",
    "comediram": "comedir",
    "comediras": "comedir",
    "comedirde": "comedir",
    "comedirdes": "comedir",
    "comedire": "comedir",
    "comedirei": "comedir",
    "comedireis": "comedir",
    "comedirem": "comedir",
    "comediremos": "comedir",
    "comedires": "comedir",
    "comediria": "comedir",
    "comediriam": "comedir",
    "comedirias": "comedir",
    "comedirmo": "comedir",
    "comedirmos": "comedir",
    "comedirá": "comedir",
    "comedirás": "comedir",
    "comedirão": "comedir",
    "comediríamos": "comedir",
    "comediríeis": "comedir",
    "comedis": "comedir",
    "comedisse": "comedir",
    "comedissem": "comedir",
    "comedisses": "comedir",
    "comediste": "comedir",
    "comedistes": "comedir",
    "comediu": "comedir",
    "comediógrafa": "comediógrafo",
    "comediógrafas": "comediógrafo",
    "comediógrafos": "comediógrafo",
    "comedoiros": "comedoiro",
    "comedora": "comedor",
    "comedoras": "comedor",
    "comedores": "comedor",
    "comedorias": "comedoria",
    "comedouros": "comedouro",
    "comedíamo": "comedir",
    "comedíamos": "comedir",
    "comedíei": "comedir",
    "comedíeis": "comedir",
    "comedíramo": "comedir",
    "comedíramos": "comedir",
    "comedírei": "comedir",
    "comedíreis": "comedir",
    "comedísseis": "comedir",
    "comedíssemos": "comedir",
    "comei": "comer",
    "comeis": "comer",
    "comelinácea": "comelináceo",
    "comelináceas": "comelináceo",
    "comelináceos": "comelináceo",
    "comem": "comer",
    "comemo": "comer",
    "comemora": "comemorar",
    "comemorada": "comemorar",
    "comemoradas": "comemorar",
    "comemorado": "comemorar",
    "comemorados": "comemorar",
    "comemorai": "comemorar",
    "comemorais": "comemorar",
    "comemoram": "comemorar",
    "comemoramo": "comemorar",
    "comemoramos": "comemorar",
    "comemorando": "comemorar",
    "comemorara": "comemorar",
    "comemoraram": "comemorar",
    "comemoraras": "comemorar",
    "comemorarde": "comemorar",
    "comemorardes": "comemorar",
    "comemorare": "comemorar",
    "comemorarei": "comemorar",
    "comemorareis": "comemorar",
    "comemorarem": "comemorar",
    "comemoraremos": "comemorar",
    "comemorares": "comemorar",
    "comemoraria": "comemorar",
    "comemorariam": "comemorar",
    "comemorarias": "comemorar",
    "comemorarmo": "comemorar",
    "comemorarmos": "comemorar",
    "comemorará": "comemorar",
    "comemorarás": "comemorar",
    "comemorarão": "comemorar",
    "comemoraríamos": "comemorar",
    "comemoraríeis": "comemorar",
    "comemoras": "comemorar",
    "comemorasse": "comemorar",
    "comemorassem": "comemorar",
    "comemorasses": "comemorar",
    "comemoraste": "comemorar",
    "comemorastes": "comemorar",
    "comemorativa": "comemorativo",
    "comemorativas": "comemorativo",
    "comemorativos": "comemorativo",
    "comemorava": "comemorar",
    "comemoravam": "comemorar",
    "comemoravas": "comemorar",
    "comemorações": "comemoração",
    "comemore": "comemorar",
    "comemorei": "comemorar",
    "comemoreis": "comemorar",
    "comemorem": "comemorar",
    "comemoremo": "comemorar",
    "comemoremos": "comemorar",
    "comemores": "comemorar",
    "comemoro": "comemorar",
    "comemorou": "comemorar",
    "comemorá": "comemorar",
    "comemorámo": "comemorar",
    "comemorámos": "comemorar",
    "comemoráramo": "comemorar",
    "comemoráramos": "comemorar",
    "comemorárei": "comemorar",
    "comemoráreis": "comemorar",
    "comemorásseis": "comemorar",
    "comemorássemos": "comemorar",
    "comemorávamo": "comemorar",
    "comemorávamos": "comemorar",
    "comemorávei": "comemorar",
    "comemoráveis": "comemorável",
    "comemos": "comer",
    "comendadeira": "comendador",
    "comendadeiras": "comendador",
    "comendadores": "comendador",
    "comendadorias": "comendadoria",
    "comendas": "comenda",
    "comendatarias": "comendataria",
    "comendativa": "comendativo",
    "comendativas": "comendativo",
    "comendativos": "comendativo",
    "comendatária": "comendatário",
    "comendatárias": "comendatário",
    "comendatários": "comendatário",
    "comendatícia": "comendatício",
    "comendatícias": "comendatício",
    "comendatícios": "comendatício",
    "comendatória": "comendatório",
    "comendatórias": "comendatório",
    "comendatórios": "comendatório",
    "comendo": "comer",
    "comensais": "comensal",
    "comensalidades": "comensalidade",
    "comensalismos": "comensalismo",
    "comensalícia": "comensalício",
    "comensalícias": "comensalício",
    "comensalícios": "comensalício",
    "comensura": "comensurar",
    "comensurabilidades": "comensurabilidade",
    "comensurada": "comensurar",
    "comensuradas": "comensurar",
    "comensurado": "comensurar",
    "comensurados": "comensurar",
    "comensurai": "comensurar",
    "comensurais": "comensurar",
    "comensuram": "comensurar",
    "comensuramo": "comensurar",
    "comensuramos": "comensurar",
    "comensurando": "comensurar",
    "comensurara": "comensurar",
    "comensuraram": "comensurar",
    "comensuraras": "comensurar",
    "comensurarde": "comensurar",
    "comensurardes": "comensurar",
    "comensurare": "comensurar",
    "comensurarei": "comensurar",
    "comensurareis": "comensurar",
    "comensurarem": "comensurar",
    "comensuraremos": "comensurar",
    "comensurares": "comensurar",
    "comensuraria": "comensurar",
    "comensurariam": "comensurar",
    "comensurarias": "comensurar",
    "comensurarmo": "comensurar",
    "comensurarmos": "comensurar",
    "comensurará": "comensurar",
    "comensurarás": "comensurar",
    "comensurarão": "comensurar",
    "comensuraríamos": "comensurar",
    "comensuraríeis": "comensurar",
    "comensuras": "comensurar",
    "comensurasse": "comensurar",
    "comensurassem": "comensurar",
    "comensurasses": "comensurar",
    "comensuraste": "comensurar",
    "comensurastes": "comensurar",
    "comensurava": "comensurar",
    "comensuravam": "comensurar",
    "comensuravas": "comensurar",
    "comensurações": "comensuração",
    "comensure": "comensurar",
    "comensurei": "comensurar",
    "comensureis": "comensurar",
    "comensurem": "comensurar",
    "comensuremo": "comensurar",
    "comensuremos": "comensurar",
    "comensures": "comensurar",
    "comensuro": "comensurar",
    "comensurou": "comensurar",
    "comensurá": "comensurar",
    "comensurámo": "comensurar",
    "comensurámos": "comensurar",
    "comensuráramo": "comensurar",
    "comensuráramos": "comensurar",
    "comensurárei": "comensurar",
    "comensuráreis": "comensurar",
    "comensurásseis": "comensurar",
    "comensurássemos": "comensurar",
    "comensurávamo": "comensurar",
    "comensurávamos": "comensurar",
    "comensurávei": "comensurar",
    "comensuráveis": "comensurável",
    "comenta": "comentar",
    "comentada": "comentar",
    "comentadas": "comentar",
    "comentado": "comentar",
    "comentadora": "comentador",
    "comentadoras": "comentador",
    "comentadores": "comentador",
    "comentados": "comentar",
    "comentadíssima": "comentado",
    "comentadíssimas": "comentado",
    "comentadíssimo": "comentado",
    "comentadíssimos": "comentado",
    "comentai": "comentar",
    "comentais": "comentar",
    "comentam": "comentar",
    "comentamo": "comentar",
    "comentamos": "comentar",
    "comentando": "comentar",
    "comentara": "comentar",
    "comentaram": "comentar",
    "comentaras": "comentar",
    "comentarde": "comentar",
    "comentardes": "comentar",
    "comentare": "comentar",
    "comentarei": "comentar",
    "comentareis": "comentar",
    "comentarem": "comentar",
    "comentaremos": "comentar",
    "comentares": "comentar",
    "comentaria": "comentar",
    "comentariam": "comentar",
    "comentarias": "comentar",
    "comentaristaa": "comentarista",
    "comentaristaas": "comentarista",
    "comentaristaes": "comentarista",
    "comentarmo": "comentar",
    "comentarmos": "comentar",
    "comentará": "comentar",
    "comentarás": "comentar",
    "comentarão": "comentar",
    "comentaríamos": "comentar",
    "comentaríeis": "comentar",
    "comentas": "comentar",
    "comentasse": "comentar",
    "comentassem": "comentar",
    "comentasses": "comentar",
    "comentaste": "comentar",
    "comentastes": "comentar",
    "comentava": "comentar",
    "comentavam": "comentar",
    "comentavas": "comentar",
    "comentações": "comentação",
    "comente": "comentar",
    "comentei": "comentar",
    "comenteis": "comentar",
    "comentem": "comentar",
    "comentemo": "comentar",
    "comentemos": "comentar",
    "comentes": "comentar",
    "comento": "comentar",
    "comentos": "comento",
    "comentou": "comentar",
    "comentá": "comentar",
    "comentámo": "comentar",
    "comentámos": "comentar",
    "comentáramo": "comentar",
    "comentáramos": "comentar",
    "comentárei": "comentar",
    "comentáreis": "comentar",
    "comentários": "comentário",
    "comentásseis": "comentar",
    "comentássemos": "comentar",
    "comentávamo": "comentar",
    "comentávamos": "comentar",
    "comentávei": "comentar",
    "comentáveis": "comentar",
    "comera": "comer",
    "comeram": "comer",
    "comeras": "comer",
    "comerceia": "comerciar",
    "comerceiam": "comerciar",
    "comerceias": "comerciar",
    "comerceie": "comerciar",
    "comerceiem": "comerciar",
    "comerceies": "comerciar",
    "comerceio": "comerciar",
    "comercia": "comerciar",
    "comerciada": "comerciar",
    "comerciadas": "comerciar",
    "comerciado": "comerciar",
    "comerciados": "comerciar",
    "comerciai": "comerciar",
    "comerciais": "comerciar",
    "comercialismos": "comercialismo",
    "comercialistas": "comercialista",
    "comercializa": "comercializar",
    "comercializada": "comercializar",
    "comercializadas": "comercializar",
    "comercializado": "comercializar",
    "comercializados": "comercializar",
    "comercializai": "comercializar",
    "comercializais": "comercializar",
    "comercializam": "comercializar",
    "comercializamo": "comercializar",
    "comercializamos": "comercializar",
    "comercializando": "comercializar",
    "comercializara": "comercializar",
    "comercializaram": "comercializar",
    "comercializaras": "comercializar",
    "comercializarde": "comercializar",
    "comercializardes": "comercializar",
    "comercializare": "comercializar",
    "comercializarei": "comercializar",
    "comercializareis": "comercializar",
    "comercializarem": "comercializar",
    "comercializaremos": "comercializar",
    "comercializares": "comercializar",
    "comercializaria": "comercializar",
    "comercializariam": "comercializar",
    "comercializarias": "comercializar",
    "comercializarmo": "comercializar",
    "comercializarmos": "comercializar",
    "comercializará": "comercializar",
    "comercializarás": "comercializar",
    "comercializarão": "comercializar",
    "comercializaríamos": "comercializar",
    "comercializaríeis": "comercializar",
    "comercializas": "comercializar",
    "comercializasse": "comercializar",
    "comercializassem": "comercializar",
    "comercializasses": "comercializar",
    "comercializaste": "comercializar",
    "comercializastes": "comercializar",
    "comercializava": "comercializar",
    "comercializavam": "comercializar",
    "comercializavas": "comercializar",
    "comercializações": "comercialização",
    "comercialize": "comercializar",
    "comercializei": "comercializar",
    "comercializeis": "comercializar",
    "comercializem": "comercializar",
    "comercializemo": "comercializar",
    "comercializemos": "comercializar",
    "comercializes": "comercializar",
    "comercializo": "comercializar",
    "comercializou": "comercializar",
    "comercializá": "comercializar",
    "comercializámo": "comercializar",
    "comercializámos": "comercializar",
    "comercializáramo": "comercializar",
    "comercializáramos": "comercializar",
    "comercializárei": "comercializar",
    "comercializáreis": "comercializar",
    "comercializásseis": "comercializar",
    "comercializássemos": "comercializar",
    "comercializávamo": "comercializar",
    "comercializávamos": "comercializar",
    "comercializávei": "comercializar",
    "comercializáveis": "comercializável",
    "comerciam": "comerciar",
    "comerciamo": "comerciar",
    "comerciamos": "comerciar",
    "comerciando": "comerciar",
    "comerciantes": "comerciante",
    "comerciara": "comerciar",
    "comerciaram": "comerciar",
    "comerciaras": "comerciar",
    "comerciarde": "comerciar",
    "comerciardes": "comerciar",
    "comerciare": "comerciar",
    "comerciarei": "comerciar",
    "comerciareis": "comerciar",
    "comerciarem": "comerciar",
    "comerciaremos": "comerciar",
    "comerciares": "comerciar",
    "comerciaria": "comerciar",
    "comerciariam": "comerciar",
    "comerciarias": "comerciar",
    "comerciarmo": "comerciar",
    "comerciarmos": "comerciar",
    "comerciará": "comerciar",
    "comerciarás": "comerciar",
    "comerciarão": "comerciar",
    "comerciaríamos": "comerciar",
    "comerciaríeis": "comerciar",
    "comercias": "comerciar",
    "comerciasse": "comerciar",
    "comerciassem": "comerciar",
    "comerciasses": "comerciar",
    "comerciaste": "comerciar",
    "comerciastes": "comerciar",
    "comerciava": "comerciar",
    "comerciavam": "comerciar",
    "comerciavas": "comerciar",
    "comercie": "comerciar",
    "comerciei": "comerciar",
    "comercieis": "comerciar",
    "comerciem": "comerciar",
    "comerciemo": "comerciar",
    "comerciemos": "comerciar",
    "comercies": "comerciar",
    "comercio": "comerciar",
    "comerciou": "comerciar",
    "comerciá": "comerciar",
    "comerciámo": "comerciar",
    "comerciámos": "comerciar",
    "comerciáramo": "comerciar",
    "comerciáramos": "comerciar",
    "comerciárei": "comerciar",
    "comerciáreis": "comerciar",
    "comerciásseis": "comerciar",
    "comerciássemos": "comerciar",
    "comerciávamo": "comerciar",
    "comerciávamos": "comerciar",
    "comerciávei": "comerciar",
    "comerciáveis": "comerciável",
    "comerde": "comer",
    "comerdes": "comer",
    "comere": "comer",
    "comerei": "comer",
    "comereis": "comer",
    "comerem": "comer",
    "comeremos": "comer",
    "comeres": "comer",
    "comeretes": "comerete",
    "comeria": "comer",
    "comeriam": "comer",
    "comerias": "comer",
    "comermo": "comer",
    "comermos": "comer",
    "comerá": "comer",
    "comerás": "comer",
    "comerão": "comer",
    "comeríamos": "comer",
    "comeríeis": "comer",
    "comes": "comer",
    "comesse": "comer",
    "comessem": "comer",
    "comesses": "comer",
    "comeste": "comer",
    "comestes": "comer",
    "comestibilidades": "comestibilidade",
    "comestíveis": "comestível",
    "cometa": "cometer",
    "cometais": "cometer",
    "cometam": "cometer",
    "cometamo": "cometer",
    "cometamos": "cometer",
    "cometares": "cometar",
    "cometas": "cometer",
    "comete": "cometer",
    "cometedora": "cometedor",
    "cometedoras": "cometedor",
    "cometedores": "cometedor",
    "cometei": "cometer",
    "cometeis": "cometer",
    "cometem": "cometer",
    "cometemo": "cometer",
    "cometemos": "cometer",
    "cometendo": "cometer",
    "cometentes": "cometente",
    "cometera": "cometer",
    "cometeram": "cometer",
    "cometeras": "cometer",
    "cometerde": "cometer",
    "cometerdes": "cometer",
    "cometere": "cometer",
    "cometerei": "cometer",
    "cometereis": "cometer",
    "cometerem": "cometer",
    "cometeremos": "cometer",
    "cometeres": "cometer",
    "cometeria": "cometer",
    "cometeriam": "cometer",
    "cometerias": "cometer",
    "cometermo": "cometer",
    "cometermos": "cometer",
    "cometerá": "cometer",
    "cometerás": "cometer",
    "cometerão": "cometer",
    "cometeríamos": "cometer",
    "cometeríeis": "cometer",
    "cometes": "cometer",
    "cometesse": "cometer",
    "cometessem": "cometer",
    "cometesses": "cometer",
    "cometeste": "cometer",
    "cometestes": "cometer",
    "cometeu": "cometer",
    "cometi": "cometer",
    "cometia": "cometer",
    "cometiam": "cometer",
    "cometias": "cometer",
    "cometida": "cometido",
    "cometidas": "cometido",
    "cometido": "cometer",
    "cometidos": "cometido",
    "cometimentos": "cometimento",
    "cometo": "cometer",
    "cometomancias": "cometomancia",
    "cometomantes": "cometomante",
    "cometomântica": "cometomântico",
    "cometomânticas": "cometomântico",
    "cometomânticos": "cometomântico",
    "cometária": "cometário",
    "cometárias": "cometário",
    "cometários": "cometário",
    "cometê": "cometer",
    "cometêramo": "cometer",
    "cometêramos": "cometer",
    "cometêrei": "cometer",
    "cometêreis": "cometer",
    "cometêsseis": "cometer",
    "cometêssemos": "cometer",
    "cometíamo": "cometer",
    "cometíamos": "cometer",
    "cometíei": "cometer",
    "cometíeis": "cometer",
    "cometíveis": "cometível",
    "comeu": "comer",
    "comezainas": "comezaina",
    "comezanas": "comezana",
    "comezinha": "comezinho",
    "comezinhas": "comezinho",
    "comezinhos": "comezinho",
    "começa": "comedir",
    "começada": "começar",
    "começadas": "começar",
    "começado": "começar",
    "começadora": "começador",
    "começadoras": "começador",
    "começadores": "começador",
    "começados": "começar",
    "começai": "começar",
    "começais": "comedir",
    "começam": "comedir",
    "começamo": "comedir",
    "começamos": "comedir",
    "começando": "começar",
    "começantes": "começante",
    "começara": "começar",
    "começaram": "começar",
    "começaras": "começar",
    "começarde": "começar",
    "começardes": "começar",
    "começare": "começar",
    "começarei": "começar",
    "começareis": "começar",
    "começarem": "começar",
    "começaremos": "começar",
    "começares": "começar",
    "começaria": "começar",
    "começariam": "começar",
    "começarias": "começar",
    "começarmo": "começar",
    "começarmos": "começar",
    "começará": "começar",
    "começarás": "começar",
    "começarão": "começar",
    "começaríamos": "começar",
    "começaríeis": "começar",
    "começas": "comedir",
    "começasse": "começar",
    "começassem": "começar",
    "começasses": "começar",
    "começaste": "começar",
    "começastes": "começar",
    "começava": "começar",
    "começavam": "começar",
    "começavas": "começar",
    "começo": "comedir",
    "começos": "começo",
    "começou": "começar",
    "começá": "começar",
    "começámo": "começar",
    "começámos": "começar",
    "começáramo": "começar",
    "começáramos": "começar",
    "começárei": "começar",
    "começáreis": "começar",
    "começásseis": "começar",
    "começássemos": "começar",
    "começávamo": "começar",
    "começávamos": "começar",
    "começávei": "começar",
    "começáveis": "começar",
    "comi": "comer",
    "comia": "comer",
    "comiam": "comer",
    "comias": "comer",
    "comichenta": "comichento",
    "comichentas": "comichento",
    "comichentos": "comichento",
    "comichona": "comichão",
    "comichonas": "comichona",
    "comichosa": "comichoso",
    "comichosas": "comichoso",
    "comichosos": "comichoso",
    "comichões": "comichão",
    "comiciais": "comicial",
    "comicidades": "comicidade",
    "comicieira": "comicieiro",
    "comicieiras": "comicieiro",
    "comicieiros": "comicieiro",
    "comics": "comic",
    "comida": "comido",
    "comidas": "comido",
    "comidinha": "comida",
    "comidinhas": "comida",
    "comidita": "comida",
    "comiditas": "comida",
    "comido": "comer",
    "comidos": "comido",
    "comila": "comilar",
    "comilada": "comilar",
    "comiladas": "comilar",
    "comilado": "comilar",
    "comilados": "comilar",
    "comilai": "comilar",
    "comilais": "comilar",
    "comilam": "comilar",
    "comilamo": "comilar",
    "comilamos": "comilar",
    "comilando": "comilar",
    "comilanças": "comilança",
    "comilara": "comilar",
    "comilaram": "comilar",
    "comilaras": "comilar",
    "comilarde": "comilar",
    "comilardes": "comilar",
    "comilare": "comilar",
    "comilarei": "comilar",
    "comilareis": "comilar",
    "comilarem": "comilar",
    "comilaremos": "comilar",
    "comilares": "comilar",
    "comilaria": "comilar",
    "comilariam": "comilar",
    "comilarias": "comilar",
    "comilarmo": "comilar",
    "comilarmos": "comilar",
    "comilará": "comilar",
    "comilarás": "comilar",
    "comilarão": "comilar",
    "comilaríamos": "comilar",
    "comilaríeis": "comilar",
    "comilas": "comilar",
    "comilasse": "comilar",
    "comilassem": "comilar",
    "comilasses": "comilar",
    "comilaste": "comilar",
    "comilastes": "comilar",
    "comilava": "comilar",
    "comilavam": "comilar",
    "comilavas": "comilar",
    "comile": "comilar",
    "comilei": "comilar",
    "comileis": "comilar",
    "comilem": "comilar",
    "comilemo": "comilar",
    "comilemos": "comilar",
    "comiles": "comilar",
    "comilo": "comilar",
    "comilona": "comilão",
    "comilonas": "comilão",
    "comilou": "comilar",
    "comilá": "comilar",
    "comilámo": "comilar",
    "comilámos": "comilar",
    "comiláramo": "comilar",
    "comiláramos": "comilar",
    "comilárei": "comilar",
    "comiláreis": "comilar",
    "comilásseis": "comilar",
    "comilássemos": "comilar",
    "comilávamo": "comilar",
    "comilávamos": "comilar",
    "comilávei": "comilar",
    "comiláveis": "comilar",
    "comilões": "comilão",
    "comina": "cominar",
    "cominada": "cominar",
    "cominadas": "cominar",
    "cominado": "cominar",
    "cominadora": "cominador",
    "cominadoras": "cominador",
    "cominadores": "cominador",
    "cominados": "cominar",
    "cominai": "cominar",
    "cominais": "cominar",
    "cominam": "cominar",
    "cominamo": "cominar",
    "cominamos": "cominar",
    "cominando": "cominar",
    "cominara": "cominar",
    "cominaram": "cominar",
    "cominaras": "cominar",
    "cominarde": "cominar",
    "cominardes": "cominar",
    "cominare": "cominar",
    "cominarei": "cominar",
    "cominareis": "cominar",
    "cominarem": "cominar",
    "cominaremos": "cominar",
    "cominares": "cominar",
    "cominaria": "cominar",
    "cominariam": "cominar",
    "cominarias": "cominar",
    "cominarmo": "cominar",
    "cominarmos": "cominar",
    "cominará": "cominar",
    "cominarás": "cominar",
    "cominarão": "cominar",
    "cominaríamos": "cominar",
    "cominaríeis": "cominar",
    "cominas": "cominar",
    "cominasse": "cominar",
    "cominassem": "cominar",
    "cominasses": "cominar",
    "cominaste": "cominar",
    "cominastes": "cominar",
    "cominativa": "cominativo",
    "cominativas": "cominativo",
    "cominativos": "cominativo",
    "cominatória": "cominatório",
    "cominatórias": "cominatório",
    "cominatórios": "cominatório",
    "cominava": "cominar",
    "cominavam": "cominar",
    "cominavas": "cominar",
    "cominações": "cominação",
    "comine": "cominar",
    "cominei": "cominar",
    "comineis": "cominar",
    "cominem": "cominar",
    "cominemo": "cominar",
    "cominemos": "cominar",
    "comines": "cominar",
    "cominheiros": "cominheiro",
    "cominhos": "cominho",
    "comino": "cominar",
    "cominou": "cominar",
    "cominua": "cominuir",
    "cominuais": "cominuir",
    "cominuam": "cominuir",
    "cominuamo": "cominuir",
    "cominuamos": "cominuir",
    "cominuas": "cominuir",
    "cominuem": "cominuir",
    "cominui": "cominuir",
    "cominuindo": "cominuir",
    "cominuirde": "cominuir",
    "cominuirdes": "cominuir",
    "cominuirei": "cominuir",
    "cominuireis": "cominuir",
    "cominuiremos": "cominuir",
    "cominuiria": "cominuir",
    "cominuiriam": "cominuir",
    "cominuirias": "cominuir",
    "cominuirmo": "cominuir",
    "cominuirmos": "cominuir",
    "cominuirá": "cominuir",
    "cominuirás": "cominuir",
    "cominuirão": "cominuir",
    "cominuiríamos": "cominuir",
    "cominuiríeis": "cominuir",
    "cominuis": "cominuir",
    "cominuiu": "cominuir",
    "cominuições": "cominuição",
    "cominuo": "cominuir",
    "cominutiva": "cominutivo",
    "cominutivas": "cominutivo",
    "cominutivos": "cominutivo",
    "cominuí": "cominuir",
    "cominuía": "cominuir",
    "cominuíam": "cominuir",
    "cominuíamo": "cominuir",
    "cominuíamos": "cominuir",
    "cominuías": "cominuir",
    "cominuída": "cominuir",
    "cominuídas": "cominuir",
    "cominuído": "cominuir",
    "cominuídos": "cominuir",
    "cominuíei": "cominuir",
    "cominuíeis": "cominuir",
    "cominuímo": "cominuir",
    "cominuímos": "cominuir",
    "cominuíra": "cominuir",
    "cominuíram": "cominuir",
    "cominuíramo": "cominuir",
    "cominuíramos": "cominuir",
    "cominuíras": "cominuir",
    "cominuíre": "cominuir",
    "cominuírei": "cominuir",
    "cominuíreis": "cominuir",
    "cominuírem": "cominuir",
    "cominuíres": "cominuir",
    "cominuís": "cominuir",
    "cominuísse": "cominuir",
    "cominuísseis": "cominuir",
    "cominuíssem": "cominuir",
    "cominuíssemos": "cominuir",
    "cominuísses": "cominuir",
    "cominuíste": "cominuir",
    "cominuístes": "cominuir",
    "cominá": "cominar",
    "cominámo": "cominar",
    "cominámos": "cominar",
    "comináramo": "cominar",
    "comináramos": "cominar",
    "cominárei": "cominar",
    "comináreis": "cominar",
    "cominásseis": "cominar",
    "cominássemos": "cominar",
    "cominávamo": "cominar",
    "cominávamos": "cominar",
    "cominávei": "cominar",
    "comináveis": "cominar",
    "comira": "comirar",
    "comirada": "comirar",
    "comiradas": "comirar",
    "comirado": "comirar",
    "comirados": "comirar",
    "comirai": "comirar",
    "comirais": "comirar",
    "comiram": "comirar",
    "comiramo": "comirar",
    "comiramos": "comirar",
    "comirando": "comirar",
    "comirara": "comirar",
    "comiraram": "comirar",
    "comiraras": "comirar",
    "comirarde": "comirar",
    "comirardes": "comirar",
    "comirare": "comirar",
    "comirarei": "comirar",
    "comirareis": "comirar",
    "comirarem": "comirar",
    "comiraremos": "comirar",
    "comirares": "comirar",
    "comiraria": "comirar",
    "comirariam": "comirar",
    "comirarias": "comirar",
    "comirarmo": "comirar",
    "comirarmos": "comirar",
    "comirará": "comirar",
    "comirarás": "comirar",
    "comirarão": "comirar",
    "comiraríamos": "comirar",
    "comiraríeis": "comirar",
    "comiras": "comirar",
    "comirasse": "comirar",
    "comirassem": "comirar",
    "comirasses": "comirar",
    "comiraste": "comirar",
    "comirastes": "comirar",
    "comirava": "comirar",
    "comiravam": "comirar",
    "comiravas": "comirar",
    "comire": "comirar",
    "comirei": "comirar",
    "comireis": "comirar",
    "comirem": "comirar",
    "comiremo": "comirar",
    "comiremos": "comirar",
    "comires": "comirar",
    "comiro": "comirar",
    "comirou": "comirar",
    "comirá": "comirar",
    "comirámo": "comirar",
    "comirámos": "comirar",
    "comiráramo": "comirar",
    "comiráramos": "comirar",
    "comirárei": "comirar",
    "comiráreis": "comirar",
    "comirásseis": "comirar",
    "comirássemos": "comirar",
    "comirávamo": "comirar",
    "comirávamos": "comirar",
    "comirávei": "comirar",
    "comiráveis": "comirar",
    "comisca": "comiscar",
    "comiscada": "comiscar",
    "comiscadas": "comiscar",
    "comiscado": "comiscar",
    "comiscados": "comiscar",
    "comiscais": "comiscar",
    "comiscam": "comiscar",
    "comiscamo": "comiscar",
    "comiscamos": "comiscar",
    "comiscando": "comiscar",
    "comiscara": "comiscar",
    "comiscaram": "comiscar",
    "comiscaras": "comiscar",
    "comiscardes": "comiscar",
    "comiscarei": "comiscar",
    "comiscareis": "comiscar",
    "comiscarem": "comiscar",
    "comiscaremos": "comiscar",
    "comiscares": "comiscar",
    "comiscaria": "comiscar",
    "comiscariam": "comiscar",
    "comiscarias": "comiscar",
    "comiscarmo": "comiscar",
    "comiscarmos": "comiscar",
    "comiscará": "comiscar",
    "comiscarás": "comiscar",
    "comiscarão": "comiscar",
    "comiscaríamos": "comiscar",
    "comiscaríeis": "comiscar",
    "comiscas": "comiscar",
    "comiscasse": "comiscar",
    "comiscassem": "comiscar",
    "comiscasses": "comiscar",
    "comiscaste": "comiscar",
    "comiscastes": "comiscar",
    "comiscava": "comiscar",
    "comiscavam": "comiscar",
    "comiscavas": "comiscar",
    "comisco": "comiscar",
    "comiscou": "comiscar",
    "comiscámo": "comiscar",
    "comiscámos": "comiscar",
    "comiscáramo": "comiscar",
    "comiscáramos": "comiscar",
    "comiscáreis": "comiscar",
    "comiscásseis": "comiscar",
    "comiscássemos": "comiscar",
    "comiscávamo": "comiscar",
    "comiscávamos": "comiscar",
    "comiscáveis": "comiscar",
    "comisera": "comiserar",
    "comiserada": "comiserar",
    "comiseradas": "comiserar",
    "comiserado": "comiserar",
    "comiseradora": "comiserador",
    "comiseradoras": "comiserador",
    "comiseradores": "comiserador",
    "comiserados": "comiserar",
    "comiserai": "comiserar",
    "comiserais": "comiserar",
    "comiseram": "comiserar",
    "comiseramo": "comiserar",
    "comiseramos": "comiserar",
    "comiserando": "comiserar",
    "comiserara": "comiserar",
    "comiseraram": "comiserar",
    "comiseraras": "comiserar",
    "comiserarde": "comiserar",
    "comiserardes": "comiserar",
    "comiserare": "comiserar",
    "comiserarei": "comiserar",
    "comiserareis": "comiserar",
    "comiserarem": "comiserar",
    "comiseraremos": "comiserar",
    "comiserares": "comiserar",
    "comiseraria": "comiserar",
    "comiserariam": "comiserar",
    "comiserarias": "comiserar",
    "comiserarmo": "comiserar",
    "comiserarmos": "comiserar",
    "comiserará": "comiserar",
    "comiserarás": "comiserar",
    "comiserarão": "comiserar",
    "comiseraríamos": "comiserar",
    "comiseraríeis": "comiserar",
    "comiseras": "comiserar",
    "comiserasse": "comiserar",
    "comiserassem": "comiserar",
    "comiserasses": "comiserar",
    "comiseraste": "comiserar",
    "comiserastes": "comiserar",
    "comiserativa": "comiserativo",
    "comiserativas": "comiserativo",
    "comiserativos": "comiserativo",
    "comiserava": "comiserar",
    "comiseravam": "comiserar",
    "comiseravas": "comiserar",
    "comiserações": "comiseração",
    "comisere": "comiserar",
    "comiserei": "comiserar",
    "comisereis": "comiserar",
    "comiserem": "comiserar",
    "comiseremo": "comiserar",
    "comiseremos": "comiserar",
    "comiseres": "comiserar",
    "comisero": "comiserar",
    "comiserou": "comiserar",
    "comiserá": "comiserar",
    "comiserámo": "comiserar",
    "comiserámos": "comiserar",
    "comiseráramo": "comiserar",
    "comiseráramos": "comiserar",
    "comiserárei": "comiserar",
    "comiseráreis": "comiserar",
    "comiserásseis": "comiserar",
    "comiserássemos": "comiserar",
    "comiserávamo": "comiserar",
    "comiserávamos": "comiserar",
    "comiserávei": "comiserar",
    "comiseráveis": "comiserar",
    "comisque": "comiscar",
    "comisquei": "comiscar",
    "comisqueis": "comiscar",
    "comisquem": "comiscar",
    "comisquemos": "comiscar",
    "comisques": "comiscar",
    "comissaria": "comissariar",
    "comissariada": "comissariar",
    "comissariadas": "comissariar",
    "comissariado": "comissariar",
    "comissariados": "comissariar",
    "comissariai": "comissariar",
    "comissariais": "comissariar",
    "comissariam": "comissariar",
    "comissariamo": "comissariar",
    "comissariamos": "comissariar",
    "comissariando": "comissariar",
    "comissariara": "comissariar",
    "comissariaram": "comissariar",
    "comissariaras": "comissariar",
    "comissariarde": "comissariar",
    "comissariardes": "comissariar",
    "comissariare": "comissariar",
    "comissariarei": "comissariar",
    "comissariareis": "comissariar",
    "comissariarem": "comissariar",
    "comissariaremos": "comissariar",
    "comissariares": "comissariar",
    "comissariaria": "comissariar",
    "comissariariam": "comissariar",
    "comissariarias": "comissariaria",
    "comissariarmo": "comissariar",
    "comissariarmos": "comissariar",
    "comissariará": "comissariar",
    "comissariarás": "comissariar",
    "comissariarão": "comissariar",
    "comissariaríamos": "comissariar",
    "comissariaríeis": "comissariar",
    "comissarias": "comissariar",
    "comissariasse": "comissariar",
    "comissariassem": "comissariar",
    "comissariasses": "comissariar",
    "comissariaste": "comissariar",
    "comissariastes": "comissariar",
    "comissariava": "comissariar",
    "comissariavam": "comissariar",
    "comissariavas": "comissariar",
    "comissarie": "comissariar",
    "comissariei": "comissariar",
    "comissarieis": "comissariar",
    "comissariem": "comissariar",
    "comissariemo": "comissariar",
    "comissariemos": "comissariar",
    "comissaries": "comissariar",
    "comissario": "comissariar",
    "comissariou": "comissariar",
    "comissariá": "comissariar",
    "comissariámo": "comissariar",
    "comissariámos": "comissariar",
    "comissariáramo": "comissariar",
    "comissariáramos": "comissariar",
    "comissariárei": "comissariar",
    "comissariáreis": "comissariar",
    "comissariásseis": "comissariar",
    "comissariássemos": "comissariar",
    "comissariávamo": "comissariar",
    "comissariávamos": "comissariar",
    "comissariávei": "comissariar",
    "comissariáveis": "comissariar",
    "comissiona": "comissionar",
    "comissionada": "comissionar",
    "comissionadas": "comissionar",
    "comissionado": "comissionar",
    "comissionados": "comissionar",
    "comissionai": "comissionar",
    "comissionais": "comissionar",
    "comissionam": "comissionar",
    "comissionamo": "comissionar",
    "comissionamos": "comissionar",
    "comissionando": "comissionar",
    "comissionara": "comissionar",
    "comissionaram": "comissionar",
    "comissionaras": "comissionar",
    "comissionarde": "comissionar",
    "comissionardes": "comissionar",
    "comissionare": "comissionar",
    "comissionarei": "comissionar",
    "comissionareis": "comissionar",
    "comissionarem": "comissionar",
    "comissionaremos": "comissionar",
    "comissionares": "comissionar",
    "comissionaria": "comissionar",
    "comissionariam": "comissionar",
    "comissionarias": "comissionar",
    "comissionarmo": "comissionar",
    "comissionarmos": "comissionar",
    "comissionará": "comissionar",
    "comissionarás": "comissionar",
    "comissionarão": "comissionar",
    "comissionaríamos": "comissionar",
    "comissionaríeis": "comissionar",
    "comissionas": "comissionar",
    "comissionasse": "comissionar",
    "comissionassem": "comissionar",
    "comissionasses": "comissionar",
    "comissionaste": "comissionar",
    "comissionastes": "comissionar",
    "comissionava": "comissionar",
    "comissionavam": "comissionar",
    "comissionavas": "comissionar",
    "comissione": "comissionar",
    "comissionei": "comissionar",
    "comissioneis": "comissionar",
    "comissionem": "comissionar",
    "comissionemo": "comissionar",
    "comissionemos": "comissionar",
    "comissiones": "comissionar",
    "comissionistas": "comissionista",
    "comissiono": "comissionar",
    "comissionou": "comissionar",
    "comissioná": "comissionar",
    "comissionámo": "comissionar",
    "comissionámos": "comissionar",
    "comissionáramo": "comissionar",
    "comissionáramos": "comissionar",
    "comissionárei": "comissionar",
    "comissionáreis": "comissionar",
    "comissionásseis": "comissionar",
    "comissionássemos": "comissionar",
    "comissionávamo": "comissionar",
    "comissionávamos": "comissionar",
    "comissionávei": "comissionar",
    "comissionáveis": "comissionar",
    "comissos": "comisso",
    "comissurais": "comissural",
    "comissurantes": "comissurante",
    "comissuras": "comissura",
    "comissária": "comissário",
    "comissárias": "comissário",
    "comissários": "comissário",
    "comissória": "comissório",
    "comissórias": "comissório",
    "comissórios": "comissório",
    "comissões": "comissão",
    "comitativa": "comitativo",
    "comitativas": "comitativo",
    "comitativos": "comitativo",
    "comitentes": "comitente",
    "comitivas": "comitiva",
    "comitres": "comitre",
    "comités": "comité",
    "comitês": "comitê",
    "como": "comer",
    "comociona": "comocionar",
    "comocionada": "comocionar",
    "comocionadas": "comocionar",
    "comocionado": "comocionar",
    "comocionados": "comocionar",
    "comocionai": "comocionar",
    "comocionais": "comocionar",
    "comocionam": "comocionar",
    "comocionamo": "comocionar",
    "comocionamos": "comocionar",
    "comocionando": "comocionar",
    "comocionara": "comocionar",
    "comocionaram": "comocionar",
    "comocionaras": "comocionar",
    "comocionarde": "comocionar",
    "comocionardes": "comocionar",
    "comocionare": "comocionar",
    "comocionarei": "comocionar",
    "comocionareis": "comocionar",
    "comocionarem": "comocionar",
    "comocionaremos": "comocionar",
    "comocionares": "comocionar",
    "comocionaria": "comocionar",
    "comocionariam": "comocionar",
    "comocionarias": "comocionar",
    "comocionarmo": "comocionar",
    "comocionarmos": "comocionar",
    "comocionará": "comocionar",
    "comocionarás": "comocionar",
    "comocionarão": "comocionar",
    "comocionaríamos": "comocionar",
    "comocionaríeis": "comocionar",
    "comocionas": "comocionar",
    "comocionasse": "comocionar",
    "comocionassem": "comocionar",
    "comocionasses": "comocionar",
    "comocionaste": "comocionar",
    "comocionastes": "comocionar",
    "comocionava": "comocionar",
    "comocionavam": "comocionar",
    "comocionavas": "comocionar",
    "comocione": "comocionar",
    "comocionei": "comocionar",
    "comocioneis": "comocionar",
    "comocionem": "comocionar",
    "comocionemo": "comocionar",
    "comocionemos": "comocionar",
    "comociones": "comocionar",
    "comociono": "comocionar",
    "comocionou": "comocionar",
    "comocioná": "comocionar",
    "comocionámo": "comocionar",
    "comocionámos": "comocionar",
    "comocionáramo": "comocionar",
    "comocionáramos": "comocionar",
    "comocionárei": "comocionar",
    "comocionáreis": "comocionar",
    "comocionásseis": "comocionar",
    "comocionássemos": "comocionar",
    "comocionávamo": "comocionar",
    "comocionávamos": "comocionar",
    "comocionávei": "comocionar",
    "comocionáveis": "comocionar",
    "comodantes": "comodante",
    "comodatos": "comodato",
    "comodatária": "comodatário",
    "comodatárias": "comodatário",
    "comodatários": "comodatário",
    "comodidades": "comodidade",
    "comodismos": "comodismo",
    "comodistas": "comodista",
    "comodoros": "comodoro",
    "comora": "comorar",
    "comorada": "comorar",
    "comoradas": "comorar",
    "comorado": "comorar",
    "comorados": "comorar",
    "comorai": "comorar",
    "comorais": "comorar",
    "comoram": "comorar",
    "comoramo": "comorar",
    "comoramos": "comorar",
    "comorando": "comorar",
    "comorantes": "comorante",
    "comorara": "comorar",
    "comoraram": "comorar",
    "comoraras": "comorar",
    "comorardes": "comorar",
    "comorarei": "comorar",
    "comorareis": "comorar",
    "comorarem": "comorar",
    "comoraremos": "comorar",
    "comorares": "comorar",
    "comoraria": "comorar",
    "comorariam": "comorar",
    "comorarias": "comorar",
    "comorarmo": "comorar",
    "comorarmos": "comorar",
    "comorará": "comorar",
    "comorarás": "comorar",
    "comorarão": "comorar",
    "comoraríamos": "comorar",
    "comoraríeis": "comorar",
    "comoras": "comorar",
    "comorasse": "comorar",
    "comorassem": "comorar",
    "comorasses": "comorar",
    "comoraste": "comorar",
    "comorastes": "comorar",
    "comorava": "comorar",
    "comoravam": "comorar",
    "comoravas": "comorar",
    "comorações": "comoração",
    "comore": "comorar",
    "comorei": "comorar",
    "comoreis": "comorar",
    "comorem": "comorar",
    "comoremo": "comorar",
    "comoremos": "comorar",
    "comores": "comorar",
    "comorientes": "comoriente",
    "comoro": "comorar",
    "comorou": "comorar",
    "comorámo": "comorar",
    "comorámos": "comorar",
    "comoráramo": "comorar",
    "comoráramos": "comorar",
    "comoráreis": "comorar",
    "comorásseis": "comorar",
    "comorássemos": "comorar",
    "comorávamo": "comorar",
    "comorávamos": "comorar",
    "comoráveis": "comorar",
    "comosa": "comoso",
    "comosas": "comoso",
    "comosos": "comoso",
    "comotividades": "comotividade",
    "comova": "comover",
    "comovais": "comover",
    "comovam": "comover",
    "comovamo": "comover",
    "comovamos": "comover",
    "comovas": "comover",
    "comove": "comover",
    "comovedora": "comovedor",
    "comovedoras": "comovedor",
    "comovedores": "comovedor",
    "comovei": "comover",
    "comoveis": "comover",
    "comovem": "comover",
    "comovemo": "comover",
    "comovemos": "comover",
    "comovendo": "comover",
    "comoventes": "comovente",
    "comovera": "comover",
    "comoveram": "comover",
    "comoveras": "comover",
    "comoverde": "comover",
    "comoverdes": "comover",
    "comovere": "comover",
    "comoverei": "comover",
    "comovereis": "comover",
    "comoverem": "comover",
    "comoveremos": "comover",
    "comoveres": "comover",
    "comoveria": "comover",
    "comoveriam": "comover",
    "comoverias": "comover",
    "comovermo": "comover",
    "comovermos": "comover",
    "comoverá": "comover",
    "comoverás": "comover",
    "comoverão": "comover",
    "comoveríamos": "comover",
    "comoveríeis": "comover",
    "comoves": "comover",
    "comovesse": "comover",
    "comovessem": "comover",
    "comovesses": "comover",
    "comoveste": "comover",
    "comovestes": "comover",
    "comoveu": "comover",
    "comovi": "comover",
    "comovia": "comover",
    "comoviam": "comover",
    "comovias": "comover",
    "comovida": "comovido",
    "comovidas": "comovido",
    "comovido": "comover",
    "comovidos": "comovido",
    "comovidíssima": "comovido",
    "comovidíssimas": "comovido",
    "comovidíssimo": "comovido",
    "comovidíssimos": "comovido",
    "comovo": "comover",
    "comovê": "comover",
    "comovêramo": "comover",
    "comovêramos": "comover",
    "comovêrei": "comover",
    "comovêreis": "comover",
    "comovêsseis": "comover",
    "comovêssemos": "comover",
    "comovíamo": "comover",
    "comovíamos": "comover",
    "comovíei": "comover",
    "comovíeis": "comover",
    "comoções": "comoção",
    "compacta": "compacto",
    "compactada": "compactado",
    "compactadas": "compactado",
    "compactados": "compactado",
    "compactas": "compacto",
    "compactações": "compactação",
    "compactidades": "compactidade",
    "compactos": "compacto",
    "compactua": "compactuar",
    "compactuada": "compactuar",
    "compactuadas": "compactuar",
    "compactuado": "compactuar",
    "compactuados": "compactuar",
    "compactuai": "compactuar",
    "compactuais": "compactuar",
    "compactuam": "compactuar",
    "compactuamo": "compactuar",
    "compactuamos": "compactuar",
    "compactuando": "compactuar",
    "compactuara": "compactuar",
    "compactuaram": "compactuar",
    "compactuaras": "compactuar",
    "compactuarde": "compactuar",
    "compactuardes": "compactuar",
    "compactuare": "compactuar",
    "compactuarei": "compactuar",
    "compactuareis": "compactuar",
    "compactuarem": "compactuar",
    "compactuaremos": "compactuar",
    "compactuares": "compactuar",
    "compactuaria": "compactuar",
    "compactuariam": "compactuar",
    "compactuarias": "compactuar",
    "compactuarmo": "compactuar",
    "compactuarmos": "compactuar",
    "compactuará": "compactuar",
    "compactuarás": "compactuar",
    "compactuarão": "compactuar",
    "compactuaríamos": "compactuar",
    "compactuaríeis": "compactuar",
    "compactuas": "compactuar",
    "compactuasse": "compactuar",
    "compactuassem": "compactuar",
    "compactuasses": "compactuar",
    "compactuaste": "compactuar",
    "compactuastes": "compactuar",
    "compactuava": "compactuar",
    "compactuavam": "compactuar",
    "compactuavas": "compactuar",
    "compactue": "compactuar",
    "compactuei": "compactuar",
    "compactueis": "compactuar",
    "compactuem": "compactuar",
    "compactuemo": "compactuar",
    "compactuemos": "compactuar",
    "compactues": "compactuar",
    "compactuo": "compactuar",
    "compactuou": "compactuar",
    "compactuá": "compactuar",
    "compactuámo": "compactuar",
    "compactuámos": "compactuar",
    "compactuáramo": "compactuar",
    "compactuáramos": "compactuar",
    "compactuárei": "compactuar",
    "compactuáreis": "compactuar",
    "compactuásseis": "compactuar",
    "compactuássemos": "compactuar",
    "compactuávamo": "compactuar",
    "compactuávamos": "compactuar",
    "compactuávei": "compactuar",
    "compactuáveis": "compactuar",
    "compadece": "compadecer",
    "compadecedora": "compadecedor",
    "compadecedoras": "compadecedor",
    "compadecedores": "compadecedor",
    "compadecei": "compadecer",
    "compadeceis": "compadecer",
    "compadecem": "compadecer",
    "compadecemo": "compadecer",
    "compadecemos": "compadecer",
    "compadecendo": "compadecer",
    "compadecera": "compadecer",
    "compadeceram": "compadecer",
    "compadeceras": "compadecer",
    "compadecerde": "compadecer",
    "compadecerdes": "compadecer",
    "compadecere": "compadecer",
    "compadecerei": "compadecer",
    "compadecereis": "compadecer",
    "compadecerem": "compadecer",
    "compadeceremos": "compadecer",
    "compadeceres": "compadecer",
    "compadeceria": "compadecer",
    "compadeceriam": "compadecer",
    "compadecerias": "compadecer",
    "compadecermo": "compadecer",
    "compadecermos": "compadecer",
    "compadecerá": "compadecer",
    "compadecerás": "compadecer",
    "compadecerão": "compadecer",
    "compadeceríamos": "compadecer",
    "compadeceríeis": "compadecer",
    "compadeces": "compadecer",
    "compadecesse": "compadecer",
    "compadecessem": "compadecer",
    "compadecesses": "compadecer",
    "compadeceste": "compadecer",
    "compadecestes": "compadecer",
    "compadeceu": "compadecer",
    "compadeci": "compadecer",
    "compadecia": "compadecer",
    "compadeciam": "compadecer",
    "compadecias": "compadecer",
    "compadecida": "compadecido",
    "compadecidas": "compadecido",
    "compadecido": "compadecer",
    "compadecidos": "compadecido",
    "compadecimentos": "compadecimento",
    "compadecê": "compadecer",
    "compadecêramo": "compadecer",
    "compadecêramos": "compadecer",
    "compadecêrei": "compadecer",
    "compadecêreis": "compadecer",
    "compadecêsseis": "compadecer",
    "compadecêssemos": "compadecer",
    "compadecíamo": "compadecer",
    "compadecíamos": "compadecer",
    "compadecíei": "compadecer",
    "compadecíeis": "compadecer",
    "compadeça": "compadecer",
    "compadeçais": "compadecer",
    "compadeçam": "compadecer",
    "compadeçamo": "compadecer",
    "compadeçamos": "compadecer",
    "compadeças": "compadecer",
    "compadeço": "compadecer",
    "compadra": "compadrar",
    "compadrada": "compadrar",
    "compadradas": "compadrar",
    "compadrado": "compadrar",
    "compadrados": "compadrar",
    "compadrai": "compadrar",
    "compadrais": "compadrar",
    "compadram": "compadrar",
    "compadramo": "compadrar",
    "compadramos": "compadrar",
    "compadrando": "compadrar",
    "compadrara": "compadrar",
    "compadraram": "compadrar",
    "compadraras": "compadrar",
    "compadrarde": "compadrar",
    "compadrardes": "compadrar",
    "compadrare": "compadrar",
    "compadrarei": "compadrar",
    "compadrareis": "compadrar",
    "compadrarem": "compadrar",
    "compadraremos": "compadrar",
    "compadrares": "compadrar",
    "compadraria": "compadrar",
    "compadrariam": "compadrar",
    "compadrarias": "compadrar",
    "compadrarmo": "compadrar",
    "compadrarmos": "compadrar",
    "compadrará": "compadrar",
    "compadrarás": "compadrar",
    "compadrarão": "compadrar",
    "compadraríamos": "compadrar",
    "compadraríeis": "compadrar",
    "compadras": "compadrar",
    "compadrasse": "compadrar",
    "compadrassem": "compadrar",
    "compadrasses": "compadrar",
    "compadraste": "compadrar",
    "compadrastes": "compadrar",
    "compadrava": "compadrar",
    "compadravam": "compadrar",
    "compadravas": "compadrar",
    "compadre": "compadrar",
    "compadreada": "compadrear",
    "compadreadas": "compadrear",
    "compadreado": "compadrear",
    "compadreados": "compadrear",
    "compadreai": "compadrear",
    "compadreais": "compadrear",
    "compadreamo": "compadrear",
    "compadreamos": "compadrear",
    "compadreando": "compadrear",
    "compadreara": "compadrear",
    "compadrearam": "compadrear",
    "compadrearas": "compadrear",
    "compadrearde": "compadrear",
    "compadreardes": "compadrear",
    "compadreare": "compadrear",
    "compadrearei": "compadrear",
    "compadreareis": "compadrear",
    "compadrearem": "compadrear",
    "compadrearemos": "compadrear",
    "compadreares": "compadrear",
    "compadrearia": "compadrear",
    "compadreariam": "compadrear",
    "compadrearias": "compadrear",
    "compadrearmo": "compadrear",
    "compadrearmos": "compadrear",
    "compadreará": "compadrear",
    "compadrearás": "compadrear",
    "compadrearão": "compadrear",
    "compadrearíamos": "compadrear",
    "compadrearíeis": "compadrear",
    "compadreasse": "compadrear",
    "compadreassem": "compadrear",
    "compadreasses": "compadrear",
    "compadreaste": "compadrear",
    "compadreastes": "compadrear",
    "compadreava": "compadrear",
    "compadreavam": "compadrear",
    "compadreavas": "compadrear",
    "compadreei": "compadrear",
    "compadreeis": "compadrear",
    "compadreemo": "compadrear",
    "compadreemos": "compadrear",
    "compadrei": "compadrar",
    "compadreia": "compadrear",
    "compadreiam": "compadrear",
    "compadreias": "compadrear",
    "compadreie": "compadrear",
    "compadreiem": "compadrear",
    "compadreies": "compadrear",
    "compadreio": "compadrear",
    "compadreis": "compadrar",
    "compadrem": "compadrar",
    "compadremo": "compadrar",
    "compadremos": "compadrar",
    "compadreou": "compadrear",
    "compadres": "compadre",
    "compadresca": "compadresco",
    "compadrescas": "compadresco",
    "compadrescos": "compadresco",
    "compadreá": "compadrear",
    "compadreámo": "compadrear",
    "compadreámos": "compadrear",
    "compadreáramo": "compadrear",
    "compadreáramos": "compadrear",
    "compadreárei": "compadrear",
    "compadreáreis": "compadrear",
    "compadreásseis": "compadrear",
    "compadreássemos": "compadrear",
    "compadreávamo": "compadrear",
    "compadreávamos": "compadrear",
    "compadreávei": "compadrear",
    "compadreáveis": "compadrear",
    "compadrices": "compadrice",
    "compadrios": "compadrio",
    "compadro": "compadrar",
    "compadrou": "compadrar",
    "compadrá": "compadrar",
    "compadrámo": "compadrar",
    "compadrámos": "compadrar",
    "compadráramo": "compadrar",
    "compadráramos": "compadrar",
    "compadrárei": "compadrar",
    "compadráreis": "compadrar",
    "compadrásseis": "compadrar",
    "compadrássemos": "compadrar",
    "compadrávamo": "compadrar",
    "compadrávamos": "compadrar",
    "compadrávei": "compadrar",
    "compadráveis": "compadrar",
    "compagina": "compaginar",
    "compaginada": "compaginar",
    "compaginadas": "compaginar",
    "compaginado": "compaginar",
    "compaginadora": "compaginador",
    "compaginadoras": "compaginador",
    "compaginadores": "compaginador",
    "compaginados": "compaginar",
    "compaginai": "compaginar",
    "compaginais": "compaginar",
    "compaginam": "compaginar",
    "compaginamo": "compaginar",
    "compaginamos": "compaginar",
    "compaginando": "compaginar",
    "compaginara": "compaginar",
    "compaginaram": "compaginar",
    "compaginaras": "compaginar",
    "compaginarde": "compaginar",
    "compaginardes": "compaginar",
    "compaginare": "compaginar",
    "compaginarei": "compaginar",
    "compaginareis": "compaginar",
    "compaginarem": "compaginar",
    "compaginaremos": "compaginar",
    "compaginares": "compaginar",
    "compaginaria": "compaginar",
    "compaginariam": "compaginar",
    "compaginarias": "compaginar",
    "compaginarmo": "compaginar",
    "compaginarmos": "compaginar",
    "compaginará": "compaginar",
    "compaginarás": "compaginar",
    "compaginarão": "compaginar",
    "compaginaríamos": "compaginar",
    "compaginaríeis": "compaginar",
    "compaginas": "compaginar",
    "compaginasse": "compaginar",
    "compaginassem": "compaginar",
    "compaginasses": "compaginar",
    "compaginaste": "compaginar",
    "compaginastes": "compaginar",
    "compaginava": "compaginar",
    "compaginavam": "compaginar",
    "compaginavas": "compaginar",
    "compaginações": "compaginação",
    "compagine": "compaginar",
    "compaginei": "compaginar",
    "compagineis": "compaginar",
    "compaginem": "compaginar",
    "compaginemo": "compaginar",
    "compaginemos": "compaginar",
    "compagines": "compaginar",
    "compagino": "compaginar",
    "compaginou": "compaginar",
    "compaginá": "compaginar",
    "compaginámo": "compaginar",
    "compaginámos": "compaginar",
    "compagináramo": "compaginar",
    "compagináramos": "compaginar",
    "compaginárei": "compaginar",
    "compagináreis": "compaginar",
    "compaginásseis": "compaginar",
    "compaginássemos": "compaginar",
    "compaginávamo": "compaginar",
    "compaginávamos": "compaginar",
    "compaginávei": "compaginar",
    "compagináveis": "compaginável",
    "compaixões": "compaixão",
    "companhas": "companha",
    "companheira": "companheiro",
    "companheiras": "companheiro",
    "companheirismos": "companheirismo",
    "companheirona": "companheirão",
    "companheironas": "companheirão",
    "companheiros": "companheiro",
    "companheirões": "companheirão",
    "companhias": "companhia",
    "compara": "comparar",
    "comparabilidades": "comparabilidade",
    "comparada": "comparar",
    "comparadas": "comparar",
    "comparado": "comparar",
    "comparadora": "comparador",
    "comparadoras": "comparador",
    "comparadores": "comparador",
    "comparados": "comparar",
    "comparai": "comparar",
    "comparais": "comparar",
    "comparam": "comparar",
    "comparamo": "comparar",
    "comparamos": "comparar",
    "comparando": "comparar",
    "comparanças": "comparança",
    "comparara": "comparar",
    "compararam": "comparar",
    "compararas": "comparar",
    "compararde": "comparar",
    "comparardes": "comparar",
    "comparare": "comparar",
    "compararei": "comparar",
    "comparareis": "comparar",
    "compararem": "comparar",
    "compararemos": "comparar",
    "comparares": "comparar",
    "compararia": "comparar",
    "comparariam": "comparar",
    "compararias": "comparar",
    "compararmo": "comparar",
    "compararmos": "comparar",
    "comparará": "comparar",
    "compararás": "comparar",
    "compararão": "comparar",
    "compararíamos": "comparar",
    "compararíeis": "comparar",
    "comparas": "comparar",
    "comparasse": "comparar",
    "comparassem": "comparar",
    "comparasses": "comparar",
    "comparaste": "comparar",
    "comparastes": "comparar",
    "comparatistas": "comparatista",
    "comparativa": "comparativo",
    "comparativas": "comparativo",
    "comparativos": "comparativo",
    "comparava": "comparar",
    "comparavam": "comparar",
    "comparavas": "comparar",
    "comparações": "comparação",
    "compare": "comparar",
    "comparece": "comparecer",
    "comparecei": "comparecer",
    "compareceis": "comparecer",
    "comparecem": "comparecer",
    "comparecemo": "comparecer",
    "comparecemos": "comparecer",
    "comparecendo": "comparecer",
    "comparecentes": "comparecente",
    "comparecera": "comparecer",
    "compareceram": "comparecer",
    "compareceras": "comparecer",
    "comparecerdes": "comparecer",
    "comparecerei": "comparecer",
    "comparecereis": "comparecer",
    "comparecerem": "comparecer",
    "compareceremos": "comparecer",
    "compareceres": "comparecer",
    "compareceria": "comparecer",
    "compareceriam": "comparecer",
    "comparecerias": "comparecer",
    "comparecermo": "comparecer",
    "comparecermos": "comparecer",
    "comparecerá": "comparecer",
    "comparecerás": "comparecer",
    "comparecerão": "comparecer",
    "compareceríamos": "comparecer",
    "compareceríeis": "comparecer",
    "compareces": "comparecer",
    "comparecesse": "comparecer",
    "comparecessem": "comparecer",
    "comparecesses": "comparecer",
    "compareceste": "comparecer",
    "comparecestes": "comparecer",
    "compareceu": "comparecer",
    "compareci": "comparecer",
    "comparecia": "comparecer",
    "compareciam": "comparecer",
    "comparecias": "comparecer",
    "comparecida": "comparecer",
    "comparecidas": "comparecer",
    "comparecido": "comparecer",
    "comparecidos": "comparecer",
    "comparecimentos": "comparecimento",
    "comparecências": "comparecência",
    "comparecêramo": "comparecer",
    "comparecêramos": "comparecer",
    "comparecêreis": "comparecer",
    "comparecêsseis": "comparecer",
    "comparecêssemos": "comparecer",
    "comparecíamo": "comparecer",
    "comparecíamos": "comparecer",
    "comparecíeis": "comparecer",
    "comparei": "comparar",
    "compareis": "comparar",
    "comparem": "comparar",
    "comparemo": "comparar",
    "comparemos": "comparar",
    "comparentes": "comparente",
    "compares": "comparar",
    "compareça": "comparecer",
    "compareçais": "comparecer",
    "compareçam": "comparecer",
    "compareçamo": "comparecer",
    "compareçamos": "comparecer",
    "compareças": "comparecer",
    "compareço": "comparecer",
    "comparo": "comparar",
    "comparoquiana": "comparoquiano",
    "comparoquianas": "comparoquiano",
    "comparoquianos": "comparoquiano",
    "comparou": "comparar",
    "comparsarias": "comparsaria",
    "comparsas": "comparsa",
    "comparta": "compartir",
    "compartais": "compartir",
    "compartam": "compartir",
    "compartamo": "compartir",
    "compartamos": "compartir",
    "compartas": "compartir",
    "comparte": "compartir",
    "compartem": "compartir",
    "compartes": "compartir",
    "comparti": "compartir",
    "compartia": "compartir",
    "compartiam": "compartir",
    "compartias": "compartir",
    "comparticipa": "comparticipar",
    "comparticipada": "comparticipar",
    "comparticipadas": "comparticipar",
    "comparticipado": "comparticipar",
    "comparticipados": "comparticipar",
    "comparticipai": "comparticipar",
    "comparticipais": "comparticipar",
    "comparticipam": "comparticipar",
    "comparticipamo": "comparticipar",
    "comparticipamos": "comparticipar",
    "comparticipando": "comparticipar",
    "comparticipantes": "comparticipante",
    "comparticipara": "comparticipar",
    "comparticiparam": "comparticipar",
    "comparticiparas": "comparticipar",
    "comparticiparde": "comparticipar",
    "comparticipardes": "comparticipar",
    "comparticipare": "comparticipar",
    "comparticiparei": "comparticipar",
    "comparticipareis": "comparticipar",
    "comparticiparem": "comparticipar",
    "comparticiparemos": "comparticipar",
    "comparticipares": "comparticipar",
    "comparticiparia": "comparticipar",
    "comparticipariam": "comparticipar",
    "comparticiparias": "comparticipar",
    "comparticiparmo": "comparticipar",
    "comparticiparmos": "comparticipar",
    "comparticipará": "comparticipar",
    "comparticiparás": "comparticipar",
    "comparticiparão": "comparticipar",
    "comparticiparíamos": "comparticipar",
    "comparticiparíeis": "comparticipar",
    "comparticipas": "comparticipar",
    "comparticipasse": "comparticipar",
    "comparticipassem": "comparticipar",
    "comparticipasses": "comparticipar",
    "comparticipaste": "comparticipar",
    "comparticipastes": "comparticipar",
    "comparticipava": "comparticipar",
    "comparticipavam": "comparticipar",
    "comparticipavas": "comparticipar",
    "comparticipações": "comparticipação",
    "comparticipe": "comparticipar",
    "comparticipei": "comparticipar",
    "comparticipeis": "comparticipar",
    "comparticipem": "comparticipar",
    "comparticipemo": "comparticipar",
    "comparticipemos": "comparticipar",
    "comparticipes": "comparticipar",
    "comparticipo": "comparticipar",
    "comparticipou": "comparticipar",
    "comparticipá": "comparticipar",
    "comparticipámo": "comparticipar",
    "comparticipámos": "comparticipar",
    "comparticipáramo": "comparticipar",
    "comparticipáramos": "comparticipar",
    "comparticipárei": "comparticipar",
    "comparticipáreis": "comparticipar",
    "comparticipásseis": "comparticipar",
    "comparticipássemos": "comparticipar",
    "comparticipávamo": "comparticipar",
    "comparticipávamos": "comparticipar",
    "comparticipávei": "comparticipar",
    "comparticipáveis": "comparticipar",
    "compartida": "compartir",
    "compartidas": "compartir",
    "compartido": "compartir",
    "compartidos": "compartir",
    "compartilha": "compartilhar",
    "compartilhada": "compartilhar",
    "compartilhadas": "compartilhar",
    "compartilhado": "compartilhar",
    "compartilhadora": "compartilhador",
    "compartilhadoras": "compartilhador",
    "compartilhadores": "compartilhador",
    "compartilhados": "compartilhar",
    "compartilhai": "compartilhar",
    "compartilhais": "compartilhar",
    "compartilham": "compartilhar",
    "compartilhamo": "compartilhar",
    "compartilhamos": "compartilhar",
    "compartilhando": "compartilhar",
    "compartilhantes": "compartilhante",
    "compartilhara": "compartilhar",
    "compartilharam": "compartilhar",
    "compartilharas": "compartilhar",
    "compartilharde": "compartilhar",
    "compartilhardes": "compartilhar",
    "compartilhare": "compartilhar",
    "compartilharei": "compartilhar",
    "compartilhareis": "compartilhar",
    "compartilharem": "compartilhar",
    "compartilharemos": "compartilhar",
    "compartilhares": "compartilhar",
    "compartilharia": "compartilhar",
    "compartilhariam": "compartilhar",
    "compartilharias": "compartilhar",
    "compartilharmo": "compartilhar",
    "compartilharmos": "compartilhar",
    "compartilhará": "compartilhar",
    "compartilharás": "compartilhar",
    "compartilharão": "compartilhar",
    "compartilharíamos": "compartilhar",
    "compartilharíeis": "compartilhar",
    "compartilhas": "compartilhar",
    "compartilhasse": "compartilhar",
    "compartilhassem": "compartilhar",
    "compartilhasses": "compartilhar",
    "compartilhaste": "compartilhar",
    "compartilhastes": "compartilhar",
    "compartilhava": "compartilhar",
    "compartilhavam": "compartilhar",
    "compartilhavas": "compartilhar",
    "compartilhe": "compartilhar",
    "compartilhei": "compartilhar",
    "compartilheis": "compartilhar",
    "compartilhem": "compartilhar",
    "compartilhemo": "compartilhar",
    "compartilhemos": "compartilhar",
    "compartilhes": "compartilhar",
    "compartilho": "compartilhar",
    "compartilhou": "compartilhar",
    "compartilhá": "compartilhar",
    "compartilhámo": "compartilhar",
    "compartilhámos": "compartilhar",
    "compartilháramo": "compartilhar",
    "compartilháramos": "compartilhar",
    "compartilhárei": "compartilhar",
    "compartilháreis": "compartilhar",
    "compartilhásseis": "compartilhar",
    "compartilhássemos": "compartilhar",
    "compartilhávamo": "compartilhar",
    "compartilhávamos": "compartilhar",
    "compartilhávei": "compartilhar",
    "compartilháveis": "compartilhar",
    "compartimenta": "compartimentar",
    "compartimentada": "compartimentar",
    "compartimentadas": "compartimentar",
    "compartimentado": "compartimentar",
    "compartimentados": "compartimentar",
    "compartimentai": "compartimentar",
    "compartimentais": "compartimentar",
    "compartimentalizações": "compartimentalização",
    "compartimentam": "compartimentar",
    "compartimentamo": "compartimentar",
    "compartimentamos": "compartimentar",
    "compartimentando": "compartimentar",
    "compartimentara": "compartimentar",
    "compartimentaram": "compartimentar",
    "compartimentaras": "compartimentar",
    "compartimentarde": "compartimentar",
    "compartimentardes": "compartimentar",
    "compartimentare": "compartimentar",
    "compartimentarei": "compartimentar",
    "compartimentareis": "compartimentar",
    "compartimentarem": "compartimentar",
    "compartimentaremos": "compartimentar",
    "compartimentares": "compartimentar",
    "compartimentaria": "compartimentar",
    "compartimentariam": "compartimentar",
    "compartimentarias": "compartimentar",
    "compartimentarmo": "compartimentar",
    "compartimentarmos": "compartimentar",
    "compartimentará": "compartimentar",
    "compartimentarás": "compartimentar",
    "compartimentarão": "compartimentar",
    "compartimentaríamos": "compartimentar",
    "compartimentaríeis": "compartimentar",
    "compartimentas": "compartimentar",
    "compartimentasse": "compartimentar",
    "compartimentassem": "compartimentar",
    "compartimentasses": "compartimentar",
    "compartimentaste": "compartimentar",
    "compartimentastes": "compartimentar",
    "compartimentava": "compartimentar",
    "compartimentavam": "compartimentar",
    "compartimentavas": "compartimentar",
    "compartimentações": "compartimentação",
    "compartimente": "compartimentar",
    "compartimentei": "compartimentar",
    "compartimenteis": "compartimentar",
    "compartimentem": "compartimentar",
    "compartimentemo": "compartimentar",
    "compartimentemos": "compartimentar",
    "compartimentes": "compartimentar",
    "compartimento": "compartimentar",
    "compartimentos": "compartimento",
    "compartimentou": "compartimentar",
    "compartimentá": "compartimentar",
    "compartimentámo": "compartimentar",
    "compartimentámos": "compartimentar",
    "compartimentáramo": "compartimentar",
    "compartimentáramos": "compartimentar",
    "compartimentárei": "compartimentar",
    "compartimentáreis": "compartimentar",
    "compartimentásseis": "compartimentar",
    "compartimentássemos": "compartimentar",
    "compartimentávamo": "compartimentar",
    "compartimentávamos": "compartimentar",
    "compartimentávei": "compartimentar",
    "compartimentáveis": "compartimentar",
    "compartimo": "compartir",
    "compartimos": "compartir",
    "compartindo": "compartir",
    "compartira": "compartir",
    "compartiram": "compartir",
    "compartiras": "compartir",
    "compartirde": "compartir",
    "compartirdes": "compartir",
    "compartire": "compartir",
    "compartirei": "compartir",
    "compartireis": "compartir",
    "compartirem": "compartir",
    "compartiremos": "compartir",
    "compartires": "compartir",
    "compartiria": "compartir",
    "compartiriam": "compartir",
    "compartirias": "compartir",
    "compartirmo": "compartir",
    "compartirmos": "compartir",
    "compartirá": "compartir",
    "compartirás": "compartir",
    "compartirão": "compartir",
    "compartiríamos": "compartir",
    "compartiríeis": "compartir",
    "compartis": "compartir",
    "compartisse": "compartir",
    "compartissem": "compartir",
    "compartisses": "compartir",
    "compartiste": "compartir",
    "compartistes": "compartir",
    "compartiu": "compartir",
    "compartições": "compartição",
    "comparto": "compartir",
    "compartíamo": "compartir",
    "compartíamos": "compartir",
    "compartícipes": "compartícipe",
    "compartíei": "compartir",
    "compartíeis": "compartir",
    "compartíramo": "compartir",
    "compartíramos": "compartir",
    "compartírei": "compartir",
    "compartíreis": "compartir",
    "compartísseis": "compartir",
    "compartíssemos": "compartir",
    "compará": "comparar",
    "comparámo": "comparar",
    "comparámos": "comparar",
    "comparáramo": "comparar",
    "comparáramos": "comparar",
    "comparárei": "comparar",
    "comparáreis": "comparar",
    "comparásseis": "comparar",
    "comparássemos": "comparar",
    "comparávamo": "comparar",
    "comparávamos": "comparar",
    "comparávei": "comparar",
    "comparáveis": "comparável",
    "comparências": "comparência",
    "compassa": "compassar",
    "compassada": "compassar",
    "compassadas": "compassar",
    "compassado": "compassar",
    "compassados": "compassar",
    "compassai": "compassar",
    "compassais": "compassar",
    "compassam": "compassar",
    "compassamo": "compassar",
    "compassamos": "compassar",
    "compassando": "compassar",
    "compassara": "compassar",
    "compassaram": "compassar",
    "compassaras": "compassar",
    "compassarde": "compassar",
    "compassardes": "compassar",
    "compassare": "compassar",
    "compassarei": "compassar",
    "compassareis": "compassar",
    "compassarem": "compassar",
    "compassaremos": "compassar",
    "compassares": "compassar",
    "compassaria": "compassar",
    "compassariam": "compassar",
    "compassarias": "compassar",
    "compassarmo": "compassar",
    "compassarmos": "compassar",
    "compassará": "compassar",
    "compassarás": "compassar",
    "compassarão": "compassar",
    "compassaríamos": "compassar",
    "compassaríeis": "compassar",
    "compassas": "compassar",
    "compassasse": "compassar",
    "compassassem": "compassar",
    "compassasses": "compassar",
    "compassaste": "compassar",
    "compassastes": "compassar",
    "compassava": "compassar",
    "compassavam": "compassar",
    "compassavas": "compassar",
    "compasse": "compassar",
    "compassei": "compassar",
    "compasseis": "compassar",
    "compassem": "compassar",
    "compassemo": "compassar",
    "compassemos": "compassar",
    "compasses": "compassar",
    "compassiva": "compassivo",
    "compassivas": "compassivo",
    "compassividades": "compassividade",
    "compassivos": "compassivo",
    "compasso": "compassar",
    "compassos": "compasso",
    "compassou": "compassar",
    "compassá": "compassar",
    "compassámo": "compassar",
    "compassámos": "compassar",
    "compassáramo": "compassar",
    "compassáramos": "compassar",
    "compassárei": "compassar",
    "compassáreis": "compassar",
    "compassásseis": "compassar",
    "compassássemos": "compassar",
    "compassávamo": "compassar",
    "compassávamos": "compassar",
    "compassávei": "compassar",
    "compassáveis": "compassar",
    "compassíveis": "compassível",
    "compaternidades": "compaternidade",
    "compatibilidades": "compatibilidade",
    "compatibiliza": "compatibilizar",
    "compatibilizada": "compatibilizar",
    "compatibilizadas": "compatibilizar",
    "compatibilizado": "compatibilizar",
    "compatibilizados": "compatibilizar",
    "compatibilizai": "compatibilizar",
    "compatibilizais": "compatibilizar",
    "compatibilizam": "compatibilizar",
    "compatibilizamo": "compatibilizar",
    "compatibilizamos": "compatibilizar",
    "compatibilizando": "compatibilizar",
    "compatibilizara": "compatibilizar",
    "compatibilizaram": "compatibilizar",
    "compatibilizaras": "compatibilizar",
    "compatibilizarde": "compatibilizar",
    "compatibilizardes": "compatibilizar",
    "compatibilizare": "compatibilizar",
    "compatibilizarei": "compatibilizar",
    "compatibilizareis": "compatibilizar",
    "compatibilizarem": "compatibilizar",
    "compatibilizaremos": "compatibilizar",
    "compatibilizares": "compatibilizar",
    "compatibilizaria": "compatibilizar",
    "compatibilizariam": "compatibilizar",
    "compatibilizarias": "compatibilizar",
    "compatibilizarmo": "compatibilizar",
    "compatibilizarmos": "compatibilizar",
    "compatibilizará": "compatibilizar",
    "compatibilizarás": "compatibilizar",
    "compatibilizarão": "compatibilizar",
    "compatibilizaríamos": "compatibilizar",
    "compatibilizaríeis": "compatibilizar",
    "compatibilizas": "compatibilizar",
    "compatibilizasse": "compatibilizar",
    "compatibilizassem": "compatibilizar",
    "compatibilizasses": "compatibilizar",
    "compatibilizaste": "compatibilizar",
    "compatibilizastes": "compatibilizar",
    "compatibilizava": "compatibilizar",
    "compatibilizavam": "compatibilizar",
    "compatibilizavas": "compatibilizar",
    "compatibilizações": "compatibilização",
    "compatibilize": "compatibilizar",
    "compatibilizei": "compatibilizar",
    "compatibilizeis": "compatibilizar",
    "compatibilizem": "compatibilizar",
    "compatibilizemo": "compatibilizar",
    "compatibilizemos": "compatibilizar",
    "compatibilizes": "compatibilizar",
    "compatibilizo": "compatibilizar",
    "compatibilizou": "compatibilizar",
    "compatibilizá": "compatibilizar",
    "compatibilizámo": "compatibilizar",
    "compatibilizámos": "compatibilizar",
    "compatibilizáramo": "compatibilizar",
    "compatibilizáramos": "compatibilizar",
    "compatibilizárei": "compatibilizar",
    "compatibilizáreis": "compatibilizar",
    "compatibilizásseis": "compatibilizar",
    "compatibilizássemos": "compatibilizar",
    "compatibilizávamo": "compatibilizar",
    "compatibilizávamos": "compatibilizar",
    "compatibilizávei": "compatibilizar",
    "compatibilizáveis": "compatibilizar",
    "compatriotas": "compatriota",
    "compatrícia": "compatrício",
    "compatrícias": "compatrício",
    "compatrícios": "compatrício",
    "compatíveis": "compatível",
    "compele": "compelir",
    "compelem": "compelir",
    "compeles": "compelir",
    "compeli": "compelir",
    "compelia": "compelir",
    "compeliam": "compelir",
    "compelias": "compelir",
    "compelida": "compelir",
    "compelidas": "compelir",
    "compelido": "compelir",
    "compelidos": "compelir",
    "compelimo": "compelir",
    "compelimos": "compelir",
    "compelindo": "compelir",
    "compelira": "compelir",
    "compeliram": "compelir",
    "compeliras": "compelir",
    "compelirde": "compelir",
    "compelirdes": "compelir",
    "compelire": "compelir",
    "compelirei": "compelir",
    "compelireis": "compelir",
    "compelirem": "compelir",
    "compeliremos": "compelir",
    "compelires": "compelir",
    "compeliria": "compelir",
    "compeliriam": "compelir",
    "compelirias": "compelir",
    "compelirmo": "compelir",
    "compelirmos": "compelir",
    "compelirá": "compelir",
    "compelirás": "compelir",
    "compelirão": "compelir",
    "compeliríamos": "compelir",
    "compeliríeis": "compelir",
    "compelis": "compelir",
    "compelisse": "compelir",
    "compelissem": "compelir",
    "compelisses": "compelir",
    "compeliste": "compelir",
    "compelistes": "compelir",
    "compeliu": "compelir",
    "compelíamo": "compelir",
    "compelíamos": "compelir",
    "compelíei": "compelir",
    "compelíeis": "compelir",
    "compelíramo": "compelir",
    "compelíramos": "compelir",
    "compelírei": "compelir",
    "compelíreis": "compelir",
    "compelísseis": "compelir",
    "compelíssemos": "compelir",
    "compendia": "compendiar",
    "compendiada": "compendiar",
    "compendiadas": "compendiar",
    "compendiado": "compendiar",
    "compendiadora": "compendiador",
    "compendiadoras": "compendiador",
    "compendiadores": "compendiador",
    "compendiados": "compendiar",
    "compendiai": "compendiar",
    "compendiais": "compendiar",
    "compendiam": "compendiar",
    "compendiamo": "compendiar",
    "compendiamos": "compendiar",
    "compendiando": "compendiar",
    "compendiara": "compendiar",
    "compendiaram": "compendiar",
    "compendiaras": "compendiar",
    "compendiarde": "compendiar",
    "compendiardes": "compendiar",
    "compendiare": "compendiar",
    "compendiarei": "compendiar",
    "compendiareis": "compendiar",
    "compendiarem": "compendiar",
    "compendiaremos": "compendiar",
    "compendiares": "compendiar",
    "compendiaria": "compendiar",
    "compendiariam": "compendiar",
    "compendiarias": "compendiar",
    "compendiarmo": "compendiar",
    "compendiarmos": "compendiar",
    "compendiará": "compendiar",
    "compendiarás": "compendiar",
    "compendiarão": "compendiar",
    "compendiaríamos": "compendiar",
    "compendiaríeis": "compendiar",
    "compendias": "compendiar",
    "compendiasse": "compendiar",
    "compendiassem": "compendiar",
    "compendiasses": "compendiar",
    "compendiaste": "compendiar",
    "compendiastes": "compendiar",
    "compendiava": "compendiar",
    "compendiavam": "compendiar",
    "compendiavas": "compendiar",
    "compendie": "compendiar",
    "compendiei": "compendiar",
    "compendieis": "compendiar",
    "compendiem": "compendiar",
    "compendiemo": "compendiar",
    "compendiemos": "compendiar",
    "compendies": "compendiar",
    "compendio": "compendiar",
    "compendiosa": "compendioso",
    "compendiosas": "compendioso",
    "compendiosos": "compendioso",
    "compendiou": "compendiar",
    "compendiá": "compendiar",
    "compendiámo": "compendiar",
    "compendiámos": "compendiar",
    "compendiáramo": "compendiar",
    "compendiáramos": "compendiar",
    "compendiárei": "compendiar",
    "compendiáreis": "compendiar",
    "compendiásseis": "compendiar",
    "compendiássemos": "compendiar",
    "compendiávamo": "compendiar",
    "compendiávamos": "compendiar",
    "compendiávei": "compendiar",
    "compendiáveis": "compendiar",
    "compenetra": "compenetrar",
    "compenetrada": "compenetrar",
    "compenetradas": "compenetrar",
    "compenetrado": "compenetrar",
    "compenetrados": "compenetrar",
    "compenetradíssima": "compenetrado",
    "compenetradíssimas": "compenetrado",
    "compenetradíssimo": "compenetrado",
    "compenetradíssimos": "compenetrado",
    "compenetrai": "compenetrar",
    "compenetrais": "compenetrar",
    "compenetram": "compenetrar",
    "compenetramo": "compenetrar",
    "compenetramos": "compenetrar",
    "compenetrando": "compenetrar",
    "compenetrara": "compenetrar",
    "compenetraram": "compenetrar",
    "compenetraras": "compenetrar",
    "compenetrarde": "compenetrar",
    "compenetrardes": "compenetrar",
    "compenetrare": "compenetrar",
    "compenetrarei": "compenetrar",
    "compenetrareis": "compenetrar",
    "compenetrarem": "compenetrar",
    "compenetraremos": "compenetrar",
    "compenetrares": "compenetrar",
    "compenetraria": "compenetrar",
    "compenetrariam": "compenetrar",
    "compenetrarias": "compenetrar",
    "compenetrarmo": "compenetrar",
    "compenetrarmos": "compenetrar",
    "compenetrará": "compenetrar",
    "compenetrarás": "compenetrar",
    "compenetrarão": "compenetrar",
    "compenetraríamos": "compenetrar",
    "compenetraríeis": "compenetrar",
    "compenetras": "compenetrar",
    "compenetrasse": "compenetrar",
    "compenetrassem": "compenetrar",
    "compenetrasses": "compenetrar",
    "compenetraste": "compenetrar",
    "compenetrastes": "compenetrar",
    "compenetrava": "compenetrar",
    "compenetravam": "compenetrar",
    "compenetravas": "compenetrar",
    "compenetrações": "compenetração",
    "compenetre": "compenetrar",
    "compenetrei": "compenetrar",
    "compenetreis": "compenetrar",
    "compenetrem": "compenetrar",
    "compenetremo": "compenetrar",
    "compenetremos": "compenetrar",
    "compenetres": "compenetrar",
    "compenetro": "compenetrar",
    "compenetrou": "compenetrar",
    "compenetrá": "compenetrar",
    "compenetrámo": "compenetrar",
    "compenetrámos": "compenetrar",
    "compenetráramo": "compenetrar",
    "compenetráramos": "compenetrar",
    "compenetrárei": "compenetrar",
    "compenetráreis": "compenetrar",
    "compenetrásseis": "compenetrar",
    "compenetrássemos": "compenetrar",
    "compenetrávamo": "compenetrar",
    "compenetrávamos": "compenetrar",
    "compenetrávei": "compenetrar",
    "compenetráveis": "compenetrar",
    "compensa": "compensar",
    "compensacionismos": "compensacionismo",
    "compensada": "compensar",
    "compensadas": "compensar",
    "compensado": "compensar",
    "compensadora": "compensador",
    "compensadoras": "compensador",
    "compensadores": "compensador",
    "compensados": "compensar",
    "compensai": "compensar",
    "compensais": "compensar",
    "compensam": "compensar",
    "compensamo": "compensar",
    "compensamos": "compensar",
    "compensando": "compensar",
    "compensantes": "compensante",
    "compensara": "compensar",
    "compensaram": "compensar",
    "compensaras": "compensar",
    "compensarde": "compensar",
    "compensardes": "compensar",
    "compensare": "compensar",
    "compensarei": "compensar",
    "compensareis": "compensar",
    "compensarem": "compensar",
    "compensaremos": "compensar",
    "compensares": "compensar",
    "compensaria": "compensar",
    "compensariam": "compensar",
    "compensarias": "compensar",
    "compensarmo": "compensar",
    "compensarmos": "compensar",
    "compensará": "compensar",
    "compensarás": "compensar",
    "compensarão": "compensar",
    "compensaríamos": "compensar",
    "compensaríeis": "compensar",
    "compensas": "compensar",
    "compensasse": "compensar",
    "compensassem": "compensar",
    "compensasses": "compensar",
    "compensaste": "compensar",
    "compensastes": "compensar",
    "compensativa": "compensativo",
    "compensativas": "compensativo",
    "compensativos": "compensativo",
    "compensatria": "compensatrio",
    "compensatrias": "compensatrio",
    "compensatrios": "compensatrio",
    "compensatória": "compensatório",
    "compensatórias": "compensatório",
    "compensatórios": "compensatório",
    "compensava": "compensar",
    "compensavam": "compensar",
    "compensavas": "compensar",
    "compensações": "compensação",
    "compense": "compensar",
    "compensei": "compensar",
    "compenseis": "compensar",
    "compensem": "compensar",
    "compensemo": "compensar",
    "compensemos": "compensar",
    "compenses": "compensar",
    "compenso": "compensar",
    "compensou": "compensar",
    "compensá": "compensar",
    "compensámo": "compensar",
    "compensámos": "compensar",
    "compensáramo": "compensar",
    "compensáramos": "compensar",
    "compensárei": "compensar",
    "compensáreis": "compensar",
    "compensásseis": "compensar",
    "compensássemos": "compensar",
    "compensávamo": "compensar",
    "compensávamos": "compensar",
    "compensávei": "compensar",
    "compensáveis": "compensável",
    "comperes": "compere",
    "compete": "competir",
    "competem": "competir",
    "competentes": "competente",
    "competentezinha": "competente",
    "competentezinhas": "competente",
    "competentezinho": "competente",
    "competentezinhos": "competente",
    "competentezita": "competente",
    "competentezitas": "competente",
    "competentezito": "competente",
    "competentezitos": "competente",
    "competentíssima": "competente",
    "competentíssimas": "competente",
    "competentíssimo": "competente",
    "competentíssimos": "competente",
    "competes": "competir",
    "competi": "competir",
    "competia": "competir",
    "competiam": "competir",
    "competias": "competir",
    "competida": "competir",
    "competidas": "competir",
    "competido": "competir",
    "competidora": "competidor",
    "competidoras": "competidor",
    "competidores": "competidor",
    "competidos": "competir",
    "competimo": "competir",
    "competimos": "competir",
    "competindo": "competir",
    "competira": "competir",
    "competiram": "competir",
    "competiras": "competir",
    "competirdes": "competir",
    "competirei": "competir",
    "competireis": "competir",
    "competirem": "competir",
    "competiremos": "competir",
    "competires": "competir",
    "competiria": "competir",
    "competiriam": "competir",
    "competirias": "competir",
    "competirmo": "competir",
    "competirmos": "competir",
    "competirá": "competir",
    "competirás": "competir",
    "competirão": "competir",
    "competiríamos": "competir",
    "competiríeis": "competir",
    "competis": "competir",
    "competisse": "competir",
    "competissem": "competir",
    "competisses": "competir",
    "competiste": "competir",
    "competistes": "competir",
    "competitiva": "competitivo",
    "competitivas": "competitivo",
    "competitividades": "competitividade",
    "competitivos": "competitivo",
    "competiu": "competir",
    "competições": "competição",
    "competências": "competência",
    "competíamo": "competir",
    "competíamos": "competir",
    "competíeis": "competir",
    "competíramo": "competir",
    "competíramos": "competir",
    "competíreis": "competir",
    "competísseis": "competir",
    "competíssemos": "competir",
    "compila": "compilar",
    "compilada": "compilar",
    "compiladas": "compilar",
    "compilado": "compilar",
    "compiladora": "compilador",
    "compiladoras": "compilador",
    "compiladores": "compilador",
    "compilados": "compilar",
    "compilai": "compilar",
    "compilais": "compilar",
    "compilam": "compilar",
    "compilamo": "compilar",
    "compilamos": "compilar",
    "compilando": "compilar",
    "compilara": "compilar",
    "compilaram": "compilar",
    "compilaras": "compilar",
    "compilarde": "compilar",
    "compilardes": "compilar",
    "compilare": "compilar",
    "compilarei": "compilar",
    "compilareis": "compilar",
    "compilarem": "compilar",
    "compilaremos": "compilar",
    "compilares": "compilar",
    "compilaria": "compilar",
    "compilariam": "compilar",
    "compilarias": "compilar",
    "compilarmo": "compilar",
    "compilarmos": "compilar",
    "compilará": "compilar",
    "compilarás": "compilar",
    "compilarão": "compilar",
    "compilaríamos": "compilar",
    "compilaríeis": "compilar",
    "compilas": "compilar",
    "compilasse": "compilar",
    "compilassem": "compilar",
    "compilasses": "compilar",
    "compilaste": "compilar",
    "compilastes": "compilar",
    "compilatória": "compilatório",
    "compilatórias": "compilatório",
    "compilatórios": "compilatório",
    "compilava": "compilar",
    "compilavam": "compilar",
    "compilavas": "compilar",
    "compilações": "compilação",
    "compile": "compilar",
    "compilei": "compilar",
    "compileis": "compilar",
    "compilem": "compilar",
    "compilemo": "compilar",
    "compilemos": "compilar",
    "compiles": "compilar",
    "compilo": "compilar",
    "compilou": "compilar",
    "compilá": "compilar",
    "compilámo": "compilar",
    "compilámos": "compilar",
    "compiláramo": "compilar",
    "compiláramos": "compilar",
    "compilárei": "compilar",
    "compiláreis": "compilar",
    "compilásseis": "compilar",
    "compilássemos": "compilar",
    "compilávamo": "compilar",
    "compilávamos": "compilar",
    "compilávei": "compilar",
    "compiláveis": "compilar",
    "compinchas": "compincha",
    "compita": "competir",
    "compitais": "competir",
    "compitam": "competir",
    "compitamo": "competir",
    "compitamos": "competir",
    "compitas": "compita",
    "compito": "competir",
    "complacentes": "complacente",
    "complacências": "complacência",
    "complana": "complanar",
    "complanada": "complanar",
    "complanadas": "complanar",
    "complanado": "complanar",
    "complanados": "complanar",
    "complanai": "complanar",
    "complanais": "complanar",
    "complanam": "complanar",
    "complanamo": "complanar",
    "complanamos": "complanar",
    "complanando": "complanar",
    "complanara": "complanar",
    "complanaram": "complanar",
    "complanaras": "complanar",
    "complanarde": "complanar",
    "complanardes": "complanar",
    "complanare": "complanar",
    "complanarei": "complanar",
    "complanareis": "complanar",
    "complanarem": "complanar",
    "complanaremos": "complanar",
    "complanares": "complanar",
    "complanaria": "complanar",
    "complanariam": "complanar",
    "complanarias": "complanar",
    "complanarmo": "complanar",
    "complanarmos": "complanar",
    "complanará": "complanar",
    "complanarás": "complanar",
    "complanarão": "complanar",
    "complanaríamos": "complanar",
    "complanaríeis": "complanar",
    "complanas": "complanar",
    "complanasse": "complanar",
    "complanassem": "complanar",
    "complanasses": "complanar",
    "complanaste": "complanar",
    "complanastes": "complanar",
    "complanava": "complanar",
    "complanavam": "complanar",
    "complanavas": "complanar",
    "complanações": "complanação",
    "complane": "complanar",
    "complanei": "complanar",
    "complaneis": "complanar",
    "complanem": "complanar",
    "complanemo": "complanar",
    "complanemos": "complanar",
    "complanes": "complanar",
    "complano": "complanar",
    "complanou": "complanar",
    "complaná": "complanar",
    "complanámo": "complanar",
    "complanámos": "complanar",
    "complanáramo": "complanar",
    "complanáramos": "complanar",
    "complanárei": "complanar",
    "complanáreis": "complanar",
    "complanásseis": "complanar",
    "complanássemos": "complanar",
    "complanávamo": "complanar",
    "complanávamos": "complanar",
    "complanávei": "complanar",
    "complanáveis": "complanar",
    "complativa": "complativo",
    "complativas": "complativo",
    "complativos": "complativo",
    "complações": "complação",
    "complectiva": "complectivo",
    "complectivas": "complectivo",
    "complectivos": "complectivo",
    "complectíveis": "complectível",
    "compleicionada": "compleicionado",
    "compleicionadas": "compleicionado",
    "compleicionados": "compleicionado",
    "compleicionais": "compleicional",
    "compleiçoada": "compleiçoado",
    "compleiçoadas": "compleiçoado",
    "compleiçoados": "compleiçoado",
    "compleições": "compleição",
    "complementa": "complementar",
    "complementada": "complementar",
    "complementadas": "complementar",
    "complementado": "complementar",
    "complementados": "complementar",
    "complementai": "complementar",
    "complementais": "complementar",
    "complementam": "complementar",
    "complementamo": "complementar",
    "complementamos": "complementar",
    "complementando": "complementar",
    "complementara": "complementar",
    "complementaram": "complementar",
    "complementaras": "complementar",
    "complementarde": "complementar",
    "complementardes": "complementar",
    "complementare": "complementar",
    "complementarei": "complementar",
    "complementareis": "complementar",
    "complementarem": "complementar",
    "complementaremos": "complementar",
    "complementares": "complementar",
    "complementaria": "complementar",
    "complementariam": "complementar",
    "complementarias": "complementar",
    "complementaridades": "complementaridade",
    "complementarmo": "complementar",
    "complementarmos": "complementar",
    "complementará": "complementar",
    "complementarás": "complementar",
    "complementarão": "complementar",
    "complementaríamos": "complementar",
    "complementaríeis": "complementar",
    "complementas": "complementar",
    "complementasse": "complementar",
    "complementassem": "complementar",
    "complementasses": "complementar",
    "complementaste": "complementar",
    "complementastes": "complementar",
    "complementava": "complementar",
    "complementavam": "complementar",
    "complementavas": "complementar",
    "complementações": "complementação",
    "complemente": "complementar",
    "complementei": "complementar",
    "complementeis": "complementar",
    "complementem": "complementar",
    "complementemo": "complementar",
    "complementemos": "complementar",
    "complementes": "complementar",
    "complemento": "complementar",
    "complementos": "complemento",
    "complementou": "complementar",
    "complementá": "complementar",
    "complementámo": "complementar",
    "complementámos": "complementar",
    "complementáramo": "complementar",
    "complementáramos": "complementar",
    "complementárei": "complementar",
    "complementáreis": "complementar",
    "complementária": "complementário",
    "complementárias": "complementário",
    "complementários": "complementário",
    "complementásseis": "complementar",
    "complementássemos": "complementar",
    "complementávamo": "complementar",
    "complementávamos": "complementar",
    "complementávei": "complementar",
    "complementáveis": "complementável",
    "completa": "completar",
    "completada": "completar",
    "completadas": "completar",
    "completado": "completar",
    "completados": "completar",
    "completai": "completar",
    "completais": "completar",
    "completam": "completar",
    "completamo": "completar",
    "completamos": "completar",
    "completando": "completar",
    "completara": "completar",
    "completaram": "completar",
    "completaras": "completar",
    "completarde": "completar",
    "completardes": "completar",
    "completare": "completar",
    "completarei": "completar",
    "completareis": "completar",
    "completarem": "completar",
    "completaremos": "completar",
    "completares": "completar",
    "completaria": "completar",
    "completariam": "completar",
    "completarias": "completar",
    "completarmo": "completar",
    "completarmos": "completar",
    "completará": "completar",
    "completarás": "completar",
    "completarão": "completar",
    "completaríamos": "completar",
    "completaríeis": "completar",
    "completas": "completar",
    "completasse": "completar",
    "completassem": "completar",
    "completasses": "completar",
    "completaste": "completar",
    "completastes": "completar",
    "completava": "completar",
    "completavam": "completar",
    "completavas": "completar",
    "completações": "completação",
    "complete": "completar",
    "completei": "completar",
    "completeis": "completar",
    "completem": "completar",
    "completemo": "completar",
    "completemos": "completar",
    "completes": "completar",
    "completinho": "completo",
    "completinhos": "completo",
    "completito": "completo",
    "completitos": "completo",
    "completitudes": "completitude",
    "completiva": "completivo",
    "completivas": "completivo",
    "completivos": "completivo",
    "completo": "completar",
    "completos": "completo",
    "completou": "completar",
    "completozinho": "completo",
    "completozinhos": "completo",
    "completozito": "completo",
    "completozitos": "completo",
    "completá": "completar",
    "completámo": "completar",
    "completámos": "completar",
    "completáramo": "completar",
    "completáramos": "completar",
    "completárei": "completar",
    "completáreis": "completar",
    "completásseis": "completar",
    "completássemos": "completar",
    "completávamo": "completar",
    "completávamos": "completar",
    "completávei": "completar",
    "completáveis": "completável",
    "completória": "completório",
    "completórias": "completório",
    "completórios": "completório",
    "complexa": "complexo",
    "complexada": "complexado",
    "complexadas": "complexado",
    "complexados": "complexado",
    "complexadíssima": "complexado",
    "complexadíssimas": "complexado",
    "complexadíssimo": "complexado",
    "complexadíssimos": "complexado",
    "complexas": "complexo",
    "complexidades": "complexidade",
    "complexidões": "complexidão",
    "complexifica": "complexificar",
    "complexificada": "complexificar",
    "complexificadas": "complexificar",
    "complexificado": "complexificar",
    "complexificados": "complexificar",
    "complexificai": "complexificar",
    "complexificais": "complexificar",
    "complexificam": "complexificar",
    "complexificamo": "complexificar",
    "complexificamos": "complexificar",
    "complexificando": "complexificar",
    "complexificara": "complexificar",
    "complexificaram": "complexificar",
    "complexificaras": "complexificar",
    "complexificarde": "complexificar",
    "complexificardes": "complexificar",
    "complexificare": "complexificar",
    "complexificarei": "complexificar",
    "complexificareis": "complexificar",
    "complexificarem": "complexificar",
    "complexificaremos": "complexificar",
    "complexificares": "complexificar",
    "complexificaria": "complexificar",
    "complexificariam": "complexificar",
    "complexificarias": "complexificar",
    "complexificarmo": "complexificar",
    "complexificarmos": "complexificar",
    "complexificará": "complexificar",
    "complexificarás": "complexificar",
    "complexificarão": "complexificar",
    "complexificaríamos": "complexificar",
    "complexificaríeis": "complexificar",
    "complexificas": "complexificar",
    "complexificasse": "complexificar",
    "complexificassem": "complexificar",
    "complexificasses": "complexificar",
    "complexificaste": "complexificar",
    "complexificastes": "complexificar",
    "complexificava": "complexificar",
    "complexificavam": "complexificar",
    "complexificavas": "complexificar",
    "complexifico": "complexificar",
    "complexificou": "complexificar",
    "complexificá": "complexificar",
    "complexificámo": "complexificar",
    "complexificámos": "complexificar",
    "complexificáramo": "complexificar",
    "complexificáramos": "complexificar",
    "complexificárei": "complexificar",
    "complexificáreis": "complexificar",
    "complexificásseis": "complexificar",
    "complexificássemos": "complexificar",
    "complexificávamo": "complexificar",
    "complexificávamos": "complexificar",
    "complexificávei": "complexificar",
    "complexificáveis": "complexificar",
    "complexifique": "complexificar",
    "complexifiquei": "complexificar",
    "complexifiqueis": "complexificar",
    "complexifiquem": "complexificar",
    "complexifiquemo": "complexificar",
    "complexifiquemos": "complexificar",
    "complexifiques": "complexificar",
    "complexos": "complexo",
    "complexíssima": "complexo",
    "complexíssimas": "complexo",
    "complexíssimo": "complexo",
    "complexíssimos": "complexo",
    "complexões": "complexão",
    "complica": "complicar",
    "complicada": "complicar",
    "complicadas": "complicar",
    "complicadazinha": "complicado",
    "complicadazinhas": "complicado",
    "complicadazita": "complicado",
    "complicadazitas": "complicado",
    "complicado": "complicar",
    "complicadora": "complicador",
    "complicadoras": "complicador",
    "complicadores": "complicador",
    "complicados": "complicar",
    "complicadozinho": "complicado",
    "complicadozinhos": "complicado",
    "complicadozito": "complicado",
    "complicadozitos": "complicado",
    "complicadíssima": "complicado",
    "complicadíssimas": "complicado",
    "complicadíssimo": "complicado",
    "complicadíssimos": "complicado",
    "complicai": "complicar",
    "complicais": "complicar",
    "complicam": "complicar",
    "complicamo": "complicar",
    "complicamos": "complicar",
    "complicando": "complicar",
    "complicara": "complicar",
    "complicaram": "complicar",
    "complicaras": "complicar",
    "complicarde": "complicar",
    "complicardes": "complicar",
    "complicare": "complicar",
    "complicarei": "complicar",
    "complicareis": "complicar",
    "complicarem": "complicar",
    "complicaremos": "complicar",
    "complicares": "complicar",
    "complicaria": "complicar",
    "complicariam": "complicar",
    "complicarias": "complicar",
    "complicarmo": "complicar",
    "complicarmos": "complicar",
    "complicará": "complicar",
    "complicarás": "complicar",
    "complicarão": "complicar",
    "complicaríamos": "complicar",
    "complicaríeis": "complicar",
    "complicas": "complicar",
    "complicasse": "complicar",
    "complicassem": "complicar",
    "complicasses": "complicar",
    "complicaste": "complicar",
    "complicastes": "complicar",
    "complicava": "complicar",
    "complicavam": "complicar",
    "complicavas": "complicar",
    "complicações": "complicação",
    "complico": "complicar",
    "complicou": "complicar",
    "complicá": "complicar",
    "complicámo": "complicar",
    "complicámos": "complicar",
    "complicáramo": "complicar",
    "complicáramos": "complicar",
    "complicárei": "complicar",
    "complicáreis": "complicar",
    "complicásseis": "complicar",
    "complicássemos": "complicar",
    "complicávamo": "complicar",
    "complicávamos": "complicar",
    "complicávei": "complicar",
    "complicáveis": "complicar",
    "complique": "complicar",
    "compliquei": "complicar",
    "compliqueis": "complicar",
    "compliquem": "complicar",
    "compliquemo": "complicar",
    "compliquemos": "complicar",
    "compliques": "complicar",
    "complots": "complot",
    "complôs": "complô",
    "complúvios": "complúvio",
    "compomo": "compor",
    "compomos": "compor",
    "componde": "compor",
    "compondes": "compor",
    "compondo": "compor",
    "componedora": "componedor",
    "componedoras": "componedor",
    "componedores": "componedor",
    "componendas": "componenda",
    "componentes": "componente",
    "componha": "compor",
    "componhais": "compor",
    "componham": "compor",
    "componhamo": "compor",
    "componhamos": "compor",
    "componhas": "compor",
    "componho": "compor",
    "componíveis": "componível",
    "comporde": "compor",
    "compordes": "compor",
    "compore": "compor",
    "comporei": "compor",
    "comporeis": "compor",
    "comporem": "compor",
    "comporemos": "compor",
    "compores": "compor",
    "comporia": "compor",
    "comporiam": "compor",
    "comporias": "compor",
    "compormo": "compor",
    "compormos": "compor",
    "comporta": "comportar",
    "comportada": "comportar",
    "comportadas": "comportar",
    "comportadinha": "comportado",
    "comportadinhas": "comportado",
    "comportadinho": "comportado",
    "comportadinhos": "comportado",
    "comportadita": "comportado",
    "comportaditas": "comportado",
    "comportadito": "comportado",
    "comportaditos": "comportado",
    "comportado": "comportar",
    "comportados": "comportar",
    "comportai": "comportar",
    "comportais": "comportar",
    "comportam": "comportar",
    "comportamentais": "comportamental",
    "comportamentos": "comportamento",
    "comportamo": "comportar",
    "comportamos": "comportar",
    "comportando": "comportar",
    "comportara": "comportar",
    "comportaram": "comportar",
    "comportaras": "comportar",
    "comportarde": "comportar",
    "comportardes": "comportar",
    "comportare": "comportar",
    "comportarei": "comportar",
    "comportareis": "comportar",
    "comportarem": "comportar",
    "comportaremos": "comportar",
    "comportares": "comportar",
    "comportaria": "comportar",
    "comportariam": "comportar",
    "comportarias": "comportar",
    "comportarmo": "comportar",
    "comportarmos": "comportar",
    "comportará": "comportar",
    "comportarás": "comportar",
    "comportarão": "comportar",
    "comportaríamos": "comportar",
    "comportaríeis": "comportar",
    "comportas": "comportar",
    "comportasse": "comportar",
    "comportassem": "comportar",
    "comportasses": "comportar",
    "comportaste": "comportar",
    "comportastes": "comportar",
    "comportava": "comportar",
    "comportavam": "comportar",
    "comportavas": "comportar",
    "comporte": "comportar",
    "comportei": "comportar",
    "comporteis": "comportar",
    "comportem": "comportar",
    "comportemo": "comportar",
    "comportemos": "comportar",
    "comportes": "comportar",
    "comporto": "comportar",
    "comportou": "comportar",
    "comportá": "comportar",
    "comportámo": "comportar",
    "comportámos": "comportar",
    "comportáramo": "comportar",
    "comportáramos": "comportar",
    "comportárei": "comportar",
    "comportáreis": "comportar",
    "comportásseis": "comportar",
    "comportássemos": "comportar",
    "comportávamo": "comportar",
    "comportávamos": "comportar",
    "comportávei": "comportar",
    "comportáveis": "comportável",
    "comporá": "compor",
    "comporás": "compor",
    "comporão": "compor",
    "comporíamos": "compor",
    "comporíeis": "compor",
    "composicionais": "composicional",
    "compositiva": "compositivo",
    "compositivas": "compositivo",
    "compositivos": "compositivo",
    "compositora": "compositor",
    "compositoras": "compositor",
    "compositores": "compositor",
    "composições": "composição",
    "composses": "composse",
    "compossessora": "compossessor",
    "compossessoras": "compossessor",
    "compossessores": "compossessor",
    "compossuidora": "compossuidor",
    "compossuidoras": "compossuidor",
    "compossuidores": "compossuidor",
    "composta": "composto",
    "compostagens": "compostagem",
    "compostas": "composto",
    "compostelana": "compostelano",
    "compostelanas": "compostelano",
    "compostelanos": "compostelano",
    "compostinha": "composto",
    "compostinhas": "composto",
    "compostinho": "composto",
    "compostinhos": "composto",
    "compostita": "composto",
    "compostitas": "composto",
    "compostito": "composto",
    "compostitos": "composto",
    "composto": "compor",
    "compostos": "composto",
    "composturas": "compostura",
    "compostíssima": "composto",
    "compostíssimas": "composto",
    "compostíssimo": "composto",
    "compostíssimos": "composto",
    "compotas": "compota",
    "compoteira": "compoteiro",
    "compoteiras": "compoteiro",
    "compoteiros": "compoteiro",
    "compra": "comprar",
    "comprada": "comprar",
    "compradas": "comprar",
    "compradiça": "compradiço",
    "compradiças": "compradiço",
    "compradiços": "compradiço",
    "comprado": "comprar",
    "compradora": "comprador",
    "compradoras": "comprador",
    "compradores": "comprador",
    "comprados": "comprar",
    "comprai": "comprar",
    "comprais": "comprar",
    "compram": "comprar",
    "compramo": "comprar",
    "compramos": "comprar",
    "comprando": "comprar",
    "comprara": "comprar",
    "compraram": "comprar",
    "compraras": "comprar",
    "comprarde": "comprar",
    "comprardes": "comprar",
    "comprare": "comprar",
    "comprarei": "comprar",
    "comprareis": "comprar",
    "comprarem": "comprar",
    "compraremos": "comprar",
    "comprares": "comprar",
    "compraria": "comprar",
    "comprariam": "comprar",
    "comprarias": "comprar",
    "comprarmo": "comprar",
    "comprarmos": "comprar",
    "comprará": "comprar",
    "comprarás": "comprar",
    "comprarão": "comprar",
    "compraríamos": "comprar",
    "compraríeis": "comprar",
    "compras": "comprar",
    "comprasse": "comprar",
    "comprassem": "comprar",
    "comprasses": "comprar",
    "compraste": "comprar",
    "comprastes": "comprar",
    "comprativa": "comprativo",
    "comprativas": "comprativo",
    "comprativos": "comprativo",
    "compratória": "compratório",
    "compratórias": "compratório",
    "compratórios": "compratório",
    "comprava": "comprar",
    "compravam": "comprar",
    "compravas": "comprar",
    "compraz": "comprazer",
    "compraza": "comprazer",
    "comprazam": "comprazer",
    "comprazedora": "comprazedor",
    "comprazedoras": "comprazedor",
    "comprazedores": "comprazedor",
    "comprazem": "comprazer",
    "comprazendo": "comprazer",
    "comprazerem": "comprazer",
    "comprazeria": "comprazer",
    "comprazeriam": "comprazer",
    "comprazerá": "comprazer",
    "comprazerão": "comprazer",
    "comprazia": "comprazer",
    "compraziam": "comprazer",
    "comprazida": "comprazido",
    "comprazidas": "comprazido",
    "comprazido": "comprazer",
    "comprazidos": "comprazido",
    "comprazimentos": "comprazimento",
    "compre": "comprar",
    "compreenda": "compreender",
    "compreendais": "compreender",
    "compreendam": "compreender",
    "compreendamo": "compreender",
    "compreendamos": "compreender",
    "compreendas": "compreender",
    "compreende": "compreender",
    "compreendei": "compreender",
    "compreendeis": "compreender",
    "compreendem": "compreender",
    "compreendemo": "compreender",
    "compreendemos": "compreender",
    "compreendendo": "compreender",
    "compreendera": "compreender",
    "compreenderam": "compreender",
    "compreenderas": "compreender",
    "compreenderde": "compreender",
    "compreenderdes": "compreender",
    "compreendere": "compreender",
    "compreenderei": "compreender",
    "compreendereis": "compreender",
    "compreenderem": "compreender",
    "compreenderemos": "compreender",
    "compreenderes": "compreender",
    "compreenderia": "compreender",
    "compreenderiam": "compreender",
    "compreenderias": "compreender",
    "compreendermo": "compreender",
    "compreendermos": "compreender",
    "compreenderá": "compreender",
    "compreenderás": "compreender",
    "compreenderão": "compreender",
    "compreenderíamos": "compreender",
    "compreenderíeis": "compreender",
    "compreendes": "compreender",
    "compreendesse": "compreender",
    "compreendessem": "compreender",
    "compreendesses": "compreender",
    "compreendeste": "compreender",
    "compreendestes": "compreender",
    "compreendeu": "compreender",
    "compreendi": "compreender",
    "compreendia": "compreender",
    "compreendiam": "compreender",
    "compreendias": "compreender",
    "compreendida": "compreendido",
    "compreendidas": "compreendido",
    "compreendido": "compreender",
    "compreendidos": "compreendido",
    "compreendo": "compreender",
    "compreendê": "compreender",
    "compreendêramo": "compreender",
    "compreendêramos": "compreender",
    "compreendêrei": "compreender",
    "compreendêreis": "compreender",
    "compreendêsseis": "compreender",
    "compreendêssemos": "compreender",
    "compreendíamo": "compreender",
    "compreendíamos": "compreender",
    "compreendíei": "compreender",
    "compreendíeis": "compreender",
    "compreensibilidades": "compreensibilidade",
    "compreensiva": "compreensivo",
    "compreensivas": "compreensivo",
    "compreensivos": "compreensivo",
    "compreensora": "compreensor",
    "compreensoras": "compreensor",
    "compreensores": "compreensor",
    "compreensíveis": "compreensível",
    "compreensões": "compreensão",
    "comprei": "comprar",
    "compreis": "comprar",
    "comprem": "comprar",
    "compremo": "comprar",
    "compremos": "comprar",
    "compres": "comprar",
    "compressa": "compresso",
    "compressas": "compresso",
    "compressibilidades": "compressibilidade",
    "compressiva": "compressivo",
    "compressivas": "compressivo",
    "compressivos": "compressivo",
    "compressora": "compressor",
    "compressoras": "compressor",
    "compressores": "compressor",
    "compressos": "compresso",
    "compressíveis": "compressível",
    "compressória": "compressório",
    "compressórias": "compressório",
    "compressórios": "compressório",
    "compressões": "compressão",
    "comprida": "comprido",
    "compridas": "comprido",
    "compridinha": "comprido",
    "compridinhas": "comprido",
    "compridinho": "comprido",
    "compridinhos": "comprido",
    "compridita": "comprido",
    "compriditas": "comprido",
    "compridito": "comprido",
    "compriditos": "comprido",
    "compridos": "comprido",
    "compridíssima": "comprido",
    "compridíssimas": "comprido",
    "compridíssimo": "comprido",
    "compridíssimos": "comprido",
    "comprima": "comprimir",
    "comprimais": "comprimir",
    "comprimam": "comprimir",
    "comprimamo": "comprimir",
    "comprimamos": "comprimir",
    "comprimas": "comprimir",
    "comprime": "comprimir",
    "comprimem": "comprimir",
    "comprimentes": "comprimente",
    "comprimentos": "comprimento",
    "comprimes": "comprimir",
    "comprimi": "comprimir",
    "comprimia": "comprimir",
    "comprimiam": "comprimir",
    "comprimias": "comprimir",
    "comprimida": "comprimir",
    "comprimidas": "comprimir",
    "comprimido": "comprimir",
    "comprimidos": "comprimir",
    "comprimimo": "comprimir",
    "comprimimos": "comprimir",
    "comprimindo": "comprimir",
    "comprimira": "comprimir",
    "comprimiram": "comprimir",
    "comprimiras": "comprimir",
    "comprimirde": "comprimir",
    "comprimirdes": "comprimir",
    "comprimire": "comprimir",
    "comprimirei": "comprimir",
    "comprimireis": "comprimir",
    "comprimirem": "comprimir",
    "comprimiremos": "comprimir",
    "comprimires": "comprimir",
    "comprimiria": "comprimir",
    "comprimiriam": "comprimir",
    "comprimirias": "comprimir",
    "comprimirmo": "comprimir",
    "comprimirmos": "comprimir",
    "comprimirá": "comprimir",
    "comprimirás": "comprimir",
    "comprimirão": "comprimir",
    "comprimiríamos": "comprimir",
    "comprimiríeis": "comprimir",
    "comprimis": "comprimir",
    "comprimisse": "comprimir",
    "comprimissem": "comprimir",
    "comprimisses": "comprimir",
    "comprimiste": "comprimir",
    "comprimistes": "comprimir",
    "comprimiu": "comprimir",
    "comprimo": "comprimir",
    "comprimíamo": "comprimir",
    "comprimíamos": "comprimir",
    "comprimíei": "comprimir",
    "comprimíeis": "comprimir",
    "comprimíramo": "comprimir",
    "comprimíramos": "comprimir",
    "comprimírei": "comprimir",
    "comprimíreis": "comprimir",
    "comprimísseis": "comprimir",
    "comprimíssemos": "comprimir",
    "compro": "comprar",
    "comprobatória": "comprobatório",
    "comprobatórias": "comprobatório",
    "comprobatórios": "comprobatório",
    "comprometa": "comprometer",
    "comprometais": "comprometer",
    "comprometam": "comprometer",
    "comprometamo": "comprometer",
    "comprometamos": "comprometer",
    "comprometas": "comprometer",
    "compromete": "comprometer",
    "comprometedora": "comprometedor",
    "comprometedoras": "comprometedor",
    "comprometedores": "comprometedor",
    "comprometei": "comprometer",
    "comprometeis": "comprometer",
    "comprometem": "comprometer",
    "comprometemo": "comprometer",
    "comprometemos": "comprometer",
    "comprometendo": "comprometer",
    "comprometera": "comprometer",
    "comprometeram": "comprometer",
    "comprometeras": "comprometer",
    "comprometerde": "comprometer",
    "comprometerdes": "comprometer",
    "comprometere": "comprometer",
    "comprometerei": "comprometer",
    "comprometereis": "comprometer",
    "comprometerem": "comprometer",
    "comprometeremos": "comprometer",
    "comprometeres": "comprometer",
    "comprometeria": "comprometer",
    "comprometeriam": "comprometer",
    "comprometerias": "comprometer",
    "comprometermo": "comprometer",
    "comprometermos": "comprometer",
    "comprometerá": "comprometer",
    "comprometerás": "comprometer",
    "comprometerão": "comprometer",
    "comprometeríamos": "comprometer",
    "comprometeríeis": "comprometer",
    "comprometes": "comprometer",
    "comprometesse": "comprometer",
    "comprometessem": "comprometer",
    "comprometesses": "comprometer",
    "comprometeste": "comprometer",
    "comprometestes": "comprometer",
    "comprometeu": "comprometer",
    "comprometi": "comprometer",
    "comprometia": "comprometer",
    "comprometiam": "comprometer",
    "comprometias": "comprometer",
    "comprometida": "comprometido",
    "comprometidas": "comprometido",
    "comprometido": "comprometer",
    "comprometidos": "comprometido",
    "comprometidíssima": "comprometido",
    "comprometidíssimas": "comprometido",
    "comprometidíssimo": "comprometido",
    "comprometidíssimos": "comprometido",
    "comprometimentos": "comprometimento",
    "comprometo": "comprometer",
    "comprometê": "comprometer",
    "comprometêramo": "comprometer",
    "comprometêramos": "comprometer",
    "comprometêrei": "comprometer",
    "comprometêreis": "comprometer",
    "comprometêsseis": "comprometer",
    "comprometêssemos": "comprometer",
    "comprometíamo": "comprometer",
    "comprometíamos": "comprometer",
    "comprometíei": "comprometer",
    "comprometíeis": "comprometer",
    "compromissiva": "compromissivo",
    "compromissivas": "compromissivo",
    "compromissivos": "compromissivo",
    "compromissos": "compromisso",
    "compromissária": "compromissário",
    "compromissárias": "compromissário",
    "compromissários": "compromissário",
    "compromissória": "compromissório",
    "compromissórias": "compromissório",
    "compromissórios": "compromissório",
    "compromitentes": "compromitente",
    "compropriedades": "compropriedade",
    "comproprietária": "comproprietário",
    "comproprietárias": "comproprietário",
    "comproprietários": "comproprietário",
    "comprotectora": "comprotector",
    "comprotectoras": "comprotector",
    "comprotectores": "comprotector",
    "comprou": "comprar",
    "comprouve": "comprazer",
    "comprouver": "comprazer",
    "comprouvera": "comprazer",
    "comprouveram": "comprazer",
    "comprouverem": "comprazer",
    "comprouvesse": "comprazer",
    "comprouvessem": "comprazer",
    "comprova": "comprovar",
    "comprovada": "comprovar",
    "comprovadas": "comprovar",
    "comprovado": "comprovar",
    "comprovadora": "comprovador",
    "comprovadoras": "comprovador",
    "comprovadores": "comprovador",
    "comprovados": "comprovar",
    "comprovadíssima": "comprovado",
    "comprovadíssimas": "comprovado",
    "comprovadíssimo": "comprovado",
    "comprovadíssimos": "comprovado",
    "comprovai": "comprovar",
    "comprovais": "comprovar",
    "comprovam": "comprovar",
    "comprovamo": "comprovar",
    "comprovamos": "comprovar",
    "comprovando": "comprovar",
    "comprovantes": "comprovante",
    "comprovara": "comprovar",
    "comprovaram": "comprovar",
    "comprovaras": "comprovar",
    "comprovarde": "comprovar",
    "comprovardes": "comprovar",
    "comprovare": "comprovar",
    "comprovarei": "comprovar",
    "comprovareis": "comprovar",
    "comprovarem": "comprovar",
    "comprovaremos": "comprovar",
    "comprovares": "comprovar",
    "comprovaria": "comprovar",
    "comprovariam": "comprovar",
    "comprovarias": "comprovar",
    "comprovarmo": "comprovar",
    "comprovarmos": "comprovar",
    "comprovará": "comprovar",
    "comprovarás": "comprovar",
    "comprovarão": "comprovar",
    "comprovaríamos": "comprovar",
    "comprovaríeis": "comprovar",
    "comprovas": "comprovar",
    "comprovasse": "comprovar",
    "comprovassem": "comprovar",
    "comprovasses": "comprovar",
    "comprovaste": "comprovar",
    "comprovastes": "comprovar",
    "comprovativa": "comprovativo",
    "comprovativas": "comprovativo",
    "comprovativos": "comprovativo",
    "comprovava": "comprovar",
    "comprovavam": "comprovar",
    "comprovavas": "comprovar",
    "comprovações": "comprovação",
    "comprove": "comprovar",
    "comprovei": "comprovar",
    "comproveis": "comprovar",
    "comprovem": "comprovar",
    "comprovemo": "comprovar",
    "comprovemos": "comprovar",
    "comproves": "comprovar",
    "comprovinciais": "comprovincial",
    "comprovinciana": "comprovinciano",
    "comprovincianas": "comprovinciano",
    "comprovincianos": "comprovinciano",
    "comprovo": "comprovar",
    "comprovou": "comprovar",
    "comprová": "comprovar",
    "comprovámo": "comprovar",
    "comprovámos": "comprovar",
    "comprováramo": "comprovar",
    "comprováramos": "comprovar",
    "comprovárei": "comprovar",
    "comprováreis": "comprovar",
    "comprovásseis": "comprovar",
    "comprovássemos": "comprovar",
    "comprovávamo": "comprovar",
    "comprovávamos": "comprovar",
    "comprovávei": "comprovar",
    "comprováveis": "comprovar",
    "comprá": "comprar",
    "comprámo": "comprar",
    "comprámos": "comprar",
    "compráramo": "comprar",
    "compráramos": "comprar",
    "comprárei": "comprar",
    "compráreis": "comprar",
    "comprásseis": "comprar",
    "comprássemos": "comprar",
    "comprávamo": "comprar",
    "comprávamos": "comprar",
    "comprávei": "comprar",
    "compráveis": "comprável",
    "compugna": "compugnar",
    "compugnada": "compugnar",
    "compugnadas": "compugnar",
    "compugnado": "compugnar",
    "compugnados": "compugnar",
    "compugnai": "compugnar",
    "compugnais": "compugnar",
    "compugnam": "compugnar",
    "compugnamo": "compugnar",
    "compugnamos": "compugnar",
    "compugnando": "compugnar",
    "compugnara": "compugnar",
    "compugnaram": "compugnar",
    "compugnaras": "compugnar",
    "compugnardes": "compugnar",
    "compugnarei": "compugnar",
    "compugnareis": "compugnar",
    "compugnarem": "compugnar",
    "compugnaremos": "compugnar",
    "compugnares": "compugnar",
    "compugnaria": "compugnar",
    "compugnariam": "compugnar",
    "compugnarias": "compugnar",
    "compugnarmo": "compugnar",
    "compugnarmos": "compugnar",
    "compugnará": "compugnar",
    "compugnarás": "compugnar",
    "compugnarão": "compugnar",
    "compugnaríamos": "compugnar",
    "compugnaríeis": "compugnar",
    "compugnas": "compugnar",
    "compugnasse": "compugnar",
    "compugnassem": "compugnar",
    "compugnasses": "compugnar",
    "compugnaste": "compugnar",
    "compugnastes": "compugnar",
    "compugnava": "compugnar",
    "compugnavam": "compugnar",
    "compugnavas": "compugnar",
    "compugne": "compugnar",
    "compugnei": "compugnar",
    "compugneis": "compugnar",
    "compugnem": "compugnar",
    "compugnemo": "compugnar",
    "compugnemos": "compugnar",
    "compugnes": "compugnar",
    "compugno": "compugnar",
    "compugnou": "compugnar",
    "compugnámo": "compugnar",
    "compugnámos": "compugnar",
    "compugnáramo": "compugnar",
    "compugnáramos": "compugnar",
    "compugnáreis": "compugnar",
    "compugnásseis": "compugnar",
    "compugnássemos": "compugnar",
    "compugnávamo": "compugnar",
    "compugnávamos": "compugnar",
    "compugnáveis": "compugnar",
    "compulsa": "compulsar",
    "compulsada": "compulsar",
    "compulsadas": "compulsar",
    "compulsado": "compulsar",
    "compulsadora": "compulsador",
    "compulsadoras": "compulsador",
    "compulsadores": "compulsador",
    "compulsados": "compulsar",
    "compulsai": "compulsar",
    "compulsais": "compulsar",
    "compulsam": "compulsar",
    "compulsamentos": "compulsamento",
    "compulsamo": "compulsar",
    "compulsamos": "compulsar",
    "compulsando": "compulsar",
    "compulsara": "compulsar",
    "compulsaram": "compulsar",
    "compulsaras": "compulsar",
    "compulsarde": "compulsar",
    "compulsardes": "compulsar",
    "compulsare": "compulsar",
    "compulsarei": "compulsar",
    "compulsareis": "compulsar",
    "compulsarem": "compulsar",
    "compulsaremos": "compulsar",
    "compulsares": "compulsar",
    "compulsaria": "compulsar",
    "compulsariam": "compulsar",
    "compulsarias": "compulsar",
    "compulsarmo": "compulsar",
    "compulsarmos": "compulsar",
    "compulsará": "compulsar",
    "compulsarás": "compulsar",
    "compulsarão": "compulsar",
    "compulsaríamos": "compulsar",
    "compulsaríeis": "compulsar",
    "compulsas": "compulsar",
    "compulsasse": "compulsar",
    "compulsassem": "compulsar",
    "compulsasses": "compulsar",
    "compulsaste": "compulsar",
    "compulsastes": "compulsar",
    "compulsava": "compulsar",
    "compulsavam": "compulsar",
    "compulsavas": "compulsar",
    "compulsações": "compulsação",
    "compulse": "compulsar",
    "compulsei": "compulsar",
    "compulseis": "compulsar",
    "compulsem": "compulsar",
    "compulsemo": "compulsar",
    "compulsemos": "compulsar",
    "compulses": "compulsar",
    "compulsiva": "compulsivo",
    "compulsivas": "compulsivo",
    "compulsivos": "compulsivo",
    "compulso": "compulsar",
    "compulsou": "compulsar",
    "compulsá": "compulsar",
    "compulsámo": "compulsar",
    "compulsámos": "compulsar",
    "compulsáramo": "compulsar",
    "compulsáramos": "compulsar",
    "compulsárei": "compulsar",
    "compulsáreis": "compulsar",
    "compulsásseis": "compulsar",
    "compulsássemos": "compulsar",
    "compulsávamo": "compulsar",
    "compulsávamos": "compulsar",
    "compulsávei": "compulsar",
    "compulsáveis": "compulsável",
    "compulsória": "compulsório",
    "compulsórias": "compulsório",
    "compulsórios": "compulsório",
    "compulsões": "compulsão",
    "compunge": "compungir",
    "compungem": "compungir",
    "compunges": "compungir",
    "compungi": "compungir",
    "compungia": "compungir",
    "compungiam": "compungir",
    "compungias": "compungir",
    "compungida": "compungir",
    "compungidas": "compungir",
    "compungido": "compungir",
    "compungidos": "compungir",
    "compungimentos": "compungimento",
    "compungimo": "compungir",
    "compungimos": "compungir",
    "compungindo": "compungir",
    "compungira": "compungir",
    "compungiram": "compungir",
    "compungiras": "compungir",
    "compungirde": "compungir",
    "compungirdes": "compungir",
    "compungire": "compungir",
    "compungirei": "compungir",
    "compungireis": "compungir",
    "compungirem": "compungir",
    "compungiremos": "compungir",
    "compungires": "compungir",
    "compungiria": "compungir",
    "compungiriam": "compungir",
    "compungirias": "compungir",
    "compungirmo": "compungir",
    "compungirmos": "compungir",
    "compungirá": "compungir",
    "compungirás": "compungir",
    "compungirão": "compungir",
    "compungiríamos": "compungir",
    "compungiríeis": "compungir",
    "compungis": "compungir",
    "compungisse": "compungir",
    "compungissem": "compungir",
    "compungisses": "compungir",
    "compungiste": "compungir",
    "compungistes": "compungir",
    "compungitiva": "compungitivo",
    "compungitivas": "compungitivo",
    "compungitivos": "compungitivo",
    "compungiu": "compungir",
    "compungíamo": "compungir",
    "compungíamos": "compungir",
    "compungíei": "compungir",
    "compungíeis": "compungir",
    "compungíramo": "compungir",
    "compungíramos": "compungir",
    "compungírei": "compungir",
    "compungíreis": "compungir",
    "compungísseis": "compungir",
    "compungíssemos": "compungir",
    "compunha": "compor",
    "compunham": "compor",
    "compunhas": "compor",
    "compunja": "compungir",
    "compunjais": "compungir",
    "compunjam": "compungir",
    "compunjamo": "compungir",
    "compunjamos": "compungir",
    "compunjas": "compungir",
    "compunjo": "compungir",
    "compunções": "compunção",
    "compurga": "compurgar",
    "compurgada": "compurgar",
    "compurgadas": "compurgar",
    "compurgado": "compurgar",
    "compurgados": "compurgar",
    "compurgai": "compurgar",
    "compurgais": "compurgar",
    "compurgam": "compurgar",
    "compurgamo": "compurgar",
    "compurgamos": "compurgar",
    "compurgando": "compurgar",
    "compurgara": "compurgar",
    "compurgaram": "compurgar",
    "compurgaras": "compurgar",
    "compurgarde": "compurgar",
    "compurgardes": "compurgar",
    "compurgare": "compurgar",
    "compurgarei": "compurgar",
    "compurgareis": "compurgar",
    "compurgarem": "compurgar",
    "compurgaremos": "compurgar",
    "compurgares": "compurgar",
    "compurgaria": "compurgar",
    "compurgariam": "compurgar",
    "compurgarias": "compurgar",
    "compurgarmo": "compurgar",
    "compurgarmos": "compurgar",
    "compurgará": "compurgar",
    "compurgarás": "compurgar",
    "compurgarão": "compurgar",
    "compurgaríamos": "compurgar",
    "compurgaríeis": "compurgar",
    "compurgas": "compurgar",
    "compurgasse": "compurgar",
    "compurgassem": "compurgar",
    "compurgasses": "compurgar",
    "compurgaste": "compurgar",
    "compurgastes": "compurgar",
    "compurgava": "compurgar",
    "compurgavam": "compurgar",
    "compurgavas": "compurgar",
    "compurgações": "compurgação",
    "compurgo": "compurgar",
    "compurgou": "compurgar",
    "compurgue": "compurgar",
    "compurguei": "compurgar",
    "compurgueis": "compurgar",
    "compurguem": "compurgar",
    "compurguemo": "compurgar",
    "compurguemos": "compurgar",
    "compurgues": "compurgar",
    "compurgá": "compurgar",
    "compurgámo": "compurgar",
    "compurgámos": "compurgar",
    "compurgáramo": "compurgar",
    "compurgáramos": "compurgar",
    "compurgárei": "compurgar",
    "compurgáreis": "compurgar",
    "compurgásseis": "compurgar",
    "compurgássemos": "compurgar",
    "compurgávamo": "compurgar",
    "compurgávamos": "compurgar",
    "compurgávei": "compurgar",
    "compurgáveis": "compurgar",
    "compus": "compor",
    "compusemo": "compor",
    "compusemos": "compor",
    "compuser": "compor",
    "compusera": "compor",
    "compuseram": "compor",
    "compuseras": "compor",
    "compuserdes": "compor",
    "compuserem": "compor",
    "compuseres": "compor",
    "compusermos": "compor",
    "compusesse": "compor",
    "compusessem": "compor",
    "compusesses": "compor",
    "compuseste": "compor",
    "compusestes": "compor",
    "compuséramo": "compor",
    "compuséramos": "compor",
    "compusérei": "compor",
    "compuséreis": "compor",
    "compusésseis": "compor",
    "compuséssemos": "compor",
    "computa": "computar",
    "computacionais": "computacional",
    "computada": "computar",
    "computadas": "computar",
    "computado": "computar",
    "computadora": "computador",
    "computadoras": "computador",
    "computadores": "computador",
    "computados": "computar",
    "computai": "computar",
    "computais": "computar",
    "computam": "computar",
    "computamo": "computar",
    "computamos": "computar",
    "computando": "computar",
    "computara": "computar",
    "computaram": "computar",
    "computaras": "computar",
    "computarde": "computar",
    "computardes": "computar",
    "computare": "computar",
    "computarei": "computar",
    "computareis": "computar",
    "computarem": "computar",
    "computaremos": "computar",
    "computares": "computar",
    "computaria": "computar",
    "computariam": "computar",
    "computarias": "computar",
    "computarmo": "computar",
    "computarmos": "computar",
    "computará": "computar",
    "computarás": "computar",
    "computarão": "computar",
    "computaríamos": "computar",
    "computaríeis": "computar",
    "computas": "computar",
    "computasse": "computar",
    "computassem": "computar",
    "computasses": "computar",
    "computaste": "computar",
    "computastes": "computar",
    "computava": "computar",
    "computavam": "computar",
    "computavas": "computar",
    "computações": "computação",
    "compute": "computar",
    "computei": "computar",
    "computeis": "computar",
    "computem": "computar",
    "computemo": "computar",
    "computemos": "computar",
    "computes": "computar",
    "computistas": "computista",
    "computo": "computar",
    "computorizada": "computorizado",
    "computorizadas": "computorizado",
    "computorizados": "computorizado",
    "computou": "computar",
    "computá": "computar",
    "computámo": "computar",
    "computámos": "computar",
    "computáramo": "computar",
    "computáramos": "computar",
    "computárei": "computar",
    "computáreis": "computar",
    "computásseis": "computar",
    "computássemos": "computar",
    "computávamo": "computar",
    "computávamos": "computar",
    "computávei": "computar",
    "computáveis": "computável",
    "compáscuos": "compáscuo",
    "compêndios": "compêndio",
    "compósita": "compósito",
    "compósitas": "compósito",
    "compósitos": "compósito",
    "compô": "compor",
    "compôs": "compor",
    "compõe": "compor",
    "compõem": "compor",
    "compões": "compor",
    "compúnhamo": "compor",
    "compúnhamos": "compor",
    "compúnhei": "compor",
    "compúnheis": "compor",
    "comtesca": "comtesco",
    "comtescas": "comtesco",
    "comtescos": "comtesco",
    "comtiana": "comtiano",
    "comtianas": "comtiano",
    "comtianos": "comtiano",
    "comtistas": "comtista",
    "comunais": "comunal",
    "comunalismos": "comunalismo",
    "comunalistas": "comunalista",
    "comunas": "comuna",
    "comuneira": "comuneiro",
    "comuneiras": "comuneiro",
    "comuneiros": "comuneiro",
    "comunga": "comungar",
    "comungada": "comungar",
    "comungadas": "comungar",
    "comungado": "comungar",
    "comungados": "comungar",
    "comungai": "comungar",
    "comungais": "comungar",
    "comungam": "comungar",
    "comungamo": "comungar",
    "comungamos": "comungar",
    "comungando": "comungar",
    "comungantes": "comungante",
    "comungara": "comungar",
    "comungaram": "comungar",
    "comungaras": "comungar",
    "comungarde": "comungar",
    "comungardes": "comungar",
    "comungare": "comungar",
    "comungarei": "comungar",
    "comungareis": "comungar",
    "comungarem": "comungar",
    "comungaremos": "comungar",
    "comungares": "comungar",
    "comungaria": "comungar",
    "comungariam": "comungar",
    "comungarias": "comungar",
    "comungarmo": "comungar",
    "comungarmos": "comungar",
    "comungará": "comungar",
    "comungarás": "comungar",
    "comungarão": "comungar",
    "comungaríamos": "comungar",
    "comungaríeis": "comungar",
    "comungas": "comungar",
    "comungasse": "comungar",
    "comungassem": "comungar",
    "comungasses": "comungar",
    "comungaste": "comungar",
    "comungastes": "comungar",
    "comungava": "comungar",
    "comungavam": "comungar",
    "comungavas": "comungar",
    "comungo": "comungar",
    "comungou": "comungar",
    "comungue": "comungar",
    "comunguei": "comungar",
    "comungueis": "comungar",
    "comunguem": "comungar",
    "comunguemo": "comungar",
    "comunguemos": "comungar",
    "comungues": "comungar",
    "comungá": "comungar",
    "comungámo": "comungar",
    "comungámos": "comungar",
    "comungáramo": "comungar",
    "comungáramos": "comungar",
    "comungárei": "comungar",
    "comungáreis": "comungar",
    "comungásseis": "comungar",
    "comungássemos": "comungar",
    "comungávamo": "comungar",
    "comungávamos": "comungar",
    "comungávei": "comungar",
    "comungáveis": "comungar",
    "comunhões": "comunhão",
    "comuniais": "comunial",
    "comunica": "comunicar",
    "comunicabilidades": "comunicabilidade",
    "comunicacionais": "comunicacional",
    "comunicada": "comunicar",
    "comunicadas": "comunicar",
    "comunicado": "comunicar",
    "comunicadora": "comunicador",
    "comunicadoras": "comunicador",
    "comunicadores": "comunicador",
    "comunicados": "comunicar",
    "comunicai": "comunicar",
    "comunicais": "comunicar",
    "comunicam": "comunicar",
    "comunicamo": "comunicar",
    "comunicamos": "comunicar",
    "comunicando": "comunicar",
    "comunicantes": "comunicante",
    "comunicara": "comunicar",
    "comunicaram": "comunicar",
    "comunicaras": "comunicar",
    "comunicarde": "comunicar",
    "comunicardes": "comunicar",
    "comunicare": "comunicar",
    "comunicarei": "comunicar",
    "comunicareis": "comunicar",
    "comunicarem": "comunicar",
    "comunicaremos": "comunicar",
    "comunicares": "comunicar",
    "comunicaria": "comunicar",
    "comunicariam": "comunicar",
    "comunicarias": "comunicar",
    "comunicarmo": "comunicar",
    "comunicarmos": "comunicar",
    "comunicará": "comunicar",
    "comunicarás": "comunicar",
    "comunicarão": "comunicar",
    "comunicaríamos": "comunicar",
    "comunicaríeis": "comunicar",
    "comunicas": "comunicar",
    "comunicasse": "comunicar",
    "comunicassem": "comunicar",
    "comunicasses": "comunicar",
    "comunicaste": "comunicar",
    "comunicastes": "comunicar",
    "comunicativa": "comunicativo",
    "comunicativas": "comunicativo",
    "comunicativos": "comunicativo",
    "comunicava": "comunicar",
    "comunicavam": "comunicar",
    "comunicavas": "comunicar",
    "comunicações": "comunicação",
    "comunico": "comunicar",
    "comunicou": "comunicar",
    "comunicá": "comunicar",
    "comunicámo": "comunicar",
    "comunicámos": "comunicar",
    "comunicáramo": "comunicar",
    "comunicáramos": "comunicar",
    "comunicárei": "comunicar",
    "comunicáreis": "comunicar",
    "comunicásseis": "comunicar",
    "comunicássemos": "comunicar",
    "comunicávamo": "comunicar",
    "comunicávamos": "comunicar",
    "comunicávei": "comunicar",
    "comunicáveis": "comunicável",
    "comunidades": "comunidade",
    "comunique": "comunicar",
    "comuniquei": "comunicar",
    "comuniqueis": "comunicar",
    "comuniquem": "comunicar",
    "comuniquemo": "comunicar",
    "comuniquemos": "comunicar",
    "comuniques": "comunicar",
    "comunismos": "comunismo",
    "comunistas": "comunista",
    "comunitarismos": "comunitarismo",
    "comunitária": "comunitário",
    "comunitárias": "comunitário",
    "comunitários": "comunitário",
    "comuniza": "comunizar",
    "comunizada": "comunizar",
    "comunizadas": "comunizar",
    "comunizado": "comunizar",
    "comunizados": "comunizar",
    "comunizai": "comunizar",
    "comunizais": "comunizar",
    "comunizam": "comunizar",
    "comunizamo": "comunizar",
    "comunizamos": "comunizar",
    "comunizando": "comunizar",
    "comunizara": "comunizar",
    "comunizaram": "comunizar",
    "comunizaras": "comunizar",
    "comunizarde": "comunizar",
    "comunizardes": "comunizar",
    "comunizare": "comunizar",
    "comunizarei": "comunizar",
    "comunizareis": "comunizar",
    "comunizarem": "comunizar",
    "comunizaremos": "comunizar",
    "comunizares": "comunizar",
    "comunizaria": "comunizar",
    "comunizariam": "comunizar",
    "comunizarias": "comunizar",
    "comunizarmo": "comunizar",
    "comunizarmos": "comunizar",
    "comunizará": "comunizar",
    "comunizarás": "comunizar",
    "comunizarão": "comunizar",
    "comunizaríamos": "comunizar",
    "comunizaríeis": "comunizar",
    "comunizas": "comunizar",
    "comunizasse": "comunizar",
    "comunizassem": "comunizar",
    "comunizasses": "comunizar",
    "comunizaste": "comunizar",
    "comunizastes": "comunizar",
    "comunizava": "comunizar",
    "comunizavam": "comunizar",
    "comunizavas": "comunizar",
    "comunize": "comunizar",
    "comunizei": "comunizar",
    "comunizeis": "comunizar",
    "comunizem": "comunizar",
    "comunizemo": "comunizar",
    "comunizemos": "comunizar",
    "comunizes": "comunizar",
    "comunizo": "comunizar",
    "comunizou": "comunizar",
    "comunizá": "comunizar",
    "comunizámo": "comunizar",
    "comunizámos": "comunizar",
    "comunizáramo": "comunizar",
    "comunizáramos": "comunizar",
    "comunizárei": "comunizar",
    "comunizáreis": "comunizar",
    "comunizásseis": "comunizar",
    "comunizássemos": "comunizar",
    "comunizávamo": "comunizar",
    "comunizávamos": "comunizar",
    "comunizávei": "comunizar",
    "comunizáveis": "comunizável",
    "comuns": "comum",
    "comuta": "comutar",
    "comutabilidades": "comutabilidade",
    "comutada": "comutar",
    "comutadas": "comutar",
    "comutado": "comutar",
    "comutadora": "comutador",
    "comutadoras": "comutador",
    "comutadores": "comutador",
    "comutados": "comutar",
    "comutai": "comutar",
    "comutais": "comutar",
    "comutam": "comutar",
    "comutamo": "comutar",
    "comutamos": "comutar",
    "comutando": "comutar",
    "comutara": "comutar",
    "comutaram": "comutar",
    "comutaras": "comutar",
    "comutarde": "comutar",
    "comutardes": "comutar",
    "comutare": "comutar",
    "comutarei": "comutar",
    "comutareis": "comutar",
    "comutarem": "comutar",
    "comutaremos": "comutar",
    "comutares": "comutar",
    "comutaria": "comutar",
    "comutariam": "comutar",
    "comutarias": "comutar",
    "comutarmo": "comutar",
    "comutarmos": "comutar",
    "comutará": "comutar",
    "comutarás": "comutar",
    "comutarão": "comutar",
    "comutaríamos": "comutar",
    "comutaríeis": "comutar",
    "comutas": "comutar",
    "comutasse": "comutar",
    "comutassem": "comutar",
    "comutasses": "comutar",
    "comutaste": "comutar",
    "comutastes": "comutar",
    "comutativa": "comutativo",
    "comutativas": "comutativo",
    "comutatividades": "comutatividade",
    "comutativos": "comutativo",
    "comutatrizes": "comutatriz",
    "comutava": "comutar",
    "comutavam": "comutar",
    "comutavas": "comutar",
    "comutações": "comutação",
    "comute": "comutar",
    "comutei": "comutar",
    "comuteis": "comutar",
    "comutem": "comutar",
    "comutemo": "comutar",
    "comutemos": "comutar",
    "comutes": "comutar",
    "comuto": "comutar",
    "comutou": "comutar",
    "comutá": "comutar",
    "comutámo": "comutar",
    "comutámos": "comutar",
    "comutáramo": "comutar",
    "comutáramos": "comutar",
    "comutárei": "comutar",
    "comutáreis": "comutar",
    "comutásseis": "comutar",
    "comutássemos": "comutar",
    "comutávamo": "comutar",
    "comutávamos": "comutar",
    "comutávei": "comutar",
    "comutáveis": "comutável",
    "comátulas": "comátula",
    "comédias": "comédia",
    "comércios": "comércio",
    "comê": "comer",
    "comêramo": "comer",
    "comêramos": "comer",
    "comêrei": "comer",
    "comêreis": "comer",
    "comêsseis": "comer",
    "comêssemos": "comer",
    "comíamo": "comer",
    "comíamos": "comer",
    "comícios": "comício",
    "comíei": "comer",
    "comíeis": "comer",
    "comíveis": "comível",
    "conas": "cona",
    "conatos": "conato",
    "conaturais": "conatural",
    "conaturalidades": "conaturalidade",
    "conações": "conação",
    "concamerações": "concameração",
    "concanis": "concani",
    "concas": "conca",
    "concatena": "concatenar",
    "concatenada": "concatenar",
    "concatenadas": "concatenar",
    "concatenado": "concatenar",
    "concatenadora": "concatenador",
    "concatenadoras": "concatenador",
    "concatenadores": "concatenador",
    "concatenados": "concatenar",
    "concatenai": "concatenar",
    "concatenais": "concatenar",
    "concatenam": "concatenar",
    "concatenamentos": "concatenamento",
    "concatenamo": "concatenar",
    "concatenamos": "concatenar",
    "concatenando": "concatenar",
    "concatenara": "concatenar",
    "concatenaram": "concatenar",
    "concatenaras": "concatenar",
    "concatenarde": "concatenar",
    "concatenardes": "concatenar",
    "concatenare": "concatenar",
    "concatenarei": "concatenar",
    "concatenareis": "concatenar",
    "concatenarem": "concatenar",
    "concatenaremos": "concatenar",
    "concatenares": "concatenar",
    "concatenaria": "concatenar",
    "concatenariam": "concatenar",
    "concatenarias": "concatenar",
    "concatenarmo": "concatenar",
    "concatenarmos": "concatenar",
    "concatenará": "concatenar",
    "concatenarás": "concatenar",
    "concatenarão": "concatenar",
    "concatenaríamos": "concatenar",
    "concatenaríeis": "concatenar",
    "concatenas": "concatenar",
    "concatenasse": "concatenar",
    "concatenassem": "concatenar",
    "concatenasses": "concatenar",
    "concatenaste": "concatenar",
    "concatenastes": "concatenar",
    "concatenava": "concatenar",
    "concatenavam": "concatenar",
    "concatenavas": "concatenar",
    "concatenações": "concatenação",
    "concatene": "concatenar",
    "concatenei": "concatenar",
    "concateneis": "concatenar",
    "concatenem": "concatenar",
    "concatenemo": "concatenar",
    "concatenemos": "concatenar",
    "concatenes": "concatenar",
    "concateno": "concatenar",
    "concatenou": "concatenar",
    "concatená": "concatenar",
    "concatenámo": "concatenar",
    "concatenámos": "concatenar",
    "concatenáramo": "concatenar",
    "concatenáramos": "concatenar",
    "concatenárei": "concatenar",
    "concatenáreis": "concatenar",
    "concatenásseis": "concatenar",
    "concatenássemos": "concatenar",
    "concatenávamo": "concatenar",
    "concatenávamos": "concatenar",
    "concatenávei": "concatenar",
    "concatenáveis": "concatenar",
    "concava": "concavar",
    "concavada": "concavar",
    "concavadas": "concavar",
    "concavado": "concavar",
    "concavados": "concavar",
    "concavai": "concavar",
    "concavais": "concavar",
    "concavam": "concavar",
    "concavamo": "concavar",
    "concavamos": "concavar",
    "concavando": "concavar",
    "concavara": "concavar",
    "concavaram": "concavar",
    "concavaras": "concavar",
    "concavarde": "concavar",
    "concavardes": "concavar",
    "concavare": "concavar",
    "concavarei": "concavar",
    "concavareis": "concavar",
    "concavarem": "concavar",
    "concavaremos": "concavar",
    "concavares": "concavar",
    "concavaria": "concavar",
    "concavariam": "concavar",
    "concavarias": "concavar",
    "concavarmo": "concavar",
    "concavarmos": "concavar",
    "concavará": "concavar",
    "concavarás": "concavar",
    "concavarão": "concavar",
    "concavaríamos": "concavar",
    "concavaríeis": "concavar",
    "concavas": "concavar",
    "concavasse": "concavar",
    "concavassem": "concavar",
    "concavasses": "concavar",
    "concavaste": "concavar",
    "concavastes": "concavar",
    "concavava": "concavar",
    "concavavam": "concavar",
    "concavavas": "concavar",
    "concave": "concavar",
    "concavei": "concavar",
    "concaveis": "concavar",
    "concavem": "concavar",
    "concavemo": "concavar",
    "concavemos": "concavar",
    "concaves": "concavar",
    "concavidades": "concavidade",
    "concavo": "concavar",
    "concavou": "concavar",
    "concavá": "concavar",
    "concavámo": "concavar",
    "concavámos": "concavar",
    "concaváramo": "concavar",
    "concaváramos": "concavar",
    "concavárei": "concavar",
    "concaváreis": "concavar",
    "concavásseis": "concavar",
    "concavássemos": "concavar",
    "concavávamo": "concavar",
    "concavávamos": "concavar",
    "concavávei": "concavar",
    "concaváveis": "concavar",
    "conceba": "conceber",
    "concebais": "conceber",
    "concebam": "conceber",
    "concebamo": "conceber",
    "concebamos": "conceber",
    "concebas": "conceber",
    "concebe": "conceber",
    "concebei": "conceber",
    "concebeis": "conceber",
    "concebem": "conceber",
    "concebemo": "conceber",
    "concebemos": "conceber",
    "concebendo": "conceber",
    "concebera": "conceber",
    "conceberam": "conceber",
    "conceberas": "conceber",
    "conceberde": "conceber",
    "conceberdes": "conceber",
    "concebere": "conceber",
    "conceberei": "conceber",
    "concebereis": "conceber",
    "conceberem": "conceber",
    "conceberemos": "conceber",
    "conceberes": "conceber",
    "conceberia": "conceber",
    "conceberiam": "conceber",
    "conceberias": "conceber",
    "concebermo": "conceber",
    "concebermos": "conceber",
    "conceberá": "conceber",
    "conceberás": "conceber",
    "conceberão": "conceber",
    "conceberíamos": "conceber",
    "conceberíeis": "conceber",
    "concebes": "conceber",
    "concebesse": "conceber",
    "concebessem": "conceber",
    "concebesses": "conceber",
    "concebeste": "conceber",
    "concebestes": "conceber",
    "concebeu": "conceber",
    "concebi": "conceber",
    "concebia": "conceber",
    "concebiam": "conceber",
    "concebias": "conceber",
    "concebida": "concebido",
    "concebidas": "concebido",
    "concebido": "conceber",
    "concebidos": "concebido",
    "concebo": "conceber",
    "concebê": "conceber",
    "concebêramo": "conceber",
    "concebêramos": "conceber",
    "concebêrei": "conceber",
    "concebêreis": "conceber",
    "concebêsseis": "conceber",
    "concebêssemos": "conceber",
    "concebíamo": "conceber",
    "concebíamos": "conceber",
    "concebíei": "conceber",
    "concebíeis": "conceber",
    "concebíveis": "concebível",
    "conceda": "conceder",
    "concedais": "conceder",
    "concedam": "conceder",
    "concedamo": "conceder",
    "concedamos": "conceder",
    "concedas": "conceder",
    "concede": "conceder",
    "concedei": "conceder",
    "concedeis": "conceder",
    "concedem": "conceder",
    "concedemo": "conceder",
    "concedemos": "conceder",
    "concedendo": "conceder",
    "concedentes": "concedente",
    "concedera": "conceder",
    "concederam": "conceder",
    "concederas": "conceder",
    "concederde": "conceder",
    "concederdes": "conceder",
    "concedere": "conceder",
    "concederei": "conceder",
    "concedereis": "conceder",
    "concederem": "conceder",
    "concederemos": "conceder",
    "concederes": "conceder",
    "concederia": "conceder",
    "concederiam": "conceder",
    "concederias": "conceder",
    "concedermo": "conceder",
    "concedermos": "conceder",
    "concederá": "conceder",
    "concederás": "conceder",
    "concederão": "conceder",
    "concederíamos": "conceder",
    "concederíeis": "conceder",
    "concedes": "conceder",
    "concedesse": "conceder",
    "concedessem": "conceder",
    "concedesses": "conceder",
    "concedeste": "conceder",
    "concedestes": "conceder",
    "concedeu": "conceder",
    "concedi": "conceder",
    "concedia": "conceder",
    "concediam": "conceder",
    "concedias": "conceder",
    "concedida": "concedido",
    "concedidas": "concedido",
    "concedido": "conceder",
    "concedidos": "concedido",
    "concedimentos": "concedimento",
    "concedo": "conceder",
    "concedê": "conceder",
    "concedêramo": "conceder",
    "concedêramos": "conceder",
    "concedêrei": "conceder",
    "concedêreis": "conceder",
    "concedêsseis": "conceder",
    "concedêssemos": "conceder",
    "concedíamo": "conceder",
    "concedíamos": "conceder",
    "concedíei": "conceder",
    "concedíeis": "conceder",
    "concedíveis": "concedível",
    "conceitistas": "conceitista",
    "conceitos": "conceito",
    "conceitua": "conceituar",
    "conceituada": "conceituar",
    "conceituadas": "conceituar",
    "conceituado": "conceituar",
    "conceituados": "conceituar",
    "conceituadíssima": "conceituado",
    "conceituadíssimas": "conceituado",
    "conceituadíssimo": "conceituado",
    "conceituadíssimos": "conceituado",
    "conceituai": "conceituar",
    "conceituais": "conceituar",
    "conceituam": "conceituar",
    "conceituamo": "conceituar",
    "conceituamos": "conceituar",
    "conceituando": "conceituar",
    "conceituara": "conceituar",
    "conceituaram": "conceituar",
    "conceituaras": "conceituar",
    "conceituarde": "conceituar",
    "conceituardes": "conceituar",
    "conceituare": "conceituar",
    "conceituarei": "conceituar",
    "conceituareis": "conceituar",
    "conceituarem": "conceituar",
    "conceituaremos": "conceituar",
    "conceituares": "conceituar",
    "conceituaria": "conceituar",
    "conceituariam": "conceituar",
    "conceituarias": "conceituar",
    "conceituarmo": "conceituar",
    "conceituarmos": "conceituar",
    "conceituará": "conceituar",
    "conceituarás": "conceituar",
    "conceituarão": "conceituar",
    "conceituaríamos": "conceituar",
    "conceituaríeis": "conceituar",
    "conceituas": "conceituar",
    "conceituasse": "conceituar",
    "conceituassem": "conceituar",
    "conceituasses": "conceituar",
    "conceituaste": "conceituar",
    "conceituastes": "conceituar",
    "conceituava": "conceituar",
    "conceituavam": "conceituar",
    "conceituavas": "conceituar",
    "conceitue": "conceituar",
    "conceituei": "conceituar",
    "conceitueis": "conceituar",
    "conceituem": "conceituar",
    "conceituemo": "conceituar",
    "conceituemos": "conceituar",
    "conceitues": "conceituar",
    "conceituo": "conceituar",
    "conceituosa": "conceituoso",
    "conceituosas": "conceituoso",
    "conceituosos": "conceituoso",
    "conceituou": "conceituar",
    "conceituá": "conceituar",
    "conceituámo": "conceituar",
    "conceituámos": "conceituar",
    "conceituáramo": "conceituar",
    "conceituáramos": "conceituar",
    "conceituárei": "conceituar",
    "conceituáreis": "conceituar",
    "conceituásseis": "conceituar",
    "conceituássemos": "conceituar",
    "conceituávamo": "conceituar",
    "conceituávamos": "conceituar",
    "conceituávei": "conceituar",
    "conceituáveis": "conceituar",
    "conceições": "conceição",
    "concelebra": "concelebrar",
    "concelebrada": "concelebrar",
    "concelebradas": "concelebrar",
    "concelebrado": "concelebrar",
    "concelebrados": "concelebrar",
    "concelebrai": "concelebrar",
    "concelebrais": "concelebrar",
    "concelebram": "concelebrar",
    "concelebramo": "concelebrar",
    "concelebramos": "concelebrar",
    "concelebrando": "concelebrar",
    "concelebrantes": "concelebrante",
    "concelebrara": "concelebrar",
    "concelebraram": "concelebrar",
    "concelebraras": "concelebrar",
    "concelebrarde": "concelebrar",
    "concelebrardes": "concelebrar",
    "concelebrare": "concelebrar",
    "concelebrarei": "concelebrar",
    "concelebrareis": "concelebrar",
    "concelebrarem": "concelebrar",
    "concelebraremos": "concelebrar",
    "concelebrares": "concelebrar",
    "concelebraria": "concelebrar",
    "concelebrariam": "concelebrar",
    "concelebrarias": "concelebrar",
    "concelebrarmo": "concelebrar",
    "concelebrarmos": "concelebrar",
    "concelebrará": "concelebrar",
    "concelebrarás": "concelebrar",
    "concelebrarão": "concelebrar",
    "concelebraríamos": "concelebrar",
    "concelebraríeis": "concelebrar",
    "concelebras": "concelebrar",
    "concelebrasse": "concelebrar",
    "concelebrassem": "concelebrar",
    "concelebrasses": "concelebrar",
    "concelebraste": "concelebrar",
    "concelebrastes": "concelebrar",
    "concelebrava": "concelebrar",
    "concelebravam": "concelebrar",
    "concelebravas": "concelebrar",
    "concelebrações": "concelebração",
    "concelebre": "concelebrar",
    "concelebrei": "concelebrar",
    "concelebreis": "concelebrar",
    "concelebrem": "concelebrar",
    "concelebremo": "concelebrar",
    "concelebremos": "concelebrar",
    "concelebres": "concelebrar",
    "concelebro": "concelebrar",
    "concelebrou": "concelebrar",
    "concelebrá": "concelebrar",
    "concelebrámo": "concelebrar",
    "concelebrámos": "concelebrar",
    "concelebráramo": "concelebrar",
    "concelebráramos": "concelebrar",
    "concelebrárei": "concelebrar",
    "concelebráreis": "concelebrar",
    "concelebrásseis": "concelebrar",
    "concelebrássemos": "concelebrar",
    "concelebrávamo": "concelebrar",
    "concelebrávamos": "concelebrar",
    "concelebrávei": "concelebrar",
    "concelebráveis": "concelebrar",
    "concelheira": "concelheiro",
    "concelheiras": "concelheiro",
    "concelheiros": "concelheiro",
    "concelhia": "concelhio",
    "concelhias": "concelhio",
    "concelhios": "concelhio",
    "concelhos": "concelho",
    "concentra": "concentrar",
    "concentracionária": "concentracionário",
    "concentracionárias": "concentracionário",
    "concentracionários": "concentracionário",
    "concentrada": "concentrar",
    "concentradas": "concentrar",
    "concentrado": "concentrar",
    "concentradora": "concentrador",
    "concentradoras": "concentrador",
    "concentradores": "concentrador",
    "concentrados": "concentrar",
    "concentradíssima": "concentrado",
    "concentradíssimas": "concentrado",
    "concentradíssimo": "concentrado",
    "concentradíssimos": "concentrado",
    "concentrai": "concentrar",
    "concentrais": "concentrar",
    "concentralizada": "concentralizado",
    "concentralizadas": "concentralizado",
    "concentralizados": "concentralizado",
    "concentralizações": "concentralização",
    "concentram": "concentrar",
    "concentramo": "concentrar",
    "concentramos": "concentrar",
    "concentrando": "concentrar",
    "concentrara": "concentrar",
    "concentraram": "concentrar",
    "concentraras": "concentrar",
    "concentrarde": "concentrar",
    "concentrardes": "concentrar",
    "concentrare": "concentrar",
    "concentrarei": "concentrar",
    "concentrareis": "concentrar",
    "concentrarem": "concentrar",
    "concentraremos": "concentrar",
    "concentrares": "concentrar",
    "concentraria": "concentrar",
    "concentrariam": "concentrar",
    "concentrarias": "concentrar",
    "concentrarmo": "concentrar",
    "concentrarmos": "concentrar",
    "concentrará": "concentrar",
    "concentrarás": "concentrar",
    "concentrarão": "concentrar",
    "concentraríamos": "concentrar",
    "concentraríeis": "concentrar",
    "concentras": "concentrar",
    "concentrasse": "concentrar",
    "concentrassem": "concentrar",
    "concentrasses": "concentrar",
    "concentraste": "concentrar",
    "concentrastes": "concentrar",
    "concentrava": "concentrar",
    "concentravam": "concentrar",
    "concentravas": "concentrar",
    "concentrações": "concentração",
    "concentre": "concentrar",
    "concentrei": "concentrar",
    "concentreis": "concentrar",
    "concentrem": "concentrar",
    "concentremo": "concentrar",
    "concentremos": "concentrar",
    "concentres": "concentrar",
    "concentricidades": "concentricidade",
    "concentrismos": "concentrismo",
    "concentristas": "concentrista",
    "concentro": "concentrar",
    "concentrou": "concentrar",
    "concentrá": "concentrar",
    "concentrámo": "concentrar",
    "concentrámos": "concentrar",
    "concentráramo": "concentrar",
    "concentráramos": "concentrar",
    "concentrárei": "concentrar",
    "concentráreis": "concentrar",
    "concentrásseis": "concentrar",
    "concentrássemos": "concentrar",
    "concentrávamo": "concentrar",
    "concentrávamos": "concentrar",
    "concentrávei": "concentrar",
    "concentráveis": "concentrável",
    "concepcionais": "concepcional",
    "concepcionistas": "concepcionista",
    "concepcionária": "concepcionário",
    "concepcionárias": "concepcionário",
    "concepcionários": "concepcionário",
    "conceptibilidades": "conceptibilidade",
    "conceptismos": "conceptismo",
    "conceptistas": "conceptista",
    "conceptiva": "conceptivo",
    "conceptivas": "conceptivo",
    "conceptivos": "conceptivo",
    "conceptuais": "conceptual",
    "conceptualismos": "conceptualismo",
    "conceptualistas": "conceptualista",
    "conceptualizações": "conceptualização",
    "conceptáculos": "conceptáculo",
    "conceptíveis": "conceptível",
    "concepções": "concepção",
    "concerne": "concernir",
    "concernem": "concernir",
    "concernentes": "concernente",
    "concernes": "concernir",
    "concerni": "concernir",
    "concernia": "concernir",
    "concerniam": "concernir",
    "concernias": "concernir",
    "concernida": "concernir",
    "concernidas": "concernir",
    "concernido": "concernir",
    "concernidos": "concernir",
    "concernimo": "concernir",
    "concernimos": "concernir",
    "concernindo": "concernir",
    "concernira": "concernir",
    "concerniram": "concernir",
    "concerniras": "concernir",
    "concernirde": "concernir",
    "concernirdes": "concernir",
    "concernire": "concernir",
    "concernirei": "concernir",
    "concernireis": "concernir",
    "concernirem": "concernir",
    "concerniremos": "concernir",
    "concernires": "concernir",
    "concerniria": "concernir",
    "concerniriam": "concernir",
    "concernirias": "concernir",
    "concernirmo": "concernir",
    "concernirmos": "concernir",
    "concernirá": "concernir",
    "concernirás": "concernir",
    "concernirão": "concernir",
    "concerniríamos": "concernir",
    "concerniríeis": "concernir",
    "concernis": "concernir",
    "concernisse": "concernir",
    "concernissem": "concernir",
    "concernisses": "concernir",
    "concerniste": "concernir",
    "concernistes": "concernir",
    "concerniu": "concernir",
    "concernências": "concernência",
    "concerníamo": "concernir",
    "concerníamos": "concernir",
    "concerníei": "concernir",
    "concerníeis": "concernir",
    "concerníramo": "concernir",
    "concerníramos": "concernir",
    "concernírei": "concernir",
    "concerníreis": "concernir",
    "concernísseis": "concernir",
    "concerníssemos": "concernir",
    "concerta": "concertar",
    "concertada": "concertar",
    "concertadas": "concertar",
    "concertado": "concertar",
    "concertadora": "concertador",
    "concertadoras": "concertador",
    "concertadores": "concertador",
    "concertados": "concertar",
    "concertai": "concertar",
    "concertais": "concertar",
    "concertam": "concertar",
    "concertamo": "concertar",
    "concertamos": "concertar",
    "concertando": "concertar",
    "concertantes": "concertante",
    "concertara": "concertar",
    "concertaram": "concertar",
    "concertaras": "concertar",
    "concertarde": "concertar",
    "concertardes": "concertar",
    "concertare": "concertar",
    "concertarei": "concertar",
    "concertareis": "concertar",
    "concertarem": "concertar",
    "concertaremos": "concertar",
    "concertares": "concertar",
    "concertaria": "concertar",
    "concertariam": "concertar",
    "concertarias": "concertar",
    "concertarmo": "concertar",
    "concertarmos": "concertar",
    "concertará": "concertar",
    "concertarás": "concertar",
    "concertarão": "concertar",
    "concertaríamos": "concertar",
    "concertaríeis": "concertar",
    "concertas": "concertar",
    "concertasse": "concertar",
    "concertassem": "concertar",
    "concertasses": "concertar",
    "concertaste": "concertar",
    "concertastes": "concertar",
    "concertava": "concertar",
    "concertavam": "concertar",
    "concertavas": "concertar",
    "concertações": "concertação",
    "concerte": "concertar",
    "concertei": "concertar",
    "concerteis": "concertar",
    "concertem": "concertar",
    "concertemo": "concertar",
    "concertemos": "concertar",
    "concertes": "concertar",
    "concertinas": "concertina",
    "concertinos": "concertino",
    "concertistas": "concertista",
    "concerto": "concertar",
    "concertos": "concerto",
    "concertou": "concertar",
    "concertá": "concertar",
    "concertámo": "concertar",
    "concertámos": "concertar",
    "concertáramo": "concertar",
    "concertáramos": "concertar",
    "concertárei": "concertar",
    "concertáreis": "concertar",
    "concertásseis": "concertar",
    "concertássemos": "concertar",
    "concertávamo": "concertar",
    "concertávamos": "concertar",
    "concertávei": "concertar",
    "concertáveis": "concertar",
    "concessiona": "concessionar",
    "concessionada": "concessionar",
    "concessionadas": "concessionar",
    "concessionado": "concessionar",
    "concessionados": "concessionar",
    "concessionai": "concessionar",
    "concessionais": "concessionar",
    "concessionam": "concessionar",
    "concessionamo": "concessionar",
    "concessionamos": "concessionar",
    "concessionando": "concessionar",
    "concessionara": "concessionar",
    "concessionaram": "concessionar",
    "concessionaras": "concessionar",
    "concessionarde": "concessionar",
    "concessionardes": "concessionar",
    "concessionare": "concessionar",
    "concessionarei": "concessionar",
    "concessionareis": "concessionar",
    "concessionarem": "concessionar",
    "concessionaremos": "concessionar",
    "concessionares": "concessionar",
    "concessionaria": "concessionar",
    "concessionariam": "concessionar",
    "concessionarias": "concessionar",
    "concessionarmo": "concessionar",
    "concessionarmos": "concessionar",
    "concessionará": "concessionar",
    "concessionarás": "concessionar",
    "concessionarão": "concessionar",
    "concessionaríamos": "concessionar",
    "concessionaríeis": "concessionar",
    "concessionas": "concessionar",
    "concessionasse": "concessionar",
    "concessionassem": "concessionar",
    "concessionasses": "concessionar",
    "concessionaste": "concessionar",
    "concessionastes": "concessionar",
    "concessionava": "concessionar",
    "concessionavam": "concessionar",
    "concessionavas": "concessionar",
    "concessione": "concessionar",
    "concessionei": "concessionar",
    "concessioneis": "concessionar",
    "concessionem": "concessionar",
    "concessionemo": "concessionar",
    "concessionemos": "concessionar",
    "concessiones": "concessionar",
    "concessiono": "concessionar",
    "concessionou": "concessionar",
    "concessioná": "concessionar",
    "concessionámo": "concessionar",
    "concessionámos": "concessionar",
    "concessionáramo": "concessionar",
    "concessionáramos": "concessionar",
    "concessionárei": "concessionar",
    "concessionáreis": "concessionar",
    "concessionária": "concessionário",
    "concessionárias": "concessionário",
    "concessionários": "concessionário",
    "concessionásseis": "concessionar",
    "concessionássemos": "concessionar",
    "concessionávamo": "concessionar",
    "concessionávamos": "concessionar",
    "concessionávei": "concessionar",
    "concessionáveis": "concessionar",
    "concessiva": "concessivo",
    "concessivas": "concessivo",
    "concessivos": "concessivo",
    "concessora": "concessor",
    "concessoras": "concessor",
    "concessores": "concessor",
    "concessíveis": "concessível",
    "concessória": "concessório",
    "concessórias": "concessório",
    "concessórios": "concessório",
    "concessões": "concessão",
    "conchada": "conchado",
    "conchadas": "conchado",
    "conchados": "conchado",
    "concharias": "concharia",
    "conchas": "concha",
    "conchava": "conchavar",
    "conchavada": "conchavar",
    "conchavadas": "conchavar",
    "conchavado": "conchavar",
    "conchavados": "conchavar",
    "conchavai": "conchavar",
    "conchavais": "conchavar",
    "conchavam": "conchavar",
    "conchavamo": "conchavar",
    "conchavamos": "conchavar",
    "conchavando": "conchavar",
    "conchavara": "conchavar",
    "conchavaram": "conchavar",
    "conchavaras": "conchavar",
    "conchavarde": "conchavar",
    "conchavardes": "conchavar",
    "conchavare": "conchavar",
    "conchavarei": "conchavar",
    "conchavareis": "conchavar",
    "conchavarem": "conchavar",
    "conchavaremos": "conchavar",
    "conchavares": "conchavar",
    "conchavaria": "conchavar",
    "conchavariam": "conchavar",
    "conchavarias": "conchavar",
    "conchavarmo": "conchavar",
    "conchavarmos": "conchavar",
    "conchavará": "conchavar",
    "conchavarás": "conchavar",
    "conchavarão": "conchavar",
    "conchavaríamos": "conchavar",
    "conchavaríeis": "conchavar",
    "conchavas": "conchavar",
    "conchavasse": "conchavar",
    "conchavassem": "conchavar",
    "conchavasses": "conchavar",
    "conchavaste": "conchavar",
    "conchavastes": "conchavar",
    "conchavava": "conchavar",
    "conchavavam": "conchavar",
    "conchavavas": "conchavar",
    "conchave": "conchavar",
    "conchavei": "conchavar",
    "conchaveis": "conchavar",
    "conchavem": "conchavar",
    "conchavemo": "conchavar",
    "conchavemos": "conchavar",
    "conchaves": "conchavar",
    "conchavo": "conchavar",
    "conchavos": "conchavo",
    "conchavou": "conchavar",
    "conchavá": "conchavar",
    "conchavámo": "conchavar",
    "conchavámos": "conchavar",
    "conchaváramo": "conchavar",
    "conchaváramos": "conchavar",
    "conchavárei": "conchavar",
    "conchaváreis": "conchavar",
    "conchavásseis": "conchavar",
    "conchavássemos": "conchavar",
    "conchavávamo": "conchavar",
    "conchavávamos": "conchavar",
    "conchavávei": "conchavar",
    "conchaváveis": "conchavar",
    "concheada": "conchear",
    "concheadas": "conchear",
    "concheado": "conchear",
    "concheados": "conchear",
    "concheai": "conchear",
    "concheais": "conchear",
    "concheamo": "conchear",
    "concheamos": "conchear",
    "concheando": "conchear",
    "concheara": "conchear",
    "conchearam": "conchear",
    "conchearas": "conchear",
    "conchearde": "conchear",
    "concheardes": "conchear",
    "concheare": "conchear",
    "conchearei": "conchear",
    "concheareis": "conchear",
    "conchearem": "conchear",
    "conchearemos": "conchear",
    "concheares": "conchear",
    "conchearia": "conchear",
    "concheariam": "conchear",
    "conchearias": "conchear",
    "conchearmo": "conchear",
    "conchearmos": "conchear",
    "concheará": "conchear",
    "conchearás": "conchear",
    "conchearão": "conchear",
    "conchearíamos": "conchear",
    "conchearíeis": "conchear",
    "concheasse": "conchear",
    "concheassem": "conchear",
    "concheasses": "conchear",
    "concheaste": "conchear",
    "concheastes": "conchear",
    "concheava": "conchear",
    "concheavam": "conchear",
    "concheavas": "conchear",
    "concheei": "conchear",
    "concheeis": "conchear",
    "concheemo": "conchear",
    "concheemos": "conchear",
    "conchega": "conchegar",
    "conchegada": "conchegar",
    "conchegadas": "conchegar",
    "conchegado": "conchegar",
    "conchegados": "conchegar",
    "conchegai": "conchegar",
    "conchegais": "conchegar",
    "conchegam": "conchegar",
    "conchegamo": "conchegar",
    "conchegamos": "conchegar",
    "conchegando": "conchegar",
    "conchegara": "conchegar",
    "conchegaram": "conchegar",
    "conchegaras": "conchegar",
    "conchegarde": "conchegar",
    "conchegardes": "conchegar",
    "conchegare": "conchegar",
    "conchegarei": "conchegar",
    "conchegareis": "conchegar",
    "conchegarem": "conchegar",
    "conchegaremos": "conchegar",
    "conchegares": "conchegar",
    "conchegaria": "conchegar",
    "conchegariam": "conchegar",
    "conchegarias": "conchegar",
    "conchegarmo": "conchegar",
    "conchegarmos": "conchegar",
    "conchegará": "conchegar",
    "conchegarás": "conchegar",
    "conchegarão": "conchegar",
    "conchegaríamos": "conchegar",
    "conchegaríeis": "conchegar",
    "conchegas": "conchegar",
    "conchegasse": "conchegar",
    "conchegassem": "conchegar",
    "conchegasses": "conchegar",
    "conchegaste": "conchegar",
    "conchegastes": "conchegar",
    "conchegativa": "conchegativo",
    "conchegativas": "conchegativo",
    "conchegativos": "conchegativo",
    "conchegava": "conchegar",
    "conchegavam": "conchegar",
    "conchegavas": "conchegar",
    "conchego": "conchegar",
    "conchegos": "conchego",
    "conchegou": "conchegar",
    "conchegue": "conchegar",
    "concheguei": "conchegar",
    "conchegueis": "conchegar",
    "concheguem": "conchegar",
    "concheguemo": "conchegar",
    "concheguemos": "conchegar",
    "conchegues": "conchegar",
    "conchegá": "conchegar",
    "conchegámo": "conchegar",
    "conchegámos": "conchegar",
    "conchegáramo": "conchegar",
    "conchegáramos": "conchegar",
    "conchegárei": "conchegar",
    "conchegáreis": "conchegar",
    "conchegásseis": "conchegar",
    "conchegássemos": "conchegar",
    "conchegávamo": "conchegar",
    "conchegávamos": "conchegar",
    "conchegávei": "conchegar",
    "conchegáveis": "conchegar",
    "concheia": "conchear",
    "concheiam": "conchear",
    "concheias": "conchear",
    "concheie": "conchear",
    "concheiem": "conchear",
    "concheies": "conchear",
    "concheio": "conchear",
    "conchelos": "conchelo",
    "concheou": "conchear",
    "concheá": "conchear",
    "concheámo": "conchear",
    "concheámos": "conchear",
    "concheáramo": "conchear",
    "concheáramos": "conchear",
    "concheárei": "conchear",
    "concheáreis": "conchear",
    "concheásseis": "conchear",
    "concheássemos": "conchear",
    "concheávamo": "conchear",
    "concheávamos": "conchear",
    "concheávei": "conchear",
    "concheáveis": "conchear",
    "conchinha": "concha",
    "conchinhas": "concha",
    "conchita": "concha",
    "conchitas": "concha",
    "conchos": "concho",
    "conchuda": "conchudo",
    "conchudas": "conchudo",
    "conchudos": "conchudo",
    "conchífera": "conchífero",
    "conchíferas": "conchífero",
    "conchíferos": "conchífero",
    "concidadanias": "concidadania",
    "concidadã": "concidadão",
    "concidadãos": "concidadão",
    "concidadãs": "concidadão",
    "concilia": "conciliar",
    "conciliada": "conciliar",
    "conciliadas": "conciliar",
    "conciliado": "conciliar",
    "conciliadora": "conciliador",
    "conciliadoras": "conciliador",
    "conciliadores": "conciliador",
    "conciliados": "conciliar",
    "conciliai": "conciliar",
    "conciliais": "conciliar",
    "conciliam": "conciliar",
    "conciliamo": "conciliar",
    "conciliamos": "conciliar",
    "conciliando": "conciliar",
    "conciliantes": "conciliante",
    "conciliara": "conciliar",
    "conciliaram": "conciliar",
    "conciliaras": "conciliar",
    "conciliarde": "conciliar",
    "conciliardes": "conciliar",
    "conciliare": "conciliar",
    "conciliarei": "conciliar",
    "conciliareis": "conciliar",
    "conciliarem": "conciliar",
    "conciliaremos": "conciliar",
    "conciliares": "conciliar",
    "conciliaria": "conciliar",
    "conciliariam": "conciliar",
    "conciliarias": "conciliar",
    "conciliarmo": "conciliar",
    "conciliarmos": "conciliar",
    "conciliará": "conciliar",
    "conciliarás": "conciliar",
    "conciliarão": "conciliar",
    "conciliaríamos": "conciliar",
    "conciliaríeis": "conciliar",
    "concilias": "conciliar",
    "conciliasse": "conciliar",
    "conciliassem": "conciliar",
    "conciliasses": "conciliar",
    "conciliaste": "conciliar",
    "conciliastes": "conciliar",
    "conciliativa": "conciliativo",
    "conciliativas": "conciliativo",
    "conciliativos": "conciliativo",
    "conciliatória": "conciliatório",
    "conciliatórias": "conciliatório",
    "conciliatórios": "conciliatório",
    "conciliava": "conciliar",
    "conciliavam": "conciliar",
    "conciliavas": "conciliar",
    "conciliações": "conciliação",
    "concilie": "conciliar",
    "conciliei": "conciliar",
    "concilieis": "conciliar",
    "conciliem": "conciliar",
    "conciliemo": "conciliar",
    "conciliemos": "conciliar",
    "concilies": "conciliar",
    "concilio": "conciliar",
    "conciliou": "conciliar",
    "conciliá": "conciliar",
    "conciliábulos": "conciliábulo",
    "conciliámo": "conciliar",
    "conciliámos": "conciliar",
    "conciliáramo": "conciliar",
    "conciliáramos": "conciliar",
    "conciliárei": "conciliar",
    "conciliáreis": "conciliar",
    "conciliária": "conciliário",
    "conciliárias": "conciliário",
    "conciliários": "conciliário",
    "conciliásseis": "conciliar",
    "conciliássemos": "conciliar",
    "conciliávamo": "conciliar",
    "conciliávamos": "conciliar",
    "conciliávei": "conciliar",
    "conciliáveis": "conciliável",
    "conciona": "concionar",
    "concionada": "concionar",
    "concionadas": "concionar",
    "concionado": "concionar",
    "concionados": "concionar",
    "concionai": "concionar",
    "concionais": "concionar",
    "concionam": "concionar",
    "concionamo": "concionar",
    "concionamos": "concionar",
    "concionando": "concionar",
    "concionara": "concionar",
    "concionaram": "concionar",
    "concionaras": "concionar",
    "concionarde": "concionar",
    "concionardes": "concionar",
    "concionare": "concionar",
    "concionarei": "concionar",
    "concionareis": "concionar",
    "concionarem": "concionar",
    "concionaremos": "concionar",
    "concionares": "concionar",
    "concionaria": "concionar",
    "concionariam": "concionar",
    "concionarias": "concionar",
    "concionarmo": "concionar",
    "concionarmos": "concionar",
    "concionará": "concionar",
    "concionarás": "concionar",
    "concionarão": "concionar",
    "concionaríamos": "concionar",
    "concionaríeis": "concionar",
    "concionas": "concionar",
    "concionasse": "concionar",
    "concionassem": "concionar",
    "concionasses": "concionar",
    "concionaste": "concionar",
    "concionastes": "concionar",
    "concionatória": "concionatório",
    "concionatórias": "concionatório",
    "concionatórios": "concionatório",
    "concionava": "concionar",
    "concionavam": "concionar",
    "concionavas": "concionar",
    "concione": "concionar",
    "concionei": "concionar",
    "concioneis": "concionar",
    "concionem": "concionar",
    "concionemo": "concionar",
    "concionemos": "concionar",
    "conciones": "concionar",
    "conciono": "concionar",
    "concionou": "concionar",
    "concioná": "concionar",
    "concionámo": "concionar",
    "concionámos": "concionar",
    "concionáramo": "concionar",
    "concionáramos": "concionar",
    "concionárei": "concionar",
    "concionáreis": "concionar",
    "concionária": "concionário",
    "concionárias": "concionário",
    "concionários": "concionário",
    "concionásseis": "concionar",
    "concionássemos": "concionar",
    "concionávamo": "concionar",
    "concionávamos": "concionar",
    "concionávei": "concionar",
    "concionáveis": "concionar",
    "concirna": "concernir",
    "concirnais": "concernir",
    "concirnam": "concernir",
    "concirnamo": "concernir",
    "concirnamos": "concernir",
    "concirnas": "concernir",
    "concirno": "concernir",
    "concisa": "conciso",
    "concisas": "conciso",
    "concisos": "conciso",
    "concisões": "concisão",
    "concita": "concitar",
    "concitada": "concitar",
    "concitadas": "concitar",
    "concitado": "concitar",
    "concitadora": "concitador",
    "concitadoras": "concitador",
    "concitadores": "concitador",
    "concitados": "concitar",
    "concitai": "concitar",
    "concitais": "concitar",
    "concitam": "concitar",
    "concitamo": "concitar",
    "concitamos": "concitar",
    "concitando": "concitar",
    "concitara": "concitar",
    "concitaram": "concitar",
    "concitaras": "concitar",
    "concitarde": "concitar",
    "concitardes": "concitar",
    "concitare": "concitar",
    "concitarei": "concitar",
    "concitareis": "concitar",
    "concitarem": "concitar",
    "concitaremos": "concitar",
    "concitares": "concitar",
    "concitaria": "concitar",
    "concitariam": "concitar",
    "concitarias": "concitar",
    "concitarmo": "concitar",
    "concitarmos": "concitar",
    "concitará": "concitar",
    "concitarás": "concitar",
    "concitarão": "concitar",
    "concitaríamos": "concitar",
    "concitaríeis": "concitar",
    "concitas": "concitar",
    "concitasse": "concitar",
    "concitassem": "concitar",
    "concitasses": "concitar",
    "concitaste": "concitar",
    "concitastes": "concitar",
    "concitativa": "concitativo",
    "concitativas": "concitativo",
    "concitativos": "concitativo",
    "concitava": "concitar",
    "concitavam": "concitar",
    "concitavas": "concitar",
    "concite": "concitar",
    "concitei": "concitar",
    "conciteis": "concitar",
    "concitem": "concitar",
    "concitemo": "concitar",
    "concitemos": "concitar",
    "concites": "concitar",
    "concito": "concitar",
    "concitou": "concitar",
    "concitá": "concitar",
    "concitámo": "concitar",
    "concitámos": "concitar",
    "concitáramo": "concitar",
    "concitáramos": "concitar",
    "concitárei": "concitar",
    "concitáreis": "concitar",
    "concitásseis": "concitar",
    "concitássemos": "concitar",
    "concitávamo": "concitar",
    "concitávamos": "concitar",
    "concitávei": "concitar",
    "concitáveis": "concitar",
    "conclama": "conclamar",
    "conclamada": "conclamar",
    "conclamadas": "conclamar",
    "conclamado": "conclamar",
    "conclamados": "conclamar",
    "conclamai": "conclamar",
    "conclamais": "conclamar",
    "conclamam": "conclamar",
    "conclamamo": "conclamar",
    "conclamamos": "conclamar",
    "conclamando": "conclamar",
    "conclamara": "conclamar",
    "conclamaram": "conclamar",
    "conclamaras": "conclamar",
    "conclamarde": "conclamar",
    "conclamardes": "conclamar",
    "conclamare": "conclamar",
    "conclamarei": "conclamar",
    "conclamareis": "conclamar",
    "conclamarem": "conclamar",
    "conclamaremos": "conclamar",
    "conclamares": "conclamar",
    "conclamaria": "conclamar",
    "conclamariam": "conclamar",
    "conclamarias": "conclamar",
    "conclamarmo": "conclamar",
    "conclamarmos": "conclamar",
    "conclamará": "conclamar",
    "conclamarás": "conclamar",
    "conclamarão": "conclamar",
    "conclamaríamos": "conclamar",
    "conclamaríeis": "conclamar",
    "conclamas": "conclamar",
    "conclamasse": "conclamar",
    "conclamassem": "conclamar",
    "conclamasses": "conclamar",
    "conclamaste": "conclamar",
    "conclamastes": "conclamar",
    "conclamava": "conclamar",
    "conclamavam": "conclamar",
    "conclamavas": "conclamar",
    "conclame": "conclamar",
    "conclamei": "conclamar",
    "conclameis": "conclamar",
    "conclamem": "conclamar",
    "conclamemo": "conclamar",
    "conclamemos": "conclamar",
    "conclames": "conclamar",
    "conclamo": "conclamar",
    "conclamou": "conclamar",
    "conclamá": "conclamar",
    "conclamámo": "conclamar",
    "conclamámos": "conclamar",
    "conclamáramo": "conclamar",
    "conclamáramos": "conclamar",
    "conclamárei": "conclamar",
    "conclamáreis": "conclamar",
    "conclamásseis": "conclamar",
    "conclamássemos": "conclamar",
    "conclamávamo": "conclamar",
    "conclamávamos": "conclamar",
    "conclamávei": "conclamar",
    "conclamáveis": "conclamar",
    "conclaves": "conclave",
    "conclavistas": "conclavista",
    "conclua": "concluir",
    "concluais": "concluir",
    "concluam": "concluir",
    "concluamo": "concluir",
    "concluamos": "concluir",
    "concluas": "concluir",
    "concludentes": "concludente",
    "concludências": "concludência",
    "concluem": "concluir",
    "conclui": "concluir",
    "concluindo": "concluir",
    "concluirde": "concluir",
    "concluirdes": "concluir",
    "concluirei": "concluir",
    "concluireis": "concluir",
    "concluiremos": "concluir",
    "concluiria": "concluir",
    "concluiriam": "concluir",
    "concluirias": "concluir",
    "concluirmo": "concluir",
    "concluirmos": "concluir",
    "concluirá": "concluir",
    "concluirás": "concluir",
    "concluirão": "concluir",
    "concluiríamos": "concluir",
    "concluiríeis": "concluir",
    "concluis": "concluir",
    "concluiu": "concluir",
    "concluo": "concluir",
    "conclusa": "concluso",
    "conclusas": "concluso",
    "conclusionistas": "conclusionista",
    "conclusiva": "conclusivo",
    "conclusivas": "conclusivo",
    "conclusivos": "conclusivo",
    "conclusos": "concluso",
    "conclusões": "conclusão",
    "concluí": "concluir",
    "concluía": "concluir",
    "concluíam": "concluir",
    "concluíamo": "concluir",
    "concluíamos": "concluir",
    "concluías": "concluir",
    "concluída": "concluir",
    "concluídas": "concluir",
    "concluído": "concluir",
    "concluídos": "concluir",
    "concluíei": "concluir",
    "concluíeis": "concluir",
    "concluímo": "concluir",
    "concluímos": "concluir",
    "concluíra": "concluir",
    "concluíram": "concluir",
    "concluíramo": "concluir",
    "concluíramos": "concluir",
    "concluíras": "concluir",
    "concluíre": "concluir",
    "concluírei": "concluir",
    "concluíreis": "concluir",
    "concluírem": "concluir",
    "concluíres": "concluir",
    "concluís": "concluir",
    "concluísse": "concluir",
    "concluísseis": "concluir",
    "concluíssem": "concluir",
    "concluíssemos": "concluir",
    "concluísses": "concluir",
    "concluíste": "concluir",
    "concluístes": "concluir",
    "concoidais": "concoidal",
    "concolores": "concolor",
    "concomitantes": "concomitante",
    "concomitâncias": "concomitância",
    "concorda": "concordar",
    "concordada": "concordar",
    "concordadas": "concordar",
    "concordado": "concordar",
    "concordados": "concordar",
    "concordai": "concordar",
    "concordais": "concordar",
    "concordam": "concordar",
    "concordamo": "concordar",
    "concordamos": "concordar",
    "concordando": "concordar",
    "concordantes": "concordante",
    "concordara": "concordar",
    "concordaram": "concordar",
    "concordaras": "concordar",
    "concordarde": "concordar",
    "concordardes": "concordar",
    "concordare": "concordar",
    "concordarei": "concordar",
    "concordareis": "concordar",
    "concordarem": "concordar",
    "concordaremos": "concordar",
    "concordares": "concordar",
    "concordaria": "concordar",
    "concordariam": "concordar",
    "concordarias": "concordar",
    "concordarmo": "concordar",
    "concordarmos": "concordar",
    "concordará": "concordar",
    "concordarás": "concordar",
    "concordarão": "concordar",
    "concordaríamos": "concordar",
    "concordaríeis": "concordar",
    "concordas": "concordar",
    "concordasse": "concordar",
    "concordassem": "concordar",
    "concordasses": "concordar",
    "concordaste": "concordar",
    "concordastes": "concordar",
    "concordatas": "concordata",
    "concordatária": "concordatário",
    "concordatárias": "concordatário",
    "concordatários": "concordatário",
    "concordava": "concordar",
    "concordavam": "concordar",
    "concordavas": "concordar",
    "concorde": "concordar",
    "concordei": "concordar",
    "concordeis": "concordar",
    "concordem": "concordar",
    "concordemo": "concordar",
    "concordemos": "concordar",
    "concordes": "concorde",
    "concordismos": "concordismo",
    "concordo": "concordar",
    "concordou": "concordar",
    "concordá": "concordar",
    "concordámo": "concordar",
    "concordámos": "concordar",
    "concordáramo": "concordar",
    "concordáramos": "concordar",
    "concordárei": "concordar",
    "concordáreis": "concordar",
    "concordásseis": "concordar",
    "concordássemos": "concordar",
    "concordávamo": "concordar",
    "concordávamos": "concordar",
    "concordávei": "concordar",
    "concordáveis": "concordável",
    "concordâncias": "concordância",
    "concorpórea": "concorpóreo",
    "concorpóreas": "concorpóreo",
    "concorpóreos": "concorpóreo",
    "concorra": "concorrer",
    "concorrais": "concorrer",
    "concorram": "concorrer",
    "concorramo": "concorrer",
    "concorramos": "concorrer",
    "concorras": "concorrer",
    "concorre": "concorrer",
    "concorrei": "concorrer",
    "concorreis": "concorrer",
    "concorrem": "concorrer",
    "concorremo": "concorrer",
    "concorremos": "concorrer",
    "concorrenciais": "concorrencial",
    "concorrendo": "concorrer",
    "concorrentes": "concorrente",
    "concorrera": "concorrer",
    "concorreram": "concorrer",
    "concorreras": "concorrer",
    "concorrerde": "concorrer",
    "concorrerdes": "concorrer",
    "concorrere": "concorrer",
    "concorrerei": "concorrer",
    "concorrereis": "concorrer",
    "concorrerem": "concorrer",
    "concorreremos": "concorrer",
    "concorreres": "concorrer",
    "concorreria": "concorrer",
    "concorreriam": "concorrer",
    "concorrerias": "concorrer",
    "concorrermo": "concorrer",
    "concorrermos": "concorrer",
    "concorrerá": "concorrer",
    "concorrerás": "concorrer",
    "concorrerão": "concorrer",
    "concorreríamos": "concorrer",
    "concorreríeis": "concorrer",
    "concorres": "concorrer",
    "concorresse": "concorrer",
    "concorressem": "concorrer",
    "concorresses": "concorrer",
    "concorreste": "concorrer",
    "concorrestes": "concorrer",
    "concorreu": "concorrer",
    "concorri": "concorrer",
    "concorria": "concorrer",
    "concorriam": "concorrer",
    "concorrias": "concorrer",
    "concorrida": "concorrido",
    "concorridas": "concorrido",
    "concorrido": "concorrer",
    "concorridos": "concorrido",
    "concorridíssima": "concorrido",
    "concorridíssimas": "concorrido",
    "concorridíssimo": "concorrido",
    "concorridíssimos": "concorrido",
    "concorro": "concorrer",
    "concorrê": "concorrer",
    "concorrências": "concorrência",
    "concorrêramo": "concorrer",
    "concorrêramos": "concorrer",
    "concorrêrei": "concorrer",
    "concorrêreis": "concorrer",
    "concorrêsseis": "concorrer",
    "concorrêssemos": "concorrer",
    "concorríamo": "concorrer",
    "concorríamos": "concorrer",
    "concorríei": "concorrer",
    "concorríeis": "concorrer",
    "concotomias": "concotomia",
    "concrecionada": "concrecionado",
    "concrecionadas": "concrecionado",
    "concrecionados": "concrecionado",
    "concrescibilidades": "concrescibilidade",
    "concrescências": "concrescência",
    "concrescíveis": "concrescível",
    "concreta": "concreto",
    "concretas": "concreto",
    "concretismos": "concretismo",
    "concretiza": "concretizar",
    "concretizada": "concretizar",
    "concretizadas": "concretizar",
    "concretizado": "concretizar",
    "concretizados": "concretizar",
    "concretizai": "concretizar",
    "concretizais": "concretizar",
    "concretizam": "concretizar",
    "concretizamo": "concretizar",
    "concretizamos": "concretizar",
    "concretizando": "concretizar",
    "concretizara": "concretizar",
    "concretizaram": "concretizar",
    "concretizaras": "concretizar",
    "concretizarde": "concretizar",
    "concretizardes": "concretizar",
    "concretizare": "concretizar",
    "concretizarei": "concretizar",
    "concretizareis": "concretizar",
    "concretizarem": "concretizar",
    "concretizaremos": "concretizar",
    "concretizares": "concretizar",
    "concretizaria": "concretizar",
    "concretizariam": "concretizar",
    "concretizarias": "concretizar",
    "concretizarmo": "concretizar",
    "concretizarmos": "concretizar",
    "concretizará": "concretizar",
    "concretizarás": "concretizar",
    "concretizarão": "concretizar",
    "concretizaríamos": "concretizar",
    "concretizaríeis": "concretizar",
    "concretizas": "concretizar",
    "concretizasse": "concretizar",
    "concretizassem": "concretizar",
    "concretizasses": "concretizar",
    "concretizaste": "concretizar",
    "concretizastes": "concretizar",
    "concretizava": "concretizar",
    "concretizavam": "concretizar",
    "concretizavas": "concretizar",
    "concretizações": "concretização",
    "concretize": "concretizar",
    "concretizei": "concretizar",
    "concretizeis": "concretizar",
    "concretizem": "concretizar",
    "concretizemo": "concretizar",
    "concretizemos": "concretizar",
    "concretizes": "concretizar",
    "concretizo": "concretizar",
    "concretizou": "concretizar",
    "concretizá": "concretizar",
    "concretizámo": "concretizar",
    "concretizámos": "concretizar",
    "concretizáramo": "concretizar",
    "concretizáramos": "concretizar",
    "concretizárei": "concretizar",
    "concretizáreis": "concretizar",
    "concretizásseis": "concretizar",
    "concretizássemos": "concretizar",
    "concretizávamo": "concretizar",
    "concretizávamos": "concretizar",
    "concretizávei": "concretizar",
    "concretizáveis": "concretizar",
    "concretos": "concreto",
    "concretíssima": "concreto",
    "concretíssimas": "concreto",
    "concretíssimo": "concreto",
    "concretíssimos": "concreto",
    "concreções": "concreção",
    "concria": "concriar",
    "concriada": "concriar",
    "concriadas": "concriar",
    "concriado": "concriar",
    "concriados": "concriar",
    "concriai": "concriar",
    "concriais": "concriar",
    "concriam": "concriar",
    "concriamo": "concriar",
    "concriamos": "concriar",
    "concriando": "concriar",
    "concriara": "concriar",
    "concriaram": "concriar",
    "concriaras": "concriar",
    "concriarde": "concriar",
    "concriardes": "concriar",
    "concriare": "concriar",
    "concriarei": "concriar",
    "concriareis": "concriar",
    "concriarem": "concriar",
    "concriaremos": "concriar",
    "concriares": "concriar",
    "concriaria": "concriar",
    "concriariam": "concriar",
    "concriarias": "concriar",
    "concriarmo": "concriar",
    "concriarmos": "concriar",
    "concriará": "concriar",
    "concriarás": "concriar",
    "concriarão": "concriar",
    "concriaríamos": "concriar",
    "concriaríeis": "concriar",
    "concrias": "concriar",
    "concriasse": "concriar",
    "concriassem": "concriar",
    "concriasses": "concriar",
    "concriaste": "concriar",
    "concriastes": "concriar",
    "concriava": "concriar",
    "concriavam": "concriar",
    "concriavas": "concriar",
    "concriações": "concriação",
    "concrie": "concriar",
    "concriei": "concriar",
    "concrieis": "concriar",
    "concriem": "concriar",
    "concriemo": "concriar",
    "concriemos": "concriar",
    "concries": "concriar",
    "concrio": "concriar",
    "concriou": "concriar",
    "concriá": "concriar",
    "concriámo": "concriar",
    "concriámos": "concriar",
    "concriáramo": "concriar",
    "concriáramos": "concriar",
    "concriárei": "concriar",
    "concriáreis": "concriar",
    "concriásseis": "concriar",
    "concriássemos": "concriar",
    "concriávamo": "concriar",
    "concriávamos": "concriar",
    "concriávei": "concriar",
    "concriáveis": "concriar",
    "concubina": "concubinar",
    "concubinada": "concubinar",
    "concubinadas": "concubinar",
    "concubinado": "concubinar",
    "concubinados": "concubinar",
    "concubinagens": "concubinagem",
    "concubinai": "concubinar",
    "concubinais": "concubinar",
    "concubinam": "concubinar",
    "concubinamo": "concubinar",
    "concubinamos": "concubinar",
    "concubinando": "concubinar",
    "concubinara": "concubinar",
    "concubinaram": "concubinar",
    "concubinaras": "concubinar",
    "concubinardes": "concubinar",
    "concubinarei": "concubinar",
    "concubinareis": "concubinar",
    "concubinarem": "concubinar",
    "concubinaremos": "concubinar",
    "concubinares": "concubinar",
    "concubinaria": "concubinar",
    "concubinariam": "concubinar",
    "concubinarias": "concubinar",
    "concubinarmo": "concubinar",
    "concubinarmos": "concubinar",
    "concubinará": "concubinar",
    "concubinarás": "concubinar",
    "concubinarão": "concubinar",
    "concubinaríamos": "concubinar",
    "concubinaríeis": "concubinar",
    "concubinas": "concubinar",
    "concubinasse": "concubinar",
    "concubinassem": "concubinar",
    "concubinasses": "concubinar",
    "concubinaste": "concubinar",
    "concubinastes": "concubinar",
    "concubinatos": "concubinato",
    "concubinava": "concubinar",
    "concubinavam": "concubinar",
    "concubinavas": "concubinar",
    "concubine": "concubinar",
    "concubinei": "concubinar",
    "concubineis": "concubinar",
    "concubinem": "concubinar",
    "concubinemo": "concubinar",
    "concubinemos": "concubinar",
    "concubines": "concubinar",
    "concubino": "concubinar",
    "concubinou": "concubinar",
    "concubinámo": "concubinar",
    "concubinámos": "concubinar",
    "concubináramo": "concubinar",
    "concubináramos": "concubinar",
    "concubináreis": "concubinar",
    "concubinários": "concubinário",
    "concubinásseis": "concubinar",
    "concubinássemos": "concubinar",
    "concubinávamo": "concubinar",
    "concubinávamos": "concubinar",
    "concubináveis": "concubinar",
    "conculca": "conculcar",
    "conculcada": "conculcar",
    "conculcadas": "conculcar",
    "conculcado": "conculcar",
    "conculcadora": "conculcador",
    "conculcadoras": "conculcador",
    "conculcadores": "conculcador",
    "conculcados": "conculcar",
    "conculcai": "conculcar",
    "conculcais": "conculcar",
    "conculcam": "conculcar",
    "conculcamo": "conculcar",
    "conculcamos": "conculcar",
    "conculcando": "conculcar",
    "conculcara": "conculcar",
    "conculcaram": "conculcar",
    "conculcaras": "conculcar",
    "conculcarde": "conculcar",
    "conculcardes": "conculcar",
    "conculcare": "conculcar",
    "conculcarei": "conculcar",
    "conculcareis": "conculcar",
    "conculcarem": "conculcar",
    "conculcaremos": "conculcar",
    "conculcares": "conculcar",
    "conculcaria": "conculcar",
    "conculcariam": "conculcar",
    "conculcarias": "conculcar",
    "conculcarmo": "conculcar",
    "conculcarmos": "conculcar",
    "conculcará": "conculcar",
    "conculcarás": "conculcar",
    "conculcarão": "conculcar",
    "conculcaríamos": "conculcar",
    "conculcaríeis": "conculcar",
    "conculcas": "conculcar",
    "conculcasse": "conculcar",
    "conculcassem": "conculcar",
    "conculcasses": "conculcar",
    "conculcaste": "conculcar",
    "conculcastes": "conculcar",
    "conculcava": "conculcar",
    "conculcavam": "conculcar",
    "conculcavas": "conculcar",
    "conculco": "conculcar",
    "conculcou": "conculcar",
    "conculcá": "conculcar",
    "conculcámo": "conculcar",
    "conculcámos": "conculcar",
    "conculcáramo": "conculcar",
    "conculcáramos": "conculcar",
    "conculcárei": "conculcar",
    "conculcáreis": "conculcar",
    "conculcásseis": "conculcar",
    "conculcássemos": "conculcar",
    "conculcávamo": "conculcar",
    "conculcávamos": "conculcar",
    "conculcávei": "conculcar",
    "conculcáveis": "conculcar",
    "conculque": "conculcar",
    "conculquei": "conculcar",
    "conculqueis": "conculcar",
    "conculquem": "conculcar",
    "conculquemo": "conculcar",
    "conculquemos": "conculcar",
    "conculques": "conculcar",
    "concuminais": "concuminal",
    "concuminária": "concuminário",
    "concuminárias": "concuminário",
    "concuminários": "concuminário",
    "concunhadoa": "concunhadoo",
    "concunhadoas": "concunhadoo",
    "concunhadoos": "concunhadoo",
    "concupiscentes": "concupiscente",
    "concupiscências": "concupiscência",
    "concupiscíveis": "concupiscível",
    "concurrentes": "concurrente",
    "concurrida": "concurrido",
    "concurridas": "concurrido",
    "concurridos": "concurrido",
    "concursistas": "concursista",
    "concursos": "concurso",
    "concussionária": "concussionário",
    "concussionárias": "concussionário",
    "concussionários": "concussionário",
    "concussora": "concussor",
    "concussoras": "concussor",
    "concussores": "concussor",
    "concussões": "concussão",
    "concuta": "concutir",
    "concutais": "concutir",
    "concutam": "concutir",
    "concutamo": "concutir",
    "concutamos": "concutir",
    "concutas": "concutir",
    "concute": "concutir",
    "concutem": "concutir",
    "concutes": "concutir",
    "concuti": "concutir",
    "concutia": "concutir",
    "concutiam": "concutir",
    "concutias": "concutir",
    "concutida": "concutir",
    "concutidas": "concutir",
    "concutido": "concutir",
    "concutidos": "concutir",
    "concutimo": "concutir",
    "concutimos": "concutir",
    "concutindo": "concutir",
    "concutira": "concutir",
    "concutiram": "concutir",
    "concutiras": "concutir",
    "concutirde": "concutir",
    "concutirdes": "concutir",
    "concutire": "concutir",
    "concutirei": "concutir",
    "concutireis": "concutir",
    "concutirem": "concutir",
    "concutiremos": "concutir",
    "concutires": "concutir",
    "concutiria": "concutir",
    "concutiriam": "concutir",
    "concutirias": "concutir",
    "concutirmo": "concutir",
    "concutirmos": "concutir",
    "concutirá": "concutir",
    "concutirás": "concutir",
    "concutirão": "concutir",
    "concutiríamos": "concutir",
    "concutiríeis": "concutir",
    "concutis": "concutir",
    "concutisse": "concutir",
    "concutissem": "concutir",
    "concutisses": "concutir",
    "concutiste": "concutir",
    "concutistes": "concutir",
    "concutiu": "concutir",
    "concuto": "concutir",
    "concutora": "concutor",
    "concutoras": "concutor",
    "concutores": "concutor",
    "concutíamo": "concutir",
    "concutíamos": "concutir",
    "concutíei": "concutir",
    "concutíeis": "concutir",
    "concutíramo": "concutir",
    "concutíramos": "concutir",
    "concutírei": "concutir",
    "concutíreis": "concutir",
    "concutísseis": "concutir",
    "concutíssemos": "concutir",
    "concutíveis": "concutível",
    "concêntrica": "concêntrico",
    "concêntricas": "concêntrico",
    "concêntricos": "concêntrico",
    "concílios": "concílio",
    "concóides": "concóide",
    "concórdias": "concórdia",
    "concúbitos": "concúbito",
    "conda": "condir",
    "condados": "condado",
    "condais": "condir",
    "condam": "condir",
    "condamo": "condir",
    "condamos": "condir",
    "condas": "condir",
    "conde": "condir",
    "condecora": "condecorar",
    "condecorada": "condecorar",
    "condecoradas": "condecorar",
    "condecorado": "condecorar",
    "condecorados": "condecorar",
    "condecorai": "condecorar",
    "condecorais": "condecorar",
    "condecoram": "condecorar",
    "condecoramo": "condecorar",
    "condecoramos": "condecorar",
    "condecorando": "condecorar",
    "condecorara": "condecorar",
    "condecoraram": "condecorar",
    "condecoraras": "condecorar",
    "condecorarde": "condecorar",
    "condecorardes": "condecorar",
    "condecorare": "condecorar",
    "condecorarei": "condecorar",
    "condecorareis": "condecorar",
    "condecorarem": "condecorar",
    "condecoraremos": "condecorar",
    "condecorares": "condecorar",
    "condecoraria": "condecorar",
    "condecorariam": "condecorar",
    "condecorarias": "condecorar",
    "condecorarmo": "condecorar",
    "condecorarmos": "condecorar",
    "condecorará": "condecorar",
    "condecorarás": "condecorar",
    "condecorarão": "condecorar",
    "condecoraríamos": "condecorar",
    "condecoraríeis": "condecorar",
    "condecoras": "condecorar",
    "condecorasse": "condecorar",
    "condecorassem": "condecorar",
    "condecorasses": "condecorar",
    "condecoraste": "condecorar",
    "condecorastes": "condecorar",
    "condecorativa": "condecorativo",
    "condecorativas": "condecorativo",
    "condecorativos": "condecorativo",
    "condecorava": "condecorar",
    "condecoravam": "condecorar",
    "condecoravas": "condecorar",
    "condecorações": "condecoração",
    "condecore": "condecorar",
    "condecorei": "condecorar",
    "condecoreis": "condecorar",
    "condecorem": "condecorar",
    "condecoremo": "condecorar",
    "condecoremos": "condecorar",
    "condecores": "condecorar",
    "condecoro": "condecorar",
    "condecorou": "condecorar",
    "condecorá": "condecorar",
    "condecorámo": "condecorar",
    "condecorámos": "condecorar",
    "condecoráramo": "condecorar",
    "condecoráramos": "condecorar",
    "condecorárei": "condecorar",
    "condecoráreis": "condecorar",
    "condecorásseis": "condecorar",
    "condecorássemos": "condecorar",
    "condecorávamo": "condecorar",
    "condecorávamos": "condecorar",
    "condecorávei": "condecorar",
    "condecoráveis": "condecorável",
    "condem": "condir",
    "condena": "condenar",
    "condenada": "condenar",
    "condenadas": "condenar",
    "condenado": "condenar",
    "condenadora": "condenador",
    "condenadoras": "condenador",
    "condenadores": "condenador",
    "condenados": "condenar",
    "condenai": "condenar",
    "condenais": "condenar",
    "condenam": "condenar",
    "condenamentos": "condenamento",
    "condenamo": "condenar",
    "condenamos": "condenar",
    "condenando": "condenar",
    "condenara": "condenar",
    "condenaram": "condenar",
    "condenaras": "condenar",
    "condenarde": "condenar",
    "condenardes": "condenar",
    "condenare": "condenar",
    "condenarei": "condenar",
    "condenareis": "condenar",
    "condenarem": "condenar",
    "condenaremos": "condenar",
    "condenares": "condenar",
    "condenaria": "condenar",
    "condenariam": "condenar",
    "condenarias": "condenar",
    "condenarmo": "condenar",
    "condenarmos": "condenar",
    "condenará": "condenar",
    "condenarás": "condenar",
    "condenarão": "condenar",
    "condenaríamos": "condenar",
    "condenaríeis": "condenar",
    "condenas": "condenar",
    "condenasse": "condenar",
    "condenassem": "condenar",
    "condenasses": "condenar",
    "condenaste": "condenar",
    "condenastes": "condenar",
    "condenatória": "condenatório",
    "condenatórias": "condenatório",
    "condenatórios": "condenatório",
    "condenava": "condenar",
    "condenavam": "condenar",
    "condenavas": "condenar",
    "condenações": "condenação",
    "condene": "condenar",
    "condenei": "condenar",
    "condeneis": "condenar",
    "condenem": "condenar",
    "condenemo": "condenar",
    "condenemos": "condenar",
    "condenes": "condenar",
    "condeno": "condenar",
    "condenou": "condenar",
    "condensa": "condensar",
    "condensabilidades": "condensabilidade",
    "condensada": "condensar",
    "condensadas": "condensar",
    "condensado": "condensar",
    "condensadora": "condensador",
    "condensadoras": "condensador",
    "condensadores": "condensador",
    "condensados": "condensar",
    "condensai": "condensar",
    "condensais": "condensar",
    "condensam": "condensar",
    "condensamo": "condensar",
    "condensamos": "condensar",
    "condensando": "condensar",
    "condensantes": "condensante",
    "condensara": "condensar",
    "condensaram": "condensar",
    "condensaras": "condensar",
    "condensarde": "condensar",
    "condensardes": "condensar",
    "condensare": "condensar",
    "condensarei": "condensar",
    "condensareis": "condensar",
    "condensarem": "condensar",
    "condensaremos": "condensar",
    "condensares": "condensar",
    "condensaria": "condensar",
    "condensariam": "condensar",
    "condensarias": "condensar",
    "condensarmo": "condensar",
    "condensarmos": "condensar",
    "condensará": "condensar",
    "condensarás": "condensar",
    "condensarão": "condensar",
    "condensaríamos": "condensar",
    "condensaríeis": "condensar",
    "condensas": "condensar",
    "condensasse": "condensar",
    "condensassem": "condensar",
    "condensasses": "condensar",
    "condensaste": "condensar",
    "condensastes": "condensar",
    "condensava": "condensar",
    "condensavam": "condensar",
    "condensavas": "condensar",
    "condensações": "condensação",
    "condense": "condensar",
    "condensei": "condensar",
    "condenseis": "condensar",
    "condensem": "condensar",
    "condensemo": "condensar",
    "condensemos": "condensar",
    "condenses": "condensar",
    "condenso": "condensar",
    "condensou": "condensar",
    "condensá": "condensar",
    "condensámo": "condensar",
    "condensámos": "condensar",
    "condensáramo": "condensar",
    "condensáramos": "condensar",
    "condensárei": "condensar",
    "condensáreis": "condensar",
    "condensásseis": "condensar",
    "condensássemos": "condensar",
    "condensávamo": "condensar",
    "condensávamos": "condensar",
    "condensávei": "condensar",
    "condensáveis": "condensar",
    "condená": "condenar",
    "condenámo": "condenar",
    "condenámos": "condenar",
    "condenáramo": "condenar",
    "condenáramos": "condenar",
    "condenárei": "condenar",
    "condenáreis": "condenar",
    "condenásseis": "condenar",
    "condenássemos": "condenar",
    "condenávamo": "condenar",
    "condenávamos": "condenar",
    "condenávei": "condenar",
    "condenáveis": "condenável",
    "condes": "condir",
    "condescenda": "condescender",
    "condescendais": "condescender",
    "condescendam": "condescender",
    "condescendamo": "condescender",
    "condescendamos": "condescender",
    "condescendas": "condescender",
    "condescende": "condescender",
    "condescendei": "condescender",
    "condescendeis": "condescender",
    "condescendem": "condescender",
    "condescendemo": "condescender",
    "condescendemos": "condescender",
    "condescendendo": "condescender",
    "condescendentes": "condescendente",
    "condescendera": "condescender",
    "condescenderam": "condescender",
    "condescenderas": "condescender",
    "condescenderde": "condescender",
    "condescenderdes": "condescender",
    "condescendere": "condescender",
    "condescenderei": "condescender",
    "condescendereis": "condescender",
    "condescenderem": "condescender",
    "condescenderemos": "condescender",
    "condescenderes": "condescender",
    "condescenderia": "condescender",
    "condescenderiam": "condescender",
    "condescenderias": "condescender",
    "condescendermo": "condescender",
    "condescendermos": "condescender",
    "condescenderá": "condescender",
    "condescenderás": "condescender",
    "condescenderão": "condescender",
    "condescenderíamos": "condescender",
    "condescenderíeis": "condescender",
    "condescendes": "condescender",
    "condescendesse": "condescender",
    "condescendessem": "condescender",
    "condescendesses": "condescender",
    "condescendeste": "condescender",
    "condescendestes": "condescender",
    "condescendeu": "condescender",
    "condescendi": "condescender",
    "condescendia": "condescender",
    "condescendiam": "condescender",
    "condescendias": "condescender",
    "condescendida": "condescender",
    "condescendidas": "condescender",
    "condescendido": "condescender",
    "condescendidos": "condescender",
    "condescendimentos": "condescendimento",
    "condescendo": "condescender",
    "condescendê": "condescender",
    "condescendências": "condescendência",
    "condescendêramo": "condescender",
    "condescendêramos": "condescender",
    "condescendêrei": "condescender",
    "condescendêreis": "condescender",
    "condescendêsseis": "condescender",
    "condescendêssemos": "condescender",
    "condescendíamo": "condescender",
    "condescendíamos": "condescender",
    "condescendíei": "condescender",
    "condescendíeis": "condescender",
    "condessa": "condessar",
    "condessada": "condessar",
    "condessadas": "condessar",
    "condessado": "condessar",
    "condessados": "condessar",
    "condessai": "condessar",
    "condessais": "condessar",
    "condessam": "condessar",
    "condessamo": "condessar",
    "condessamos": "condessar",
    "condessando": "condessar",
    "condessara": "condessar",
    "condessaram": "condessar",
    "condessaras": "condessar",
    "condessarde": "condessar",
    "condessardes": "condessar",
    "condessare": "condessar",
    "condessarei": "condessar",
    "condessareis": "condessar",
    "condessarem": "condessar",
    "condessaremos": "condessar",
    "condessares": "condessar",
    "condessaria": "condessar",
    "condessariam": "condessar",
    "condessarias": "condessar",
    "condessarmo": "condessar",
    "condessarmos": "condessar",
    "condessará": "condessar",
    "condessarás": "condessar",
    "condessarão": "condessar",
    "condessaríamos": "condessar",
    "condessaríeis": "condessar",
    "condessas": "condessar",
    "condessasse": "condessar",
    "condessassem": "condessar",
    "condessasses": "condessar",
    "condessaste": "condessar",
    "condessastes": "condessar",
    "condessava": "condessar",
    "condessavam": "condessar",
    "condessavas": "condessar",
    "condesse": "condessar",
    "condessei": "condessar",
    "condesseiros": "condesseiro",
    "condesseis": "condessar",
    "condessem": "condessar",
    "condessemo": "condessar",
    "condessemos": "condessar",
    "condesses": "condessar",
    "condessinhas": "condessinha",
    "condesso": "condessar",
    "condessos": "condesso",
    "condessou": "condessar",
    "condessá": "condessar",
    "condessámo": "condessar",
    "condessámos": "condessar",
    "condessáramo": "condessar",
    "condessáramos": "condessar",
    "condessárei": "condessar",
    "condessáreis": "condessar",
    "condessásseis": "condessar",
    "condessássemos": "condessar",
    "condessávamo": "condessar",
    "condessávamos": "condessar",
    "condessávei": "condessar",
    "condessáveis": "condessar",
    "condestabres": "condestabre",
    "condestáveis": "condestável",
    "condi": "condir",
    "condia": "condir",
    "condiam": "condir",
    "condias": "condir",
    "condicentes": "condicente",
    "condiciona": "condicionar",
    "condicionada": "condicionar",
    "condicionadas": "condicionar",
    "condicionado": "condicionar",
    "condicionadora": "condicionador",
    "condicionadoras": "condicionador",
    "condicionadores": "condicionador",
    "condicionados": "condicionar",
    "condicionai": "condicionar",
    "condicionais": "condicionar",
    "condicionalidades": "condicionalidade",
    "condicionalismos": "condicionalismo",
    "condicionam": "condicionar",
    "condicionamentos": "condicionamento",
    "condicionamo": "condicionar",
    "condicionamos": "condicionar",
    "condicionando": "condicionar",
    "condicionantes": "condicionante",
    "condicionara": "condicionar",
    "condicionaram": "condicionar",
    "condicionaras": "condicionar",
    "condicionarde": "condicionar",
    "condicionardes": "condicionar",
    "condicionare": "condicionar",
    "condicionarei": "condicionar",
    "condicionareis": "condicionar",
    "condicionarem": "condicionar",
    "condicionaremos": "condicionar",
    "condicionares": "condicionar",
    "condicionaria": "condicionar",
    "condicionariam": "condicionar",
    "condicionarias": "condicionar",
    "condicionarmo": "condicionar",
    "condicionarmos": "condicionar",
    "condicionará": "condicionar",
    "condicionarás": "condicionar",
    "condicionarão": "condicionar",
    "condicionaríamos": "condicionar",
    "condicionaríeis": "condicionar",
    "condicionas": "condicionar",
    "condicionasse": "condicionar",
    "condicionassem": "condicionar",
    "condicionasses": "condicionar",
    "condicionaste": "condicionar",
    "condicionastes": "condicionar",
    "condicionava": "condicionar",
    "condicionavam": "condicionar",
    "condicionavas": "condicionar",
    "condicione": "condicionar",
    "condicionei": "condicionar",
    "condicioneis": "condicionar",
    "condicionem": "condicionar",
    "condicionemo": "condicionar",
    "condicionemos": "condicionar",
    "condiciones": "condicionar",
    "condiciono": "condicionar",
    "condicionou": "condicionar",
    "condicioná": "condicionar",
    "condicionámo": "condicionar",
    "condicionámos": "condicionar",
    "condicionáramo": "condicionar",
    "condicionáramos": "condicionar",
    "condicionárei": "condicionar",
    "condicionáreis": "condicionar",
    "condicionásseis": "condicionar",
    "condicionássemos": "condicionar",
    "condicionávamo": "condicionar",
    "condicionávamos": "condicionar",
    "condicionávei": "condicionar",
    "condicionáveis": "condicionar",
    "condida": "condir",
    "condidas": "condir",
    "condido": "condir",
    "condidos": "condir",
    "condiga": "condizer",
    "condigais": "condizer",
    "condigam": "condizer",
    "condigamo": "condizer",
    "condigamos": "condizer",
    "condigas": "condizer",
    "condigna": "condigno",
    "condignas": "condigno",
    "condignidades": "condignidade",
    "condignos": "condigno",
    "condigo": "condizer",
    "condilomas": "condiloma",
    "condilóides": "condilóide",
    "condimenta": "condimentar",
    "condimentada": "condimentar",
    "condimentadas": "condimentar",
    "condimentado": "condimentar",
    "condimentados": "condimentar",
    "condimentai": "condimentar",
    "condimentais": "condimentar",
    "condimentam": "condimentar",
    "condimentamo": "condimentar",
    "condimentamos": "condimentar",
    "condimentando": "condimentar",
    "condimentara": "condimentar",
    "condimentaram": "condimentar",
    "condimentaras": "condimentar",
    "condimentarde": "condimentar",
    "condimentardes": "condimentar",
    "condimentare": "condimentar",
    "condimentarei": "condimentar",
    "condimentareis": "condimentar",
    "condimentarem": "condimentar",
    "condimentaremos": "condimentar",
    "condimentares": "condimentar",
    "condimentaria": "condimentar",
    "condimentariam": "condimentar",
    "condimentarias": "condimentar",
    "condimentarmo": "condimentar",
    "condimentarmos": "condimentar",
    "condimentará": "condimentar",
    "condimentarás": "condimentar",
    "condimentarão": "condimentar",
    "condimentaríamos": "condimentar",
    "condimentaríeis": "condimentar",
    "condimentas": "condimentar",
    "condimentasse": "condimentar",
    "condimentassem": "condimentar",
    "condimentasses": "condimentar",
    "condimentaste": "condimentar",
    "condimentastes": "condimentar",
    "condimentava": "condimentar",
    "condimentavam": "condimentar",
    "condimentavas": "condimentar",
    "condimentações": "condimentação",
    "condimente": "condimentar",
    "condimentei": "condimentar",
    "condimenteis": "condimentar",
    "condimentem": "condimentar",
    "condimentemo": "condimentar",
    "condimentemos": "condimentar",
    "condimentes": "condimentar",
    "condimento": "condimentar",
    "condimentos": "condimento",
    "condimentosa": "condimentoso",
    "condimentosas": "condimentoso",
    "condimentosos": "condimentoso",
    "condimentou": "condimentar",
    "condimentá": "condimentar",
    "condimentámo": "condimentar",
    "condimentámos": "condimentar",
    "condimentáramo": "condimentar",
    "condimentáramos": "condimentar",
    "condimentárei": "condimentar",
    "condimentáreis": "condimentar",
    "condimentásseis": "condimentar",
    "condimentássemos": "condimentar",
    "condimentávamo": "condimentar",
    "condimentávamos": "condimentar",
    "condimentávei": "condimentar",
    "condimentáveis": "condimentar",
    "condimentícia": "condimentício",
    "condimentícias": "condimentício",
    "condimentícios": "condimentício",
    "condimo": "condir",
    "condimos": "condir",
    "condindo": "condir",
    "condira": "condir",
    "condiram": "condir",
    "condiras": "condir",
    "condirde": "condir",
    "condirdes": "condir",
    "condire": "condir",
    "condirei": "condizer",
    "condireis": "condizer",
    "condirem": "condir",
    "condiremos": "condizer",
    "condires": "condir",
    "condiria": "condizer",
    "condiriam": "condizer",
    "condirias": "condizer",
    "condirmo": "condir",
    "condirmos": "condir",
    "condirá": "condizer",
    "condirás": "condizer",
    "condirão": "condizer",
    "condiríamos": "condizer",
    "condiríeis": "condizer",
    "condis": "condir",
    "condiscípula": "condiscípulo",
    "condiscípulas": "condiscípulo",
    "condiscípulos": "condiscípulo",
    "condisse": "condizer",
    "condissem": "condir",
    "condissemo": "condizer",
    "condissemos": "condizer",
    "condisser": "condizer",
    "condissera": "condizer",
    "condisseram": "condizer",
    "condisseras": "condizer",
    "condisserdes": "condizer",
    "condisserem": "condizer",
    "condisseres": "condizer",
    "condissermos": "condizer",
    "condisses": "condir",
    "condissesse": "condizer",
    "condissessem": "condizer",
    "condissesses": "condizer",
    "condisseste": "condizer",
    "condissestes": "condizer",
    "condisséramo": "condizer",
    "condisséramos": "condizer",
    "condissérei": "condizer",
    "condisséreis": "condizer",
    "condissésseis": "condizer",
    "condisséssemos": "condizer",
    "condiste": "condir",
    "condistes": "condir",
    "condita": "condizer",
    "conditas": "condizer",
    "condito": "condizer",
    "conditos": "condizer",
    "condiu": "condir",
    "condiz": "condizer",
    "condize": "condizer",
    "condizei": "condizer",
    "condizeis": "condizer",
    "condizem": "condizer",
    "condizemo": "condizer",
    "condizemos": "condizer",
    "condizendo": "condizer",
    "condizentes": "condizente",
    "condizerde": "condizer",
    "condizerdes": "condizer",
    "condizere": "condizer",
    "condizerem": "condizer",
    "condizeres": "condizer",
    "condizermo": "condizer",
    "condizermos": "condizer",
    "condizes": "condizer",
    "condizia": "condizer",
    "condiziam": "condizer",
    "condizias": "condizer",
    "condizê": "condizer",
    "condizíamo": "condizer",
    "condizíamos": "condizer",
    "condizíei": "condizer",
    "condizíeis": "condizer",
    "condições": "condição",
    "condo": "condir",
    "condoa": "condoer",
    "condoais": "condoer",
    "condoam": "condoer",
    "condoamo": "condoer",
    "condoamos": "condoer",
    "condoas": "condoer",
    "condoei": "condoer",
    "condoeis": "condoer",
    "condoem": "condoer",
    "condoemo": "condoer",
    "condoemos": "condoer",
    "condoendo": "condoer",
    "condoera": "condoer",
    "condoeram": "condoer",
    "condoeras": "condoer",
    "condoerde": "condoer",
    "condoerdes": "condoer",
    "condoere": "condoer",
    "condoerei": "condoer",
    "condoereis": "condoer",
    "condoerem": "condoer",
    "condoeremos": "condoer",
    "condoeres": "condoer",
    "condoeria": "condoer",
    "condoeriam": "condoer",
    "condoerias": "condoer",
    "condoermo": "condoer",
    "condoermos": "condoer",
    "condoerá": "condoer",
    "condoerás": "condoer",
    "condoerão": "condoer",
    "condoeríamos": "condoer",
    "condoeríeis": "condoer",
    "condoesse": "condoer",
    "condoessem": "condoer",
    "condoesses": "condoer",
    "condoeste": "condoer",
    "condoestes": "condoer",
    "condoeu": "condoer",
    "condolentes": "condolente",
    "condolimentos": "condolimento",
    "condolências": "condolência",
    "condomínios": "condomínio",
    "condonatária": "condonatário",
    "condonatárias": "condonatário",
    "condonatários": "condonatário",
    "condoo": "condoer",
    "condores": "condor",
    "condoê": "condoer",
    "condoêramo": "condoer",
    "condoêramos": "condoer",
    "condoêrei": "condoer",
    "condoêreis": "condoer",
    "condoêsseis": "condoer",
    "condoêssemos": "condoer",
    "condoí": "condoer",
    "condoía": "condoer",
    "condoíam": "condoer",
    "condoíamo": "condoer",
    "condoíamos": "condoer",
    "condoías": "condoer",
    "condoída": "condoído",
    "condoídas": "condoído",
    "condoído": "condoer",
    "condoídos": "condoído",
    "condoíei": "condoer",
    "condoíeis": "condoer",
    "condoíveis": "condoível",
    "condrais": "condral",
    "condrinas": "condrina",
    "condriocontos": "condrioconto",
    "condriomas": "condrioma",
    "condriometrias": "condriometria",
    "condriomitos": "condriomito",
    "condriossomas": "condriossoma",
    "condritos": "condrito",
    "condriómetros": "condriómetro",
    "condrologias": "condrologia",
    "condrologistas": "condrologista",
    "condrológica": "condrológico",
    "condrológicas": "condrológico",
    "condrológicos": "condrológico",
    "condropterígea": "condropterígeo",
    "condropterígeas": "condropterígeo",
    "condropterígeos": "condropterígeo",
    "condropterígios": "condropterígio",
    "condróides": "condróide",
    "condróloga": "condrólogo",
    "condrólogas": "condrólogo",
    "condrólogos": "condrólogo",
    "conducentes": "conducente",
    "condutas": "conduta",
    "condutibilidades": "condutibilidade",
    "condutismos": "condutismo",
    "condutiva": "condutivo",
    "condutivas": "condutivo",
    "condutividades": "condutividade",
    "condutivos": "condutivo",
    "condutora": "condutor",
    "condutoras": "condutor",
    "condutores": "condutor",
    "condutos": "conduto",
    "condutâncias": "condutância",
    "condutícia": "condutício",
    "condutícias": "condutício",
    "condutícios": "condutício",
    "condutíveis": "condutível",
    "conduz": "conduzir",
    "conduza": "conduzir",
    "conduzais": "conduzir",
    "conduzam": "conduzir",
    "conduzamo": "conduzir",
    "conduzamos": "conduzir",
    "conduzas": "conduzir",
    "conduze": "conduzir",
    "conduzem": "conduzir",
    "conduzes": "conduzir",
    "conduzi": "conduzir",
    "conduzia": "conduzir",
    "conduziam": "conduzir",
    "conduzias": "conduzir",
    "conduzida": "conduzir",
    "conduzidas": "conduzir",
    "conduzido": "conduzir",
    "conduzidos": "conduzir",
    "conduzimo": "conduzir",
    "conduzimos": "conduzir",
    "conduzindo": "conduzir",
    "conduzira": "conduzir",
    "conduziram": "conduzir",
    "conduziras": "conduzir",
    "conduzirde": "conduzir",
    "conduzirdes": "conduzir",
    "conduzire": "conduzir",
    "conduzirei": "conduzir",
    "conduzireis": "conduzir",
    "conduzirem": "conduzir",
    "conduziremos": "conduzir",
    "conduzires": "conduzir",
    "conduziria": "conduzir",
    "conduziriam": "conduzir",
    "conduzirias": "conduzir",
    "conduzirmo": "conduzir",
    "conduzirmos": "conduzir",
    "conduzirá": "conduzir",
    "conduzirás": "conduzir",
    "conduzirão": "conduzir",
    "conduziríamos": "conduzir",
    "conduziríeis": "conduzir",
    "conduzis": "conduzir",
    "conduzisse": "conduzir",
    "conduzissem": "conduzir",
    "conduzisses": "conduzir",
    "conduziste": "conduzir",
    "conduzistes": "conduzir",
    "conduziu": "conduzir",
    "conduzo": "conduzir",
    "conduzíamo": "conduzir",
    "conduzíamos": "conduzir",
    "conduzíei": "conduzir",
    "conduzíeis": "conduzir",
    "conduzíramo": "conduzir",
    "conduzíramos": "conduzir",
    "conduzírei": "conduzir",
    "conduzíreis": "conduzir",
    "conduzísseis": "conduzir",
    "conduzíssemos": "conduzir",
    "conduções": "condução",
    "conduítes": "conduíte",
    "condíamo": "condir",
    "condíamos": "condir",
    "condíei": "condir",
    "condíeis": "condir",
    "condíramo": "condir",
    "condíramos": "condir",
    "condírei": "condir",
    "condíreis": "condir",
    "condísseis": "condir",
    "condíssemos": "condir",
    "condói": "condoer",
    "condóis": "condoer",
    "condómina": "condómino",
    "condóminas": "condómino",
    "condóminos": "condómino",
    "condões": "condão",
    "conecta": "conectar",
    "conectada": "conectar",
    "conectadas": "conectar",
    "conectado": "conectar",
    "conectados": "conectar",
    "conectai": "conectar",
    "conectais": "conectar",
    "conectam": "conectar",
    "conectamo": "conectar",
    "conectamos": "conectar",
    "conectando": "conectar",
    "conectara": "conectar",
    "conectaram": "conectar",
    "conectaras": "conectar",
    "conectarde": "conectar",
    "conectardes": "conectar",
    "conectare": "conectar",
    "conectarei": "conectar",
    "conectareis": "conectar",
    "conectarem": "conectar",
    "conectaremos": "conectar",
    "conectares": "conectar",
    "conectaria": "conectar",
    "conectariam": "conectar",
    "conectarias": "conectar",
    "conectarmo": "conectar",
    "conectarmos": "conectar",
    "conectará": "conectar",
    "conectarás": "conectar",
    "conectarão": "conectar",
    "conectaríamos": "conectar",
    "conectaríeis": "conectar",
    "conectas": "conectar",
    "conectasse": "conectar",
    "conectassem": "conectar",
    "conectasses": "conectar",
    "conectaste": "conectar",
    "conectastes": "conectar",
    "conectava": "conectar",
    "conectavam": "conectar",
    "conectavas": "conectar",
    "conecte": "conectar",
    "conectei": "conectar",
    "conecteis": "conectar",
    "conectem": "conectar",
    "conectemo": "conectar",
    "conectemos": "conectar",
    "conectes": "conectar",
    "conectiva": "conectivo",
    "conectivas": "conectivo",
    "conectivos": "conectivo",
    "conecto": "conectar",
    "conectores": "conector",
    "conectou": "conectar",
    "conectá": "conectar",
    "conectámo": "conectar",
    "conectámos": "conectar",
    "conectáramo": "conectar",
    "conectáramos": "conectar",
    "conectárei": "conectar",
    "conectáreis": "conectar",
    "conectásseis": "conectar",
    "conectássemos": "conectar",
    "conectávamo": "conectar",
    "conectávamos": "conectar",
    "conectávei": "conectar",
    "conectáveis": "conectar",
    "cones": "cone",
    "conexa": "conexo",
    "conexas": "conexo",
    "conexidades": "conexidade",
    "conexiona": "conexionar",
    "conexionada": "conexionar",
    "conexionadas": "conexionar",
    "conexionado": "conexionar",
    "conexionados": "conexionar",
    "conexionai": "conexionar",
    "conexionais": "conexionar",
    "conexionam": "conexionar",
    "conexionamo": "conexionar",
    "conexionamos": "conexionar",
    "conexionando": "conexionar",
    "conexionara": "conexionar",
    "conexionaram": "conexionar",
    "conexionaras": "conexionar",
    "conexionarde": "conexionar",
    "conexionardes": "conexionar",
    "conexionare": "conexionar",
    "conexionarei": "conexionar",
    "conexionareis": "conexionar",
    "conexionarem": "conexionar",
    "conexionaremos": "conexionar",
    "conexionares": "conexionar",
    "conexionaria": "conexionar",
    "conexionariam": "conexionar",
    "conexionarias": "conexionar",
    "conexionarmo": "conexionar",
    "conexionarmos": "conexionar",
    "conexionará": "conexionar",
    "conexionarás": "conexionar",
    "conexionarão": "conexionar",
    "conexionaríamos": "conexionar",
    "conexionaríeis": "conexionar",
    "conexionas": "conexionar",
    "conexionasse": "conexionar",
    "conexionassem": "conexionar",
    "conexionasses": "conexionar",
    "conexionaste": "conexionar",
    "conexionastes": "conexionar",
    "conexionava": "conexionar",
    "conexionavam": "conexionar",
    "conexionavas": "conexionar",
    "conexione": "conexionar",
    "conexionei": "conexionar",
    "conexioneis": "conexionar",
    "conexionem": "conexionar",
    "conexionemo": "conexionar",
    "conexionemos": "conexionar",
    "conexiones": "conexionar",
    "conexiono": "conexionar",
    "conexionou": "conexionar",
    "conexioná": "conexionar",
    "conexionámo": "conexionar",
    "conexionámos": "conexionar",
    "conexionáramo": "conexionar",
    "conexionáramos": "conexionar",
    "conexionárei": "conexionar",
    "conexionáreis": "conexionar",
    "conexionásseis": "conexionar",
    "conexionássemos": "conexionar",
    "conexionávamo": "conexionar",
    "conexionávamos": "conexionar",
    "conexionávei": "conexionar",
    "conexionáveis": "conexionar",
    "conexiva": "conexivo",
    "conexivas": "conexivo",
    "conexivos": "conexivo",
    "conexos": "conexo",
    "conexões": "conexão",
    "conezias": "conezia",
    "confabula": "confabular",
    "confabulada": "confabular",
    "confabuladas": "confabular",
    "confabulado": "confabular",
    "confabuladora": "confabulador",
    "confabuladoras": "confabulador",
    "confabuladores": "confabulador",
    "confabulados": "confabular",
    "confabulai": "confabular",
    "confabulais": "confabular",
    "confabulam": "confabular",
    "confabulamo": "confabular",
    "confabulamos": "confabular",
    "confabulando": "confabular",
    "confabulara": "confabular",
    "confabularam": "confabular",
    "confabularas": "confabular",
    "confabularde": "confabular",
    "confabulardes": "confabular",
    "confabulare": "confabular",
    "confabularei": "confabular",
    "confabulareis": "confabular",
    "confabularem": "confabular",
    "confabularemos": "confabular",
    "confabulares": "confabular",
    "confabularia": "confabular",
    "confabulariam": "confabular",
    "confabularias": "confabular",
    "confabularmo": "confabular",
    "confabularmos": "confabular",
    "confabulará": "confabular",
    "confabularás": "confabular",
    "confabularão": "confabular",
    "confabularíamos": "confabular",
    "confabularíeis": "confabular",
    "confabulas": "confabular",
    "confabulasse": "confabular",
    "confabulassem": "confabular",
    "confabulasses": "confabular",
    "confabulaste": "confabular",
    "confabulastes": "confabular",
    "confabulava": "confabular",
    "confabulavam": "confabular",
    "confabulavas": "confabular",
    "confabulações": "confabulação",
    "confabule": "confabular",
    "confabulei": "confabular",
    "confabuleis": "confabular",
    "confabulem": "confabular",
    "confabulemo": "confabular",
    "confabulemos": "confabular",
    "confabules": "confabular",
    "confabulo": "confabular",
    "confabulou": "confabular",
    "confabulá": "confabular",
    "confabulámo": "confabular",
    "confabulámos": "confabular",
    "confabuláramo": "confabular",
    "confabuláramos": "confabular",
    "confabulárei": "confabular",
    "confabuláreis": "confabular",
    "confabulásseis": "confabular",
    "confabulássemos": "confabular",
    "confabulávamo": "confabular",
    "confabulávamos": "confabular",
    "confabulávei": "confabular",
    "confabuláveis": "confabular",
    "confecciona": "confeccionar",
    "confeccionada": "confeccionar",
    "confeccionadas": "confeccionar",
    "confeccionado": "confeccionar",
    "confeccionadora": "confeccionador",
    "confeccionadoras": "confeccionador",
    "confeccionadores": "confeccionador",
    "confeccionados": "confeccionar",
    "confeccionai": "confeccionar",
    "confeccionais": "confeccionar",
    "confeccionam": "confeccionar",
    "confeccionamo": "confeccionar",
    "confeccionamos": "confeccionar",
    "confeccionando": "confeccionar",
    "confeccionara": "confeccionar",
    "confeccionaram": "confeccionar",
    "confeccionaras": "confeccionar",
    "confeccionarde": "confeccionar",
    "confeccionardes": "confeccionar",
    "confeccionare": "confeccionar",
    "confeccionarei": "confeccionar",
    "confeccionareis": "confeccionar",
    "confeccionarem": "confeccionar",
    "confeccionaremos": "confeccionar",
    "confeccionares": "confeccionar",
    "confeccionaria": "confeccionar",
    "confeccionariam": "confeccionar",
    "confeccionarias": "confeccionar",
    "confeccionarmo": "confeccionar",
    "confeccionarmos": "confeccionar",
    "confeccionará": "confeccionar",
    "confeccionarás": "confeccionar",
    "confeccionarão": "confeccionar",
    "confeccionaríamos": "confeccionar",
    "confeccionaríeis": "confeccionar",
    "confeccionas": "confeccionar",
    "confeccionasse": "confeccionar",
    "confeccionassem": "confeccionar",
    "confeccionasses": "confeccionar",
    "confeccionaste": "confeccionar",
    "confeccionastes": "confeccionar",
    "confeccionava": "confeccionar",
    "confeccionavam": "confeccionar",
    "confeccionavas": "confeccionar",
    "confeccione": "confeccionar",
    "confeccionei": "confeccionar",
    "confeccioneis": "confeccionar",
    "confeccionem": "confeccionar",
    "confeccionemo": "confeccionar",
    "confeccionemos": "confeccionar",
    "confecciones": "confeccionar",
    "confecciono": "confeccionar",
    "confeccionou": "confeccionar",
    "confeccioná": "confeccionar",
    "confeccionámo": "confeccionar",
    "confeccionámos": "confeccionar",
    "confeccionáramo": "confeccionar",
    "confeccionáramos": "confeccionar",
    "confeccionárei": "confeccionar",
    "confeccionáreis": "confeccionar",
    "confeccionásseis": "confeccionar",
    "confeccionássemos": "confeccionar",
    "confeccionávamo": "confeccionar",
    "confeccionávamos": "confeccionar",
    "confeccionávei": "confeccionar",
    "confeccionáveis": "confeccionar",
    "confecções": "confecção",
    "confedera": "confederar",
    "confederada": "confederar",
    "confederadas": "confederar",
    "confederado": "confederar",
    "confederados": "confederar",
    "confederai": "confederar",
    "confederais": "confederar",
    "confederam": "confederar",
    "confederamo": "confederar",
    "confederamos": "confederar",
    "confederando": "confederar",
    "confederara": "confederar",
    "confederaram": "confederar",
    "confederaras": "confederar",
    "confederarde": "confederar",
    "confederardes": "confederar",
    "confederare": "confederar",
    "confederarei": "confederar",
    "confederareis": "confederar",
    "confederarem": "confederar",
    "confederaremos": "confederar",
    "confederares": "confederar",
    "confederaria": "confederar",
    "confederariam": "confederar",
    "confederarias": "confederar",
    "confederarmo": "confederar",
    "confederarmos": "confederar",
    "confederará": "confederar",
    "confederarás": "confederar",
    "confederarão": "confederar",
    "confederaríamos": "confederar",
    "confederaríeis": "confederar",
    "confederas": "confederar",
    "confederasse": "confederar",
    "confederassem": "confederar",
    "confederasses": "confederar",
    "confederaste": "confederar",
    "confederastes": "confederar",
    "confederativa": "confederativo",
    "confederativas": "confederativo",
    "confederativos": "confederativo",
    "confederava": "confederar",
    "confederavam": "confederar",
    "confederavas": "confederar",
    "confederações": "confederação",
    "confedere": "confederar",
    "confederei": "confederar",
    "confedereis": "confederar",
    "confederem": "confederar",
    "confederemo": "confederar",
    "confederemos": "confederar",
    "confederes": "confederar",
    "confedero": "confederar",
    "confederou": "confederar",
    "confederá": "confederar",
    "confederámo": "confederar",
    "confederámos": "confederar",
    "confederáramo": "confederar",
    "confederáramos": "confederar",
    "confederárei": "confederar",
    "confederáreis": "confederar",
    "confederásseis": "confederar",
    "confederássemos": "confederar",
    "confederávamo": "confederar",
    "confederávamos": "confederar",
    "confederávei": "confederar",
    "confederáveis": "confederável",
    "confeita": "confeitar",
    "confeitada": "confeitar",
    "confeitadas": "confeitar",
    "confeitado": "confeitar",
    "confeitados": "confeitar",
    "confeitai": "confeitar",
    "confeitais": "confeitar",
    "confeitam": "confeitar",
    "confeitamo": "confeitar",
    "confeitamos": "confeitar",
    "confeitando": "confeitar",
    "confeitara": "confeitar",
    "confeitaram": "confeitar",
    "confeitaras": "confeitar",
    "confeitarde": "confeitar",
    "confeitardes": "confeitar",
    "confeitare": "confeitar",
    "confeitarei": "confeitar",
    "confeitareis": "confeitar",
    "confeitarem": "confeitar",
    "confeitaremos": "confeitar",
    "confeitares": "confeitar",
    "confeitaria": "confeitar",
    "confeitariam": "confeitar",
    "confeitarias": "confeitaria",
    "confeitarmo": "confeitar",
    "confeitarmos": "confeitar",
    "confeitará": "confeitar",
    "confeitarás": "confeitar",
    "confeitarão": "confeitar",
    "confeitaríamos": "confeitar",
    "confeitaríeis": "confeitar",
    "confeitas": "confeitar",
    "confeitasse": "confeitar",
    "confeitassem": "confeitar",
    "confeitasses": "confeitar",
    "confeitaste": "confeitar",
    "confeitastes": "confeitar",
    "confeitava": "confeitar",
    "confeitavam": "confeitar",
    "confeitavas": "confeitar",
    "confeite": "confeitar",
    "confeitei": "confeitar",
    "confeiteira": "confeiteiro",
    "confeiteiras": "confeiteiro",
    "confeiteiros": "confeiteiro",
    "confeiteis": "confeitar",
    "confeitem": "confeitar",
    "confeitemo": "confeitar",
    "confeitemos": "confeitar",
    "confeites": "confeitar",
    "confeito": "confeitar",
    "confeitos": "confeito",
    "confeitou": "confeitar",
    "confeitá": "confeitar",
    "confeitámo": "confeitar",
    "confeitámos": "confeitar",
    "confeitáramo": "confeitar",
    "confeitáramos": "confeitar",
    "confeitárei": "confeitar",
    "confeitáreis": "confeitar",
    "confeitásseis": "confeitar",
    "confeitássemos": "confeitar",
    "confeitávamo": "confeitar",
    "confeitávamos": "confeitar",
    "confeitávei": "confeitar",
    "confeitáveis": "confeitar",
    "confeiçoa": "confeiçoar",
    "confeiçoada": "confeiçoar",
    "confeiçoadas": "confeiçoar",
    "confeiçoado": "confeiçoar",
    "confeiçoados": "confeiçoar",
    "confeiçoai": "confeiçoar",
    "confeiçoais": "confeiçoar",
    "confeiçoam": "confeiçoar",
    "confeiçoamo": "confeiçoar",
    "confeiçoamos": "confeiçoar",
    "confeiçoando": "confeiçoar",
    "confeiçoara": "confeiçoar",
    "confeiçoaram": "confeiçoar",
    "confeiçoaras": "confeiçoar",
    "confeiçoarde": "confeiçoar",
    "confeiçoardes": "confeiçoar",
    "confeiçoare": "confeiçoar",
    "confeiçoarei": "confeiçoar",
    "confeiçoareis": "confeiçoar",
    "confeiçoarem": "confeiçoar",
    "confeiçoaremos": "confeiçoar",
    "confeiçoares": "confeiçoar",
    "confeiçoaria": "confeiçoar",
    "confeiçoariam": "confeiçoar",
    "confeiçoarias": "confeiçoar",
    "confeiçoarmo": "confeiçoar",
    "confeiçoarmos": "confeiçoar",
    "confeiçoará": "confeiçoar",
    "confeiçoarás": "confeiçoar",
    "confeiçoarão": "confeiçoar",
    "confeiçoaríamos": "confeiçoar",
    "confeiçoaríeis": "confeiçoar",
    "confeiçoas": "confeiçoar",
    "confeiçoasse": "confeiçoar",
    "confeiçoassem": "confeiçoar",
    "confeiçoasses": "confeiçoar",
    "confeiçoaste": "confeiçoar",
    "confeiçoastes": "confeiçoar",
    "confeiçoava": "confeiçoar",
    "confeiçoavam": "confeiçoar",
    "confeiçoavas": "confeiçoar",
    "confeiçoe": "confeiçoar",
    "confeiçoei": "confeiçoar",
    "confeiçoeis": "confeiçoar",
    "confeiçoem": "confeiçoar",
    "confeiçoemo": "confeiçoar",
    "confeiçoemos": "confeiçoar",
    "confeiçoes": "confeiçoar",
    "confeiçoo": "confeiçoar",
    "confeiçoou": "confeiçoar",
    "confeiçoá": "confeiçoar",
    "confeiçoámo": "confeiçoar",
    "confeiçoámos": "confeiçoar",
    "confeiçoáramo": "confeiçoar",
    "confeiçoáramos": "confeiçoar",
    "confeiçoárei": "confeiçoar",
    "confeiçoáreis": "confeiçoar",
    "confeiçoásseis": "confeiçoar",
    "confeiçoássemos": "confeiçoar",
    "confeiçoávamo": "confeiçoar",
    "confeiçoávamos": "confeiçoar",
    "confeiçoávei": "confeiçoar",
    "confeiçoáveis": "confeiçoar",
    "confeições": "confeição",
    "confere": "conferir",
    "conferem": "conferir",
    "conferencia": "conferenciar",
    "conferenciada": "conferenciar",
    "conferenciadas": "conferenciar",
    "conferenciado": "conferenciar",
    "conferenciados": "conferenciar",
    "conferenciai": "conferenciar",
    "conferenciais": "conferenciar",
    "conferenciam": "conferenciar",
    "conferenciamo": "conferenciar",
    "conferenciamos": "conferenciar",
    "conferenciando": "conferenciar",
    "conferenciara": "conferenciar",
    "conferenciaram": "conferenciar",
    "conferenciaras": "conferenciar",
    "conferenciarde": "conferenciar",
    "conferenciardes": "conferenciar",
    "conferenciare": "conferenciar",
    "conferenciarei": "conferenciar",
    "conferenciareis": "conferenciar",
    "conferenciarem": "conferenciar",
    "conferenciaremos": "conferenciar",
    "conferenciares": "conferenciar",
    "conferenciaria": "conferenciar",
    "conferenciariam": "conferenciar",
    "conferenciarias": "conferenciar",
    "conferenciarmo": "conferenciar",
    "conferenciarmos": "conferenciar",
    "conferenciará": "conferenciar",
    "conferenciarás": "conferenciar",
    "conferenciarão": "conferenciar",
    "conferenciaríamos": "conferenciar",
    "conferenciaríeis": "conferenciar",
    "conferencias": "conferenciar",
    "conferenciasse": "conferenciar",
    "conferenciassem": "conferenciar",
    "conferenciasses": "conferenciar",
    "conferenciaste": "conferenciar",
    "conferenciastes": "conferenciar",
    "conferenciava": "conferenciar",
    "conferenciavam": "conferenciar",
    "conferenciavas": "conferenciar",
    "conferenciaveis": "conferenciavel",
    "conferencie": "conferenciar",
    "conferenciei": "conferenciar",
    "conferencieis": "conferenciar",
    "conferenciem": "conferenciar",
    "conferenciemo": "conferenciar",
    "conferenciemos": "conferenciar",
    "conferencies": "conferenciar",
    "conferencio": "conferenciar",
    "conferenciou": "conferenciar",
    "conferencistas": "conferencista",
    "conferenciá": "conferenciar",
    "conferenciámo": "conferenciar",
    "conferenciámos": "conferenciar",
    "conferenciáramo": "conferenciar",
    "conferenciáramos": "conferenciar",
    "conferenciárei": "conferenciar",
    "conferenciáreis": "conferenciar",
    "conferenciásseis": "conferenciar",
    "conferenciássemos": "conferenciar",
    "conferenciávamo": "conferenciar",
    "conferenciávamos": "conferenciar",
    "conferenciávei": "conferenciar",
    "conferenciáveis": "conferenciar",
    "conferentes": "conferente",
    "conferes": "conferir",
    "conferi": "conferir",
    "conferia": "conferir",
    "conferiam": "conferir",
    "conferias": "conferir",
    "conferida": "conferir",
    "conferidas": "conferir",
    "conferido": "conferir",
    "conferidora": "conferidor",
    "conferidoras": "conferidor",
    "conferidores": "conferidor",
    "conferidos": "conferir",
    "conferimo": "conferir",
    "conferimos": "conferir",
    "conferindo": "conferir",
    "conferira": "conferir",
    "conferiram": "conferir",
    "conferiras": "conferir",
    "conferirde": "conferir",
    "conferirdes": "conferir",
    "conferire": "conferir",
    "conferirei": "conferir",
    "conferireis": "conferir",
    "conferirem": "conferir",
    "conferiremos": "conferir",
    "conferires": "conferir",
    "conferiria": "conferir",
    "confeririam": "conferir",
    "conferirias": "conferir",
    "conferirmo": "conferir",
    "conferirmos": "conferir",
    "conferirá": "conferir",
    "conferirás": "conferir",
    "conferirão": "conferir",
    "conferiríamos": "conferir",
    "conferiríeis": "conferir",
    "conferis": "conferir",
    "conferisse": "conferir",
    "conferissem": "conferir",
    "conferisses": "conferir",
    "conferiste": "conferir",
    "conferistes": "conferir",
    "conferiu": "conferir",
    "conferências": "conferência",
    "conferíamo": "conferir",
    "conferíamos": "conferir",
    "conferíei": "conferir",
    "conferíeis": "conferir",
    "conferíramo": "conferir",
    "conferíramos": "conferir",
    "conferírei": "conferir",
    "conferíreis": "conferir",
    "conferísseis": "conferir",
    "conferíssemos": "conferir",
    "conferíveis": "conferível",
    "confessa": "confesso",
    "confessada": "confessar",
    "confessadas": "confessar",
    "confessado": "confessar",
    "confessados": "confessar",
    "confessai": "confessar",
    "confessais": "confessar",
    "confessam": "confessar",
    "confessamo": "confessar",
    "confessamos": "confessar",
    "confessanda": "confessando",
    "confessandas": "confessando",
    "confessando": "confessar",
    "confessandos": "confessando",
    "confessara": "confessar",
    "confessaram": "confessar",
    "confessaras": "confessar",
    "confessarde": "confessar",
    "confessardes": "confessar",
    "confessare": "confessar",
    "confessarei": "confessar",
    "confessareis": "confessar",
    "confessarem": "confessar",
    "confessaremos": "confessar",
    "confessares": "confessar",
    "confessaria": "confessar",
    "confessariam": "confessar",
    "confessarias": "confessar",
    "confessarmo": "confessar",
    "confessarmos": "confessar",
    "confessará": "confessar",
    "confessarás": "confessar",
    "confessarão": "confessar",
    "confessaríamos": "confessar",
    "confessaríeis": "confessar",
    "confessas": "confesso",
    "confessasse": "confessar",
    "confessassem": "confessar",
    "confessasses": "confessar",
    "confessaste": "confessar",
    "confessastes": "confessar",
    "confessava": "confessar",
    "confessavam": "confessar",
    "confessavas": "confessar",
    "confesse": "confessar",
    "confessei": "confessar",
    "confesseis": "confessar",
    "confessem": "confessar",
    "confessemo": "confessar",
    "confessemos": "confessar",
    "confesses": "confessar",
    "confessionais": "confessional",
    "confessionalidades": "confessionalidade",
    "confessionários": "confessionário",
    "confesso": "confessar",
    "confessorais": "confessoral",
    "confessores": "confessor",
    "confessos": "confesso",
    "confessou": "confessar",
    "confessá": "confessar",
    "confessámo": "confessar",
    "confessámos": "confessar",
    "confessáramo": "confessar",
    "confessáramos": "confessar",
    "confessárei": "confessar",
    "confessáreis": "confessar",
    "confessásseis": "confessar",
    "confessássemos": "confessar",
    "confessávamo": "confessar",
    "confessávamos": "confessar",
    "confessávei": "confessar",
    "confessáveis": "confessável",
    "confessória": "confessório",
    "confessórias": "confessório",
    "confessórios": "confessório",
    "confia": "confiar",
    "confiada": "confiar",
    "confiadas": "confiar",
    "confiado": "confiar",
    "confiados": "confiar",
    "confiai": "confiar",
    "confiais": "confiar",
    "confiam": "confiar",
    "confiamo": "confiar",
    "confiamos": "confiar",
    "confiando": "confiar",
    "confiantes": "confiante",
    "confianças": "confiança",
    "confiara": "confiar",
    "confiaram": "confiar",
    "confiaras": "confiar",
    "confiarde": "confiar",
    "confiardes": "confiar",
    "confiare": "confiar",
    "confiarei": "confiar",
    "confiareis": "confiar",
    "confiarem": "confiar",
    "confiaremos": "confiar",
    "confiares": "confiar",
    "confiaria": "confiar",
    "confiariam": "confiar",
    "confiarias": "confiar",
    "confiarmo": "confiar",
    "confiarmos": "confiar",
    "confiará": "confiar",
    "confiarás": "confiar",
    "confiarão": "confiar",
    "confiaríamos": "confiar",
    "confiaríeis": "confiar",
    "confias": "confiar",
    "confiasse": "confiar",
    "confiassem": "confiar",
    "confiasses": "confiar",
    "confiaste": "confiar",
    "confiastes": "confiar",
    "confiava": "confiar",
    "confiavam": "confiar",
    "confiavas": "confiar",
    "confidencia": "confidenciar",
    "confidenciada": "confidenciar",
    "confidenciadas": "confidenciar",
    "confidenciado": "confidenciar",
    "confidenciados": "confidenciar",
    "confidenciai": "confidenciar",
    "confidenciais": "confidenciar",
    "confidencialidades": "confidencialidade",
    "confidenciam": "confidenciar",
    "confidenciamo": "confidenciar",
    "confidenciamos": "confidenciar",
    "confidenciando": "confidenciar",
    "confidenciara": "confidenciar",
    "confidenciaram": "confidenciar",
    "confidenciaras": "confidenciar",
    "confidenciarde": "confidenciar",
    "confidenciardes": "confidenciar",
    "confidenciare": "confidenciar",
    "confidenciarei": "confidenciar",
    "confidenciareis": "confidenciar",
    "confidenciarem": "confidenciar",
    "confidenciaremos": "confidenciar",
    "confidenciares": "confidenciar",
    "confidenciaria": "confidenciar",
    "confidenciariam": "confidenciar",
    "confidenciarias": "confidenciar",
    "confidenciarmo": "confidenciar",
    "confidenciarmos": "confidenciar",
    "confidenciará": "confidenciar",
    "confidenciarás": "confidenciar",
    "confidenciarão": "confidenciar",
    "confidenciaríamos": "confidenciar",
    "confidenciaríeis": "confidenciar",
    "confidencias": "confidenciar",
    "confidenciasse": "confidenciar",
    "confidenciassem": "confidenciar",
    "confidenciasses": "confidenciar",
    "confidenciaste": "confidenciar",
    "confidenciastes": "confidenciar",
    "confidenciava": "confidenciar",
    "confidenciavam": "confidenciar",
    "confidenciavas": "confidenciar",
    "confidencie": "confidenciar",
    "confidenciei": "confidenciar",
    "confidencieis": "confidenciar",
    "confidenciem": "confidenciar",
    "confidenciemo": "confidenciar",
    "confidenciemos": "confidenciar",
    "confidencies": "confidenciar",
    "confidencio": "confidenciar",
    "confidenciosa": "confidencioso",
    "confidenciosas": "confidencioso",
    "confidenciosos": "confidencioso",
    "confidenciou": "confidenciar",
    "confidenciá": "confidenciar",
    "confidenciámo": "confidenciar",
    "confidenciámos": "confidenciar",
    "confidenciáramo": "confidenciar",
    "confidenciáramos": "confidenciar",
    "confidenciárei": "confidenciar",
    "confidenciáreis": "confidenciar",
    "confidenciásseis": "confidenciar",
    "confidenciássemos": "confidenciar",
    "confidenciávamo": "confidenciar",
    "confidenciávamos": "confidenciar",
    "confidenciávei": "confidenciar",
    "confidenciáveis": "confidenciável",
    "confidentes": "confidente",
    "confidências": "confidência",
    "confie": "confiar",
    "confiei": "confiar",
    "confieis": "confiar",
    "confiem": "confiar",
    "confiemo": "confiar",
    "confiemos": "confiar",
    "confies": "confiar",
    "configura": "configurar",
    "configurada": "configurar",
    "configuradas": "configurar",
    "configurado": "configurar",
    "configurados": "configurar",
    "configurai": "configurar",
    "configurais": "configurar",
    "configuram": "configurar",
    "configuramo": "configurar",
    "configuramos": "configurar",
    "configurando": "configurar",
    "configurara": "configurar",
    "configuraram": "configurar",
    "configuraras": "configurar",
    "configurarde": "configurar",
    "configurardes": "configurar",
    "configurare": "configurar",
    "configurarei": "configurar",
    "configurareis": "configurar",
    "configurarem": "configurar",
    "configuraremos": "configurar",
    "configurares": "configurar",
    "configuraria": "configurar",
    "configurariam": "configurar",
    "configurarias": "configurar",
    "configurarmo": "configurar",
    "configurarmos": "configurar",
    "configurará": "configurar",
    "configurarás": "configurar",
    "configurarão": "configurar",
    "configuraríamos": "configurar",
    "configuraríeis": "configurar",
    "configuras": "configurar",
    "configurasse": "configurar",
    "configurassem": "configurar",
    "configurasses": "configurar",
    "configuraste": "configurar",
    "configurastes": "configurar",
    "configurava": "configurar",
    "configuravam": "configurar",
    "configuravas": "configurar",
    "configurações": "configuração",
    "configure": "configurar",
    "configurei": "configurar",
    "configureis": "configurar",
    "configurem": "configurar",
    "configuremo": "configurar",
    "configuremos": "configurar",
    "configures": "configurar",
    "configuro": "configurar",
    "configurou": "configurar",
    "configurá": "configurar",
    "configurámo": "configurar",
    "configurámos": "configurar",
    "configuráramo": "configurar",
    "configuráramos": "configurar",
    "configurárei": "configurar",
    "configuráreis": "configurar",
    "configurásseis": "configurar",
    "configurássemos": "configurar",
    "configurávamo": "configurar",
    "configurávamos": "configurar",
    "configurávei": "configurar",
    "configuráveis": "configurar",
    "confina": "confinar",
    "confinada": "confinar",
    "confinadas": "confinar",
    "confinado": "confinar",
    "confinados": "confinar",
    "confinai": "confinar",
    "confinais": "confinar",
    "confinam": "confinar",
    "confinamentos": "confinamento",
    "confinamo": "confinar",
    "confinamos": "confinar",
    "confinando": "confinar",
    "confinantes": "confinante",
    "confinara": "confinar",
    "confinaram": "confinar",
    "confinaras": "confinar",
    "confinarde": "confinar",
    "confinardes": "confinar",
    "confinare": "confinar",
    "confinarei": "confinar",
    "confinareis": "confinar",
    "confinarem": "confinar",
    "confinaremos": "confinar",
    "confinares": "confinar",
    "confinaria": "confinar",
    "confinariam": "confinar",
    "confinarias": "confinar",
    "confinarmo": "confinar",
    "confinarmos": "confinar",
    "confinará": "confinar",
    "confinarás": "confinar",
    "confinarão": "confinar",
    "confinaríamos": "confinar",
    "confinaríeis": "confinar",
    "confinas": "confinar",
    "confinasse": "confinar",
    "confinassem": "confinar",
    "confinasses": "confinar",
    "confinaste": "confinar",
    "confinastes": "confinar",
    "confinava": "confinar",
    "confinavam": "confinar",
    "confinavas": "confinar",
    "confine": "confinar",
    "confinei": "confinar",
    "confineis": "confinar",
    "confinem": "confinar",
    "confinemo": "confinar",
    "confinemos": "confinar",
    "confines": "confinar",
    "confinidades": "confinidade",
    "confino": "confinar",
    "confinou": "confinar",
    "confins": "confim",
    "confiná": "confinar",
    "confinámo": "confinar",
    "confinámos": "confinar",
    "confináramo": "confinar",
    "confináramos": "confinar",
    "confinárei": "confinar",
    "confináreis": "confinar",
    "confinásseis": "confinar",
    "confinássemos": "confinar",
    "confinávamo": "confinar",
    "confinávamos": "confinar",
    "confinávei": "confinar",
    "confináveis": "confinar",
    "confio": "confiar",
    "confiou": "confiar",
    "confira": "conferir",
    "confirais": "conferir",
    "confiram": "conferir",
    "confiramo": "conferir",
    "confiramos": "conferir",
    "confiras": "conferir",
    "confirma": "confirmar",
    "confirmada": "confirmar",
    "confirmadas": "confirmar",
    "confirmado": "confirmar",
    "confirmadora": "confirmador",
    "confirmadoras": "confirmador",
    "confirmadores": "confirmador",
    "confirmados": "confirmar",
    "confirmai": "confirmar",
    "confirmais": "confirmar",
    "confirmam": "confirmar",
    "confirmamo": "confirmar",
    "confirmamos": "confirmar",
    "confirmando": "confirmar",
    "confirmantes": "confirmante",
    "confirmara": "confirmar",
    "confirmaram": "confirmar",
    "confirmaras": "confirmar",
    "confirmarde": "confirmar",
    "confirmardes": "confirmar",
    "confirmare": "confirmar",
    "confirmarei": "confirmar",
    "confirmareis": "confirmar",
    "confirmarem": "confirmar",
    "confirmaremos": "confirmar",
    "confirmares": "confirmar",
    "confirmaria": "confirmar",
    "confirmariam": "confirmar",
    "confirmarias": "confirmar",
    "confirmarmo": "confirmar",
    "confirmarmos": "confirmar",
    "confirmará": "confirmar",
    "confirmarás": "confirmar",
    "confirmarão": "confirmar",
    "confirmaríamos": "confirmar",
    "confirmaríeis": "confirmar",
    "confirmas": "confirmar",
    "confirmasse": "confirmar",
    "confirmassem": "confirmar",
    "confirmasses": "confirmar",
    "confirmaste": "confirmar",
    "confirmastes": "confirmar",
    "confirmativa": "confirmativo",
    "confirmativas": "confirmativo",
    "confirmativos": "confirmativo",
    "confirmatória": "confirmatório",
    "confirmatórias": "confirmatório",
    "confirmatórios": "confirmatório",
    "confirmava": "confirmar",
    "confirmavam": "confirmar",
    "confirmavas": "confirmar",
    "confirmações": "confirmação",
    "confirme": "confirmar",
    "confirmei": "confirmar",
    "confirmeis": "confirmar",
    "confirmem": "confirmar",
    "confirmemo": "confirmar",
    "confirmemos": "confirmar",
    "confirmes": "confirmar",
    "confirmo": "confirmar",
    "confirmou": "confirmar",
    "confirmá": "confirmar",
    "confirmámo": "confirmar",
    "confirmámos": "confirmar",
    "confirmáramo": "confirmar",
    "confirmáramos": "confirmar",
    "confirmárei": "confirmar",
    "confirmáreis": "confirmar",
    "confirmásseis": "confirmar",
    "confirmássemos": "confirmar",
    "confirmávamo": "confirmar",
    "confirmávamos": "confirmar",
    "confirmávei": "confirmar",
    "confirmáveis": "confirmar",
    "confiro": "conferir",
    "confisca": "confiscar",
    "confiscada": "confiscar",
    "confiscadas": "confiscar",
    "confiscado": "confiscar",
    "confiscados": "confiscar",
    "confiscai": "confiscar",
    "confiscais": "confiscar",
    "confiscam": "confiscar",
    "confiscamo": "confiscar",
    "confiscamos": "confiscar",
    "confiscando": "confiscar",
    "confiscara": "confiscar",
    "confiscaram": "confiscar",
    "confiscaras": "confiscar",
    "confiscarde": "confiscar",
    "confiscardes": "confiscar",
    "confiscare": "confiscar",
    "confiscarei": "confiscar",
    "confiscareis": "confiscar",
    "confiscarem": "confiscar",
    "confiscaremos": "confiscar",
    "confiscares": "confiscar",
    "confiscaria": "confiscar",
    "confiscariam": "confiscar",
    "confiscarias": "confiscar",
    "confiscarmo": "confiscar",
    "confiscarmos": "confiscar",
    "confiscará": "confiscar",
    "confiscarás": "confiscar",
    "confiscarão": "confiscar",
    "confiscaríamos": "confiscar",
    "confiscaríeis": "confiscar",
    "confiscas": "confiscar",
    "confiscasse": "confiscar",
    "confiscassem": "confiscar",
    "confiscasses": "confiscar",
    "confiscaste": "confiscar",
    "confiscastes": "confiscar",
    "confiscava": "confiscar",
    "confiscavam": "confiscar",
    "confiscavas": "confiscar",
    "confiscações": "confiscação",
    "confisco": "confiscar",
    "confiscos": "confisco",
    "confiscou": "confiscar",
    "confiscá": "confiscar",
    "confiscámo": "confiscar",
    "confiscámos": "confiscar",
    "confiscáramo": "confiscar",
    "confiscáramos": "confiscar",
    "confiscárei": "confiscar",
    "confiscáreis": "confiscar",
    "confiscásseis": "confiscar",
    "confiscássemos": "confiscar",
    "confiscávamo": "confiscar",
    "confiscávamos": "confiscar",
    "confiscávei": "confiscar",
    "confiscáveis": "confiscável",
    "confisque": "confiscar",
    "confisquei": "confiscar",
    "confisqueis": "confiscar",
    "confisquem": "confiscar",
    "confisquemo": "confiscar",
    "confisquemos": "confiscar",
    "confisques": "confiscar",
    "confissões": "confissão",
    "confitas": "confita",
    "confitentes": "confitente",
    "confiá": "confiar",
    "confiámo": "confiar",
    "confiámos": "confiar",
    "confiáramo": "confiar",
    "confiáramos": "confiar",
    "confiárei": "confiar",
    "confiáreis": "confiar",
    "confiásseis": "confiar",
    "confiássemos": "confiar",
    "confiávamo": "confiar",
    "confiávamos": "confiar",
    "confiávei": "confiar",
    "confiáveis": "confiar",
    "conflagra": "conflagrar",
    "conflagrada": "conflagrar",
    "conflagradas": "conflagrar",
    "conflagrado": "conflagrar",
    "conflagrados": "conflagrar",
    "conflagrai": "conflagrar",
    "conflagrais": "conflagrar",
    "conflagram": "conflagrar",
    "conflagramo": "conflagrar",
    "conflagramos": "conflagrar",
    "conflagrando": "conflagrar",
    "conflagrara": "conflagrar",
    "conflagraram": "conflagrar",
    "conflagraras": "conflagrar",
    "conflagrarde": "conflagrar",
    "conflagrardes": "conflagrar",
    "conflagrare": "conflagrar",
    "conflagrarei": "conflagrar",
    "conflagrareis": "conflagrar",
    "conflagrarem": "conflagrar",
    "conflagraremos": "conflagrar",
    "conflagrares": "conflagrar",
    "conflagraria": "conflagrar",
    "conflagrariam": "conflagrar",
    "conflagrarias": "conflagrar",
    "conflagrarmo": "conflagrar",
    "conflagrarmos": "conflagrar",
    "conflagrará": "conflagrar",
    "conflagrarás": "conflagrar",
    "conflagrarão": "conflagrar",
    "conflagraríamos": "conflagrar",
    "conflagraríeis": "conflagrar",
    "conflagras": "conflagrar",
    "conflagrasse": "conflagrar",
    "conflagrassem": "conflagrar",
    "conflagrasses": "conflagrar",
    "conflagraste": "conflagrar",
    "conflagrastes": "conflagrar",
    "conflagrava": "conflagrar",
    "conflagravam": "conflagrar",
    "conflagravas": "conflagrar",
    "conflagrações": "conflagração",
    "conflagre": "conflagrar",
    "conflagrei": "conflagrar",
    "conflagreis": "conflagrar",
    "conflagrem": "conflagrar",
    "conflagremo": "conflagrar",
    "conflagremos": "conflagrar",
    "conflagres": "conflagrar",
    "conflagro": "conflagrar",
    "conflagrou": "conflagrar",
    "conflagrá": "conflagrar",
    "conflagrámo": "conflagrar",
    "conflagrámos": "conflagrar",
    "conflagráramo": "conflagrar",
    "conflagráramos": "conflagrar",
    "conflagrárei": "conflagrar",
    "conflagráreis": "conflagrar",
    "conflagrásseis": "conflagrar",
    "conflagrássemos": "conflagrar",
    "conflagrávamo": "conflagrar",
    "conflagrávamos": "conflagrar",
    "conflagrávei": "conflagrar",
    "conflagráveis": "conflagrável",
    "conflitos": "conflito",
    "conflituais": "conflitual",
    "conflitualidades": "conflitualidade",
    "conflituosa": "conflituoso",
    "conflituosas": "conflituoso",
    "conflituosidades": "conflituosidade",
    "conflituosos": "conflituoso",
    "conflua": "confluir",
    "confluais": "confluir",
    "confluam": "confluir",
    "confluamo": "confluir",
    "confluamos": "confluir",
    "confluas": "confluir",
    "confluem": "confluir",
    "confluentes": "confluente",
    "conflui": "confluir",
    "confluindo": "confluir",
    "confluirde": "confluir",
    "confluirdes": "confluir",
    "confluirei": "confluir",
    "confluireis": "confluir",
    "confluiremos": "confluir",
    "confluiria": "confluir",
    "confluiriam": "confluir",
    "confluirias": "confluir",
    "confluirmo": "confluir",
    "confluirmos": "confluir",
    "confluirá": "confluir",
    "confluirás": "confluir",
    "confluirão": "confluir",
    "confluiríamos": "confluir",
    "confluiríeis": "confluir",
    "confluis": "confluir",
    "confluiu": "confluir",
    "confluo": "confluir",
    "confluências": "confluência",
    "confluí": "confluir",
    "confluía": "confluir",
    "confluíam": "confluir",
    "confluíamo": "confluir",
    "confluíamos": "confluir",
    "confluías": "confluir",
    "confluída": "confluir",
    "confluídas": "confluir",
    "confluído": "confluir",
    "confluídos": "confluir",
    "confluíei": "confluir",
    "confluíeis": "confluir",
    "confluímo": "confluir",
    "confluímos": "confluir",
    "confluíra": "confluir",
    "confluíram": "confluir",
    "confluíramo": "confluir",
    "confluíramos": "confluir",
    "confluíras": "confluir",
    "confluíre": "confluir",
    "confluírei": "confluir",
    "confluíreis": "confluir",
    "confluírem": "confluir",
    "confluíres": "confluir",
    "confluís": "confluir",
    "confluísse": "confluir",
    "confluísseis": "confluir",
    "confluíssem": "confluir",
    "confluíssemos": "confluir",
    "confluísses": "confluir",
    "confluíste": "confluir",
    "confluístes": "confluir",
    "confoge": "confugir",
    "confogem": "confugir",
    "confoges": "confugir",
    "conforma": "conformar",
    "conformada": "conformar",
    "conformadas": "conformar",
    "conformado": "conformar",
    "conformadora": "conformador",
    "conformadoras": "conformador",
    "conformadores": "conformador",
    "conformados": "conformar",
    "conformai": "conformar",
    "conformais": "conformar",
    "conformam": "conformar",
    "conformamo": "conformar",
    "conformamos": "conformar",
    "conformando": "conformar",
    "conformara": "conformar",
    "conformaram": "conformar",
    "conformaras": "conformar",
    "conformarde": "conformar",
    "conformardes": "conformar",
    "conformare": "conformar",
    "conformarei": "conformar",
    "conformareis": "conformar",
    "conformarem": "conformar",
    "conformaremos": "conformar",
    "conformares": "conformar",
    "conformaria": "conformar",
    "conformariam": "conformar",
    "conformarias": "conformar",
    "conformarmo": "conformar",
    "conformarmos": "conformar",
    "conformará": "conformar",
    "conformarás": "conformar",
    "conformarão": "conformar",
    "conformaríamos": "conformar",
    "conformaríeis": "conformar",
    "conformas": "conformar",
    "conformasse": "conformar",
    "conformassem": "conformar",
    "conformasses": "conformar",
    "conformaste": "conformar",
    "conformastes": "conformar",
    "conformativa": "conformativo",
    "conformativas": "conformativo",
    "conformativos": "conformativo",
    "conformava": "conformar",
    "conformavam": "conformar",
    "conformavas": "conformar",
    "conformações": "conformação",
    "conforme": "conformar",
    "conformei": "conformar",
    "conformeis": "conformar",
    "conformem": "conformar",
    "conformemo": "conformar",
    "conformemos": "conformar",
    "conformes": "conforme",
    "conformidades": "conformidade",
    "conformismos": "conformismo",
    "conformistas": "conformista",
    "conformo": "conformar",
    "conformou": "conformar",
    "conformá": "conformar",
    "conformámo": "conformar",
    "conformámos": "conformar",
    "conformáramo": "conformar",
    "conformáramos": "conformar",
    "conformárei": "conformar",
    "conformáreis": "conformar",
    "conformásseis": "conformar",
    "conformássemos": "conformar",
    "conformávamo": "conformar",
    "conformávamos": "conformar",
    "conformávei": "conformar",
    "conformáveis": "conformável",
    "conforta": "confortar",
    "confortabilidades": "confortabilidade",
    "confortada": "confortar",
    "confortadas": "confortar",
    "confortado": "confortar",
    "confortadora": "confortador",
    "confortadoras": "confortador",
    "confortadores": "confortador",
    "confortados": "confortar",
    "confortai": "confortar",
    "confortais": "confortar",
    "confortam": "confortar",
    "confortamentos": "confortamento",
    "confortamo": "confortar",
    "confortamos": "confortar",
    "confortando": "confortar",
    "confortantes": "confortante",
    "confortara": "confortar",
    "confortaram": "confortar",
    "confortaras": "confortar",
    "confortarde": "confortar",
    "confortardes": "confortar",
    "confortare": "confortar",
    "confortarei": "confortar",
    "confortareis": "confortar",
    "confortarem": "confortar",
    "confortaremos": "confortar",
    "confortares": "confortar",
    "confortaria": "confortar",
    "confortariam": "confortar",
    "confortarias": "confortar",
    "confortarmo": "confortar",
    "confortarmos": "confortar",
    "confortará": "confortar",
    "confortarás": "confortar",
    "confortarão": "confortar",
    "confortaríamos": "confortar",
    "confortaríeis": "confortar",
    "confortas": "confortar",
    "confortasse": "confortar",
    "confortassem": "confortar",
    "confortasses": "confortar",
    "confortaste": "confortar",
    "confortastes": "confortar",
    "confortativa": "confortativo",
    "confortativas": "confortativo",
    "confortativos": "confortativo",
    "confortava": "confortar",
    "confortavam": "confortar",
    "confortavas": "confortar",
    "confortações": "confortação",
    "conforte": "confortar",
    "confortei": "confortar",
    "conforteis": "confortar",
    "confortem": "confortar",
    "confortemo": "confortar",
    "confortemos": "confortar",
    "confortes": "confortar",
    "conforto": "confortar",
    "confortos": "conforto",
    "confortou": "confortar",
    "confortá": "confortar",
    "confortámo": "confortar",
    "confortámos": "confortar",
    "confortáramo": "confortar",
    "confortáramos": "confortar",
    "confortárei": "confortar",
    "confortáreis": "confortar",
    "confortásseis": "confortar",
    "confortássemos": "confortar",
    "confortávamo": "confortar",
    "confortávamos": "confortar",
    "confortávei": "confortar",
    "confortáveis": "confortável",
    "confrades": "confrade",
    "confragosa": "confragoso",
    "confragosas": "confragoso",
    "confragosos": "confragoso",
    "confrange": "confranger",
    "confrangedora": "confrangedor",
    "confrangedoras": "confrangedor",
    "confrangedores": "confrangedor",
    "confrangei": "confranger",
    "confrangeis": "confranger",
    "confrangem": "confranger",
    "confrangemo": "confranger",
    "confrangemos": "confranger",
    "confrangendo": "confranger",
    "confrangentes": "confrangente",
    "confrangera": "confranger",
    "confrangeram": "confranger",
    "confrangeras": "confranger",
    "confrangerde": "confranger",
    "confrangerdes": "confranger",
    "confrangere": "confranger",
    "confrangerei": "confranger",
    "confrangereis": "confranger",
    "confrangerem": "confranger",
    "confrangeremos": "confranger",
    "confrangeres": "confranger",
    "confrangeria": "confranger",
    "confrangeriam": "confranger",
    "confrangerias": "confranger",
    "confrangermo": "confranger",
    "confrangermos": "confranger",
    "confrangerá": "confranger",
    "confrangerás": "confranger",
    "confrangerão": "confranger",
    "confrangeríamos": "confranger",
    "confrangeríeis": "confranger",
    "confranges": "confranger",
    "confrangesse": "confranger",
    "confrangessem": "confranger",
    "confrangesses": "confranger",
    "confrangeste": "confranger",
    "confrangestes": "confranger",
    "confrangeu": "confranger",
    "confrangi": "confranger",
    "confrangia": "confranger",
    "confrangiam": "confranger",
    "confrangias": "confranger",
    "confrangida": "confrangido",
    "confrangidas": "confrangido",
    "confrangido": "confranger",
    "confrangidos": "confrangido",
    "confrangidíssima": "confrangido",
    "confrangidíssimas": "confrangido",
    "confrangidíssimo": "confrangido",
    "confrangidíssimos": "confrangido",
    "confrangimentos": "confrangimento",
    "confrangê": "confranger",
    "confrangêramo": "confranger",
    "confrangêramos": "confranger",
    "confrangêrei": "confranger",
    "confrangêreis": "confranger",
    "confrangêsseis": "confranger",
    "confrangêssemos": "confranger",
    "confrangíamo": "confranger",
    "confrangíamos": "confranger",
    "confrangíei": "confranger",
    "confrangíeis": "confranger",
    "confranja": "confranger",
    "confranjais": "confranger",
    "confranjam": "confranger",
    "confranjamo": "confranger",
    "confranjamos": "confranger",
    "confranjas": "confranger",
    "confranjo": "confranger",
    "confrarias": "confraria",
    "confraterna": "confraterno",
    "confraternada": "confraternar",
    "confraternadas": "confraternar",
    "confraternado": "confraternar",
    "confraternados": "confraternar",
    "confraternai": "confraternar",
    "confraternais": "confraternar",
    "confraternam": "confraternar",
    "confraternamo": "confraternar",
    "confraternamos": "confraternar",
    "confraternando": "confraternar",
    "confraternara": "confraternar",
    "confraternaram": "confraternar",
    "confraternaras": "confraternar",
    "confraternarde": "confraternar",
    "confraternardes": "confraternar",
    "confraternare": "confraternar",
    "confraternarei": "confraternar",
    "confraternareis": "confraternar",
    "confraternarem": "confraternar",
    "confraternaremos": "confraternar",
    "confraternares": "confraternar",
    "confraternaria": "confraternar",
    "confraternariam": "confraternar",
    "confraternarias": "confraternar",
    "confraternarmo": "confraternar",
    "confraternarmos": "confraternar",
    "confraternará": "confraternar",
    "confraternarás": "confraternar",
    "confraternarão": "confraternar",
    "confraternaríamos": "confraternar",
    "confraternaríeis": "confraternar",
    "confraternas": "confraterno",
    "confraternasse": "confraternar",
    "confraternassem": "confraternar",
    "confraternasses": "confraternar",
    "confraternaste": "confraternar",
    "confraternastes": "confraternar",
    "confraternava": "confraternar",
    "confraternavam": "confraternar",
    "confraternavas": "confraternar",
    "confraterne": "confraternar",
    "confraternei": "confraternar",
    "confraterneis": "confraternar",
    "confraternem": "confraternar",
    "confraternemo": "confraternar",
    "confraternemos": "confraternar",
    "confraternes": "confraternar",
    "confraternidades": "confraternidade",
    "confraterniza": "confraternizar",
    "confraternizada": "confraternizar",
    "confraternizadas": "confraternizar",
    "confraternizado": "confraternizar",
    "confraternizados": "confraternizar",
    "confraternizai": "confraternizar",
    "confraternizais": "confraternizar",
    "confraternizam": "confraternizar",
    "confraternizamo": "confraternizar",
    "confraternizamos": "confraternizar",
    "confraternizando": "confraternizar",
    "confraternizara": "confraternizar",
    "confraternizaram": "confraternizar",
    "confraternizaras": "confraternizar",
    "confraternizarde": "confraternizar",
    "confraternizardes": "confraternizar",
    "confraternizare": "confraternizar",
    "confraternizarei": "confraternizar",
    "confraternizareis": "confraternizar",
    "confraternizarem": "confraternizar",
    "confraternizaremos": "confraternizar",
    "confraternizares": "confraternizar",
    "confraternizaria": "confraternizar",
    "confraternizariam": "confraternizar",
    "confraternizarias": "confraternizar",
    "confraternizarmo": "confraternizar",
    "confraternizarmos": "confraternizar",
    "confraternizará": "confraternizar",
    "confraternizarás": "confraternizar",
    "confraternizarão": "confraternizar",
    "confraternizaríamos": "confraternizar",
    "confraternizaríeis": "confraternizar",
    "confraternizas": "confraternizar",
    "confraternizasse": "confraternizar",
    "confraternizassem": "confraternizar",
    "confraternizasses": "confraternizar",
    "confraternizaste": "confraternizar",
    "confraternizastes": "confraternizar",
    "confraternizava": "confraternizar",
    "confraternizavam": "confraternizar",
    "confraternizavas": "confraternizar",
    "confraternizações": "confraternização",
    "confraternize": "confraternizar",
    "confraternizei": "confraternizar",
    "confraternizeis": "confraternizar",
    "confraternizem": "confraternizar",
    "confraternizemo": "confraternizar",
    "confraternizemos": "confraternizar",
    "confraternizes": "confraternizar",
    "confraternizo": "confraternizar",
    "confraternizou": "confraternizar",
    "confraternizá": "confraternizar",
    "confraternizámo": "confraternizar",
    "confraternizámos": "confraternizar",
    "confraternizáramo": "confraternizar",
    "confraternizáramos": "confraternizar",
    "confraternizárei": "confraternizar",
    "confraternizáreis": "confraternizar",
    "confraternizásseis": "confraternizar",
    "confraternizássemos": "confraternizar",
    "confraternizávamo": "confraternizar",
    "confraternizávamos": "confraternizar",
    "confraternizávei": "confraternizar",
    "confraternizáveis": "confraternizar",
    "confraterno": "confraternar",
    "confraternos": "confraterno",
    "confraternou": "confraternar",
    "confraterná": "confraternar",
    "confraternámo": "confraternar",
    "confraternámos": "confraternar",
    "confraternáramo": "confraternar",
    "confraternáramos": "confraternar",
    "confraternárei": "confraternar",
    "confraternáreis": "confraternar",
    "confraternásseis": "confraternar",
    "confraternássemos": "confraternar",
    "confraternávamo": "confraternar",
    "confraternávamos": "confraternar",
    "confraternávei": "confraternar",
    "confraternáveis": "confraternar",
    "confreiras": "confreira",
    "confronta": "confrontar",
    "confrontada": "confrontar",
    "confrontadas": "confrontar",
    "confrontado": "confrontar",
    "confrontadora": "confrontador",
    "confrontadoras": "confrontador",
    "confrontadores": "confrontador",
    "confrontados": "confrontar",
    "confrontai": "confrontar",
    "confrontais": "confrontar",
    "confrontam": "confrontar",
    "confrontamo": "confrontar",
    "confrontamos": "confrontar",
    "confrontando": "confrontar",
    "confrontantes": "confrontante",
    "confrontara": "confrontar",
    "confrontaram": "confrontar",
    "confrontaras": "confrontar",
    "confrontarde": "confrontar",
    "confrontardes": "confrontar",
    "confrontare": "confrontar",
    "confrontarei": "confrontar",
    "confrontareis": "confrontar",
    "confrontarem": "confrontar",
    "confrontaremos": "confrontar",
    "confrontares": "confrontar",
    "confrontaria": "confrontar",
    "confrontariam": "confrontar",
    "confrontarias": "confrontar",
    "confrontarmo": "confrontar",
    "confrontarmos": "confrontar",
    "confrontará": "confrontar",
    "confrontarás": "confrontar",
    "confrontarão": "confrontar",
    "confrontaríamos": "confrontar",
    "confrontaríeis": "confrontar",
    "confrontas": "confrontar",
    "confrontasse": "confrontar",
    "confrontassem": "confrontar",
    "confrontasses": "confrontar",
    "confrontaste": "confrontar",
    "confrontastes": "confrontar",
    "confrontava": "confrontar",
    "confrontavam": "confrontar",
    "confrontavas": "confrontar",
    "confrontações": "confrontação",
    "confronte": "confrontar",
    "confrontei": "confrontar",
    "confronteis": "confrontar",
    "confrontem": "confrontar",
    "confrontemo": "confrontar",
    "confrontemos": "confrontar",
    "confrontes": "confronte",
    "confronto": "confrontar",
    "confrontos": "confronto",
    "confrontou": "confrontar",
    "confrontá": "confrontar",
    "confrontámo": "confrontar",
    "confrontámos": "confrontar",
    "confrontáramo": "confrontar",
    "confrontáramos": "confrontar",
    "confrontárei": "confrontar",
    "confrontáreis": "confrontar",
    "confrontásseis": "confrontar",
    "confrontássemos": "confrontar",
    "confrontávamo": "confrontar",
    "confrontávamos": "confrontar",
    "confrontávei": "confrontar",
    "confrontáveis": "confrontável",
    "confucianismos": "confucianismo",
    "confucianistas": "confucianista",
    "confucionismos": "confucionismo",
    "confugi": "confugir",
    "confugia": "confugir",
    "confugiam": "confugir",
    "confugias": "confugir",
    "confugida": "confugir",
    "confugidas": "confugir",
    "confugido": "confugir",
    "confugidos": "confugir",
    "confugimo": "confugir",
    "confugimos": "confugir",
    "confugindo": "confugir",
    "confugira": "confugir",
    "confugiram": "confugir",
    "confugiras": "confugir",
    "confugirdes": "confugir",
    "confugirei": "confugir",
    "confugireis": "confugir",
    "confugirem": "confugir",
    "confugiremos": "confugir",
    "confugires": "confugir",
    "confugiria": "confugir",
    "confugiriam": "confugir",
    "confugirias": "confugir",
    "confugirmo": "confugir",
    "confugirmos": "confugir",
    "confugirá": "confugir",
    "confugirás": "confugir",
    "confugirão": "confugir",
    "confugiríamos": "confugir",
    "confugiríeis": "confugir",
    "confugis": "confugir",
    "confugisse": "confugir",
    "confugissem": "confugir",
    "confugisses": "confugir",
    "confugiste": "confugir",
    "confugistes": "confugir",
    "confugiu": "confugir",
    "confugíamo": "confugir",
    "confugíamos": "confugir",
    "confugíeis": "confugir",
    "confugíramo": "confugir",
    "confugíramos": "confugir",
    "confugíreis": "confugir",
    "confugísseis": "confugir",
    "confugíssemos": "confugir",
    "confuja": "confugir",
    "confujais": "confugir",
    "confujam": "confugir",
    "confujamo": "confugir",
    "confujamos": "confugir",
    "confujas": "confugir",
    "confujo": "confugir",
    "confunda": "confundir",
    "confundais": "confundir",
    "confundam": "confundir",
    "confundamo": "confundir",
    "confundamos": "confundir",
    "confundas": "confundir",
    "confunde": "confundir",
    "confundem": "confundir",
    "confundes": "confundir",
    "confundi": "confundir",
    "confundia": "confundir",
    "confundiam": "confundir",
    "confundias": "confundir",
    "confundida": "confundir",
    "confundidas": "confundir",
    "confundido": "confundir",
    "confundidos": "confundir",
    "confundidíssima": "confundido",
    "confundidíssimas": "confundido",
    "confundidíssimo": "confundido",
    "confundidíssimos": "confundido",
    "confundimo": "confundir",
    "confundimos": "confundir",
    "confundindo": "confundir",
    "confundira": "confundir",
    "confundiram": "confundir",
    "confundiras": "confundir",
    "confundirde": "confundir",
    "confundirdes": "confundir",
    "confundire": "confundir",
    "confundirei": "confundir",
    "confundireis": "confundir",
    "confundirem": "confundir",
    "confundiremos": "confundir",
    "confundires": "confundir",
    "confundiria": "confundir",
    "confundiriam": "confundir",
    "confundirias": "confundir",
    "confundirmo": "confundir",
    "confundirmos": "confundir",
    "confundirá": "confundir",
    "confundirás": "confundir",
    "confundirão": "confundir",
    "confundiríamos": "confundir",
    "confundiríeis": "confundir",
    "confundis": "confundir",
    "confundisse": "confundir",
    "confundissem": "confundir",
    "confundisses": "confundir",
    "confundiste": "confundir",
    "confundistes": "confundir",
    "confundiu": "confundir",
    "confundo": "confundir",
    "confundíamo": "confundir",
    "confundíamos": "confundir",
    "confundíei": "confundir",
    "confundíeis": "confundir",
    "confundíramo": "confundir",
    "confundíramos": "confundir",
    "confundírei": "confundir",
    "confundíreis": "confundir",
    "confundísseis": "confundir",
    "confundíssemos": "confundir",
    "confundíveis": "confundível",
    "confusa": "confuso",
    "confusas": "confuso",
    "confusos": "confuso",
    "confusotes": "confusote",
    "confusões": "confusão",
    "confuta": "confutar",
    "confutada": "confutar",
    "confutadas": "confutar",
    "confutado": "confutar",
    "confutadora": "confutador",
    "confutadoras": "confutador",
    "confutadores": "confutador",
    "confutados": "confutar",
    "confutai": "confutar",
    "confutais": "confutar",
    "confutam": "confutar",
    "confutamo": "confutar",
    "confutamos": "confutar",
    "confutando": "confutar",
    "confutara": "confutar",
    "confutaram": "confutar",
    "confutaras": "confutar",
    "confutarde": "confutar",
    "confutardes": "confutar",
    "confutare": "confutar",
    "confutarei": "confutar",
    "confutareis": "confutar",
    "confutarem": "confutar",
    "confutaremos": "confutar",
    "confutares": "confutar",
    "confutaria": "confutar",
    "confutariam": "confutar",
    "confutarias": "confutar",
    "confutarmo": "confutar",
    "confutarmos": "confutar",
    "confutará": "confutar",
    "confutarás": "confutar",
    "confutarão": "confutar",
    "confutaríamos": "confutar",
    "confutaríeis": "confutar",
    "confutas": "confutar",
    "confutasse": "confutar",
    "confutassem": "confutar",
    "confutasses": "confutar",
    "confutaste": "confutar",
    "confutastes": "confutar",
    "confutava": "confutar",
    "confutavam": "confutar",
    "confutavas": "confutar",
    "confutações": "confutação",
    "confute": "confutar",
    "confutei": "confutar",
    "confuteis": "confutar",
    "confutem": "confutar",
    "confutemo": "confutar",
    "confutemos": "confutar",
    "confutes": "confutar",
    "confuto": "confutar",
    "confutou": "confutar",
    "confutá": "confutar",
    "confutámo": "confutar",
    "confutámos": "confutar",
    "confutáramo": "confutar",
    "confutáramos": "confutar",
    "confutárei": "confutar",
    "confutáreis": "confutar",
    "confutásseis": "confutar",
    "confutássemos": "confutar",
    "confutávamo": "confutar",
    "confutávamos": "confutar",
    "confutávei": "confutar",
    "confutáveis": "confutável",
    "congas": "conga",
    "congela": "congelar",
    "congelabilidades": "congelabilidade",
    "congelada": "congelar",
    "congeladas": "congelar",
    "congelado": "congelar",
    "congeladora": "congelador",
    "congeladoras": "congelador",
    "congeladores": "congelador",
    "congelados": "congelar",
    "congelai": "congelar",
    "congelais": "congelar",
    "congelam": "congelar",
    "congelamentos": "congelamento",
    "congelamo": "congelar",
    "congelamos": "congelar",
    "congelando": "congelar",
    "congelantes": "congelante",
    "congelara": "congelar",
    "congelaram": "congelar",
    "congelaras": "congelar",
    "congelarde": "congelar",
    "congelardes": "congelar",
    "congelare": "congelar",
    "congelarei": "congelar",
    "congelareis": "congelar",
    "congelarem": "congelar",
    "congelaremos": "congelar",
    "congelares": "congelar",
    "congelaria": "congelar",
    "congelariam": "congelar",
    "congelarias": "congelar",
    "congelarmo": "congelar",
    "congelarmos": "congelar",
    "congelará": "congelar",
    "congelarás": "congelar",
    "congelarão": "congelar",
    "congelaríamos": "congelar",
    "congelaríeis": "congelar",
    "congelas": "congelar",
    "congelasse": "congelar",
    "congelassem": "congelar",
    "congelasses": "congelar",
    "congelaste": "congelar",
    "congelastes": "congelar",
    "congelativa": "congelativo",
    "congelativas": "congelativo",
    "congelativos": "congelativo",
    "congelava": "congelar",
    "congelavam": "congelar",
    "congelavas": "congelar",
    "congelações": "congelação",
    "congele": "congelar",
    "congelei": "congelar",
    "congeleis": "congelar",
    "congelem": "congelar",
    "congelemo": "congelar",
    "congelemos": "congelar",
    "congeles": "congelar",
    "congelo": "congelar",
    "congelos": "congelo",
    "congelou": "congelar",
    "congelá": "congelar",
    "congelámo": "congelar",
    "congelámos": "congelar",
    "congeláramo": "congelar",
    "congeláramos": "congelar",
    "congelárei": "congelar",
    "congeláreis": "congelar",
    "congelásseis": "congelar",
    "congelássemos": "congelar",
    "congelávamo": "congelar",
    "congelávamos": "congelar",
    "congelávei": "congelar",
    "congeláveis": "congelável",
    "congemina": "congeminar",
    "congeminada": "congeminar",
    "congeminadas": "congeminar",
    "congeminado": "congeminar",
    "congeminadora": "congeminador",
    "congeminadoras": "congeminador",
    "congeminadores": "congeminador",
    "congeminados": "congeminar",
    "congeminai": "congeminar",
    "congeminais": "congeminar",
    "congeminam": "congeminar",
    "congeminamo": "congeminar",
    "congeminamos": "congeminar",
    "congeminando": "congeminar",
    "congeminantes": "congeminante",
    "congeminara": "congeminar",
    "congeminaram": "congeminar",
    "congeminaras": "congeminar",
    "congeminarde": "congeminar",
    "congeminardes": "congeminar",
    "congeminare": "congeminar",
    "congeminarei": "congeminar",
    "congeminareis": "congeminar",
    "congeminarem": "congeminar",
    "congeminaremos": "congeminar",
    "congeminares": "congeminar",
    "congeminaria": "congeminar",
    "congeminariam": "congeminar",
    "congeminarias": "congeminar",
    "congeminarmo": "congeminar",
    "congeminarmos": "congeminar",
    "congeminará": "congeminar",
    "congeminarás": "congeminar",
    "congeminarão": "congeminar",
    "congeminaríamos": "congeminar",
    "congeminaríeis": "congeminar",
    "congeminas": "congeminar",
    "congeminasse": "congeminar",
    "congeminassem": "congeminar",
    "congeminasses": "congeminar",
    "congeminaste": "congeminar",
    "congeminastes": "congeminar",
    "congeminativa": "congeminativo",
    "congeminativas": "congeminativo",
    "congeminativos": "congeminativo",
    "congeminava": "congeminar",
    "congeminavam": "congeminar",
    "congeminavas": "congeminar",
    "congeminações": "congeminação",
    "congemine": "congeminar",
    "congeminei": "congeminar",
    "congemineis": "congeminar",
    "congeminem": "congeminar",
    "congeminemo": "congeminar",
    "congeminemos": "congeminar",
    "congeminentes": "congeminente",
    "congemines": "congeminar",
    "congemino": "congeminar",
    "congeminou": "congeminar",
    "congeminá": "congeminar",
    "congeminámo": "congeminar",
    "congeminámos": "congeminar",
    "congemináramo": "congeminar",
    "congemináramos": "congeminar",
    "congeminárei": "congeminar",
    "congemináreis": "congeminar",
    "congeminásseis": "congeminar",
    "congeminássemos": "congeminar",
    "congeminávamo": "congeminar",
    "congeminávamos": "congeminar",
    "congeminávei": "congeminar",
    "congemináveis": "congeminar",
    "congeminências": "congeminência",
    "congeneridades": "congeneridade",
    "congeniais": "congenial",
    "congenialidades": "congenialidade",
    "congestiona": "congestionar",
    "congestionada": "congestionar",
    "congestionadas": "congestionar",
    "congestionado": "congestionar",
    "congestionados": "congestionar",
    "congestionai": "congestionar",
    "congestionais": "congestionar",
    "congestionam": "congestionar",
    "congestionamentos": "congestionamento",
    "congestionamo": "congestionar",
    "congestionamos": "congestionar",
    "congestionando": "congestionar",
    "congestionantes": "congestionante",
    "congestionara": "congestionar",
    "congestionaram": "congestionar",
    "congestionaras": "congestionar",
    "congestionarde": "congestionar",
    "congestionardes": "congestionar",
    "congestionare": "congestionar",
    "congestionarei": "congestionar",
    "congestionareis": "congestionar",
    "congestionarem": "congestionar",
    "congestionaremos": "congestionar",
    "congestionares": "congestionar",
    "congestionaria": "congestionar",
    "congestionariam": "congestionar",
    "congestionarias": "congestionar",
    "congestionarmo": "congestionar",
    "congestionarmos": "congestionar",
    "congestionará": "congestionar",
    "congestionarás": "congestionar",
    "congestionarão": "congestionar",
    "congestionaríamos": "congestionar",
    "congestionaríeis": "congestionar",
    "congestionas": "congestionar",
    "congestionasse": "congestionar",
    "congestionassem": "congestionar",
    "congestionasses": "congestionar",
    "congestionaste": "congestionar",
    "congestionastes": "congestionar",
    "congestionava": "congestionar",
    "congestionavam": "congestionar",
    "congestionavas": "congestionar",
    "congestione": "congestionar",
    "congestionei": "congestionar",
    "congestioneis": "congestionar",
    "congestionem": "congestionar",
    "congestionemo": "congestionar",
    "congestionemos": "congestionar",
    "congestiones": "congestionar",
    "congestiono": "congestionar",
    "congestionou": "congestionar",
    "congestioná": "congestionar",
    "congestionámo": "congestionar",
    "congestionámos": "congestionar",
    "congestionáramo": "congestionar",
    "congestionáramos": "congestionar",
    "congestionárei": "congestionar",
    "congestionáreis": "congestionar",
    "congestionásseis": "congestionar",
    "congestionássemos": "congestionar",
    "congestionávamo": "congestionar",
    "congestionávamos": "congestionar",
    "congestionávei": "congestionar",
    "congestionáveis": "congestionável",
    "congestiva": "congestivo",
    "congestivas": "congestivo",
    "congestivos": "congestivo",
    "congestões": "congestão",
    "congloba": "conglobar",
    "conglobada": "conglobar",
    "conglobadas": "conglobar",
    "conglobado": "conglobar",
    "conglobados": "conglobar",
    "conglobai": "conglobar",
    "conglobais": "conglobar",
    "conglobam": "conglobar",
    "conglobamo": "conglobar",
    "conglobamos": "conglobar",
    "conglobando": "conglobar",
    "conglobara": "conglobar",
    "conglobaram": "conglobar",
    "conglobaras": "conglobar",
    "conglobarde": "conglobar",
    "conglobardes": "conglobar",
    "conglobare": "conglobar",
    "conglobarei": "conglobar",
    "conglobareis": "conglobar",
    "conglobarem": "conglobar",
    "conglobaremos": "conglobar",
    "conglobares": "conglobar",
    "conglobaria": "conglobar",
    "conglobariam": "conglobar",
    "conglobarias": "conglobar",
    "conglobarmo": "conglobar",
    "conglobarmos": "conglobar",
    "conglobará": "conglobar",
    "conglobarás": "conglobar",
    "conglobarão": "conglobar",
    "conglobaríamos": "conglobar",
    "conglobaríeis": "conglobar",
    "conglobas": "conglobar",
    "conglobasse": "conglobar",
    "conglobassem": "conglobar",
    "conglobasses": "conglobar",
    "conglobaste": "conglobar",
    "conglobastes": "conglobar",
    "conglobava": "conglobar",
    "conglobavam": "conglobar",
    "conglobavas": "conglobar",
    "conglobações": "conglobação",
    "conglobe": "conglobar",
    "conglobei": "conglobar",
    "conglobeis": "conglobar",
    "conglobem": "conglobar",
    "conglobemo": "conglobar",
    "conglobemos": "conglobar",
    "conglobes": "conglobar",
    "conglobo": "conglobar",
    "conglobou": "conglobar",
    "conglobá": "conglobar",
    "conglobámo": "conglobar",
    "conglobámos": "conglobar",
    "conglobáramo": "conglobar",
    "conglobáramos": "conglobar",
    "conglobárei": "conglobar",
    "conglobáreis": "conglobar",
    "conglobásseis": "conglobar",
    "conglobássemos": "conglobar",
    "conglobávamo": "conglobar",
    "conglobávamos": "conglobar",
    "conglobávei": "conglobar",
    "conglobáveis": "conglobar",
    "conglomera": "conglomerar",
    "conglomerada": "conglomerar",
    "conglomeradas": "conglomerar",
    "conglomerado": "conglomerar",
    "conglomerados": "conglomerar",
    "conglomerai": "conglomerar",
    "conglomerais": "conglomerar",
    "conglomeram": "conglomerar",
    "conglomeramo": "conglomerar",
    "conglomeramos": "conglomerar",
    "conglomerando": "conglomerar",
    "conglomerara": "conglomerar",
    "conglomeraram": "conglomerar",
    "conglomeraras": "conglomerar",
    "conglomerarde": "conglomerar",
    "conglomerardes": "conglomerar",
    "conglomerare": "conglomerar",
    "conglomerarei": "conglomerar",
    "conglomerareis": "conglomerar",
    "conglomerarem": "conglomerar",
    "conglomeraremos": "conglomerar",
    "conglomerares": "conglomerar",
    "conglomeraria": "conglomerar",
    "conglomerariam": "conglomerar",
    "conglomerarias": "conglomerar",
    "conglomerarmo": "conglomerar",
    "conglomerarmos": "conglomerar",
    "conglomerará": "conglomerar",
    "conglomerarás": "conglomerar",
    "conglomerarão": "conglomerar",
    "conglomeraríamos": "conglomerar",
    "conglomeraríeis": "conglomerar",
    "conglomeras": "conglomerar",
    "conglomerasse": "conglomerar",
    "conglomerassem": "conglomerar",
    "conglomerasses": "conglomerar",
    "conglomeraste": "conglomerar",
    "conglomerastes": "conglomerar",
    "conglomerativa": "conglomerativo",
    "conglomerativas": "conglomerativo",
    "conglomerativos": "conglomerativo",
    "conglomerava": "conglomerar",
    "conglomeravam": "conglomerar",
    "conglomeravas": "conglomerar",
    "conglomerações": "conglomeração",
    "conglomere": "conglomerar",
    "conglomerei": "conglomerar",
    "conglomereis": "conglomerar",
    "conglomerem": "conglomerar",
    "conglomeremo": "conglomerar",
    "conglomeremos": "conglomerar",
    "conglomeres": "conglomerar",
    "conglomero": "conglomerar",
    "conglomerou": "conglomerar",
    "conglomerá": "conglomerar",
    "conglomerámo": "conglomerar",
    "conglomerámos": "conglomerar",
    "conglomeráramo": "conglomerar",
    "conglomeráramos": "conglomerar",
    "conglomerárei": "conglomerar",
    "conglomeráreis": "conglomerar",
    "conglomerásseis": "conglomerar",
    "conglomerássemos": "conglomerar",
    "conglomerávamo": "conglomerar",
    "conglomerávamos": "conglomerar",
    "conglomerávei": "conglomerar",
    "conglomeráveis": "conglomerar",
    "conglutina": "conglutinar",
    "conglutinada": "conglutinar",
    "conglutinadas": "conglutinar",
    "conglutinado": "conglutinar",
    "conglutinados": "conglutinar",
    "conglutinai": "conglutinar",
    "conglutinais": "conglutinar",
    "conglutinam": "conglutinar",
    "conglutinamentos": "conglutinamento",
    "conglutinamo": "conglutinar",
    "conglutinamos": "conglutinar",
    "conglutinando": "conglutinar",
    "conglutinantes": "conglutinante",
    "conglutinara": "conglutinar",
    "conglutinaram": "conglutinar",
    "conglutinaras": "conglutinar",
    "conglutinarde": "conglutinar",
    "conglutinardes": "conglutinar",
    "conglutinare": "conglutinar",
    "conglutinarei": "conglutinar",
    "conglutinareis": "conglutinar",
    "conglutinarem": "conglutinar",
    "conglutinaremos": "conglutinar",
    "conglutinares": "conglutinar",
    "conglutinaria": "conglutinar",
    "conglutinariam": "conglutinar",
    "conglutinarias": "conglutinar",
    "conglutinarmo": "conglutinar",
    "conglutinarmos": "conglutinar",
    "conglutinará": "conglutinar",
    "conglutinarás": "conglutinar",
    "conglutinarão": "conglutinar",
    "conglutinaríamos": "conglutinar",
    "conglutinaríeis": "conglutinar",
    "conglutinas": "conglutinar",
    "conglutinasse": "conglutinar",
    "conglutinassem": "conglutinar",
    "conglutinasses": "conglutinar",
    "conglutinaste": "conglutinar",
    "conglutinastes": "conglutinar",
    "conglutinativa": "conglutinativo",
    "conglutinativas": "conglutinativo",
    "conglutinativos": "conglutinativo",
    "conglutinava": "conglutinar",
    "conglutinavam": "conglutinar",
    "conglutinavas": "conglutinar",
    "conglutinações": "conglutinação",
    "conglutine": "conglutinar",
    "conglutinei": "conglutinar",
    "conglutineis": "conglutinar",
    "conglutinem": "conglutinar",
    "conglutinemo": "conglutinar",
    "conglutinemos": "conglutinar",
    "conglutines": "conglutinar",
    "conglutino": "conglutinar",
    "conglutinosa": "conglutinoso",
    "conglutinosas": "conglutinoso",
    "conglutinosos": "conglutinoso",
    "conglutinou": "conglutinar",
    "conglutiná": "conglutinar",
    "conglutinámo": "conglutinar",
    "conglutinámos": "conglutinar",
    "conglutináramo": "conglutinar",
    "conglutináramos": "conglutinar",
    "conglutinárei": "conglutinar",
    "conglutináreis": "conglutinar",
    "conglutinásseis": "conglutinar",
    "conglutinássemos": "conglutinar",
    "conglutinávamo": "conglutinar",
    "conglutinávamos": "conglutinar",
    "conglutinávei": "conglutinar",
    "conglutináveis": "conglutinar",
    "congochada": "congochado",
    "congochadas": "congochado",
    "congochados": "congochado",
    "congochas": "congocha",
    "congocheira": "congocheiro",
    "congocheiras": "congocheiro",
    "congocheiros": "congocheiro",
    "congolesa": "congolês",
    "congolesas": "congolês",
    "congoleses": "congolês",
    "congonha": "congonhar",
    "congonhada": "congonhar",
    "congonhadas": "congonhar",
    "congonhado": "congonhar",
    "congonhados": "congonhar",
    "congonhai": "congonhar",
    "congonhais": "congonhar",
    "congonham": "congonhar",
    "congonhamo": "congonhar",
    "congonhamos": "congonhar",
    "congonhando": "congonhar",
    "congonhara": "congonhar",
    "congonharam": "congonhar",
    "congonharas": "congonhar",
    "congonharde": "congonhar",
    "congonhardes": "congonhar",
    "congonhare": "congonhar",
    "congonharei": "congonhar",
    "congonhareis": "congonhar",
    "congonharem": "congonhar",
    "congonharemos": "congonhar",
    "congonhares": "congonhar",
    "congonharia": "congonhar",
    "congonhariam": "congonhar",
    "congonharias": "congonhar",
    "congonharmo": "congonhar",
    "congonharmos": "congonhar",
    "congonhará": "congonhar",
    "congonharás": "congonhar",
    "congonharão": "congonhar",
    "congonharíamos": "congonhar",
    "congonharíeis": "congonhar",
    "congonhas": "congonhar",
    "congonhasse": "congonhar",
    "congonhassem": "congonhar",
    "congonhasses": "congonhar",
    "congonhaste": "congonhar",
    "congonhastes": "congonhar",
    "congonhava": "congonhar",
    "congonhavam": "congonhar",
    "congonhavas": "congonhar",
    "congonhe": "congonhar",
    "congonhei": "congonhar",
    "congonheis": "congonhar",
    "congonhem": "congonhar",
    "congonhemo": "congonhar",
    "congonhemos": "congonhar",
    "congonhes": "congonhar",
    "congonho": "congonhar",
    "congonhou": "congonhar",
    "congonhá": "congonhar",
    "congonhámo": "congonhar",
    "congonhámos": "congonhar",
    "congonháramo": "congonhar",
    "congonháramos": "congonhar",
    "congonhárei": "congonhar",
    "congonháreis": "congonhar",
    "congonhásseis": "congonhar",
    "congonhássemos": "congonhar",
    "congonhávamo": "congonhar",
    "congonhávamos": "congonhar",
    "congonhávei": "congonhar",
    "congonháveis": "congonhar",
    "congorsas": "congorsa",
    "congostas": "congosta",
    "congoças": "congoça",
    "congrace": "congraçar",
    "congracei": "congraçar",
    "congraceis": "congraçar",
    "congracem": "congraçar",
    "congracemo": "congraçar",
    "congracemos": "congraçar",
    "congraces": "congraçar",
    "congratula": "congratular",
    "congratulada": "congratular",
    "congratuladas": "congratular",
    "congratulado": "congratular",
    "congratuladora": "congratulador",
    "congratuladoras": "congratulador",
    "congratuladores": "congratulador",
    "congratulados": "congratular",
    "congratulai": "congratular",
    "congratulais": "congratular",
    "congratulam": "congratular",
    "congratulamo": "congratular",
    "congratulamos": "congratular",
    "congratulando": "congratular",
    "congratulantes": "congratulante",
    "congratulara": "congratular",
    "congratularam": "congratular",
    "congratularas": "congratular",
    "congratularde": "congratular",
    "congratulardes": "congratular",
    "congratulare": "congratular",
    "congratularei": "congratular",
    "congratulareis": "congratular",
    "congratularem": "congratular",
    "congratularemos": "congratular",
    "congratulares": "congratular",
    "congratularia": "congratular",
    "congratulariam": "congratular",
    "congratularias": "congratular",
    "congratularmo": "congratular",
    "congratularmos": "congratular",
    "congratulará": "congratular",
    "congratularás": "congratular",
    "congratularão": "congratular",
    "congratularíamos": "congratular",
    "congratularíeis": "congratular",
    "congratulas": "congratular",
    "congratulasse": "congratular",
    "congratulassem": "congratular",
    "congratulasses": "congratular",
    "congratulaste": "congratular",
    "congratulastes": "congratular",
    "congratulatória": "congratulatório",
    "congratulatórias": "congratulatório",
    "congratulatórios": "congratulatório",
    "congratulava": "congratular",
    "congratulavam": "congratular",
    "congratulavas": "congratular",
    "congratulações": "congratulação",
    "congratule": "congratular",
    "congratulei": "congratular",
    "congratuleis": "congratular",
    "congratulem": "congratular",
    "congratulemo": "congratular",
    "congratulemos": "congratular",
    "congratules": "congratular",
    "congratulo": "congratular",
    "congratulou": "congratular",
    "congratulá": "congratular",
    "congratulámo": "congratular",
    "congratulámos": "congratular",
    "congratuláramo": "congratular",
    "congratuláramos": "congratular",
    "congratulárei": "congratular",
    "congratuláreis": "congratular",
    "congratulásseis": "congratular",
    "congratulássemos": "congratular",
    "congratulávamo": "congratular",
    "congratulávamos": "congratular",
    "congratulávei": "congratular",
    "congratuláveis": "congratular",
    "congraça": "congraçar",
    "congraçada": "congraçar",
    "congraçadas": "congraçar",
    "congraçado": "congraçar",
    "congraçadora": "congraçador",
    "congraçadoras": "congraçador",
    "congraçadores": "congraçador",
    "congraçados": "congraçar",
    "congraçai": "congraçar",
    "congraçais": "congraçar",
    "congraçam": "congraçar",
    "congraçamentos": "congraçamento",
    "congraçamo": "congraçar",
    "congraçamos": "congraçar",
    "congraçando": "congraçar",
    "congraçara": "congraçar",
    "congraçaram": "congraçar",
    "congraçaras": "congraçar",
    "congraçarde": "congraçar",
    "congraçardes": "congraçar",
    "congraçare": "congraçar",
    "congraçarei": "congraçar",
    "congraçareis": "congraçar",
    "congraçarem": "congraçar",
    "congraçaremos": "congraçar",
    "congraçares": "congraçar",
    "congraçaria": "congraçar",
    "congraçariam": "congraçar",
    "congraçarias": "congraçar",
    "congraçarmo": "congraçar",
    "congraçarmos": "congraçar",
    "congraçará": "congraçar",
    "congraçarás": "congraçar",
    "congraçarão": "congraçar",
    "congraçaríamos": "congraçar",
    "congraçaríeis": "congraçar",
    "congraças": "congraçar",
    "congraçasse": "congraçar",
    "congraçassem": "congraçar",
    "congraçasses": "congraçar",
    "congraçaste": "congraçar",
    "congraçastes": "congraçar",
    "congraçava": "congraçar",
    "congraçavam": "congraçar",
    "congraçavas": "congraçar",
    "congraço": "congraçar",
    "congraçou": "congraçar",
    "congraçá": "congraçar",
    "congraçámo": "congraçar",
    "congraçámos": "congraçar",
    "congraçáramo": "congraçar",
    "congraçáramos": "congraçar",
    "congraçárei": "congraçar",
    "congraçáreis": "congraçar",
    "congraçásseis": "congraçar",
    "congraçássemos": "congraçar",
    "congraçávamo": "congraçar",
    "congraçávamos": "congraçar",
    "congraçávei": "congraçar",
    "congraçáveis": "congraçar",
    "congrega": "congregar",
    "congregacionais": "congregacional",
    "congregacionistas": "congregacionista",
    "congregada": "congregar",
    "congregadas": "congregar",
    "congregadistas": "congregadista",
    "congregado": "congregar",
    "congregadora": "congregador",
    "congregadoras": "congregador",
    "congregadores": "congregador",
    "congregados": "congregar",
    "congregai": "congregar",
    "congregais": "congregar",
    "congregam": "congregar",
    "congregamo": "congregar",
    "congregamos": "congregar",
    "congregando": "congregar",
    "congreganistas": "congreganista",
    "congregantes": "congregante",
    "congregara": "congregar",
    "congregaram": "congregar",
    "congregaras": "congregar",
    "congregarde": "congregar",
    "congregardes": "congregar",
    "congregare": "congregar",
    "congregarei": "congregar",
    "congregareis": "congregar",
    "congregarem": "congregar",
    "congregaremos": "congregar",
    "congregares": "congregar",
    "congregaria": "congregar",
    "congregariam": "congregar",
    "congregarias": "congregar",
    "congregarmo": "congregar",
    "congregarmos": "congregar",
    "congregará": "congregar",
    "congregarás": "congregar",
    "congregarão": "congregar",
    "congregaríamos": "congregar",
    "congregaríeis": "congregar",
    "congregas": "congregar",
    "congregasse": "congregar",
    "congregassem": "congregar",
    "congregasses": "congregar",
    "congregaste": "congregar",
    "congregastes": "congregar",
    "congregava": "congregar",
    "congregavam": "congregar",
    "congregavas": "congregar",
    "congregações": "congregação",
    "congrego": "congregar",
    "congregou": "congregar",
    "congregue": "congregar",
    "congreguei": "congregar",
    "congregueis": "congregar",
    "congreguem": "congregar",
    "congreguemo": "congregar",
    "congreguemos": "congregar",
    "congregues": "congregar",
    "congregá": "congregar",
    "congregámo": "congregar",
    "congregámos": "congregar",
    "congregáramo": "congregar",
    "congregáramos": "congregar",
    "congregárei": "congregar",
    "congregáreis": "congregar",
    "congregásseis": "congregar",
    "congregássemos": "congregar",
    "congregávamo": "congregar",
    "congregávamos": "congregar",
    "congregávei": "congregar",
    "congregáveis": "congregável",
    "congressionais": "congressional",
    "congressistas": "congressista",
    "congressos": "congresso",
    "congressuais": "congressual",
    "congros": "congro",
    "congruada": "congruado",
    "congruadas": "congruado",
    "congruados": "congruado",
    "congruentes": "congruente",
    "congruidades": "congruidade",
    "congruistas": "congruista",
    "congruária": "congruário",
    "congruárias": "congruário",
    "congruários": "congruário",
    "congruências": "congruência",
    "congruísmos": "congruísmo",
    "congruístas": "congruísta",
    "conguesa": "conguês",
    "conguesas": "conguês",
    "congueses": "conguês",
    "congéneres": "congénere",
    "congénita": "congénito",
    "congénitas": "congénito",
    "congénitos": "congénito",
    "congéries": "congérie",
    "conhaques": "conhaque",
    "conhaquezinho": "conhaque",
    "conhaquezinhos": "conhaque",
    "conhaquezito": "conhaque",
    "conhaquezitos": "conhaque",
    "conhas": "conha",
    "conhece": "conhecer",
    "conhecedora": "conhecedor",
    "conhecedoras": "conhecedor",
    "conhecedores": "conhecedor",
    "conhecei": "conhecer",
    "conheceis": "conhecer",
    "conhecem": "conhecer",
    "conhecemo": "conhecer",
    "conhecemos": "conhecer",
    "conhecendo": "conhecer",
    "conhecenças": "conhecença",
    "conhecera": "conhecer",
    "conheceram": "conhecer",
    "conheceras": "conhecer",
    "conhecerde": "conhecer",
    "conhecerdes": "conhecer",
    "conhecere": "conhecer",
    "conhecerei": "conhecer",
    "conhecereis": "conhecer",
    "conhecerem": "conhecer",
    "conheceremos": "conhecer",
    "conheceres": "conhecer",
    "conheceria": "conhecer",
    "conheceriam": "conhecer",
    "conhecerias": "conhecer",
    "conhecermo": "conhecer",
    "conhecermos": "conhecer",
    "conhecerá": "conhecer",
    "conhecerás": "conhecer",
    "conhecerão": "conhecer",
    "conheceríamos": "conhecer",
    "conheceríeis": "conhecer",
    "conheces": "conhecer",
    "conhecesse": "conhecer",
    "conhecessem": "conhecer",
    "conhecesses": "conhecer",
    "conheceste": "conhecer",
    "conhecestes": "conhecer",
    "conheceu": "conhecer",
    "conheci": "conhecer",
    "conhecia": "conhecer",
    "conheciam": "conhecer",
    "conhecias": "conhecer",
    "conhecida": "conhecido",
    "conhecidas": "conhecido",
    "conhecido": "conhecer",
    "conhecidos": "conhecido",
    "conhecidíssima": "conhecido",
    "conhecidíssimas": "conhecido",
    "conhecidíssimo": "conhecido",
    "conhecidíssimos": "conhecido",
    "conhecimentos": "conhecimento",
    "conhecê": "conhecer",
    "conhecêramo": "conhecer",
    "conhecêramos": "conhecer",
    "conhecêrei": "conhecer",
    "conhecêreis": "conhecer",
    "conhecêsseis": "conhecer",
    "conhecêssemos": "conhecer",
    "conhecíamo": "conhecer",
    "conhecíamos": "conhecer",
    "conhecíei": "conhecer",
    "conhecíeis": "conhecer",
    "conhecíveis": "conhecível",
    "conheça": "conhecer",
    "conheçais": "conhecer",
    "conheçam": "conhecer",
    "conheçamo": "conhecer",
    "conheçamos": "conhecer",
    "conheças": "conhecer",
    "conheço": "conhecer",
    "conhos": "conho",
    "conicidades": "conicidade",
    "conicinas": "conicina",
    "conideóforos": "conideóforo",
    "coniflora": "conifloro",
    "conifloras": "conifloro",
    "conifloros": "conifloro",
    "conimbricenses": "conimbricense",
    "conimbrigenses": "conimbrigense",
    "coninas": "conina",
    "conirrostra": "conirrostro",
    "conirrostras": "conirrostro",
    "conirrostros": "conirrostro",
    "conivalves": "conivalve",
    "coniventes": "conivente",
    "conivências": "conivência",
    "conjectura": "conjecturar",
    "conjecturada": "conjecturar",
    "conjecturadas": "conjecturar",
    "conjecturado": "conjecturar",
    "conjecturadora": "conjecturador",
    "conjecturadoras": "conjecturador",
    "conjecturadores": "conjecturador",
    "conjecturados": "conjecturar",
    "conjecturai": "conjecturar",
    "conjecturais": "conjecturar",
    "conjecturam": "conjecturar",
    "conjecturamo": "conjecturar",
    "conjecturamos": "conjecturar",
    "conjecturando": "conjecturar",
    "conjecturara": "conjecturar",
    "conjecturaram": "conjecturar",
    "conjecturaras": "conjecturar",
    "conjecturarde": "conjecturar",
    "conjecturardes": "conjecturar",
    "conjecturare": "conjecturar",
    "conjecturarei": "conjecturar",
    "conjecturareis": "conjecturar",
    "conjecturarem": "conjecturar",
    "conjecturaremos": "conjecturar",
    "conjecturares": "conjecturar",
    "conjecturaria": "conjecturar",
    "conjecturariam": "conjecturar",
    "conjecturarias": "conjecturar",
    "conjecturarmo": "conjecturar",
    "conjecturarmos": "conjecturar",
    "conjecturará": "conjecturar",
    "conjecturarás": "conjecturar",
    "conjecturarão": "conjecturar",
    "conjecturaríamos": "conjecturar",
    "conjecturaríeis": "conjecturar",
    "conjecturas": "conjecturar",
    "conjecturasse": "conjecturar",
    "conjecturassem": "conjecturar",
    "conjecturasses": "conjecturar",
    "conjecturaste": "conjecturar",
    "conjecturastes": "conjecturar",
    "conjecturava": "conjecturar",
    "conjecturavam": "conjecturar",
    "conjecturavas": "conjecturar",
    "conjecture": "conjecturar",
    "conjecturei": "conjecturar",
    "conjectureis": "conjecturar",
    "conjecturem": "conjecturar",
    "conjecturemo": "conjecturar",
    "conjecturemos": "conjecturar",
    "conjectures": "conjecturar",
    "conjecturo": "conjecturar",
    "conjecturou": "conjecturar",
    "conjecturá": "conjecturar",
    "conjecturámo": "conjecturar",
    "conjecturámos": "conjecturar",
    "conjecturáramo": "conjecturar",
    "conjecturáramos": "conjecturar",
    "conjecturárei": "conjecturar",
    "conjecturáreis": "conjecturar",
    "conjecturásseis": "conjecturar",
    "conjecturássemos": "conjecturar",
    "conjecturávamo": "conjecturar",
    "conjecturávamos": "conjecturar",
    "conjecturávei": "conjecturar",
    "conjecturáveis": "conjecturável",
    "conjectânea": "conjectâneo",
    "conjectâneas": "conjectâneo",
    "conjectâneos": "conjectâneo",
    "conjectânias": "conjectânia",
    "conjuga": "conjugar",
    "conjugada": "conjugar",
    "conjugadas": "conjugar",
    "conjugado": "conjugar",
    "conjugados": "conjugar",
    "conjugai": "conjugar",
    "conjugais": "conjugar",
    "conjugam": "conjugar",
    "conjugamo": "conjugar",
    "conjugamos": "conjugar",
    "conjugando": "conjugar",
    "conjugara": "conjugar",
    "conjugaram": "conjugar",
    "conjugaras": "conjugar",
    "conjugarde": "conjugar",
    "conjugardes": "conjugar",
    "conjugare": "conjugar",
    "conjugarei": "conjugar",
    "conjugareis": "conjugar",
    "conjugarem": "conjugar",
    "conjugaremos": "conjugar",
    "conjugares": "conjugar",
    "conjugaria": "conjugar",
    "conjugariam": "conjugar",
    "conjugarias": "conjugar",
    "conjugarmo": "conjugar",
    "conjugarmos": "conjugar",
    "conjugará": "conjugar",
    "conjugarás": "conjugar",
    "conjugarão": "conjugar",
    "conjugaríamos": "conjugar",
    "conjugaríeis": "conjugar",
    "conjugas": "conjugar",
    "conjugasse": "conjugar",
    "conjugassem": "conjugar",
    "conjugasses": "conjugar",
    "conjugaste": "conjugar",
    "conjugastes": "conjugar",
    "conjugativa": "conjugativo",
    "conjugativas": "conjugativo",
    "conjugativos": "conjugativo",
    "conjugava": "conjugar",
    "conjugavam": "conjugar",
    "conjugavas": "conjugar",
    "conjugações": "conjugação",
    "conjugicidas": "conjugicida",
    "conjugicídios": "conjugicídio",
    "conjugo": "conjugar",
    "conjugou": "conjugar",
    "conjugue": "conjugar",
    "conjuguei": "conjugar",
    "conjugueis": "conjugar",
    "conjuguem": "conjugar",
    "conjuguemo": "conjugar",
    "conjuguemos": "conjugar",
    "conjugues": "conjugar",
    "conjugá": "conjugar",
    "conjugámo": "conjugar",
    "conjugámos": "conjugar",
    "conjugáramo": "conjugar",
    "conjugáramos": "conjugar",
    "conjugárei": "conjugar",
    "conjugáreis": "conjugar",
    "conjugásseis": "conjugar",
    "conjugássemos": "conjugar",
    "conjugávamo": "conjugar",
    "conjugávamos": "conjugar",
    "conjugávei": "conjugar",
    "conjugáveis": "conjugável",
    "conjuncionais": "conjuncional",
    "conjunge": "conjungir",
    "conjungem": "conjungir",
    "conjunges": "conjungir",
    "conjungi": "conjungir",
    "conjungia": "conjungir",
    "conjungiam": "conjungir",
    "conjungias": "conjungir",
    "conjungida": "conjungir",
    "conjungidas": "conjungir",
    "conjungido": "conjungir",
    "conjungidos": "conjungir",
    "conjungimo": "conjungir",
    "conjungimos": "conjungir",
    "conjungindo": "conjungir",
    "conjungira": "conjungir",
    "conjungiram": "conjungir",
    "conjungiras": "conjungir",
    "conjungirde": "conjungir",
    "conjungirdes": "conjungir",
    "conjungire": "conjungir",
    "conjungirei": "conjungir",
    "conjungireis": "conjungir",
    "conjungirem": "conjungir",
    "conjungiremos": "conjungir",
    "conjungires": "conjungir",
    "conjungiria": "conjungir",
    "conjungiriam": "conjungir",
    "conjungirias": "conjungir",
    "conjungirmo": "conjungir",
    "conjungirmos": "conjungir",
    "conjungirá": "conjungir",
    "conjungirás": "conjungir",
    "conjungirão": "conjungir",
    "conjungiríamos": "conjungir",
    "conjungiríeis": "conjungir",
    "conjungis": "conjungir",
    "conjungisse": "conjungir",
    "conjungissem": "conjungir",
    "conjungisses": "conjungir",
    "conjungiste": "conjungir",
    "conjungistes": "conjungir",
    "conjungiu": "conjungir",
    "conjungos": "conjungo",
    "conjungíamo": "conjungir",
    "conjungíamos": "conjungir",
    "conjungíei": "conjungir",
    "conjungíeis": "conjungir",
    "conjungíramo": "conjungir",
    "conjungíramos": "conjungir",
    "conjungírei": "conjungir",
    "conjungíreis": "conjungir",
    "conjungísseis": "conjungir",
    "conjungíssemos": "conjungir",
    "conjunja": "conjungir",
    "conjunjais": "conjungir",
    "conjunjam": "conjungir",
    "conjunjamo": "conjungir",
    "conjunjamos": "conjungir",
    "conjunjas": "conjungir",
    "conjunjo": "conjungir",
    "conjunta": "conjunto",
    "conjuntada": "conjuntar",
    "conjuntadas": "conjuntar",
    "conjuntado": "conjuntar",
    "conjuntados": "conjuntar",
    "conjuntai": "conjuntar",
    "conjuntais": "conjuntar",
    "conjuntam": "conjuntar",
    "conjuntamo": "conjuntar",
    "conjuntamos": "conjuntar",
    "conjuntando": "conjuntar",
    "conjuntara": "conjuntar",
    "conjuntaram": "conjuntar",
    "conjuntaras": "conjuntar",
    "conjuntarde": "conjuntar",
    "conjuntardes": "conjuntar",
    "conjuntare": "conjuntar",
    "conjuntarei": "conjuntar",
    "conjuntareis": "conjuntar",
    "conjuntarem": "conjuntar",
    "conjuntaremos": "conjuntar",
    "conjuntares": "conjuntar",
    "conjuntaria": "conjuntar",
    "conjuntariam": "conjuntar",
    "conjuntarias": "conjuntar",
    "conjuntarmo": "conjuntar",
    "conjuntarmos": "conjuntar",
    "conjuntará": "conjuntar",
    "conjuntarás": "conjuntar",
    "conjuntarão": "conjuntar",
    "conjuntaríamos": "conjuntar",
    "conjuntaríeis": "conjuntar",
    "conjuntas": "conjunto",
    "conjuntasse": "conjuntar",
    "conjuntassem": "conjuntar",
    "conjuntasses": "conjuntar",
    "conjuntaste": "conjuntar",
    "conjuntastes": "conjuntar",
    "conjuntava": "conjuntar",
    "conjuntavam": "conjuntar",
    "conjuntavas": "conjuntar",
    "conjunte": "conjuntar",
    "conjuntei": "conjuntar",
    "conjunteis": "conjuntar",
    "conjuntem": "conjuntar",
    "conjuntemo": "conjuntar",
    "conjuntemos": "conjuntar",
    "conjuntes": "conjuntar",
    "conjuntiva": "conjuntivo",
    "conjuntivas": "conjuntivo",
    "conjuntivites": "conjuntivite",
    "conjuntivos": "conjuntivo",
    "conjunto": "conjuntar",
    "conjuntos": "conjunto",
    "conjuntou": "conjuntar",
    "conjunturais": "conjuntural",
    "conjunturas": "conjuntura",
    "conjuntá": "conjuntar",
    "conjuntámo": "conjuntar",
    "conjuntámos": "conjuntar",
    "conjuntáramo": "conjuntar",
    "conjuntáramos": "conjuntar",
    "conjuntárei": "conjuntar",
    "conjuntáreis": "conjuntar",
    "conjuntásseis": "conjuntar",
    "conjuntássemos": "conjuntar",
    "conjuntávamo": "conjuntar",
    "conjuntávamos": "conjuntar",
    "conjuntávei": "conjuntar",
    "conjuntáveis": "conjuntar",
    "conjuntórios": "conjuntório",
    "conjunções": "conjunção",
    "conjura": "conjurar",
    "conjurada": "conjurar",
    "conjuradas": "conjurar",
    "conjurado": "conjurar",
    "conjuradora": "conjurador",
    "conjuradoras": "conjurador",
    "conjuradores": "conjurador",
    "conjurados": "conjurar",
    "conjurai": "conjurar",
    "conjurais": "conjurar",
    "conjuram": "conjurar",
    "conjuramo": "conjurar",
    "conjuramos": "conjurar",
    "conjurando": "conjurar",
    "conjurantes": "conjurante",
    "conjurara": "conjurar",
    "conjuraram": "conjurar",
    "conjuraras": "conjurar",
    "conjurarde": "conjurar",
    "conjurardes": "conjurar",
    "conjurare": "conjurar",
    "conjurarei": "conjurar",
    "conjurareis": "conjurar",
    "conjurarem": "conjurar",
    "conjuraremos": "conjurar",
    "conjurares": "conjurar",
    "conjuraria": "conjurar",
    "conjurariam": "conjurar",
    "conjurarias": "conjurar",
    "conjurarmo": "conjurar",
    "conjurarmos": "conjurar",
    "conjurará": "conjurar",
    "conjurarás": "conjurar",
    "conjurarão": "conjurar",
    "conjuraríamos": "conjurar",
    "conjuraríeis": "conjurar",
    "conjuras": "conjurar",
    "conjurasse": "conjurar",
    "conjurassem": "conjurar",
    "conjurasses": "conjurar",
    "conjuraste": "conjurar",
    "conjurastes": "conjurar",
    "conjuratória": "conjuratório",
    "conjuratórias": "conjuratório",
    "conjuratórios": "conjuratório",
    "conjurava": "conjurar",
    "conjuravam": "conjurar",
    "conjuravas": "conjurar",
    "conjurações": "conjuração",
    "conjure": "conjurar",
    "conjurei": "conjurar",
    "conjureis": "conjurar",
    "conjurem": "conjurar",
    "conjuremo": "conjurar",
    "conjuremos": "conjurar",
    "conjures": "conjurar",
    "conjuro": "conjurar",
    "conjuros": "conjuro",
    "conjurou": "conjurar",
    "conjurá": "conjurar",
    "conjurámo": "conjurar",
    "conjurámos": "conjurar",
    "conjuráramo": "conjurar",
    "conjuráramos": "conjurar",
    "conjurárei": "conjurar",
    "conjuráreis": "conjurar",
    "conjurásseis": "conjurar",
    "conjurássemos": "conjurar",
    "conjurávamo": "conjurar",
    "conjurávamos": "conjurar",
    "conjurávei": "conjurar",
    "conjuráveis": "conjurar",
    "conjúgios": "conjúgio",
    "conluia": "conluiar",
    "conluiada": "conluiar",
    "conluiadas": "conluiar",
    "conluiado": "conluiar",
    "conluiados": "conluiar",
    "conluiai": "conluiar",
    "conluiais": "conluiar",
    "conluiam": "conluiar",
    "conluiamo": "conluiar",
    "conluiamos": "conluiar",
    "conluiando": "conluiar",
    "conluiara": "conluiar",
    "conluiaram": "conluiar",
    "conluiaras": "conluiar",
    "conluiardes": "conluiar",
    "conluiarei": "conluiar",
    "conluiareis": "conluiar",
    "conluiarem": "conluiar",
    "conluiaremos": "conluiar",
    "conluiares": "conluiar",
    "conluiaria": "conluiar",
    "conluiariam": "conluiar",
    "conluiarias": "conluiar",
    "conluiarmo": "conluiar",
    "conluiarmos": "conluiar",
    "conluiará": "conluiar",
    "conluiarás": "conluiar",
    "conluiarão": "conluiar",
    "conluiaríamos": "conluiar",
    "conluiaríeis": "conluiar",
    "conluias": "conluiar",
    "conluiasse": "conluiar",
    "conluiassem": "conluiar",
    "conluiasses": "conluiar",
    "conluiaste": "conluiar",
    "conluiastes": "conluiar",
    "conluiava": "conluiar",
    "conluiavam": "conluiar",
    "conluiavas": "conluiar",
    "conluie": "conluiar",
    "conluiei": "conluiar",
    "conluieis": "conluiar",
    "conluiem": "conluiar",
    "conluiemo": "conluiar",
    "conluiemos": "conluiar",
    "conluies": "conluiar",
    "conluio": "conluiar",
    "conluios": "conluio",
    "conluiou": "conluiar",
    "conluiámo": "conluiar",
    "conluiámos": "conluiar",
    "conluiáramo": "conluiar",
    "conluiáramos": "conluiar",
    "conluiáreis": "conluiar",
    "conluiásseis": "conluiar",
    "conluiássemos": "conluiar",
    "conluiávamo": "conluiar",
    "conluiávamos": "conluiar",
    "conluiáveis": "conluiar",
    "connosco": "comigo",
    "conoidais": "conoidal",
    "conos": "cono",
    "conota": "conotar",
    "conotada": "conotar",
    "conotadas": "conotar",
    "conotado": "conotar",
    "conotados": "conotar",
    "conotai": "conotar",
    "conotais": "conotar",
    "conotam": "conotar",
    "conotamo": "conotar",
    "conotamos": "conotar",
    "conotando": "conotar",
    "conotara": "conotar",
    "conotaram": "conotar",
    "conotaras": "conotar",
    "conotarde": "conotar",
    "conotardes": "conotar",
    "conotare": "conotar",
    "conotarei": "conotar",
    "conotareis": "conotar",
    "conotarem": "conotar",
    "conotaremos": "conotar",
    "conotares": "conotar",
    "conotaria": "conotar",
    "conotariam": "conotar",
    "conotarias": "conotar",
    "conotarmo": "conotar",
    "conotarmos": "conotar",
    "conotará": "conotar",
    "conotarás": "conotar",
    "conotarão": "conotar",
    "conotaríamos": "conotar",
    "conotaríeis": "conotar",
    "conotas": "conotar",
    "conotasse": "conotar",
    "conotassem": "conotar",
    "conotasses": "conotar",
    "conotaste": "conotar",
    "conotastes": "conotar",
    "conotava": "conotar",
    "conotavam": "conotar",
    "conotavas": "conotar",
    "conotações": "conotação",
    "conote": "conotar",
    "conotei": "conotar",
    "conoteis": "conotar",
    "conotem": "conotar",
    "conotemo": "conotar",
    "conotemos": "conotar",
    "conotes": "conotar",
    "conoto": "conotar",
    "conotou": "conotar",
    "conotá": "conotar",
    "conotámo": "conotar",
    "conotámos": "conotar",
    "conotáramo": "conotar",
    "conotáramos": "conotar",
    "conotárei": "conotar",
    "conotáreis": "conotar",
    "conotásseis": "conotar",
    "conotássemos": "conotar",
    "conotávamo": "conotar",
    "conotávamos": "conotar",
    "conotávei": "conotar",
    "conotáveis": "conotar",
    "conquiformes": "conquiforme",
    "conquilhas": "conquilha",
    "conquiliana": "conquiliano",
    "conquilianas": "conquiliano",
    "conquilianos": "conquiliano",
    "conquiliologias": "conquiliologia",
    "conquiliologistas": "conquiliologista",
    "conquiliológica": "conquiliológico",
    "conquiliológicas": "conquiliológico",
    "conquiliológicos": "conquiliológico",
    "conquilióides": "conquilióide",
    "conquilióloga": "conquiliólogo",
    "conquiliólogas": "conquiliólogo",
    "conquiliólogos": "conquiliólogo",
    "conquiologias": "conquiologia",
    "conquiologistas": "conquiologista",
    "conquiológica": "conquiológico",
    "conquiológicas": "conquiológico",
    "conquiológicos": "conquiológico",
    "conquista": "conquistar",
    "conquistada": "conquistar",
    "conquistadas": "conquistar",
    "conquistado": "conquistar",
    "conquistadora": "conquistador",
    "conquistadoras": "conquistador",
    "conquistadores": "conquistador",
    "conquistados": "conquistar",
    "conquistai": "conquistar",
    "conquistais": "conquistar",
    "conquistam": "conquistar",
    "conquistamo": "conquistar",
    "conquistamos": "conquistar",
    "conquistando": "conquistar",
    "conquistara": "conquistar",
    "conquistaram": "conquistar",
    "conquistaras": "conquistar",
    "conquistarde": "conquistar",
    "conquistardes": "conquistar",
    "conquistare": "conquistar",
    "conquistarei": "conquistar",
    "conquistareis": "conquistar",
    "conquistarem": "conquistar",
    "conquistaremos": "conquistar",
    "conquistares": "conquistar",
    "conquistaria": "conquistar",
    "conquistariam": "conquistar",
    "conquistarias": "conquistar",
    "conquistarmo": "conquistar",
    "conquistarmos": "conquistar",
    "conquistará": "conquistar",
    "conquistarás": "conquistar",
    "conquistarão": "conquistar",
    "conquistaríamos": "conquistar",
    "conquistaríeis": "conquistar",
    "conquistas": "conquistar",
    "conquistasse": "conquistar",
    "conquistassem": "conquistar",
    "conquistasses": "conquistar",
    "conquistaste": "conquistar",
    "conquistastes": "conquistar",
    "conquistava": "conquistar",
    "conquistavam": "conquistar",
    "conquistavas": "conquistar",
    "conquiste": "conquistar",
    "conquistei": "conquistar",
    "conquisteis": "conquistar",
    "conquistem": "conquistar",
    "conquistemo": "conquistar",
    "conquistemos": "conquistar",
    "conquistes": "conquistar",
    "conquisto": "conquistar",
    "conquistou": "conquistar",
    "conquistá": "conquistar",
    "conquistámo": "conquistar",
    "conquistámos": "conquistar",
    "conquistáramo": "conquistar",
    "conquistáramos": "conquistar",
    "conquistárei": "conquistar",
    "conquistáreis": "conquistar",
    "conquistásseis": "conquistar",
    "conquistássemos": "conquistar",
    "conquistávamo": "conquistar",
    "conquistávamos": "conquistar",
    "conquistávei": "conquistar",
    "conquistáveis": "conquistável",
    "conquites": "conquite",
    "conquióloga": "conquiólogo",
    "conquiólogas": "conquiólogo",
    "conquiólogos": "conquiólogo",
    "conquícolas": "conquícola",
    "conquífera": "conquífero",
    "conquíferas": "conquífero",
    "conquíferos": "conquífero",
    "consabedora": "consabedor",
    "consabedoras": "consabedor",
    "consabedores": "consabedor",
    "consabida": "consabido",
    "consabidas": "consabido",
    "consabidos": "consabido",
    "consagra": "consagrar",
    "consagrada": "consagrar",
    "consagradas": "consagrar",
    "consagrado": "consagrar",
    "consagradora": "consagrador",
    "consagradoras": "consagrador",
    "consagradores": "consagrador",
    "consagrados": "consagrar",
    "consagrai": "consagrar",
    "consagrais": "consagrar",
    "consagram": "consagrar",
    "consagramo": "consagrar",
    "consagramos": "consagrar",
    "consagrando": "consagrar",
    "consagrantes": "consagrante",
    "consagrara": "consagrar",
    "consagraram": "consagrar",
    "consagraras": "consagrar",
    "consagrarde": "consagrar",
    "consagrardes": "consagrar",
    "consagrare": "consagrar",
    "consagrarei": "consagrar",
    "consagrareis": "consagrar",
    "consagrarem": "consagrar",
    "consagraremos": "consagrar",
    "consagrares": "consagrar",
    "consagraria": "consagrar",
    "consagrariam": "consagrar",
    "consagrarias": "consagrar",
    "consagrarmo": "consagrar",
    "consagrarmos": "consagrar",
    "consagrará": "consagrar",
    "consagrarás": "consagrar",
    "consagrarão": "consagrar",
    "consagraríamos": "consagrar",
    "consagraríeis": "consagrar",
    "consagras": "consagrar",
    "consagrasse": "consagrar",
    "consagrassem": "consagrar",
    "consagrasses": "consagrar",
    "consagraste": "consagrar",
    "consagrastes": "consagrar",
    "consagrativa": "consagrativo",
    "consagrativas": "consagrativo",
    "consagrativos": "consagrativo",
    "consagrava": "consagrar",
    "consagravam": "consagrar",
    "consagravas": "consagrar",
    "consagrações": "consagração",
    "consagre": "consagrar",
    "consagrei": "consagrar",
    "consagreis": "consagrar",
    "consagrem": "consagrar",
    "consagremo": "consagrar",
    "consagremos": "consagrar",
    "consagres": "consagrar",
    "consagro": "consagrar",
    "consagrou": "consagrar",
    "consagrá": "consagrar",
    "consagrámo": "consagrar",
    "consagrámos": "consagrar",
    "consagráramo": "consagrar",
    "consagráramos": "consagrar",
    "consagrárei": "consagrar",
    "consagráreis": "consagrar",
    "consagrásseis": "consagrar",
    "consagrássemos": "consagrar",
    "consagrávamo": "consagrar",
    "consagrávamos": "consagrar",
    "consagrávei": "consagrar",
    "consagráveis": "consagrável",
    "consciencialismos": "consciencialismo",
    "consciencializa": "consciencializar",
    "consciencializada": "consciencializar",
    "consciencializadas": "consciencializar",
    "consciencializado": "consciencializar",
    "consciencializados": "consciencializar",
    "consciencializai": "consciencializar",
    "consciencializais": "consciencializar",
    "consciencializam": "consciencializar",
    "consciencializamo": "consciencializar",
    "consciencializamos": "consciencializar",
    "consciencializando": "consciencializar",
    "consciencializara": "consciencializar",
    "consciencializaram": "consciencializar",
    "consciencializaras": "consciencializar",
    "consciencializarde": "consciencializar",
    "consciencializardes": "consciencializar",
    "consciencializare": "consciencializar",
    "consciencializarei": "consciencializar",
    "consciencializareis": "consciencializar",
    "consciencializarem": "consciencializar",
    "consciencializaremos": "consciencializar",
    "consciencializares": "consciencializar",
    "consciencializaria": "consciencializar",
    "consciencializariam": "consciencializar",
    "consciencializarias": "consciencializar",
    "consciencializarmo": "consciencializar",
    "consciencializarmos": "consciencializar",
    "consciencializará": "consciencializar",
    "consciencializarás": "consciencializar",
    "consciencializarão": "consciencializar",
    "consciencializaríamos": "consciencializar",
    "consciencializaríeis": "consciencializar",
    "consciencializas": "consciencializar",
    "consciencializasse": "consciencializar",
    "consciencializassem": "consciencializar",
    "consciencializasses": "consciencializar",
    "consciencializaste": "consciencializar",
    "consciencializastes": "consciencializar",
    "consciencializava": "consciencializar",
    "consciencializavam": "consciencializar",
    "consciencializavas": "consciencializar",
    "consciencializações": "consciencialização",
    "consciencialize": "consciencializar",
    "consciencializei": "consciencializar",
    "consciencializeis": "consciencializar",
    "consciencializem": "consciencializar",
    "consciencializemo": "consciencializar",
    "consciencializemos": "consciencializar",
    "consciencializes": "consciencializar",
    "consciencializo": "consciencializar",
    "consciencializou": "consciencializar",
    "consciencializá": "consciencializar",
    "consciencializámo": "consciencializar",
    "consciencializámos": "consciencializar",
    "consciencializáramo": "consciencializar",
    "consciencializáramos": "consciencializar",
    "consciencializárei": "consciencializar",
    "consciencializáreis": "consciencializar",
    "consciencializásseis": "consciencializar",
    "consciencializássemos": "consciencializar",
    "consciencializávamo": "consciencializar",
    "consciencializávamos": "consciencializar",
    "consciencializávei": "consciencializar",
    "consciencializáveis": "consciencializar",
    "conscienciosa": "consciencioso",
    "conscienciosas": "consciencioso",
    "conscienciosos": "consciencioso",
    "conscientes": "consciente",
    "consciências": "consciência",
    "conscreva": "conscrever",
    "conscrevais": "conscrever",
    "conscrevam": "conscrever",
    "conscrevamo": "conscrever",
    "conscrevamos": "conscrever",
    "conscrevas": "conscrever",
    "conscreve": "conscrever",
    "conscrevei": "conscrever",
    "conscreveis": "conscrever",
    "conscrevem": "conscrever",
    "conscrevemo": "conscrever",
    "conscrevemos": "conscrever",
    "conscrevendo": "conscrever",
    "conscrevera": "conscrever",
    "conscreveram": "conscrever",
    "conscreveras": "conscrever",
    "conscreverde": "conscrever",
    "conscreverdes": "conscrever",
    "conscrevere": "conscrever",
    "conscreverei": "conscrever",
    "conscrevereis": "conscrever",
    "conscreverem": "conscrever",
    "conscreveremos": "conscrever",
    "conscreveres": "conscrever",
    "conscreveria": "conscrever",
    "conscreveriam": "conscrever",
    "conscreverias": "conscrever",
    "conscrevermo": "conscrever",
    "conscrevermos": "conscrever",
    "conscreverá": "conscrever",
    "conscreverás": "conscrever",
    "conscreverão": "conscrever",
    "conscreveríamos": "conscrever",
    "conscreveríeis": "conscrever",
    "conscreves": "conscrever",
    "conscrevesse": "conscrever",
    "conscrevessem": "conscrever",
    "conscrevesses": "conscrever",
    "conscreveste": "conscrever",
    "conscrevestes": "conscrever",
    "conscreveu": "conscrever",
    "conscrevi": "conscrever",
    "conscrevia": "conscrever",
    "conscreviam": "conscrever",
    "conscrevias": "conscrever",
    "conscrevo": "conscrever",
    "conscrevê": "conscrever",
    "conscrevêramo": "conscrever",
    "conscrevêramos": "conscrever",
    "conscrevêrei": "conscrever",
    "conscrevêreis": "conscrever",
    "conscrevêsseis": "conscrever",
    "conscrevêssemos": "conscrever",
    "conscrevíamo": "conscrever",
    "conscrevíamos": "conscrever",
    "conscrevíei": "conscrever",
    "conscrevíeis": "conscrever",
    "conscrita": "conscrito",
    "conscritas": "conscrito",
    "conscrito": "conscrever",
    "conscritos": "conscrito",
    "conscrições": "conscrição",
    "consecrantes": "consecrante",
    "consecratória": "consecratório",
    "consecratórias": "consecratório",
    "consecratórios": "consecratório",
    "consectária": "consectário",
    "consectárias": "consectário",
    "consectários": "consectário",
    "consecutiva": "consecutivo",
    "consecutivas": "consecutivo",
    "consecutivos": "consecutivo",
    "consecuções": "consecução",
    "consegue": "conseguir",
    "conseguem": "conseguir",
    "consegues": "conseguir",
    "consegui": "conseguir",
    "conseguia": "conseguir",
    "conseguiam": "conseguir",
    "conseguias": "conseguir",
    "conseguida": "conseguir",
    "conseguidas": "conseguir",
    "conseguido": "conseguir",
    "conseguidora": "conseguidor",
    "conseguidoras": "conseguidor",
    "conseguidores": "conseguidor",
    "conseguidos": "conseguir",
    "conseguidíssima": "conseguido",
    "conseguidíssimas": "conseguido",
    "conseguidíssimo": "conseguido",
    "conseguidíssimos": "conseguido",
    "conseguimentos": "conseguimento",
    "conseguimo": "conseguir",
    "conseguimos": "conseguir",
    "conseguindo": "conseguir",
    "conseguintes": "conseguinte",
    "conseguira": "conseguir",
    "conseguiram": "conseguir",
    "conseguiras": "conseguir",
    "conseguirde": "conseguir",
    "conseguirdes": "conseguir",
    "conseguire": "conseguir",
    "conseguirei": "conseguir",
    "conseguireis": "conseguir",
    "conseguirem": "conseguir",
    "conseguiremos": "conseguir",
    "conseguires": "conseguir",
    "conseguiria": "conseguir",
    "conseguiriam": "conseguir",
    "conseguirias": "conseguir",
    "conseguirmo": "conseguir",
    "conseguirmos": "conseguir",
    "conseguirá": "conseguir",
    "conseguirás": "conseguir",
    "conseguirão": "conseguir",
    "conseguiríamos": "conseguir",
    "conseguiríeis": "conseguir",
    "conseguis": "conseguir",
    "conseguisse": "conseguir",
    "conseguissem": "conseguir",
    "conseguisses": "conseguir",
    "conseguiste": "conseguir",
    "conseguistes": "conseguir",
    "conseguiu": "conseguir",
    "conseguíamo": "conseguir",
    "conseguíamos": "conseguir",
    "conseguíei": "conseguir",
    "conseguíeis": "conseguir",
    "conseguíramo": "conseguir",
    "conseguíramos": "conseguir",
    "conseguírei": "conseguir",
    "conseguíreis": "conseguir",
    "conseguísseis": "conseguir",
    "conseguíssemos": "conseguir",
    "conseguíveis": "conseguível",
    "conselheira": "conselheiro",
    "conselheirais": "conselheiral",
    "conselheiras": "conselheiro",
    "conselheiresca": "conselheiresco",
    "conselheirescas": "conselheiresco",
    "conselheirescos": "conselheiresco",
    "conselheirismos": "conselheirismo",
    "conselheiros": "conselheiro",
    "conselheirática": "conselheirático",
    "conselheiráticas": "conselheirático",
    "conselheiráticos": "conselheirático",
    "conselhinho": "conselho",
    "conselhinhos": "conselho",
    "conselhito": "conselho",
    "conselhitos": "conselho",
    "conselhos": "conselho",
    "consemelhanças": "consemelhança",
    "consencientes": "consenciente",
    "consensiais": "consensial",
    "consensos": "consenso",
    "consensuais": "consensual",
    "consensualidades": "consensualidade",
    "consentaneidades": "consentaneidade",
    "consente": "consentir",
    "consentem": "consentir",
    "consentes": "consentir",
    "consenti": "consentir",
    "consentia": "consentir",
    "consentiam": "consentir",
    "consentias": "consentir",
    "consentida": "consentir",
    "consentidas": "consentir",
    "consentido": "consentir",
    "consentidora": "consentidor",
    "consentidoras": "consentidor",
    "consentidores": "consentidor",
    "consentidos": "consentir",
    "consentimentos": "consentimento",
    "consentimo": "consentir",
    "consentimos": "consentir",
    "consentindo": "consentir",
    "consentira": "consentir",
    "consentiram": "consentir",
    "consentiras": "consentir",
    "consentirde": "consentir",
    "consentirdes": "consentir",
    "consentire": "consentir",
    "consentirei": "consentir",
    "consentireis": "consentir",
    "consentirem": "consentir",
    "consentiremos": "consentir",
    "consentires": "consentir",
    "consentiria": "consentir",
    "consentiriam": "consentir",
    "consentirias": "consentir",
    "consentirmo": "consentir",
    "consentirmos": "consentir",
    "consentirá": "consentir",
    "consentirás": "consentir",
    "consentirão": "consentir",
    "consentiríamos": "consentir",
    "consentiríeis": "consentir",
    "consentis": "consentir",
    "consentisse": "consentir",
    "consentissem": "consentir",
    "consentisses": "consentir",
    "consentiste": "consentir",
    "consentistes": "consentir",
    "consentiu": "consentir",
    "consentânea": "consentâneo",
    "consentâneas": "consentâneo",
    "consentâneos": "consentâneo",
    "consentíamo": "consentir",
    "consentíamos": "consentir",
    "consentíei": "consentir",
    "consentíeis": "consentir",
    "consentíramo": "consentir",
    "consentíramos": "consentir",
    "consentírei": "consentir",
    "consentíreis": "consentir",
    "consentísseis": "consentir",
    "consentíssemos": "consentir",
    "consequenciais": "consequencial",
    "consequentes": "consequente",
    "consequências": "consequência",
    "conserta": "consertar",
    "consertada": "consertar",
    "consertadas": "consertar",
    "consertado": "consertar",
    "consertadora": "consertador",
    "consertadoras": "consertador",
    "consertadores": "consertador",
    "consertados": "consertar",
    "consertai": "consertar",
    "consertais": "consertar",
    "consertam": "consertar",
    "consertamo": "consertar",
    "consertamos": "consertar",
    "consertando": "consertar",
    "consertara": "consertar",
    "consertaram": "consertar",
    "consertaras": "consertar",
    "consertarde": "consertar",
    "consertardes": "consertar",
    "consertare": "consertar",
    "consertarei": "consertar",
    "consertareis": "consertar",
    "consertarem": "consertar",
    "consertaremos": "consertar",
    "consertares": "consertar",
    "consertaria": "consertar",
    "consertariam": "consertar",
    "consertarias": "consertar",
    "consertarmo": "consertar",
    "consertarmos": "consertar",
    "consertará": "consertar",
    "consertarás": "consertar",
    "consertarão": "consertar",
    "consertaríamos": "consertar",
    "consertaríeis": "consertar",
    "consertas": "consertar",
    "consertasse": "consertar",
    "consertassem": "consertar",
    "consertasses": "consertar",
    "consertaste": "consertar",
    "consertastes": "consertar",
    "consertava": "consertar",
    "consertavam": "consertar",
    "consertavas": "consertar",
    "conserte": "consertar",
    "consertei": "consertar",
    "conserteis": "consertar",
    "consertem": "consertar",
    "consertemo": "consertar",
    "consertemos": "consertar",
    "consertes": "consertar",
    "conserto": "consertar",
    "consertos": "conserto",
    "consertou": "consertar",
    "consertá": "consertar",
    "consertámo": "consertar",
    "consertámos": "consertar",
    "consertáramo": "consertar",
    "consertáramos": "consertar",
    "consertárei": "consertar",
    "consertáreis": "consertar",
    "consertásseis": "consertar",
    "consertássemos": "consertar",
    "consertávamo": "consertar",
    "consertávamos": "consertar",
    "consertávei": "consertar",
    "consertáveis": "consertar",
    "conserva": "conservar",
    "conservabilidades": "conservabilidade",
    "conservada": "conservar",
    "conservadas": "conservar",
    "conservado": "conservar",
    "conservadora": "conservador",
    "conservadoras": "conservador",
    "conservadores": "conservador",
    "conservadorismos": "conservadorismo",
    "conservados": "conservar",
    "conservai": "conservar",
    "conservais": "conservar",
    "conservam": "conservar",
    "conservamo": "conservar",
    "conservamos": "conservar",
    "conservando": "conservar",
    "conservantes": "conservante",
    "conservantismos": "conservantismo",
    "conservantistas": "conservantista",
    "conservara": "conservar",
    "conservaram": "conservar",
    "conservaras": "conservar",
    "conservarde": "conservar",
    "conservardes": "conservar",
    "conservare": "conservar",
    "conservarei": "conservar",
    "conservareis": "conservar",
    "conservarem": "conservar",
    "conservaremos": "conservar",
    "conservares": "conservar",
    "conservaria": "conservar",
    "conservariam": "conservar",
    "conservarias": "conservaria",
    "conservarmo": "conservar",
    "conservarmos": "conservar",
    "conservará": "conservar",
    "conservarás": "conservar",
    "conservarão": "conservar",
    "conservaríamos": "conservar",
    "conservaríeis": "conservar",
    "conservas": "conservar",
    "conservasse": "conservar",
    "conservassem": "conservar",
    "conservasses": "conservar",
    "conservaste": "conservar",
    "conservastes": "conservar",
    "conservativa": "conservativo",
    "conservativas": "conservativo",
    "conservativos": "conservativo",
    "conservatória": "conservatório",
    "conservatórias": "conservatório",
    "conservatórios": "conservatório",
    "conservava": "conservar",
    "conservavam": "conservar",
    "conservavas": "conservar",
    "conservações": "conservação",
    "conserve": "conservar",
    "conservei": "conservar",
    "conserveira": "conserveiro",
    "conserveiras": "conserveiro",
    "conserveiros": "conserveiro",
    "conserveis": "conservar",
    "conservem": "conservar",
    "conservemo": "conservar",
    "conservemos": "conservar",
    "conserves": "conservar",
    "conservidora": "conservidor",
    "conservidoras": "conservidor",
    "conservidores": "conservidor",
    "conservo": "conservar",
    "conservos": "conservo",
    "conservou": "conservar",
    "conservá": "conservar",
    "conservámo": "conservar",
    "conservámos": "conservar",
    "conserváramo": "conservar",
    "conserváramos": "conservar",
    "conservárei": "conservar",
    "conserváreis": "conservar",
    "conservásseis": "conservar",
    "conservássemos": "conservar",
    "conservávamo": "conservar",
    "conservávamos": "conservar",
    "conservávei": "conservar",
    "conserváveis": "conservável",
    "considera": "considerar",
    "considerada": "considerar",
    "consideradas": "considerar",
    "considerado": "considerar",
    "considerados": "considerar",
    "consideradíssima": "considerado",
    "consideradíssimas": "considerado",
    "consideradíssimo": "considerado",
    "consideradíssimos": "considerado",
    "considerai": "considerar",
    "considerais": "considerar",
    "consideram": "considerar",
    "consideramo": "considerar",
    "consideramos": "considerar",
    "considerando": "considerar",
    "considerandos": "considerando",
    "considerara": "considerar",
    "consideraram": "considerar",
    "consideraras": "considerar",
    "considerarde": "considerar",
    "considerardes": "considerar",
    "considerare": "considerar",
    "considerarei": "considerar",
    "considerareis": "considerar",
    "considerarem": "considerar",
    "consideraremos": "considerar",
    "considerares": "considerar",
    "consideraria": "considerar",
    "considerariam": "considerar",
    "considerarias": "considerar",
    "considerarmo": "considerar",
    "considerarmos": "considerar",
    "considerará": "considerar",
    "considerarás": "considerar",
    "considerarão": "considerar",
    "consideraríamos": "considerar",
    "consideraríeis": "considerar",
    "consideras": "considerar",
    "considerasse": "considerar",
    "considerassem": "considerar",
    "considerasses": "considerar",
    "consideraste": "considerar",
    "considerastes": "considerar",
    "considerativa": "considerativo",
    "considerativas": "considerativo",
    "considerativos": "considerativo",
    "considerava": "considerar",
    "consideravam": "considerar",
    "consideravas": "considerar",
    "considerações": "consideração",
    "considere": "considerar",
    "considerei": "considerar",
    "considereis": "considerar",
    "considerem": "considerar",
    "consideremo": "considerar",
    "consideremos": "considerar",
    "consideres": "considerar",
    "considero": "considerar",
    "considerou": "considerar",
    "considerá": "considerar",
    "considerámo": "considerar",
    "considerámos": "considerar",
    "consideráramo": "considerar",
    "consideráramos": "considerar",
    "considerárei": "considerar",
    "consideráreis": "considerar",
    "considerásseis": "considerar",
    "considerássemos": "considerar",
    "considerávamo": "considerar",
    "considerávamos": "considerar",
    "considerávei": "considerar",
    "consideráveis": "considerável",
    "consiga": "conseguir",
    "consigais": "conseguir",
    "consigam": "conseguir",
    "consigamo": "conseguir",
    "consigamos": "conseguir",
    "consigas": "conseguir",
    "consigna": "consignar",
    "consignada": "consignar",
    "consignadas": "consignar",
    "consignado": "consignar",
    "consignadora": "consignador",
    "consignadoras": "consignador",
    "consignadores": "consignador",
    "consignados": "consignar",
    "consignai": "consignar",
    "consignais": "consignar",
    "consignam": "consignar",
    "consignamo": "consignar",
    "consignamos": "consignar",
    "consignando": "consignar",
    "consignantes": "consignante",
    "consignara": "consignar",
    "consignaram": "consignar",
    "consignaras": "consignar",
    "consignarde": "consignar",
    "consignardes": "consignar",
    "consignare": "consignar",
    "consignarei": "consignar",
    "consignareis": "consignar",
    "consignarem": "consignar",
    "consignaremos": "consignar",
    "consignares": "consignar",
    "consignaria": "consignar",
    "consignariam": "consignar",
    "consignarias": "consignar",
    "consignarmo": "consignar",
    "consignarmos": "consignar",
    "consignará": "consignar",
    "consignarás": "consignar",
    "consignarão": "consignar",
    "consignaríamos": "consignar",
    "consignaríeis": "consignar",
    "consignas": "consignar",
    "consignasse": "consignar",
    "consignassem": "consignar",
    "consignasses": "consignar",
    "consignaste": "consignar",
    "consignastes": "consignar",
    "consignativa": "consignativo",
    "consignativas": "consignativo",
    "consignativos": "consignativo",
    "consignatária": "consignatário",
    "consignatárias": "consignatário",
    "consignatários": "consignatário",
    "consignava": "consignar",
    "consignavam": "consignar",
    "consignavas": "consignar",
    "consignações": "consignação",
    "consigne": "consignar",
    "consignei": "consignar",
    "consigneis": "consignar",
    "consignem": "consignar",
    "consignemo": "consignar",
    "consignemos": "consignar",
    "consignes": "consignar",
    "consigno": "consignar",
    "consignou": "consignar",
    "consigná": "consignar",
    "consignámo": "consignar",
    "consignámos": "consignar",
    "consignáramo": "consignar",
    "consignáramos": "consignar",
    "consignárei": "consignar",
    "consignáreis": "consignar",
    "consignásseis": "consignar",
    "consignássemos": "consignar",
    "consignávamo": "consignar",
    "consignávamos": "consignar",
    "consignávei": "consignar",
    "consignáveis": "consignável",
    "consigo": "conseguir",
    "consinta": "consentir",
    "consintais": "consentir",
    "consintam": "consentir",
    "consintamo": "consentir",
    "consintamos": "consentir",
    "consintas": "consentir",
    "consinto": "consentir",
    "consista": "consistir",
    "consistais": "consistir",
    "consistam": "consistir",
    "consistamo": "consistir",
    "consistamos": "consistir",
    "consistas": "consistir",
    "consiste": "consistir",
    "consistem": "consistir",
    "consistentes": "consistente",
    "consistes": "consistir",
    "consisti": "consistir",
    "consistia": "consistir",
    "consistiam": "consistir",
    "consistias": "consistir",
    "consistida": "consistir",
    "consistidas": "consistir",
    "consistido": "consistir",
    "consistidos": "consistir",
    "consistimo": "consistir",
    "consistimos": "consistir",
    "consistindo": "consistir",
    "consistira": "consistir",
    "consistiram": "consistir",
    "consistiras": "consistir",
    "consistirdes": "consistir",
    "consistirei": "consistir",
    "consistireis": "consistir",
    "consistirem": "consistir",
    "consistiremos": "consistir",
    "consistires": "consistir",
    "consistiria": "consistir",
    "consistiriam": "consistir",
    "consistirias": "consistir",
    "consistirmo": "consistir",
    "consistirmos": "consistir",
    "consistirá": "consistir",
    "consistirás": "consistir",
    "consistirão": "consistir",
    "consistiríamos": "consistir",
    "consistiríeis": "consistir",
    "consistis": "consistir",
    "consistisse": "consistir",
    "consistissem": "consistir",
    "consistisses": "consistir",
    "consististe": "consistir",
    "consististes": "consistir",
    "consistiu": "consistir",
    "consisto": "consistir",
    "consistoriais": "consistorial",
    "consistências": "consistência",
    "consistíamo": "consistir",
    "consistíamos": "consistir",
    "consistíeis": "consistir",
    "consistíramo": "consistir",
    "consistíramos": "consistir",
    "consistíreis": "consistir",
    "consistísseis": "consistir",
    "consistíssemos": "consistir",
    "consistória": "consistório",
    "consistórias": "consistório",
    "consistórios": "consistório",
    "consoa": "consoar",
    "consoada": "consoar",
    "consoadas": "consoar",
    "consoado": "consoar",
    "consoados": "consoar",
    "consoai": "consoar",
    "consoais": "consoar",
    "consoam": "consoar",
    "consoamo": "consoar",
    "consoamos": "consoar",
    "consoando": "consoar",
    "consoantes": "consoante",
    "consoara": "consoar",
    "consoaram": "consoar",
    "consoaras": "consoar",
    "consoarde": "consoar",
    "consoardes": "consoar",
    "consoare": "consoar",
    "consoarei": "consoar",
    "consoareis": "consoar",
    "consoarem": "consoar",
    "consoaremos": "consoar",
    "consoares": "consoar",
    "consoaria": "consoar",
    "consoariam": "consoar",
    "consoarias": "consoar",
    "consoarmo": "consoar",
    "consoarmos": "consoar",
    "consoará": "consoar",
    "consoarás": "consoar",
    "consoarão": "consoar",
    "consoaríamos": "consoar",
    "consoaríeis": "consoar",
    "consoas": "consoar",
    "consoasse": "consoar",
    "consoassem": "consoar",
    "consoasses": "consoar",
    "consoaste": "consoar",
    "consoastes": "consoar",
    "consoava": "consoar",
    "consoavam": "consoar",
    "consoavas": "consoar",
    "consocia": "consociar",
    "consociada": "consociar",
    "consociadas": "consociar",
    "consociado": "consociar",
    "consociados": "consociar",
    "consociai": "consociar",
    "consociais": "consociar",
    "consociam": "consociar",
    "consociamo": "consociar",
    "consociamos": "consociar",
    "consociando": "consociar",
    "consociara": "consociar",
    "consociaram": "consociar",
    "consociaras": "consociar",
    "consociarde": "consociar",
    "consociardes": "consociar",
    "consociare": "consociar",
    "consociarei": "consociar",
    "consociareis": "consociar",
    "consociarem": "consociar",
    "consociaremos": "consociar",
    "consociares": "consociar",
    "consociaria": "consociar",
    "consociariam": "consociar",
    "consociarias": "consociar",
    "consociarmo": "consociar",
    "consociarmos": "consociar",
    "consociará": "consociar",
    "consociarás": "consociar",
    "consociarão": "consociar",
    "consociaríamos": "consociar",
    "consociaríeis": "consociar",
    "consocias": "consociar",
    "consociasse": "consociar",
    "consociassem": "consociar",
    "consociasses": "consociar",
    "consociaste": "consociar",
    "consociastes": "consociar",
    "consociava": "consociar",
    "consociavam": "consociar",
    "consociavas": "consociar",
    "consocie": "consociar",
    "consociei": "consociar",
    "consocieis": "consociar",
    "consociem": "consociar",
    "consociemo": "consociar",
    "consociemos": "consociar",
    "consocies": "consociar",
    "consocio": "consociar",
    "consociou": "consociar",
    "consociá": "consociar",
    "consociámo": "consociar",
    "consociámos": "consociar",
    "consociáramo": "consociar",
    "consociáramos": "consociar",
    "consociárei": "consociar",
    "consociáreis": "consociar",
    "consociásseis": "consociar",
    "consociássemos": "consociar",
    "consociávamo": "consociar",
    "consociávamos": "consociar",
    "consociávei": "consociar",
    "consociáveis": "consociável",
    "consoe": "consoar",
    "consoei": "consoar",
    "consoeis": "consoar",
    "consoem": "consoar",
    "consoemo": "consoar",
    "consoemos": "consoar",
    "consoes": "consoar",
    "consogra": "consogro",
    "consogras": "consogro",
    "consogros": "consogro",
    "consola": "consolar",
    "consolada": "consolar",
    "consoladas": "consolar",
    "consolado": "consolar",
    "consoladora": "consolador",
    "consoladoras": "consolador",
    "consoladores": "consolador",
    "consolados": "consolar",
    "consolai": "consolar",
    "consolais": "consolar",
    "consolam": "consolar",
    "consolamo": "consolar",
    "consolamos": "consolar",
    "consolando": "consolar",
    "consolara": "consolar",
    "consolaram": "consolar",
    "consolaras": "consolar",
    "consolarde": "consolar",
    "consolardes": "consolar",
    "consolare": "consolar",
    "consolarei": "consolar",
    "consolareis": "consolar",
    "consolarem": "consolar",
    "consolaremos": "consolar",
    "consolares": "consolar",
    "consolaria": "consolar",
    "consolariam": "consolar",
    "consolarias": "consolar",
    "consolarmo": "consolar",
    "consolarmos": "consolar",
    "consolará": "consolar",
    "consolarás": "consolar",
    "consolarão": "consolar",
    "consolaríamos": "consolar",
    "consolaríeis": "consolar",
    "consolas": "consolar",
    "consolasse": "consolar",
    "consolassem": "consolar",
    "consolasses": "consolar",
    "consolaste": "consolar",
    "consolastes": "consolar",
    "consolativa": "consolativo",
    "consolativas": "consolativo",
    "consolativos": "consolativo",
    "consolatória": "consolatório",
    "consolatórias": "consolatório",
    "consolatórios": "consolatório",
    "consolava": "consolar",
    "consolavam": "consolar",
    "consolavas": "consolar",
    "consolações": "consolação",
    "consoldas": "consolda",
    "console": "consolar",
    "consolei": "consolar",
    "consoleis": "consolar",
    "consolem": "consolar",
    "consolemo": "consolar",
    "consolemos": "consolar",
    "consoles": "consolar",
    "consolida": "consolidar",
    "consolidada": "consolidar",
    "consolidadas": "consolidar",
    "consolidado": "consolidar",
    "consolidados": "consolidar",
    "consolidai": "consolidar",
    "consolidais": "consolidar",
    "consolidam": "consolidar",
    "consolidamo": "consolidar",
    "consolidamos": "consolidar",
    "consolidando": "consolidar",
    "consolidantes": "consolidante",
    "consolidara": "consolidar",
    "consolidaram": "consolidar",
    "consolidaras": "consolidar",
    "consolidarde": "consolidar",
    "consolidardes": "consolidar",
    "consolidare": "consolidar",
    "consolidarei": "consolidar",
    "consolidareis": "consolidar",
    "consolidarem": "consolidar",
    "consolidaremos": "consolidar",
    "consolidares": "consolidar",
    "consolidaria": "consolidar",
    "consolidariam": "consolidar",
    "consolidarias": "consolidar",
    "consolidarmo": "consolidar",
    "consolidarmos": "consolidar",
    "consolidará": "consolidar",
    "consolidarás": "consolidar",
    "consolidarão": "consolidar",
    "consolidaríamos": "consolidar",
    "consolidaríeis": "consolidar",
    "consolidas": "consolidar",
    "consolidasse": "consolidar",
    "consolidassem": "consolidar",
    "consolidasses": "consolidar",
    "consolidaste": "consolidar",
    "consolidastes": "consolidar",
    "consolidativa": "consolidativo",
    "consolidativas": "consolidativo",
    "consolidativos": "consolidativo",
    "consolidava": "consolidar",
    "consolidavam": "consolidar",
    "consolidavas": "consolidar",
    "consolidações": "consolidação",
    "consolide": "consolidar",
    "consolidei": "consolidar",
    "consolideis": "consolidar",
    "consolidem": "consolidar",
    "consolidemo": "consolidar",
    "consolidemos": "consolidar",
    "consolides": "consolidar",
    "consolido": "consolidar",
    "consolidou": "consolidar",
    "consolidá": "consolidar",
    "consolidámo": "consolidar",
    "consolidámos": "consolidar",
    "consolidáramo": "consolidar",
    "consolidáramos": "consolidar",
    "consolidárei": "consolidar",
    "consolidáreis": "consolidar",
    "consolidásseis": "consolidar",
    "consolidássemos": "consolidar",
    "consolidávamo": "consolidar",
    "consolidávamos": "consolidar",
    "consolidávei": "consolidar",
    "consolidáveis": "consolidável",
    "consolo": "consolar",
    "consolos": "consolo",
    "consolou": "consolar",
    "consolá": "consolar",
    "consolámo": "consolar",
    "consolámos": "consolar",
    "consoláramo": "consolar",
    "consoláramos": "consolar",
    "consolárei": "consolar",
    "consoláreis": "consolar",
    "consolásseis": "consolar",
    "consolássemos": "consolar",
    "consolávamo": "consolar",
    "consolávamos": "consolar",
    "consolávei": "consolar",
    "consoláveis": "consolável",
    "consome": "consumir",
    "consomem": "consumir",
    "consomes": "consumir",
    "consomês": "consomê",
    "consona": "consonar",
    "consonada": "consonar",
    "consonadas": "consonar",
    "consonado": "consonar",
    "consonados": "consonar",
    "consonai": "consonar",
    "consonais": "consonar",
    "consonam": "consonar",
    "consonamo": "consonar",
    "consonamos": "consonar",
    "consonando": "consonar",
    "consonantais": "consonantal",
    "consonantes": "consonante",
    "consonantismos": "consonantismo",
    "consonantiza": "consonantizar",
    "consonantizada": "consonantizar",
    "consonantizadas": "consonantizar",
    "consonantizado": "consonantizar",
    "consonantizados": "consonantizar",
    "consonantizai": "consonantizar",
    "consonantizais": "consonantizar",
    "consonantizam": "consonantizar",
    "consonantizamo": "consonantizar",
    "consonantizamos": "consonantizar",
    "consonantizando": "consonantizar",
    "consonantizara": "consonantizar",
    "consonantizaram": "consonantizar",
    "consonantizaras": "consonantizar",
    "consonantizarde": "consonantizar",
    "consonantizardes": "consonantizar",
    "consonantizare": "consonantizar",
    "consonantizarei": "consonantizar",
    "consonantizareis": "consonantizar",
    "consonantizarem": "consonantizar",
    "consonantizaremos": "consonantizar",
    "consonantizares": "consonantizar",
    "consonantizaria": "consonantizar",
    "consonantizariam": "consonantizar",
    "consonantizarias": "consonantizar",
    "consonantizarmo": "consonantizar",
    "consonantizarmos": "consonantizar",
    "consonantizará": "consonantizar",
    "consonantizarás": "consonantizar",
    "consonantizarão": "consonantizar",
    "consonantizaríamos": "consonantizar",
    "consonantizaríeis": "consonantizar",
    "consonantizas": "consonantizar",
    "consonantizasse": "consonantizar",
    "consonantizassem": "consonantizar",
    "consonantizasses": "consonantizar",
    "consonantizaste": "consonantizar",
    "consonantizastes": "consonantizar",
    "consonantizava": "consonantizar",
    "consonantizavam": "consonantizar",
    "consonantizavas": "consonantizar",
    "consonantizações": "consonantização",
    "consonantize": "consonantizar",
    "consonantizei": "consonantizar",
    "consonantizeis": "consonantizar",
    "consonantizem": "consonantizar",
    "consonantizemo": "consonantizar",
    "consonantizemos": "consonantizar",
    "consonantizes": "consonantizar",
    "consonantizo": "consonantizar",
    "consonantizou": "consonantizar",
    "consonantizá": "consonantizar",
    "consonantizámo": "consonantizar",
    "consonantizámos": "consonantizar",
    "consonantizáramo": "consonantizar",
    "consonantizáramos": "consonantizar",
    "consonantizárei": "consonantizar",
    "consonantizáreis": "consonantizar",
    "consonantizásseis": "consonantizar",
    "consonantizássemos": "consonantizar",
    "consonantizávamo": "consonantizar",
    "consonantizávamos": "consonantizar",
    "consonantizávei": "consonantizar",
    "consonantizáveis": "consonantizar",
    "consonara": "consonar",
    "consonaram": "consonar",
    "consonaras": "consonar",
    "consonarde": "consonar",
    "consonardes": "consonar",
    "consonare": "consonar",
    "consonarei": "consonar",
    "consonareis": "consonar",
    "consonarem": "consonar",
    "consonaremos": "consonar",
    "consonares": "consonar",
    "consonaria": "consonar",
    "consonariam": "consonar",
    "consonarias": "consonar",
    "consonarmo": "consonar",
    "consonarmos": "consonar",
    "consonará": "consonar",
    "consonarás": "consonar",
    "consonarão": "consonar",
    "consonaríamos": "consonar",
    "consonaríeis": "consonar",
    "consonas": "consonar",
    "consonasse": "consonar",
    "consonassem": "consonar",
    "consonasses": "consonar",
    "consonaste": "consonar",
    "consonastes": "consonar",
    "consonava": "consonar",
    "consonavam": "consonar",
    "consonavas": "consonar",
    "consone": "consonar",
    "consonei": "consonar",
    "consoneis": "consonar",
    "consonem": "consonar",
    "consonemo": "consonar",
    "consonemos": "consonar",
    "consones": "consonar",
    "consono": "consonar",
    "consonou": "consonar",
    "consoná": "consonar",
    "consonámo": "consonar",
    "consonámos": "consonar",
    "consonáramo": "consonar",
    "consonáramos": "consonar",
    "consonárei": "consonar",
    "consonáreis": "consonar",
    "consonásseis": "consonar",
    "consonássemos": "consonar",
    "consonávamo": "consonar",
    "consonávamos": "consonar",
    "consonávei": "consonar",
    "consonáveis": "consonar",
    "consonâncias": "consonância",
    "consonântica": "consonântico",
    "consonânticas": "consonântico",
    "consonânticos": "consonântico",
    "consoo": "consoar",
    "consoou": "consoar",
    "consorcia": "consorciar",
    "consorciada": "consorciar",
    "consorciadas": "consorciar",
    "consorciado": "consorciar",
    "consorciados": "consorciar",
    "consorciai": "consorciar",
    "consorciais": "consorciar",
    "consorciam": "consorciar",
    "consorciamo": "consorciar",
    "consorciamos": "consorciar",
    "consorciando": "consorciar",
    "consorciara": "consorciar",
    "consorciaram": "consorciar",
    "consorciaras": "consorciar",
    "consorciarde": "consorciar",
    "consorciardes": "consorciar",
    "consorciare": "consorciar",
    "consorciarei": "consorciar",
    "consorciareis": "consorciar",
    "consorciarem": "consorciar",
    "consorciaremos": "consorciar",
    "consorciares": "consorciar",
    "consorciaria": "consorciar",
    "consorciariam": "consorciar",
    "consorciarias": "consorciar",
    "consorciarmo": "consorciar",
    "consorciarmos": "consorciar",
    "consorciará": "consorciar",
    "consorciarás": "consorciar",
    "consorciarão": "consorciar",
    "consorciaríamos": "consorciar",
    "consorciaríeis": "consorciar",
    "consorcias": "consorciar",
    "consorciasse": "consorciar",
    "consorciassem": "consorciar",
    "consorciasses": "consorciar",
    "consorciaste": "consorciar",
    "consorciastes": "consorciar",
    "consorciava": "consorciar",
    "consorciavam": "consorciar",
    "consorciavas": "consorciar",
    "consorcie": "consorciar",
    "consorciei": "consorciar",
    "consorcieis": "consorciar",
    "consorciem": "consorciar",
    "consorciemo": "consorciar",
    "consorciemos": "consorciar",
    "consorcies": "consorciar",
    "consorcio": "consorciar",
    "consorciou": "consorciar",
    "consorciá": "consorciar",
    "consorciámo": "consorciar",
    "consorciámos": "consorciar",
    "consorciáramo": "consorciar",
    "consorciáramos": "consorciar",
    "consorciárei": "consorciar",
    "consorciáreis": "consorciar",
    "consorciásseis": "consorciar",
    "consorciássemos": "consorciar",
    "consorciávamo": "consorciar",
    "consorciávamos": "consorciar",
    "consorciávei": "consorciar",
    "consorciáveis": "consorciar",
    "consorores": "consoror",
    "consortes": "consorte",
    "consoá": "consoar",
    "consoámo": "consoar",
    "consoámos": "consoar",
    "consoáramo": "consoar",
    "consoáramos": "consoar",
    "consoárei": "consoar",
    "consoáreis": "consoar",
    "consoásseis": "consoar",
    "consoássemos": "consoar",
    "consoávamo": "consoar",
    "consoávamos": "consoar",
    "consoávei": "consoar",
    "consoáveis": "consoar",
    "conspectos": "conspecto",
    "conspecções": "conspecção",
    "conspeitos": "conspeito",
    "conspicuidades": "conspicuidade",
    "conspira": "conspirar",
    "conspirada": "conspirar",
    "conspiradas": "conspirar",
    "conspirado": "conspirar",
    "conspiradora": "conspirador",
    "conspiradoras": "conspirador",
    "conspiradores": "conspirador",
    "conspirados": "conspirar",
    "conspirai": "conspirar",
    "conspirais": "conspirar",
    "conspiram": "conspirar",
    "conspiramo": "conspirar",
    "conspiramos": "conspirar",
    "conspirando": "conspirar",
    "conspirantes": "conspirante",
    "conspirara": "conspirar",
    "conspiraram": "conspirar",
    "conspiraras": "conspirar",
    "conspirarde": "conspirar",
    "conspirardes": "conspirar",
    "conspirare": "conspirar",
    "conspirarei": "conspirar",
    "conspirareis": "conspirar",
    "conspirarem": "conspirar",
    "conspiraremos": "conspirar",
    "conspirares": "conspirar",
    "conspiraria": "conspirar",
    "conspirariam": "conspirar",
    "conspirarias": "conspirar",
    "conspirarmo": "conspirar",
    "conspirarmos": "conspirar",
    "conspirará": "conspirar",
    "conspirarás": "conspirar",
    "conspirarão": "conspirar",
    "conspiraríamos": "conspirar",
    "conspiraríeis": "conspirar",
    "conspiras": "conspirar",
    "conspirasse": "conspirar",
    "conspirassem": "conspirar",
    "conspirasses": "conspirar",
    "conspiraste": "conspirar",
    "conspirastes": "conspirar",
    "conspiratas": "conspirata",
    "conspirativa": "conspirativo",
    "conspirativas": "conspirativo",
    "conspirativos": "conspirativo",
    "conspiratória": "conspiratório",
    "conspiratórias": "conspiratório",
    "conspiratórios": "conspiratório",
    "conspirava": "conspirar",
    "conspiravam": "conspirar",
    "conspiravas": "conspirar",
    "conspirações": "conspiração",
    "conspire": "conspirar",
    "conspirei": "conspirar",
    "conspireis": "conspirar",
    "conspirem": "conspirar",
    "conspiremo": "conspirar",
    "conspiremos": "conspirar",
    "conspires": "conspirar",
    "conspiro": "conspirar",
    "conspirou": "conspirar",
    "conspirá": "conspirar",
    "conspirámo": "conspirar",
    "conspirámos": "conspirar",
    "conspiráramo": "conspirar",
    "conspiráramos": "conspirar",
    "conspirárei": "conspirar",
    "conspiráreis": "conspirar",
    "conspirásseis": "conspirar",
    "conspirássemos": "conspirar",
    "conspirávamo": "conspirar",
    "conspirávamos": "conspirar",
    "conspirávei": "conspirar",
    "conspiráveis": "conspirar",
    "conspurca": "conspurcar",
    "conspurcada": "conspurcar",
    "conspurcadas": "conspurcar",
    "conspurcado": "conspurcar",
    "conspurcados": "conspurcar",
    "conspurcai": "conspurcar",
    "conspurcais": "conspurcar",
    "conspurcam": "conspurcar",
    "conspurcamo": "conspurcar",
    "conspurcamos": "conspurcar",
    "conspurcando": "conspurcar",
    "conspurcara": "conspurcar",
    "conspurcaram": "conspurcar",
    "conspurcaras": "conspurcar",
    "conspurcarde": "conspurcar",
    "conspurcardes": "conspurcar",
    "conspurcare": "conspurcar",
    "conspurcarei": "conspurcar",
    "conspurcareis": "conspurcar",
    "conspurcarem": "conspurcar",
    "conspurcaremos": "conspurcar",
    "conspurcares": "conspurcar",
    "conspurcaria": "conspurcar",
    "conspurcariam": "conspurcar",
    "conspurcarias": "conspurcar",
    "conspurcarmo": "conspurcar",
    "conspurcarmos": "conspurcar",
    "conspurcará": "conspurcar",
    "conspurcarás": "conspurcar",
    "conspurcarão": "conspurcar",
    "conspurcaríamos": "conspurcar",
    "conspurcaríeis": "conspurcar",
    "conspurcas": "conspurcar",
    "conspurcasse": "conspurcar",
    "conspurcassem": "conspurcar",
    "conspurcasses": "conspurcar",
    "conspurcaste": "conspurcar",
    "conspurcastes": "conspurcar",
    "conspurcava": "conspurcar",
    "conspurcavam": "conspurcar",
    "conspurcavas": "conspurcar",
    "conspurcações": "conspurcação",
    "conspurco": "conspurcar",
    "conspurcou": "conspurcar",
    "conspurcá": "conspurcar",
    "conspurcámo": "conspurcar",
    "conspurcámos": "conspurcar",
    "conspurcáramo": "conspurcar",
    "conspurcáramos": "conspurcar",
    "conspurcárei": "conspurcar",
    "conspurcáreis": "conspurcar",
    "conspurcásseis": "conspurcar",
    "conspurcássemos": "conspurcar",
    "conspurcávamo": "conspurcar",
    "conspurcávamos": "conspurcar",
    "conspurcávei": "conspurcar",
    "conspurcáveis": "conspurcar",
    "conspurque": "conspurcar",
    "conspurquei": "conspurcar",
    "conspurqueis": "conspurcar",
    "conspurquem": "conspurcar",
    "conspurquemo": "conspurcar",
    "conspurquemos": "conspurcar",
    "conspurques": "conspurcar",
    "conspícua": "conspícuo",
    "conspícuas": "conspícuo",
    "conspícuos": "conspícuo",
    "consta": "constar",
    "constada": "constar",
    "constadas": "constar",
    "constado": "constar",
    "constados": "constar",
    "constai": "constar",
    "constais": "constar",
    "constam": "constar",
    "constamo": "constar",
    "constamos": "constar",
    "constando": "constar",
    "constantes": "constante",
    "constantiniana": "constantiniano",
    "constantinianas": "constantiniano",
    "constantinianos": "constantiniano",
    "constantinopolitana": "constantinopolitano",
    "constantinopolitanas": "constantinopolitano",
    "constantinopolitanos": "constantinopolitano",
    "constara": "constar",
    "constaram": "constar",
    "constaras": "constar",
    "constarde": "constar",
    "constardes": "constar",
    "constare": "constar",
    "constarei": "constar",
    "constareis": "constar",
    "constarem": "constar",
    "constaremos": "constar",
    "constares": "constar",
    "constaria": "constar",
    "constariam": "constar",
    "constarias": "constar",
    "constarmo": "constar",
    "constarmos": "constar",
    "constará": "constar",
    "constarás": "constar",
    "constarão": "constar",
    "constaríamos": "constar",
    "constaríeis": "constar",
    "constas": "constar",
    "constasse": "constar",
    "constassem": "constar",
    "constasses": "constar",
    "constaste": "constar",
    "constastes": "constar",
    "constata": "constatar",
    "constatada": "constatar",
    "constatadas": "constatar",
    "constatado": "constatar",
    "constatados": "constatar",
    "constatai": "constatar",
    "constatais": "constatar",
    "constatam": "constatar",
    "constatamo": "constatar",
    "constatamos": "constatar",
    "constatando": "constatar",
    "constatara": "constatar",
    "constataram": "constatar",
    "constataras": "constatar",
    "constatarde": "constatar",
    "constatardes": "constatar",
    "constatare": "constatar",
    "constatarei": "constatar",
    "constatareis": "constatar",
    "constatarem": "constatar",
    "constataremos": "constatar",
    "constatares": "constatar",
    "constataria": "constatar",
    "constatariam": "constatar",
    "constatarias": "constatar",
    "constatarmo": "constatar",
    "constatarmos": "constatar",
    "constatará": "constatar",
    "constatarás": "constatar",
    "constatarão": "constatar",
    "constataríamos": "constatar",
    "constataríeis": "constatar",
    "constatas": "constatar",
    "constatasse": "constatar",
    "constatassem": "constatar",
    "constatasses": "constatar",
    "constataste": "constatar",
    "constatastes": "constatar",
    "constatava": "constatar",
    "constatavam": "constatar",
    "constatavas": "constatar",
    "constatações": "constatação",
    "constate": "constatar",
    "constatei": "constatar",
    "constateis": "constatar",
    "constatem": "constatar",
    "constatemo": "constatar",
    "constatemos": "constatar",
    "constates": "constatar",
    "constato": "constatar",
    "constatou": "constatar",
    "constatá": "constatar",
    "constatámo": "constatar",
    "constatámos": "constatar",
    "constatáramo": "constatar",
    "constatáramos": "constatar",
    "constatárei": "constatar",
    "constatáreis": "constatar",
    "constatásseis": "constatar",
    "constatássemos": "constatar",
    "constatávamo": "constatar",
    "constatávamos": "constatar",
    "constatávei": "constatar",
    "constatáveis": "constatável",
    "constava": "constar",
    "constavam": "constar",
    "constavas": "constar",
    "conste": "constar",
    "constei": "constar",
    "consteis": "constar",
    "constela": "constelar",
    "constelada": "constelar",
    "consteladas": "constelar",
    "constelado": "constelar",
    "constelados": "constelar",
    "constelai": "constelar",
    "constelais": "constelar",
    "constelam": "constelar",
    "constelamo": "constelar",
    "constelamos": "constelar",
    "constelando": "constelar",
    "constelara": "constelar",
    "constelaram": "constelar",
    "constelaras": "constelar",
    "constelarde": "constelar",
    "constelardes": "constelar",
    "constelare": "constelar",
    "constelarei": "constelar",
    "constelareis": "constelar",
    "constelarem": "constelar",
    "constelaremos": "constelar",
    "constelares": "constelar",
    "constelaria": "constelar",
    "constelariam": "constelar",
    "constelarias": "constelar",
    "constelarmo": "constelar",
    "constelarmos": "constelar",
    "constelará": "constelar",
    "constelarás": "constelar",
    "constelarão": "constelar",
    "constelaríamos": "constelar",
    "constelaríeis": "constelar",
    "constelas": "constelar",
    "constelasse": "constelar",
    "constelassem": "constelar",
    "constelasses": "constelar",
    "constelaste": "constelar",
    "constelastes": "constelar",
    "constelava": "constelar",
    "constelavam": "constelar",
    "constelavas": "constelar",
    "constelações": "constelação",
    "constele": "constelar",
    "constelei": "constelar",
    "consteleis": "constelar",
    "constelem": "constelar",
    "constelemo": "constelar",
    "constelemos": "constelar",
    "consteles": "constelar",
    "constelo": "constelar",
    "constelou": "constelar",
    "constelá": "constelar",
    "constelámo": "constelar",
    "constelámos": "constelar",
    "consteláramo": "constelar",
    "consteláramos": "constelar",
    "constelárei": "constelar",
    "consteláreis": "constelar",
    "constelásseis": "constelar",
    "constelássemos": "constelar",
    "constelávamo": "constelar",
    "constelávamos": "constelar",
    "constelávei": "constelar",
    "consteláveis": "constelar",
    "constem": "constar",
    "constemo": "constar",
    "constemos": "constar",
    "consterna": "consternar",
    "consternada": "consternar",
    "consternadas": "consternar",
    "consternado": "consternar",
    "consternadora": "consternador",
    "consternadoras": "consternador",
    "consternadores": "consternador",
    "consternados": "consternar",
    "consternai": "consternar",
    "consternais": "consternar",
    "consternam": "consternar",
    "consternamo": "consternar",
    "consternamos": "consternar",
    "consternando": "consternar",
    "consternara": "consternar",
    "consternaram": "consternar",
    "consternaras": "consternar",
    "consternarde": "consternar",
    "consternardes": "consternar",
    "consternare": "consternar",
    "consternarei": "consternar",
    "consternareis": "consternar",
    "consternarem": "consternar",
    "consternaremos": "consternar",
    "consternares": "consternar",
    "consternaria": "consternar",
    "consternariam": "consternar",
    "consternarias": "consternar",
    "consternarmo": "consternar",
    "consternarmos": "consternar",
    "consternará": "consternar",
    "consternarás": "consternar",
    "consternarão": "consternar",
    "consternaríamos": "consternar",
    "consternaríeis": "consternar",
    "consternas": "consternar",
    "consternasse": "consternar",
    "consternassem": "consternar",
    "consternasses": "consternar",
    "consternaste": "consternar",
    "consternastes": "consternar",
    "consternativa": "consternativo",
    "consternativas": "consternativo",
    "consternativos": "consternativo",
    "consternava": "consternar",
    "consternavam": "consternar",
    "consternavas": "consternar",
    "consternações": "consternação",
    "consterne": "consternar",
    "consternei": "consternar",
    "consterneis": "consternar",
    "consternem": "consternar",
    "consternemo": "consternar",
    "consternemos": "consternar",
    "consternes": "consternar",
    "consterno": "consternar",
    "consternou": "consternar",
    "consterná": "consternar",
    "consternámo": "consternar",
    "consternámos": "consternar",
    "consternáramo": "consternar",
    "consternáramos": "consternar",
    "consternárei": "consternar",
    "consternáreis": "consternar",
    "consternásseis": "consternar",
    "consternássemos": "consternar",
    "consternávamo": "consternar",
    "consternávamos": "consternar",
    "consternávei": "consternar",
    "consternáveis": "consternar",
    "constes": "constar",
    "constipa": "constipar",
    "constipada": "constipar",
    "constipadas": "constipar",
    "constipado": "constipar",
    "constipados": "constipar",
    "constipai": "constipar",
    "constipais": "constipar",
    "constipam": "constipar",
    "constipamo": "constipar",
    "constipamos": "constipar",
    "constipando": "constipar",
    "constipara": "constipar",
    "constiparam": "constipar",
    "constiparas": "constipar",
    "constiparde": "constipar",
    "constipardes": "constipar",
    "constipare": "constipar",
    "constiparei": "constipar",
    "constipareis": "constipar",
    "constiparem": "constipar",
    "constiparemos": "constipar",
    "constipares": "constipar",
    "constiparia": "constipar",
    "constipariam": "constipar",
    "constiparias": "constipar",
    "constiparmo": "constipar",
    "constiparmos": "constipar",
    "constipará": "constipar",
    "constiparás": "constipar",
    "constiparão": "constipar",
    "constiparíamos": "constipar",
    "constiparíeis": "constipar",
    "constipas": "constipar",
    "constipasse": "constipar",
    "constipassem": "constipar",
    "constipasses": "constipar",
    "constipaste": "constipar",
    "constipastes": "constipar",
    "constipativa": "constipativo",
    "constipativas": "constipativo",
    "constipativos": "constipativo",
    "constipava": "constipar",
    "constipavam": "constipar",
    "constipavas": "constipar",
    "constipações": "constipação",
    "constipe": "constipar",
    "constipei": "constipar",
    "constipeis": "constipar",
    "constipem": "constipar",
    "constipemo": "constipar",
    "constipemos": "constipar",
    "constipes": "constipar",
    "constipo": "constipar",
    "constipou": "constipar",
    "constipá": "constipar",
    "constipámo": "constipar",
    "constipámos": "constipar",
    "constipáramo": "constipar",
    "constipáramos": "constipar",
    "constipárei": "constipar",
    "constipáreis": "constipar",
    "constipásseis": "constipar",
    "constipássemos": "constipar",
    "constipávamo": "constipar",
    "constipávamos": "constipar",
    "constipávei": "constipar",
    "constipáveis": "constipar",
    "constitua": "constituir",
    "constituais": "constituir",
    "constituam": "constituir",
    "constituamo": "constituir",
    "constituamos": "constituir",
    "constituas": "constituir",
    "constitucionais": "constitucional",
    "constitucionalidades": "constitucionalidade",
    "constitucionalismos": "constitucionalismo",
    "constitucionalistas": "constitucionalista",
    "constitucionaliza": "constitucionalizar",
    "constitucionalizada": "constitucionalizar",
    "constitucionalizadas": "constitucionalizar",
    "constitucionalizado": "constitucionalizar",
    "constitucionalizados": "constitucionalizar",
    "constitucionalizai": "constitucionalizar",
    "constitucionalizais": "constitucionalizar",
    "constitucionalizam": "constitucionalizar",
    "constitucionalizamo": "constitucionalizar",
    "constitucionalizamos": "constitucionalizar",
    "constitucionalizando": "constitucionalizar",
    "constitucionalizara": "constitucionalizar",
    "constitucionalizaram": "constitucionalizar",
    "constitucionalizaras": "constitucionalizar",
    "constitucionalizarde": "constitucionalizar",
    "constitucionalizardes": "constitucionalizar",
    "constitucionalizare": "constitucionalizar",
    "constitucionalizarei": "constitucionalizar",
    "constitucionalizareis": "constitucionalizar",
    "constitucionalizarem": "constitucionalizar",
    "constitucionalizaremos": "constitucionalizar",
    "constitucionalizares": "constitucionalizar",
    "constitucionalizaria": "constitucionalizar",
    "constitucionalizariam": "constitucionalizar",
    "constitucionalizarias": "constitucionalizar",
    "constitucionalizarmo": "constitucionalizar",
    "constitucionalizarmos": "constitucionalizar",
    "constitucionalizará": "constitucionalizar",
    "constitucionalizarás": "constitucionalizar",
    "constitucionalizarão": "constitucionalizar",
    "constitucionalizaríamos": "constitucionalizar",
    "constitucionalizaríeis": "constitucionalizar",
    "constitucionalizas": "constitucionalizar",
    "constitucionalizasse": "constitucionalizar",
    "constitucionalizassem": "constitucionalizar",
    "constitucionalizasses": "constitucionalizar",
    "constitucionalizaste": "constitucionalizar",
    "constitucionalizastes": "constitucionalizar",
    "constitucionalizava": "constitucionalizar",
    "constitucionalizavam": "constitucionalizar",
    "constitucionalizavas": "constitucionalizar",
    "constitucionalize": "constitucionalizar",
    "constitucionalizei": "constitucionalizar",
    "constitucionalizeis": "constitucionalizar",
    "constitucionalizem": "constitucionalizar",
    "constitucionalizemo": "constitucionalizar",
    "constitucionalizemos": "constitucionalizar",
    "constitucionalizes": "constitucionalizar",
    "constitucionalizo": "constitucionalizar",
    "constitucionalizou": "constitucionalizar",
    "constitucionalizá": "constitucionalizar",
    "constitucionalizámo": "constitucionalizar",
    "constitucionalizámos": "constitucionalizar",
    "constitucionalizáramo": "constitucionalizar",
    "constitucionalizáramos": "constitucionalizar",
    "constitucionalizárei": "constitucionalizar",
    "constitucionalizáreis": "constitucionalizar",
    "constitucionalizásseis": "constitucionalizar",
    "constitucionalizássemos": "constitucionalizar",
    "constitucionalizávamo": "constitucionalizar",
    "constitucionalizávamos": "constitucionalizar",
    "constitucionalizávei": "constitucionalizar",
    "constitucionalizáveis": "constitucionalizar",
    "constituem": "constituir",
    "constitui": "constituir",
    "constituicionalistas": "constituicionalista",
    "constituidora": "constituidor",
    "constituidoras": "constituidor",
    "constituidores": "constituidor",
    "constituindo": "constituir",
    "constituintes": "constituinte",
    "constituirde": "constituir",
    "constituirdes": "constituir",
    "constituirei": "constituir",
    "constituireis": "constituir",
    "constituiremos": "constituir",
    "constituiria": "constituir",
    "constituiriam": "constituir",
    "constituirias": "constituir",
    "constituirmo": "constituir",
    "constituirmos": "constituir",
    "constituirá": "constituir",
    "constituirás": "constituir",
    "constituirão": "constituir",
    "constituiríamos": "constituir",
    "constituiríeis": "constituir",
    "constituis": "constituir",
    "constituiu": "constituir",
    "constituições": "constituição",
    "constituo": "constituir",
    "constitutiva": "constitutivo",
    "constitutivas": "constitutivo",
    "constitutivos": "constitutivo",
    "constituí": "constituir",
    "constituía": "constituir",
    "constituíam": "constituir",
    "constituíamo": "constituir",
    "constituíamos": "constituir",
    "constituías": "constituir",
    "constituída": "constituir",
    "constituídas": "constituir",
    "constituído": "constituir",
    "constituídos": "constituir",
    "constituíei": "constituir",
    "constituíeis": "constituir",
    "constituímo": "constituir",
    "constituímos": "constituir",
    "constituíra": "constituir",
    "constituíram": "constituir",
    "constituíramo": "constituir",
    "constituíramos": "constituir",
    "constituíras": "constituir",
    "constituíre": "constituir",
    "constituírei": "constituir",
    "constituíreis": "constituir",
    "constituírem": "constituir",
    "constituíres": "constituir",
    "constituís": "constituir",
    "constituísse": "constituir",
    "constituísseis": "constituir",
    "constituíssem": "constituir",
    "constituíssemos": "constituir",
    "constituísses": "constituir",
    "constituíste": "constituir",
    "constituístes": "constituir",
    "constituíveis": "constituível",
    "consto": "constar",
    "constou": "constar",
    "constrange": "constranger",
    "constrangedora": "constrangedor",
    "constrangedoras": "constrangedor",
    "constrangedores": "constrangedor",
    "constrangei": "constranger",
    "constrangeis": "constranger",
    "constrangem": "constranger",
    "constrangemo": "constranger",
    "constrangemos": "constranger",
    "constrangendo": "constranger",
    "constrangera": "constranger",
    "constrangeram": "constranger",
    "constrangeras": "constranger",
    "constrangerde": "constranger",
    "constrangerdes": "constranger",
    "constrangere": "constranger",
    "constrangerei": "constranger",
    "constrangereis": "constranger",
    "constrangerem": "constranger",
    "constrangeremos": "constranger",
    "constrangeres": "constranger",
    "constrangeria": "constranger",
    "constrangeriam": "constranger",
    "constrangerias": "constranger",
    "constrangermo": "constranger",
    "constrangermos": "constranger",
    "constrangerá": "constranger",
    "constrangerás": "constranger",
    "constrangerão": "constranger",
    "constrangeríamos": "constranger",
    "constrangeríeis": "constranger",
    "constranges": "constranger",
    "constrangesse": "constranger",
    "constrangessem": "constranger",
    "constrangesses": "constranger",
    "constrangeste": "constranger",
    "constrangestes": "constranger",
    "constrangeu": "constranger",
    "constrangi": "constranger",
    "constrangia": "constranger",
    "constrangiam": "constranger",
    "constrangias": "constranger",
    "constrangida": "constrangido",
    "constrangidas": "constrangido",
    "constrangido": "constranger",
    "constrangidos": "constrangido",
    "constrangimentos": "constrangimento",
    "constrangê": "constranger",
    "constrangêramo": "constranger",
    "constrangêramos": "constranger",
    "constrangêrei": "constranger",
    "constrangêreis": "constranger",
    "constrangêsseis": "constranger",
    "constrangêssemos": "constranger",
    "constrangíamo": "constranger",
    "constrangíamos": "constranger",
    "constrangíei": "constranger",
    "constrangíeis": "constranger",
    "constranja": "constranger",
    "constranjais": "constranger",
    "constranjam": "constranger",
    "constranjamo": "constranger",
    "constranjamos": "constranger",
    "constranjas": "constranger",
    "constranjo": "constranger",
    "constri": "construir",
    "constrimentos": "constrimento",
    "constringe": "constringir",
    "constringem": "constringir",
    "constringentes": "constringente",
    "constringes": "constringir",
    "constringi": "constringir",
    "constringia": "constringir",
    "constringiam": "constringir",
    "constringias": "constringir",
    "constringida": "constringir",
    "constringidas": "constringir",
    "constringido": "constringir",
    "constringidos": "constringir",
    "constringimo": "constringir",
    "constringimos": "constringir",
    "constringindo": "constringir",
    "constringira": "constringir",
    "constringiram": "constringir",
    "constringiras": "constringir",
    "constringirde": "constringir",
    "constringirdes": "constringir",
    "constringire": "constringir",
    "constringirei": "constringir",
    "constringireis": "constringir",
    "constringirem": "constringir",
    "constringiremos": "constringir",
    "constringires": "constringir",
    "constringiria": "constringir",
    "constringiriam": "constringir",
    "constringirias": "constringir",
    "constringirmo": "constringir",
    "constringirmos": "constringir",
    "constringirá": "constringir",
    "constringirás": "constringir",
    "constringirão": "constringir",
    "constringiríamos": "constringir",
    "constringiríeis": "constringir",
    "constringis": "constringir",
    "constringisse": "constringir",
    "constringissem": "constringir",
    "constringisses": "constringir",
    "constringiste": "constringir",
    "constringistes": "constringir",
    "constringiu": "constringir",
    "constringíamo": "constringir",
    "constringíamos": "constringir",
    "constringíei": "constringir",
    "constringíeis": "constringir",
    "constringíramo": "constringir",
    "constringíramos": "constringir",
    "constringírei": "constringir",
    "constringíreis": "constringir",
    "constringísseis": "constringir",
    "constringíssemos": "constringir",
    "constrinja": "constringir",
    "constrinjais": "constringir",
    "constrinjam": "constringir",
    "constrinjamo": "constringir",
    "constrinjamos": "constringir",
    "constrinjas": "constringir",
    "constrinjo": "constringir",
    "constrita": "constrito",
    "constritas": "constrito",
    "constritiva": "constritivo",
    "constritivas": "constritivo",
    "constritivos": "constritivo",
    "constritora": "constritor",
    "constritoras": "constritor",
    "constritores": "constritor",
    "constritos": "constrito",
    "constrições": "constrição",
    "constroem": "construir",
    "construa": "construir",
    "construais": "construir",
    "construam": "construir",
    "construamo": "construir",
    "construamos": "construir",
    "construas": "construir",
    "constructos": "constructo",
    "construem": "construir",
    "construi": "construir",
    "construindo": "construir",
    "construirde": "construir",
    "construirdes": "construir",
    "construirei": "construir",
    "construireis": "construir",
    "construiremos": "construir",
    "construiria": "construir",
    "construiriam": "construir",
    "construirias": "construir",
    "construirmo": "construir",
    "construirmos": "construir",
    "construirá": "construir",
    "construirás": "construir",
    "construirão": "construir",
    "construiríamos": "construir",
    "construiríeis": "construir",
    "construis": "construir",
    "construiu": "construir",
    "construo": "construir",
    "construtiva": "construtivo",
    "construtivas": "construtivo",
    "construtivismos": "construtivismo",
    "construtivistas": "construtivista",
    "construtivos": "construtivo",
    "construtora": "construtor",
    "construtoras": "construtor",
    "construtores": "construtor",
    "construturas": "construtura",
    "construções": "construção",
    "construí": "construir",
    "construía": "construir",
    "construíam": "construir",
    "construíamo": "construir",
    "construíamos": "construir",
    "construías": "construir",
    "construída": "construir",
    "construídas": "construir",
    "construído": "construir",
    "construídos": "construir",
    "construíei": "construir",
    "construíeis": "construir",
    "construímo": "construir",
    "construímos": "construir",
    "construíra": "construir",
    "construíram": "construir",
    "construíramo": "construir",
    "construíramos": "construir",
    "construíras": "construir",
    "construíre": "construir",
    "construírei": "construir",
    "construíreis": "construir",
    "construírem": "construir",
    "construíres": "construir",
    "construís": "construir",
    "construísse": "construir",
    "construísseis": "construir",
    "construíssem": "construir",
    "construíssemos": "construir",
    "construísses": "construir",
    "construíste": "construir",
    "construístes": "construir",
    "constrói": "construir",
    "constróis": "construir",
    "constá": "constar",
    "constámo": "constar",
    "constámos": "constar",
    "constáramo": "constar",
    "constáramos": "constar",
    "constárei": "constar",
    "constáreis": "constar",
    "constásseis": "constar",
    "constássemos": "constar",
    "constávamo": "constar",
    "constávamos": "constar",
    "constávei": "constar",
    "constáveis": "constar",
    "constâncias": "constância",
    "consubstancia": "consubstanciar",
    "consubstanciada": "consubstanciar",
    "consubstanciadas": "consubstanciar",
    "consubstanciado": "consubstanciar",
    "consubstanciadora": "consubstanciador",
    "consubstanciadoras": "consubstanciador",
    "consubstanciadores": "consubstanciador",
    "consubstanciados": "consubstanciar",
    "consubstanciai": "consubstanciar",
    "consubstanciais": "consubstanciar",
    "consubstancialidades": "consubstancialidade",
    "consubstancializações": "consubstancialização",
    "consubstanciam": "consubstanciar",
    "consubstanciamo": "consubstanciar",
    "consubstanciamos": "consubstanciar",
    "consubstanciando": "consubstanciar",
    "consubstanciara": "consubstanciar",
    "consubstanciaram": "consubstanciar",
    "consubstanciaras": "consubstanciar",
    "consubstanciarde": "consubstanciar",
    "consubstanciardes": "consubstanciar",
    "consubstanciare": "consubstanciar",
    "consubstanciarei": "consubstanciar",
    "consubstanciareis": "consubstanciar",
    "consubstanciarem": "consubstanciar",
    "consubstanciaremos": "consubstanciar",
    "consubstanciares": "consubstanciar",
    "consubstanciaria": "consubstanciar",
    "consubstanciariam": "consubstanciar",
    "consubstanciarias": "consubstanciar",
    "consubstanciarmo": "consubstanciar",
    "consubstanciarmos": "consubstanciar",
    "consubstanciará": "consubstanciar",
    "consubstanciarás": "consubstanciar",
    "consubstanciarão": "consubstanciar",
    "consubstanciaríamos": "consubstanciar",
    "consubstanciaríeis": "consubstanciar",
    "consubstancias": "consubstanciar",
    "consubstanciasse": "consubstanciar",
    "consubstanciassem": "consubstanciar",
    "consubstanciasses": "consubstanciar",
    "consubstanciaste": "consubstanciar",
    "consubstanciastes": "consubstanciar",
    "consubstanciava": "consubstanciar",
    "consubstanciavam": "consubstanciar",
    "consubstanciavas": "consubstanciar",
    "consubstanciações": "consubstanciação",
    "consubstancie": "consubstanciar",
    "consubstanciei": "consubstanciar",
    "consubstancieis": "consubstanciar",
    "consubstanciem": "consubstanciar",
    "consubstanciemo": "consubstanciar",
    "consubstanciemos": "consubstanciar",
    "consubstancies": "consubstanciar",
    "consubstancio": "consubstanciar",
    "consubstanciou": "consubstanciar",
    "consubstanciá": "consubstanciar",
    "consubstanciámo": "consubstanciar",
    "consubstanciámos": "consubstanciar",
    "consubstanciáramo": "consubstanciar",
    "consubstanciáramos": "consubstanciar",
    "consubstanciárei": "consubstanciar",
    "consubstanciáreis": "consubstanciar",
    "consubstanciásseis": "consubstanciar",
    "consubstanciássemos": "consubstanciar",
    "consubstanciávamo": "consubstanciar",
    "consubstanciávamos": "consubstanciar",
    "consubstanciávei": "consubstanciar",
    "consubstanciáveis": "consubstanciar",
    "consueta": "consueto",
    "consuetas": "consueto",
    "consuetos": "consueto",
    "consuetudinária": "consuetudinário",
    "consuetudinárias": "consuetudinário",
    "consuetudinários": "consuetudinário",
    "consulados": "consulado",
    "consulagens": "consulagem",
    "consulares": "consular",
    "consulentes": "consulente",
    "consulesa": "cônsul",
    "consulesas": "cônsul",
    "consulta": "consulto",
    "consultada": "consultar",
    "consultadas": "consultar",
    "consultado": "consultar",
    "consultadora": "consultador",
    "consultadoras": "consultador",
    "consultadores": "consultador",
    "consultadorias": "consultadoria",
    "consultados": "consultar",
    "consultai": "consultar",
    "consultais": "consultar",
    "consultam": "consultar",
    "consultamo": "consultar",
    "consultamos": "consultar",
    "consultando": "consultar",
    "consultantes": "consultante",
    "consultara": "consultar",
    "consultaram": "consultar",
    "consultaras": "consultar",
    "consultarde": "consultar",
    "consultardes": "consultar",
    "consultare": "consultar",
    "consultarei": "consultar",
    "consultareis": "consultar",
    "consultarem": "consultar",
    "consultaremos": "consultar",
    "consultares": "consultar",
    "consultaria": "consultar",
    "consultariam": "consultar",
    "consultarias": "consultar",
    "consultarmo": "consultar",
    "consultarmos": "consultar",
    "consultará": "consultar",
    "consultarás": "consultar",
    "consultarão": "consultar",
    "consultaríamos": "consultar",
    "consultaríeis": "consultar",
    "consultas": "consulto",
    "consultasse": "consultar",
    "consultassem": "consultar",
    "consultasses": "consultar",
    "consultaste": "consultar",
    "consultastes": "consultar",
    "consultava": "consultar",
    "consultavam": "consultar",
    "consultavas": "consultar",
    "consultações": "consultação",
    "consulte": "consultar",
    "consultei": "consultar",
    "consulteis": "consultar",
    "consultem": "consultar",
    "consultemo": "consultar",
    "consultemos": "consultar",
    "consultes": "consultar",
    "consultiva": "consultivo",
    "consultivas": "consultivo",
    "consultivos": "consultivo",
    "consulto": "consultar",
    "consultora": "consultor",
    "consultoras": "consultor",
    "consultores": "consultor",
    "consultorias": "consultoria",
    "consultos": "consulto",
    "consultou": "consultar",
    "consultá": "consultar",
    "consultámo": "consultar",
    "consultámos": "consultar",
    "consultáramo": "consultar",
    "consultáramos": "consultar",
    "consultárei": "consultar",
    "consultáreis": "consultar",
    "consultásseis": "consultar",
    "consultássemos": "consultar",
    "consultávamo": "consultar",
    "consultávamos": "consultar",
    "consultávei": "consultar",
    "consultáveis": "consultável",
    "consultórios": "consultório",
    "consuma": "consumir",
    "consumada": "consumar",
    "consumadas": "consumar",
    "consumado": "consumar",
    "consumadora": "consumador",
    "consumadoras": "consumador",
    "consumadores": "consumador",
    "consumados": "consumar",
    "consumai": "consumar",
    "consumais": "consumir",
    "consumam": "consumir",
    "consumamo": "consumir",
    "consumamos": "consumir",
    "consumando": "consumar",
    "consumara": "consumar",
    "consumaram": "consumar",
    "consumaras": "consumar",
    "consumarde": "consumar",
    "consumardes": "consumar",
    "consumare": "consumar",
    "consumarei": "consumar",
    "consumareis": "consumar",
    "consumarem": "consumar",
    "consumaremos": "consumar",
    "consumares": "consumar",
    "consumaria": "consumar",
    "consumariam": "consumar",
    "consumarias": "consumar",
    "consumarmo": "consumar",
    "consumarmos": "consumar",
    "consumará": "consumar",
    "consumarás": "consumar",
    "consumarão": "consumar",
    "consumaríamos": "consumar",
    "consumaríeis": "consumar",
    "consumas": "consumir",
    "consumasse": "consumar",
    "consumassem": "consumar",
    "consumasses": "consumar",
    "consumaste": "consumar",
    "consumastes": "consumar",
    "consumava": "consumar",
    "consumavam": "consumar",
    "consumavas": "consumar",
    "consumações": "consumação",
    "consume": "consumar",
    "consumei": "consumar",
    "consumeis": "consumar",
    "consumem": "consumar",
    "consumemo": "consumar",
    "consumemos": "consumar",
    "consumes": "consumar",
    "consumi": "consumir",
    "consumia": "consumir",
    "consumiam": "consumir",
    "consumias": "consumir",
    "consumida": "consumir",
    "consumidas": "consumir",
    "consumido": "consumir",
    "consumidora": "consumidor",
    "consumidoras": "consumidor",
    "consumidores": "consumidor",
    "consumidos": "consumir",
    "consumidíssima": "consumido",
    "consumidíssimas": "consumido",
    "consumidíssimo": "consumido",
    "consumidíssimos": "consumido",
    "consumimo": "consumir",
    "consumimos": "consumir",
    "consumindo": "consumir",
    "consumira": "consumir",
    "consumiram": "consumir",
    "consumiras": "consumir",
    "consumirde": "consumir",
    "consumirdes": "consumir",
    "consumire": "consumir",
    "consumirei": "consumir",
    "consumireis": "consumir",
    "consumirem": "consumir",
    "consumiremos": "consumir",
    "consumires": "consumir",
    "consumiria": "consumir",
    "consumiriam": "consumir",
    "consumirias": "consumir",
    "consumirmo": "consumir",
    "consumirmos": "consumir",
    "consumirá": "consumir",
    "consumirás": "consumir",
    "consumirão": "consumir",
    "consumiríamos": "consumir",
    "consumiríeis": "consumir",
    "consumis": "consumir",
    "consumismos": "consumismo",
    "consumisse": "consumir",
    "consumissem": "consumir",
    "consumisses": "consumir",
    "consumistas": "consumista",
    "consumiste": "consumir",
    "consumistes": "consumir",
    "consumiu": "consumir",
    "consumições": "consumição",
    "consumo": "consumir",
    "consumos": "consumo",
    "consumou": "consumar",
    "consumpta": "consumpto",
    "consumptas": "consumpto",
    "consumptibilidades": "consumptibilidade",
    "consumptos": "consumpto",
    "consumptíveis": "consumptível",
    "consumpções": "consumpção",
    "consumtiva": "consumtivo",
    "consumtivas": "consumtivo",
    "consumtivos": "consumtivo",
    "consumá": "consumar",
    "consumámo": "consumar",
    "consumámos": "consumar",
    "consumáramo": "consumar",
    "consumáramos": "consumar",
    "consumárei": "consumar",
    "consumáreis": "consumar",
    "consumásseis": "consumar",
    "consumássemos": "consumar",
    "consumávamo": "consumar",
    "consumávamos": "consumar",
    "consumávei": "consumar",
    "consumáveis": "consumar",
    "consumíamo": "consumir",
    "consumíamos": "consumir",
    "consumíei": "consumir",
    "consumíeis": "consumir",
    "consumíramo": "consumir",
    "consumíramos": "consumir",
    "consumírei": "consumir",
    "consumíreis": "consumir",
    "consumísseis": "consumir",
    "consumíssemos": "consumir",
    "consumíveis": "consumível",
    "consílios": "consílio",
    "consócia": "consócio",
    "consócias": "consócio",
    "consócios": "consócio",
    "consórcios": "consórcio",
    "consórores": "consóror",
    "consúteis": "consútil",
    "conta": "contar",
    "contabesce": "contabescer",
    "contabescei": "contabescer",
    "contabesceis": "contabescer",
    "contabescem": "contabescer",
    "contabescemo": "contabescer",
    "contabescemos": "contabescer",
    "contabescendo": "contabescer",
    "contabescera": "contabescer",
    "contabesceram": "contabescer",
    "contabesceras": "contabescer",
    "contabescerde": "contabescer",
    "contabescerdes": "contabescer",
    "contabescere": "contabescer",
    "contabescerei": "contabescer",
    "contabescereis": "contabescer",
    "contabescerem": "contabescer",
    "contabesceremos": "contabescer",
    "contabesceres": "contabescer",
    "contabesceria": "contabescer",
    "contabesceriam": "contabescer",
    "contabescerias": "contabescer",
    "contabescermo": "contabescer",
    "contabescermos": "contabescer",
    "contabescerá": "contabescer",
    "contabescerás": "contabescer",
    "contabescerão": "contabescer",
    "contabesceríamos": "contabescer",
    "contabesceríeis": "contabescer",
    "contabesces": "contabescer",
    "contabescesse": "contabescer",
    "contabescessem": "contabescer",
    "contabescesses": "contabescer",
    "contabesceste": "contabescer",
    "contabescestes": "contabescer",
    "contabesceu": "contabescer",
    "contabesci": "contabescer",
    "contabescia": "contabescer",
    "contabesciam": "contabescer",
    "contabescias": "contabescer",
    "contabescida": "contabescer",
    "contabescidas": "contabescer",
    "contabescido": "contabescer",
    "contabescidos": "contabescer",
    "contabescê": "contabescer",
    "contabescêramo": "contabescer",
    "contabescêramos": "contabescer",
    "contabescêrei": "contabescer",
    "contabescêreis": "contabescer",
    "contabescêsseis": "contabescer",
    "contabescêssemos": "contabescer",
    "contabescíamo": "contabescer",
    "contabescíamos": "contabescer",
    "contabescíei": "contabescer",
    "contabescíeis": "contabescer",
    "contabesça": "contabescer",
    "contabesçais": "contabescer",
    "contabesçam": "contabescer",
    "contabesçamo": "contabescer",
    "contabesçamos": "contabescer",
    "contabesças": "contabescer",
    "contabesço": "contabescer",
    "contabilidades": "contabilidade",
    "contabilistas": "contabilista",
    "contabiliza": "contabilizar",
    "contabilizada": "contabilizar",
    "contabilizadas": "contabilizar",
    "contabilizado": "contabilizar",
    "contabilizados": "contabilizar",
    "contabilizai": "contabilizar",
    "contabilizais": "contabilizar",
    "contabilizam": "contabilizar",
    "contabilizamo": "contabilizar",
    "contabilizamos": "contabilizar",
    "contabilizando": "contabilizar",
    "contabilizara": "contabilizar",
    "contabilizaram": "contabilizar",
    "contabilizaras": "contabilizar",
    "contabilizarde": "contabilizar",
    "contabilizardes": "contabilizar",
    "contabilizare": "contabilizar",
    "contabilizarei": "contabilizar",
    "contabilizareis": "contabilizar",
    "contabilizarem": "contabilizar",
    "contabilizaremos": "contabilizar",
    "contabilizares": "contabilizar",
    "contabilizaria": "contabilizar",
    "contabilizariam": "contabilizar",
    "contabilizarias": "contabilizar",
    "contabilizarmo": "contabilizar",
    "contabilizarmos": "contabilizar",
    "contabilizará": "contabilizar",
    "contabilizarás": "contabilizar",
    "contabilizarão": "contabilizar",
    "contabilizaríamos": "contabilizar",
    "contabilizaríeis": "contabilizar",
    "contabilizas": "contabilizar",
    "contabilizasse": "contabilizar",
    "contabilizassem": "contabilizar",
    "contabilizasses": "contabilizar",
    "contabilizaste": "contabilizar",
    "contabilizastes": "contabilizar",
    "contabilizava": "contabilizar",
    "contabilizavam": "contabilizar",
    "contabilizavas": "contabilizar",
    "contabilizações": "contabilização",
    "contabilize": "contabilizar",
    "contabilizei": "contabilizar",
    "contabilizeis": "contabilizar",
    "contabilizem": "contabilizar",
    "contabilizemo": "contabilizar",
    "contabilizemos": "contabilizar",
    "contabilizes": "contabilizar",
    "contabilizo": "contabilizar",
    "contabilizou": "contabilizar",
    "contabilizá": "contabilizar",
    "contabilizámo": "contabilizar",
    "contabilizámos": "contabilizar",
    "contabilizáramo": "contabilizar",
    "contabilizáramos": "contabilizar",
    "contabilizárei": "contabilizar",
    "contabilizáreis": "contabilizar",
    "contabilizásseis": "contabilizar",
    "contabilizássemos": "contabilizar",
    "contabilizávamo": "contabilizar",
    "contabilizávamos": "contabilizar",
    "contabilizávei": "contabilizar",
    "contabilizáveis": "contabilizável",
    "contabilística": "contabilístico",
    "contabilísticas": "contabilístico",
    "contabilísticos": "contabilístico",
    "contacta": "contactar",
    "contactada": "contactar",
    "contactadas": "contactar",
    "contactado": "contactar",
    "contactados": "contactar",
    "contactai": "contactar",
    "contactais": "contactar",
    "contactam": "contactar",
    "contactamo": "contactar",
    "contactamos": "contactar",
    "contactando": "contactar",
    "contactara": "contactar",
    "contactaram": "contactar",
    "contactaras": "contactar",
    "contactarde": "contactar",
    "contactardes": "contactar",
    "contactare": "contactar",
    "contactarei": "contactar",
    "contactareis": "contactar",
    "contactarem": "contactar",
    "contactaremos": "contactar",
    "contactares": "contactar",
    "contactaria": "contactar",
    "contactariam": "contactar",
    "contactarias": "contactar",
    "contactarmo": "contactar",
    "contactarmos": "contactar",
    "contactará": "contactar",
    "contactarás": "contactar",
    "contactarão": "contactar",
    "contactaríamos": "contactar",
    "contactaríeis": "contactar",
    "contactas": "contactar",
    "contactasse": "contactar",
    "contactassem": "contactar",
    "contactasses": "contactar",
    "contactaste": "contactar",
    "contactastes": "contactar",
    "contactava": "contactar",
    "contactavam": "contactar",
    "contactavas": "contactar",
    "contacte": "contactar",
    "contactei": "contactar",
    "contacteis": "contactar",
    "contactem": "contactar",
    "contactemo": "contactar",
    "contactemos": "contactar",
    "contactes": "contactar",
    "contacto": "contactar",
    "contactos": "contacto",
    "contactou": "contactar",
    "contactuais": "contactual",
    "contactá": "contactar",
    "contactámo": "contactar",
    "contactámos": "contactar",
    "contactáramo": "contactar",
    "contactáramos": "contactar",
    "contactárei": "contactar",
    "contactáreis": "contactar",
    "contactásseis": "contactar",
    "contactássemos": "contactar",
    "contactávamo": "contactar",
    "contactávamos": "contactar",
    "contactávei": "contactar",
    "contactáveis": "contactável",
    "contada": "contar",
    "contadas": "contar",
    "contado": "contar",
    "contadora": "contador",
    "contadoras": "contador",
    "contadores": "contador",
    "contadorias": "contadoria",
    "contados": "contar",
    "contagens": "contagem",
    "contagia": "contagiar",
    "contagiada": "contagiar",
    "contagiadas": "contagiar",
    "contagiado": "contagiar",
    "contagiados": "contagiar",
    "contagiai": "contagiar",
    "contagiais": "contagiar",
    "contagiam": "contagiar",
    "contagiamo": "contagiar",
    "contagiamos": "contagiar",
    "contagiando": "contagiar",
    "contagiantes": "contagiante",
    "contagiara": "contagiar",
    "contagiaram": "contagiar",
    "contagiaras": "contagiar",
    "contagiarde": "contagiar",
    "contagiardes": "contagiar",
    "contagiare": "contagiar",
    "contagiarei": "contagiar",
    "contagiareis": "contagiar",
    "contagiarem": "contagiar",
    "contagiaremos": "contagiar",
    "contagiares": "contagiar",
    "contagiaria": "contagiar",
    "contagiariam": "contagiar",
    "contagiarias": "contagiar",
    "contagiarmo": "contagiar",
    "contagiarmos": "contagiar",
    "contagiará": "contagiar",
    "contagiarás": "contagiar",
    "contagiarão": "contagiar",
    "contagiaríamos": "contagiar",
    "contagiaríeis": "contagiar",
    "contagias": "contagiar",
    "contagiasse": "contagiar",
    "contagiassem": "contagiar",
    "contagiasses": "contagiar",
    "contagiaste": "contagiar",
    "contagiastes": "contagiar",
    "contagiava": "contagiar",
    "contagiavam": "contagiar",
    "contagiavas": "contagiar",
    "contagie": "contagiar",
    "contagiei": "contagiar",
    "contagieis": "contagiar",
    "contagiem": "contagiar",
    "contagiemo": "contagiar",
    "contagiemos": "contagiar",
    "contagies": "contagiar",
    "contagio": "contagiar",
    "contagionais": "contagional",
    "contagiosa": "contagioso",
    "contagiosas": "contagioso",
    "contagiosidades": "contagiosidade",
    "contagiosos": "contagioso",
    "contagiou": "contagiar",
    "contagiá": "contagiar",
    "contagiámo": "contagiar",
    "contagiámos": "contagiar",
    "contagiáramo": "contagiar",
    "contagiáramos": "contagiar",
    "contagiárei": "contagiar",
    "contagiáreis": "contagiar",
    "contagiásseis": "contagiar",
    "contagiássemos": "contagiar",
    "contagiávamo": "contagiar",
    "contagiávamos": "contagiar",
    "contagiávei": "contagiar",
    "contagiáveis": "contagiável",
    "contagiões": "contagião",
    "contai": "contar",
    "contais": "contar",
    "contam": "contar",
    "contamina": "contaminar",
    "contaminabilidades": "contaminabilidade",
    "contaminada": "contaminar",
    "contaminadas": "contaminar",
    "contaminado": "contaminar",
    "contaminadora": "contaminador",
    "contaminadoras": "contaminador",
    "contaminadores": "contaminador",
    "contaminados": "contaminar",
    "contaminai": "contaminar",
    "contaminais": "contaminar",
    "contaminam": "contaminar",
    "contaminamo": "contaminar",
    "contaminamos": "contaminar",
    "contaminando": "contaminar",
    "contaminantes": "contaminante",
    "contaminara": "contaminar",
    "contaminaram": "contaminar",
    "contaminaras": "contaminar",
    "contaminarde": "contaminar",
    "contaminardes": "contaminar",
    "contaminare": "contaminar",
    "contaminarei": "contaminar",
    "contaminareis": "contaminar",
    "contaminarem": "contaminar",
    "contaminaremos": "contaminar",
    "contaminares": "contaminar",
    "contaminaria": "contaminar",
    "contaminariam": "contaminar",
    "contaminarias": "contaminar",
    "contaminarmo": "contaminar",
    "contaminarmos": "contaminar",
    "contaminará": "contaminar",
    "contaminarás": "contaminar",
    "contaminarão": "contaminar",
    "contaminaríamos": "contaminar",
    "contaminaríeis": "contaminar",
    "contaminas": "contaminar",
    "contaminasse": "contaminar",
    "contaminassem": "contaminar",
    "contaminasses": "contaminar",
    "contaminaste": "contaminar",
    "contaminastes": "contaminar",
    "contaminava": "contaminar",
    "contaminavam": "contaminar",
    "contaminavas": "contaminar",
    "contaminações": "contaminação",
    "contamine": "contaminar",
    "contaminei": "contaminar",
    "contamineis": "contaminar",
    "contaminem": "contaminar",
    "contaminemo": "contaminar",
    "contaminemos": "contaminar",
    "contamines": "contaminar",
    "contamino": "contaminar",
    "contaminou": "contaminar",
    "contaminá": "contaminar",
    "contaminámo": "contaminar",
    "contaminámos": "contaminar",
    "contamináramo": "contaminar",
    "contamináramos": "contaminar",
    "contaminárei": "contaminar",
    "contamináreis": "contaminar",
    "contaminásseis": "contaminar",
    "contaminássemos": "contaminar",
    "contaminávamo": "contaminar",
    "contaminávamos": "contaminar",
    "contaminávei": "contaminar",
    "contamináveis": "contaminável",
    "contamo": "contar",
    "contamos": "contar",
    "contando": "contar",
    "contara": "contar",
    "contaram": "contar",
    "contaras": "contar",
    "contarde": "contar",
    "contardes": "contar",
    "contare": "contar",
    "contarei": "contar",
    "contareis": "contar",
    "contarelos": "contarelo",
    "contarem": "contar",
    "contaremos": "contar",
    "contares": "contar",
    "contaria": "contar",
    "contariam": "contar",
    "contarias": "contaria",
    "contarmo": "contar",
    "contarmos": "contar",
    "contará": "contar",
    "contarás": "contar",
    "contarão": "contar",
    "contaríamos": "contar",
    "contaríeis": "contar",
    "contas": "contar",
    "contasse": "contar",
    "contassem": "contar",
    "contasses": "contar",
    "contaste": "contar",
    "contastes": "contar",
    "contava": "contar",
    "contavam": "contar",
    "contavas": "contar",
    "conte": "contar",
    "contecos": "conteco",
    "contei": "contar",
    "conteira": "conteiro",
    "conteiras": "conteiro",
    "conteiros": "conteiro",
    "conteis": "contar",
    "contem": "contar",
    "contemo": "conter",
    "contemos": "conter",
    "contempla": "contemplar",
    "contemplada": "contemplar",
    "contempladas": "contemplar",
    "contemplado": "contemplar",
    "contempladora": "contemplador",
    "contempladoras": "contemplador",
    "contempladores": "contemplador",
    "contemplados": "contemplar",
    "contemplai": "contemplar",
    "contemplais": "contemplar",
    "contemplam": "contemplar",
    "contemplamo": "contemplar",
    "contemplamos": "contemplar",
    "contemplando": "contemplar",
    "contemplantes": "contemplante",
    "contemplara": "contemplar",
    "contemplaram": "contemplar",
    "contemplaras": "contemplar",
    "contemplarde": "contemplar",
    "contemplardes": "contemplar",
    "contemplare": "contemplar",
    "contemplarei": "contemplar",
    "contemplareis": "contemplar",
    "contemplarem": "contemplar",
    "contemplaremos": "contemplar",
    "contemplares": "contemplar",
    "contemplaria": "contemplar",
    "contemplariam": "contemplar",
    "contemplarias": "contemplar",
    "contemplarmo": "contemplar",
    "contemplarmos": "contemplar",
    "contemplará": "contemplar",
    "contemplarás": "contemplar",
    "contemplarão": "contemplar",
    "contemplaríamos": "contemplar",
    "contemplaríeis": "contemplar",
    "contemplas": "contemplar",
    "contemplasse": "contemplar",
    "contemplassem": "contemplar",
    "contemplasses": "contemplar",
    "contemplaste": "contemplar",
    "contemplastes": "contemplar",
    "contemplativa": "contemplativo",
    "contemplativas": "contemplativo",
    "contemplatividades": "contemplatividade",
    "contemplativos": "contemplativo",
    "contemplava": "contemplar",
    "contemplavam": "contemplar",
    "contemplavas": "contemplar",
    "contemplações": "contemplação",
    "contemple": "contemplar",
    "contemplei": "contemplar",
    "contempleis": "contemplar",
    "contemplem": "contemplar",
    "contemplemo": "contemplar",
    "contemplemos": "contemplar",
    "contemples": "contemplar",
    "contemplo": "contemplar",
    "contemplou": "contemplar",
    "contemplá": "contemplar",
    "contemplámo": "contemplar",
    "contemplámos": "contemplar",
    "contempláramo": "contemplar",
    "contempláramos": "contemplar",
    "contemplárei": "contemplar",
    "contempláreis": "contemplar",
    "contemplásseis": "contemplar",
    "contemplássemos": "contemplar",
    "contemplávamo": "contemplar",
    "contemplávamos": "contemplar",
    "contemplávei": "contemplar",
    "contempláveis": "contemplável",
    "contemporaneidades": "contemporaneidade",
    "contemporiza": "contemporizar",
    "contemporizada": "contemporizar",
    "contemporizadas": "contemporizar",
    "contemporizado": "contemporizar",
    "contemporizadora": "contemporizador",
    "contemporizadoras": "contemporizador",
    "contemporizadores": "contemporizador",
    "contemporizados": "contemporizar",
    "contemporizai": "contemporizar",
    "contemporizais": "contemporizar",
    "contemporizam": "contemporizar",
    "contemporizamo": "contemporizar",
    "contemporizamos": "contemporizar",
    "contemporizando": "contemporizar",
    "contemporizantes": "contemporizante",
    "contemporizara": "contemporizar",
    "contemporizaram": "contemporizar",
    "contemporizaras": "contemporizar",
    "contemporizarde": "contemporizar",
    "contemporizardes": "contemporizar",
    "contemporizare": "contemporizar",
    "contemporizarei": "contemporizar",
    "contemporizareis": "contemporizar",
    "contemporizarem": "contemporizar",
    "contemporizaremos": "contemporizar",
    "contemporizares": "contemporizar",
    "contemporizaria": "contemporizar",
    "contemporizariam": "contemporizar",
    "contemporizarias": "contemporizar",
    "contemporizarmo": "contemporizar",
    "contemporizarmos": "contemporizar",
    "contemporizará": "contemporizar",
    "contemporizarás": "contemporizar",
    "contemporizarão": "contemporizar",
    "contemporizaríamos": "contemporizar",
    "contemporizaríeis": "contemporizar",
    "contemporizas": "contemporizar",
    "contemporizasse": "contemporizar",
    "contemporizassem": "contemporizar",
    "contemporizasses": "contemporizar",
    "contemporizaste": "contemporizar",
    "contemporizastes": "contemporizar",
    "contemporizava": "contemporizar",
    "contemporizavam": "contemporizar",
    "contemporizavas": "contemporizar",
    "contemporizações": "contemporização",
    "contemporize": "contemporizar",
    "contemporizei": "contemporizar",
    "contemporizeis": "contemporizar",
    "contemporizem": "contemporizar",
    "contemporizemo": "contemporizar",
    "contemporizemos": "contemporizar",
    "contemporizes": "contemporizar",
    "contemporizo": "contemporizar",
    "contemporizou": "contemporizar",
    "contemporizá": "contemporizar",
    "contemporizámo": "contemporizar",
    "contemporizámos": "contemporizar",
    "contemporizáramo": "contemporizar",
    "contemporizáramos": "contemporizar",
    "contemporizárei": "contemporizar",
    "contemporizáreis": "contemporizar",
    "contemporizásseis": "contemporizar",
    "contemporizássemos": "contemporizar",
    "contemporizávamo": "contemporizar",
    "contemporizávamos": "contemporizar",
    "contemporizávei": "contemporizar",
    "contemporizáveis": "contemporizar",
    "contemporânea": "contemporâneo",
    "contemporâneas": "contemporâneo",
    "contemporâneos": "contemporâneo",
    "contemptora": "contemptor",
    "contemptoras": "contemptor",
    "contemptores": "contemptor",
    "contemptos": "contempto",
    "contemptíveis": "contemptível",
    "contenciosa": "contencioso",
    "contenciosas": "contencioso",
    "contenciosos": "contencioso",
    "contenda": "contender",
    "contendais": "contender",
    "contendam": "contender",
    "contendamo": "contender",
    "contendamos": "contender",
    "contendas": "contender",
    "contende": "conter",
    "contendedora": "contendedor",
    "contendedoras": "contendedor",
    "contendedores": "contendedor",
    "contendei": "contender",
    "contendeis": "contender",
    "contendem": "contender",
    "contendemo": "contender",
    "contendemos": "contender",
    "contendendo": "contender",
    "contendentes": "contendente",
    "contendera": "contender",
    "contenderam": "contender",
    "contenderas": "contender",
    "contenderde": "contender",
    "contenderdes": "contender",
    "contendere": "contender",
    "contenderei": "contender",
    "contendereis": "contender",
    "contenderem": "contender",
    "contenderemos": "contender",
    "contenderes": "contender",
    "contenderia": "contender",
    "contenderiam": "contender",
    "contenderias": "contender",
    "contendermo": "contender",
    "contendermos": "contender",
    "contenderá": "contender",
    "contenderás": "contender",
    "contenderão": "contender",
    "contenderíamos": "contender",
    "contenderíeis": "contender",
    "contendes": "conter",
    "contendesse": "contender",
    "contendessem": "contender",
    "contendesses": "contender",
    "contendeste": "contender",
    "contendestes": "contender",
    "contendeu": "contender",
    "contendi": "contender",
    "contendia": "contender",
    "contendiam": "contender",
    "contendias": "contender",
    "contendida": "contender",
    "contendidas": "contender",
    "contendido": "contender",
    "contendidos": "contender",
    "contendo": "conter",
    "contendora": "contendor",
    "contendoras": "contendor",
    "contendores": "contendor",
    "contendê": "contender",
    "contendêramo": "contender",
    "contendêramos": "contender",
    "contendêrei": "contender",
    "contendêreis": "contender",
    "contendêsseis": "contender",
    "contendêssemos": "contender",
    "contendíamo": "contender",
    "contendíamos": "contender",
    "contendíei": "contender",
    "contendíeis": "contender",
    "contendíveis": "contendível",
    "contenha": "conter",
    "contenhais": "conter",
    "contenham": "conter",
    "contenhamo": "conter",
    "contenhamos": "conter",
    "contenhas": "conter",
    "contenho": "conter",
    "contenhos": "contenho",
    "contensões": "contensão",
    "contenta": "contentar",
    "contentada": "contentar",
    "contentadas": "contentar",
    "contentado": "contentar",
    "contentados": "contentar",
    "contentai": "contentar",
    "contentais": "contentar",
    "contentam": "contentar",
    "contentamentos": "contentamento",
    "contentamo": "contentar",
    "contentamos": "contentar",
    "contentando": "contentar",
    "contentara": "contentar",
    "contentaram": "contentar",
    "contentaras": "contentar",
    "contentarde": "contentar",
    "contentardes": "contentar",
    "contentare": "contentar",
    "contentarei": "contentar",
    "contentareis": "contentar",
    "contentarem": "contentar",
    "contentaremos": "contentar",
    "contentares": "contentar",
    "contentaria": "contentar",
    "contentariam": "contentar",
    "contentarias": "contentar",
    "contentarmo": "contentar",
    "contentarmos": "contentar",
    "contentará": "contentar",
    "contentarás": "contentar",
    "contentarão": "contentar",
    "contentaríamos": "contentar",
    "contentaríeis": "contentar",
    "contentas": "contentar",
    "contentasse": "contentar",
    "contentassem": "contentar",
    "contentasses": "contentar",
    "contentaste": "contentar",
    "contentastes": "contentar",
    "contentava": "contentar",
    "contentavam": "contentar",
    "contentavas": "contentar",
    "contente": "contentar",
    "contentei": "contentar",
    "contenteis": "contentar",
    "contentem": "contentar",
    "contentemo": "contentar",
    "contentemos": "contentar",
    "contentes": "contente",
    "contentinha": "contente",
    "contentinhas": "contente",
    "contentinho": "contente",
    "contentinhos": "contente",
    "contentita": "contente",
    "contentitas": "contente",
    "contentito": "contente",
    "contentitos": "contente",
    "contentiva": "contentivo",
    "contentivas": "contentivo",
    "contentivos": "contentivo",
    "contento": "contentar",
    "contentores": "contentor",
    "contentos": "contento",
    "contentou": "contentar",
    "contentá": "contentar",
    "contentámo": "contentar",
    "contentámos": "contentar",
    "contentáramo": "contentar",
    "contentáramos": "contentar",
    "contentárei": "contentar",
    "contentáreis": "contentar",
    "contentásseis": "contentar",
    "contentássemos": "contentar",
    "contentávamo": "contentar",
    "contentávamos": "contentar",
    "contentávei": "contentar",
    "contentáveis": "contentável",
    "contentíssima": "contente",
    "contentíssimas": "contente",
    "contentíssimo": "contente",
    "contentíssimos": "contente",
    "contenças": "contença",
    "contenções": "contenção",
    "conterde": "conter",
    "conterdes": "conter",
    "contere": "conter",
    "conterei": "conter",
    "contereis": "conter",
    "conterem": "conter",
    "conteremos": "conter",
    "conteres": "conter",
    "conteria": "conter",
    "conteriam": "conter",
    "conterias": "conter",
    "contermo": "conter",
    "contermos": "conter",
    "conterrânea": "conterrâneo",
    "conterrâneas": "conterrâneo",
    "conterrâneos": "conterrâneo",
    "conterá": "conter",
    "conterás": "conter",
    "conterão": "conter",
    "conteríamos": "conter",
    "conteríeis": "conter",
    "contes": "contar",
    "contesta": "contestar",
    "contestabilidades": "contestabilidade",
    "contestada": "contestar",
    "contestadas": "contestar",
    "contestado": "contestar",
    "contestadora": "contestador",
    "contestadoras": "contestador",
    "contestadores": "contestador",
    "contestados": "contestar",
    "contestadíssima": "contestado",
    "contestadíssimas": "contestado",
    "contestadíssimo": "contestado",
    "contestadíssimos": "contestado",
    "contestai": "contestar",
    "contestais": "contestar",
    "contestam": "contestar",
    "contestamo": "contestar",
    "contestamos": "contestar",
    "contestando": "contestar",
    "contestantes": "contestante",
    "contestara": "contestar",
    "contestaram": "contestar",
    "contestaras": "contestar",
    "contestarde": "contestar",
    "contestardes": "contestar",
    "contestare": "contestar",
    "contestarei": "contestar",
    "contestareis": "contestar",
    "contestarem": "contestar",
    "contestaremos": "contestar",
    "contestares": "contestar",
    "contestaria": "contestar",
    "contestariam": "contestar",
    "contestarias": "contestar",
    "contestarmo": "contestar",
    "contestarmos": "contestar",
    "contestará": "contestar",
    "contestarás": "contestar",
    "contestarão": "contestar",
    "contestaríamos": "contestar",
    "contestaríeis": "contestar",
    "contestas": "contestar",
    "contestasse": "contestar",
    "contestassem": "contestar",
    "contestasses": "contestar",
    "contestaste": "contestar",
    "contestastes": "contestar",
    "contestatária": "contestatário",
    "contestatárias": "contestatário",
    "contestatários": "contestatário",
    "contestava": "contestar",
    "contestavam": "contestar",
    "contestavas": "contestar",
    "contestações": "contestação",
    "conteste": "contestar",
    "contestei": "contestar",
    "contesteis": "contestar",
    "contestem": "contestar",
    "contestemo": "contestar",
    "contestemos": "contestar",
    "contestes": "conteste",
    "contesto": "contestar",
    "contestou": "contestar",
    "contestá": "contestar",
    "contestámo": "contestar",
    "contestámos": "contestar",
    "contestáramo": "contestar",
    "contestáramos": "contestar",
    "contestárei": "contestar",
    "contestáreis": "contestar",
    "contestária": "contestário",
    "contestárias": "contestário",
    "contestários": "contestário",
    "contestásseis": "contestar",
    "contestássemos": "contestar",
    "contestávamo": "contestar",
    "contestávamos": "contestar",
    "contestávei": "contestar",
    "contestáveis": "contestável",
    "conteve": "conter",
    "contextos": "contexto",
    "contextuais": "contextual",
    "contextualiza": "contextualizar",
    "contextualizada": "contextualizar",
    "contextualizadas": "contextualizar",
    "contextualizado": "contextualizar",
    "contextualizados": "contextualizar",
    "contextualizai": "contextualizar",
    "contextualizais": "contextualizar",
    "contextualizam": "contextualizar",
    "contextualizamo": "contextualizar",
    "contextualizamos": "contextualizar",
    "contextualizando": "contextualizar",
    "contextualizara": "contextualizar",
    "contextualizaram": "contextualizar",
    "contextualizaras": "contextualizar",
    "contextualizarde": "contextualizar",
    "contextualizardes": "contextualizar",
    "contextualizare": "contextualizar",
    "contextualizarei": "contextualizar",
    "contextualizareis": "contextualizar",
    "contextualizarem": "contextualizar",
    "contextualizaremos": "contextualizar",
    "contextualizares": "contextualizar",
    "contextualizaria": "contextualizar",
    "contextualizariam": "contextualizar",
    "contextualizarias": "contextualizar",
    "contextualizarmo": "contextualizar",
    "contextualizarmos": "contextualizar",
    "contextualizará": "contextualizar",
    "contextualizarás": "contextualizar",
    "contextualizarão": "contextualizar",
    "contextualizaríamos": "contextualizar",
    "contextualizaríeis": "contextualizar",
    "contextualizas": "contextualizar",
    "contextualizasse": "contextualizar",
    "contextualizassem": "contextualizar",
    "contextualizasses": "contextualizar",
    "contextualizaste": "contextualizar",
    "contextualizastes": "contextualizar",
    "contextualizava": "contextualizar",
    "contextualizavam": "contextualizar",
    "contextualizavas": "contextualizar",
    "contextualizações": "contextualização",
    "contextualize": "contextualizar",
    "contextualizei": "contextualizar",
    "contextualizeis": "contextualizar",
    "contextualizem": "contextualizar",
    "contextualizemo": "contextualizar",
    "contextualizemos": "contextualizar",
    "contextualizes": "contextualizar",
    "contextualizo": "contextualizar",
    "contextualizou": "contextualizar",
    "contextualizá": "contextualizar",
    "contextualizámo": "contextualizar",
    "contextualizámos": "contextualizar",
    "contextualizáramo": "contextualizar",
    "contextualizáramos": "contextualizar",
    "contextualizárei": "contextualizar",
    "contextualizáreis": "contextualizar",
    "contextualizásseis": "contextualizar",
    "contextualizássemos": "contextualizar",
    "contextualizávamo": "contextualizar",
    "contextualizávamos": "contextualizar",
    "contextualizávei": "contextualizar",
    "contextualizáveis": "contextualizar",
    "contexturas": "contextura",
    "conteúda": "conteúdo",
    "conteúdas": "conteúdo",
    "conteúdos": "conteúdo",
    "contida": "contido",
    "contidas": "contido",
    "contido": "conter",
    "contidos": "contido",
    "contigo": "comigo",
    "contigua": "contiguar",
    "contiguada": "contiguar",
    "contiguadas": "contiguar",
    "contiguado": "contiguar",
    "contiguados": "contiguar",
    "contiguai": "contiguar",
    "contiguais": "contiguar",
    "contiguam": "contiguar",
    "contiguamo": "contiguar",
    "contiguamos": "contiguar",
    "contiguando": "contiguar",
    "contiguara": "contiguar",
    "contiguaram": "contiguar",
    "contiguaras": "contiguar",
    "contiguarde": "contiguar",
    "contiguardes": "contiguar",
    "contiguare": "contiguar",
    "contiguarei": "contiguar",
    "contiguareis": "contiguar",
    "contiguarem": "contiguar",
    "contiguaremos": "contiguar",
    "contiguares": "contiguar",
    "contiguaria": "contiguar",
    "contiguariam": "contiguar",
    "contiguarias": "contiguar",
    "contiguarmo": "contiguar",
    "contiguarmos": "contiguar",
    "contiguará": "contiguar",
    "contiguarás": "contiguar",
    "contiguarão": "contiguar",
    "contiguaríamos": "contiguar",
    "contiguaríeis": "contiguar",
    "contiguas": "contiguar",
    "contiguasse": "contiguar",
    "contiguassem": "contiguar",
    "contiguasses": "contiguar",
    "contiguaste": "contiguar",
    "contiguastes": "contiguar",
    "contiguava": "contiguar",
    "contiguavam": "contiguar",
    "contiguavas": "contiguar",
    "contiguei": "contiguar",
    "contigueis": "contiguar",
    "contiguemo": "contiguar",
    "contiguemos": "contiguar",
    "contigues": "contiguar",
    "contiguidades": "contiguidade",
    "contiguo": "contiguar",
    "contiguou": "contiguar",
    "contiguá": "contiguar",
    "contiguámo": "contiguar",
    "contiguámos": "contiguar",
    "contiguáramo": "contiguar",
    "contiguáramos": "contiguar",
    "contiguárei": "contiguar",
    "contiguáreis": "contiguar",
    "contiguásseis": "contiguar",
    "contiguássemos": "contiguar",
    "contiguávamo": "contiguar",
    "contiguávamos": "contiguar",
    "contiguávei": "contiguar",
    "contiguáveis": "contiguar",
    "contigúe": "contiguar",
    "contigúem": "contiguar",
    "contigúes": "contiguar",
    "contilheiras": "contilheira",
    "continentais": "continental",
    "continentalidades": "continentalidade",
    "continentes": "continente",
    "contingenciais": "contingencial",
    "contingenciamentos": "contingenciamento",
    "contingentes": "contingente",
    "contingentismos": "contingentismo",
    "contingências": "contingência",
    "continha": "conter",
    "continham": "conter",
    "continhas": "conter",
    "continho": "conto",
    "continhos": "conto",
    "continua": "continuar",
    "continuada": "continuar",
    "continuadas": "continuar",
    "continuado": "continuar",
    "continuadora": "continuador",
    "continuadoras": "continuador",
    "continuadores": "continuador",
    "continuados": "continuar",
    "continuai": "continuar",
    "continuais": "continuar",
    "continuam": "continuar",
    "continuamo": "continuar",
    "continuamos": "continuar",
    "continuando": "continuar",
    "continuara": "continuar",
    "continuaram": "continuar",
    "continuaras": "continuar",
    "continuarde": "continuar",
    "continuardes": "continuar",
    "continuare": "continuar",
    "continuarei": "continuar",
    "continuareis": "continuar",
    "continuarem": "continuar",
    "continuaremos": "continuar",
    "continuares": "continuar",
    "continuaria": "continuar",
    "continuariam": "continuar",
    "continuarias": "continuar",
    "continuarmo": "continuar",
    "continuarmos": "continuar",
    "continuará": "continuar",
    "continuarás": "continuar",
    "continuarão": "continuar",
    "continuaríamos": "continuar",
    "continuaríeis": "continuar",
    "continuas": "continuar",
    "continuasse": "continuar",
    "continuassem": "continuar",
    "continuasses": "continuar",
    "continuaste": "continuar",
    "continuastes": "continuar",
    "continuativa": "continuativo",
    "continuativas": "continuativo",
    "continuativos": "continuativo",
    "continuava": "continuar",
    "continuavam": "continuar",
    "continuavas": "continuar",
    "continuações": "continuação",
    "continue": "continuar",
    "continuei": "continuar",
    "continueis": "continuar",
    "continuem": "continuar",
    "continuemo": "continuar",
    "continuemos": "continuar",
    "continues": "continuar",
    "continuidades": "continuidade",
    "continuo": "continuar",
    "continuou": "continuar",
    "continuá": "continuar",
    "continuámo": "continuar",
    "continuámos": "continuar",
    "continuáramo": "continuar",
    "continuáramos": "continuar",
    "continuárei": "continuar",
    "continuáreis": "continuar",
    "continuásseis": "continuar",
    "continuássemos": "continuar",
    "continuávamo": "continuar",
    "continuávamos": "continuar",
    "continuávei": "continuar",
    "continuáveis": "continuar",
    "continências": "continência",
    "contistas": "contista",
    "contita": "conta",
    "contitas": "conta",
    "contito": "conto",
    "contitos": "conto",
    "contive": "conter",
    "contivemo": "conter",
    "contivemos": "conter",
    "contiver": "conter",
    "contivera": "conter",
    "contiveram": "conter",
    "contiveras": "conter",
    "contiverdes": "conter",
    "contiverem": "conter",
    "contiveres": "conter",
    "contivermos": "conter",
    "contivesse": "conter",
    "contivessem": "conter",
    "contivesses": "conter",
    "contiveste": "conter",
    "contivestes": "conter",
    "contivéramo": "conter",
    "contivéramos": "conter",
    "contivérei": "conter",
    "contivéreis": "conter",
    "contivésseis": "conter",
    "contivéssemos": "conter",
    "conto": "contar",
    "contoadas": "contoada",
    "contorce": "contorcer",
    "contorcei": "contorcer",
    "contorceis": "contorcer",
    "contorcem": "contorcer",
    "contorcemo": "contorcer",
    "contorcemos": "contorcer",
    "contorcendo": "contorcer",
    "contorcera": "contorcer",
    "contorceram": "contorcer",
    "contorceras": "contorcer",
    "contorcerde": "contorcer",
    "contorcerdes": "contorcer",
    "contorcere": "contorcer",
    "contorcerei": "contorcer",
    "contorcereis": "contorcer",
    "contorcerem": "contorcer",
    "contorceremos": "contorcer",
    "contorceres": "contorcer",
    "contorceria": "contorcer",
    "contorceriam": "contorcer",
    "contorcerias": "contorcer",
    "contorcermo": "contorcer",
    "contorcermos": "contorcer",
    "contorcerá": "contorcer",
    "contorcerás": "contorcer",
    "contorcerão": "contorcer",
    "contorceríamos": "contorcer",
    "contorceríeis": "contorcer",
    "contorces": "contorcer",
    "contorcesse": "contorcer",
    "contorcessem": "contorcer",
    "contorcesses": "contorcer",
    "contorceste": "contorcer",
    "contorcestes": "contorcer",
    "contorceu": "contorcer",
    "contorci": "contorcer",
    "contorcia": "contorcer",
    "contorciam": "contorcer",
    "contorcias": "contorcer",
    "contorcida": "contorcido",
    "contorcidas": "contorcido",
    "contorcido": "contorcer",
    "contorcidos": "contorcido",
    "contorcionismos": "contorcionismo",
    "contorcionistas": "contorcionista",
    "contorcê": "contorcer",
    "contorcêramo": "contorcer",
    "contorcêramos": "contorcer",
    "contorcêrei": "contorcer",
    "contorcêreis": "contorcer",
    "contorcêsseis": "contorcer",
    "contorcêssemos": "contorcer",
    "contorcíamo": "contorcer",
    "contorcíamos": "contorcer",
    "contorcíei": "contorcer",
    "contorcíeis": "contorcer",
    "contorna": "contornar",
    "contornada": "contornar",
    "contornadas": "contornar",
    "contornado": "contornar",
    "contornados": "contornar",
    "contornai": "contornar",
    "contornais": "contornar",
    "contornam": "contornar",
    "contornamo": "contornar",
    "contornamos": "contornar",
    "contornando": "contornar",
    "contornara": "contornar",
    "contornaram": "contornar",
    "contornaras": "contornar",
    "contornarde": "contornar",
    "contornardes": "contornar",
    "contornare": "contornar",
    "contornarei": "contornar",
    "contornareis": "contornar",
    "contornarem": "contornar",
    "contornaremos": "contornar",
    "contornares": "contornar",
    "contornaria": "contornar",
    "contornariam": "contornar",
    "contornarias": "contornar",
    "contornarmo": "contornar",
    "contornarmos": "contornar",
    "contornará": "contornar",
    "contornarás": "contornar",
    "contornarão": "contornar",
    "contornaríamos": "contornar",
    "contornaríeis": "contornar",
    "contornas": "contornar",
    "contornasse": "contornar",
    "contornassem": "contornar",
    "contornasses": "contornar",
    "contornaste": "contornar",
    "contornastes": "contornar",
    "contornava": "contornar",
    "contornavam": "contornar",
    "contornavas": "contornar",
    "contorne": "contornar",
    "contornei": "contornar",
    "contorneis": "contornar",
    "contornem": "contornar",
    "contornemo": "contornar",
    "contornemos": "contornar",
    "contornes": "contornar",
    "contorno": "contornar",
    "contornos": "contorno",
    "contornou": "contornar",
    "contorná": "contornar",
    "contornámo": "contornar",
    "contornámos": "contornar",
    "contornáramo": "contornar",
    "contornáramos": "contornar",
    "contornárei": "contornar",
    "contornáreis": "contornar",
    "contornásseis": "contornar",
    "contornássemos": "contornar",
    "contornávamo": "contornar",
    "contornávamos": "contornar",
    "contornávei": "contornar",
    "contornáveis": "contornar",
    "contorça": "contorcer",
    "contorçais": "contorcer",
    "contorçam": "contorcer",
    "contorçamo": "contorcer",
    "contorçamos": "contorcer",
    "contorças": "contorcer",
    "contorço": "contorcer",
    "contorções": "contorção",
    "contos": "conto",
    "contou": "contar",
    "contrabaixistas": "contrabaixista",
    "contrabaixos": "contrabaixo",
    "contrabalance": "contrabalançar",
    "contrabalancei": "contrabalançar",
    "contrabalanceis": "contrabalançar",
    "contrabalancem": "contrabalançar",
    "contrabalancemo": "contrabalançar",
    "contrabalancemos": "contrabalançar",
    "contrabalances": "contrabalançar",
    "contrabalança": "contrabalançar",
    "contrabalançada": "contrabalançar",
    "contrabalançadas": "contrabalançar",
    "contrabalançado": "contrabalançar",
    "contrabalançados": "contrabalançar",
    "contrabalançai": "contrabalançar",
    "contrabalançais": "contrabalançar",
    "contrabalançam": "contrabalançar",
    "contrabalançamo": "contrabalançar",
    "contrabalançamos": "contrabalançar",
    "contrabalançando": "contrabalançar",
    "contrabalançara": "contrabalançar",
    "contrabalançaram": "contrabalançar",
    "contrabalançaras": "contrabalançar",
    "contrabalançarde": "contrabalançar",
    "contrabalançardes": "contrabalançar",
    "contrabalançare": "contrabalançar",
    "contrabalançarei": "contrabalançar",
    "contrabalançareis": "contrabalançar",
    "contrabalançarem": "contrabalançar",
    "contrabalançaremos": "contrabalançar",
    "contrabalançares": "contrabalançar",
    "contrabalançaria": "contrabalançar",
    "contrabalançariam": "contrabalançar",
    "contrabalançarias": "contrabalançar",
    "contrabalançarmo": "contrabalançar",
    "contrabalançarmos": "contrabalançar",
    "contrabalançará": "contrabalançar",
    "contrabalançarás": "contrabalançar",
    "contrabalançarão": "contrabalançar",
    "contrabalançaríamos": "contrabalançar",
    "contrabalançaríeis": "contrabalançar",
    "contrabalanças": "contrabalançar",
    "contrabalançasse": "contrabalançar",
    "contrabalançassem": "contrabalançar",
    "contrabalançasses": "contrabalançar",
    "contrabalançaste": "contrabalançar",
    "contrabalançastes": "contrabalançar",
    "contrabalançava": "contrabalançar",
    "contrabalançavam": "contrabalançar",
    "contrabalançavas": "contrabalançar",
    "contrabalanço": "contrabalançar",
    "contrabalançou": "contrabalançar",
    "contrabalançá": "contrabalançar",
    "contrabalançámo": "contrabalançar",
    "contrabalançámos": "contrabalançar",
    "contrabalançáramo": "contrabalançar",
    "contrabalançáramos": "contrabalançar",
    "contrabalançárei": "contrabalançar",
    "contrabalançáreis": "contrabalançar",
    "contrabalançásseis": "contrabalançar",
    "contrabalançássemos": "contrabalançar",
    "contrabalançávamo": "contrabalançar",
    "contrabalançávamos": "contrabalançar",
    "contrabalançávei": "contrabalançar",
    "contrabalançáveis": "contrabalançar",
    "contrabaluartes": "contrabaluarte",
    "contrabandas": "contrabanda",
    "contrabandeada": "contrabandear",
    "contrabandeadas": "contrabandear",
    "contrabandeado": "contrabandear",
    "contrabandeados": "contrabandear",
    "contrabandeai": "contrabandear",
    "contrabandeais": "contrabandear",
    "contrabandeamo": "contrabandear",
    "contrabandeamos": "contrabandear",
    "contrabandeando": "contrabandear",
    "contrabandeara": "contrabandear",
    "contrabandearam": "contrabandear",
    "contrabandearas": "contrabandear",
    "contrabandearde": "contrabandear",
    "contrabandeardes": "contrabandear",
    "contrabandeare": "contrabandear",
    "contrabandearei": "contrabandear",
    "contrabandeareis": "contrabandear",
    "contrabandearem": "contrabandear",
    "contrabandearemos": "contrabandear",
    "contrabandeares": "contrabandear",
    "contrabandearia": "contrabandear",
    "contrabandeariam": "contrabandear",
    "contrabandearias": "contrabandear",
    "contrabandearmo": "contrabandear",
    "contrabandearmos": "contrabandear",
    "contrabandeará": "contrabandear",
    "contrabandearás": "contrabandear",
    "contrabandearão": "contrabandear",
    "contrabandearíamos": "contrabandear",
    "contrabandearíeis": "contrabandear",
    "contrabandeasse": "contrabandear",
    "contrabandeassem": "contrabandear",
    "contrabandeasses": "contrabandear",
    "contrabandeaste": "contrabandear",
    "contrabandeastes": "contrabandear",
    "contrabandeava": "contrabandear",
    "contrabandeavam": "contrabandear",
    "contrabandeavas": "contrabandear",
    "contrabandeei": "contrabandear",
    "contrabandeeis": "contrabandear",
    "contrabandeemo": "contrabandear",
    "contrabandeemos": "contrabandear",
    "contrabandeia": "contrabandear",
    "contrabandeiam": "contrabandear",
    "contrabandeias": "contrabandear",
    "contrabandeie": "contrabandear",
    "contrabandeiem": "contrabandear",
    "contrabandeies": "contrabandear",
    "contrabandeio": "contrabandear",
    "contrabandeou": "contrabandear",
    "contrabandeá": "contrabandear",
    "contrabandeámo": "contrabandear",
    "contrabandeámos": "contrabandear",
    "contrabandeáramo": "contrabandear",
    "contrabandeáramos": "contrabandear",
    "contrabandeárei": "contrabandear",
    "contrabandeáreis": "contrabandear",
    "contrabandeásseis": "contrabandear",
    "contrabandeássemos": "contrabandear",
    "contrabandeávamo": "contrabandear",
    "contrabandeávamos": "contrabandear",
    "contrabandeávei": "contrabandear",
    "contrabandeáveis": "contrabandear",
    "contrabandismos": "contrabandismo",
    "contrabandistas": "contrabandista",
    "contrabandos": "contrabando",
    "contrabata": "contrabater",
    "contrabatais": "contrabater",
    "contrabatam": "contrabater",
    "contrabatamo": "contrabater",
    "contrabatamos": "contrabater",
    "contrabatas": "contrabater",
    "contrabate": "contrabater",
    "contrabatei": "contrabater",
    "contrabateis": "contrabater",
    "contrabatem": "contrabater",
    "contrabatemo": "contrabater",
    "contrabatemos": "contrabater",
    "contrabatendo": "contrabater",
    "contrabatera": "contrabater",
    "contrabateram": "contrabater",
    "contrabateras": "contrabater",
    "contrabaterde": "contrabater",
    "contrabaterdes": "contrabater",
    "contrabatere": "contrabater",
    "contrabaterei": "contrabater",
    "contrabatereis": "contrabater",
    "contrabaterem": "contrabater",
    "contrabateremos": "contrabater",
    "contrabateres": "contrabater",
    "contrabateria": "contrabater",
    "contrabateriam": "contrabater",
    "contrabaterias": "contrabateria",
    "contrabatermo": "contrabater",
    "contrabatermos": "contrabater",
    "contrabaterá": "contrabater",
    "contrabaterás": "contrabater",
    "contrabaterão": "contrabater",
    "contrabateríamos": "contrabater",
    "contrabateríeis": "contrabater",
    "contrabates": "contrabater",
    "contrabatesse": "contrabater",
    "contrabatessem": "contrabater",
    "contrabatesses": "contrabater",
    "contrabateste": "contrabater",
    "contrabatestes": "contrabater",
    "contrabateu": "contrabater",
    "contrabati": "contrabater",
    "contrabatia": "contrabater",
    "contrabatiam": "contrabater",
    "contrabatias": "contrabater",
    "contrabatida": "contrabater",
    "contrabatidas": "contrabater",
    "contrabatido": "contrabater",
    "contrabatidos": "contrabater",
    "contrabato": "contrabater",
    "contrabatê": "contrabater",
    "contrabatêramo": "contrabater",
    "contrabatêramos": "contrabater",
    "contrabatêrei": "contrabater",
    "contrabatêreis": "contrabater",
    "contrabatêsseis": "contrabater",
    "contrabatêssemos": "contrabater",
    "contrabatíamo": "contrabater",
    "contrabatíamos": "contrabater",
    "contrabatíei": "contrabater",
    "contrabatíeis": "contrabater",
    "contrabordos": "contrabordo",
    "contracadastes": "contracadaste",
    "contracaixas": "contracaixa",
    "contracambia": "contracambiar",
    "contracambiada": "contracambiar",
    "contracambiadas": "contracambiar",
    "contracambiado": "contracambiar",
    "contracambiados": "contracambiar",
    "contracambiai": "contracambiar",
    "contracambiais": "contracambiar",
    "contracambiam": "contracambiar",
    "contracambiamo": "contracambiar",
    "contracambiamos": "contracambiar",
    "contracambiando": "contracambiar",
    "contracambiara": "contracambiar",
    "contracambiaram": "contracambiar",
    "contracambiaras": "contracambiar",
    "contracambiarde": "contracambiar",
    "contracambiardes": "contracambiar",
    "contracambiare": "contracambiar",
    "contracambiarei": "contracambiar",
    "contracambiareis": "contracambiar",
    "contracambiarem": "contracambiar",
    "contracambiaremos": "contracambiar",
    "contracambiares": "contracambiar",
    "contracambiaria": "contracambiar",
    "contracambiariam": "contracambiar",
    "contracambiarias": "contracambiar",
    "contracambiarmo": "contracambiar",
    "contracambiarmos": "contracambiar",
    "contracambiará": "contracambiar",
    "contracambiarás": "contracambiar",
    "contracambiarão": "contracambiar",
    "contracambiaríamos": "contracambiar",
    "contracambiaríeis": "contracambiar",
    "contracambias": "contracambiar",
    "contracambiasse": "contracambiar",
    "contracambiassem": "contracambiar",
    "contracambiasses": "contracambiar",
    "contracambiaste": "contracambiar",
    "contracambiastes": "contracambiar",
    "contracambiava": "contracambiar",
    "contracambiavam": "contracambiar",
    "contracambiavas": "contracambiar",
    "contracambie": "contracambiar",
    "contracambiei": "contracambiar",
    "contracambieis": "contracambiar",
    "contracambiem": "contracambiar",
    "contracambiemo": "contracambiar",
    "contracambiemos": "contracambiar",
    "contracambies": "contracambiar",
    "contracambio": "contracambiar",
    "contracambiou": "contracambiar",
    "contracambiá": "contracambiar",
    "contracambiámo": "contracambiar",
    "contracambiámos": "contracambiar",
    "contracambiáramo": "contracambiar",
    "contracambiáramos": "contracambiar",
    "contracambiárei": "contracambiar",
    "contracambiáreis": "contracambiar",
    "contracambiásseis": "contracambiar",
    "contracambiássemos": "contracambiar",
    "contracambiávamo": "contracambiar",
    "contracambiávamos": "contracambiar",
    "contracambiávei": "contracambiar",
    "contracambiáveis": "contracambiar",
    "contracampanhas": "contracampanha",
    "contracampos": "contracampo",
    "contracantos": "contracanto",
    "contracapas": "contracapa",
    "contracarris": "contracarril",
    "contraccionistas": "contraccionista",
    "contracena": "contracenar",
    "contracenada": "contracenar",
    "contracenadas": "contracenar",
    "contracenado": "contracenar",
    "contracenados": "contracenar",
    "contracenai": "contracenar",
    "contracenais": "contracenar",
    "contracenam": "contracenar",
    "contracenamo": "contracenar",
    "contracenamos": "contracenar",
    "contracenando": "contracenar",
    "contracenara": "contracenar",
    "contracenaram": "contracenar",
    "contracenaras": "contracenar",
    "contracenarde": "contracenar",
    "contracenardes": "contracenar",
    "contracenare": "contracenar",
    "contracenarei": "contracenar",
    "contracenareis": "contracenar",
    "contracenarem": "contracenar",
    "contracenaremos": "contracenar",
    "contracenares": "contracenar",
    "contracenaria": "contracenar",
    "contracenariam": "contracenar",
    "contracenarias": "contracenar",
    "contracenarmo": "contracenar",
    "contracenarmos": "contracenar",
    "contracenará": "contracenar",
    "contracenarás": "contracenar",
    "contracenarão": "contracenar",
    "contracenaríamos": "contracenar",
    "contracenaríeis": "contracenar",
    "contracenas": "contracenar",
    "contracenasse": "contracenar",
    "contracenassem": "contracenar",
    "contracenasses": "contracenar",
    "contracenaste": "contracenar",
    "contracenastes": "contracenar",
    "contracenava": "contracenar",
    "contracenavam": "contracenar",
    "contracenavas": "contracenar",
    "contracene": "contracenar",
    "contracenei": "contracenar",
    "contraceneis": "contracenar",
    "contracenem": "contracenar",
    "contracenemo": "contracenar",
    "contracenemos": "contracenar",
    "contracenes": "contracenar",
    "contraceno": "contracenar",
    "contracenou": "contracenar",
    "contracená": "contracenar",
    "contracenámo": "contracenar",
    "contracenámos": "contracenar",
    "contracenáramo": "contracenar",
    "contracenáramos": "contracenar",
    "contracenárei": "contracenar",
    "contracenáreis": "contracenar",
    "contracenásseis": "contracenar",
    "contracenássemos": "contracenar",
    "contracenávamo": "contracenar",
    "contracenávamos": "contracenar",
    "contracenávei": "contracenar",
    "contracenáveis": "contracenar",
    "contraceptiva": "contraceptivo",
    "contraceptivas": "contraceptivo",
    "contraceptivos": "contraceptivo",
    "contracepções": "contracepção",
    "contracifras": "contracifra",
    "contracorrentes": "contracorrente",
    "contracostas": "contracosta",
    "contracrítica": "contracrítico",
    "contracríticas": "contracrítico",
    "contracríticos": "contracrítico",
    "contracta": "contracto",
    "contractada": "contractar",
    "contractadas": "contractar",
    "contractado": "contractar",
    "contractados": "contractar",
    "contractai": "contractar",
    "contractais": "contractar",
    "contractam": "contractar",
    "contractamo": "contractar",
    "contractamos": "contractar",
    "contractando": "contractar",
    "contractara": "contractar",
    "contractaram": "contractar",
    "contractaras": "contractar",
    "contractarde": "contractar",
    "contractardes": "contractar",
    "contractare": "contractar",
    "contractarei": "contractar",
    "contractareis": "contractar",
    "contractarem": "contractar",
    "contractaremos": "contractar",
    "contractares": "contractar",
    "contractaria": "contractar",
    "contractariam": "contractar",
    "contractarias": "contractar",
    "contractarmo": "contractar",
    "contractarmos": "contractar",
    "contractará": "contractar",
    "contractarás": "contractar",
    "contractarão": "contractar",
    "contractaríamos": "contractar",
    "contractaríeis": "contractar",
    "contractas": "contracto",
    "contractasse": "contractar",
    "contractassem": "contractar",
    "contractasses": "contractar",
    "contractaste": "contractar",
    "contractastes": "contractar",
    "contractava": "contractar",
    "contractavam": "contractar",
    "contractavas": "contractar",
    "contracte": "contractar",
    "contractei": "contractar",
    "contracteis": "contractar",
    "contractem": "contractar",
    "contractemo": "contractar",
    "contractemos": "contractar",
    "contractes": "contractar",
    "contractilidades": "contractilidade",
    "contractiva": "contractivo",
    "contractivas": "contractivo",
    "contractivos": "contractivo",
    "contracto": "contractar",
    "contractos": "contracto",
    "contractou": "contractar",
    "contracturantes": "contracturante",
    "contracturas": "contractura",
    "contractá": "contractar",
    "contractámo": "contractar",
    "contractámos": "contractar",
    "contractáramo": "contractar",
    "contractáramos": "contractar",
    "contractárei": "contractar",
    "contractáreis": "contractar",
    "contractásseis": "contractar",
    "contractássemos": "contractar",
    "contractávamo": "contractar",
    "contractávamos": "contractar",
    "contractávei": "contractar",
    "contractáveis": "contractar",
    "contractíveis": "contractível",
    "contraculturas": "contracultura",
    "contracunha": "contracunhar",
    "contracunhada": "contracunhar",
    "contracunhadas": "contracunhar",
    "contracunhado": "contracunhar",
    "contracunhados": "contracunhar",
    "contracunhai": "contracunhar",
    "contracunhais": "contracunhar",
    "contracunham": "contracunhar",
    "contracunhamo": "contracunhar",
    "contracunhamos": "contracunhar",
    "contracunhando": "contracunhar",
    "contracunhara": "contracunhar",
    "contracunharam": "contracunhar",
    "contracunharas": "contracunhar",
    "contracunharde": "contracunhar",
    "contracunhardes": "contracunhar",
    "contracunhare": "contracunhar",
    "contracunharei": "contracunhar",
    "contracunhareis": "contracunhar",
    "contracunharem": "contracunhar",
    "contracunharemos": "contracunhar",
    "contracunhares": "contracunhar",
    "contracunharia": "contracunhar",
    "contracunhariam": "contracunhar",
    "contracunharias": "contracunhar",
    "contracunharmo": "contracunhar",
    "contracunharmos": "contracunhar",
    "contracunhará": "contracunhar",
    "contracunharás": "contracunhar",
    "contracunharão": "contracunhar",
    "contracunharíamos": "contracunhar",
    "contracunharíeis": "contracunhar",
    "contracunhas": "contracunhar",
    "contracunhasse": "contracunhar",
    "contracunhassem": "contracunhar",
    "contracunhasses": "contracunhar",
    "contracunhaste": "contracunhar",
    "contracunhastes": "contracunhar",
    "contracunhava": "contracunhar",
    "contracunhavam": "contracunhar",
    "contracunhavas": "contracunhar",
    "contracunhe": "contracunhar",
    "contracunhei": "contracunhar",
    "contracunheis": "contracunhar",
    "contracunhem": "contracunhar",
    "contracunhemo": "contracunhar",
    "contracunhemos": "contracunhar",
    "contracunhes": "contracunhar",
    "contracunho": "contracunhar",
    "contracunhos": "contracunho",
    "contracunhou": "contracunhar",
    "contracunhá": "contracunhar",
    "contracunhámo": "contracunhar",
    "contracunhámos": "contracunhar",
    "contracunháramo": "contracunhar",
    "contracunháramos": "contracunhar",
    "contracunhárei": "contracunhar",
    "contracunháreis": "contracunhar",
    "contracunhásseis": "contracunhar",
    "contracunhássemos": "contracunhar",
    "contracunhávamo": "contracunhar",
    "contracunhávamos": "contracunhar",
    "contracunhávei": "contracunhar",
    "contracunháveis": "contracunhar",
    "contracurva": "contracurvo",
    "contracurvas": "contracurvo",
    "contracurvos": "contracurvo",
    "contracâmbios": "contracâmbio",
    "contracções": "contracção",
    "contracédulas": "contracédula",
    "contradanças": "contradança",
    "contradeclara": "contradeclarar",
    "contradeclarada": "contradeclarar",
    "contradeclaradas": "contradeclarar",
    "contradeclarado": "contradeclarar",
    "contradeclarados": "contradeclarar",
    "contradeclarai": "contradeclarar",
    "contradeclarais": "contradeclarar",
    "contradeclaram": "contradeclarar",
    "contradeclaramo": "contradeclarar",
    "contradeclaramos": "contradeclarar",
    "contradeclarando": "contradeclarar",
    "contradeclarara": "contradeclarar",
    "contradeclararam": "contradeclarar",
    "contradeclararas": "contradeclarar",
    "contradeclararde": "contradeclarar",
    "contradeclarardes": "contradeclarar",
    "contradeclarare": "contradeclarar",
    "contradeclararei": "contradeclarar",
    "contradeclarareis": "contradeclarar",
    "contradeclararem": "contradeclarar",
    "contradeclararemos": "contradeclarar",
    "contradeclarares": "contradeclarar",
    "contradeclararia": "contradeclarar",
    "contradeclarariam": "contradeclarar",
    "contradeclararias": "contradeclarar",
    "contradeclararmo": "contradeclarar",
    "contradeclararmos": "contradeclarar",
    "contradeclarará": "contradeclarar",
    "contradeclararás": "contradeclarar",
    "contradeclararão": "contradeclarar",
    "contradeclararíamos": "contradeclarar",
    "contradeclararíeis": "contradeclarar",
    "contradeclaras": "contradeclarar",
    "contradeclarasse": "contradeclarar",
    "contradeclarassem": "contradeclarar",
    "contradeclarasses": "contradeclarar",
    "contradeclaraste": "contradeclarar",
    "contradeclarastes": "contradeclarar",
    "contradeclarava": "contradeclarar",
    "contradeclaravam": "contradeclarar",
    "contradeclaravas": "contradeclarar",
    "contradeclarações": "contradeclaração",
    "contradeclare": "contradeclarar",
    "contradeclarei": "contradeclarar",
    "contradeclareis": "contradeclarar",
    "contradeclarem": "contradeclarar",
    "contradeclaremo": "contradeclarar",
    "contradeclaremos": "contradeclarar",
    "contradeclares": "contradeclarar",
    "contradeclaro": "contradeclarar",
    "contradeclarou": "contradeclarar",
    "contradeclará": "contradeclarar",
    "contradeclarámo": "contradeclarar",
    "contradeclarámos": "contradeclarar",
    "contradeclaráramo": "contradeclarar",
    "contradeclaráramos": "contradeclarar",
    "contradeclarárei": "contradeclarar",
    "contradeclaráreis": "contradeclarar",
    "contradeclarásseis": "contradeclarar",
    "contradeclarássemos": "contradeclarar",
    "contradeclarávamo": "contradeclarar",
    "contradeclarávamos": "contradeclarar",
    "contradeclarávei": "contradeclarar",
    "contradeclaráveis": "contradeclarar",
    "contradiga": "contradizer",
    "contradigais": "contradizer",
    "contradigam": "contradizer",
    "contradigamo": "contradizer",
    "contradigamos": "contradizer",
    "contradigas": "contradizer",
    "contradigo": "contradizer",
    "contradiques": "contradique",
    "contradirei": "contradizer",
    "contradireis": "contradizer",
    "contradiremos": "contradizer",
    "contradiria": "contradizer",
    "contradiriam": "contradizer",
    "contradirias": "contradizer",
    "contradirá": "contradizer",
    "contradirás": "contradizer",
    "contradirão": "contradizer",
    "contradiríamos": "contradizer",
    "contradiríeis": "contradizer",
    "contradisse": "contradizer",
    "contradissemo": "contradizer",
    "contradissemos": "contradizer",
    "contradisser": "contradizer",
    "contradissera": "contradizer",
    "contradisseram": "contradizer",
    "contradisseras": "contradizer",
    "contradisserdes": "contradizer",
    "contradisserem": "contradizer",
    "contradisseres": "contradizer",
    "contradissermos": "contradizer",
    "contradissesse": "contradizer",
    "contradissessem": "contradizer",
    "contradissesses": "contradizer",
    "contradisseste": "contradizer",
    "contradissestes": "contradizer",
    "contradisséramo": "contradizer",
    "contradisséramos": "contradizer",
    "contradissérei": "contradizer",
    "contradisséreis": "contradizer",
    "contradissésseis": "contradizer",
    "contradisséssemos": "contradizer",
    "contradita": "contradizer",
    "contraditada": "contraditar",
    "contraditadas": "contraditar",
    "contraditado": "contraditar",
    "contraditados": "contraditar",
    "contraditai": "contraditar",
    "contraditais": "contraditar",
    "contraditam": "contraditar",
    "contraditamo": "contraditar",
    "contraditamos": "contraditar",
    "contraditando": "contraditar",
    "contraditara": "contraditar",
    "contraditaram": "contraditar",
    "contraditaras": "contraditar",
    "contraditarde": "contraditar",
    "contraditardes": "contraditar",
    "contraditare": "contraditar",
    "contraditarei": "contraditar",
    "contraditareis": "contraditar",
    "contraditarem": "contraditar",
    "contraditaremos": "contraditar",
    "contraditares": "contraditar",
    "contraditaria": "contraditar",
    "contraditariam": "contraditar",
    "contraditarias": "contraditar",
    "contraditarmo": "contraditar",
    "contraditarmos": "contraditar",
    "contraditará": "contraditar",
    "contraditarás": "contraditar",
    "contraditarão": "contraditar",
    "contraditaríamos": "contraditar",
    "contraditaríeis": "contraditar",
    "contraditas": "contradizer",
    "contraditasse": "contraditar",
    "contraditassem": "contraditar",
    "contraditasses": "contraditar",
    "contraditaste": "contraditar",
    "contraditastes": "contraditar",
    "contraditava": "contraditar",
    "contraditavam": "contraditar",
    "contraditavas": "contraditar",
    "contradite": "contraditar",
    "contraditei": "contraditar",
    "contraditeis": "contraditar",
    "contraditem": "contraditar",
    "contraditemo": "contraditar",
    "contraditemos": "contraditar",
    "contradites": "contraditar",
    "contradito": "contradizer",
    "contraditora": "contraditor",
    "contraditoras": "contraditor",
    "contraditores": "contraditor",
    "contraditos": "contradizer",
    "contraditou": "contraditar",
    "contraditá": "contraditar",
    "contraditámo": "contraditar",
    "contraditámos": "contraditar",
    "contraditáramo": "contraditar",
    "contraditáramos": "contraditar",
    "contraditárei": "contraditar",
    "contraditáreis": "contraditar",
    "contraditásseis": "contraditar",
    "contraditássemos": "contraditar",
    "contraditávamo": "contraditar",
    "contraditávamos": "contraditar",
    "contraditávei": "contraditar",
    "contraditáveis": "contraditável",
    "contraditória": "contraditório",
    "contraditórias": "contraditório",
    "contraditórios": "contraditório",
    "contradiz": "contradizer",
    "contradize": "contradizer",
    "contradizei": "contradizer",
    "contradizeis": "contradizer",
    "contradizem": "contradizer",
    "contradizemo": "contradizer",
    "contradizemos": "contradizer",
    "contradizendo": "contradizer",
    "contradizerde": "contradizer",
    "contradizerdes": "contradizer",
    "contradizere": "contradizer",
    "contradizerem": "contradizer",
    "contradizeres": "contradizer",
    "contradizermo": "contradizer",
    "contradizermos": "contradizer",
    "contradizes": "contradizer",
    "contradizia": "contradizer",
    "contradiziam": "contradizer",
    "contradizias": "contradizer",
    "contradizê": "contradizer",
    "contradizíamo": "contradizer",
    "contradizíamos": "contradizer",
    "contradizíei": "contradizer",
    "contradizíeis": "contradizer",
    "contradições": "contradição",
    "contraem": "contrair",
    "contraentes": "contraente",
    "contrafactora": "contrafactor",
    "contrafactoras": "contrafactor",
    "contrafactores": "contrafactor",
    "contrafacções": "contrafacção",
    "contrafaixas": "contrafaixa",
    "contrafarei": "contrafazer",
    "contrafareis": "contrafazer",
    "contrafaremos": "contrafazer",
    "contrafaria": "contrafazer",
    "contrafariam": "contrafazer",
    "contrafarias": "contrafazer",
    "contrafará": "contrafazer",
    "contrafarás": "contrafazer",
    "contrafarão": "contrafazer",
    "contrafaríamos": "contrafazer",
    "contrafaríeis": "contrafazer",
    "contrafaz": "contrafazer",
    "contrafaze": "contrafazer",
    "contrafazei": "contrafazer",
    "contrafazeis": "contrafazer",
    "contrafazem": "contrafazer",
    "contrafazemo": "contrafazer",
    "contrafazemos": "contrafazer",
    "contrafazendo": "contrafazer",
    "contrafazerde": "contrafazer",
    "contrafazerdes": "contrafazer",
    "contrafazere": "contrafazer",
    "contrafazerem": "contrafazer",
    "contrafazeres": "contrafazer",
    "contrafazermo": "contrafazer",
    "contrafazermos": "contrafazer",
    "contrafazes": "contrafazer",
    "contrafazia": "contrafazer",
    "contrafaziam": "contrafazer",
    "contrafazias": "contrafazer",
    "contrafazê": "contrafazer",
    "contrafazíamo": "contrafazer",
    "contrafazíamos": "contrafazer",
    "contrafazíei": "contrafazer",
    "contrafazíeis": "contrafazer",
    "contrafaça": "contrafazer",
    "contrafaçais": "contrafazer",
    "contrafaçam": "contrafazer",
    "contrafaçamo": "contrafazer",
    "contrafaçamos": "contrafazer",
    "contrafaças": "contrafazer",
    "contrafaço": "contrafazer",
    "contrafechos": "contrafecho",
    "contrafeita": "contrafeito",
    "contrafeitas": "contrafeito",
    "contrafeito": "contrafazer",
    "contrafeitos": "contrafeito",
    "contrafeições": "contrafeição",
    "contrafez": "contrafazer",
    "contrafi": "contrafazer",
    "contrafiguras": "contrafigura",
    "contrafilas": "contrafila",
    "contrafileiras": "contrafileira",
    "contrafios": "contrafio",
    "contrafiz": "contrafazer",
    "contrafizemo": "contrafazer",
    "contrafizemos": "contrafazer",
    "contrafizer": "contrafazer",
    "contrafizera": "contrafazer",
    "contrafizeram": "contrafazer",
    "contrafizeras": "contrafazer",
    "contrafizerdes": "contrafazer",
    "contrafizerem": "contrafazer",
    "contrafizeres": "contrafazer",
    "contrafizermos": "contrafazer",
    "contrafizesse": "contrafazer",
    "contrafizessem": "contrafazer",
    "contrafizesses": "contrafazer",
    "contrafizeste": "contrafazer",
    "contrafizestes": "contrafazer",
    "contrafizéramo": "contrafazer",
    "contrafizéramos": "contrafazer",
    "contrafizérei": "contrafazer",
    "contrafizéreis": "contrafazer",
    "contrafizésseis": "contrafazer",
    "contrafizéssemos": "contrafazer",
    "contraflancos": "contraflanco",
    "contrafoleados": "contrafoleado",
    "contrafortes": "contraforte",
    "contrafossos": "contrafosso",
    "contrafugas": "contrafuga",
    "contrafá": "contrafazer",
    "contrafés": "contrafé",
    "contrafê": "contrafazer",
    "contragolpes": "contragolpe",
    "contrai": "contrair",
    "contraia": "contrair",
    "contraiais": "contrair",
    "contraiam": "contrair",
    "contraiamo": "contrair",
    "contraiamos": "contrair",
    "contraias": "contrair",
    "contraindo": "contrair",
    "contraio": "contrair",
    "contrairde": "contrair",
    "contrairdes": "contrair",
    "contrairei": "contrair",
    "contraireis": "contrair",
    "contrairemos": "contrair",
    "contrairia": "contrair",
    "contrairiam": "contrair",
    "contrairias": "contrair",
    "contrairmo": "contrair",
    "contrairmos": "contrair",
    "contrairá": "contrair",
    "contrairás": "contrair",
    "contrairão": "contrair",
    "contrairíamos": "contrair",
    "contrairíeis": "contrair",
    "contrais": "contrair",
    "contraiu": "contrair",
    "contralinhas": "contralinha",
    "contraltos": "contralto",
    "contraluzes": "contraluz",
    "contramalha": "contramalhar",
    "contramalhada": "contramalhar",
    "contramalhadas": "contramalhar",
    "contramalhado": "contramalhar",
    "contramalhados": "contramalhar",
    "contramalhai": "contramalhar",
    "contramalhais": "contramalhar",
    "contramalham": "contramalhar",
    "contramalhamo": "contramalhar",
    "contramalhamos": "contramalhar",
    "contramalhando": "contramalhar",
    "contramalhara": "contramalhar",
    "contramalharam": "contramalhar",
    "contramalharas": "contramalhar",
    "contramalharde": "contramalhar",
    "contramalhardes": "contramalhar",
    "contramalhare": "contramalhar",
    "contramalharei": "contramalhar",
    "contramalhareis": "contramalhar",
    "contramalharem": "contramalhar",
    "contramalharemos": "contramalhar",
    "contramalhares": "contramalhar",
    "contramalharia": "contramalhar",
    "contramalhariam": "contramalhar",
    "contramalharias": "contramalhar",
    "contramalharmo": "contramalhar",
    "contramalharmos": "contramalhar",
    "contramalhará": "contramalhar",
    "contramalharás": "contramalhar",
    "contramalharão": "contramalhar",
    "contramalharíamos": "contramalhar",
    "contramalharíeis": "contramalhar",
    "contramalhas": "contramalhar",
    "contramalhasse": "contramalhar",
    "contramalhassem": "contramalhar",
    "contramalhasses": "contramalhar",
    "contramalhaste": "contramalhar",
    "contramalhastes": "contramalhar",
    "contramalhava": "contramalhar",
    "contramalhavam": "contramalhar",
    "contramalhavas": "contramalhar",
    "contramalhe": "contramalhar",
    "contramalhei": "contramalhar",
    "contramalheis": "contramalhar",
    "contramalhem": "contramalhar",
    "contramalhemo": "contramalhar",
    "contramalhemos": "contramalhar",
    "contramalhes": "contramalhar",
    "contramalho": "contramalhar",
    "contramalhou": "contramalhar",
    "contramalhá": "contramalhar",
    "contramalhámo": "contramalhar",
    "contramalhámos": "contramalhar",
    "contramalháramo": "contramalhar",
    "contramalháramos": "contramalhar",
    "contramalhárei": "contramalhar",
    "contramalháreis": "contramalhar",
    "contramalhásseis": "contramalhar",
    "contramalhássemos": "contramalhar",
    "contramalhávamo": "contramalhar",
    "contramalhávamos": "contramalhar",
    "contramalhávei": "contramalhar",
    "contramalháveis": "contramalhar",
    "contramanda": "contramandar",
    "contramandada": "contramandar",
    "contramandadas": "contramandar",
    "contramandado": "contramandar",
    "contramandados": "contramandar",
    "contramandai": "contramandar",
    "contramandais": "contramandar",
    "contramandam": "contramandar",
    "contramandamo": "contramandar",
    "contramandamos": "contramandar",
    "contramandando": "contramandar",
    "contramandara": "contramandar",
    "contramandaram": "contramandar",
    "contramandaras": "contramandar",
    "contramandarde": "contramandar",
    "contramandardes": "contramandar",
    "contramandare": "contramandar",
    "contramandarei": "contramandar",
    "contramandareis": "contramandar",
    "contramandarem": "contramandar",
    "contramandaremos": "contramandar",
    "contramandares": "contramandar",
    "contramandaria": "contramandar",
    "contramandariam": "contramandar",
    "contramandarias": "contramandar",
    "contramandarmo": "contramandar",
    "contramandarmos": "contramandar",
    "contramandará": "contramandar",
    "contramandarás": "contramandar",
    "contramandarão": "contramandar",
    "contramandaríamos": "contramandar",
    "contramandaríeis": "contramandar",
    "contramandas": "contramandar",
    "contramandasse": "contramandar",
    "contramandassem": "contramandar",
    "contramandasses": "contramandar",
    "contramandaste": "contramandar",
    "contramandastes": "contramandar",
    "contramandava": "contramandar",
    "contramandavam": "contramandar",
    "contramandavas": "contramandar",
    "contramande": "contramandar",
    "contramandei": "contramandar",
    "contramandeis": "contramandar",
    "contramandem": "contramandar",
    "contramandemo": "contramandar",
    "contramandemos": "contramandar",
    "contramandes": "contramandar",
    "contramando": "contramandar",
    "contramandou": "contramandar",
    "contramandá": "contramandar",
    "contramandámo": "contramandar",
    "contramandámos": "contramandar",
    "contramandáramo": "contramandar",
    "contramandáramos": "contramandar",
    "contramandárei": "contramandar",
    "contramandáreis": "contramandar",
    "contramandásseis": "contramandar",
    "contramandássemos": "contramandar",
    "contramandávamo": "contramandar",
    "contramandávamos": "contramandar",
    "contramandávei": "contramandar",
    "contramandáveis": "contramandar",
    "contramangas": "contramanga",
    "contramanifestações": "contramanifestação",
    "contramanobras": "contramanobra",
    "contramarca": "contramarcar",
    "contramarcada": "contramarcar",
    "contramarcadas": "contramarcar",
    "contramarcado": "contramarcar",
    "contramarcados": "contramarcar",
    "contramarcai": "contramarcar",
    "contramarcais": "contramarcar",
    "contramarcam": "contramarcar",
    "contramarcamo": "contramarcar",
    "contramarcamos": "contramarcar",
    "contramarcando": "contramarcar",
    "contramarcara": "contramarcar",
    "contramarcaram": "contramarcar",
    "contramarcaras": "contramarcar",
    "contramarcarde": "contramarcar",
    "contramarcardes": "contramarcar",
    "contramarcare": "contramarcar",
    "contramarcarei": "contramarcar",
    "contramarcareis": "contramarcar",
    "contramarcarem": "contramarcar",
    "contramarcaremos": "contramarcar",
    "contramarcares": "contramarcar",
    "contramarcaria": "contramarcar",
    "contramarcariam": "contramarcar",
    "contramarcarias": "contramarcar",
    "contramarcarmo": "contramarcar",
    "contramarcarmos": "contramarcar",
    "contramarcará": "contramarcar",
    "contramarcarás": "contramarcar",
    "contramarcarão": "contramarcar",
    "contramarcaríamos": "contramarcar",
    "contramarcaríeis": "contramarcar",
    "contramarcas": "contramarcar",
    "contramarcasse": "contramarcar",
    "contramarcassem": "contramarcar",
    "contramarcasses": "contramarcar",
    "contramarcaste": "contramarcar",
    "contramarcastes": "contramarcar",
    "contramarcava": "contramarcar",
    "contramarcavam": "contramarcar",
    "contramarcavas": "contramarcar",
    "contramarcações": "contramarcação",
    "contramarcha": "contramarchar",
    "contramarchada": "contramarchar",
    "contramarchadas": "contramarchar",
    "contramarchado": "contramarchar",
    "contramarchados": "contramarchar",
    "contramarchai": "contramarchar",
    "contramarchais": "contramarchar",
    "contramarcham": "contramarchar",
    "contramarchamo": "contramarchar",
    "contramarchamos": "contramarchar",
    "contramarchando": "contramarchar",
    "contramarchara": "contramarchar",
    "contramarcharam": "contramarchar",
    "contramarcharas": "contramarchar",
    "contramarcharde": "contramarchar",
    "contramarchardes": "contramarchar",
    "contramarchare": "contramarchar",
    "contramarcharei": "contramarchar",
    "contramarchareis": "contramarchar",
    "contramarcharem": "contramarchar",
    "contramarcharemos": "contramarchar",
    "contramarchares": "contramarchar",
    "contramarcharia": "contramarchar",
    "contramarchariam": "contramarchar",
    "contramarcharias": "contramarchar",
    "contramarcharmo": "contramarchar",
    "contramarcharmos": "contramarchar",
    "contramarchará": "contramarchar",
    "contramarcharás": "contramarchar",
    "contramarcharão": "contramarchar",
    "contramarcharíamos": "contramarchar",
    "contramarcharíeis": "contramarchar",
    "contramarchas": "contramarchar",
    "contramarchasse": "contramarchar",
    "contramarchassem": "contramarchar",
    "contramarchasses": "contramarchar",
    "contramarchaste": "contramarchar",
    "contramarchastes": "contramarchar",
    "contramarchava": "contramarchar",
    "contramarchavam": "contramarchar",
    "contramarchavas": "contramarchar",
    "contramarche": "contramarchar",
    "contramarchei": "contramarchar",
    "contramarcheis": "contramarchar",
    "contramarchem": "contramarchar",
    "contramarchemo": "contramarchar",
    "contramarchemos": "contramarchar",
    "contramarches": "contramarchar",
    "contramarcho": "contramarchar",
    "contramarchou": "contramarchar",
    "contramarchá": "contramarchar",
    "contramarchámo": "contramarchar",
    "contramarchámos": "contramarchar",
    "contramarcháramo": "contramarchar",
    "contramarcháramos": "contramarchar",
    "contramarchárei": "contramarchar",
    "contramarcháreis": "contramarchar",
    "contramarchásseis": "contramarchar",
    "contramarchássemos": "contramarchar",
    "contramarchávamo": "contramarchar",
    "contramarchávamos": "contramarchar",
    "contramarchávei": "contramarchar",
    "contramarcháveis": "contramarchar",
    "contramarco": "contramarcar",
    "contramarcou": "contramarcar",
    "contramarcá": "contramarcar",
    "contramarcámo": "contramarcar",
    "contramarcámos": "contramarcar",
    "contramarcáramo": "contramarcar",
    "contramarcáramos": "contramarcar",
    "contramarcárei": "contramarcar",
    "contramarcáreis": "contramarcar",
    "contramarcásseis": "contramarcar",
    "contramarcássemos": "contramarcar",
    "contramarcávamo": "contramarcar",
    "contramarcávamos": "contramarcar",
    "contramarcávei": "contramarcar",
    "contramarcáveis": "contramarcar",
    "contramargens": "contramargem",
    "contramarque": "contramarcar",
    "contramarquei": "contramarcar",
    "contramarqueis": "contramarcar",
    "contramarquem": "contramarcar",
    "contramarquemo": "contramarcar",
    "contramarquemos": "contramarcar",
    "contramarques": "contramarcar",
    "contramarés": "contramaré",
    "contramestra": "contramestre",
    "contramestras": "contramestre",
    "contramestres": "contramestre",
    "contrametades": "contrametade",
    "contramezenas": "contramezena",
    "contramina": "contraminar",
    "contraminada": "contraminar",
    "contraminadas": "contraminar",
    "contraminado": "contraminar",
    "contraminados": "contraminar",
    "contraminai": "contraminar",
    "contraminais": "contraminar",
    "contraminam": "contraminar",
    "contraminamo": "contraminar",
    "contraminamos": "contraminar",
    "contraminando": "contraminar",
    "contraminara": "contraminar",
    "contraminaram": "contraminar",
    "contraminaras": "contraminar",
    "contraminarde": "contraminar",
    "contraminardes": "contraminar",
    "contraminare": "contraminar",
    "contraminarei": "contraminar",
    "contraminareis": "contraminar",
    "contraminarem": "contraminar",
    "contraminaremos": "contraminar",
    "contraminares": "contraminar",
    "contraminaria": "contraminar",
    "contraminariam": "contraminar",
    "contraminarias": "contraminar",
    "contraminarmo": "contraminar",
    "contraminarmos": "contraminar",
    "contraminará": "contraminar",
    "contraminarás": "contraminar",
    "contraminarão": "contraminar",
    "contraminaríamos": "contraminar",
    "contraminaríeis": "contraminar",
    "contraminas": "contraminar",
    "contraminasse": "contraminar",
    "contraminassem": "contraminar",
    "contraminasses": "contraminar",
    "contraminaste": "contraminar",
    "contraminastes": "contraminar",
    "contraminava": "contraminar",
    "contraminavam": "contraminar",
    "contraminavas": "contraminar",
    "contramine": "contraminar",
    "contraminei": "contraminar",
    "contramineis": "contraminar",
    "contraminem": "contraminar",
    "contraminemo": "contraminar",
    "contraminemos": "contraminar",
    "contramines": "contraminar",
    "contramino": "contraminar",
    "contraminou": "contraminar",
    "contraminá": "contraminar",
    "contraminámo": "contraminar",
    "contraminámos": "contraminar",
    "contramináramo": "contraminar",
    "contramináramos": "contraminar",
    "contraminárei": "contraminar",
    "contramináreis": "contraminar",
    "contraminásseis": "contraminar",
    "contraminássemos": "contraminar",
    "contraminávamo": "contraminar",
    "contraminávamos": "contraminar",
    "contraminávei": "contraminar",
    "contramináveis": "contraminar",
    "contramolda": "contramoldar",
    "contramoldada": "contramoldar",
    "contramoldadas": "contramoldar",
    "contramoldado": "contramoldar",
    "contramoldados": "contramoldar",
    "contramoldagens": "contramoldagem",
    "contramoldai": "contramoldar",
    "contramoldais": "contramoldar",
    "contramoldam": "contramoldar",
    "contramoldamo": "contramoldar",
    "contramoldamos": "contramoldar",
    "contramoldando": "contramoldar",
    "contramoldara": "contramoldar",
    "contramoldaram": "contramoldar",
    "contramoldaras": "contramoldar",
    "contramoldarde": "contramoldar",
    "contramoldardes": "contramoldar",
    "contramoldare": "contramoldar",
    "contramoldarei": "contramoldar",
    "contramoldareis": "contramoldar",
    "contramoldarem": "contramoldar",
    "contramoldaremos": "contramoldar",
    "contramoldares": "contramoldar",
    "contramoldaria": "contramoldar",
    "contramoldariam": "contramoldar",
    "contramoldarias": "contramoldar",
    "contramoldarmo": "contramoldar",
    "contramoldarmos": "contramoldar",
    "contramoldará": "contramoldar",
    "contramoldarás": "contramoldar",
    "contramoldarão": "contramoldar",
    "contramoldaríamos": "contramoldar",
    "contramoldaríeis": "contramoldar",
    "contramoldas": "contramoldar",
    "contramoldasse": "contramoldar",
    "contramoldassem": "contramoldar",
    "contramoldasses": "contramoldar",
    "contramoldaste": "contramoldar",
    "contramoldastes": "contramoldar",
    "contramoldava": "contramoldar",
    "contramoldavam": "contramoldar",
    "contramoldavas": "contramoldar",
    "contramolde": "contramoldar",
    "contramoldei": "contramoldar",
    "contramoldeis": "contramoldar",
    "contramoldem": "contramoldar",
    "contramoldemo": "contramoldar",
    "contramoldemos": "contramoldar",
    "contramoldes": "contramolde",
    "contramoldo": "contramoldar",
    "contramoldou": "contramoldar",
    "contramoldá": "contramoldar",
    "contramoldámo": "contramoldar",
    "contramoldámos": "contramoldar",
    "contramoldáramo": "contramoldar",
    "contramoldáramos": "contramoldar",
    "contramoldárei": "contramoldar",
    "contramoldáreis": "contramoldar",
    "contramoldásseis": "contramoldar",
    "contramoldássemos": "contramoldar",
    "contramoldávamo": "contramoldar",
    "contramoldávamos": "contramoldar",
    "contramoldávei": "contramoldar",
    "contramoldáveis": "contramoldar",
    "contramonções": "contramonção",
    "contramovimentos": "contramovimento",
    "contramura": "contramurar",
    "contramurada": "contramurar",
    "contramuradas": "contramurar",
    "contramurado": "contramurar",
    "contramurados": "contramurar",
    "contramurai": "contramurar",
    "contramurais": "contramurar",
    "contramuralhas": "contramuralha",
    "contramuram": "contramurar",
    "contramuramo": "contramurar",
    "contramuramos": "contramurar",
    "contramurando": "contramurar",
    "contramurara": "contramurar",
    "contramuraram": "contramurar",
    "contramuraras": "contramurar",
    "contramurarde": "contramurar",
    "contramurardes": "contramurar",
    "contramurare": "contramurar",
    "contramurarei": "contramurar",
    "contramurareis": "contramurar",
    "contramurarem": "contramurar",
    "contramuraremos": "contramurar",
    "contramurares": "contramurar",
    "contramuraria": "contramurar",
    "contramurariam": "contramurar",
    "contramurarias": "contramurar",
    "contramurarmo": "contramurar",
    "contramurarmos": "contramurar",
    "contramurará": "contramurar",
    "contramurarás": "contramurar",
    "contramurarão": "contramurar",
    "contramuraríamos": "contramurar",
    "contramuraríeis": "contramurar",
    "contramuras": "contramurar",
    "contramurasse": "contramurar",
    "contramurassem": "contramurar",
    "contramurasses": "contramurar",
    "contramuraste": "contramurar",
    "contramurastes": "contramurar",
    "contramurava": "contramurar",
    "contramuravam": "contramurar",
    "contramuravas": "contramurar",
    "contramure": "contramurar",
    "contramurei": "contramurar",
    "contramureis": "contramurar",
    "contramurem": "contramurar",
    "contramuremo": "contramurar",
    "contramuremos": "contramurar",
    "contramures": "contramurar",
    "contramuro": "contramurar",
    "contramuros": "contramuro",
    "contramurou": "contramurar",
    "contramurá": "contramurar",
    "contramurámo": "contramurar",
    "contramurámos": "contramurar",
    "contramuráramo": "contramurar",
    "contramuráramos": "contramurar",
    "contramurárei": "contramurar",
    "contramuráreis": "contramurar",
    "contramurásseis": "contramurar",
    "contramurássemos": "contramurar",
    "contramurávamo": "contramurar",
    "contramurávamos": "contramurar",
    "contramurávei": "contramurar",
    "contramuráveis": "contramurar",
    "contramãos": "contramão",
    "contranaturais": "contranatural",
    "contranaturalidades": "contranaturalidade",
    "contranotas": "contranota",
    "contraparentes": "contraparente",
    "contrapartidas": "contrapartida",
    "contrapassos": "contrapasso",
    "contrapelos": "contrapelo",
    "contrapesa": "contrapesar",
    "contrapesada": "contrapesar",
    "contrapesadas": "contrapesar",
    "contrapesado": "contrapesar",
    "contrapesados": "contrapesar",
    "contrapesai": "contrapesar",
    "contrapesais": "contrapesar",
    "contrapesam": "contrapesar",
    "contrapesamo": "contrapesar",
    "contrapesamos": "contrapesar",
    "contrapesando": "contrapesar",
    "contrapesara": "contrapesar",
    "contrapesaram": "contrapesar",
    "contrapesaras": "contrapesar",
    "contrapesarde": "contrapesar",
    "contrapesardes": "contrapesar",
    "contrapesare": "contrapesar",
    "contrapesarei": "contrapesar",
    "contrapesareis": "contrapesar",
    "contrapesarem": "contrapesar",
    "contrapesaremos": "contrapesar",
    "contrapesares": "contrapesar",
    "contrapesaria": "contrapesar",
    "contrapesariam": "contrapesar",
    "contrapesarias": "contrapesar",
    "contrapesarmo": "contrapesar",
    "contrapesarmos": "contrapesar",
    "contrapesará": "contrapesar",
    "contrapesarás": "contrapesar",
    "contrapesarão": "contrapesar",
    "contrapesaríamos": "contrapesar",
    "contrapesaríeis": "contrapesar",
    "contrapesas": "contrapesar",
    "contrapesasse": "contrapesar",
    "contrapesassem": "contrapesar",
    "contrapesasses": "contrapesar",
    "contrapesaste": "contrapesar",
    "contrapesastes": "contrapesar",
    "contrapesava": "contrapesar",
    "contrapesavam": "contrapesar",
    "contrapesavas": "contrapesar",
    "contrapese": "contrapesar",
    "contrapesei": "contrapesar",
    "contrapeseis": "contrapesar",
    "contrapesem": "contrapesar",
    "contrapesemo": "contrapesar",
    "contrapesemos": "contrapesar",
    "contrapeses": "contrapesar",
    "contrapeso": "contrapesar",
    "contrapesos": "contrapeso",
    "contrapesou": "contrapesar",
    "contrapesá": "contrapesar",
    "contrapesámo": "contrapesar",
    "contrapesámos": "contrapesar",
    "contrapesáramo": "contrapesar",
    "contrapesáramos": "contrapesar",
    "contrapesárei": "contrapesar",
    "contrapesáreis": "contrapesar",
    "contrapesásseis": "contrapesar",
    "contrapesássemos": "contrapesar",
    "contrapesávamo": "contrapesar",
    "contrapesávamos": "contrapesar",
    "contrapesávei": "contrapesar",
    "contrapesáveis": "contrapesar",
    "contrapeçonhas": "contrapeçonha",
    "contrapilastras": "contrapilastra",
    "contrapinázios": "contrapinázio",
    "contrapisas": "contrapisa",
    "contraplacados": "contraplacado",
    "contrapoderes": "contrapoder",
    "contrapomo": "contrapor",
    "contrapomos": "contrapor",
    "contraponde": "contrapor",
    "contrapondes": "contrapor",
    "contrapondo": "contrapor",
    "contraponha": "contrapor",
    "contraponhais": "contrapor",
    "contraponham": "contrapor",
    "contraponhamo": "contrapor",
    "contraponhamos": "contrapor",
    "contraponhas": "contrapor",
    "contraponho": "contrapor",
    "contraponteada": "contrapontear",
    "contraponteadas": "contrapontear",
    "contraponteado": "contrapontear",
    "contraponteados": "contrapontear",
    "contraponteai": "contrapontear",
    "contraponteais": "contrapontear",
    "contraponteamo": "contrapontear",
    "contraponteamos": "contrapontear",
    "contraponteando": "contrapontear",
    "contraponteara": "contrapontear",
    "contrapontearam": "contrapontear",
    "contrapontearas": "contrapontear",
    "contrapontearde": "contrapontear",
    "contraponteardes": "contrapontear",
    "contraponteare": "contrapontear",
    "contrapontearei": "contrapontear",
    "contraponteareis": "contrapontear",
    "contrapontearem": "contrapontear",
    "contrapontearemos": "contrapontear",
    "contraponteares": "contrapontear",
    "contrapontearia": "contrapontear",
    "contraponteariam": "contrapontear",
    "contrapontearias": "contrapontear",
    "contrapontearmo": "contrapontear",
    "contrapontearmos": "contrapontear",
    "contraponteará": "contrapontear",
    "contrapontearás": "contrapontear",
    "contrapontearão": "contrapontear",
    "contrapontearíamos": "contrapontear",
    "contrapontearíeis": "contrapontear",
    "contraponteasse": "contrapontear",
    "contraponteassem": "contrapontear",
    "contraponteasses": "contrapontear",
    "contraponteaste": "contrapontear",
    "contraponteastes": "contrapontear",
    "contraponteava": "contrapontear",
    "contraponteavam": "contrapontear",
    "contraponteavas": "contrapontear",
    "contraponteei": "contrapontear",
    "contraponteeis": "contrapontear",
    "contraponteemo": "contrapontear",
    "contraponteemos": "contrapontear",
    "contraponteia": "contrapontear",
    "contraponteiam": "contrapontear",
    "contraponteias": "contrapontear",
    "contraponteie": "contrapontear",
    "contraponteiem": "contrapontear",
    "contraponteies": "contrapontear",
    "contraponteio": "contrapontear",
    "contraponteou": "contrapontear",
    "contraponteá": "contrapontear",
    "contraponteámo": "contrapontear",
    "contraponteámos": "contrapontear",
    "contraponteáramo": "contrapontear",
    "contraponteáramos": "contrapontear",
    "contraponteárei": "contrapontear",
    "contraponteáreis": "contrapontear",
    "contraponteásseis": "contrapontear",
    "contraponteássemos": "contrapontear",
    "contraponteávamo": "contrapontear",
    "contraponteávamos": "contrapontear",
    "contraponteávei": "contrapontear",
    "contraponteáveis": "contrapontear",
    "contrapontistas": "contrapontista",
    "contrapontos": "contraponto",
    "contraporde": "contrapor",
    "contrapordes": "contrapor",
    "contrapore": "contrapor",
    "contraporei": "contrapor",
    "contraporeis": "contrapor",
    "contraporem": "contrapor",
    "contraporemos": "contrapor",
    "contrapores": "contrapor",
    "contraporia": "contrapor",
    "contraporiam": "contrapor",
    "contraporias": "contrapor",
    "contrapormo": "contrapor",
    "contrapormos": "contrapor",
    "contraporá": "contrapor",
    "contraporás": "contrapor",
    "contraporão": "contrapor",
    "contraporíamos": "contrapor",
    "contraporíeis": "contrapor",
    "contraposições": "contraposição",
    "contraposta": "contraposto",
    "contrapostas": "contraposto",
    "contraposto": "contrapor",
    "contrapostos": "contraposto",
    "contrapressões": "contrapressão",
    "contraproducentes": "contraproducente",
    "contraproduz": "contraproduzir",
    "contraproduza": "contraproduzir",
    "contraproduzais": "contraproduzir",
    "contraproduzam": "contraproduzir",
    "contraproduzamo": "contraproduzir",
    "contraproduzamos": "contraproduzir",
    "contraproduzas": "contraproduzir",
    "contraproduze": "contraproduzir",
    "contraproduzem": "contraproduzir",
    "contraproduzes": "contraproduzir",
    "contraproduzi": "contraproduzir",
    "contraproduzia": "contraproduzir",
    "contraproduziam": "contraproduzir",
    "contraproduzias": "contraproduzir",
    "contraproduzida": "contraproduzir",
    "contraproduzidas": "contraproduzir",
    "contraproduzido": "contraproduzir",
    "contraproduzidos": "contraproduzir",
    "contraproduzimo": "contraproduzir",
    "contraproduzimos": "contraproduzir",
    "contraproduzindo": "contraproduzir",
    "contraproduzira": "contraproduzir",
    "contraproduziram": "contraproduzir",
    "contraproduziras": "contraproduzir",
    "contraproduzirde": "contraproduzir",
    "contraproduzirdes": "contraproduzir",
    "contraproduzire": "contraproduzir",
    "contraproduzirei": "contraproduzir",
    "contraproduzireis": "contraproduzir",
    "contraproduzirem": "contraproduzir",
    "contraproduziremos": "contraproduzir",
    "contraproduzires": "contraproduzir",
    "contraproduziria": "contraproduzir",
    "contraproduziriam": "contraproduzir",
    "contraproduzirias": "contraproduzir",
    "contraproduzirmo": "contraproduzir",
    "contraproduzirmos": "contraproduzir",
    "contraproduzirá": "contraproduzir",
    "contraproduzirás": "contraproduzir",
    "contraproduzirão": "contraproduzir",
    "contraproduziríamos": "contraproduzir",
    "contraproduziríeis": "contraproduzir",
    "contraproduzis": "contraproduzir",
    "contraproduzisse": "contraproduzir",
    "contraproduzissem": "contraproduzir",
    "contraproduzisses": "contraproduzir",
    "contraproduziste": "contraproduzir",
    "contraproduzistes": "contraproduzir",
    "contraproduziu": "contraproduzir",
    "contraproduzo": "contraproduzir",
    "contraproduzíamo": "contraproduzir",
    "contraproduzíamos": "contraproduzir",
    "contraproduzíei": "contraproduzir",
    "contraproduzíeis": "contraproduzir",
    "contraproduzíramo": "contraproduzir",
    "contraproduzíramos": "contraproduzir",
    "contraproduzírei": "contraproduzir",
    "contraproduzíreis": "contraproduzir",
    "contraproduzísseis": "contraproduzir",
    "contraproduzíssemos": "contraproduzir",
    "contraprogramas": "contraprograma",
    "contrapropagandas": "contrapropaganda",
    "contrapropomo": "contrapropor",
    "contrapropomos": "contrapropor",
    "contraproponde": "contrapropor",
    "contrapropondes": "contrapropor",
    "contrapropondo": "contrapropor",
    "contraproponha": "contrapropor",
    "contraproponhais": "contrapropor",
    "contraproponham": "contrapropor",
    "contraproponhamo": "contrapropor",
    "contraproponhamos": "contrapropor",
    "contraproponhas": "contrapropor",
    "contraproponho": "contrapropor",
    "contraproporde": "contrapropor",
    "contrapropordes": "contrapropor",
    "contrapropore": "contrapropor",
    "contraproporei": "contrapropor",
    "contraproporeis": "contrapropor",
    "contraproporem": "contrapropor",
    "contraproporemos": "contrapropor",
    "contrapropores": "contrapropor",
    "contraproporia": "contrapropor",
    "contraproporiam": "contrapropor",
    "contraproporias": "contrapropor",
    "contrapropormo": "contrapropor",
    "contrapropormos": "contrapropor",
    "contraproporá": "contrapropor",
    "contraproporás": "contrapropor",
    "contraproporão": "contrapropor",
    "contraproporíamos": "contrapropor",
    "contraproporíeis": "contrapropor",
    "contraproposta": "contrapropor",
    "contrapropostas": "contraproposta",
    "contraproposto": "contrapropor",
    "contrapropostos": "contrapropor",
    "contrapropunha": "contrapropor",
    "contrapropunham": "contrapropor",
    "contrapropunhas": "contrapropor",
    "contrapropus": "contrapropor",
    "contrapropusemo": "contrapropor",
    "contrapropusemos": "contrapropor",
    "contrapropuser": "contrapropor",
    "contrapropusera": "contrapropor",
    "contrapropuseram": "contrapropor",
    "contrapropuseras": "contrapropor",
    "contrapropuserdes": "contrapropor",
    "contrapropuserem": "contrapropor",
    "contrapropuseres": "contrapropor",
    "contrapropusermos": "contrapropor",
    "contrapropusesse": "contrapropor",
    "contrapropusessem": "contrapropor",
    "contrapropusesses": "contrapropor",
    "contrapropuseste": "contrapropor",
    "contrapropusestes": "contrapropor",
    "contrapropuséramo": "contrapropor",
    "contrapropuséramos": "contrapropor",
    "contrapropusérei": "contrapropor",
    "contrapropuséreis": "contrapropor",
    "contrapropusésseis": "contrapropor",
    "contrapropuséssemos": "contrapropor",
    "contrapropô": "contrapropor",
    "contrapropôs": "contrapropor",
    "contrapropõe": "contrapropor",
    "contrapropõem": "contrapropor",
    "contrapropões": "contrapropor",
    "contrapropúnhamo": "contrapropor",
    "contrapropúnhamos": "contrapropor",
    "contrapropúnhei": "contrapropor",
    "contrapropúnheis": "contrapropor",
    "contraprova": "contraprovar",
    "contraprovada": "contraprovar",
    "contraprovadas": "contraprovar",
    "contraprovado": "contraprovar",
    "contraprovados": "contraprovar",
    "contraprovai": "contraprovar",
    "contraprovais": "contraprovar",
    "contraprovam": "contraprovar",
    "contraprovamo": "contraprovar",
    "contraprovamos": "contraprovar",
    "contraprovando": "contraprovar",
    "contraprovara": "contraprovar",
    "contraprovaram": "contraprovar",
    "contraprovaras": "contraprovar",
    "contraprovarde": "contraprovar",
    "contraprovardes": "contraprovar",
    "contraprovare": "contraprovar",
    "contraprovarei": "contraprovar",
    "contraprovareis": "contraprovar",
    "contraprovarem": "contraprovar",
    "contraprovaremos": "contraprovar",
    "contraprovares": "contraprovar",
    "contraprovaria": "contraprovar",
    "contraprovariam": "contraprovar",
    "contraprovarias": "contraprovar",
    "contraprovarmo": "contraprovar",
    "contraprovarmos": "contraprovar",
    "contraprovará": "contraprovar",
    "contraprovarás": "contraprovar",
    "contraprovarão": "contraprovar",
    "contraprovaríamos": "contraprovar",
    "contraprovaríeis": "contraprovar",
    "contraprovas": "contraprovar",
    "contraprovasse": "contraprovar",
    "contraprovassem": "contraprovar",
    "contraprovasses": "contraprovar",
    "contraprovaste": "contraprovar",
    "contraprovastes": "contraprovar",
    "contraprovava": "contraprovar",
    "contraprovavam": "contraprovar",
    "contraprovavas": "contraprovar",
    "contraprove": "contraprovar",
    "contraprovei": "contraprovar",
    "contraproveis": "contraprovar",
    "contraprovem": "contraprovar",
    "contraprovemo": "contraprovar",
    "contraprovemos": "contraprovar",
    "contraproves": "contraprovar",
    "contraprovo": "contraprovar",
    "contraprovou": "contraprovar",
    "contraprová": "contraprovar",
    "contraprovámo": "contraprovar",
    "contraprovámos": "contraprovar",
    "contraprováramo": "contraprovar",
    "contraprováramos": "contraprovar",
    "contraprovárei": "contraprovar",
    "contraprováreis": "contraprovar",
    "contraprovásseis": "contraprovar",
    "contraprovássemos": "contraprovar",
    "contraprovávamo": "contraprovar",
    "contraprovávamos": "contraprovar",
    "contraprovávei": "contraprovar",
    "contraprováveis": "contraprovar",
    "contrapunha": "contrapor",
    "contrapunham": "contrapor",
    "contrapunhas": "contrapor",
    "contrapunhos": "contrapunho",
    "contrapunçoa": "contrapunçoar",
    "contrapunçoada": "contrapunçoar",
    "contrapunçoadas": "contrapunçoar",
    "contrapunçoado": "contrapunçoar",
    "contrapunçoados": "contrapunçoar",
    "contrapunçoai": "contrapunçoar",
    "contrapunçoais": "contrapunçoar",
    "contrapunçoam": "contrapunçoar",
    "contrapunçoamo": "contrapunçoar",
    "contrapunçoamos": "contrapunçoar",
    "contrapunçoando": "contrapunçoar",
    "contrapunçoara": "contrapunçoar",
    "contrapunçoaram": "contrapunçoar",
    "contrapunçoaras": "contrapunçoar",
    "contrapunçoarde": "contrapunçoar",
    "contrapunçoardes": "contrapunçoar",
    "contrapunçoare": "contrapunçoar",
    "contrapunçoarei": "contrapunçoar",
    "contrapunçoareis": "contrapunçoar",
    "contrapunçoarem": "contrapunçoar",
    "contrapunçoaremos": "contrapunçoar",
    "contrapunçoares": "contrapunçoar",
    "contrapunçoaria": "contrapunçoar",
    "contrapunçoariam": "contrapunçoar",
    "contrapunçoarias": "contrapunçoar",
    "contrapunçoarmo": "contrapunçoar",
    "contrapunçoarmos": "contrapunçoar",
    "contrapunçoará": "contrapunçoar",
    "contrapunçoarás": "contrapunçoar",
    "contrapunçoarão": "contrapunçoar",
    "contrapunçoaríamos": "contrapunçoar",
    "contrapunçoaríeis": "contrapunçoar",
    "contrapunçoas": "contrapunçoar",
    "contrapunçoasse": "contrapunçoar",
    "contrapunçoassem": "contrapunçoar",
    "contrapunçoasses": "contrapunçoar",
    "contrapunçoaste": "contrapunçoar",
    "contrapunçoastes": "contrapunçoar",
    "contrapunçoava": "contrapunçoar",
    "contrapunçoavam": "contrapunçoar",
    "contrapunçoavas": "contrapunçoar",
    "contrapunçoe": "contrapunçoar",
    "contrapunçoei": "contrapunçoar",
    "contrapunçoeis": "contrapunçoar",
    "contrapunçoem": "contrapunçoar",
    "contrapunçoemo": "contrapunçoar",
    "contrapunçoemos": "contrapunçoar",
    "contrapunçoes": "contrapunçoar",
    "contrapunçoo": "contrapunçoar",
    "contrapunçoou": "contrapunçoar",
    "contrapunçoá": "contrapunçoar",
    "contrapunçoámo": "contrapunçoar",
    "contrapunçoámos": "contrapunçoar",
    "contrapunçoáramo": "contrapunçoar",
    "contrapunçoáramos": "contrapunçoar",
    "contrapunçoárei": "contrapunçoar",
    "contrapunçoáreis": "contrapunçoar",
    "contrapunçoásseis": "contrapunçoar",
    "contrapunçoássemos": "contrapunçoar",
    "contrapunçoávamo": "contrapunçoar",
    "contrapunçoávamos": "contrapunçoar",
    "contrapunçoávei": "contrapunçoar",
    "contrapunçoáveis": "contrapunçoar",
    "contrapus": "contrapor",
    "contrapusemo": "contrapor",
    "contrapusemos": "contrapor",
    "contrapuser": "contrapor",
    "contrapusera": "contrapor",
    "contrapuseram": "contrapor",
    "contrapuseras": "contrapor",
    "contrapuserdes": "contrapor",
    "contrapuserem": "contrapor",
    "contrapuseres": "contrapor",
    "contrapusermos": "contrapor",
    "contrapusesse": "contrapor",
    "contrapusessem": "contrapor",
    "contrapusesses": "contrapor",
    "contrapuseste": "contrapor",
    "contrapusestes": "contrapor",
    "contrapuséramo": "contrapor",
    "contrapuséramos": "contrapor",
    "contrapusérei": "contrapor",
    "contrapuséreis": "contrapor",
    "contrapusésseis": "contrapor",
    "contrapuséssemos": "contrapor",
    "contrapés": "contrapé",
    "contrapô": "contrapor",
    "contrapôs": "contrapor",
    "contrapõe": "contrapor",
    "contrapõem": "contrapor",
    "contrapões": "contrapor",
    "contrapúnhamo": "contrapor",
    "contrapúnhamos": "contrapor",
    "contrapúnhei": "contrapor",
    "contrapúnheis": "contrapor",
    "contraquarteada": "contraquarteado",
    "contraquarteadas": "contraquarteado",
    "contraquarteados": "contraquarteado",
    "contraquarteis": "contraquartel",
    "contraquilhas": "contraquilha",
    "contraria": "contrariar",
    "contrariada": "contrariar",
    "contrariadas": "contrariar",
    "contrariado": "contrariar",
    "contrariadora": "contrariador",
    "contrariadoras": "contrariador",
    "contrariadores": "contrariador",
    "contrariados": "contrariar",
    "contrariadíssima": "contrariado",
    "contrariadíssimas": "contrariado",
    "contrariadíssimo": "contrariado",
    "contrariadíssimos": "contrariado",
    "contrariai": "contrariar",
    "contrariais": "contrariar",
    "contrariam": "contrariar",
    "contrariamo": "contrariar",
    "contrariamos": "contrariar",
    "contrariando": "contrariar",
    "contrariantes": "contrariante",
    "contrariara": "contrariar",
    "contrariaram": "contrariar",
    "contrariaras": "contrariar",
    "contrariarde": "contrariar",
    "contrariardes": "contrariar",
    "contrariare": "contrariar",
    "contrariarei": "contrariar",
    "contrariareis": "contrariar",
    "contrariarem": "contrariar",
    "contrariaremos": "contrariar",
    "contrariares": "contrariar",
    "contrariaria": "contrariar",
    "contrariariam": "contrariar",
    "contrariarias": "contrariar",
    "contrariarmo": "contrariar",
    "contrariarmos": "contrariar",
    "contrariará": "contrariar",
    "contrariarás": "contrariar",
    "contrariarão": "contrariar",
    "contrariaríamos": "contrariar",
    "contrariaríeis": "contrariar",
    "contrarias": "contrariar",
    "contrariasse": "contrariar",
    "contrariassem": "contrariar",
    "contrariasses": "contrariar",
    "contrariaste": "contrariar",
    "contrariastes": "contrariar",
    "contrariava": "contrariar",
    "contrariavam": "contrariar",
    "contrariavas": "contrariar",
    "contrarie": "contrariar",
    "contrariedades": "contrariedade",
    "contrariei": "contrariar",
    "contrarieis": "contrariar",
    "contrariem": "contrariar",
    "contrariemo": "contrariar",
    "contrariemos": "contrariar",
    "contraries": "contrariar",
    "contrario": "contrariar",
    "contrariou": "contrariar",
    "contrariá": "contrariar",
    "contrariámo": "contrariar",
    "contrariámos": "contrariar",
    "contrariáramo": "contrariar",
    "contrariáramos": "contrariar",
    "contrariárei": "contrariar",
    "contrariáreis": "contrariar",
    "contrariásseis": "contrariar",
    "contrariássemos": "contrariar",
    "contrariávamo": "contrariar",
    "contrariávamos": "contrariar",
    "contrariávei": "contrariar",
    "contrariáveis": "contrariável",
    "contras": "contra",
    "contrasta": "contrastar",
    "contrastada": "contrastar",
    "contrastadas": "contrastar",
    "contrastado": "contrastar",
    "contrastadora": "contrastador",
    "contrastadoras": "contrastador",
    "contrastadores": "contrastador",
    "contrastados": "contrastar",
    "contrastai": "contrastar",
    "contrastais": "contrastar",
    "contrastam": "contrastar",
    "contrastamo": "contrastar",
    "contrastamos": "contrastar",
    "contrastando": "contrastar",
    "contrastantes": "contrastante",
    "contrastara": "contrastar",
    "contrastaram": "contrastar",
    "contrastaras": "contrastar",
    "contrastarde": "contrastar",
    "contrastardes": "contrastar",
    "contrastare": "contrastar",
    "contrastarei": "contrastar",
    "contrastareis": "contrastar",
    "contrastarem": "contrastar",
    "contrastaremos": "contrastar",
    "contrastares": "contrastar",
    "contrastaria": "contrastar",
    "contrastariam": "contrastar",
    "contrastarias": "contrastaria",
    "contrastarmo": "contrastar",
    "contrastarmos": "contrastar",
    "contrastará": "contrastar",
    "contrastarás": "contrastar",
    "contrastarão": "contrastar",
    "contrastaríamos": "contrastar",
    "contrastaríeis": "contrastar",
    "contrastas": "contrastar",
    "contrastasse": "contrastar",
    "contrastassem": "contrastar",
    "contrastasses": "contrastar",
    "contrastaste": "contrastar",
    "contrastastes": "contrastar",
    "contrastava": "contrastar",
    "contrastavam": "contrastar",
    "contrastavas": "contrastar",
    "contrastações": "contrastação",
    "contraste": "contrastar",
    "contrastei": "contrastar",
    "contrasteis": "contrastar",
    "contrastem": "contrastar",
    "contrastemo": "contrastar",
    "contrastemos": "contrastar",
    "contrastes": "contraste",
    "contrasto": "contrastar",
    "contrastou": "contrastar",
    "contrastá": "contrastar",
    "contrastámo": "contrastar",
    "contrastámos": "contrastar",
    "contrastáramo": "contrastar",
    "contrastáramos": "contrastar",
    "contrastárei": "contrastar",
    "contrastáreis": "contrastar",
    "contrastásseis": "contrastar",
    "contrastássemos": "contrastar",
    "contrastávamo": "contrastar",
    "contrastávamos": "contrastar",
    "contrastávei": "contrastar",
    "contrastáveis": "contrastável",
    "contrata": "contratar",
    "contratada": "contratar",
    "contratadas": "contratar",
    "contratadeira": "contratador",
    "contratadeiras": "contratador",
    "contratado": "contratar",
    "contratadora": "contratador",
    "contratadoras": "contratador",
    "contratadores": "contratador",
    "contratados": "contratar",
    "contratai": "contratar",
    "contratais": "contratar",
    "contratam": "contratar",
    "contratamo": "contratar",
    "contratamos": "contratar",
    "contratando": "contratar",
    "contratantes": "contratante",
    "contratara": "contratar",
    "contrataram": "contratar",
    "contrataras": "contratar",
    "contratarde": "contratar",
    "contratardes": "contratar",
    "contratare": "contratar",
    "contratarei": "contratar",
    "contratareis": "contratar",
    "contratarem": "contratar",
    "contrataremos": "contratar",
    "contratares": "contratar",
    "contrataria": "contratar",
    "contratariam": "contratar",
    "contratarias": "contratar",
    "contratarmo": "contratar",
    "contratarmos": "contratar",
    "contratará": "contratar",
    "contratarás": "contratar",
    "contratarão": "contratar",
    "contrataríamos": "contratar",
    "contrataríeis": "contratar",
    "contratas": "contratar",
    "contratasse": "contratar",
    "contratassem": "contratar",
    "contratasses": "contratar",
    "contrataste": "contratar",
    "contratastes": "contratar",
    "contratava": "contratar",
    "contratavam": "contratar",
    "contratavas": "contratar",
    "contratações": "contratação",
    "contrate": "contratar",
    "contrateada": "contratear",
    "contrateadas": "contratear",
    "contrateado": "contratear",
    "contrateados": "contratear",
    "contrateai": "contratear",
    "contrateais": "contratear",
    "contrateamo": "contratear",
    "contrateamos": "contratear",
    "contrateando": "contratear",
    "contrateara": "contratear",
    "contratearam": "contratear",
    "contratearas": "contratear",
    "contratearde": "contratear",
    "contrateardes": "contratear",
    "contrateare": "contratear",
    "contratearei": "contratear",
    "contrateareis": "contratear",
    "contratearem": "contratear",
    "contratearemos": "contratear",
    "contrateares": "contratear",
    "contratearia": "contratear",
    "contrateariam": "contratear",
    "contratearias": "contratear",
    "contratearmo": "contratear",
    "contratearmos": "contratear",
    "contrateará": "contratear",
    "contratearás": "contratear",
    "contratearão": "contratear",
    "contratearíamos": "contratear",
    "contratearíeis": "contratear",
    "contrateasse": "contratear",
    "contrateassem": "contratear",
    "contrateasses": "contratear",
    "contrateaste": "contratear",
    "contrateastes": "contratear",
    "contrateava": "contratear",
    "contrateavam": "contratear",
    "contrateavas": "contratear",
    "contrateei": "contratear",
    "contrateeis": "contratear",
    "contrateemo": "contratear",
    "contrateemos": "contratear",
    "contratei": "contratar",
    "contrateia": "contratear",
    "contrateiam": "contratear",
    "contrateias": "contratear",
    "contrateie": "contratear",
    "contrateiem": "contratear",
    "contrateies": "contratear",
    "contrateio": "contratear",
    "contrateis": "contratar",
    "contratela": "contratelar",
    "contratelada": "contratelar",
    "contrateladas": "contratelar",
    "contratelado": "contratelar",
    "contratelados": "contratelar",
    "contratelai": "contratelar",
    "contratelais": "contratelar",
    "contratelam": "contratelar",
    "contratelamo": "contratelar",
    "contratelamos": "contratelar",
    "contratelando": "contratelar",
    "contratelara": "contratelar",
    "contratelaram": "contratelar",
    "contratelaras": "contratelar",
    "contratelarde": "contratelar",
    "contratelardes": "contratelar",
    "contratelare": "contratelar",
    "contratelarei": "contratelar",
    "contratelareis": "contratelar",
    "contratelarem": "contratelar",
    "contratelaremos": "contratelar",
    "contratelares": "contratelar",
    "contratelaria": "contratelar",
    "contratelariam": "contratelar",
    "contratelarias": "contratelar",
    "contratelarmo": "contratelar",
    "contratelarmos": "contratelar",
    "contratelará": "contratelar",
    "contratelarás": "contratelar",
    "contratelarão": "contratelar",
    "contratelaríamos": "contratelar",
    "contratelaríeis": "contratelar",
    "contratelas": "contratelar",
    "contratelasse": "contratelar",
    "contratelassem": "contratelar",
    "contratelasses": "contratelar",
    "contratelaste": "contratelar",
    "contratelastes": "contratelar",
    "contratelava": "contratelar",
    "contratelavam": "contratelar",
    "contratelavas": "contratelar",
    "contratele": "contratelar",
    "contratelei": "contratelar",
    "contrateleis": "contratelar",
    "contratelem": "contratelar",
    "contratelemo": "contratelar",
    "contratelemos": "contratelar",
    "contrateles": "contratelar",
    "contratelo": "contratelar",
    "contratelou": "contratelar",
    "contratelá": "contratelar",
    "contratelámo": "contratelar",
    "contratelámos": "contratelar",
    "contrateláramo": "contratelar",
    "contrateláramos": "contratelar",
    "contratelárei": "contratelar",
    "contrateláreis": "contratelar",
    "contratelásseis": "contratelar",
    "contratelássemos": "contratelar",
    "contratelávamo": "contratelar",
    "contratelávamos": "contratelar",
    "contratelávei": "contratelar",
    "contrateláveis": "contratelar",
    "contratem": "contratar",
    "contratemo": "contratar",
    "contratemos": "contratar",
    "contratempos": "contratempo",
    "contrateou": "contratear",
    "contrates": "contratar",
    "contratestemunhas": "contratestemunha",
    "contratestemunhos": "contratestemunho",
    "contrateá": "contratear",
    "contrateámo": "contratear",
    "contrateámos": "contratear",
    "contrateáramo": "contratear",
    "contrateáramos": "contratear",
    "contrateárei": "contratear",
    "contrateáreis": "contratear",
    "contrateásseis": "contratear",
    "contrateássemos": "contratear",
    "contrateávamo": "contratear",
    "contrateávamos": "contratear",
    "contrateávei": "contratear",
    "contrateáveis": "contratear",
    "contratistas": "contratista",
    "contrato": "contratar",
    "contratorpedeiros": "contratorpedeiro",
    "contratos": "contrato",
    "contratou": "contratar",
    "contratrista": "contratristar",
    "contratristada": "contratristar",
    "contratristadas": "contratristar",
    "contratristado": "contratristar",
    "contratristados": "contratristar",
    "contratristai": "contratristar",
    "contratristais": "contratristar",
    "contratristam": "contratristar",
    "contratristamo": "contratristar",
    "contratristamos": "contratristar",
    "contratristando": "contratristar",
    "contratristara": "contratristar",
    "contratristaram": "contratristar",
    "contratristaras": "contratristar",
    "contratristarde": "contratristar",
    "contratristardes": "contratristar",
    "contratristare": "contratristar",
    "contratristarei": "contratristar",
    "contratristareis": "contratristar",
    "contratristarem": "contratristar",
    "contratristaremos": "contratristar",
    "contratristares": "contratristar",
    "contratristaria": "contratristar",
    "contratristariam": "contratristar",
    "contratristarias": "contratristar",
    "contratristarmo": "contratristar",
    "contratristarmos": "contratristar",
    "contratristará": "contratristar",
    "contratristarás": "contratristar",
    "contratristarão": "contratristar",
    "contratristaríamos": "contratristar",
    "contratristaríeis": "contratristar",
    "contratristas": "contratristar",
    "contratristasse": "contratristar",
    "contratristassem": "contratristar",
    "contratristasses": "contratristar",
    "contratristaste": "contratristar",
    "contratristastes": "contratristar",
    "contratristava": "contratristar",
    "contratristavam": "contratristar",
    "contratristavas": "contratristar",
    "contratriste": "contratristar",
    "contratristei": "contratristar",
    "contratristeis": "contratristar",
    "contratristem": "contratristar",
    "contratristemo": "contratristar",
    "contratristemos": "contratristar",
    "contratristes": "contratristar",
    "contratristo": "contratristar",
    "contratristou": "contratristar",
    "contratristá": "contratristar",
    "contratristámo": "contratristar",
    "contratristámos": "contratristar",
    "contratristáramo": "contratristar",
    "contratristáramos": "contratristar",
    "contratristárei": "contratristar",
    "contratristáreis": "contratristar",
    "contratristásseis": "contratristar",
    "contratristássemos": "contratristar",
    "contratristávamo": "contratristar",
    "contratristávamos": "contratristar",
    "contratristávei": "contratristar",
    "contratristáveis": "contratristar",
    "contratuais": "contratual",
    "contratá": "contratar",
    "contratámo": "contratar",
    "contratámos": "contratar",
    "contratáramo": "contratar",
    "contratáramos": "contratar",
    "contratárei": "contratar",
    "contratáreis": "contratar",
    "contratásseis": "contratar",
    "contratássemos": "contratar",
    "contratávamo": "contratar",
    "contratávamos": "contratar",
    "contratávei": "contratar",
    "contratáveis": "contratável",
    "contravala": "contravalar",
    "contravalada": "contravalar",
    "contravaladas": "contravalar",
    "contravalado": "contravalar",
    "contravalados": "contravalar",
    "contravalai": "contravalar",
    "contravalais": "contravalar",
    "contravalam": "contravalar",
    "contravalamo": "contravalar",
    "contravalamos": "contravalar",
    "contravalando": "contravalar",
    "contravalara": "contravalar",
    "contravalaram": "contravalar",
    "contravalaras": "contravalar",
    "contravalarde": "contravalar",
    "contravalardes": "contravalar",
    "contravalare": "contravalar",
    "contravalarei": "contravalar",
    "contravalareis": "contravalar",
    "contravalarem": "contravalar",
    "contravalaremos": "contravalar",
    "contravalares": "contravalar",
    "contravalaria": "contravalar",
    "contravalariam": "contravalar",
    "contravalarias": "contravalar",
    "contravalarmo": "contravalar",
    "contravalarmos": "contravalar",
    "contravalará": "contravalar",
    "contravalarás": "contravalar",
    "contravalarão": "contravalar",
    "contravalaríamos": "contravalar",
    "contravalaríeis": "contravalar",
    "contravalas": "contravalar",
    "contravalasse": "contravalar",
    "contravalassem": "contravalar",
    "contravalasses": "contravalar",
    "contravalaste": "contravalar",
    "contravalastes": "contravalar",
    "contravalava": "contravalar",
    "contravalavam": "contravalar",
    "contravalavas": "contravalar",
    "contravalações": "contravalação",
    "contravale": "contravalar",
    "contravalei": "contravalar",
    "contravaleis": "contravalar",
    "contravalem": "contravalar",
    "contravalemo": "contravalar",
    "contravalemos": "contravalar",
    "contravales": "contravalar",
    "contravalo": "contravalar",
    "contravalou": "contravalar",
    "contravalá": "contravalar",
    "contravalámo": "contravalar",
    "contravalámos": "contravalar",
    "contravaláramo": "contravalar",
    "contravaláramos": "contravalar",
    "contravalárei": "contravalar",
    "contravaláreis": "contravalar",
    "contravalásseis": "contravalar",
    "contravalássemos": "contravalar",
    "contravalávamo": "contravalar",
    "contravalávamos": "contravalar",
    "contravalávei": "contravalar",
    "contravaláveis": "contravalar",
    "contravapores": "contravapor",
    "contraveio": "contravir",
    "contraveira": "contraveirar",
    "contraveirada": "contraveirar",
    "contraveiradas": "contraveirar",
    "contraveirado": "contraveirar",
    "contraveirados": "contraveirar",
    "contraveirai": "contraveirar",
    "contraveirais": "contraveirar",
    "contraveiram": "contraveirar",
    "contraveiramo": "contraveirar",
    "contraveiramos": "contraveirar",
    "contraveirando": "contraveirar",
    "contraveirara": "contraveirar",
    "contraveiraram": "contraveirar",
    "contraveiraras": "contraveirar",
    "contraveirarde": "contraveirar",
    "contraveirardes": "contraveirar",
    "contraveirare": "contraveirar",
    "contraveirarei": "contraveirar",
    "contraveirareis": "contraveirar",
    "contraveirarem": "contraveirar",
    "contraveiraremos": "contraveirar",
    "contraveirares": "contraveirar",
    "contraveiraria": "contraveirar",
    "contraveirariam": "contraveirar",
    "contraveirarias": "contraveirar",
    "contraveirarmo": "contraveirar",
    "contraveirarmos": "contraveirar",
    "contraveirará": "contraveirar",
    "contraveirarás": "contraveirar",
    "contraveirarão": "contraveirar",
    "contraveiraríamos": "contraveirar",
    "contraveiraríeis": "contraveirar",
    "contraveiras": "contraveirar",
    "contraveirasse": "contraveirar",
    "contraveirassem": "contraveirar",
    "contraveirasses": "contraveirar",
    "contraveiraste": "contraveirar",
    "contraveirastes": "contraveirar",
    "contraveirava": "contraveirar",
    "contraveiravam": "contraveirar",
    "contraveiravas": "contraveirar",
    "contraveire": "contraveirar",
    "contraveirei": "contraveirar",
    "contraveireis": "contraveirar",
    "contraveirem": "contraveirar",
    "contraveiremo": "contraveirar",
    "contraveiremos": "contraveirar",
    "contraveires": "contraveirar",
    "contraveiro": "contraveirar",
    "contraveirou": "contraveirar",
    "contraveirá": "contraveirar",
    "contraveirámo": "contraveirar",
    "contraveirámos": "contraveirar",
    "contraveiráramo": "contraveirar",
    "contraveiráramos": "contraveirar",
    "contraveirárei": "contraveirar",
    "contraveiráreis": "contraveirar",
    "contraveirásseis": "contraveirar",
    "contraveirássemos": "contraveirar",
    "contraveirávamo": "contraveirar",
    "contraveirávamos": "contraveirar",
    "contraveirávei": "contraveirar",
    "contraveiráveis": "contraveirar",
    "contravem": "contravir",
    "contravenenos": "contraveneno",
    "contravenha": "contravir",
    "contravenhais": "contravir",
    "contravenham": "contravir",
    "contravenhamo": "contravir",
    "contravenhamos": "contravir",
    "contravenhas": "contravir",
    "contravenho": "contravir",
    "contraventora": "contraventor",
    "contraventoras": "contraventor",
    "contraventores": "contraventor",
    "contraventos": "contravento",
    "contravenções": "contravenção",
    "contraverdades": "contraverdade",
    "contraversões": "contraversão",
    "contraverta": "contraverter",
    "contravertais": "contraverter",
    "contravertam": "contraverter",
    "contravertamo": "contraverter",
    "contravertamos": "contraverter",
    "contravertas": "contraverter",
    "contraverte": "contraverter",
    "contravertei": "contraverter",
    "contraverteis": "contraverter",
    "contravertem": "contraverter",
    "contravertemo": "contraverter",
    "contravertemos": "contraverter",
    "contravertendo": "contraverter",
    "contravertera": "contraverter",
    "contraverteram": "contraverter",
    "contraverteras": "contraverter",
    "contraverterde": "contraverter",
    "contraverterdes": "contraverter",
    "contravertere": "contraverter",
    "contraverterei": "contraverter",
    "contravertereis": "contraverter",
    "contraverterem": "contraverter",
    "contraverteremos": "contraverter",
    "contraverteres": "contraverter",
    "contraverteria": "contraverter",
    "contraverteriam": "contraverter",
    "contraverterias": "contraverter",
    "contravertermo": "contraverter",
    "contravertermos": "contraverter",
    "contraverterá": "contraverter",
    "contraverterás": "contraverter",
    "contraverterão": "contraverter",
    "contraverteríamos": "contraverter",
    "contraverteríeis": "contraverter",
    "contravertes": "contraverter",
    "contravertesse": "contraverter",
    "contravertessem": "contraverter",
    "contravertesses": "contraverter",
    "contraverteste": "contraverter",
    "contravertestes": "contraverter",
    "contraverteu": "contraverter",
    "contraverti": "contraverter",
    "contravertia": "contraverter",
    "contravertiam": "contraverter",
    "contravertias": "contraverter",
    "contravertida": "contraverter",
    "contravertidas": "contraverter",
    "contravertido": "contraverter",
    "contravertidos": "contraverter",
    "contraverto": "contraverter",
    "contravertê": "contraverter",
    "contravertêramo": "contraverter",
    "contravertêramos": "contraverter",
    "contravertêrei": "contraverter",
    "contravertêreis": "contraverter",
    "contravertêsseis": "contraverter",
    "contravertêssemos": "contraverter",
    "contravertíamo": "contraverter",
    "contravertíamos": "contraverter",
    "contravertíei": "contraverter",
    "contravertíeis": "contraverter",
    "contraviemo": "contravir",
    "contraviemos": "contravir",
    "contravier": "contravir",
    "contraviera": "contravir",
    "contravieram": "contravir",
    "contravieras": "contravir",
    "contravierdes": "contravir",
    "contravierem": "contravir",
    "contravieres": "contravir",
    "contraviermos": "contravir",
    "contraviesse": "contravir",
    "contraviessem": "contravir",
    "contraviesses": "contravir",
    "contravieste": "contravir",
    "contraviestes": "contravir",
    "contravim": "contravir",
    "contravimo": "contravir",
    "contravimos": "contravir",
    "contravinda": "contravir",
    "contravindas": "contravir",
    "contravinde": "contravir",
    "contravindes": "contravir",
    "contravindo": "contravir",
    "contravindos": "contravir",
    "contravinha": "contravir",
    "contravinham": "contravir",
    "contravinhas": "contravir",
    "contravirdes": "contravir",
    "contravirei": "contravir",
    "contravireis": "contravir",
    "contravirem": "contravir",
    "contraviremos": "contravir",
    "contravires": "contravir",
    "contraviria": "contravir",
    "contraviriam": "contravir",
    "contravirias": "contravir",
    "contravirmo": "contravir",
    "contravirmos": "contravir",
    "contravirá": "contravir",
    "contravirás": "contravir",
    "contravirão": "contravir",
    "contraviríamos": "contravir",
    "contraviríeis": "contravir",
    "contraviéramo": "contravir",
    "contraviéramos": "contravir",
    "contraviéreis": "contravir",
    "contraviésseis": "contravir",
    "contraviéssemos": "contravir",
    "contravoltas": "contravolta",
    "contravém": "contravir",
    "contravéns": "contravir",
    "contravêm": "contravir",
    "contravínhamo": "contravir",
    "contravínhamos": "contravir",
    "contravínheis": "contravir",
    "contraí": "contrair",
    "contraía": "contrair",
    "contraíam": "contrair",
    "contraíamo": "contrair",
    "contraíamos": "contrair",
    "contraías": "contrair",
    "contraída": "contrair",
    "contraídas": "contrair",
    "contraído": "contrair",
    "contraídos": "contrair",
    "contraíei": "contrair",
    "contraíeis": "contrair",
    "contraímo": "contrair",
    "contraímos": "contrair",
    "contraíra": "contrair",
    "contraíram": "contrair",
    "contraíramo": "contrair",
    "contraíramos": "contrair",
    "contraíras": "contrair",
    "contraíre": "contrair",
    "contraírei": "contrair",
    "contraíreis": "contrair",
    "contraírem": "contrair",
    "contraíres": "contrair",
    "contraís": "contrair",
    "contraísse": "contrair",
    "contraísseis": "contrair",
    "contraíssem": "contrair",
    "contraíssemos": "contrair",
    "contraísses": "contrair",
    "contraíste": "contrair",
    "contraístes": "contrair",
    "contraíveis": "contraível",
    "contrectações": "contrectação",
    "contribua": "contribuir",
    "contribuais": "contribuir",
    "contribuam": "contribuir",
    "contribuamo": "contribuir",
    "contribuamos": "contribuir",
    "contribuas": "contribuir",
    "contribuem": "contribuir",
    "contribui": "contribuir",
    "contribuidora": "contribuidor",
    "contribuidoras": "contribuidor",
    "contribuidores": "contribuidor",
    "contribuindo": "contribuir",
    "contribuintes": "contribuinte",
    "contribuirde": "contribuir",
    "contribuirdes": "contribuir",
    "contribuirei": "contribuir",
    "contribuireis": "contribuir",
    "contribuiremos": "contribuir",
    "contribuiria": "contribuir",
    "contribuiriam": "contribuir",
    "contribuirias": "contribuir",
    "contribuirmo": "contribuir",
    "contribuirmos": "contribuir",
    "contribuirá": "contribuir",
    "contribuirás": "contribuir",
    "contribuirão": "contribuir",
    "contribuiríamos": "contribuir",
    "contribuiríeis": "contribuir",
    "contribuis": "contribuir",
    "contribuiu": "contribuir",
    "contribuições": "contribuição",
    "contribuo": "contribuir",
    "contributiva": "contributivo",
    "contributivas": "contributivo",
    "contributivos": "contributivo",
    "contributos": "contributo",
    "contributária": "contributário",
    "contributárias": "contributário",
    "contributários": "contributário",
    "contribuária": "contribuário",
    "contribuárias": "contribuário",
    "contribuários": "contribuário",
    "contribuí": "contribuir",
    "contribuía": "contribuir",
    "contribuíam": "contribuir",
    "contribuíamo": "contribuir",
    "contribuíamos": "contribuir",
    "contribuías": "contribuir",
    "contribuída": "contribuir",
    "contribuídas": "contribuir",
    "contribuído": "contribuir",
    "contribuídos": "contribuir",
    "contribuíei": "contribuir",
    "contribuíeis": "contribuir",
    "contribuímo": "contribuir",
    "contribuímos": "contribuir",
    "contribuíra": "contribuir",
    "contribuíram": "contribuir",
    "contribuíramo": "contribuir",
    "contribuíramos": "contribuir",
    "contribuíras": "contribuir",
    "contribuíre": "contribuir",
    "contribuírei": "contribuir",
    "contribuíreis": "contribuir",
    "contribuírem": "contribuir",
    "contribuíres": "contribuir",
    "contribuís": "contribuir",
    "contribuísse": "contribuir",
    "contribuísseis": "contribuir",
    "contribuíssem": "contribuir",
    "contribuíssemos": "contribuir",
    "contribuísses": "contribuir",
    "contribuíste": "contribuir",
    "contribuístes": "contribuir",
    "contristada": "contristado",
    "contristadas": "contristado",
    "contristadora": "contristador",
    "contristadoras": "contristador",
    "contristadores": "contristador",
    "contristados": "contristado",
    "contristações": "contristação",
    "contrita": "contrito",
    "contritas": "contrito",
    "contritos": "contrito",
    "contrições": "contrição",
    "controla": "controlar",
    "controlada": "controlar",
    "controladas": "controlar",
    "controlado": "controlar",
    "controladora": "controlador",
    "controladoras": "controlador",
    "controladores": "controlador",
    "controlados": "controlar",
    "controladíssima": "controlado",
    "controladíssimas": "controlado",
    "controladíssimo": "controlado",
    "controladíssimos": "controlado",
    "controlai": "controlar",
    "controlais": "controlar",
    "controlam": "controlar",
    "controlamo": "controlar",
    "controlamos": "controlar",
    "controlando": "controlar",
    "controlara": "controlar",
    "controlaram": "controlar",
    "controlaras": "controlar",
    "controlarde": "controlar",
    "controlardes": "controlar",
    "controlare": "controlar",
    "controlarei": "controlar",
    "controlareis": "controlar",
    "controlarem": "controlar",
    "controlaremos": "controlar",
    "controlares": "controlar",
    "controlaria": "controlar",
    "controlariam": "controlar",
    "controlarias": "controlar",
    "controlarmo": "controlar",
    "controlarmos": "controlar",
    "controlará": "controlar",
    "controlarás": "controlar",
    "controlarão": "controlar",
    "controlaríamos": "controlar",
    "controlaríeis": "controlar",
    "controlas": "controlar",
    "controlasse": "controlar",
    "controlassem": "controlar",
    "controlasses": "controlar",
    "controlaste": "controlar",
    "controlastes": "controlar",
    "controlava": "controlar",
    "controlavam": "controlar",
    "controlavas": "controlar",
    "controle": "controlo",
    "controlei": "controlar",
    "controleis": "controlar",
    "controlem": "controlar",
    "controlemo": "controlar",
    "controlemos": "controlar",
    "controles": "controlo",
    "controlo": "controlar",
    "controlos": "controlo",
    "controlou": "controlar",
    "controlá": "controlar",
    "controlámo": "controlar",
    "controlámos": "controlar",
    "controláramo": "controlar",
    "controláramos": "controlar",
    "controlárei": "controlar",
    "controláreis": "controlar",
    "controlásseis": "controlar",
    "controlássemos": "controlar",
    "controlávamo": "controlar",
    "controlávamos": "controlar",
    "controlávei": "controlar",
    "controláveis": "controlável",
    "controversa": "controverso",
    "controversas": "controverso",
    "controversistas": "controversista",
    "controversos": "controverso",
    "controverta": "controverter",
    "controvertais": "controverter",
    "controvertam": "controverter",
    "controvertamo": "controverter",
    "controvertamos": "controverter",
    "controvertas": "controverter",
    "controverte": "controverter",
    "controvertei": "controverter",
    "controverteis": "controverter",
    "controvertem": "controverter",
    "controvertemo": "controverter",
    "controvertemos": "controverter",
    "controvertendo": "controverter",
    "controvertera": "controverter",
    "controverteram": "controverter",
    "controverteras": "controverter",
    "controverterde": "controverter",
    "controverterdes": "controverter",
    "controvertere": "controverter",
    "controverterei": "controverter",
    "controvertereis": "controverter",
    "controverterem": "controverter",
    "controverteremos": "controverter",
    "controverteres": "controverter",
    "controverteria": "controverter",
    "controverteriam": "controverter",
    "controverterias": "controverter",
    "controvertermo": "controverter",
    "controvertermos": "controverter",
    "controverterá": "controverter",
    "controverterás": "controverter",
    "controverterão": "controverter",
    "controverteríamos": "controverter",
    "controverteríeis": "controverter",
    "controvertes": "controverter",
    "controvertesse": "controverter",
    "controvertessem": "controverter",
    "controvertesses": "controverter",
    "controverteste": "controverter",
    "controvertestes": "controverter",
    "controverteu": "controverter",
    "controverti": "controverter",
    "controvertia": "controverter",
    "controvertiam": "controverter",
    "controvertias": "controverter",
    "controvertida": "controverter",
    "controvertidas": "controverter",
    "controvertido": "controverter",
    "controvertidos": "controverter",
    "controverto": "controverter",
    "controvertê": "controverter",
    "controvertêramo": "controverter",
    "controvertêramos": "controverter",
    "controvertêrei": "controverter",
    "controvertêreis": "controverter",
    "controvertêsseis": "controverter",
    "controvertêssemos": "controverter",
    "controvertíamo": "controverter",
    "controvertíamos": "controverter",
    "controvertíei": "controverter",
    "controvertíeis": "controverter",
    "controvertíveis": "controvertível",
    "controvérsias": "controvérsia",
    "contrácteis": "contráctil",
    "contrária": "contrário",
    "contrárias": "contrário",
    "contrários": "contrário",
    "contuberna": "contubernar",
    "contubernada": "contubernar",
    "contubernadas": "contubernar",
    "contubernado": "contubernar",
    "contubernados": "contubernar",
    "contubernai": "contubernar",
    "contubernais": "contubernar",
    "contubernam": "contubernar",
    "contubernamo": "contubernar",
    "contubernamos": "contubernar",
    "contubernando": "contubernar",
    "contubernara": "contubernar",
    "contubernaram": "contubernar",
    "contubernaras": "contubernar",
    "contubernarde": "contubernar",
    "contubernardes": "contubernar",
    "contubernare": "contubernar",
    "contubernarei": "contubernar",
    "contubernareis": "contubernar",
    "contubernarem": "contubernar",
    "contubernaremos": "contubernar",
    "contubernares": "contubernar",
    "contubernaria": "contubernar",
    "contubernariam": "contubernar",
    "contubernarias": "contubernar",
    "contubernarmo": "contubernar",
    "contubernarmos": "contubernar",
    "contubernará": "contubernar",
    "contubernarás": "contubernar",
    "contubernarão": "contubernar",
    "contubernaríamos": "contubernar",
    "contubernaríeis": "contubernar",
    "contubernas": "contubernar",
    "contubernasse": "contubernar",
    "contubernassem": "contubernar",
    "contubernasses": "contubernar",
    "contubernaste": "contubernar",
    "contubernastes": "contubernar",
    "contubernava": "contubernar",
    "contubernavam": "contubernar",
    "contubernavas": "contubernar",
    "contuberne": "contubernar",
    "contubernei": "contubernar",
    "contuberneis": "contubernar",
    "contubernem": "contubernar",
    "contubernemo": "contubernar",
    "contubernemos": "contubernar",
    "contubernes": "contubernar",
    "contuberno": "contubernar",
    "contubernou": "contubernar",
    "contuberná": "contubernar",
    "contubernámo": "contubernar",
    "contubernámos": "contubernar",
    "contubernáramo": "contubernar",
    "contubernáramos": "contubernar",
    "contubernárei": "contubernar",
    "contubernáreis": "contubernar",
    "contubernásseis": "contubernar",
    "contubernássemos": "contubernar",
    "contubernávamo": "contubernar",
    "contubernávamos": "contubernar",
    "contubernávei": "contubernar",
    "contubernáveis": "contubernar",
    "contubérnios": "contubérnio",
    "contumeliosa": "contumelioso",
    "contumeliosas": "contumelioso",
    "contumeliosos": "contumelioso",
    "contumácias": "contumácia",
    "contumélias": "contumélia",
    "contunda": "contundir",
    "contundais": "contundir",
    "contundam": "contundir",
    "contundamo": "contundir",
    "contundamos": "contundir",
    "contundas": "contundir",
    "contunde": "contundir",
    "contundem": "contundir",
    "contundentes": "contundente",
    "contundes": "contundir",
    "contundi": "contundir",
    "contundia": "contundir",
    "contundiam": "contundir",
    "contundias": "contundir",
    "contundida": "contundir",
    "contundidas": "contundir",
    "contundido": "contundir",
    "contundidos": "contundir",
    "contundimo": "contundir",
    "contundimos": "contundir",
    "contundindo": "contundir",
    "contundira": "contundir",
    "contundiram": "contundir",
    "contundiras": "contundir",
    "contundirde": "contundir",
    "contundirdes": "contundir",
    "contundire": "contundir",
    "contundirei": "contundir",
    "contundireis": "contundir",
    "contundirem": "contundir",
    "contundiremos": "contundir",
    "contundires": "contundir",
    "contundiria": "contundir",
    "contundiriam": "contundir",
    "contundirias": "contundir",
    "contundirmo": "contundir",
    "contundirmos": "contundir",
    "contundirá": "contundir",
    "contundirás": "contundir",
    "contundirão": "contundir",
    "contundiríamos": "contundir",
    "contundiríeis": "contundir",
    "contundis": "contundir",
    "contundisse": "contundir",
    "contundissem": "contundir",
    "contundisses": "contundir",
    "contundiste": "contundir",
    "contundistes": "contundir",
    "contundiu": "contundir",
    "contundo": "contundir",
    "contundências": "contundência",
    "contundíamo": "contundir",
    "contundíamos": "contundir",
    "contundíei": "contundir",
    "contundíeis": "contundir",
    "contundíramo": "contundir",
    "contundíramos": "contundir",
    "contundírei": "contundir",
    "contundíreis": "contundir",
    "contundísseis": "contundir",
    "contundíssemos": "contundir",
    "conturba": "conturbar",
    "conturbada": "conturbar",
    "conturbadas": "conturbar",
    "conturbado": "conturbar",
    "conturbadora": "conturbador",
    "conturbadoras": "conturbador",
    "conturbadores": "conturbador",
    "conturbados": "conturbar",
    "conturbai": "conturbar",
    "conturbais": "conturbar",
    "conturbam": "conturbar",
    "conturbamo": "conturbar",
    "conturbamos": "conturbar",
    "conturbando": "conturbar",
    "conturbara": "conturbar",
    "conturbaram": "conturbar",
    "conturbaras": "conturbar",
    "conturbarde": "conturbar",
    "conturbardes": "conturbar",
    "conturbare": "conturbar",
    "conturbarei": "conturbar",
    "conturbareis": "conturbar",
    "conturbarem": "conturbar",
    "conturbaremos": "conturbar",
    "conturbares": "conturbar",
    "conturbaria": "conturbar",
    "conturbariam": "conturbar",
    "conturbarias": "conturbar",
    "conturbarmo": "conturbar",
    "conturbarmos": "conturbar",
    "conturbará": "conturbar",
    "conturbarás": "conturbar",
    "conturbarão": "conturbar",
    "conturbaríamos": "conturbar",
    "conturbaríeis": "conturbar",
    "conturbas": "conturbar",
    "conturbasse": "conturbar",
    "conturbassem": "conturbar",
    "conturbasses": "conturbar",
    "conturbaste": "conturbar",
    "conturbastes": "conturbar",
    "conturbativa": "conturbativo",
    "conturbativas": "conturbativo",
    "conturbativos": "conturbativo",
    "conturbava": "conturbar",
    "conturbavam": "conturbar",
    "conturbavas": "conturbar",
    "conturbações": "conturbação",
    "conturbe": "conturbar",
    "conturbei": "conturbar",
    "conturbeis": "conturbar",
    "conturbem": "conturbar",
    "conturbemo": "conturbar",
    "conturbemos": "conturbar",
    "conturbes": "conturbar",
    "conturbo": "conturbar",
    "conturbou": "conturbar",
    "conturbá": "conturbar",
    "conturbámo": "conturbar",
    "conturbámos": "conturbar",
    "conturbáramo": "conturbar",
    "conturbáramos": "conturbar",
    "conturbárei": "conturbar",
    "conturbáreis": "conturbar",
    "conturbásseis": "conturbar",
    "conturbássemos": "conturbar",
    "conturbávamo": "conturbar",
    "conturbávamos": "conturbar",
    "conturbávei": "conturbar",
    "conturbáveis": "conturbar",
    "contusa": "contuso",
    "contusas": "contuso",
    "contusos": "contuso",
    "contusões": "contusão",
    "contá": "contar",
    "contágios": "contágio",
    "contámo": "contar",
    "contámos": "contar",
    "contáramo": "contar",
    "contáramos": "contar",
    "contárei": "contar",
    "contáreis": "contar",
    "contásseis": "contar",
    "contássemos": "contar",
    "contávamo": "contar",
    "contávamos": "contar",
    "contávei": "contar",
    "contáveis": "contável",
    "contém": "conter",
    "conténs": "conter",
    "contérmina": "contérmino",
    "contérminas": "contérmino",
    "contérminos": "contérmino",
    "contérrita": "contérrito",
    "contérritas": "contérrito",
    "contérritos": "contérrito",
    "contê": "conter",
    "contêm": "conter",
    "contígua": "contíguo",
    "contíguas": "contíguo",
    "contíguos": "contíguo",
    "contínhamo": "conter",
    "contínhamos": "conter",
    "contínhei": "conter",
    "contínheis": "conter",
    "contínua": "contínuo",
    "contínuas": "contínuo",
    "contínuos": "contínuo",
    "conubiais": "conubial",
    "conurbações": "conurbação",
    "convais": "conval",
    "convalarinas": "convalarina",
    "convalesce": "convalescer",
    "convalescei": "convalescer",
    "convalesceis": "convalescer",
    "convalescem": "convalescer",
    "convalescemo": "convalescer",
    "convalescemos": "convalescer",
    "convalescendo": "convalescer",
    "convalescentes": "convalescente",
    "convalescenças": "convalescença",
    "convalescera": "convalescer",
    "convalesceram": "convalescer",
    "convalesceras": "convalescer",
    "convalescerde": "convalescer",
    "convalescerdes": "convalescer",
    "convalescere": "convalescer",
    "convalescerei": "convalescer",
    "convalescereis": "convalescer",
    "convalescerem": "convalescer",
    "convalesceremos": "convalescer",
    "convalesceres": "convalescer",
    "convalesceria": "convalescer",
    "convalesceriam": "convalescer",
    "convalescerias": "convalescer",
    "convalescermo": "convalescer",
    "convalescermos": "convalescer",
    "convalescerá": "convalescer",
    "convalescerás": "convalescer",
    "convalescerão": "convalescer",
    "convalesceríamos": "convalescer",
    "convalesceríeis": "convalescer",
    "convalesces": "convalescer",
    "convalescesse": "convalescer",
    "convalescessem": "convalescer",
    "convalescesses": "convalescer",
    "convalesceste": "convalescer",
    "convalescestes": "convalescer",
    "convalesceu": "convalescer",
    "convalesci": "convalescer",
    "convalescia": "convalescer",
    "convalesciam": "convalescer",
    "convalescias": "convalescer",
    "convalescida": "convalescer",
    "convalescidas": "convalescer",
    "convalescido": "convalescer",
    "convalescidos": "convalescer",
    "convalescê": "convalescer",
    "convalescêramo": "convalescer",
    "convalescêramos": "convalescer",
    "convalescêrei": "convalescer",
    "convalescêreis": "convalescer",
    "convalescêsseis": "convalescer",
    "convalescêssemos": "convalescer",
    "convalescíamo": "convalescer",
    "convalescíamos": "convalescer",
    "convalescíei": "convalescer",
    "convalescíeis": "convalescer",
    "convalesça": "convalescer",
    "convalesçais": "convalescer",
    "convalesçam": "convalescer",
    "convalesçamo": "convalescer",
    "convalesçamos": "convalescer",
    "convalesças": "convalescer",
    "convalesço": "convalescer",
    "convalárias": "convalária",
    "convectores": "convector",
    "convecções": "convecção",
    "conveio": "convir",
    "convem": "convir",
    "convence": "convencer",
    "convencedora": "convencedor",
    "convencedoras": "convencedor",
    "convencedores": "convencedor",
    "convencei": "convencer",
    "convenceis": "convencer",
    "convencem": "convencer",
    "convencemo": "convencer",
    "convencemos": "convencer",
    "convencendo": "convencer",
    "convencera": "convencer",
    "convenceram": "convencer",
    "convenceras": "convencer",
    "convencerde": "convencer",
    "convencerdes": "convencer",
    "convencere": "convencer",
    "convencerei": "convencer",
    "convencereis": "convencer",
    "convencerem": "convencer",
    "convenceremos": "convencer",
    "convenceres": "convencer",
    "convenceria": "convencer",
    "convenceriam": "convencer",
    "convencerias": "convencer",
    "convencermo": "convencer",
    "convencermos": "convencer",
    "convencerá": "convencer",
    "convencerás": "convencer",
    "convencerão": "convencer",
    "convenceríamos": "convencer",
    "convenceríeis": "convencer",
    "convences": "convencer",
    "convencesse": "convencer",
    "convencessem": "convencer",
    "convencesses": "convencer",
    "convenceste": "convencer",
    "convencestes": "convencer",
    "convenceu": "convencer",
    "convenci": "convencer",
    "convencia": "convencer",
    "convenciam": "convencer",
    "convencias": "convencer",
    "convencida": "convencido",
    "convencidas": "convencido",
    "convencido": "convencer",
    "convencidos": "convencido",
    "convencidíssima": "convencido",
    "convencidíssimas": "convencido",
    "convencidíssimo": "convencido",
    "convencidíssimos": "convencido",
    "convencimentos": "convencimento",
    "convenciona": "convencionar",
    "convencionada": "convencionar",
    "convencionadas": "convencionar",
    "convencionado": "convencionar",
    "convencionados": "convencionar",
    "convencionai": "convencionar",
    "convencionais": "convencionar",
    "convencionalismos": "convencionalismo",
    "convencionalistas": "convencionalista",
    "convencionam": "convencionar",
    "convencionamo": "convencionar",
    "convencionamos": "convencionar",
    "convencionando": "convencionar",
    "convencionara": "convencionar",
    "convencionaram": "convencionar",
    "convencionaras": "convencionar",
    "convencionarde": "convencionar",
    "convencionardes": "convencionar",
    "convencionare": "convencionar",
    "convencionarei": "convencionar",
    "convencionareis": "convencionar",
    "convencionarem": "convencionar",
    "convencionaremos": "convencionar",
    "convencionares": "convencionar",
    "convencionaria": "convencionar",
    "convencionariam": "convencionar",
    "convencionarias": "convencionar",
    "convencionarmo": "convencionar",
    "convencionarmos": "convencionar",
    "convencionará": "convencionar",
    "convencionarás": "convencionar",
    "convencionarão": "convencionar",
    "convencionaríamos": "convencionar",
    "convencionaríeis": "convencionar",
    "convencionas": "convencionar",
    "convencionasse": "convencionar",
    "convencionassem": "convencionar",
    "convencionasses": "convencionar",
    "convencionaste": "convencionar",
    "convencionastes": "convencionar",
    "convencionava": "convencionar",
    "convencionavam": "convencionar",
    "convencionavas": "convencionar",
    "convencione": "convencionar",
    "convencionei": "convencionar",
    "convencioneis": "convencionar",
    "convencionem": "convencionar",
    "convencionemo": "convencionar",
    "convencionemos": "convencionar",
    "convenciones": "convencionar",
    "convenciono": "convencionar",
    "convencionou": "convencionar",
    "convencioná": "convencionar",
    "convencionámo": "convencionar",
    "convencionámos": "convencionar",
    "convencionáramo": "convencionar",
    "convencionáramos": "convencionar",
    "convencionárei": "convencionar",
    "convencionáreis": "convencionar",
    "convencionásseis": "convencionar",
    "convencionássemos": "convencionar",
    "convencionávamo": "convencionar",
    "convencionávamos": "convencionar",
    "convencionávei": "convencionar",
    "convencionáveis": "convencionar",
    "convencê": "convencer",
    "convencêramo": "convencer",
    "convencêramos": "convencer",
    "convencêrei": "convencer",
    "convencêreis": "convencer",
    "convencêsseis": "convencer",
    "convencêssemos": "convencer",
    "convencíamo": "convencer",
    "convencíamos": "convencer",
    "convencíei": "convencer",
    "convencíeis": "convencer",
    "convencíveis": "convencível",
    "convenha": "convir",
    "convenhais": "convir",
    "convenham": "convir",
    "convenhamo": "convir",
    "convenhamos": "convir",
    "convenhas": "convir",
    "convenho": "convir",
    "convenientes": "conveniente",
    "conveniências": "conveniência",
    "conventiculares": "conventicular",
    "conventos": "convento",
    "conventuais": "conventual",
    "conventualidades": "conventualidade",
    "conventículos": "conventículo",
    "convença": "convencer",
    "convençais": "convencer",
    "convençam": "convencer",
    "convençamo": "convencer",
    "convençamos": "convencer",
    "convenças": "convencer",
    "convenço": "convencer",
    "convenções": "convenção",
    "converge": "convergir",
    "convergem": "convergir",
    "convergentes": "convergente",
    "converges": "convergir",
    "convergi": "convergir",
    "convergia": "convergir",
    "convergiam": "convergir",
    "convergias": "convergir",
    "convergida": "convergir",
    "convergidas": "convergir",
    "convergido": "convergir",
    "convergidos": "convergir",
    "convergimo": "convergir",
    "convergimos": "convergir",
    "convergindo": "convergir",
    "convergira": "convergir",
    "convergiram": "convergir",
    "convergiras": "convergir",
    "convergirde": "convergir",
    "convergirdes": "convergir",
    "convergire": "convergir",
    "convergirei": "convergir",
    "convergireis": "convergir",
    "convergirem": "convergir",
    "convergiremos": "convergir",
    "convergires": "convergir",
    "convergiria": "convergir",
    "convergiriam": "convergir",
    "convergirias": "convergir",
    "convergirmo": "convergir",
    "convergirmos": "convergir",
    "convergirá": "convergir",
    "convergirás": "convergir",
    "convergirão": "convergir",
    "convergiríamos": "convergir",
    "convergiríeis": "convergir",
    "convergis": "convergir",
    "convergisse": "convergir",
    "convergissem": "convergir",
    "convergisses": "convergir",
    "convergiste": "convergir",
    "convergistes": "convergir",
    "convergiu": "convergir",
    "convergências": "convergência",
    "convergíamo": "convergir",
    "convergíamos": "convergir",
    "convergíei": "convergir",
    "convergíeis": "convergir",
    "convergíramo": "convergir",
    "convergíramos": "convergir",
    "convergírei": "convergir",
    "convergíreis": "convergir",
    "convergísseis": "convergir",
    "convergíssemos": "convergir",
    "conversa": "converso",
    "conversacionais": "conversacional",
    "conversada": "conversar",
    "conversadas": "conversar",
    "conversadeira": "conversador",
    "conversadeiras": "conversador",
    "conversadeiros": "conversadeiro",
    "conversado": "conversar",
    "conversadora": "conversador",
    "conversadoras": "conversador",
    "conversadores": "conversador",
    "conversados": "conversar",
    "conversai": "conversar",
    "conversais": "conversar",
    "conversam": "conversar",
    "conversamo": "conversar",
    "conversamos": "conversar",
    "conversando": "conversar",
    "conversara": "conversar",
    "conversaram": "conversar",
    "conversaras": "conversar",
    "conversarde": "conversar",
    "conversardes": "conversar",
    "conversare": "conversar",
    "conversarei": "conversar",
    "conversareis": "conversar",
    "conversarem": "conversar",
    "conversaremos": "conversar",
    "conversares": "conversar",
    "conversaria": "conversar",
    "conversariam": "conversar",
    "conversarias": "conversar",
    "conversarmo": "conversar",
    "conversarmos": "conversar",
    "conversará": "conversar",
    "conversarás": "conversar",
    "conversarão": "conversar",
    "conversaríamos": "conversar",
    "conversaríeis": "conversar",
    "conversas": "converso",
    "conversasse": "conversar",
    "conversassem": "conversar",
    "conversasses": "conversar",
    "conversaste": "conversar",
    "conversastes": "conversar",
    "conversava": "conversar",
    "conversavam": "conversar",
    "conversavas": "conversar",
    "conversações": "conversação",
    "converse": "conversar",
    "conversei": "conversar",
    "converseis": "conversar",
    "conversem": "conversar",
    "conversemo": "conversar",
    "conversemos": "conversar",
    "converses": "conversar",
    "conversibilidades": "conversibilidade",
    "conversiva": "conversivo",
    "conversivas": "conversivo",
    "conversivos": "conversivo",
    "converso": "conversar",
    "conversora": "conversor",
    "conversoras": "conversor",
    "conversores": "conversor",
    "conversos": "converso",
    "conversou": "conversar",
    "conversá": "conversar",
    "conversámo": "conversar",
    "conversámos": "conversar",
    "conversáramo": "conversar",
    "conversáramos": "conversar",
    "conversárei": "conversar",
    "conversáreis": "conversar",
    "conversásseis": "conversar",
    "conversássemos": "conversar",
    "conversávamo": "conversar",
    "conversávamos": "conversar",
    "conversávei": "conversar",
    "conversáveis": "conversável",
    "conversíveis": "conversível",
    "conversões": "conversão",
    "converta": "converter",
    "convertais": "converter",
    "convertam": "converter",
    "convertamo": "converter",
    "convertamos": "converter",
    "convertas": "converter",
    "converte": "converter",
    "convertedora": "convertedor",
    "convertedoras": "convertedor",
    "convertedores": "convertedor",
    "convertei": "converter",
    "converteis": "converter",
    "convertem": "converter",
    "convertemo": "converter",
    "convertemos": "converter",
    "convertendo": "converter",
    "convertera": "converter",
    "converteram": "converter",
    "converteras": "converter",
    "converterde": "converter",
    "converterdes": "converter",
    "convertere": "converter",
    "converterei": "converter",
    "convertereis": "converter",
    "converterem": "converter",
    "converteremos": "converter",
    "converteres": "converter",
    "converteria": "converter",
    "converteriam": "converter",
    "converterias": "converter",
    "convertermo": "converter",
    "convertermos": "converter",
    "converterá": "converter",
    "converterás": "converter",
    "converterão": "converter",
    "converteríamos": "converter",
    "converteríeis": "converter",
    "convertes": "converter",
    "convertesse": "converter",
    "convertessem": "converter",
    "convertesses": "converter",
    "converteste": "converter",
    "convertestes": "converter",
    "converteu": "converter",
    "converti": "converter",
    "convertia": "converter",
    "convertiam": "converter",
    "convertias": "converter",
    "convertibilidades": "convertibilidade",
    "convertida": "convertido",
    "convertidas": "convertido",
    "convertido": "converter",
    "convertidos": "convertido",
    "convertimentos": "convertimento",
    "converto": "converter",
    "convertê": "converter",
    "convertêramo": "converter",
    "convertêramos": "converter",
    "convertêrei": "converter",
    "convertêreis": "converter",
    "convertêsseis": "converter",
    "convertêssemos": "converter",
    "convertíamo": "converter",
    "convertíamos": "converter",
    "convertíei": "converter",
    "convertíeis": "converter",
    "convertíveis": "convertível",
    "conveses": "convés",
    "convexa": "convexo",
    "convexas": "convexo",
    "convexidades": "convexidade",
    "convexirrostra": "convexirrostro",
    "convexirrostras": "convexirrostro",
    "convexirrostros": "convexirrostro",
    "convexos": "convexo",
    "convi": "convir",
    "conviciosa": "convicioso",
    "conviciosas": "convicioso",
    "conviciosos": "convicioso",
    "convicta": "convicto",
    "convictas": "convicto",
    "convictos": "convicto",
    "convicções": "convicção",
    "convida": "convidar",
    "convidada": "convidar",
    "convidadas": "convidar",
    "convidado": "convidar",
    "convidadora": "convidador",
    "convidadoras": "convidador",
    "convidadores": "convidador",
    "convidados": "convidar",
    "convidai": "convidar",
    "convidais": "convidar",
    "convidam": "convidar",
    "convidamo": "convidar",
    "convidamos": "convidar",
    "convidando": "convidar",
    "convidantes": "convidante",
    "convidara": "convidar",
    "convidaram": "convidar",
    "convidaras": "convidar",
    "convidarde": "convidar",
    "convidardes": "convidar",
    "convidare": "convidar",
    "convidarei": "convidar",
    "convidareis": "convidar",
    "convidarem": "convidar",
    "convidaremos": "convidar",
    "convidares": "convidar",
    "convidaria": "convidar",
    "convidariam": "convidar",
    "convidarias": "convidar",
    "convidarmo": "convidar",
    "convidarmos": "convidar",
    "convidará": "convidar",
    "convidarás": "convidar",
    "convidarão": "convidar",
    "convidaríamos": "convidar",
    "convidaríeis": "convidar",
    "convidas": "convidar",
    "convidasse": "convidar",
    "convidassem": "convidar",
    "convidasses": "convidar",
    "convidaste": "convidar",
    "convidastes": "convidar",
    "convidativa": "convidativo",
    "convidativas": "convidativo",
    "convidativos": "convidativo",
    "convidava": "convidar",
    "convidavam": "convidar",
    "convidavas": "convidar",
    "convide": "convidar",
    "convidei": "convidar",
    "convideis": "convidar",
    "convidem": "convidar",
    "convidemo": "convidar",
    "convidemos": "convidar",
    "convides": "convidar",
    "convido": "convidar",
    "convidou": "convidar",
    "convidá": "convidar",
    "convidámo": "convidar",
    "convidámos": "convidar",
    "convidáramo": "convidar",
    "convidáramos": "convidar",
    "convidárei": "convidar",
    "convidáreis": "convidar",
    "convidásseis": "convidar",
    "convidássemos": "convidar",
    "convidávamo": "convidar",
    "convidávamos": "convidar",
    "convidávei": "convidar",
    "convidáveis": "convidar",
    "conviemo": "convir",
    "conviemos": "convir",
    "convier": "convir",
    "conviera": "convir",
    "convieram": "convir",
    "convieras": "convir",
    "convierdes": "convir",
    "convierem": "convir",
    "convieres": "convir",
    "conviermos": "convir",
    "conviesse": "convir",
    "conviessem": "convir",
    "conviesses": "convir",
    "convieste": "convir",
    "conviestes": "convir",
    "convim": "convir",
    "convimo": "convir",
    "convimos": "convir",
    "convincentes": "convincente",
    "convinda": "convir",
    "convindas": "convir",
    "convinde": "convir",
    "convindes": "convir",
    "convindo": "convir",
    "convindos": "convir",
    "convinha": "convir",
    "convinham": "convir",
    "convinhas": "convir",
    "convinháveis": "convinhável",
    "convirde": "convir",
    "convirdes": "convir",
    "convire": "convir",
    "convirei": "convir",
    "convireis": "convir",
    "convirem": "convir",
    "conviremos": "convir",
    "convires": "convir",
    "conviria": "convir",
    "conviriam": "convir",
    "convirias": "convir",
    "convirja": "convergir",
    "convirjais": "convergir",
    "convirjam": "convergir",
    "convirjamo": "convergir",
    "convirjamos": "convergir",
    "convirjas": "convergir",
    "convirjo": "convergir",
    "convirmo": "convir",
    "convirmos": "convir",
    "convirá": "convir",
    "convirás": "convir",
    "convirão": "convir",
    "conviríamos": "convir",
    "conviríeis": "convir",
    "convites": "convite",
    "conviva": "conviver",
    "convivais": "conviver",
    "convivam": "conviver",
    "convivamo": "conviver",
    "convivamos": "conviver",
    "convivas": "conviver",
    "convive": "conviver",
    "convivei": "conviver",
    "conviveis": "conviver",
    "convivem": "conviver",
    "convivemo": "conviver",
    "convivemos": "conviver",
    "convivendo": "conviver",
    "conviventes": "convivente",
    "convivera": "conviver",
    "conviveram": "conviver",
    "conviveras": "conviver",
    "conviverde": "conviver",
    "conviverdes": "conviver",
    "convivere": "conviver",
    "conviverei": "conviver",
    "convivereis": "conviver",
    "conviverem": "conviver",
    "conviveremos": "conviver",
    "conviveres": "conviver",
    "conviveria": "conviver",
    "conviveriam": "conviver",
    "conviverias": "conviver",
    "convivermo": "conviver",
    "convivermos": "conviver",
    "conviverá": "conviver",
    "conviverás": "conviver",
    "conviverão": "conviver",
    "conviveríamos": "conviver",
    "conviveríeis": "conviver",
    "convives": "conviver",
    "convivesse": "conviver",
    "convivessem": "conviver",
    "convivesses": "conviver",
    "conviveste": "conviver",
    "convivestes": "conviver",
    "conviveu": "conviver",
    "convivi": "conviver",
    "convivia": "conviver",
    "conviviais": "convivial",
    "conviviam": "conviver",
    "convivias": "conviver",
    "convivida": "conviver",
    "convividas": "conviver",
    "convivido": "conviver",
    "convividos": "conviver",
    "convivo": "conviver",
    "convivê": "conviver",
    "convivências": "convivência",
    "convivêramo": "conviver",
    "convivêramos": "conviver",
    "convivêrei": "conviver",
    "convivêreis": "conviver",
    "convivêsseis": "conviver",
    "convivêssemos": "conviver",
    "convivíamo": "conviver",
    "convivíamos": "conviver",
    "convivíei": "conviver",
    "convivíeis": "conviver",
    "convizinha": "convizinho",
    "convizinhada": "convizinhar",
    "convizinhadas": "convizinhar",
    "convizinhado": "convizinhar",
    "convizinhados": "convizinhar",
    "convizinhai": "convizinhar",
    "convizinhais": "convizinhar",
    "convizinham": "convizinhar",
    "convizinhamo": "convizinhar",
    "convizinhamos": "convizinhar",
    "convizinhando": "convizinhar",
    "convizinhanças": "convizinhança",
    "convizinhara": "convizinhar",
    "convizinharam": "convizinhar",
    "convizinharas": "convizinhar",
    "convizinharde": "convizinhar",
    "convizinhardes": "convizinhar",
    "convizinhare": "convizinhar",
    "convizinharei": "convizinhar",
    "convizinhareis": "convizinhar",
    "convizinharem": "convizinhar",
    "convizinharemos": "convizinhar",
    "convizinhares": "convizinhar",
    "convizinharia": "convizinhar",
    "convizinhariam": "convizinhar",
    "convizinharias": "convizinhar",
    "convizinharmo": "convizinhar",
    "convizinharmos": "convizinhar",
    "convizinhará": "convizinhar",
    "convizinharás": "convizinhar",
    "convizinharão": "convizinhar",
    "convizinharíamos": "convizinhar",
    "convizinharíeis": "convizinhar",
    "convizinhas": "convizinho",
    "convizinhasse": "convizinhar",
    "convizinhassem": "convizinhar",
    "convizinhasses": "convizinhar",
    "convizinhaste": "convizinhar",
    "convizinhastes": "convizinhar",
    "convizinhava": "convizinhar",
    "convizinhavam": "convizinhar",
    "convizinhavas": "convizinhar",
    "convizinhe": "convizinhar",
    "convizinhei": "convizinhar",
    "convizinheis": "convizinhar",
    "convizinhem": "convizinhar",
    "convizinhemo": "convizinhar",
    "convizinhemos": "convizinhar",
    "convizinhes": "convizinhar",
    "convizinho": "convizinhar",
    "convizinhos": "convizinho",
    "convizinhou": "convizinhar",
    "convizinhá": "convizinhar",
    "convizinhámo": "convizinhar",
    "convizinhámos": "convizinhar",
    "convizinháramo": "convizinhar",
    "convizinháramos": "convizinhar",
    "convizinhárei": "convizinhar",
    "convizinháreis": "convizinhar",
    "convizinhásseis": "convizinhar",
    "convizinhássemos": "convizinhar",
    "convizinhávamo": "convizinhar",
    "convizinhávamos": "convizinhar",
    "convizinhávei": "convizinhar",
    "convizinháveis": "convizinhar",
    "conviéramo": "convir",
    "conviéramos": "convir",
    "conviérei": "convir",
    "conviéreis": "convir",
    "conviésseis": "convir",
    "conviéssemos": "convir",
    "convoca": "convocar",
    "convocada": "convocar",
    "convocadas": "convocar",
    "convocado": "convocar",
    "convocadora": "convocador",
    "convocadoras": "convocador",
    "convocadores": "convocador",
    "convocados": "convocar",
    "convocai": "convocar",
    "convocais": "convocar",
    "convocam": "convocar",
    "convocamo": "convocar",
    "convocamos": "convocar",
    "convocando": "convocar",
    "convocara": "convocar",
    "convocaram": "convocar",
    "convocaras": "convocar",
    "convocarde": "convocar",
    "convocardes": "convocar",
    "convocare": "convocar",
    "convocarei": "convocar",
    "convocareis": "convocar",
    "convocarem": "convocar",
    "convocaremos": "convocar",
    "convocares": "convocar",
    "convocaria": "convocar",
    "convocariam": "convocar",
    "convocarias": "convocar",
    "convocarmo": "convocar",
    "convocarmos": "convocar",
    "convocará": "convocar",
    "convocarás": "convocar",
    "convocarão": "convocar",
    "convocaríamos": "convocar",
    "convocaríeis": "convocar",
    "convocas": "convocar",
    "convocasse": "convocar",
    "convocassem": "convocar",
    "convocasses": "convocar",
    "convocaste": "convocar",
    "convocastes": "convocar",
    "convocatória": "convocatório",
    "convocatórias": "convocatório",
    "convocatórios": "convocatório",
    "convocava": "convocar",
    "convocavam": "convocar",
    "convocavas": "convocar",
    "convocações": "convocação",
    "convoco": "convocar",
    "convocou": "convocar",
    "convocá": "convocar",
    "convocámo": "convocar",
    "convocámos": "convocar",
    "convocáramo": "convocar",
    "convocáramos": "convocar",
    "convocárei": "convocar",
    "convocáreis": "convocar",
    "convocásseis": "convocar",
    "convocássemos": "convocar",
    "convocávamo": "convocar",
    "convocávamos": "convocar",
    "convocávei": "convocar",
    "convocáveis": "convocar",
    "convola": "convolar",
    "convolada": "convolar",
    "convoladas": "convolar",
    "convolado": "convolar",
    "convolados": "convolar",
    "convolai": "convolar",
    "convolais": "convolar",
    "convolam": "convolar",
    "convolamo": "convolar",
    "convolamos": "convolar",
    "convolando": "convolar",
    "convolara": "convolar",
    "convolaram": "convolar",
    "convolaras": "convolar",
    "convolarde": "convolar",
    "convolardes": "convolar",
    "convolare": "convolar",
    "convolarei": "convolar",
    "convolareis": "convolar",
    "convolarem": "convolar",
    "convolaremos": "convolar",
    "convolares": "convolar",
    "convolaria": "convolar",
    "convolariam": "convolar",
    "convolarias": "convolar",
    "convolarmo": "convolar",
    "convolarmos": "convolar",
    "convolará": "convolar",
    "convolarás": "convolar",
    "convolarão": "convolar",
    "convolaríamos": "convolar",
    "convolaríeis": "convolar",
    "convolas": "convolar",
    "convolasse": "convolar",
    "convolassem": "convolar",
    "convolasses": "convolar",
    "convolaste": "convolar",
    "convolastes": "convolar",
    "convolava": "convolar",
    "convolavam": "convolar",
    "convolavas": "convolar",
    "convole": "convolar",
    "convolei": "convolar",
    "convoleis": "convolar",
    "convolem": "convolar",
    "convolemo": "convolar",
    "convolemos": "convolar",
    "convoles": "convolar",
    "convolo": "convolar",
    "convolou": "convolar",
    "convoluta": "convoluto",
    "convolutas": "convoluto",
    "convolutos": "convoluto",
    "convoluções": "convolução",
    "convolvuláceas": "convolvulácea",
    "convolá": "convolar",
    "convolámo": "convolar",
    "convolámos": "convolar",
    "convoláramo": "convolar",
    "convoláramos": "convolar",
    "convolárei": "convolar",
    "convoláreis": "convolar",
    "convolásseis": "convolar",
    "convolássemos": "convolar",
    "convolávamo": "convolar",
    "convolávamos": "convolar",
    "convolávei": "convolar",
    "convoláveis": "convolar",
    "convoque": "convocar",
    "convoquei": "convocar",
    "convoqueis": "convocar",
    "convoquem": "convocar",
    "convoquemo": "convocar",
    "convoquemos": "convocar",
    "convoques": "convocar",
    "convosco": "comigo",
    "convovulácea": "convovuláceo",
    "convovuláceas": "convovuláceo",
    "convovuláceos": "convovuláceo",
    "convulsa": "convulso",
    "convulsada": "convulsar",
    "convulsadas": "convulsar",
    "convulsado": "convulsar",
    "convulsados": "convulsar",
    "convulsai": "convulsar",
    "convulsais": "convulsar",
    "convulsam": "convulsar",
    "convulsamo": "convulsar",
    "convulsamos": "convulsar",
    "convulsando": "convulsar",
    "convulsara": "convulsar",
    "convulsaram": "convulsar",
    "convulsaras": "convulsar",
    "convulsarde": "convulsar",
    "convulsardes": "convulsar",
    "convulsare": "convulsar",
    "convulsarei": "convulsar",
    "convulsareis": "convulsar",
    "convulsarem": "convulsar",
    "convulsaremos": "convulsar",
    "convulsares": "convulsar",
    "convulsaria": "convulsar",
    "convulsariam": "convulsar",
    "convulsarias": "convulsar",
    "convulsarmo": "convulsar",
    "convulsarmos": "convulsar",
    "convulsará": "convulsar",
    "convulsarás": "convulsar",
    "convulsarão": "convulsar",
    "convulsaríamos": "convulsar",
    "convulsaríeis": "convulsar",
    "convulsas": "convulso",
    "convulsasse": "convulsar",
    "convulsassem": "convulsar",
    "convulsasses": "convulsar",
    "convulsaste": "convulsar",
    "convulsastes": "convulsar",
    "convulsava": "convulsar",
    "convulsavam": "convulsar",
    "convulsavas": "convulsar",
    "convulse": "convulsar",
    "convulsei": "convulsar",
    "convulseis": "convulsar",
    "convulsem": "convulsar",
    "convulsemo": "convulsar",
    "convulsemos": "convulsar",
    "convulses": "convulsar",
    "convulsibilidades": "convulsibilidade",
    "convulsiona": "convulsionar",
    "convulsionada": "convulsionar",
    "convulsionadas": "convulsionar",
    "convulsionado": "convulsionar",
    "convulsionados": "convulsionar",
    "convulsionai": "convulsionar",
    "convulsionais": "convulsionar",
    "convulsionam": "convulsionar",
    "convulsionamo": "convulsionar",
    "convulsionamos": "convulsionar",
    "convulsionando": "convulsionar",
    "convulsionantes": "convulsionante",
    "convulsionara": "convulsionar",
    "convulsionaram": "convulsionar",
    "convulsionaras": "convulsionar",
    "convulsionarde": "convulsionar",
    "convulsionardes": "convulsionar",
    "convulsionare": "convulsionar",
    "convulsionarei": "convulsionar",
    "convulsionareis": "convulsionar",
    "convulsionarem": "convulsionar",
    "convulsionaremos": "convulsionar",
    "convulsionares": "convulsionar",
    "convulsionaria": "convulsionar",
    "convulsionariam": "convulsionar",
    "convulsionarias": "convulsionar",
    "convulsionarmo": "convulsionar",
    "convulsionarmos": "convulsionar",
    "convulsionará": "convulsionar",
    "convulsionarás": "convulsionar",
    "convulsionarão": "convulsionar",
    "convulsionaríamos": "convulsionar",
    "convulsionaríeis": "convulsionar",
    "convulsionas": "convulsionar",
    "convulsionasse": "convulsionar",
    "convulsionassem": "convulsionar",
    "convulsionasses": "convulsionar",
    "convulsionaste": "convulsionar",
    "convulsionastes": "convulsionar",
    "convulsionava": "convulsionar",
    "convulsionavam": "convulsionar",
    "convulsionavas": "convulsionar",
    "convulsione": "convulsionar",
    "convulsionei": "convulsionar",
    "convulsioneis": "convulsionar",
    "convulsionem": "convulsionar",
    "convulsionemo": "convulsionar",
    "convulsionemos": "convulsionar",
    "convulsiones": "convulsionar",
    "convulsiono": "convulsionar",
    "convulsionou": "convulsionar",
    "convulsioná": "convulsionar",
    "convulsionámo": "convulsionar",
    "convulsionámos": "convulsionar",
    "convulsionáramo": "convulsionar",
    "convulsionáramos": "convulsionar",
    "convulsionárei": "convulsionar",
    "convulsionáreis": "convulsionar",
    "convulsionária": "convulsionário",
    "convulsionárias": "convulsionário",
    "convulsionários": "convulsionário",
    "convulsionásseis": "convulsionar",
    "convulsionássemos": "convulsionar",
    "convulsionávamo": "convulsionar",
    "convulsionávamos": "convulsionar",
    "convulsionávei": "convulsionar",
    "convulsionáveis": "convulsionar",
    "convulsiva": "convulsivo",
    "convulsivas": "convulsivo",
    "convulsivos": "convulsivo",
    "convulso": "convulsar",
    "convulsos": "convulso",
    "convulsou": "convulsar",
    "convulsá": "convulsar",
    "convulsámo": "convulsar",
    "convulsámos": "convulsar",
    "convulsáramo": "convulsar",
    "convulsáramos": "convulsar",
    "convulsárei": "convulsar",
    "convulsáreis": "convulsar",
    "convulsásseis": "convulsar",
    "convulsássemos": "convulsar",
    "convulsávamo": "convulsar",
    "convulsávamos": "convulsar",
    "convulsávei": "convulsar",
    "convulsáveis": "convulsar",
    "convulsíveis": "convulsível",
    "convulsões": "convulsão",
    "convém": "convir",
    "convénios": "convénio",
    "convéns": "convir",
    "convêm": "convir",
    "convícios": "convício",
    "convínhamo": "convir",
    "convínhamos": "convir",
    "convínhei": "convir",
    "convínheis": "convir",
    "convívios": "convívio",
    "conídea": "conídeo",
    "conídeas": "conídeo",
    "conídeos": "conídeo",
    "conídios": "conídio",
    "conífera": "conífero",
    "coníferas": "conífero",
    "coníferos": "conífero",
    "conóides": "conóide",
    "conúbios": "conúbio",
    "coo": "coar",
    "cooba": "coobar",
    "coobada": "coobar",
    "coobadas": "coobar",
    "coobado": "coobar",
    "coobadora": "coobador",
    "coobadoras": "coobador",
    "coobadores": "coobador",
    "coobados": "coobar",
    "coobai": "coobar",
    "coobais": "coobar",
    "coobam": "coobar",
    "coobamo": "coobar",
    "coobamos": "coobar",
    "coobando": "coobar",
    "coobara": "coobar",
    "coobaram": "coobar",
    "coobaras": "coobar",
    "coobarde": "coobar",
    "coobardes": "coobar",
    "coobare": "coobar",
    "coobarei": "coobar",
    "coobareis": "coobar",
    "coobarem": "coobar",
    "coobaremos": "coobar",
    "coobares": "coobar",
    "coobaria": "coobar",
    "coobariam": "coobar",
    "coobarias": "coobar",
    "coobarmo": "coobar",
    "coobarmos": "coobar",
    "coobará": "coobar",
    "coobarás": "coobar",
    "coobarão": "coobar",
    "coobaríamos": "coobar",
    "coobaríeis": "coobar",
    "coobas": "coobar",
    "coobasse": "coobar",
    "coobassem": "coobar",
    "coobasses": "coobar",
    "coobaste": "coobar",
    "coobastes": "coobar",
    "coobava": "coobar",
    "coobavam": "coobar",
    "coobavas": "coobar",
    "coobe": "coobar",
    "coobei": "coobar",
    "coobeis": "coobar",
    "coobem": "coobar",
    "coobemo": "coobar",
    "coobemos": "coobar",
    "coobes": "coobar",
    "coobo": "coobar",
    "coobou": "coobar",
    "coobriga": "coobrigar",
    "coobrigada": "coobrigar",
    "coobrigadas": "coobrigar",
    "coobrigado": "coobrigar",
    "coobrigados": "coobrigar",
    "coobrigai": "coobrigar",
    "coobrigais": "coobrigar",
    "coobrigam": "coobrigar",
    "coobrigamo": "coobrigar",
    "coobrigamos": "coobrigar",
    "coobrigando": "coobrigar",
    "coobrigara": "coobrigar",
    "coobrigaram": "coobrigar",
    "coobrigaras": "coobrigar",
    "coobrigarde": "coobrigar",
    "coobrigardes": "coobrigar",
    "coobrigare": "coobrigar",
    "coobrigarei": "coobrigar",
    "coobrigareis": "coobrigar",
    "coobrigarem": "coobrigar",
    "coobrigaremos": "coobrigar",
    "coobrigares": "coobrigar",
    "coobrigaria": "coobrigar",
    "coobrigariam": "coobrigar",
    "coobrigarias": "coobrigar",
    "coobrigarmo": "coobrigar",
    "coobrigarmos": "coobrigar",
    "coobrigará": "coobrigar",
    "coobrigarás": "coobrigar",
    "coobrigarão": "coobrigar",
    "coobrigaríamos": "coobrigar",
    "coobrigaríeis": "coobrigar",
    "coobrigas": "coobrigar",
    "coobrigasse": "coobrigar",
    "coobrigassem": "coobrigar",
    "coobrigasses": "coobrigar",
    "coobrigaste": "coobrigar",
    "coobrigastes": "coobrigar",
    "coobrigava": "coobrigar",
    "coobrigavam": "coobrigar",
    "coobrigavas": "coobrigar",
    "coobrigações": "coobrigação",
    "coobrigo": "coobrigar",
    "coobrigou": "coobrigar",
    "coobrigue": "coobrigar",
    "coobriguei": "coobrigar",
    "coobrigueis": "coobrigar",
    "coobriguem": "coobrigar",
    "coobriguemo": "coobrigar",
    "coobriguemos": "coobrigar",
    "coobrigues": "coobrigar",
    "coobrigá": "coobrigar",
    "coobrigámo": "coobrigar",
    "coobrigámos": "coobrigar",
    "coobrigáramo": "coobrigar",
    "coobrigáramos": "coobrigar",
    "coobrigárei": "coobrigar",
    "coobrigáreis": "coobrigar",
    "coobrigásseis": "coobrigar",
    "coobrigássemos": "coobrigar",
    "coobrigávamo": "coobrigar",
    "coobrigávamos": "coobrigar",
    "coobrigávei": "coobrigar",
    "coobrigáveis": "coobrigar",
    "coobá": "coobar",
    "coobámo": "coobar",
    "coobámos": "coobar",
    "coobáramo": "coobar",
    "coobáramos": "coobar",
    "coobárei": "coobar",
    "coobáreis": "coobar",
    "coobásseis": "coobar",
    "coobássemos": "coobar",
    "coobávamo": "coobar",
    "coobávamos": "coobar",
    "coobávei": "coobar",
    "coobáveis": "coobar",
    "coonesta": "coonestar",
    "coonestada": "coonestar",
    "coonestadas": "coonestar",
    "coonestado": "coonestar",
    "coonestadora": "coonestador",
    "coonestadoras": "coonestador",
    "coonestadores": "coonestador",
    "coonestados": "coonestar",
    "coonestai": "coonestar",
    "coonestais": "coonestar",
    "coonestam": "coonestar",
    "coonestamo": "coonestar",
    "coonestamos": "coonestar",
    "coonestando": "coonestar",
    "coonestara": "coonestar",
    "coonestaram": "coonestar",
    "coonestaras": "coonestar",
    "coonestarde": "coonestar",
    "coonestardes": "coonestar",
    "coonestare": "coonestar",
    "coonestarei": "coonestar",
    "coonestareis": "coonestar",
    "coonestarem": "coonestar",
    "coonestaremos": "coonestar",
    "coonestares": "coonestar",
    "coonestaria": "coonestar",
    "coonestariam": "coonestar",
    "coonestarias": "coonestar",
    "coonestarmo": "coonestar",
    "coonestarmos": "coonestar",
    "coonestará": "coonestar",
    "coonestarás": "coonestar",
    "coonestarão": "coonestar",
    "coonestaríamos": "coonestar",
    "coonestaríeis": "coonestar",
    "coonestas": "coonestar",
    "coonestasse": "coonestar",
    "coonestassem": "coonestar",
    "coonestasses": "coonestar",
    "coonestaste": "coonestar",
    "coonestastes": "coonestar",
    "coonestava": "coonestar",
    "coonestavam": "coonestar",
    "coonestavas": "coonestar",
    "coonestações": "coonestação",
    "cooneste": "coonestar",
    "coonestei": "coonestar",
    "coonesteis": "coonestar",
    "coonestem": "coonestar",
    "coonestemo": "coonestar",
    "coonestemos": "coonestar",
    "coonestes": "coonestar",
    "coonesto": "coonestar",
    "coonestou": "coonestar",
    "coonestá": "coonestar",
    "coonestámo": "coonestar",
    "coonestámos": "coonestar",
    "coonestáramo": "coonestar",
    "coonestáramos": "coonestar",
    "coonestárei": "coonestar",
    "coonestáreis": "coonestar",
    "coonestásseis": "coonestar",
    "coonestássemos": "coonestar",
    "coonestávamo": "coonestar",
    "coonestávamos": "coonestar",
    "coonestávei": "coonestar",
    "coonestáveis": "coonestar",
    "coopera": "cooperar",
    "cooperacionais": "cooperacional",
    "cooperada": "cooperar",
    "cooperadas": "cooperar",
    "cooperado": "cooperar",
    "cooperadora": "cooperador",
    "cooperadoras": "cooperador",
    "cooperadores": "cooperador",
    "cooperados": "cooperar",
    "cooperai": "cooperar",
    "cooperais": "cooperar",
    "cooperam": "cooperar",
    "cooperamo": "cooperar",
    "cooperamos": "cooperar",
    "cooperando": "cooperar",
    "cooperantes": "cooperante",
    "cooperara": "cooperar",
    "cooperaram": "cooperar",
    "cooperaras": "cooperar",
    "cooperarde": "cooperar",
    "cooperardes": "cooperar",
    "cooperare": "cooperar",
    "cooperarei": "cooperar",
    "cooperareis": "cooperar",
    "cooperarem": "cooperar",
    "cooperaremos": "cooperar",
    "cooperares": "cooperar",
    "cooperaria": "cooperar",
    "cooperariam": "cooperar",
    "cooperarias": "cooperar",
    "cooperarmo": "cooperar",
    "cooperarmos": "cooperar",
    "cooperará": "cooperar",
    "cooperarás": "cooperar",
    "cooperarão": "cooperar",
    "cooperaríamos": "cooperar",
    "cooperaríeis": "cooperar",
    "cooperas": "cooperar",
    "cooperasse": "cooperar",
    "cooperassem": "cooperar",
    "cooperasses": "cooperar",
    "cooperaste": "cooperar",
    "cooperastes": "cooperar",
    "cooperativa": "cooperativo",
    "cooperativas": "cooperativo",
    "cooperativismos": "cooperativismo",
    "cooperativistas": "cooperativista",
    "cooperativos": "cooperativo",
    "cooperava": "cooperar",
    "cooperavam": "cooperar",
    "cooperavas": "cooperar",
    "cooperações": "cooperação",
    "coopere": "cooperar",
    "cooperei": "cooperar",
    "coopereis": "cooperar",
    "cooperem": "cooperar",
    "cooperemo": "cooperar",
    "cooperemos": "cooperar",
    "cooperes": "cooperar",
    "coopero": "cooperar",
    "cooperou": "cooperar",
    "cooperá": "cooperar",
    "cooperámo": "cooperar",
    "cooperámos": "cooperar",
    "cooperáramo": "cooperar",
    "cooperáramos": "cooperar",
    "cooperárei": "cooperar",
    "cooperáreis": "cooperar",
    "cooperásseis": "cooperar",
    "cooperássemos": "cooperar",
    "cooperávamo": "cooperar",
    "cooperávamos": "cooperar",
    "cooperávei": "cooperar",
    "cooperáveis": "cooperar",
    "coopositora": "coopositor",
    "coopositoras": "coopositor",
    "coopositores": "coopositor",
    "coopta": "cooptar",
    "cooptada": "cooptar",
    "cooptadas": "cooptar",
    "cooptado": "cooptar",
    "cooptados": "cooptar",
    "cooptai": "cooptar",
    "cooptais": "cooptar",
    "cooptam": "cooptar",
    "cooptamo": "cooptar",
    "cooptamos": "cooptar",
    "cooptando": "cooptar",
    "cooptara": "cooptar",
    "cooptaram": "cooptar",
    "cooptaras": "cooptar",
    "cooptarde": "cooptar",
    "cooptardes": "cooptar",
    "cooptare": "cooptar",
    "cooptarei": "cooptar",
    "cooptareis": "cooptar",
    "cooptarem": "cooptar",
    "cooptaremos": "cooptar",
    "cooptares": "cooptar",
    "cooptaria": "cooptar",
    "cooptariam": "cooptar",
    "cooptarias": "cooptar",
    "cooptarmo": "cooptar",
    "cooptarmos": "cooptar",
    "cooptará": "cooptar",
    "cooptarás": "cooptar",
    "cooptarão": "cooptar",
    "cooptaríamos": "cooptar",
    "cooptaríeis": "cooptar",
    "cooptas": "cooptar",
    "cooptasse": "cooptar",
    "cooptassem": "cooptar",
    "cooptasses": "cooptar",
    "cooptaste": "cooptar",
    "cooptastes": "cooptar",
    "cooptava": "cooptar",
    "cooptavam": "cooptar",
    "cooptavas": "cooptar",
    "cooptações": "cooptação",
    "coopte": "cooptar",
    "cooptei": "cooptar",
    "coopteis": "cooptar",
    "cooptem": "cooptar",
    "cooptemo": "cooptar",
    "cooptemos": "cooptar",
    "cooptes": "cooptar",
    "coopto": "cooptar",
    "cooptou": "cooptar",
    "cooptá": "cooptar",
    "cooptámo": "cooptar",
    "cooptámos": "cooptar",
    "cooptáramo": "cooptar",
    "cooptáramos": "cooptar",
    "cooptárei": "cooptar",
    "cooptáreis": "cooptar",
    "cooptásseis": "cooptar",
    "cooptássemos": "cooptar",
    "cooptávamo": "cooptar",
    "cooptávamos": "cooptar",
    "cooptávei": "cooptar",
    "cooptáveis": "cooptar",
    "coordena": "coordenar",
    "coordenada": "coordenar",
    "coordenadas": "coordenar",
    "coordenado": "coordenar",
    "coordenadora": "coordenador",
    "coordenadoras": "coordenador",
    "coordenadores": "coordenador",
    "coordenados": "coordenar",
    "coordenai": "coordenar",
    "coordenais": "coordenar",
    "coordenam": "coordenar",
    "coordenamo": "coordenar",
    "coordenamos": "coordenar",
    "coordenando": "coordenar",
    "coordenara": "coordenar",
    "coordenaram": "coordenar",
    "coordenaras": "coordenar",
    "coordenarde": "coordenar",
    "coordenardes": "coordenar",
    "coordenare": "coordenar",
    "coordenarei": "coordenar",
    "coordenareis": "coordenar",
    "coordenarem": "coordenar",
    "coordenaremos": "coordenar",
    "coordenares": "coordenar",
    "coordenaria": "coordenar",
    "coordenariam": "coordenar",
    "coordenarias": "coordenar",
    "coordenarmo": "coordenar",
    "coordenarmos": "coordenar",
    "coordenará": "coordenar",
    "coordenarás": "coordenar",
    "coordenarão": "coordenar",
    "coordenaríamos": "coordenar",
    "coordenaríeis": "coordenar",
    "coordenas": "coordenar",
    "coordenasse": "coordenar",
    "coordenassem": "coordenar",
    "coordenasses": "coordenar",
    "coordenaste": "coordenar",
    "coordenastes": "coordenar",
    "coordenativa": "coordenativo",
    "coordenativas": "coordenativo",
    "coordenativos": "coordenativo",
    "coordenava": "coordenar",
    "coordenavam": "coordenar",
    "coordenavas": "coordenar",
    "coordenações": "coordenação",
    "coordene": "coordenar",
    "coordenei": "coordenar",
    "coordeneis": "coordenar",
    "coordenem": "coordenar",
    "coordenemo": "coordenar",
    "coordenemos": "coordenar",
    "coordenes": "coordenar",
    "coordeno": "coordenar",
    "coordenou": "coordenar",
    "coordená": "coordenar",
    "coordenámo": "coordenar",
    "coordenámos": "coordenar",
    "coordenáramo": "coordenar",
    "coordenáramos": "coordenar",
    "coordenárei": "coordenar",
    "coordenáreis": "coordenar",
    "coordenásseis": "coordenar",
    "coordenássemos": "coordenar",
    "coordenávamo": "coordenar",
    "coordenávamos": "coordenar",
    "coordenávei": "coordenar",
    "coordenáveis": "coordenar",
    "coortes": "coorte",
    "coossificações": "coossificação",
    "coou": "coar",
    "coovadora": "coovador",
    "coovadoras": "coovador",
    "coovadores": "coovador",
    "coovações": "coovação",
    "copa": "copar",
    "copacabanenses": "copacabanense",
    "copada": "copar",
    "copadas": "copar",
    "copado": "copar",
    "copados": "copar",
    "copagens": "copagem",
    "copai": "copar",
    "copaibeira": "copaibeiro",
    "copaibeiras": "copaibeiro",
    "copaibeiros": "copaibeiro",
    "copais": "copar",
    "copalina": "copalino",
    "copalinas": "copalino",
    "copalinos": "copalino",
    "copam": "copar",
    "copamo": "copar",
    "copamos": "copar",
    "copando": "copar",
    "copara": "copar",
    "coparam": "copar",
    "coparas": "copar",
    "coparde": "copar",
    "copardes": "copar",
    "copare": "copar",
    "coparei": "copar",
    "copareis": "copar",
    "coparem": "copar",
    "coparemos": "copar",
    "copares": "copar",
    "coparia": "copar",
    "copariam": "copar",
    "coparias": "copar",
    "coparmo": "copar",
    "coparmos": "copar",
    "copará": "copar",
    "coparás": "copar",
    "coparão": "copar",
    "coparíamos": "copar",
    "coparíeis": "copar",
    "copas": "copar",
    "copasse": "copar",
    "copassem": "copar",
    "copasses": "copar",
    "copaste": "copar",
    "copastes": "copar",
    "copava": "copar",
    "copavam": "copar",
    "copavas": "copar",
    "copazinha": "copa",
    "copazinhas": "copa",
    "copazita": "copa",
    "copazitas": "copa",
    "copaíbas": "copaíba",
    "copaínas": "copaína",
    "cope": "copar",
    "copei": "copar",
    "copeira": "copeiro",
    "copeiragens": "copeiragem",
    "copeiras": "copeiro",
    "copeiros": "copeiro",
    "copeis": "copel",
    "copeja": "copejar",
    "copejada": "copejar",
    "copejadas": "copejar",
    "copejado": "copejar",
    "copejadora": "copejador",
    "copejadoras": "copejador",
    "copejadores": "copejador",
    "copejados": "copejar",
    "copejaduras": "copejadura",
    "copejai": "copejar",
    "copejais": "copejar",
    "copejam": "copejar",
    "copejamo": "copejar",
    "copejamos": "copejar",
    "copejando": "copejar",
    "copejara": "copejar",
    "copejaram": "copejar",
    "copejaras": "copejar",
    "copejarde": "copejar",
    "copejardes": "copejar",
    "copejare": "copejar",
    "copejarei": "copejar",
    "copejareis": "copejar",
    "copejarem": "copejar",
    "copejaremos": "copejar",
    "copejares": "copejar",
    "copejaria": "copejar",
    "copejariam": "copejar",
    "copejarias": "copejar",
    "copejarmo": "copejar",
    "copejarmos": "copejar",
    "copejará": "copejar",
    "copejarás": "copejar",
    "copejarão": "copejar",
    "copejaríamos": "copejar",
    "copejaríeis": "copejar",
    "copejas": "copejar",
    "copejasse": "copejar",
    "copejassem": "copejar",
    "copejasses": "copejar",
    "copejaste": "copejar",
    "copejastes": "copejar",
    "copejava": "copejar",
    "copejavam": "copejar",
    "copejavas": "copejar",
    "copeje": "copejar",
    "copejei": "copejar",
    "copejeis": "copejar",
    "copejem": "copejar",
    "copejemo": "copejar",
    "copejemos": "copejar",
    "copejes": "copejar",
    "copejo": "copejar",
    "copejos": "copejo",
    "copejou": "copejar",
    "copejá": "copejar",
    "copejámo": "copejar",
    "copejámos": "copejar",
    "copejáramo": "copejar",
    "copejáramos": "copejar",
    "copejárei": "copejar",
    "copejáreis": "copejar",
    "copejásseis": "copejar",
    "copejássemos": "copejar",
    "copejávamo": "copejar",
    "copejávamos": "copejar",
    "copejávei": "copejar",
    "copejáveis": "copejar",
    "copela": "copelar",
    "copelada": "copelar",
    "copeladas": "copelar",
    "copelado": "copelar",
    "copelados": "copelar",
    "copelai": "copelar",
    "copelais": "copelar",
    "copelam": "copelar",
    "copelamo": "copelar",
    "copelamos": "copelar",
    "copelando": "copelar",
    "copelara": "copelar",
    "copelaram": "copelar",
    "copelaras": "copelar",
    "copelarde": "copelar",
    "copelardes": "copelar",
    "copelare": "copelar",
    "copelarei": "copelar",
    "copelareis": "copelar",
    "copelarem": "copelar",
    "copelaremos": "copelar",
    "copelares": "copelar",
    "copelaria": "copelar",
    "copelariam": "copelar",
    "copelarias": "copelar",
    "copelarmo": "copelar",
    "copelarmos": "copelar",
    "copelará": "copelar",
    "copelarás": "copelar",
    "copelarão": "copelar",
    "copelaríamos": "copelar",
    "copelaríeis": "copelar",
    "copelas": "copelar",
    "copelasse": "copelar",
    "copelassem": "copelar",
    "copelasses": "copelar",
    "copelaste": "copelar",
    "copelastes": "copelar",
    "copelava": "copelar",
    "copelavam": "copelar",
    "copelavas": "copelar",
    "copelações": "copelação",
    "copele": "copelar",
    "copelei": "copelar",
    "copeleis": "copelar",
    "copelem": "copelar",
    "copelemo": "copelar",
    "copelemos": "copelar",
    "copeles": "copelar",
    "copelo": "copelar",
    "copelou": "copelar",
    "copelá": "copelar",
    "copelámo": "copelar",
    "copelámos": "copelar",
    "copeláramo": "copelar",
    "copeláramos": "copelar",
    "copelárei": "copelar",
    "copeláreis": "copelar",
    "copelásseis": "copelar",
    "copelássemos": "copelar",
    "copelávamo": "copelar",
    "copelávamos": "copelar",
    "copelávei": "copelar",
    "copeláveis": "copelar",
    "copem": "copar",
    "copemo": "copar",
    "copemos": "copar",
    "coperniciana": "coperniciano",
    "copernicianas": "coperniciano",
    "copernicianos": "coperniciano",
    "copes": "copar",
    "copia": "copiar",
    "copiada": "copiar",
    "copiadas": "copiar",
    "copiado": "copiar",
    "copiadora": "copiador",
    "copiadoras": "copiadora",
    "copiadores": "copiador",
    "copiados": "copiar",
    "copiai": "copiar",
    "copiais": "copiar",
    "copiam": "copiar",
    "copiamo": "copiar",
    "copiamos": "copiar",
    "copiando": "copiar",
    "copiara": "copiar",
    "copiaram": "copiar",
    "copiaras": "copiara",
    "copiarde": "copiar",
    "copiardes": "copiar",
    "copiare": "copiar",
    "copiarei": "copiar",
    "copiareis": "copiar",
    "copiarem": "copiar",
    "copiaremos": "copiar",
    "copiares": "copiar",
    "copiaria": "copiar",
    "copiariam": "copiar",
    "copiarias": "copiar",
    "copiarmo": "copiar",
    "copiarmos": "copiar",
    "copiará": "copiar",
    "copiarás": "copiar",
    "copiarão": "copiar",
    "copiaríamos": "copiar",
    "copiaríeis": "copiar",
    "copias": "copiar",
    "copiasse": "copiar",
    "copiassem": "copiar",
    "copiasses": "copiar",
    "copiaste": "copiar",
    "copiastes": "copiar",
    "copiava": "copiar",
    "copiavam": "copiar",
    "copiavas": "copiar",
    "copie": "copiar",
    "copiei": "copiar",
    "copieis": "copiar",
    "copiem": "copiar",
    "copiemo": "copiar",
    "copiemos": "copiar",
    "copies": "copiar",
    "copila": "copilar",
    "copilada": "copilar",
    "copiladas": "copilar",
    "copilado": "copilar",
    "copilados": "copilar",
    "copilai": "copilar",
    "copilais": "copilar",
    "copilam": "copilar",
    "copilamo": "copilar",
    "copilamos": "copilar",
    "copilando": "copilar",
    "copilara": "copilar",
    "copilaram": "copilar",
    "copilaras": "copilar",
    "copilarde": "copilar",
    "copilardes": "copilar",
    "copilare": "copilar",
    "copilarei": "copilar",
    "copilareis": "copilar",
    "copilarem": "copilar",
    "copilaremos": "copilar",
    "copilares": "copilar",
    "copilaria": "copilar",
    "copilariam": "copilar",
    "copilarias": "copilar",
    "copilarmo": "copilar",
    "copilarmos": "copilar",
    "copilará": "copilar",
    "copilarás": "copilar",
    "copilarão": "copilar",
    "copilaríamos": "copilar",
    "copilaríeis": "copilar",
    "copilas": "copilar",
    "copilasse": "copilar",
    "copilassem": "copilar",
    "copilasses": "copilar",
    "copilaste": "copilar",
    "copilastes": "copilar",
    "copilava": "copilar",
    "copilavam": "copilar",
    "copilavas": "copilar",
    "copile": "copilar",
    "copilei": "copilar",
    "copileis": "copilar",
    "copilem": "copilar",
    "copilemo": "copilar",
    "copilemos": "copilar",
    "copiles": "copilar",
    "copilo": "copilar",
    "copilou": "copilar",
    "copilá": "copilar",
    "copilámo": "copilar",
    "copilámos": "copilar",
    "copiláramo": "copilar",
    "copiláramos": "copilar",
    "copilárei": "copilar",
    "copiláreis": "copilar",
    "copilásseis": "copilar",
    "copilássemos": "copilar",
    "copilávamo": "copilar",
    "copilávamos": "copilar",
    "copilávei": "copilar",
    "copiláveis": "copilar",
    "copinha": "copa",
    "copinhas": "copa",
    "copinho": "copo",
    "copinhos": "copo",
    "copio": "copiar",
    "copiografa": "copiografar",
    "copiografada": "copiografar",
    "copiografadas": "copiografar",
    "copiografado": "copiografar",
    "copiografados": "copiografar",
    "copiografai": "copiografar",
    "copiografais": "copiografar",
    "copiografam": "copiografar",
    "copiografamo": "copiografar",
    "copiografamos": "copiografar",
    "copiografando": "copiografar",
    "copiografara": "copiografar",
    "copiografaram": "copiografar",
    "copiografaras": "copiografar",
    "copiografarde": "copiografar",
    "copiografardes": "copiografar",
    "copiografare": "copiografar",
    "copiografarei": "copiografar",
    "copiografareis": "copiografar",
    "copiografarem": "copiografar",
    "copiografaremos": "copiografar",
    "copiografares": "copiografar",
    "copiografaria": "copiografar",
    "copiografariam": "copiografar",
    "copiografarias": "copiografar",
    "copiografarmo": "copiografar",
    "copiografarmos": "copiografar",
    "copiografará": "copiografar",
    "copiografarás": "copiografar",
    "copiografarão": "copiografar",
    "copiografaríamos": "copiografar",
    "copiografaríeis": "copiografar",
    "copiografas": "copiografar",
    "copiografasse": "copiografar",
    "copiografassem": "copiografar",
    "copiografasses": "copiografar",
    "copiografaste": "copiografar",
    "copiografastes": "copiografar",
    "copiografava": "copiografar",
    "copiografavam": "copiografar",
    "copiografavas": "copiografar",
    "copiografe": "copiografar",
    "copiografei": "copiografar",
    "copiografeis": "copiografar",
    "copiografem": "copiografar",
    "copiografemo": "copiografar",
    "copiografemos": "copiografar",
    "copiografes": "copiografar",
    "copiografias": "copiografia",
    "copiografo": "copiografar",
    "copiografou": "copiografar",
    "copiografá": "copiografar",
    "copiografámo": "copiografar",
    "copiografámos": "copiografar",
    "copiografáramo": "copiografar",
    "copiografáramos": "copiografar",
    "copiografárei": "copiografar",
    "copiografáreis": "copiografar",
    "copiografásseis": "copiografar",
    "copiografássemos": "copiografar",
    "copiografávamo": "copiografar",
    "copiografávamos": "copiografar",
    "copiografávei": "copiografar",
    "copiografáveis": "copiografar",
    "copiográfica": "copiográfico",
    "copiográficas": "copiográfico",
    "copiográficos": "copiográfico",
    "copios": "copio",
    "copiosa": "copioso",
    "copiosas": "copioso",
    "copiosidades": "copiosidade",
    "copiosos": "copioso",
    "copiou": "copiar",
    "copistas": "copista",
    "copita": "copa",
    "copitas": "copa",
    "copito": "copo",
    "copitos": "copo",
    "copiá": "copiar",
    "copiámo": "copiar",
    "copiámos": "copiar",
    "copiáramo": "copiar",
    "copiáramos": "copiar",
    "copiárei": "copiar",
    "copiáreis": "copiar",
    "copiásseis": "copiar",
    "copiássemos": "copiar",
    "copiávamo": "copiar",
    "copiávamos": "copiar",
    "copiávei": "copiar",
    "copiáveis": "copiar",
    "copiógrafos": "copiógrafo",
    "coplas": "copla",
    "coplistas": "coplista",
    "copo": "copar",
    "copocrásica": "copocrásico",
    "copocrásicas": "copocrásico",
    "copocrásicos": "copocrásico",
    "copofones": "copofone",
    "copofónica": "copofónico",
    "copofónicas": "copofónico",
    "copofónicos": "copofónico",
    "copos": "copo",
    "copou": "copar",
    "copracrasias": "copracrasia",
    "copras": "copra",
    "copraóis": "copraol",
    "copremias": "copremia",
    "coprodutora": "coprodutor",
    "coprodutoras": "coprodutor",
    "coprodutores": "coprodutor",
    "coprofagias": "coprofagia",
    "coprofágica": "coprofágico",
    "coprofágicas": "coprofágico",
    "coprofágicos": "coprofágico",
    "coprolalias": "coprolalia",
    "coprologias": "coprologia",
    "coprologistas": "coprologista",
    "coprolálica": "coprolálico",
    "coprolálicas": "coprolálico",
    "coprolálicos": "coprolálico",
    "coprológica": "coprológico",
    "coprológicas": "coprológico",
    "coprológicos": "coprológico",
    "coprostasias": "coprostasia",
    "coprostásica": "coprostásico",
    "coprostásicas": "coprostásico",
    "coprostásicos": "coprostásico",
    "coprénica": "coprénico",
    "coprénicas": "coprénico",
    "coprénicos": "coprénico",
    "coprófaga": "coprófago",
    "coprófagas": "coprófago",
    "coprófagos": "coprófago",
    "coprófila": "coprófilo",
    "coprófilas": "coprófilo",
    "coprófilos": "coprófilo",
    "coprólitos": "coprólito",
    "copróloga": "coprólogo",
    "coprólogas": "coprólogo",
    "coprólogos": "coprólogo",
    "copta": "copto",
    "coptas": "copto",
    "coptica": "coptico",
    "copticas": "coptico",
    "copticos": "coptico",
    "coptografias": "coptografia",
    "coptográfica": "coptográfico",
    "coptográficas": "coptográfico",
    "coptográficos": "coptográfico",
    "coptos": "copto",
    "copula": "copular",
    "copulada": "copular",
    "copuladas": "copular",
    "copulado": "copular",
    "copuladora": "copulador",
    "copuladoras": "copulador",
    "copuladores": "copulador",
    "copulados": "copular",
    "copulai": "copular",
    "copulais": "copular",
    "copulam": "copular",
    "copulamo": "copular",
    "copulamos": "copular",
    "copulando": "copular",
    "copulara": "copular",
    "copularam": "copular",
    "copularas": "copular",
    "copularde": "copular",
    "copulardes": "copular",
    "copulare": "copular",
    "copularei": "copular",
    "copulareis": "copular",
    "copularem": "copular",
    "copularemos": "copular",
    "copulares": "copular",
    "copularia": "copular",
    "copulariam": "copular",
    "copularias": "copular",
    "copularmo": "copular",
    "copularmos": "copular",
    "copulará": "copular",
    "copularás": "copular",
    "copularão": "copular",
    "copularíamos": "copular",
    "copularíeis": "copular",
    "copulas": "copular",
    "copulasse": "copular",
    "copulassem": "copular",
    "copulasses": "copular",
    "copulaste": "copular",
    "copulastes": "copular",
    "copulativa": "copulativo",
    "copulativas": "copulativo",
    "copulativos": "copulativo",
    "copulava": "copular",
    "copulavam": "copular",
    "copulavas": "copular",
    "copulações": "copulação",
    "copule": "copular",
    "copulei": "copular",
    "copuleis": "copular",
    "copulem": "copular",
    "copulemo": "copular",
    "copulemos": "copular",
    "copules": "copular",
    "copulo": "copular",
    "copulou": "copular",
    "copulá": "copular",
    "copulámo": "copular",
    "copulámos": "copular",
    "copuláramo": "copular",
    "copuláramos": "copular",
    "copulárei": "copular",
    "copuláreis": "copular",
    "copulásseis": "copular",
    "copulássemos": "copular",
    "copulávamo": "copular",
    "copulávamos": "copular",
    "copulávei": "copular",
    "copuláveis": "copular",
    "copyrights": "copyright",
    "copá": "copar",
    "copámo": "copar",
    "copámos": "copar",
    "copáramo": "copar",
    "copáramos": "copar",
    "copárei": "copar",
    "copáreis": "copar",
    "copásseis": "copar",
    "copássemos": "copar",
    "copávamo": "copar",
    "copávamos": "copar",
    "copávei": "copar",
    "copáveis": "copar",
    "copázios": "copázio",
    "copépodes": "copépode",
    "copérnica": "copérnico",
    "copérnicas": "copérnico",
    "copérnicos": "copérnico",
    "copés": "copé",
    "coque": "cocar",
    "coquei": "cocar",
    "coqueirais": "coqueiral",
    "coqueiros": "coqueiro",
    "coqueis": "cocar",
    "coqueluches": "coqueluche",
    "coqueluchóides": "coqueluchóide",
    "coquem": "cocar",
    "coquemo": "cocar",
    "coquemos": "cocar",
    "coques": "coque",
    "coquetarias": "coquetaria",
    "coqueteada": "coquetear",
    "coqueteadas": "coquetear",
    "coqueteado": "coquetear",
    "coqueteados": "coquetear",
    "coqueteai": "coquetear",
    "coqueteais": "coquetear",
    "coqueteamo": "coquetear",
    "coqueteamos": "coquetear",
    "coqueteando": "coquetear",
    "coqueteara": "coquetear",
    "coquetearam": "coquetear",
    "coquetearas": "coquetear",
    "coquetearde": "coquetear",
    "coqueteardes": "coquetear",
    "coqueteare": "coquetear",
    "coquetearei": "coquetear",
    "coqueteareis": "coquetear",
    "coquetearem": "coquetear",
    "coquetearemos": "coquetear",
    "coqueteares": "coquetear",
    "coquetearia": "coquetear",
    "coqueteariam": "coquetear",
    "coquetearias": "coquetear",
    "coquetearmo": "coquetear",
    "coquetearmos": "coquetear",
    "coqueteará": "coquetear",
    "coquetearás": "coquetear",
    "coquetearão": "coquetear",
    "coquetearíamos": "coquetear",
    "coquetearíeis": "coquetear",
    "coqueteasse": "coquetear",
    "coqueteassem": "coquetear",
    "coqueteasses": "coquetear",
    "coqueteaste": "coquetear",
    "coqueteastes": "coquetear",
    "coqueteava": "coquetear",
    "coqueteavam": "coquetear",
    "coqueteavas": "coquetear",
    "coqueteei": "coquetear",
    "coqueteeis": "coquetear",
    "coqueteemo": "coquetear",
    "coqueteemos": "coquetear",
    "coqueteia": "coquetear",
    "coqueteiam": "coquetear",
    "coqueteias": "coquetear",
    "coqueteie": "coquetear",
    "coqueteiem": "coquetear",
    "coqueteies": "coquetear",
    "coqueteio": "coquetear",
    "coqueteou": "coquetear",
    "coqueterias": "coqueteria",
    "coquetes": "coquete",
    "coqueteá": "coquetear",
    "coqueteámo": "coquetear",
    "coqueteámos": "coquetear",
    "coqueteáramo": "coquetear",
    "coqueteáramos": "coquetear",
    "coqueteárei": "coquetear",
    "coqueteáreis": "coquetear",
    "coqueteásseis": "coquetear",
    "coqueteássemos": "coquetear",
    "coqueteávamo": "coquetear",
    "coqueteávamos": "coquetear",
    "coqueteávei": "coquetear",
    "coqueteáveis": "coquetear",
    "coquetismos": "coquetismo",
    "coquilheiros": "coquilheiro",
    "coquilhos": "coquilho",
    "coquinadas": "coquinada",
    "cora": "corar",
    "coraciformes": "coraciforme",
    "coraciídas": "coraciída",
    "coracomantes": "coracomante",
    "coracomântica": "coracomântico",
    "coracomânticas": "coracomântico",
    "coracomânticos": "coracomântico",
    "coracídea": "coracídeo",
    "coracídeas": "coracídeo",
    "coracídeos": "coracídeo",
    "coracóidea": "coracóideo",
    "coracóideas": "coracóideo",
    "coracóideos": "coracóideo",
    "coracóides": "coracóide",
    "corada": "corar",
    "coradas": "corar",
    "coradinha": "corado",
    "coradinhas": "corado",
    "coradinho": "corado",
    "coradinhos": "corado",
    "coradita": "corado",
    "coraditas": "corado",
    "coradito": "corado",
    "coraditos": "corado",
    "corado": "corar",
    "coradoiros": "coradoiro",
    "corados": "corar",
    "coradouros": "coradouro",
    "coradíssima": "corado",
    "coradíssimas": "corado",
    "coradíssimo": "corado",
    "coradíssimos": "corado",
    "coragens": "coragem",
    "corai": "corar",
    "corais": "corar",
    "coraixitas": "coraixita",
    "corajosa": "corajoso",
    "corajosas": "corajoso",
    "corajosos": "corajoso",
    "coraleira": "coraleiro",
    "coraleiras": "coraleiro",
    "coraleiros": "coraleiro",
    "coraleária": "coraleário",
    "coraleárias": "coraleário",
    "coraleários": "coraleário",
    "coraliformes": "coraliforme",
    "coralina": "coralino",
    "coralinas": "coralino",
    "coralinos": "coralino",
    "coralinácea": "coralináceo",
    "coralináceas": "coralináceo",
    "coralináceos": "coralináceo",
    "coralistas": "coralista",
    "coraliários": "coraliário",
    "coralífera": "coralífero",
    "coralíferas": "coralífero",
    "coralíferos": "coralífero",
    "coralígena": "coralígeno",
    "coralígenas": "coralígeno",
    "coralígenos": "coralígeno",
    "coralígera": "coralígero",
    "coralígeras": "coralígero",
    "coralígeros": "coralígero",
    "coralóides": "coralóide",
    "coram": "corar",
    "coraminas": "coramina",
    "coramo": "corar",
    "coramos": "corar",
    "corandeis": "corandel",
    "corando": "corar",
    "corantes": "corante",
    "corara": "corar",
    "coraram": "corar",
    "coraras": "corar",
    "corarde": "corar",
    "corardes": "corar",
    "corare": "corar",
    "corarei": "corar",
    "corareis": "corar",
    "corarem": "corar",
    "coraremos": "corar",
    "corares": "corar",
    "coraria": "corar",
    "corariam": "corar",
    "corarias": "corar",
    "corarmo": "corar",
    "corarmos": "corar",
    "corará": "corar",
    "corarás": "corar",
    "corarão": "corar",
    "coraríamos": "corar",
    "coraríeis": "corar",
    "coras": "corar",
    "corasse": "corar",
    "corassem": "corar",
    "corasses": "corar",
    "coraste": "corar",
    "corastes": "corar",
    "corava": "corar",
    "coravam": "corar",
    "coravas": "corar",
    "coraçãozinho": "coração",
    "coraçãozito": "coração",
    "corações": "coração",
    "coraçõezinhos": "coração",
    "coraçõezitos": "coração",
    "corbelhas": "corbelha",
    "corca": "corcar",
    "corcada": "corcar",
    "corcadas": "corcar",
    "corcado": "corcar",
    "corcados": "corcar",
    "corcai": "corcar",
    "corcais": "corcar",
    "corcam": "corcar",
    "corcamo": "corcar",
    "corcamos": "corcar",
    "corcando": "corcar",
    "corcara": "corcar",
    "corcaram": "corcar",
    "corcaras": "corcar",
    "corcarde": "corcar",
    "corcardes": "corcar",
    "corcare": "corcar",
    "corcarei": "corcar",
    "corcareis": "corcar",
    "corcarem": "corcar",
    "corcaremos": "corcar",
    "corcares": "corcar",
    "corcaria": "corcar",
    "corcariam": "corcar",
    "corcarias": "corcar",
    "corcarmo": "corcar",
    "corcarmos": "corcar",
    "corcará": "corcar",
    "corcarás": "corcar",
    "corcarão": "corcar",
    "corcaríamos": "corcar",
    "corcaríeis": "corcar",
    "corcas": "corcar",
    "corcasse": "corcar",
    "corcassem": "corcar",
    "corcasses": "corcar",
    "corcaste": "corcar",
    "corcastes": "corcar",
    "corcava": "corcar",
    "corcavam": "corcar",
    "corcavas": "corcar",
    "corceis": "corcel",
    "corchas": "corcha",
    "corchos": "corcho",
    "corco": "corcar",
    "corcou": "corcar",
    "corcova": "corcovar",
    "corcovada": "corcovar",
    "corcovadas": "corcovar",
    "corcovado": "corcovar",
    "corcovados": "corcovar",
    "corcovai": "corcovar",
    "corcovais": "corcovar",
    "corcovam": "corcovar",
    "corcovamo": "corcovar",
    "corcovamos": "corcovar",
    "corcovando": "corcovar",
    "corcovara": "corcovar",
    "corcovaram": "corcovar",
    "corcovaras": "corcovar",
    "corcovarde": "corcovar",
    "corcovardes": "corcovar",
    "corcovare": "corcovar",
    "corcovarei": "corcovar",
    "corcovareis": "corcovar",
    "corcovarem": "corcovar",
    "corcovaremos": "corcovar",
    "corcovares": "corcovar",
    "corcovaria": "corcovar",
    "corcovariam": "corcovar",
    "corcovarias": "corcovar",
    "corcovarmo": "corcovar",
    "corcovarmos": "corcovar",
    "corcovará": "corcovar",
    "corcovarás": "corcovar",
    "corcovarão": "corcovar",
    "corcovaríamos": "corcovar",
    "corcovaríeis": "corcovar",
    "corcovas": "corcovar",
    "corcovasse": "corcovar",
    "corcovassem": "corcovar",
    "corcovasses": "corcovar",
    "corcovaste": "corcovar",
    "corcovastes": "corcovar",
    "corcovava": "corcovar",
    "corcovavam": "corcovar",
    "corcovavas": "corcovar",
    "corcove": "corcovar",
    "corcoveada": "corcovear",
    "corcoveadas": "corcovear",
    "corcoveado": "corcovear",
    "corcoveados": "corcovear",
    "corcoveai": "corcovear",
    "corcoveais": "corcovear",
    "corcoveamo": "corcovear",
    "corcoveamos": "corcovear",
    "corcoveando": "corcovear",
    "corcoveara": "corcovear",
    "corcovearam": "corcovear",
    "corcovearas": "corcovear",
    "corcovearde": "corcovear",
    "corcoveardes": "corcovear",
    "corcoveare": "corcovear",
    "corcovearei": "corcovear",
    "corcoveareis": "corcovear",
    "corcovearem": "corcovear",
    "corcovearemos": "corcovear",
    "corcoveares": "corcovear",
    "corcovearia": "corcovear",
    "corcoveariam": "corcovear",
    "corcovearias": "corcovear",
    "corcovearmo": "corcovear",
    "corcovearmos": "corcovear",
    "corcoveará": "corcovear",
    "corcovearás": "corcovear",
    "corcovearão": "corcovear",
    "corcovearíamos": "corcovear",
    "corcovearíeis": "corcovear",
    "corcoveasse": "corcovear",
    "corcoveassem": "corcovear",
    "corcoveasses": "corcovear",
    "corcoveaste": "corcovear",
    "corcoveastes": "corcovear",
    "corcoveava": "corcovear",
    "corcoveavam": "corcovear",
    "corcoveavas": "corcovear",
    "corcoveei": "corcovear",
    "corcoveeis": "corcovear",
    "corcoveemo": "corcovear",
    "corcoveemos": "corcovear",
    "corcovei": "corcovar",
    "corcoveia": "corcovear",
    "corcoveiam": "corcovear",
    "corcoveias": "corcovear",
    "corcoveie": "corcovear",
    "corcoveiem": "corcovear",
    "corcoveies": "corcovear",
    "corcoveio": "corcovear",
    "corcoveis": "corcovar",
    "corcovem": "corcovar",
    "corcovemo": "corcovar",
    "corcovemos": "corcovar",
    "corcoveou": "corcovear",
    "corcoves": "corcovar",
    "corcoveá": "corcovear",
    "corcoveámo": "corcovear",
    "corcoveámos": "corcovear",
    "corcoveáramo": "corcovear",
    "corcoveáramos": "corcovear",
    "corcoveárei": "corcovear",
    "corcoveáreis": "corcovear",
    "corcoveásseis": "corcovear",
    "corcoveássemos": "corcovear",
    "corcoveávamo": "corcovear",
    "corcoveávamos": "corcovear",
    "corcoveávei": "corcovear",
    "corcoveáveis": "corcovear",
    "corcovo": "corcovar",
    "corcovos": "corcovo",
    "corcovou": "corcovar",
    "corcová": "corcovar",
    "corcovámo": "corcovar",
    "corcovámos": "corcovar",
    "corcováramo": "corcovar",
    "corcováramos": "corcovar",
    "corcovárei": "corcovar",
    "corcováreis": "corcovar",
    "corcovásseis": "corcovar",
    "corcovássemos": "corcovar",
    "corcovávamo": "corcovar",
    "corcovávamos": "corcovar",
    "corcovávei": "corcovar",
    "corcováveis": "corcovar",
    "corcundas": "corcunda",
    "corcá": "corcar",
    "corcámo": "corcar",
    "corcámos": "corcar",
    "corcáramo": "corcar",
    "corcáramos": "corcar",
    "corcárei": "corcar",
    "corcáreis": "corcar",
    "corcásseis": "corcar",
    "corcássemos": "corcar",
    "corcávamo": "corcar",
    "corcávamos": "corcar",
    "corcávei": "corcar",
    "corcáveis": "corcar",
    "corcíveis": "corcível",
    "corda": "cordo",
    "cordada": "cordado",
    "cordadas": "cordado",
    "cordados": "cordado",
    "cordames": "cordame",
    "cordas": "cordo",
    "cordata": "cordato",
    "cordatas": "cordato",
    "cordatos": "cordato",
    "cordeada": "cordear",
    "cordeadas": "cordear",
    "cordeado": "cordear",
    "cordeados": "cordear",
    "cordeai": "cordear",
    "cordeais": "cordear",
    "cordeamo": "cordear",
    "cordeamos": "cordear",
    "cordeando": "cordear",
    "cordeara": "cordear",
    "cordearam": "cordear",
    "cordearas": "cordear",
    "cordearde": "cordear",
    "cordeardes": "cordear",
    "cordeare": "cordear",
    "cordearei": "cordear",
    "cordeareis": "cordear",
    "cordearem": "cordear",
    "cordearemos": "cordear",
    "cordeares": "cordear",
    "cordearia": "cordear",
    "cordeariam": "cordear",
    "cordearias": "cordear",
    "cordearmo": "cordear",
    "cordearmos": "cordear",
    "cordeará": "cordear",
    "cordearás": "cordear",
    "cordearão": "cordear",
    "cordearíamos": "cordear",
    "cordearíeis": "cordear",
    "cordeasse": "cordear",
    "cordeassem": "cordear",
    "cordeasses": "cordear",
    "cordeaste": "cordear",
    "cordeastes": "cordear",
    "cordeava": "cordear",
    "cordeavam": "cordear",
    "cordeavas": "cordear",
    "cordeações": "cordeação",
    "cordeei": "cordear",
    "cordeeis": "cordear",
    "cordeemo": "cordear",
    "cordeemos": "cordear",
    "cordeia": "cordear",
    "cordeiam": "cordear",
    "cordeias": "cordear",
    "cordeie": "cordear",
    "cordeiem": "cordear",
    "cordeies": "cordear",
    "cordeio": "cordear",
    "cordeira": "cordeiro",
    "cordeiras": "cordeiro",
    "cordeirinha": "cordeiro",
    "cordeirinhas": "cordeiro",
    "cordeirinho": "cordeiro",
    "cordeirinhos": "cordeiro",
    "cordeirita": "cordeiro",
    "cordeiritas": "cordeiro",
    "cordeirito": "cordeiro",
    "cordeiritos": "cordeiro",
    "cordeiros": "cordeiro",
    "cordeitínea": "cordeitíneo",
    "cordeitíneas": "cordeitíneo",
    "cordeitíneos": "cordeitíneo",
    "cordelinhos": "cordelinho",
    "cordeou": "cordear",
    "cordeá": "cordear",
    "cordeámo": "cordear",
    "cordeámos": "cordear",
    "cordeáramo": "cordear",
    "cordeáramos": "cordear",
    "cordeárei": "cordear",
    "cordeáreis": "cordear",
    "cordeásseis": "cordear",
    "cordeássemos": "cordear",
    "cordeávamo": "cordear",
    "cordeávamos": "cordear",
    "cordeávei": "cordear",
    "cordeáveis": "cordear",
    "cordeítes": "cordeíte",
    "cordiais": "cordial",
    "cordialidades": "cordialidade",
    "cordializa": "cordializar",
    "cordializada": "cordializar",
    "cordializadas": "cordializar",
    "cordializado": "cordializar",
    "cordializados": "cordializar",
    "cordializai": "cordializar",
    "cordializais": "cordializar",
    "cordializam": "cordializar",
    "cordializamo": "cordializar",
    "cordializamos": "cordializar",
    "cordializando": "cordializar",
    "cordializara": "cordializar",
    "cordializaram": "cordializar",
    "cordializaras": "cordializar",
    "cordializarde": "cordializar",
    "cordializardes": "cordializar",
    "cordializare": "cordializar",
    "cordializarei": "cordializar",
    "cordializareis": "cordializar",
    "cordializarem": "cordializar",
    "cordializaremos": "cordializar",
    "cordializares": "cordializar",
    "cordializaria": "cordializar",
    "cordializariam": "cordializar",
    "cordializarias": "cordializar",
    "cordializarmo": "cordializar",
    "cordializarmos": "cordializar",
    "cordializará": "cordializar",
    "cordializarás": "cordializar",
    "cordializarão": "cordializar",
    "cordializaríamos": "cordializar",
    "cordializaríeis": "cordializar",
    "cordializas": "cordializar",
    "cordializasse": "cordializar",
    "cordializassem": "cordializar",
    "cordializasses": "cordializar",
    "cordializaste": "cordializar",
    "cordializastes": "cordializar",
    "cordializava": "cordializar",
    "cordializavam": "cordializar",
    "cordializavas": "cordializar",
    "cordialize": "cordializar",
    "cordializei": "cordializar",
    "cordializeis": "cordializar",
    "cordializem": "cordializar",
    "cordializemo": "cordializar",
    "cordializemos": "cordializar",
    "cordializes": "cordializar",
    "cordializo": "cordializar",
    "cordializou": "cordializar",
    "cordializá": "cordializar",
    "cordializámo": "cordializar",
    "cordializámos": "cordializar",
    "cordializáramo": "cordializar",
    "cordializáramos": "cordializar",
    "cordializárei": "cordializar",
    "cordializáreis": "cordializar",
    "cordializásseis": "cordializar",
    "cordializássemos": "cordializar",
    "cordializávamo": "cordializar",
    "cordializávamos": "cordializar",
    "cordializávei": "cordializar",
    "cordializáveis": "cordializar",
    "cordialíssima": "cordial",
    "cordialíssimas": "cordial",
    "cordialíssimo": "cordial",
    "cordialíssimos": "cordial",
    "cordierites": "cordierite",
    "cordiformes": "cordiforme",
    "cordifólia": "cordifólio",
    "cordifólias": "cordifólio",
    "cordifólios": "cordifólio",
    "cordilhas": "cordilha",
    "cordilheiras": "cordilheira",
    "cordinha": "corda",
    "cordinhas": "corda",
    "cordita": "corda",
    "corditas": "corda",
    "cordites": "cordite",
    "cordoa": "cordoar",
    "cordoada": "cordoar",
    "cordoadas": "cordoar",
    "cordoado": "cordoar",
    "cordoados": "cordoar",
    "cordoagens": "cordoagem",
    "cordoai": "cordoar",
    "cordoais": "cordoar",
    "cordoam": "cordoar",
    "cordoames": "cordoame",
    "cordoamo": "cordoar",
    "cordoamos": "cordoar",
    "cordoando": "cordoar",
    "cordoara": "cordoar",
    "cordoaram": "cordoar",
    "cordoaras": "cordoar",
    "cordoarde": "cordoar",
    "cordoardes": "cordoar",
    "cordoare": "cordoar",
    "cordoarei": "cordoar",
    "cordoareis": "cordoar",
    "cordoarem": "cordoar",
    "cordoaremos": "cordoar",
    "cordoares": "cordoar",
    "cordoaria": "cordoar",
    "cordoariam": "cordoar",
    "cordoarias": "cordoaria",
    "cordoarmo": "cordoar",
    "cordoarmos": "cordoar",
    "cordoará": "cordoar",
    "cordoarás": "cordoar",
    "cordoarão": "cordoar",
    "cordoaríamos": "cordoar",
    "cordoaríeis": "cordoar",
    "cordoas": "cordoar",
    "cordoasse": "cordoar",
    "cordoassem": "cordoar",
    "cordoasses": "cordoar",
    "cordoaste": "cordoar",
    "cordoastes": "cordoar",
    "cordoava": "cordoar",
    "cordoavam": "cordoar",
    "cordoavas": "cordoar",
    "cordoe": "cordoar",
    "cordoei": "cordoar",
    "cordoeira": "cordoeiro",
    "cordoeiras": "cordoeiro",
    "cordoeiros": "cordoeiro",
    "cordoeis": "cordoar",
    "cordoem": "cordoar",
    "cordoemo": "cordoar",
    "cordoemos": "cordoar",
    "cordoes": "cordoar",
    "cordoo": "cordoar",
    "cordoou": "cordoar",
    "cordos": "cordo",
    "cordovaneira": "cordovaneiro",
    "cordovaneiras": "cordovaneiro",
    "cordovaneiros": "cordovaneiro",
    "cordoveada": "cordoveado",
    "cordoveadas": "cordoveado",
    "cordoveados": "cordoveado",
    "cordoveias": "cordoveia",
    "cordovesa": "cordovês",
    "cordovesas": "cordovês",
    "cordoveses": "cordovês",
    "cordovis": "cordovil",
    "cordovões": "cordovão",
    "cordoá": "cordoar",
    "cordoámo": "cordoar",
    "cordoámos": "cordoar",
    "cordoáramo": "cordoar",
    "cordoáramos": "cordoar",
    "cordoárei": "cordoar",
    "cordoáreis": "cordoar",
    "cordoásseis": "cordoar",
    "cordoássemos": "cordoar",
    "cordoávamo": "cordoar",
    "cordoávamos": "cordoar",
    "cordoávei": "cordoar",
    "cordoáveis": "cordoar",
    "corduras": "cordura",
    "cordãozinho": "cordão",
    "cordãozito": "cordão",
    "cordéis": "cordel",
    "cordões": "cordão",
    "cordõezinhos": "cordão",
    "cordõezitos": "cordão",
    "core": "corar",
    "coreana": "coreano",
    "coreanas": "coreano",
    "coreaniácea": "coreaniáceo",
    "coreaniáceas": "coreaniáceo",
    "coreaniáceos": "coreaniáceo",
    "coreanos": "coreano",
    "coregrafias": "coregrafia",
    "corei": "corar",
    "coreiformes": "coreiforme",
    "coreira": "coreiro",
    "coreiras": "coreiro",
    "coreiros": "coreiro",
    "coreis": "corar",
    "corem": "corar",
    "coremo": "corar",
    "coremos": "corar",
    "corentes": "corente",
    "coreografa": "coreografar",
    "coreografada": "coreografar",
    "coreografadas": "coreografar",
    "coreografado": "coreografar",
    "coreografados": "coreografar",
    "coreografai": "coreografar",
    "coreografais": "coreografar",
    "coreografam": "coreografar",
    "coreografamo": "coreografar",
    "coreografamos": "coreografar",
    "coreografando": "coreografar",
    "coreografara": "coreografar",
    "coreografaram": "coreografar",
    "coreografaras": "coreografar",
    "coreografarde": "coreografar",
    "coreografardes": "coreografar",
    "coreografare": "coreografar",
    "coreografarei": "coreografar",
    "coreografareis": "coreografar",
    "coreografarem": "coreografar",
    "coreografaremos": "coreografar",
    "coreografares": "coreografar",
    "coreografaria": "coreografar",
    "coreografariam": "coreografar",
    "coreografarias": "coreografar",
    "coreografarmo": "coreografar",
    "coreografarmos": "coreografar",
    "coreografará": "coreografar",
    "coreografarás": "coreografar",
    "coreografarão": "coreografar",
    "coreografaríamos": "coreografar",
    "coreografaríeis": "coreografar",
    "coreografas": "coreografar",
    "coreografasse": "coreografar",
    "coreografassem": "coreografar",
    "coreografasses": "coreografar",
    "coreografaste": "coreografar",
    "coreografastes": "coreografar",
    "coreografava": "coreografar",
    "coreografavam": "coreografar",
    "coreografavas": "coreografar",
    "coreografe": "coreografar",
    "coreografei": "coreografar",
    "coreografeis": "coreografar",
    "coreografem": "coreografar",
    "coreografemo": "coreografar",
    "coreografemos": "coreografar",
    "coreografes": "coreografar",
    "coreografias": "coreografia",
    "coreografo": "coreografar",
    "coreografou": "coreografar",
    "coreografá": "coreografar",
    "coreografámo": "coreografar",
    "coreografámos": "coreografar",
    "coreografáramo": "coreografar",
    "coreografáramos": "coreografar",
    "coreografárei": "coreografar",
    "coreografáreis": "coreografar",
    "coreografásseis": "coreografar",
    "coreografássemos": "coreografar",
    "coreografávamo": "coreografar",
    "coreografávamos": "coreografar",
    "coreografávei": "coreografar",
    "coreografáveis": "coreografar",
    "coreográfica": "coreográfico",
    "coreográficas": "coreográfico",
    "coreográficos": "coreográfico",
    "coreomanias": "coreomania",
    "coreomaníaca": "coreomaníaco",
    "coreomaníacas": "coreomaníaco",
    "coreomaníacos": "coreomaníaco",
    "cores": "corar",
    "coretos": "coreto",
    "coreutas": "coreuta",
    "coreácia": "coreácio",
    "coreácias": "coreácio",
    "coreácios": "coreácio",
    "coreógrafa": "coreógrafo",
    "coreógrafas": "coreógrafo",
    "coreógrafos": "coreógrafo",
    "coreómana": "coreómano",
    "coreómanas": "coreómano",
    "coreómanos": "coreómano",
    "corgas": "corga",
    "corgos": "corgo",
    "coriambos": "coriambo",
    "coriandros": "coriandro",
    "coriariáceas": "coriariácea",
    "coribantes": "coribante",
    "coricidas": "coricida",
    "corifeus": "corifeu",
    "corifoliada": "corifoliado",
    "corifoliadas": "corifoliado",
    "corifoliados": "corifoliado",
    "coriláceas": "corilácea",
    "corimbiformes": "corimbiforme",
    "corimbos": "corimbo",
    "corimbosa": "corimboso",
    "corimbosas": "corimboso",
    "corimbosos": "corimboso",
    "corimbífera": "corimbífero",
    "corimbíferas": "corimbífero",
    "corimbíferos": "corimbífero",
    "corinas": "corina",
    "corindos": "corindo",
    "coringas": "coringa",
    "corintos": "corinto",
    "corioplasta": "corioplasto",
    "corioplastas": "corioplasto",
    "corioplastias": "corioplastia",
    "corioplastos": "corioplasto",
    "coris": "cori",
    "corisca": "coriscar",
    "coriscada": "coriscar",
    "coriscadas": "coriscar",
    "coriscado": "coriscar",
    "coriscados": "coriscar",
    "coriscai": "coriscar",
    "coriscais": "coriscar",
    "coriscam": "coriscar",
    "coriscamo": "coriscar",
    "coriscamos": "coriscar",
    "coriscando": "coriscar",
    "coriscantes": "coriscante",
    "coriscara": "coriscar",
    "coriscaram": "coriscar",
    "coriscaras": "coriscar",
    "coriscarde": "coriscar",
    "coriscardes": "coriscar",
    "coriscare": "coriscar",
    "coriscarei": "coriscar",
    "coriscareis": "coriscar",
    "coriscarem": "coriscar",
    "coriscaremos": "coriscar",
    "coriscares": "coriscar",
    "coriscaria": "coriscar",
    "coriscariam": "coriscar",
    "coriscarias": "coriscar",
    "coriscarmo": "coriscar",
    "coriscarmos": "coriscar",
    "coriscará": "coriscar",
    "coriscarás": "coriscar",
    "coriscarão": "coriscar",
    "coriscaríamos": "coriscar",
    "coriscaríeis": "coriscar",
    "coriscas": "coriscar",
    "coriscasse": "coriscar",
    "coriscassem": "coriscar",
    "coriscasses": "coriscar",
    "coriscaste": "coriscar",
    "coriscastes": "coriscar",
    "coriscava": "coriscar",
    "coriscavam": "coriscar",
    "coriscavas": "coriscar",
    "coriscações": "coriscação",
    "corisco": "coriscar",
    "coriscos": "corisco",
    "coriscou": "coriscar",
    "coriscá": "coriscar",
    "coriscámo": "coriscar",
    "coriscámos": "coriscar",
    "coriscáramo": "coriscar",
    "coriscáramos": "coriscar",
    "coriscárei": "coriscar",
    "coriscáreis": "coriscar",
    "coriscásseis": "coriscar",
    "coriscássemos": "coriscar",
    "coriscávamo": "coriscar",
    "coriscávamos": "coriscar",
    "coriscávei": "coriscar",
    "coriscáveis": "coriscar",
    "corisque": "coriscar",
    "corisquei": "coriscar",
    "corisqueis": "coriscar",
    "corisquem": "coriscar",
    "corisquemo": "coriscar",
    "corisquemos": "coriscar",
    "corisques": "coriscar",
    "coristas": "corista",
    "corizontes": "corizonte",
    "coriácea": "coriáceo",
    "coriáceas": "coriáceo",
    "coriáceos": "coriáceo",
    "coriárias": "coriária",
    "coriânica": "coriânico",
    "coriânicas": "coriânico",
    "coriânicos": "coriânico",
    "corióides": "corióide",
    "corjas": "corja",
    "cormos": "cormo",
    "cormófitas": "cormófita",
    "cormófitos": "cormófito",
    "corna": "cornar",
    "cornacas": "cornaca",
    "cornada": "cornar",
    "cornadas": "cornar",
    "cornado": "cornar",
    "cornados": "cornar",
    "cornaduras": "cornadura",
    "cornai": "cornar",
    "cornais": "cornar",
    "cornalheiras": "cornalheira",
    "cornalinas": "cornalina",
    "cornalões": "cornalão",
    "cornam": "cornar",
    "cornamentas": "cornamenta",
    "cornamo": "cornar",
    "cornamos": "cornar",
    "cornamusas": "cornamusa",
    "cornando": "cornar",
    "cornara": "cornar",
    "cornaram": "cornar",
    "cornaras": "cornar",
    "cornarde": "cornar",
    "cornardes": "cornar",
    "cornare": "cornar",
    "cornarei": "cornar",
    "cornareis": "cornar",
    "cornarem": "cornar",
    "cornaremos": "cornar",
    "cornares": "cornar",
    "cornaria": "cornar",
    "cornariam": "cornar",
    "cornarias": "cornar",
    "cornarmo": "cornar",
    "cornarmos": "cornar",
    "cornará": "cornar",
    "cornarás": "cornar",
    "cornarão": "cornar",
    "cornaríamos": "cornar",
    "cornaríeis": "cornar",
    "cornas": "cornar",
    "cornasse": "cornar",
    "cornassem": "cornar",
    "cornasses": "cornar",
    "cornaste": "cornar",
    "cornastes": "cornar",
    "cornava": "cornar",
    "cornavam": "cornar",
    "cornavas": "cornar",
    "corne": "cornar",
    "corneada": "cornear",
    "corneadas": "cornear",
    "corneado": "cornear",
    "corneadora": "corneador",
    "corneadoras": "corneador",
    "corneadores": "corneador",
    "corneados": "cornear",
    "corneai": "cornear",
    "corneais": "cornear",
    "corneamo": "cornear",
    "corneamos": "cornear",
    "corneanas": "corneana",
    "corneando": "cornear",
    "corneara": "cornear",
    "cornearam": "cornear",
    "cornearas": "cornear",
    "cornearde": "cornear",
    "corneardes": "cornear",
    "corneare": "cornear",
    "cornearei": "cornear",
    "corneareis": "cornear",
    "cornearem": "cornear",
    "cornearemos": "cornear",
    "corneares": "cornear",
    "cornearia": "cornear",
    "corneariam": "cornear",
    "cornearias": "cornear",
    "cornearmo": "cornear",
    "cornearmos": "cornear",
    "corneará": "cornear",
    "cornearás": "cornear",
    "cornearão": "cornear",
    "cornearíamos": "cornear",
    "cornearíeis": "cornear",
    "corneasse": "cornear",
    "corneassem": "cornear",
    "corneasses": "cornear",
    "corneaste": "cornear",
    "corneastes": "cornear",
    "corneava": "cornear",
    "corneavam": "cornear",
    "corneavas": "cornear",
    "corneações": "corneação",
    "cornechas": "cornecha",
    "cornechos": "cornecho",
    "corneei": "cornear",
    "corneeis": "cornear",
    "corneemo": "cornear",
    "corneemos": "cornear",
    "cornei": "cornar",
    "corneia": "cornear",
    "corneiam": "cornear",
    "corneias": "cornear",
    "corneie": "cornear",
    "corneiem": "cornear",
    "corneies": "cornear",
    "corneio": "cornear",
    "corneiras": "corneira",
    "corneis": "cornar",
    "corneja": "cornejar",
    "cornejada": "cornejar",
    "cornejadas": "cornejar",
    "cornejado": "cornejar",
    "cornejados": "cornejar",
    "cornejai": "cornejar",
    "cornejais": "cornejar",
    "cornejam": "cornejar",
    "cornejamo": "cornejar",
    "cornejamos": "cornejar",
    "cornejando": "cornejar",
    "cornejara": "cornejar",
    "cornejaram": "cornejar",
    "cornejaras": "cornejar",
    "cornejardes": "cornejar",
    "cornejarei": "cornejar",
    "cornejareis": "cornejar",
    "cornejarem": "cornejar",
    "cornejaremos": "cornejar",
    "cornejares": "cornejar",
    "cornejaria": "cornejar",
    "cornejariam": "cornejar",
    "cornejarias": "cornejar",
    "cornejarmo": "cornejar",
    "cornejarmos": "cornejar",
    "cornejará": "cornejar",
    "cornejarás": "cornejar",
    "cornejarão": "cornejar",
    "cornejaríamos": "cornejar",
    "cornejaríeis": "cornejar",
    "cornejas": "cornejar",
    "cornejasse": "cornejar",
    "cornejassem": "cornejar",
    "cornejasses": "cornejar",
    "cornejaste": "cornejar",
    "cornejastes": "cornejar",
    "cornejava": "cornejar",
    "cornejavam": "cornejar",
    "cornejavas": "cornejar",
    "corneje": "cornejar",
    "cornejei": "cornejar",
    "cornejeis": "cornejar",
    "cornejem": "cornejar",
    "cornejemo": "cornejar",
    "cornejemos": "cornejar",
    "cornejes": "cornejar",
    "cornejo": "cornejar",
    "cornejou": "cornejar",
    "cornejámo": "cornejar",
    "cornejámos": "cornejar",
    "cornejáramo": "cornejar",
    "cornejáramos": "cornejar",
    "cornejáreis": "cornejar",
    "cornejásseis": "cornejar",
    "cornejássemos": "cornejar",
    "cornejávamo": "cornejar",
    "cornejávamos": "cornejar",
    "cornejáveis": "cornejar",
    "cornelas": "cornela",
    "cornem": "cornar",
    "cornemo": "cornar",
    "cornemos": "cornar",
    "corneou": "cornear",
    "cornes": "corne",
    "cornetadas": "cornetada",
    "cornetas": "corneta",
    "corneteada": "cornetear",
    "corneteadas": "cornetear",
    "corneteado": "cornetear",
    "corneteados": "cornetear",
    "corneteai": "cornetear",
    "corneteais": "cornetear",
    "corneteamo": "cornetear",
    "corneteamos": "cornetear",
    "corneteando": "cornetear",
    "corneteara": "cornetear",
    "cornetearam": "cornetear",
    "cornetearas": "cornetear",
    "corneteardes": "cornetear",
    "cornetearei": "cornetear",
    "corneteareis": "cornetear",
    "cornetearem": "cornetear",
    "cornetearemos": "cornetear",
    "corneteares": "cornetear",
    "cornetearia": "cornetear",
    "corneteariam": "cornetear",
    "cornetearias": "cornetear",
    "cornetearmo": "cornetear",
    "cornetearmos": "cornetear",
    "corneteará": "cornetear",
    "cornetearás": "cornetear",
    "cornetearão": "cornetear",
    "cornetearíamos": "cornetear",
    "cornetearíeis": "cornetear",
    "corneteasse": "cornetear",
    "corneteassem": "cornetear",
    "corneteasses": "cornetear",
    "corneteaste": "cornetear",
    "corneteastes": "cornetear",
    "corneteava": "cornetear",
    "corneteavam": "cornetear",
    "corneteavas": "cornetear",
    "corneteei": "cornetear",
    "corneteeis": "cornetear",
    "corneteemo": "cornetear",
    "corneteemos": "cornetear",
    "corneteia": "cornetear",
    "corneteiam": "cornetear",
    "corneteias": "cornetear",
    "corneteie": "cornetear",
    "corneteiem": "cornetear",
    "corneteies": "cornetear",
    "corneteio": "cornetear",
    "corneteiros": "corneteiro",
    "corneteou": "cornetear",
    "corneteámo": "cornetear",
    "corneteámos": "cornetear",
    "corneteáramo": "cornetear",
    "corneteáramos": "cornetear",
    "corneteáreis": "cornetear",
    "corneteásseis": "cornetear",
    "corneteássemos": "cornetear",
    "corneteávamo": "cornetear",
    "corneteávamos": "cornetear",
    "corneteáveis": "cornetear",
    "cornetinha": "corneta",
    "cornetinhas": "corneta",
    "cornetins": "cornetim",
    "cornetita": "corneta",
    "cornetitas": "corneta",
    "cornetos": "corneto",
    "cornetões": "cornetão",
    "corneá": "cornear",
    "corneáceas": "corneácea",
    "corneámo": "cornear",
    "corneámos": "cornear",
    "corneáramo": "cornear",
    "corneáramos": "cornear",
    "corneárei": "cornear",
    "corneáreis": "cornear",
    "corneásseis": "cornear",
    "corneássemos": "cornear",
    "corneávamo": "cornear",
    "corneávamos": "cornear",
    "corneávei": "cornear",
    "corneáveis": "cornear",
    "corniaberta": "corniaberto",
    "corniabertas": "corniaberto",
    "corniabertos": "corniaberto",
    "cornialta": "cornialto",
    "cornialtas": "cornialto",
    "cornialtos": "cornialto",
    "cornibaixa": "cornibaixo",
    "cornibaixas": "cornibaixo",
    "cornibaixos": "cornibaixo",
    "cornicabras": "cornicabra",
    "cornichos": "cornicho",
    "cornichosa": "cornichoso",
    "cornichosas": "cornichoso",
    "cornichosos": "cornichoso",
    "corniculada": "corniculado",
    "corniculadas": "corniculado",
    "corniculados": "corniculado",
    "cornicurta": "cornicurto",
    "cornicurtas": "cornicurto",
    "cornicurtos": "cornicurto",
    "cornicões": "cornicão",
    "cornifica": "cornificar",
    "cornificada": "cornificar",
    "cornificadas": "cornificar",
    "cornificado": "cornificar",
    "cornificados": "cornificar",
    "cornificai": "cornificar",
    "cornificais": "cornificar",
    "cornificam": "cornificar",
    "cornificamo": "cornificar",
    "cornificamos": "cornificar",
    "cornificando": "cornificar",
    "cornificara": "cornificar",
    "cornificaram": "cornificar",
    "cornificaras": "cornificar",
    "cornificarde": "cornificar",
    "cornificardes": "cornificar",
    "cornificare": "cornificar",
    "cornificarei": "cornificar",
    "cornificareis": "cornificar",
    "cornificarem": "cornificar",
    "cornificaremos": "cornificar",
    "cornificares": "cornificar",
    "cornificaria": "cornificar",
    "cornificariam": "cornificar",
    "cornificarias": "cornificar",
    "cornificarmo": "cornificar",
    "cornificarmos": "cornificar",
    "cornificará": "cornificar",
    "cornificarás": "cornificar",
    "cornificarão": "cornificar",
    "cornificaríamos": "cornificar",
    "cornificaríeis": "cornificar",
    "cornificas": "cornificar",
    "cornificasse": "cornificar",
    "cornificassem": "cornificar",
    "cornificasses": "cornificar",
    "cornificaste": "cornificar",
    "cornificastes": "cornificar",
    "cornificava": "cornificar",
    "cornificavam": "cornificar",
    "cornificavas": "cornificar",
    "cornifico": "cornificar",
    "cornificou": "cornificar",
    "cornificá": "cornificar",
    "cornificámo": "cornificar",
    "cornificámos": "cornificar",
    "cornificáramo": "cornificar",
    "cornificáramos": "cornificar",
    "cornificárei": "cornificar",
    "cornificáreis": "cornificar",
    "cornificásseis": "cornificar",
    "cornificássemos": "cornificar",
    "cornificávamo": "cornificar",
    "cornificávamos": "cornificar",
    "cornificávei": "cornificar",
    "cornificáveis": "cornificar",
    "cornifique": "cornificar",
    "cornifiquei": "cornificar",
    "cornifiqueis": "cornificar",
    "cornifiquem": "cornificar",
    "cornifiquemo": "cornificar",
    "cornifiquemos": "cornificar",
    "cornifiques": "cornificar",
    "corniformes": "corniforme",
    "cornijas": "cornija",
    "cornilarga": "cornilargo",
    "cornilargas": "cornilargo",
    "cornilargos": "cornilargo",
    "cornilhões": "cornilhão",
    "cornimboques": "cornimboque",
    "corninho": "corno",
    "corninhos": "corno",
    "cornipos": "cornipo",
    "cornito": "corno",
    "cornitos": "corno",
    "cornizolos": "cornizolo",
    "cornizos": "cornizo",
    "corno": "cornar",
    "cornogodinhos": "cornogodinho",
    "cornográfica": "cornográfico",
    "cornográficas": "cornográfico",
    "cornográficos": "cornográfico",
    "cornos": "corno",
    "cornou": "cornar",
    "cornozelos": "cornozelo",
    "cornucópias": "cornucópia",
    "cornuda": "cornudo",
    "cornudas": "cornudo",
    "cornudos": "cornudo",
    "cornuta": "cornuto",
    "cornutas": "cornuto",
    "cornutos": "cornuto",
    "corná": "cornar",
    "cornácea": "cornáceo",
    "cornáceas": "cornáceo",
    "cornáceos": "cornáceo",
    "cornámo": "cornar",
    "cornámos": "cornar",
    "cornáramo": "cornar",
    "cornáramos": "cornar",
    "cornárei": "cornar",
    "cornáreis": "cornar",
    "cornásseis": "cornar",
    "cornássemos": "cornar",
    "cornávamo": "cornar",
    "cornávamos": "cornar",
    "cornávei": "cornar",
    "cornáveis": "cornar",
    "cornículos": "cornículo",
    "cornífera": "cornífero",
    "corníferas": "cornífero",
    "corníferos": "cornífero",
    "cornígera": "cornígero",
    "cornígeras": "cornígero",
    "cornígeros": "cornígero",
    "corníolas": "corníola",
    "corníolos": "corníolo",
    "cornípedes": "cornípede",
    "cornípeta": "cornípeto",
    "cornípetas": "cornípeto",
    "cornípetos": "cornípeto",
    "cornóides": "cornóide",
    "coro": "corar",
    "coroa": "coroar",
    "coroada": "coroar",
    "coroadas": "coroar",
    "coroado": "coroar",
    "coroados": "coroar",
    "coroai": "coroar",
    "coroais": "coroar",
    "coroam": "coroar",
    "coroamentos": "coroamento",
    "coroamo": "coroar",
    "coroamos": "coroar",
    "coroando": "coroar",
    "coroara": "coroar",
    "coroaram": "coroar",
    "coroaras": "coroar",
    "coroarde": "coroar",
    "coroardes": "coroar",
    "coroare": "coroar",
    "coroarei": "coroar",
    "coroareis": "coroar",
    "coroarem": "coroar",
    "coroaremos": "coroar",
    "coroares": "coroar",
    "coroaria": "coroar",
    "coroariam": "coroar",
    "coroarias": "coroar",
    "coroarmo": "coroar",
    "coroarmos": "coroar",
    "coroará": "coroar",
    "coroarás": "coroar",
    "coroarão": "coroar",
    "coroaríamos": "coroar",
    "coroaríeis": "coroar",
    "coroas": "coroar",
    "coroasse": "coroar",
    "coroassem": "coroar",
    "coroasses": "coroar",
    "coroaste": "coroar",
    "coroastes": "coroar",
    "coroava": "coroar",
    "coroavam": "coroar",
    "coroavas": "coroar",
    "coroações": "coroação",
    "corocas": "coroca",
    "corodidáscalos": "corodidáscalo",
    "coroe": "coroar",
    "coroei": "coroar",
    "coroeis": "coroar",
    "coroem": "coroar",
    "coroemo": "coroar",
    "coroemos": "coroar",
    "coroes": "coroar",
    "corofones": "corofone",
    "corografias": "corografia",
    "coroidites": "coroidite",
    "coroidéias": "coroidéia",
    "coroinhas": "coroinha",
    "corolas": "corola",
    "coroliformes": "coroliforme",
    "corolina": "corolino",
    "corolinas": "corolino",
    "corolinos": "corolino",
    "corolácea": "coroláceo",
    "coroláceas": "coroláceo",
    "coroláceos": "coroláceo",
    "corolários": "corolário",
    "corolífera": "corolífero",
    "corolíferas": "corolífero",
    "corolíferos": "corolífero",
    "corolítica": "corolítico",
    "corolíticas": "corolítico",
    "corolíticos": "corolítico",
    "coronada": "coronado",
    "coronadas": "coronado",
    "coronados": "coronado",
    "coronais": "coronal",
    "coronas": "corona",
    "coronela": "coronel",
    "coronelas": "coronel",
    "coronhadas": "coronhada",
    "coronhas": "coronha",
    "coronheiros": "coronheiro",
    "coronhos": "coronho",
    "coroniformes": "coroniforme",
    "coronilhas": "coronilha",
    "coronária": "coronário",
    "coronárias": "coronário",
    "coronários": "coronário",
    "coronéis": "coronel",
    "coronóidea": "coronóideo",
    "coronóideas": "coronóideo",
    "coronóideos": "coronóideo",
    "coroo": "coroar",
    "coroou": "coroar",
    "coroplasta": "coroplasto",
    "coroplastas": "coroplasto",
    "coroplastias": "coroplastia",
    "coroplastos": "coroplasto",
    "coros": "coro",
    "corou": "corar",
    "corozos": "corozo",
    "coroá": "coroar",
    "coroámo": "coroar",
    "coroámos": "coroar",
    "coroáramo": "coroar",
    "coroáramos": "coroar",
    "coroárei": "coroar",
    "coroáreis": "coroar",
    "coroás": "coroá",
    "coroásseis": "coroar",
    "coroássemos": "coroar",
    "coroávamo": "coroar",
    "coroávamos": "coroar",
    "coroávei": "coroar",
    "coroáveis": "coroar",
    "coroças": "coroça",
    "coroços": "coroço",
    "corpanziis": "corpanzil",
    "corpanzuda": "corpanzudo",
    "corpanzudas": "corpanzudo",
    "corpanzudos": "corpanzudo",
    "corpaços": "corpaço",
    "corpetes": "corpete",
    "corpieirinhas": "corpieirinha",
    "corpinho": "corpo",
    "corpinhos": "corpo",
    "corpito": "corpo",
    "corpitos": "corpo",
    "corpiés": "corpié",
    "corpolenta": "corpolento",
    "corpolentas": "corpolento",
    "corpolentos": "corpolento",
    "corpora": "corpus",
    "corporais": "corporal",
    "corporalidades": "corporalidade",
    "corporaliza": "corporalizar",
    "corporalizada": "corporalizar",
    "corporalizadas": "corporalizar",
    "corporalizado": "corporalizar",
    "corporalizados": "corporalizar",
    "corporalizai": "corporalizar",
    "corporalizais": "corporalizar",
    "corporalizam": "corporalizar",
    "corporalizamo": "corporalizar",
    "corporalizamos": "corporalizar",
    "corporalizando": "corporalizar",
    "corporalizara": "corporalizar",
    "corporalizaram": "corporalizar",
    "corporalizaras": "corporalizar",
    "corporalizarde": "corporalizar",
    "corporalizardes": "corporalizar",
    "corporalizare": "corporalizar",
    "corporalizarei": "corporalizar",
    "corporalizareis": "corporalizar",
    "corporalizarem": "corporalizar",
    "corporalizaremos": "corporalizar",
    "corporalizares": "corporalizar",
    "corporalizaria": "corporalizar",
    "corporalizariam": "corporalizar",
    "corporalizarias": "corporalizar",
    "corporalizarmo": "corporalizar",
    "corporalizarmos": "corporalizar",
    "corporalizará": "corporalizar",
    "corporalizarás": "corporalizar",
    "corporalizarão": "corporalizar",
    "corporalizaríamos": "corporalizar",
    "corporalizaríeis": "corporalizar",
    "corporalizas": "corporalizar",
    "corporalizasse": "corporalizar",
    "corporalizassem": "corporalizar",
    "corporalizasses": "corporalizar",
    "corporalizaste": "corporalizar",
    "corporalizastes": "corporalizar",
    "corporalizava": "corporalizar",
    "corporalizavam": "corporalizar",
    "corporalizavas": "corporalizar",
    "corporalizações": "corporalização",
    "corporalize": "corporalizar",
    "corporalizei": "corporalizar",
    "corporalizeis": "corporalizar",
    "corporalizem": "corporalizar",
    "corporalizemo": "corporalizar",
    "corporalizemos": "corporalizar",
    "corporalizes": "corporalizar",
    "corporalizo": "corporalizar",
    "corporalizou": "corporalizar",
    "corporalizá": "corporalizar",
    "corporalizámo": "corporalizar",
    "corporalizámos": "corporalizar",
    "corporalizáramo": "corporalizar",
    "corporalizáramos": "corporalizar",
    "corporalizárei": "corporalizar",
    "corporalizáreis": "corporalizar",
    "corporalizásseis": "corporalizar",
    "corporalizássemos": "corporalizar",
    "corporalizávamo": "corporalizar",
    "corporalizávamos": "corporalizar",
    "corporalizávei": "corporalizar",
    "corporalizáveis": "corporalizar",
    "corporativa": "corporativo",
    "corporativas": "corporativo",
    "corporativismos": "corporativismo",
    "corporativistas": "corporativista",
    "corporativos": "corporativo",
    "corporaturas": "corporatura",
    "corporações": "corporação",
    "corporeidades": "corporeidade",
    "corporifica": "corporificar",
    "corporificada": "corporificar",
    "corporificadas": "corporificar",
    "corporificado": "corporificar",
    "corporificados": "corporificar",
    "corporificai": "corporificar",
    "corporificais": "corporificar",
    "corporificam": "corporificar",
    "corporificamo": "corporificar",
    "corporificamos": "corporificar",
    "corporificando": "corporificar",
    "corporificara": "corporificar",
    "corporificaram": "corporificar",
    "corporificaras": "corporificar",
    "corporificarde": "corporificar",
    "corporificardes": "corporificar",
    "corporificare": "corporificar",
    "corporificarei": "corporificar",
    "corporificareis": "corporificar",
    "corporificarem": "corporificar",
    "corporificaremos": "corporificar",
    "corporificares": "corporificar",
    "corporificaria": "corporificar",
    "corporificariam": "corporificar",
    "corporificarias": "corporificar",
    "corporificarmo": "corporificar",
    "corporificarmos": "corporificar",
    "corporificará": "corporificar",
    "corporificarás": "corporificar",
    "corporificarão": "corporificar",
    "corporificaríamos": "corporificar",
    "corporificaríeis": "corporificar",
    "corporificas": "corporificar",
    "corporificasse": "corporificar",
    "corporificassem": "corporificar",
    "corporificasses": "corporificar",
    "corporificaste": "corporificar",
    "corporificastes": "corporificar",
    "corporificava": "corporificar",
    "corporificavam": "corporificar",
    "corporificavas": "corporificar",
    "corporificações": "corporificação",
    "corporifico": "corporificar",
    "corporificou": "corporificar",
    "corporificá": "corporificar",
    "corporificámo": "corporificar",
    "corporificámos": "corporificar",
    "corporificáramo": "corporificar",
    "corporificáramos": "corporificar",
    "corporificárei": "corporificar",
    "corporificáreis": "corporificar",
    "corporificásseis": "corporificar",
    "corporificássemos": "corporificar",
    "corporificávamo": "corporificar",
    "corporificávamos": "corporificar",
    "corporificávei": "corporificar",
    "corporificáveis": "corporificar",
    "corporifique": "corporificar",
    "corporifiquei": "corporificar",
    "corporifiqueis": "corporificar",
    "corporifiquem": "corporificar",
    "corporifiquemo": "corporificar",
    "corporifiquemos": "corporificar",
    "corporifiques": "corporificar",
    "corporiformes": "corporiforme",
    "corporiza": "corporizar",
    "corporizada": "corporizar",
    "corporizadas": "corporizar",
    "corporizado": "corporizar",
    "corporizados": "corporizar",
    "corporizai": "corporizar",
    "corporizais": "corporizar",
    "corporizam": "corporizar",
    "corporizamo": "corporizar",
    "corporizamos": "corporizar",
    "corporizando": "corporizar",
    "corporizara": "corporizar",
    "corporizaram": "corporizar",
    "corporizaras": "corporizar",
    "corporizarde": "corporizar",
    "corporizardes": "corporizar",
    "corporizare": "corporizar",
    "corporizarei": "corporizar",
    "corporizareis": "corporizar",
    "corporizarem": "corporizar",
    "corporizaremos": "corporizar",
    "corporizares": "corporizar",
    "corporizaria": "corporizar",
    "corporizariam": "corporizar",
    "corporizarias": "corporizar",
    "corporizarmo": "corporizar",
    "corporizarmos": "corporizar",
    "corporizará": "corporizar",
    "corporizarás": "corporizar",
    "corporizarão": "corporizar",
    "corporizaríamos": "corporizar",
    "corporizaríeis": "corporizar",
    "corporizas": "corporizar",
    "corporizasse": "corporizar",
    "corporizassem": "corporizar",
    "corporizasses": "corporizar",
    "corporizaste": "corporizar",
    "corporizastes": "corporizar",
    "corporizava": "corporizar",
    "corporizavam": "corporizar",
    "corporizavas": "corporizar",
    "corporizações": "corporização",
    "corporize": "corporizar",
    "corporizei": "corporizar",
    "corporizeis": "corporizar",
    "corporizem": "corporizar",
    "corporizemo": "corporizar",
    "corporizemos": "corporizar",
    "corporizes": "corporizar",
    "corporizo": "corporizar",
    "corporizou": "corporizar",
    "corporizá": "corporizar",
    "corporizámo": "corporizar",
    "corporizámos": "corporizar",
    "corporizáramo": "corporizar",
    "corporizáramos": "corporizar",
    "corporizárei": "corporizar",
    "corporizáreis": "corporizar",
    "corporizásseis": "corporizar",
    "corporizássemos": "corporizar",
    "corporizávamo": "corporizar",
    "corporizávamos": "corporizar",
    "corporizávei": "corporizar",
    "corporizáveis": "corporizar",
    "corpos": "corpo",
    "corposculares": "corposcular",
    "corpulências": "corpulência",
    "corpórea": "corpóreo",
    "corpóreas": "corpóreo",
    "corpóreos": "corpóreo",
    "corpúsculos": "corpúsculo",
    "corque": "corcar",
    "corquei": "corcar",
    "corqueis": "corcar",
    "corquem": "corcar",
    "corquemo": "corcar",
    "corquemos": "corcar",
    "corques": "corcar",
    "corra": "correr",
    "corrais": "correr",
    "corram": "correr",
    "corramo": "correr",
    "corramos": "correr",
    "corras": "correr",
    "corre": "correr",
    "correada": "correar",
    "correadas": "correar",
    "correado": "correar",
    "correados": "correar",
    "correagens": "correagem",
    "correai": "correar",
    "correais": "correar",
    "correames": "correame",
    "correamo": "correar",
    "correamos": "correar",
    "correando": "correar",
    "correara": "correar",
    "correaram": "correar",
    "correaras": "correar",
    "correarde": "correar",
    "correardes": "correar",
    "correare": "correar",
    "correarei": "correar",
    "correareis": "correar",
    "correarem": "correar",
    "correaremos": "correar",
    "correares": "correar",
    "correaria": "correar",
    "correariam": "correar",
    "correarias": "correaria",
    "correarmo": "correar",
    "correarmos": "correar",
    "correará": "correar",
    "correarás": "correar",
    "correarão": "correar",
    "correaríamos": "correar",
    "correaríeis": "correar",
    "correasse": "correar",
    "correassem": "correar",
    "correasses": "correar",
    "correaste": "correar",
    "correastes": "correar",
    "correava": "correar",
    "correavam": "correar",
    "correavas": "correar",
    "correccionais": "correccional",
    "correcta": "correcto",
    "correctas": "correcto",
    "correctiva": "correctivo",
    "correctivas": "correctivo",
    "correctivos": "correctivo",
    "correctora": "corrector",
    "correctoras": "corrector",
    "correctores": "corrector",
    "correctorias": "correctoria",
    "correctos": "correcto",
    "correctrizes": "correctriz",
    "correctíssima": "correcto",
    "correctíssimas": "correcto",
    "correctíssimo": "correcto",
    "correctíssimos": "correcto",
    "correctória": "correctório",
    "correctórias": "correctório",
    "correctórios": "correctório",
    "correcções": "correcção",
    "corredelas": "corredela",
    "corredia": "corredio",
    "corredias": "corredio",
    "corredios": "corredio",
    "corrediça": "corrediço",
    "corrediças": "corrediço",
    "corrediços": "corrediço",
    "corredoiras": "corredoira",
    "corredoiros": "corredoiro",
    "corredora": "corredor",
    "corredoras": "corredora",
    "corredores": "corredor",
    "corredouras": "corredoura",
    "corredouros": "corredouro",
    "correduras": "corredura",
    "correei": "correar",
    "correeiros": "correeiro",
    "correeis": "correar",
    "correemo": "correar",
    "correemos": "correar",
    "correenta": "correento",
    "correentas": "correento",
    "correentos": "correento",
    "correge": "correger",
    "corregedores": "corregedor",
    "corregedorias": "corregedoria",
    "corregei": "correger",
    "corregeis": "correger",
    "corregem": "correger",
    "corregemo": "correger",
    "corregemos": "correger",
    "corregendo": "correger",
    "corregera": "correger",
    "corregeram": "correger",
    "corregeras": "correger",
    "corregerde": "correger",
    "corregerdes": "correger",
    "corregere": "correger",
    "corregerei": "correger",
    "corregereis": "correger",
    "corregerem": "correger",
    "corregeremos": "correger",
    "corregeres": "correger",
    "corregeria": "correger",
    "corregeriam": "correger",
    "corregerias": "correger",
    "corregermo": "correger",
    "corregermos": "correger",
    "corregerá": "correger",
    "corregerás": "correger",
    "corregerão": "correger",
    "corregeríamos": "correger",
    "corregeríeis": "correger",
    "correges": "correger",
    "corregesse": "correger",
    "corregessem": "correger",
    "corregesses": "correger",
    "corregeste": "correger",
    "corregestes": "correger",
    "corregeu": "correger",
    "corregi": "correger",
    "corregia": "correger",
    "corregiam": "correger",
    "corregias": "correger",
    "corregida": "correger",
    "corregidas": "correger",
    "corregido": "correger",
    "corregidos": "correger",
    "corregimentos": "corregimento",
    "corregê": "correger",
    "corregêramo": "correger",
    "corregêramos": "correger",
    "corregêrei": "correger",
    "corregêreis": "correger",
    "corregêsseis": "correger",
    "corregêssemos": "correger",
    "corregíamo": "correger",
    "corregíamos": "correger",
    "corregíei": "correger",
    "corregíeis": "correger",
    "correi": "correr",
    "correia": "correar",
    "correiam": "correar",
    "correias": "correia",
    "correie": "correar",
    "correiem": "correar",
    "correies": "correar",
    "correio": "correar",
    "correios": "correio",
    "correis": "correr",
    "correições": "correição",
    "correja": "correger",
    "correjais": "correger",
    "correjam": "correger",
    "correjamo": "correger",
    "correjamos": "correger",
    "correjas": "correger",
    "correjo": "correger",
    "correjolas": "correjola",
    "correlaciona": "correlacionar",
    "correlacionada": "correlacionar",
    "correlacionadas": "correlacionar",
    "correlacionado": "correlacionar",
    "correlacionados": "correlacionar",
    "correlacionai": "correlacionar",
    "correlacionais": "correlacionar",
    "correlacionam": "correlacionar",
    "correlacionamentos": "correlacionamento",
    "correlacionamo": "correlacionar",
    "correlacionamos": "correlacionar",
    "correlacionando": "correlacionar",
    "correlacionantes": "correlacionante",
    "correlacionara": "correlacionar",
    "correlacionaram": "correlacionar",
    "correlacionaras": "correlacionar",
    "correlacionarde": "correlacionar",
    "correlacionardes": "correlacionar",
    "correlacionare": "correlacionar",
    "correlacionarei": "correlacionar",
    "correlacionareis": "correlacionar",
    "correlacionarem": "correlacionar",
    "correlacionaremos": "correlacionar",
    "correlacionares": "correlacionar",
    "correlacionaria": "correlacionar",
    "correlacionariam": "correlacionar",
    "correlacionarias": "correlacionar",
    "correlacionarmo": "correlacionar",
    "correlacionarmos": "correlacionar",
    "correlacionará": "correlacionar",
    "correlacionarás": "correlacionar",
    "correlacionarão": "correlacionar",
    "correlacionaríamos": "correlacionar",
    "correlacionaríeis": "correlacionar",
    "correlacionas": "correlacionar",
    "correlacionasse": "correlacionar",
    "correlacionassem": "correlacionar",
    "correlacionasses": "correlacionar",
    "correlacionaste": "correlacionar",
    "correlacionastes": "correlacionar",
    "correlacionava": "correlacionar",
    "correlacionavam": "correlacionar",
    "correlacionavas": "correlacionar",
    "correlacione": "correlacionar",
    "correlacionei": "correlacionar",
    "correlacioneis": "correlacionar",
    "correlacionem": "correlacionar",
    "correlacionemo": "correlacionar",
    "correlacionemos": "correlacionar",
    "correlaciones": "correlacionar",
    "correlaciono": "correlacionar",
    "correlacionou": "correlacionar",
    "correlacioná": "correlacionar",
    "correlacionámo": "correlacionar",
    "correlacionámos": "correlacionar",
    "correlacionáramo": "correlacionar",
    "correlacionáramos": "correlacionar",
    "correlacionárei": "correlacionar",
    "correlacionáreis": "correlacionar",
    "correlacionásseis": "correlacionar",
    "correlacionássemos": "correlacionar",
    "correlacionávamo": "correlacionar",
    "correlacionávamos": "correlacionar",
    "correlacionávei": "correlacionar",
    "correlacionáveis": "correlacionável",
    "correlata": "correlatar",
    "correlatada": "correlatar",
    "correlatadas": "correlatar",
    "correlatado": "correlatar",
    "correlatados": "correlatar",
    "correlatai": "correlatar",
    "correlatais": "correlatar",
    "correlatam": "correlatar",
    "correlatamo": "correlatar",
    "correlatamos": "correlatar",
    "correlatando": "correlatar",
    "correlatara": "correlatar",
    "correlataram": "correlatar",
    "correlataras": "correlatar",
    "correlatarde": "correlatar",
    "correlatardes": "correlatar",
    "correlatare": "correlatar",
    "correlatarei": "correlatar",
    "correlatareis": "correlatar",
    "correlatarem": "correlatar",
    "correlataremos": "correlatar",
    "correlatares": "correlatar",
    "correlataria": "correlatar",
    "correlatariam": "correlatar",
    "correlatarias": "correlatar",
    "correlatarmo": "correlatar",
    "correlatarmos": "correlatar",
    "correlatará": "correlatar",
    "correlatarás": "correlatar",
    "correlatarão": "correlatar",
    "correlataríamos": "correlatar",
    "correlataríeis": "correlatar",
    "correlatas": "correlatar",
    "correlatasse": "correlatar",
    "correlatassem": "correlatar",
    "correlatasses": "correlatar",
    "correlataste": "correlatar",
    "correlatastes": "correlatar",
    "correlatava": "correlatar",
    "correlatavam": "correlatar",
    "correlatavas": "correlatar",
    "correlate": "correlatar",
    "correlatei": "correlatar",
    "correlateis": "correlatar",
    "correlatem": "correlatar",
    "correlatemo": "correlatar",
    "correlatemos": "correlatar",
    "correlates": "correlatar",
    "correlativa": "correlativo",
    "correlativas": "correlativo",
    "correlatividades": "correlatividade",
    "correlativos": "correlativo",
    "correlato": "correlatar",
    "correlatou": "correlatar",
    "correlatá": "correlatar",
    "correlatámo": "correlatar",
    "correlatámos": "correlatar",
    "correlatáramo": "correlatar",
    "correlatáramos": "correlatar",
    "correlatárei": "correlatar",
    "correlatáreis": "correlatar",
    "correlatásseis": "correlatar",
    "correlatássemos": "correlatar",
    "correlatávamo": "correlatar",
    "correlatávamos": "correlatar",
    "correlatávei": "correlatar",
    "correlatáveis": "correlatar",
    "correlações": "correlação",
    "correlegionária": "correlegionário",
    "correlegionárias": "correlegionário",
    "correlegionários": "correlegionário",
    "correligionária": "correligionário",
    "correligionárias": "correligionário",
    "correligionários": "correligionário",
    "correm": "correr",
    "corremo": "correr",
    "corremos": "correr",
    "correndo": "correr",
    "correntes": "corrente",
    "correntezas": "correnteza",
    "correntia": "correntio",
    "correntias": "correntio",
    "correntios": "correntio",
    "correntosa": "correntoso",
    "correntosas": "correntoso",
    "correntosos": "correntoso",
    "correou": "correar",
    "correpta": "correpto",
    "correptas": "correpto",
    "correptos": "correpto",
    "correra": "correr",
    "correram": "correr",
    "correras": "correr",
    "correrde": "correr",
    "correrdes": "correr",
    "correre": "correr",
    "correrei": "correr",
    "correreis": "correr",
    "correrem": "correr",
    "correremos": "correr",
    "correres": "correr",
    "correria": "correr",
    "correriam": "correr",
    "correrias": "correria",
    "corrermo": "correr",
    "corrermos": "correr",
    "correrá": "correr",
    "correrás": "correr",
    "correrão": "correr",
    "correríamos": "correr",
    "correríeis": "correr",
    "corres": "correr",
    "corresponda": "corresponder",
    "correspondais": "corresponder",
    "correspondam": "corresponder",
    "correspondamo": "corresponder",
    "correspondamos": "corresponder",
    "correspondas": "corresponder",
    "corresponde": "corresponder",
    "correspondei": "corresponder",
    "correspondeis": "corresponder",
    "correspondem": "corresponder",
    "correspondemo": "corresponder",
    "correspondemos": "corresponder",
    "correspondendo": "corresponder",
    "correspondentes": "correspondente",
    "correspondera": "corresponder",
    "corresponderam": "corresponder",
    "corresponderas": "corresponder",
    "corresponderdes": "corresponder",
    "corresponderei": "corresponder",
    "correspondereis": "corresponder",
    "corresponderem": "corresponder",
    "corresponderemos": "corresponder",
    "corresponderes": "corresponder",
    "corresponderia": "corresponder",
    "corresponderiam": "corresponder",
    "corresponderias": "corresponder",
    "correspondermo": "corresponder",
    "correspondermos": "corresponder",
    "corresponderá": "corresponder",
    "corresponderás": "corresponder",
    "corresponderão": "corresponder",
    "corresponderíamos": "corresponder",
    "corresponderíeis": "corresponder",
    "correspondes": "corresponder",
    "correspondesse": "corresponder",
    "correspondessem": "corresponder",
    "correspondesses": "corresponder",
    "correspondeste": "corresponder",
    "correspondestes": "corresponder",
    "correspondeu": "corresponder",
    "correspondi": "corresponder",
    "correspondia": "corresponder",
    "correspondiam": "corresponder",
    "correspondias": "corresponder",
    "correspondida": "correspondido",
    "correspondidas": "correspondido",
    "correspondido": "corresponder",
    "correspondidos": "correspondido",
    "correspondo": "corresponder",
    "correspondências": "correspondência",
    "correspondêramo": "corresponder",
    "correspondêramos": "corresponder",
    "correspondêreis": "corresponder",
    "correspondêsseis": "corresponder",
    "correspondêssemos": "corresponder",
    "correspondíamo": "corresponder",
    "correspondíamos": "corresponder",
    "correspondíeis": "corresponder",
    "corresponsabilidades": "corresponsabilidade",
    "corresponsabiliza": "corresponsabilizar",
    "corresponsabilizada": "corresponsabilizar",
    "corresponsabilizadas": "corresponsabilizar",
    "corresponsabilizado": "corresponsabilizar",
    "corresponsabilizados": "corresponsabilizar",
    "corresponsabilizai": "corresponsabilizar",
    "corresponsabilizais": "corresponsabilizar",
    "corresponsabilizam": "corresponsabilizar",
    "corresponsabilizamo": "corresponsabilizar",
    "corresponsabilizamos": "corresponsabilizar",
    "corresponsabilizando": "corresponsabilizar",
    "corresponsabilizara": "corresponsabilizar",
    "corresponsabilizaram": "corresponsabilizar",
    "corresponsabilizaras": "corresponsabilizar",
    "corresponsabilizarde": "corresponsabilizar",
    "corresponsabilizardes": "corresponsabilizar",
    "corresponsabilizare": "corresponsabilizar",
    "corresponsabilizarei": "corresponsabilizar",
    "corresponsabilizareis": "corresponsabilizar",
    "corresponsabilizarem": "corresponsabilizar",
    "corresponsabilizaremos": "corresponsabilizar",
    "corresponsabilizares": "corresponsabilizar",
    "corresponsabilizaria": "corresponsabilizar",
    "corresponsabilizariam": "corresponsabilizar",
    "corresponsabilizarias": "corresponsabilizar",
    "corresponsabilizarmo": "corresponsabilizar",
    "corresponsabilizarmos": "corresponsabilizar",
    "corresponsabilizará": "corresponsabilizar",
    "corresponsabilizarás": "corresponsabilizar",
    "corresponsabilizarão": "corresponsabilizar",
    "corresponsabilizaríamos": "corresponsabilizar",
    "corresponsabilizaríeis": "corresponsabilizar",
    "corresponsabilizas": "corresponsabilizar",
    "corresponsabilizasse": "corresponsabilizar",
    "corresponsabilizassem": "corresponsabilizar",
    "corresponsabilizasses": "corresponsabilizar",
    "corresponsabilizaste": "corresponsabilizar",
    "corresponsabilizastes": "corresponsabilizar",
    "corresponsabilizava": "corresponsabilizar",
    "corresponsabilizavam": "corresponsabilizar",
    "corresponsabilizavas": "corresponsabilizar",
    "corresponsabilizações": "corresponsabilização",
    "corresponsabilize": "corresponsabilizar",
    "corresponsabilizei": "corresponsabilizar",
    "corresponsabilizeis": "corresponsabilizar",
    "corresponsabilizem": "corresponsabilizar",
    "corresponsabilizemo": "corresponsabilizar",
    "corresponsabilizemos": "corresponsabilizar",
    "corresponsabilizes": "corresponsabilizar",
    "corresponsabilizo": "corresponsabilizar",
    "corresponsabilizou": "corresponsabilizar",
    "corresponsabilizá": "corresponsabilizar",
    "corresponsabilizámo": "corresponsabilizar",
    "corresponsabilizámos": "corresponsabilizar",
    "corresponsabilizáramo": "corresponsabilizar",
    "corresponsabilizáramos": "corresponsabilizar",
    "corresponsabilizárei": "corresponsabilizar",
    "corresponsabilizáreis": "corresponsabilizar",
    "corresponsabilizásseis": "corresponsabilizar",
    "corresponsabilizássemos": "corresponsabilizar",
    "corresponsabilizávamo": "corresponsabilizar",
    "corresponsabilizávamos": "corresponsabilizar",
    "corresponsabilizávei": "corresponsabilizar",
    "corresponsabilizáveis": "corresponsabilizar",
    "corresponsáveis": "corresponsável",
    "corresse": "correr",
    "corressem": "correr",
    "corresses": "correr",
    "correste": "correr",
    "correstes": "correr",
    "correta": "corretar",
    "corretada": "corretar",
    "corretadas": "corretar",
    "corretado": "corretar",
    "corretados": "corretar",
    "corretagens": "corretagem",
    "corretai": "corretar",
    "corretais": "corretar",
    "corretam": "corretar",
    "corretamo": "corretar",
    "corretamos": "corretar",
    "corretando": "corretar",
    "corretara": "corretar",
    "corretaram": "corretar",
    "corretaras": "corretar",
    "corretardes": "corretar",
    "corretarei": "corretar",
    "corretareis": "corretar",
    "corretarem": "corretar",
    "corretaremos": "corretar",
    "corretares": "corretar",
    "corretaria": "corretar",
    "corretariam": "corretar",
    "corretarias": "corretar",
    "corretarmo": "corretar",
    "corretarmos": "corretar",
    "corretará": "corretar",
    "corretarás": "corretar",
    "corretarão": "corretar",
    "corretaríamos": "corretar",
    "corretaríeis": "corretar",
    "corretas": "corretar",
    "corretasse": "corretar",
    "corretassem": "corretar",
    "corretasses": "corretar",
    "corretaste": "corretar",
    "corretastes": "corretar",
    "corretava": "corretar",
    "corretavam": "corretar",
    "corretavas": "corretar",
    "correte": "corretar",
    "corretei": "corretar",
    "correteis": "corretar",
    "corretem": "corretar",
    "corretemo": "corretar",
    "corretemos": "corretar",
    "corretes": "corretar",
    "correto": "corretar",
    "corretora": "corretor",
    "corretoras": "corretora",
    "corretores": "corretor",
    "corretou": "corretar",
    "corretámo": "corretar",
    "corretámos": "corretar",
    "corretáramo": "corretar",
    "corretáramos": "corretar",
    "corretáreis": "corretar",
    "corretásseis": "corretar",
    "corretássemos": "corretar",
    "corretávamo": "corretar",
    "corretávamos": "corretar",
    "corretáveis": "corretar",
    "corretãs": "corretã",
    "correu": "correr",
    "correá": "correar",
    "correámo": "correar",
    "correámos": "correar",
    "correáramo": "correar",
    "correáramos": "correar",
    "correárei": "correar",
    "correáreis": "correar",
    "correásseis": "correar",
    "correássemos": "correar",
    "correávamo": "correar",
    "correávamos": "correar",
    "correávei": "correar",
    "correáveis": "correar",
    "correões": "correão",
    "corri": "correr",
    "corria": "correr",
    "corriam": "correr",
    "corrias": "correr",
    "corrica": "corricar",
    "corricada": "corricar",
    "corricadas": "corricar",
    "corricado": "corricar",
    "corricados": "corricar",
    "corricai": "corricar",
    "corricais": "corricar",
    "corricam": "corricar",
    "corricamo": "corricar",
    "corricamos": "corricar",
    "corricando": "corricar",
    "corricara": "corricar",
    "corricaram": "corricar",
    "corricaras": "corricar",
    "corricarde": "corricar",
    "corricardes": "corricar",
    "corricare": "corricar",
    "corricarei": "corricar",
    "corricareis": "corricar",
    "corricarem": "corricar",
    "corricaremos": "corricar",
    "corricares": "corricar",
    "corricaria": "corricar",
    "corricariam": "corricar",
    "corricarias": "corricar",
    "corricarmo": "corricar",
    "corricarmos": "corricar",
    "corricará": "corricar",
    "corricarás": "corricar",
    "corricarão": "corricar",
    "corricaríamos": "corricar",
    "corricaríeis": "corricar",
    "corricas": "corricar",
    "corricasse": "corricar",
    "corricassem": "corricar",
    "corricasses": "corricar",
    "corricaste": "corricar",
    "corricastes": "corricar",
    "corricava": "corricar",
    "corricavam": "corricar",
    "corricavas": "corricar",
    "corricha": "corrichar",
    "corrichada": "corrichar",
    "corrichadas": "corrichar",
    "corrichado": "corrichar",
    "corrichados": "corrichar",
    "corrichai": "corrichar",
    "corrichais": "corrichar",
    "corricham": "corrichar",
    "corrichamo": "corrichar",
    "corrichamos": "corrichar",
    "corrichando": "corrichar",
    "corrichara": "corrichar",
    "corricharam": "corrichar",
    "corricharas": "corrichar",
    "corrichardes": "corrichar",
    "corricharei": "corrichar",
    "corrichareis": "corrichar",
    "corricharem": "corrichar",
    "corricharemos": "corrichar",
    "corrichares": "corrichar",
    "corricharia": "corrichar",
    "corrichariam": "corrichar",
    "corricharias": "corrichar",
    "corricharmo": "corrichar",
    "corricharmos": "corrichar",
    "corrichará": "corrichar",
    "corricharás": "corrichar",
    "corricharão": "corrichar",
    "corricharíamos": "corrichar",
    "corricharíeis": "corrichar",
    "corrichas": "corrichar",
    "corrichasse": "corrichar",
    "corrichassem": "corrichar",
    "corrichasses": "corrichar",
    "corrichaste": "corrichar",
    "corrichastes": "corrichar",
    "corrichava": "corrichar",
    "corrichavam": "corrichar",
    "corrichavas": "corrichar",
    "corriche": "corrichar",
    "corrichei": "corrichar",
    "corricheis": "corrichar",
    "corrichem": "corrichar",
    "corrichemo": "corrichar",
    "corrichemos": "corrichar",
    "corriches": "corrichar",
    "corricho": "corrichar",
    "corrichou": "corrichar",
    "corrichámo": "corrichar",
    "corrichámos": "corrichar",
    "corricháramo": "corrichar",
    "corricháramos": "corrichar",
    "corricháreis": "corrichar",
    "corrichásseis": "corrichar",
    "corrichássemos": "corrichar",
    "corrichávamo": "corrichar",
    "corrichávamos": "corrichar",
    "corricháveis": "corrichar",
    "corrico": "corricar",
    "corricou": "corricar",
    "corricá": "corricar",
    "corricámo": "corricar",
    "corricámos": "corricar",
    "corricáramo": "corricar",
    "corricáramos": "corricar",
    "corricárei": "corricar",
    "corricáreis": "corricar",
    "corricásseis": "corricar",
    "corricássemos": "corricar",
    "corricávamo": "corricar",
    "corricávamos": "corricar",
    "corricávei": "corricar",
    "corricáveis": "corricar",
    "corricões": "corricão",
    "corrida": "corrido",
    "corridas": "corrido",
    "corridinha": "corrida",
    "corridinhas": "corrida",
    "corridinhos": "corridinho",
    "corridita": "corrida",
    "corriditas": "corrida",
    "corrido": "correr",
    "corridos": "corrido",
    "corrienta": "corriento",
    "corrientas": "corriento",
    "corrientos": "corriento",
    "corrige": "corrigir",
    "corrigem": "corrigir",
    "corrigendas": "corrigenda",
    "corriges": "corrigir",
    "corrigi": "corrigir",
    "corrigia": "corrigir",
    "corrigiam": "corrigir",
    "corrigias": "corrigir",
    "corrigibilidades": "corrigibilidade",
    "corrigida": "corrigir",
    "corrigidas": "corrigir",
    "corrigido": "corrigir",
    "corrigidos": "corrigir",
    "corrigimo": "corrigir",
    "corrigimos": "corrigir",
    "corrigindo": "corrigir",
    "corrigira": "corrigir",
    "corrigiram": "corrigir",
    "corrigiras": "corrigir",
    "corrigirde": "corrigir",
    "corrigirdes": "corrigir",
    "corrigire": "corrigir",
    "corrigirei": "corrigir",
    "corrigireis": "corrigir",
    "corrigirem": "corrigir",
    "corrigiremos": "corrigir",
    "corrigires": "corrigir",
    "corrigiria": "corrigir",
    "corrigiriam": "corrigir",
    "corrigirias": "corrigir",
    "corrigirmo": "corrigir",
    "corrigirmos": "corrigir",
    "corrigirá": "corrigir",
    "corrigirás": "corrigir",
    "corrigirão": "corrigir",
    "corrigiríamos": "corrigir",
    "corrigiríeis": "corrigir",
    "corrigis": "corrigir",
    "corrigisse": "corrigir",
    "corrigissem": "corrigir",
    "corrigisses": "corrigir",
    "corrigiste": "corrigir",
    "corrigistes": "corrigir",
    "corrigiu": "corrigir",
    "corrigíamo": "corrigir",
    "corrigíamos": "corrigir",
    "corrigíei": "corrigir",
    "corrigíeis": "corrigir",
    "corrigíramo": "corrigir",
    "corrigíramos": "corrigir",
    "corrigírei": "corrigir",
    "corrigíreis": "corrigir",
    "corrigísseis": "corrigir",
    "corrigíssemos": "corrigir",
    "corrigíveis": "corrigível",
    "corrija": "corrigir",
    "corrijais": "corrigir",
    "corrijam": "corrigir",
    "corrijamo": "corrigir",
    "corrijamos": "corrigir",
    "corrijas": "corrigir",
    "corrijo": "corrigir",
    "corrijolas": "corrijola",
    "corrijós": "corrijó",
    "corrilheira": "corrilheiro",
    "corrilheiras": "corrilheiro",
    "corrilheiros": "corrilheiro",
    "corrilhos": "corrilho",
    "corrimaças": "corrimaça",
    "corrimentos": "corrimento",
    "corrimãos": "corrimão",
    "corrimões": "corrimão",
    "corriolas": "corriola",
    "corripa": "corripar",
    "corripada": "corripar",
    "corripadas": "corripar",
    "corripado": "corripar",
    "corripados": "corripar",
    "corripai": "corripar",
    "corripais": "corripar",
    "corripam": "corripar",
    "corripamo": "corripar",
    "corripamos": "corripar",
    "corripando": "corripar",
    "corripara": "corripar",
    "corriparam": "corripar",
    "corriparas": "corripar",
    "corriparde": "corripar",
    "corripardes": "corripar",
    "corripare": "corripar",
    "corriparei": "corripar",
    "corripareis": "corripar",
    "corriparem": "corripar",
    "corriparemos": "corripar",
    "corripares": "corripar",
    "corriparia": "corripar",
    "corripariam": "corripar",
    "corriparias": "corripar",
    "corriparmo": "corripar",
    "corriparmos": "corripar",
    "corripará": "corripar",
    "corriparás": "corripar",
    "corriparão": "corripar",
    "corriparíamos": "corripar",
    "corriparíeis": "corripar",
    "corripas": "corripar",
    "corripasse": "corripar",
    "corripassem": "corripar",
    "corripasses": "corripar",
    "corripaste": "corripar",
    "corripastes": "corripar",
    "corripava": "corripar",
    "corripavam": "corripar",
    "corripavas": "corripar",
    "corripe": "corripar",
    "corripei": "corripar",
    "corripeis": "corripar",
    "corripem": "corripar",
    "corripemo": "corripar",
    "corripemos": "corripar",
    "corripes": "corripar",
    "corripo": "corripar",
    "corripos": "corripo",
    "corripou": "corripar",
    "corripá": "corripar",
    "corripámo": "corripar",
    "corripámos": "corripar",
    "corripáramo": "corripar",
    "corripáramos": "corripar",
    "corripárei": "corripar",
    "corripáreis": "corripar",
    "corripásseis": "corripar",
    "corripássemos": "corripar",
    "corripávamo": "corripar",
    "corripávamos": "corripar",
    "corripávei": "corripar",
    "corripáveis": "corripar",
    "corrique": "corricar",
    "corriquei": "corricar",
    "corriqueira": "corriqueiro",
    "corriqueiras": "corriqueiro",
    "corriqueirices": "corriqueirice",
    "corriqueiros": "corriqueiro",
    "corriqueis": "corricar",
    "corriquem": "corricar",
    "corriquemo": "corricar",
    "corriquemos": "corricar",
    "corriques": "corricar",
    "corro": "correr",
    "corroa": "corroer",
    "corroais": "corroer",
    "corroam": "corroer",
    "corroamo": "corroer",
    "corroamos": "corroer",
    "corroas": "corroer",
    "corrobora": "corroborar",
    "corroborada": "corroborar",
    "corroboradas": "corroborar",
    "corroborado": "corroborar",
    "corroborados": "corroborar",
    "corroborai": "corroborar",
    "corroborais": "corroborar",
    "corroboram": "corroborar",
    "corroboramo": "corroborar",
    "corroboramos": "corroborar",
    "corroborando": "corroborar",
    "corroborantes": "corroborante",
    "corroborara": "corroborar",
    "corroboraram": "corroborar",
    "corroboraras": "corroborar",
    "corroborarde": "corroborar",
    "corroborardes": "corroborar",
    "corroborare": "corroborar",
    "corroborarei": "corroborar",
    "corroborareis": "corroborar",
    "corroborarem": "corroborar",
    "corroboraremos": "corroborar",
    "corroborares": "corroborar",
    "corroboraria": "corroborar",
    "corroborariam": "corroborar",
    "corroborarias": "corroborar",
    "corroborarmo": "corroborar",
    "corroborarmos": "corroborar",
    "corroborará": "corroborar",
    "corroborarás": "corroborar",
    "corroborarão": "corroborar",
    "corroboraríamos": "corroborar",
    "corroboraríeis": "corroborar",
    "corroboras": "corroborar",
    "corroborasse": "corroborar",
    "corroborassem": "corroborar",
    "corroborasses": "corroborar",
    "corroboraste": "corroborar",
    "corroborastes": "corroborar",
    "corroborativa": "corroborativo",
    "corroborativas": "corroborativo",
    "corroborativos": "corroborativo",
    "corroborava": "corroborar",
    "corroboravam": "corroborar",
    "corroboravas": "corroborar",
    "corroborações": "corroboração",
    "corrobore": "corroborar",
    "corroborei": "corroborar",
    "corroboreis": "corroborar",
    "corroborem": "corroborar",
    "corroboremo": "corroborar",
    "corroboremos": "corroborar",
    "corrobores": "corroborar",
    "corroboro": "corroborar",
    "corroborou": "corroborar",
    "corroborá": "corroborar",
    "corroborámo": "corroborar",
    "corroborámos": "corroborar",
    "corroboráramo": "corroborar",
    "corroboráramos": "corroborar",
    "corroborárei": "corroborar",
    "corroboráreis": "corroborar",
    "corroborásseis": "corroborar",
    "corroborássemos": "corroborar",
    "corroborávamo": "corroborar",
    "corroborávamos": "corroborar",
    "corroborávei": "corroborar",
    "corroboráveis": "corroborável",
    "corroei": "corroer",
    "corroeis": "corroer",
    "corroem": "corroer",
    "corroemo": "corroer",
    "corroemos": "corroer",
    "corroendo": "corroer",
    "corroera": "corroer",
    "corroeram": "corroer",
    "corroeras": "corroer",
    "corroerde": "corroer",
    "corroerdes": "corroer",
    "corroere": "corroer",
    "corroerei": "corroer",
    "corroereis": "corroer",
    "corroerem": "corroer",
    "corroeremos": "corroer",
    "corroeres": "corroer",
    "corroeria": "corroer",
    "corroeriam": "corroer",
    "corroerias": "corroer",
    "corroermo": "corroer",
    "corroermos": "corroer",
    "corroerá": "corroer",
    "corroerás": "corroer",
    "corroerão": "corroer",
    "corroeríamos": "corroer",
    "corroeríeis": "corroer",
    "corroesse": "corroer",
    "corroessem": "corroer",
    "corroesses": "corroer",
    "corroeste": "corroer",
    "corroestes": "corroer",
    "corroeu": "corroer",
    "corroida": "corroido",
    "corroidas": "corroido",
    "corroidos": "corroido",
    "corrompa": "corromper",
    "corrompais": "corromper",
    "corrompam": "corromper",
    "corrompamo": "corromper",
    "corrompamos": "corromper",
    "corrompas": "corromper",
    "corrompe": "corromper",
    "corrompedora": "corrompedor",
    "corrompedoras": "corrompedor",
    "corrompedores": "corrompedor",
    "corrompei": "corromper",
    "corrompeis": "corromper",
    "corrompem": "corromper",
    "corrompemo": "corromper",
    "corrompemos": "corromper",
    "corrompendo": "corromper",
    "corrompera": "corromper",
    "corromperam": "corromper",
    "corromperas": "corromper",
    "corromperde": "corromper",
    "corromperdes": "corromper",
    "corrompere": "corromper",
    "corromperei": "corromper",
    "corrompereis": "corromper",
    "corromperem": "corromper",
    "corromperemos": "corromper",
    "corromperes": "corromper",
    "corromperia": "corromper",
    "corromperiam": "corromper",
    "corromperias": "corromper",
    "corrompermo": "corromper",
    "corrompermos": "corromper",
    "corromperá": "corromper",
    "corromperás": "corromper",
    "corromperão": "corromper",
    "corromperíamos": "corromper",
    "corromperíeis": "corromper",
    "corrompes": "corromper",
    "corrompesse": "corromper",
    "corrompessem": "corromper",
    "corrompesses": "corromper",
    "corrompeste": "corromper",
    "corrompestes": "corromper",
    "corrompeu": "corromper",
    "corrompi": "corromper",
    "corrompia": "corromper",
    "corrompiam": "corromper",
    "corrompias": "corromper",
    "corrompida": "corrompido",
    "corrompidas": "corrompido",
    "corrompido": "corromper",
    "corrompidos": "corrompido",
    "corrompimentos": "corrompimento",
    "corrompo": "corromper",
    "corrompê": "corromper",
    "corrompêramo": "corromper",
    "corrompêramos": "corromper",
    "corrompêrei": "corromper",
    "corrompêreis": "corromper",
    "corrompêsseis": "corromper",
    "corrompêssemos": "corromper",
    "corrompíamo": "corromper",
    "corrompíamos": "corromper",
    "corrompíei": "corromper",
    "corrompíeis": "corromper",
    "corrompíveis": "corrompível",
    "corroo": "corroer",
    "corros": "corro",
    "corrosibilidades": "corrosibilidade",
    "corrosiva": "corrosivo",
    "corrosivas": "corrosivo",
    "corrosivos": "corrosivo",
    "corrosíveis": "corrosível",
    "corrosões": "corrosão",
    "corroê": "corroer",
    "corroêramo": "corroer",
    "corroêramos": "corroer",
    "corroêrei": "corroer",
    "corroêreis": "corroer",
    "corroêsseis": "corroer",
    "corroêssemos": "corroer",
    "corroí": "corroer",
    "corroía": "corroer",
    "corroíam": "corroer",
    "corroíamo": "corroer",
    "corroíamos": "corroer",
    "corroías": "corroer",
    "corroída": "corroer",
    "corroídas": "corroer",
    "corroído": "corroer",
    "corroídos": "corroer",
    "corroíei": "corroer",
    "corroíeis": "corroer",
    "corrudas": "corruda",
    "corrumes": "corrume",
    "corrupia": "corrupiar",
    "corrupiada": "corrupiar",
    "corrupiadas": "corrupiar",
    "corrupiado": "corrupiar",
    "corrupiados": "corrupiar",
    "corrupiai": "corrupiar",
    "corrupiais": "corrupiar",
    "corrupiam": "corrupiar",
    "corrupiamo": "corrupiar",
    "corrupiamos": "corrupiar",
    "corrupiando": "corrupiar",
    "corrupiara": "corrupiar",
    "corrupiaram": "corrupiar",
    "corrupiaras": "corrupiar",
    "corrupiardes": "corrupiar",
    "corrupiarei": "corrupiar",
    "corrupiareis": "corrupiar",
    "corrupiarem": "corrupiar",
    "corrupiaremos": "corrupiar",
    "corrupiares": "corrupiar",
    "corrupiaria": "corrupiar",
    "corrupiariam": "corrupiar",
    "corrupiarias": "corrupiar",
    "corrupiarmo": "corrupiar",
    "corrupiarmos": "corrupiar",
    "corrupiará": "corrupiar",
    "corrupiarás": "corrupiar",
    "corrupiarão": "corrupiar",
    "corrupiaríamos": "corrupiar",
    "corrupiaríeis": "corrupiar",
    "corrupias": "corrupiar",
    "corrupiasse": "corrupiar",
    "corrupiassem": "corrupiar",
    "corrupiasses": "corrupiar",
    "corrupiaste": "corrupiar",
    "corrupiastes": "corrupiar",
    "corrupiava": "corrupiar",
    "corrupiavam": "corrupiar",
    "corrupiavas": "corrupiar",
    "corrupichões": "corrupichão",
    "corrupie": "corrupiar",
    "corrupiei": "corrupiar",
    "corrupieis": "corrupiar",
    "corrupiem": "corrupiar",
    "corrupiemo": "corrupiar",
    "corrupiemos": "corrupiar",
    "corrupies": "corrupiar",
    "corrupio": "corrupiar",
    "corrupios": "corrupio",
    "corrupiou": "corrupiar",
    "corrupiámo": "corrupiar",
    "corrupiámos": "corrupiar",
    "corrupiáramo": "corrupiar",
    "corrupiáramos": "corrupiar",
    "corrupiáreis": "corrupiar",
    "corrupiásseis": "corrupiar",
    "corrupiássemos": "corrupiar",
    "corrupiávamo": "corrupiar",
    "corrupiávamos": "corrupiar",
    "corrupiáveis": "corrupiar",
    "corrupiões": "corrupião",
    "corrupta": "corrupto",
    "corruptas": "corrupto",
    "corruptelas": "corruptela",
    "corruptibilidades": "corruptibilidade",
    "corruptiva": "corruptivo",
    "corruptivas": "corruptivo",
    "corruptivos": "corruptivo",
    "corruptora": "corruptor",
    "corruptoras": "corruptor",
    "corruptores": "corruptor",
    "corruptos": "corrupto",
    "corruptíveis": "corruptível",
    "corrupções": "corrupção",
    "corrê": "correr",
    "corrêramo": "correr",
    "corrêramos": "correr",
    "corrêrei": "correr",
    "corrêreis": "correr",
    "corrêsseis": "correr",
    "corrêssemos": "correr",
    "corríamo": "correr",
    "corríamos": "correr",
    "corríei": "correr",
    "corríeis": "correr",
    "corrói": "corroer",
    "corróis": "corroer",
    "corsa": "corso",
    "corsaletes": "corsalete",
    "corsas": "corso",
    "corseada": "corsear",
    "corseadas": "corsear",
    "corseado": "corsear",
    "corseados": "corsear",
    "corseai": "corsear",
    "corseais": "corsear",
    "corseamo": "corsear",
    "corseamos": "corsear",
    "corseando": "corsear",
    "corseara": "corsear",
    "corsearam": "corsear",
    "corsearas": "corsear",
    "corseardes": "corsear",
    "corsearei": "corsear",
    "corseareis": "corsear",
    "corsearem": "corsear",
    "corsearemos": "corsear",
    "corseares": "corsear",
    "corsearia": "corsear",
    "corseariam": "corsear",
    "corsearias": "corsear",
    "corsearmo": "corsear",
    "corsearmos": "corsear",
    "corseará": "corsear",
    "corsearás": "corsear",
    "corsearão": "corsear",
    "corsearíamos": "corsear",
    "corsearíeis": "corsear",
    "corseasse": "corsear",
    "corseassem": "corsear",
    "corseasses": "corsear",
    "corseaste": "corsear",
    "corseastes": "corsear",
    "corseava": "corsear",
    "corseavam": "corsear",
    "corseavas": "corsear",
    "corseei": "corsear",
    "corseeis": "corsear",
    "corseemo": "corsear",
    "corseemos": "corsear",
    "corseia": "corsear",
    "corseiam": "corsear",
    "corseias": "corsear",
    "corseie": "corsear",
    "corseiem": "corsear",
    "corseies": "corsear",
    "corseio": "corsear",
    "corseou": "corsear",
    "corseámo": "corsear",
    "corseámos": "corsear",
    "corseáramo": "corsear",
    "corseáramos": "corsear",
    "corseáreis": "corsear",
    "corseásseis": "corsear",
    "corseássemos": "corsear",
    "corseávamo": "corsear",
    "corseávamos": "corsear",
    "corseáveis": "corsear",
    "corsos": "corso",
    "corsária": "corsário",
    "corsárias": "corsário",
    "corsários": "corsário",
    "corta": "cortar",
    "cortada": "cortar",
    "cortadas": "cortar",
    "cortadeiras": "cortadeira",
    "cortadelas": "cortadela",
    "cortado": "cortar",
    "cortadora": "cortador",
    "cortadoras": "cortador",
    "cortadores": "cortador",
    "cortados": "cortar",
    "cortaduras": "cortadura",
    "cortagens": "cortagem",
    "cortai": "cortar",
    "cortais": "cortar",
    "cortam": "cortar",
    "cortamentos": "cortamento",
    "cortamo": "cortar",
    "cortamos": "cortar",
    "cortando": "cortar",
    "cortantes": "cortante",
    "cortara": "cortar",
    "cortaram": "cortar",
    "cortaras": "cortar",
    "cortarde": "cortar",
    "cortardes": "cortar",
    "cortare": "cortar",
    "cortarei": "cortar",
    "cortareis": "cortar",
    "cortarem": "cortar",
    "cortaremos": "cortar",
    "cortares": "cortar",
    "cortaria": "cortar",
    "cortariam": "cortar",
    "cortarias": "cortar",
    "cortarmo": "cortar",
    "cortarmos": "cortar",
    "cortará": "cortar",
    "cortarás": "cortar",
    "cortarão": "cortar",
    "cortaríamos": "cortar",
    "cortaríeis": "cortar",
    "cortas": "cortar",
    "cortasse": "cortar",
    "cortassem": "cortar",
    "cortasses": "cortar",
    "cortaste": "cortar",
    "cortastes": "cortar",
    "cortava": "cortar",
    "cortavam": "cortar",
    "cortavas": "cortar",
    "corte": "cortar",
    "cortei": "cortar",
    "corteis": "cortar",
    "corteja": "cortejar",
    "cortejada": "cortejar",
    "cortejadas": "cortejar",
    "cortejado": "cortejar",
    "cortejadora": "cortejador",
    "cortejadoras": "cortejador",
    "cortejadores": "cortejador",
    "cortejados": "cortejar",
    "cortejadíssima": "cortejado",
    "cortejadíssimas": "cortejado",
    "cortejadíssimo": "cortejado",
    "cortejadíssimos": "cortejado",
    "cortejai": "cortejar",
    "cortejais": "cortejar",
    "cortejam": "cortejar",
    "cortejamo": "cortejar",
    "cortejamos": "cortejar",
    "cortejando": "cortejar",
    "cortejara": "cortejar",
    "cortejaram": "cortejar",
    "cortejaras": "cortejar",
    "cortejarde": "cortejar",
    "cortejardes": "cortejar",
    "cortejare": "cortejar",
    "cortejarei": "cortejar",
    "cortejareis": "cortejar",
    "cortejarem": "cortejar",
    "cortejaremos": "cortejar",
    "cortejares": "cortejar",
    "cortejaria": "cortejar",
    "cortejariam": "cortejar",
    "cortejarias": "cortejar",
    "cortejarmo": "cortejar",
    "cortejarmos": "cortejar",
    "cortejará": "cortejar",
    "cortejarás": "cortejar",
    "cortejarão": "cortejar",
    "cortejaríamos": "cortejar",
    "cortejaríeis": "cortejar",
    "cortejas": "cortejar",
    "cortejasse": "cortejar",
    "cortejassem": "cortejar",
    "cortejasses": "cortejar",
    "cortejaste": "cortejar",
    "cortejastes": "cortejar",
    "cortejava": "cortejar",
    "cortejavam": "cortejar",
    "cortejavas": "cortejar",
    "corteje": "cortejar",
    "cortejei": "cortejar",
    "cortejeis": "cortejar",
    "cortejem": "cortejar",
    "cortejemo": "cortejar",
    "cortejemos": "cortejar",
    "cortejes": "cortejar",
    "cortejo": "cortejar",
    "cortejos": "cortejo",
    "cortejou": "cortejar",
    "cortejá": "cortejar",
    "cortejámo": "cortejar",
    "cortejámos": "cortejar",
    "cortejáramo": "cortejar",
    "cortejáramos": "cortejar",
    "cortejárei": "cortejar",
    "cortejáreis": "cortejar",
    "cortejásseis": "cortejar",
    "cortejássemos": "cortejar",
    "cortejávamo": "cortejar",
    "cortejávamos": "cortejar",
    "cortejávei": "cortejar",
    "cortejáveis": "cortejar",
    "cortelhas": "cortelha",
    "cortelhos": "cortelho",
    "cortem": "cortar",
    "cortemo": "cortar",
    "cortemos": "cortar",
    "cortes": "corte",
    "cortesanesa": "cortesanês",
    "cortesanesas": "cortesanês",
    "cortesanesca": "cortesanesco",
    "cortesanescas": "cortesanesco",
    "cortesanescos": "cortesanesco",
    "cortesaneses": "cortesanês",
    "cortesanias": "cortesania",
    "cortesanices": "cortesanice",
    "corteses": "cortês",
    "cortesias": "cortesia",
    "cortesã": "cortesão",
    "cortesãos": "cortesão",
    "cortesãs": "cortesão",
    "corticais": "cortical",
    "corticeira": "corticeiro",
    "corticeiras": "corticeiro",
    "corticeiros": "corticeiro",
    "corticenta": "corticento",
    "corticentas": "corticento",
    "corticentos": "corticento",
    "corticiformes": "corticiforme",
    "corticites": "corticite",
    "corticosa": "corticoso",
    "corticosas": "corticoso",
    "corticosos": "corticoso",
    "corticícolas": "corticícola",
    "corticóides": "corticóide",
    "cortilha": "cortilhar",
    "cortilhada": "cortilhar",
    "cortilhadas": "cortilhar",
    "cortilhado": "cortilhar",
    "cortilhados": "cortilhar",
    "cortilhai": "cortilhar",
    "cortilhais": "cortilhar",
    "cortilham": "cortilhar",
    "cortilhamo": "cortilhar",
    "cortilhamos": "cortilhar",
    "cortilhando": "cortilhar",
    "cortilhara": "cortilhar",
    "cortilharam": "cortilhar",
    "cortilharas": "cortilhar",
    "cortilharde": "cortilhar",
    "cortilhardes": "cortilhar",
    "cortilhare": "cortilhar",
    "cortilharei": "cortilhar",
    "cortilhareis": "cortilhar",
    "cortilharem": "cortilhar",
    "cortilharemos": "cortilhar",
    "cortilhares": "cortilhar",
    "cortilharia": "cortilhar",
    "cortilhariam": "cortilhar",
    "cortilharias": "cortilhar",
    "cortilharmo": "cortilhar",
    "cortilharmos": "cortilhar",
    "cortilhará": "cortilhar",
    "cortilharás": "cortilhar",
    "cortilharão": "cortilhar",
    "cortilharíamos": "cortilhar",
    "cortilharíeis": "cortilhar",
    "cortilhas": "cortilhar",
    "cortilhasse": "cortilhar",
    "cortilhassem": "cortilhar",
    "cortilhasses": "cortilhar",
    "cortilhaste": "cortilhar",
    "cortilhastes": "cortilhar",
    "cortilhava": "cortilhar",
    "cortilhavam": "cortilhar",
    "cortilhavas": "cortilhar",
    "cortilhe": "cortilhar",
    "cortilhei": "cortilhar",
    "cortilheis": "cortilhar",
    "cortilhem": "cortilhar",
    "cortilhemo": "cortilhar",
    "cortilhemos": "cortilhar",
    "cortilhes": "cortilhar",
    "cortilho": "cortilhar",
    "cortilhou": "cortilhar",
    "cortilhá": "cortilhar",
    "cortilhámo": "cortilhar",
    "cortilhámos": "cortilhar",
    "cortilháramo": "cortilhar",
    "cortilháramos": "cortilhar",
    "cortilhárei": "cortilhar",
    "cortilháreis": "cortilhar",
    "cortilhásseis": "cortilhar",
    "cortilhássemos": "cortilhar",
    "cortilhávamo": "cortilhar",
    "cortilhávamos": "cortilhar",
    "cortilhávei": "cortilhar",
    "cortilháveis": "cortilhar",
    "cortina": "cortinar",
    "cortinada": "cortinar",
    "cortinadas": "cortinar",
    "cortinado": "cortinar",
    "cortinados": "cortinar",
    "cortinai": "cortinar",
    "cortinais": "cortinar",
    "cortinam": "cortinar",
    "cortinamo": "cortinar",
    "cortinamos": "cortinar",
    "cortinando": "cortinar",
    "cortinara": "cortinar",
    "cortinaram": "cortinar",
    "cortinaras": "cortinar",
    "cortinarde": "cortinar",
    "cortinardes": "cortinar",
    "cortinare": "cortinar",
    "cortinarei": "cortinar",
    "cortinareis": "cortinar",
    "cortinarem": "cortinar",
    "cortinaremos": "cortinar",
    "cortinares": "cortinar",
    "cortinaria": "cortinar",
    "cortinariam": "cortinar",
    "cortinarias": "cortinar",
    "cortinarmo": "cortinar",
    "cortinarmos": "cortinar",
    "cortinará": "cortinar",
    "cortinarás": "cortinar",
    "cortinarão": "cortinar",
    "cortinaríamos": "cortinar",
    "cortinaríeis": "cortinar",
    "cortinas": "cortinar",
    "cortinasse": "cortinar",
    "cortinassem": "cortinar",
    "cortinasses": "cortinar",
    "cortinaste": "cortinar",
    "cortinastes": "cortinar",
    "cortinava": "cortinar",
    "cortinavam": "cortinar",
    "cortinavas": "cortinar",
    "cortinazinha": "cortina",
    "cortinazinhas": "cortina",
    "cortinazita": "cortina",
    "cortinazitas": "cortina",
    "cortine": "cortinar",
    "cortinei": "cortinar",
    "cortineis": "cortinar",
    "cortinem": "cortinar",
    "cortinemo": "cortinar",
    "cortinemos": "cortinar",
    "cortines": "cortinar",
    "cortinhais": "cortinhal",
    "cortinhas": "cortinha",
    "cortinheiros": "cortinheiro",
    "cortininha": "cortina",
    "cortininhas": "cortina",
    "cortinita": "cortina",
    "cortinitas": "cortina",
    "cortino": "cortinar",
    "cortinou": "cortinar",
    "cortiná": "cortinar",
    "cortinámo": "cortinar",
    "cortinámos": "cortinar",
    "cortináramo": "cortinar",
    "cortináramos": "cortinar",
    "cortinárei": "cortinar",
    "cortináreis": "cortinar",
    "cortinásseis": "cortinar",
    "cortinássemos": "cortinar",
    "cortinávamo": "cortinar",
    "cortinávamos": "cortinar",
    "cortinávei": "cortinar",
    "cortináveis": "cortinar",
    "cortisonas": "cortisona",
    "cortiçada": "cortiçado",
    "cortiçadas": "cortiçado",
    "cortiçados": "cortiçado",
    "cortiças": "cortiça",
    "cortiços": "cortiço",
    "cortiçosa": "cortiçoso",
    "cortiçosas": "cortiçoso",
    "cortiçosos": "cortiçoso",
    "cortiçós": "cortiçó",
    "corto": "cortar",
    "cortonomias": "cortonomia",
    "cortonómica": "cortonómico",
    "cortonómicas": "cortonómico",
    "cortonómicos": "cortonómico",
    "cortou": "cortar",
    "cortá": "cortar",
    "cortámo": "cortar",
    "cortámos": "cortar",
    "cortáramo": "cortar",
    "cortáramos": "cortar",
    "cortárei": "cortar",
    "cortáreis": "cortar",
    "cortásseis": "cortar",
    "cortássemos": "cortar",
    "cortávamo": "cortar",
    "cortávamos": "cortar",
    "cortávei": "cortar",
    "cortáveis": "cortar",
    "cortícea": "cortíceo",
    "cortíceas": "cortíceo",
    "cortíceos": "cortíceo",
    "cortícolas": "cortícola",
    "coruchéus": "coruchéu",
    "coruja": "corujar",
    "corujada": "corujar",
    "corujadas": "corujar",
    "corujado": "corujar",
    "corujados": "corujar",
    "corujai": "corujar",
    "corujais": "corujar",
    "corujam": "corujar",
    "corujamo": "corujar",
    "corujamos": "corujar",
    "corujando": "corujar",
    "corujara": "corujar",
    "corujaram": "corujar",
    "corujaras": "corujar",
    "corujardes": "corujar",
    "corujarei": "corujar",
    "corujareis": "corujar",
    "corujarem": "corujar",
    "corujaremos": "corujar",
    "corujares": "corujar",
    "corujaria": "corujar",
    "corujariam": "corujar",
    "corujarias": "corujar",
    "corujarmo": "corujar",
    "corujarmos": "corujar",
    "corujará": "corujar",
    "corujarás": "corujar",
    "corujarão": "corujar",
    "corujaríamos": "corujar",
    "corujaríeis": "corujar",
    "corujas": "corujar",
    "corujasse": "corujar",
    "corujassem": "corujar",
    "corujasses": "corujar",
    "corujaste": "corujar",
    "corujastes": "corujar",
    "corujava": "corujar",
    "corujavam": "corujar",
    "corujavas": "corujar",
    "corujazinha": "coruja",
    "corujazinhas": "coruja",
    "corujazita": "coruja",
    "corujazitas": "coruja",
    "coruje": "corujar",
    "corujei": "corujar",
    "corujeiras": "corujeira",
    "corujeiros": "corujeiro",
    "corujeis": "corujar",
    "corujem": "corujar",
    "corujemo": "corujar",
    "corujemos": "corujar",
    "corujenta": "corujento",
    "corujentas": "corujento",
    "corujentos": "corujento",
    "corujes": "corujar",
    "corujinha": "coruja",
    "corujinhas": "corujinha",
    "corujita": "coruja",
    "corujitas": "coruja",
    "corujo": "corujar",
    "corujos": "corujo",
    "corujou": "corujar",
    "corujámo": "corujar",
    "corujámos": "corujar",
    "corujáramo": "corujar",
    "corujáramos": "corujar",
    "corujáreis": "corujar",
    "corujásseis": "corujar",
    "corujássemos": "corujar",
    "corujávamo": "corujar",
    "corujávamos": "corujar",
    "corujáveis": "corujar",
    "corujões": "corujão",
    "corundos": "corundo",
    "corunhesa": "corunhês",
    "corunhesas": "corunhês",
    "corunheses": "corunhês",
    "corusca": "coruscar",
    "coruscada": "coruscar",
    "coruscadas": "coruscar",
    "coruscado": "coruscar",
    "coruscados": "coruscar",
    "coruscais": "coruscar",
    "coruscam": "coruscar",
    "coruscamo": "coruscar",
    "coruscamos": "coruscar",
    "coruscando": "coruscar",
    "coruscantes": "coruscante",
    "coruscara": "coruscar",
    "coruscaram": "coruscar",
    "coruscaras": "coruscar",
    "coruscardes": "coruscar",
    "coruscarei": "coruscar",
    "coruscareis": "coruscar",
    "coruscarem": "coruscar",
    "coruscaremos": "coruscar",
    "coruscares": "coruscar",
    "coruscaria": "coruscar",
    "coruscariam": "coruscar",
    "coruscarias": "coruscar",
    "coruscarmo": "coruscar",
    "coruscarmos": "coruscar",
    "coruscará": "coruscar",
    "coruscarás": "coruscar",
    "coruscarão": "coruscar",
    "coruscaríamos": "coruscar",
    "coruscaríeis": "coruscar",
    "coruscas": "coruscar",
    "coruscasse": "coruscar",
    "coruscassem": "coruscar",
    "coruscasses": "coruscar",
    "coruscaste": "coruscar",
    "coruscastes": "coruscar",
    "coruscava": "coruscar",
    "coruscavam": "coruscar",
    "coruscavas": "coruscar",
    "coruscações": "coruscação",
    "corusco": "coruscar",
    "coruscos": "corusco",
    "coruscou": "coruscar",
    "coruscámo": "coruscar",
    "coruscámos": "coruscar",
    "coruscáramo": "coruscar",
    "coruscáramos": "coruscar",
    "coruscáreis": "coruscar",
    "coruscásseis": "coruscar",
    "coruscássemos": "coruscar",
    "coruscávamo": "coruscar",
    "coruscávamos": "coruscar",
    "coruscáveis": "coruscar",
    "corusque": "coruscar",
    "corusquei": "coruscar",
    "corusqueis": "coruscar",
    "corusquem": "coruscar",
    "corusquemos": "coruscar",
    "corusques": "coruscar",
    "corutas": "coruta",
    "corutilhos": "corutilho",
    "corutos": "coruto",
    "corvachos": "corvacho",
    "corvas": "corva",
    "corveiras": "corveira",
    "corveiros": "corveiro",
    "corveja": "corvejar",
    "corvejada": "corvejar",
    "corvejadas": "corvejar",
    "corvejado": "corvejar",
    "corvejados": "corvejar",
    "corvejai": "corvejar",
    "corvejais": "corvejar",
    "corvejam": "corvejar",
    "corvejamo": "corvejar",
    "corvejamos": "corvejar",
    "corvejando": "corvejar",
    "corvejara": "corvejar",
    "corvejaram": "corvejar",
    "corvejaras": "corvejar",
    "corvejardes": "corvejar",
    "corvejarei": "corvejar",
    "corvejareis": "corvejar",
    "corvejarem": "corvejar",
    "corvejaremos": "corvejar",
    "corvejares": "corvejar",
    "corvejaria": "corvejar",
    "corvejariam": "corvejar",
    "corvejarias": "corvejar",
    "corvejarmo": "corvejar",
    "corvejarmos": "corvejar",
    "corvejará": "corvejar",
    "corvejarás": "corvejar",
    "corvejarão": "corvejar",
    "corvejaríamos": "corvejar",
    "corvejaríeis": "corvejar",
    "corvejas": "corvejar",
    "corvejasse": "corvejar",
    "corvejassem": "corvejar",
    "corvejasses": "corvejar",
    "corvejaste": "corvejar",
    "corvejastes": "corvejar",
    "corvejava": "corvejar",
    "corvejavam": "corvejar",
    "corvejavas": "corvejar",
    "corveje": "corvejar",
    "corvejei": "corvejar",
    "corvejeis": "corvejar",
    "corvejem": "corvejar",
    "corvejemo": "corvejar",
    "corvejemos": "corvejar",
    "corvejes": "corvejar",
    "corvejo": "corvejar",
    "corvejou": "corvejar",
    "corvejámo": "corvejar",
    "corvejámos": "corvejar",
    "corvejáramo": "corvejar",
    "corvejáramos": "corvejar",
    "corvejáreis": "corvejar",
    "corvejásseis": "corvejar",
    "corvejássemos": "corvejar",
    "corvejávamo": "corvejar",
    "corvejávamos": "corvejar",
    "corvejáveis": "corvejar",
    "corvelos": "corvelo",
    "corvenses": "corvense",
    "corvetas": "corveta",
    "corvina": "corvino",
    "corvinas": "corvino",
    "corvineira": "corvineiro",
    "corvineiras": "corvineiro",
    "corvineiros": "corvineiro",
    "corvinos": "corvino",
    "corvos": "corvo",
    "corvéus": "corvéu",
    "corvídeos": "corvídeo",
    "corvínea": "corvíneo",
    "corvíneas": "corvíneo",
    "corvíneos": "corvíneo",
    "corzinha": "cor",
    "corzinhas": "cor",
    "corzita": "cor",
    "corzitas": "cor",
    "corá": "corar",
    "corámo": "corar",
    "corámos": "corar",
    "coráramo": "corar",
    "coráramos": "corar",
    "corárei": "corar",
    "coráreis": "corar",
    "corásseis": "corar",
    "corássemos": "corar",
    "corávamo": "corar",
    "corávamos": "corar",
    "corávei": "corar",
    "coráveis": "corar",
    "corânica": "corânico",
    "corânicas": "corânico",
    "corânicos": "corânico",
    "corça": "corço",
    "corças": "corço",
    "corços": "corço",
    "corégrafa": "corégrafo",
    "corégrafas": "corégrafo",
    "corégrafos": "corégrafo",
    "coréias": "coréia",
    "coréica": "coréico",
    "coréicas": "coréico",
    "coréicos": "coréico",
    "coríndones": "coríndon",
    "coríntia": "coríntio",
    "coríntias": "coríntio",
    "coríntios": "coríntio",
    "corógrafa": "corógrafo",
    "corógrafas": "corógrafo",
    "corógrafos": "corógrafo",
    "coróides": "coróide",
    "corónides": "corónide",
    "corúpeta": "corúpeto",
    "corúpetas": "corúpeto",
    "corúpetos": "corúpeto",
    "cosa": "coser",
    "cosais": "coser",
    "cosam": "coser",
    "cosamo": "coser",
    "cosamos": "coser",
    "cosas": "coser",
    "coscinomancias": "coscinomancia",
    "coscinomantes": "coscinomante",
    "coscinomântica": "coscinomântico",
    "coscinomânticas": "coscinomântico",
    "coscinomânticos": "coscinomântico",
    "coscinoscopias": "coscinoscopia",
    "coscinoscópica": "coscinoscópico",
    "coscinoscópicas": "coscinoscópico",
    "coscinoscópicos": "coscinoscópico",
    "coscora": "coscorar",
    "coscorada": "coscorar",
    "coscoradas": "coscorar",
    "coscorado": "coscorar",
    "coscorados": "coscorar",
    "coscorai": "coscorar",
    "coscorais": "coscorar",
    "coscoram": "coscorar",
    "coscoramo": "coscorar",
    "coscoramos": "coscorar",
    "coscorando": "coscorar",
    "coscorara": "coscorar",
    "coscoraram": "coscorar",
    "coscoraras": "coscorar",
    "coscorarde": "coscorar",
    "coscorardes": "coscorar",
    "coscorare": "coscorar",
    "coscorarei": "coscorar",
    "coscorareis": "coscorar",
    "coscorarem": "coscorar",
    "coscoraremos": "coscorar",
    "coscorares": "coscorar",
    "coscoraria": "coscorar",
    "coscorariam": "coscorar",
    "coscorarias": "coscorar",
    "coscorarmo": "coscorar",
    "coscorarmos": "coscorar",
    "coscorará": "coscorar",
    "coscorarás": "coscorar",
    "coscorarão": "coscorar",
    "coscoraríamos": "coscorar",
    "coscoraríeis": "coscorar",
    "coscoras": "coscorar",
    "coscorasse": "coscorar",
    "coscorassem": "coscorar",
    "coscorasses": "coscorar",
    "coscoraste": "coscorar",
    "coscorastes": "coscorar",
    "coscorava": "coscorar",
    "coscoravam": "coscorar",
    "coscoravas": "coscorar",
    "coscore": "coscorar",
    "coscorei": "coscorar",
    "coscoreis": "coscorar",
    "coscorem": "coscorar",
    "coscoremo": "coscorar",
    "coscoremos": "coscorar",
    "coscores": "coscorar",
    "coscoro": "coscorar",
    "coscoros": "coscoro",
    "coscorou": "coscorar",
    "coscorrinhos": "coscorrinho",
    "coscorrões": "coscorrão",
    "coscorá": "coscorar",
    "coscorámo": "coscorar",
    "coscorámos": "coscorar",
    "coscoráramo": "coscorar",
    "coscoráramos": "coscorar",
    "coscorárei": "coscorar",
    "coscoráreis": "coscorar",
    "coscorásseis": "coscorar",
    "coscorássemos": "coscorar",
    "coscorávamo": "coscorar",
    "coscorávamos": "coscorar",
    "coscorávei": "coscorar",
    "coscoráveis": "coscorar",
    "coscorões": "coscorão",
    "coscos": "cosco",
    "coscuvilha": "coscuvilhar",
    "coscuvilhada": "coscuvilhar",
    "coscuvilhadas": "coscuvilhar",
    "coscuvilhado": "coscuvilhar",
    "coscuvilhados": "coscuvilhar",
    "coscuvilhai": "coscuvilhar",
    "coscuvilhais": "coscuvilhar",
    "coscuvilham": "coscuvilhar",
    "coscuvilhamo": "coscuvilhar",
    "coscuvilhamos": "coscuvilhar",
    "coscuvilhando": "coscuvilhar",
    "coscuvilhara": "coscuvilhar",
    "coscuvilharam": "coscuvilhar",
    "coscuvilharas": "coscuvilhar",
    "coscuvilhardes": "coscuvilhar",
    "coscuvilharei": "coscuvilhar",
    "coscuvilhareis": "coscuvilhar",
    "coscuvilharem": "coscuvilhar",
    "coscuvilharemos": "coscuvilhar",
    "coscuvilhares": "coscuvilhar",
    "coscuvilharia": "coscuvilhar",
    "coscuvilhariam": "coscuvilhar",
    "coscuvilharias": "coscuvilhar",
    "coscuvilharmo": "coscuvilhar",
    "coscuvilharmos": "coscuvilhar",
    "coscuvilhará": "coscuvilhar",
    "coscuvilharás": "coscuvilhar",
    "coscuvilharão": "coscuvilhar",
    "coscuvilharíamos": "coscuvilhar",
    "coscuvilharíeis": "coscuvilhar",
    "coscuvilhas": "coscuvilhar",
    "coscuvilhasse": "coscuvilhar",
    "coscuvilhassem": "coscuvilhar",
    "coscuvilhasses": "coscuvilhar",
    "coscuvilhaste": "coscuvilhar",
    "coscuvilhastes": "coscuvilhar",
    "coscuvilhava": "coscuvilhar",
    "coscuvilhavam": "coscuvilhar",
    "coscuvilhavas": "coscuvilhar",
    "coscuvilhe": "coscuvilhar",
    "coscuvilhei": "coscuvilhar",
    "coscuvilheira": "coscuvilheiro",
    "coscuvilheiras": "coscuvilheiro",
    "coscuvilheiros": "coscuvilheiro",
    "coscuvilheis": "coscuvilhar",
    "coscuvilhem": "coscuvilhar",
    "coscuvilhemo": "coscuvilhar",
    "coscuvilhemos": "coscuvilhar",
    "coscuvilhes": "coscuvilhar",
    "coscuvilhices": "coscuvilhice",
    "coscuvilho": "coscuvilhar",
    "coscuvilhou": "coscuvilhar",
    "coscuvilhámo": "coscuvilhar",
    "coscuvilhámos": "coscuvilhar",
    "coscuvilháramo": "coscuvilhar",
    "coscuvilháramos": "coscuvilhar",
    "coscuvilháreis": "coscuvilhar",
    "coscuvilhásseis": "coscuvilhar",
    "coscuvilhássemos": "coscuvilhar",
    "coscuvilhávamo": "coscuvilhar",
    "coscuvilhávamos": "coscuvilhar",
    "coscuvilháveis": "coscuvilhar",
    "cose": "coser",
    "cosedora": "cosedor",
    "cosedoras": "cosedora",
    "cosedores": "cosedor",
    "coseduras": "cosedura",
    "cosei": "coser",
    "coseis": "coser",
    "cosem": "coser",
    "cosemo": "coser",
    "cosemos": "coser",
    "cosendo": "coser",
    "cosera": "coser",
    "coseram": "coser",
    "coseras": "coser",
    "coserde": "coser",
    "coserdes": "coser",
    "cosere": "coser",
    "coserei": "coser",
    "cosereis": "coser",
    "coserem": "coser",
    "coseremos": "coser",
    "coseres": "coser",
    "coseria": "coser",
    "coseriam": "coser",
    "coserias": "coser",
    "cosermo": "coser",
    "cosermos": "coser",
    "coserá": "coser",
    "coserás": "coser",
    "coserão": "coser",
    "coseríamos": "coser",
    "coseríeis": "coser",
    "coses": "coser",
    "cosesse": "coser",
    "cosessem": "coser",
    "cosesses": "coser",
    "coseste": "coser",
    "cosestes": "coser",
    "coseu": "coser",
    "cosi": "coser",
    "cosia": "coser",
    "cosiam": "coser",
    "cosias": "coser",
    "cosica": "cosicar",
    "cosicada": "cosicar",
    "cosicadas": "cosicar",
    "cosicado": "cosicar",
    "cosicados": "cosicar",
    "cosicai": "cosicar",
    "cosicais": "cosicar",
    "cosicam": "cosicar",
    "cosicamo": "cosicar",
    "cosicamos": "cosicar",
    "cosicando": "cosicar",
    "cosicara": "cosicar",
    "cosicaram": "cosicar",
    "cosicaras": "cosicar",
    "cosicarde": "cosicar",
    "cosicardes": "cosicar",
    "cosicare": "cosicar",
    "cosicarei": "cosicar",
    "cosicareis": "cosicar",
    "cosicarem": "cosicar",
    "cosicaremos": "cosicar",
    "cosicares": "cosicar",
    "cosicaria": "cosicar",
    "cosicariam": "cosicar",
    "cosicarias": "cosicar",
    "cosicarmo": "cosicar",
    "cosicarmos": "cosicar",
    "cosicará": "cosicar",
    "cosicarás": "cosicar",
    "cosicarão": "cosicar",
    "cosicaríamos": "cosicar",
    "cosicaríeis": "cosicar",
    "cosicas": "cosicar",
    "cosicasse": "cosicar",
    "cosicassem": "cosicar",
    "cosicasses": "cosicar",
    "cosicaste": "cosicar",
    "cosicastes": "cosicar",
    "cosicava": "cosicar",
    "cosicavam": "cosicar",
    "cosicavas": "cosicar",
    "cosico": "cosicar",
    "cosicou": "cosicar",
    "cosicá": "cosicar",
    "cosicámo": "cosicar",
    "cosicámos": "cosicar",
    "cosicáramo": "cosicar",
    "cosicáramos": "cosicar",
    "cosicárei": "cosicar",
    "cosicáreis": "cosicar",
    "cosicásseis": "cosicar",
    "cosicássemos": "cosicar",
    "cosicávamo": "cosicar",
    "cosicávamos": "cosicar",
    "cosicávei": "cosicar",
    "cosicáveis": "cosicar",
    "cosida": "cosido",
    "cosidas": "cosido",
    "cosidelas": "cosidela",
    "cosido": "coser",
    "cosidos": "cosido",
    "cosipa": "cosipar",
    "cosipada": "cosipar",
    "cosipadas": "cosipar",
    "cosipado": "cosipar",
    "cosipados": "cosipar",
    "cosipai": "cosipar",
    "cosipais": "cosipar",
    "cosipam": "cosipar",
    "cosipamo": "cosipar",
    "cosipamos": "cosipar",
    "cosipando": "cosipar",
    "cosipanços": "cosipanço",
    "cosipara": "cosipar",
    "cosiparam": "cosipar",
    "cosiparas": "cosipar",
    "cosiparde": "cosipar",
    "cosipardes": "cosipar",
    "cosipare": "cosipar",
    "cosiparei": "cosipar",
    "cosipareis": "cosipar",
    "cosiparem": "cosipar",
    "cosiparemos": "cosipar",
    "cosipares": "cosipar",
    "cosiparia": "cosipar",
    "cosipariam": "cosipar",
    "cosiparias": "cosipar",
    "cosiparmo": "cosipar",
    "cosiparmos": "cosipar",
    "cosipará": "cosipar",
    "cosiparás": "cosipar",
    "cosiparão": "cosipar",
    "cosiparíamos": "cosipar",
    "cosiparíeis": "cosipar",
    "cosipas": "cosipar",
    "cosipasse": "cosipar",
    "cosipassem": "cosipar",
    "cosipasses": "cosipar",
    "cosipaste": "cosipar",
    "cosipastes": "cosipar",
    "cosipava": "cosipar",
    "cosipavam": "cosipar",
    "cosipavas": "cosipar",
    "cosipe": "cosipar",
    "cosipei": "cosipar",
    "cosipeis": "cosipar",
    "cosipem": "cosipar",
    "cosipemo": "cosipar",
    "cosipemos": "cosipar",
    "cosipes": "cosipar",
    "cosipo": "cosipar",
    "cosipou": "cosipar",
    "cosipá": "cosipar",
    "cosipámo": "cosipar",
    "cosipámos": "cosipar",
    "cosipáramo": "cosipar",
    "cosipáramos": "cosipar",
    "cosipárei": "cosipar",
    "cosipáreis": "cosipar",
    "cosipásseis": "cosipar",
    "cosipássemos": "cosipar",
    "cosipávamo": "cosipar",
    "cosipávamos": "cosipar",
    "cosipávei": "cosipar",
    "cosipáveis": "cosipar",
    "cosique": "cosicar",
    "cosiquei": "cosicar",
    "cosiqueis": "cosicar",
    "cosiquem": "cosicar",
    "cosiquemo": "cosicar",
    "cosiquemos": "cosicar",
    "cosiques": "cosicar",
    "cosmeticistas": "cosmeticista",
    "cosmetologias": "cosmetologia",
    "cosmetológica": "cosmetológico",
    "cosmetológicas": "cosmetológico",
    "cosmetológicos": "cosmetológico",
    "cosmetóloga": "cosmetólogo",
    "cosmetólogas": "cosmetólogo",
    "cosmetólogos": "cosmetólogo",
    "cosmognosias": "cosmognosia",
    "cosmognósica": "cosmognósico",
    "cosmognósicas": "cosmognósico",
    "cosmognósicos": "cosmognósico",
    "cosmogonias": "cosmogonia",
    "cosmogonistas": "cosmogonista",
    "cosmografias": "cosmografia",
    "cosmográfica": "cosmográfico",
    "cosmográficas": "cosmográfico",
    "cosmográficos": "cosmográfico",
    "cosmogónica": "cosmogónico",
    "cosmogónicas": "cosmogónico",
    "cosmogónicos": "cosmogónico",
    "cosmologias": "cosmologia",
    "cosmolábios": "cosmolábio",
    "cosmológica": "cosmológico",
    "cosmológicas": "cosmológico",
    "cosmológicos": "cosmológico",
    "cosmometrias": "cosmometria",
    "cosmométrica": "cosmométrico",
    "cosmométricas": "cosmométrico",
    "cosmométricos": "cosmométrico",
    "cosmonautas": "cosmonauta",
    "cosmonomias": "cosmonomia",
    "cosmonáutica": "cosmonáutico",
    "cosmonáuticas": "cosmonáutico",
    "cosmonáuticos": "cosmonáutico",
    "cosmopolitana": "cosmopolitano",
    "cosmopolitanas": "cosmopolitano",
    "cosmopolitanos": "cosmopolitano",
    "cosmopolitas": "cosmopolita",
    "cosmopolitismos": "cosmopolitismo",
    "cosmopolitizações": "cosmopolitização",
    "cosmopoliza": "cosmopolizar",
    "cosmopolizada": "cosmopolizar",
    "cosmopolizadas": "cosmopolizar",
    "cosmopolizado": "cosmopolizar",
    "cosmopolizados": "cosmopolizar",
    "cosmopolizai": "cosmopolizar",
    "cosmopolizais": "cosmopolizar",
    "cosmopolizam": "cosmopolizar",
    "cosmopolizamo": "cosmopolizar",
    "cosmopolizamos": "cosmopolizar",
    "cosmopolizando": "cosmopolizar",
    "cosmopolizara": "cosmopolizar",
    "cosmopolizaram": "cosmopolizar",
    "cosmopolizaras": "cosmopolizar",
    "cosmopolizarde": "cosmopolizar",
    "cosmopolizardes": "cosmopolizar",
    "cosmopolizare": "cosmopolizar",
    "cosmopolizarei": "cosmopolizar",
    "cosmopolizareis": "cosmopolizar",
    "cosmopolizarem": "cosmopolizar",
    "cosmopolizaremos": "cosmopolizar",
    "cosmopolizares": "cosmopolizar",
    "cosmopolizaria": "cosmopolizar",
    "cosmopolizariam": "cosmopolizar",
    "cosmopolizarias": "cosmopolizar",
    "cosmopolizarmo": "cosmopolizar",
    "cosmopolizarmos": "cosmopolizar",
    "cosmopolizará": "cosmopolizar",
    "cosmopolizarás": "cosmopolizar",
    "cosmopolizarão": "cosmopolizar",
    "cosmopolizaríamos": "cosmopolizar",
    "cosmopolizaríeis": "cosmopolizar",
    "cosmopolizas": "cosmopolizar",
    "cosmopolizasse": "cosmopolizar",
    "cosmopolizassem": "cosmopolizar",
    "cosmopolizasses": "cosmopolizar",
    "cosmopolizaste": "cosmopolizar",
    "cosmopolizastes": "cosmopolizar",
    "cosmopolizava": "cosmopolizar",
    "cosmopolizavam": "cosmopolizar",
    "cosmopolizavas": "cosmopolizar",
    "cosmopolize": "cosmopolizar",
    "cosmopolizei": "cosmopolizar",
    "cosmopolizeis": "cosmopolizar",
    "cosmopolizem": "cosmopolizar",
    "cosmopolizemo": "cosmopolizar",
    "cosmopolizemos": "cosmopolizar",
    "cosmopolizes": "cosmopolizar",
    "cosmopolizo": "cosmopolizar",
    "cosmopolizou": "cosmopolizar",
    "cosmopolizá": "cosmopolizar",
    "cosmopolizámo": "cosmopolizar",
    "cosmopolizámos": "cosmopolizar",
    "cosmopolizáramo": "cosmopolizar",
    "cosmopolizáramos": "cosmopolizar",
    "cosmopolizárei": "cosmopolizar",
    "cosmopolizáreis": "cosmopolizar",
    "cosmopolizásseis": "cosmopolizar",
    "cosmopolizássemos": "cosmopolizar",
    "cosmopolizávamo": "cosmopolizar",
    "cosmopolizávamos": "cosmopolizar",
    "cosmopolizávei": "cosmopolizar",
    "cosmopolizáveis": "cosmopolizar",
    "cosmopolítica": "cosmopolítico",
    "cosmopolíticas": "cosmopolítico",
    "cosmopolíticos": "cosmopolítico",
    "cosmoramas": "cosmorama",
    "cosmos": "cosmo",
    "cosmosofias": "cosmosofia",
    "cosmosófica": "cosmosófico",
    "cosmosóficas": "cosmosófico",
    "cosmosóficos": "cosmosófico",
    "cosmovisões": "cosmovisão",
    "cosmética": "cosmético",
    "cosméticas": "cosmético",
    "cosméticos": "cosmético",
    "cosmógrafa": "cosmógrafo",
    "cosmógrafas": "cosmógrafo",
    "cosmógrafos": "cosmógrafo",
    "cosmóloga": "cosmólogo",
    "cosmólogas": "cosmólogo",
    "cosmólogos": "cosmólogo",
    "coso": "coser",
    "cospe": "cuspir",
    "cospem": "cuspir",
    "cospes": "cuspir",
    "cossaca": "cossaco",
    "cossacas": "cossaco",
    "cossacos": "cossaco",
    "cossas": "cossa",
    "cossecantes": "cossecante",
    "cossenos": "cosseno",
    "cossoilos": "cossoilo",
    "cossoiros": "cossoiro",
    "cossolentos": "cossolento",
    "cossos": "cosso",
    "cossoulos": "cossoulo",
    "costabaixos": "costabaixo",
    "costabdominais": "costabdominal",
    "costada": "costado",
    "costadas": "costado",
    "costados": "costado",
    "costais": "costal",
    "costaleiras": "costaleira",
    "costalgias": "costalgia",
    "costaneira": "costaneiro",
    "costaneiras": "costaneiro",
    "costaneiros": "costaneiro",
    "costas": "costa",
    "costeada": "costear",
    "costeadas": "costear",
    "costeado": "costear",
    "costeados": "costear",
    "costeagens": "costeagem",
    "costeai": "costear",
    "costeais": "costear",
    "costeamentos": "costeamento",
    "costeamo": "costear",
    "costeamos": "costear",
    "costeando": "costear",
    "costeara": "costear",
    "costearam": "costear",
    "costearas": "costear",
    "costeardes": "costear",
    "costearei": "costear",
    "costeareis": "costear",
    "costearem": "costear",
    "costearemos": "costear",
    "costeares": "costear",
    "costearia": "costear",
    "costeariam": "costear",
    "costearias": "costear",
    "costearmo": "costear",
    "costearmos": "costear",
    "costeará": "costear",
    "costearás": "costear",
    "costearão": "costear",
    "costearíamos": "costear",
    "costearíeis": "costear",
    "costeasse": "costear",
    "costeassem": "costear",
    "costeasses": "costear",
    "costeaste": "costear",
    "costeastes": "costear",
    "costeava": "costear",
    "costeavam": "costear",
    "costeavas": "costear",
    "costeei": "costear",
    "costeeis": "costear",
    "costeemo": "costear",
    "costeemos": "costear",
    "costeia": "costear",
    "costeiam": "costear",
    "costeias": "costear",
    "costeie": "costear",
    "costeiem": "costear",
    "costeies": "costear",
    "costeio": "costear",
    "costeios": "costeio",
    "costeira": "costeiro",
    "costeiras": "costeiro",
    "costeiros": "costeiro",
    "costelames": "costelame",
    "costelas": "costela",
    "costeletas": "costeleta",
    "costeou": "costear",
    "costeámo": "costear",
    "costeámos": "costear",
    "costeáramo": "costear",
    "costeáramos": "costear",
    "costeáreis": "costear",
    "costeásseis": "costear",
    "costeássemos": "costear",
    "costeávamo": "costear",
    "costeávamos": "costear",
    "costeáveis": "costear",
    "costiformes": "costiforme",
    "costilhas": "costilha",
    "costocapulares": "costocapular",
    "costoclaviculares": "costoclavicular",
    "costos": "costo",
    "costosternais": "costosternal",
    "costostómica": "costostómico",
    "costostómicas": "costostómico",
    "costostómicos": "costostómico",
    "costoternias": "costoternia",
    "costotomias": "costotomia",
    "costovertebrais": "costovertebral",
    "costuma": "costumar",
    "costumada": "costumar",
    "costumadas": "costumar",
    "costumado": "costumar",
    "costumados": "costumar",
    "costumagens": "costumagem",
    "costumai": "costumar",
    "costumais": "costumar",
    "costumam": "costumar",
    "costumamo": "costumar",
    "costumamos": "costumar",
    "costumando": "costumar",
    "costumanças": "costumança",
    "costumara": "costumar",
    "costumaram": "costumar",
    "costumaras": "costumar",
    "costumarde": "costumar",
    "costumardes": "costumar",
    "costumare": "costumar",
    "costumarei": "costumar",
    "costumareis": "costumar",
    "costumarem": "costumar",
    "costumaremos": "costumar",
    "costumares": "costumar",
    "costumaria": "costumar",
    "costumariam": "costumar",
    "costumarias": "costumar",
    "costumarmo": "costumar",
    "costumarmos": "costumar",
    "costumará": "costumar",
    "costumarás": "costumar",
    "costumarão": "costumar",
    "costumaríamos": "costumar",
    "costumaríeis": "costumar",
    "costumas": "costumar",
    "costumasse": "costumar",
    "costumassem": "costumar",
    "costumasses": "costumar",
    "costumaste": "costumar",
    "costumastes": "costumar",
    "costumava": "costumar",
    "costumavam": "costumar",
    "costumavas": "costumar",
    "costumbrismos": "costumbrismo",
    "costumbristas": "costumbrista",
    "costume": "costumar",
    "costumei": "costumar",
    "costumeira": "costumeiro",
    "costumeiras": "costumeiro",
    "costumeiros": "costumeiro",
    "costumeis": "costumar",
    "costumem": "costumar",
    "costumemo": "costumar",
    "costumemos": "costumar",
    "costumes": "costume",
    "costumo": "costumar",
    "costumou": "costumar",
    "costumá": "costumar",
    "costumámo": "costumar",
    "costumámos": "costumar",
    "costumáramo": "costumar",
    "costumáramos": "costumar",
    "costumárei": "costumar",
    "costumáreis": "costumar",
    "costumária": "costumário",
    "costumárias": "costumário",
    "costumários": "costumário",
    "costumásseis": "costumar",
    "costumássemos": "costumar",
    "costumávamo": "costumar",
    "costumávamos": "costumar",
    "costumávei": "costumar",
    "costumáveis": "costumar",
    "costura": "costurar",
    "costurada": "costurar",
    "costuradas": "costurar",
    "costurado": "costurar",
    "costurados": "costurar",
    "costurai": "costurar",
    "costurais": "costurar",
    "costuram": "costurar",
    "costuramo": "costurar",
    "costuramos": "costurar",
    "costurando": "costurar",
    "costurara": "costurar",
    "costuraram": "costurar",
    "costuraras": "costurar",
    "costurarde": "costurar",
    "costurardes": "costurar",
    "costurare": "costurar",
    "costurarei": "costurar",
    "costurareis": "costurar",
    "costurarem": "costurar",
    "costuraremos": "costurar",
    "costurares": "costurar",
    "costuraria": "costurar",
    "costurariam": "costurar",
    "costurarias": "costurar",
    "costurarmo": "costurar",
    "costurarmos": "costurar",
    "costurará": "costurar",
    "costurarás": "costurar",
    "costurarão": "costurar",
    "costuraríamos": "costurar",
    "costuraríeis": "costurar",
    "costuras": "costurar",
    "costurasse": "costurar",
    "costurassem": "costurar",
    "costurasses": "costurar",
    "costuraste": "costurar",
    "costurastes": "costurar",
    "costurava": "costurar",
    "costuravam": "costurar",
    "costuravas": "costurar",
    "costure": "costurar",
    "costurei": "costurar",
    "costureira": "costureiro",
    "costureiras": "costureiro",
    "costureiros": "costureiro",
    "costureis": "costurar",
    "costurem": "costurar",
    "costuremo": "costurar",
    "costuremos": "costurar",
    "costures": "costurar",
    "costuro": "costurar",
    "costurou": "costurar",
    "costurá": "costurar",
    "costurámo": "costurar",
    "costurámos": "costurar",
    "costuráramo": "costurar",
    "costuráramos": "costurar",
    "costurárei": "costurar",
    "costuráreis": "costurar",
    "costurásseis": "costurar",
    "costurássemos": "costurar",
    "costurávamo": "costurar",
    "costurávamos": "costurar",
    "costurávei": "costurar",
    "costuráveis": "costurar",
    "costurões": "costurão",
    "costálgica": "costálgico",
    "costálgicas": "costálgico",
    "costálgicos": "costálgico",
    "costótomos": "costótomo",
    "cosê": "coser",
    "cosêramo": "coser",
    "cosêramos": "coser",
    "cosêrei": "coser",
    "cosêreis": "coser",
    "cosêsseis": "coser",
    "cosêssemos": "coser",
    "cosíamo": "coser",
    "cosíamos": "coser",
    "cosíei": "coser",
    "cosíeis": "coser",
    "cota": "cotar",
    "cotada": "cotar",
    "cotadas": "cotar",
    "cotadilhos": "cotadilho",
    "cotado": "cotar",
    "cotadora": "cotador",
    "cotadoras": "cotador",
    "cotadores": "cotador",
    "cotados": "cotar",
    "cotadíssima": "cotado",
    "cotadíssimas": "cotado",
    "cotadíssimo": "cotado",
    "cotadíssimos": "cotado",
    "cotai": "cotar",
    "cotais": "cotar",
    "cotam": "cotar",
    "cotamentos": "cotamento",
    "cotamo": "cotar",
    "cotamos": "cotar",
    "cotando": "cotar",
    "cotangentes": "cotangente",
    "cotanilhosa": "cotanilhoso",
    "cotanilhosas": "cotanilhoso",
    "cotanilhosos": "cotanilhoso",
    "cotara": "cotar",
    "cotaram": "cotar",
    "cotaras": "cotar",
    "cotarde": "cotar",
    "cotardes": "cotar",
    "cotare": "cotar",
    "cotarei": "cotar",
    "cotareis": "cotar",
    "cotarem": "cotar",
    "cotaremos": "cotar",
    "cotares": "cotar",
    "cotaria": "cotar",
    "cotariam": "cotar",
    "cotarias": "cotar",
    "cotarmo": "cotar",
    "cotarmos": "cotar",
    "cotará": "cotar",
    "cotarás": "cotar",
    "cotarão": "cotar",
    "cotaríamos": "cotar",
    "cotaríeis": "cotar",
    "cotas": "cotar",
    "cotasse": "cotar",
    "cotassem": "cotar",
    "cotasses": "cotar",
    "cotaste": "cotar",
    "cotastes": "cotar",
    "cotava": "cotar",
    "cotavam": "cotar",
    "cotavas": "cotar",
    "cotações": "cotação",
    "cote": "cotar",
    "coteada": "coteado",
    "coteadas": "coteado",
    "coteados": "coteado",
    "cotei": "cotar",
    "coteis": "cotar",
    "coteja": "cotejar",
    "cotejada": "cotejar",
    "cotejadas": "cotejar",
    "cotejado": "cotejar",
    "cotejadora": "cotejador",
    "cotejadoras": "cotejador",
    "cotejadores": "cotejador",
    "cotejados": "cotejar",
    "cotejai": "cotejar",
    "cotejais": "cotejar",
    "cotejam": "cotejar",
    "cotejamo": "cotejar",
    "cotejamos": "cotejar",
    "cotejando": "cotejar",
    "cotejara": "cotejar",
    "cotejaram": "cotejar",
    "cotejaras": "cotejar",
    "cotejarde": "cotejar",
    "cotejardes": "cotejar",
    "cotejare": "cotejar",
    "cotejarei": "cotejar",
    "cotejareis": "cotejar",
    "cotejarem": "cotejar",
    "cotejaremos": "cotejar",
    "cotejares": "cotejar",
    "cotejaria": "cotejar",
    "cotejariam": "cotejar",
    "cotejarias": "cotejar",
    "cotejarmo": "cotejar",
    "cotejarmos": "cotejar",
    "cotejará": "cotejar",
    "cotejarás": "cotejar",
    "cotejarão": "cotejar",
    "cotejaríamos": "cotejar",
    "cotejaríeis": "cotejar",
    "cotejas": "cotejar",
    "cotejasse": "cotejar",
    "cotejassem": "cotejar",
    "cotejasses": "cotejar",
    "cotejaste": "cotejar",
    "cotejastes": "cotejar",
    "cotejava": "cotejar",
    "cotejavam": "cotejar",
    "cotejavas": "cotejar",
    "coteje": "cotejar",
    "cotejei": "cotejar",
    "cotejeis": "cotejar",
    "cotejem": "cotejar",
    "cotejemo": "cotejar",
    "cotejemos": "cotejar",
    "cotejes": "cotejar",
    "cotejo": "cotejar",
    "cotejos": "cotejo",
    "cotejou": "cotejar",
    "cotejá": "cotejar",
    "cotejámo": "cotejar",
    "cotejámos": "cotejar",
    "cotejáramo": "cotejar",
    "cotejáramos": "cotejar",
    "cotejárei": "cotejar",
    "cotejáreis": "cotejar",
    "cotejásseis": "cotejar",
    "cotejássemos": "cotejar",
    "cotejávamo": "cotejar",
    "cotejávamos": "cotejar",
    "cotejávei": "cotejar",
    "cotejáveis": "cotejar",
    "cotem": "cotar",
    "cotemo": "cotar",
    "cotemos": "cotar",
    "cotes": "cote",
    "cotetos": "coteto",
    "cotia": "cotio",
    "cotiada": "cotiar",
    "cotiadas": "cotiar",
    "cotiado": "cotiar",
    "cotiados": "cotiar",
    "cotiai": "cotiar",
    "cotiais": "cotiar",
    "cotiam": "cotiar",
    "cotiamo": "cotiar",
    "cotiamos": "cotiar",
    "cotiando": "cotiar",
    "cotiara": "cotiar",
    "cotiaram": "cotiar",
    "cotiaras": "cotiar",
    "cotiarde": "cotiar",
    "cotiardes": "cotiar",
    "cotiare": "cotiar",
    "cotiarei": "cotiar",
    "cotiareis": "cotiar",
    "cotiarem": "cotiar",
    "cotiaremos": "cotiar",
    "cotiares": "cotiar",
    "cotiaria": "cotiar",
    "cotiariam": "cotiar",
    "cotiarias": "cotiar",
    "cotiarmo": "cotiar",
    "cotiarmos": "cotiar",
    "cotiará": "cotiar",
    "cotiarás": "cotiar",
    "cotiarão": "cotiar",
    "cotiaríamos": "cotiar",
    "cotiaríeis": "cotiar",
    "cotias": "cotio",
    "cotiasse": "cotiar",
    "cotiassem": "cotiar",
    "cotiasses": "cotiar",
    "cotiaste": "cotiar",
    "cotiastes": "cotiar",
    "cotiava": "cotiar",
    "cotiavam": "cotiar",
    "cotiavas": "cotiar",
    "coticada": "coticado",
    "coticadas": "coticado",
    "coticados": "coticado",
    "cotidiana": "cotidiano",
    "cotidianas": "cotidiano",
    "cotidianos": "cotidiano",
    "cotie": "cotiar",
    "cotiei": "cotiar",
    "cotieis": "cotiar",
    "cotiem": "cotiar",
    "cotiemo": "cotiar",
    "cotiemos": "cotiar",
    "coties": "cotiar",
    "cotiledonares": "cotiledonar",
    "cotiledónea": "cotiledóneo",
    "cotiledóneas": "cotiledóneo",
    "cotiledóneos": "cotiledóneo",
    "cotilhões": "cotilhão",
    "cotilédones": "cotilédone",
    "cotilóides": "cotilóide",
    "cotingas": "cotinga",
    "cotingídeos": "cotingídeo",
    "cotingídia": "cotingídio",
    "cotingídias": "cotingídio",
    "cotingídios": "cotingídio",
    "cotins": "cotim",
    "cotio": "cotiar",
    "cotios": "cotio",
    "cotiou": "cotiar",
    "cotiza": "cotizar",
    "cotizada": "cotizar",
    "cotizadas": "cotizar",
    "cotizado": "cotizar",
    "cotizados": "cotizar",
    "cotizai": "cotizar",
    "cotizais": "cotizar",
    "cotizam": "cotizar",
    "cotizamo": "cotizar",
    "cotizamos": "cotizar",
    "cotizando": "cotizar",
    "cotizara": "cotizar",
    "cotizaram": "cotizar",
    "cotizaras": "cotizar",
    "cotizarde": "cotizar",
    "cotizardes": "cotizar",
    "cotizare": "cotizar",
    "cotizarei": "cotizar",
    "cotizareis": "cotizar",
    "cotizarem": "cotizar",
    "cotizaremos": "cotizar",
    "cotizares": "cotizar",
    "cotizaria": "cotizar",
    "cotizariam": "cotizar",
    "cotizarias": "cotizar",
    "cotizarmo": "cotizar",
    "cotizarmos": "cotizar",
    "cotizará": "cotizar",
    "cotizarás": "cotizar",
    "cotizarão": "cotizar",
    "cotizaríamos": "cotizar",
    "cotizaríeis": "cotizar",
    "cotizas": "cotizar",
    "cotizasse": "cotizar",
    "cotizassem": "cotizar",
    "cotizasses": "cotizar",
    "cotizaste": "cotizar",
    "cotizastes": "cotizar",
    "cotizava": "cotizar",
    "cotizavam": "cotizar",
    "cotizavas": "cotizar",
    "cotizações": "cotização",
    "cotize": "cotizar",
    "cotizei": "cotizar",
    "cotizeis": "cotizar",
    "cotizem": "cotizar",
    "cotizemo": "cotizar",
    "cotizemos": "cotizar",
    "cotizes": "cotizar",
    "cotizo": "cotizar",
    "cotizou": "cotizar",
    "cotizá": "cotizar",
    "cotizámo": "cotizar",
    "cotizámos": "cotizar",
    "cotizáramo": "cotizar",
    "cotizáramos": "cotizar",
    "cotizárei": "cotizar",
    "cotizáreis": "cotizar",
    "cotizásseis": "cotizar",
    "cotizássemos": "cotizar",
    "cotizávamo": "cotizar",
    "cotizávamos": "cotizar",
    "cotizávei": "cotizar",
    "cotizáveis": "cotizável",
    "cotiá": "cotiar",
    "cotiámo": "cotiar",
    "cotiámos": "cotiar",
    "cotiáramo": "cotiar",
    "cotiáramos": "cotiar",
    "cotiárei": "cotiar",
    "cotiáreis": "cotiar",
    "cotiásseis": "cotiar",
    "cotiássemos": "cotiar",
    "cotiávamo": "cotiar",
    "cotiávamos": "cotiar",
    "cotiávei": "cotiar",
    "cotiáveis": "cotiar",
    "coto": "cotar",
    "cotocos": "cotoco",
    "cotona": "cotonar",
    "cotonada": "cotonar",
    "cotonadas": "cotonar",
    "cotonado": "cotonar",
    "cotonados": "cotonar",
    "cotonai": "cotonar",
    "cotonais": "cotonar",
    "cotonam": "cotonar",
    "cotonamo": "cotonar",
    "cotonamos": "cotonar",
    "cotonando": "cotonar",
    "cotonara": "cotonar",
    "cotonaram": "cotonar",
    "cotonaras": "cotonar",
    "cotonarde": "cotonar",
    "cotonardes": "cotonar",
    "cotonare": "cotonar",
    "cotonarei": "cotonar",
    "cotonareis": "cotonar",
    "cotonarem": "cotonar",
    "cotonaremos": "cotonar",
    "cotonares": "cotonar",
    "cotonaria": "cotonar",
    "cotonariam": "cotonar",
    "cotonarias": "cotonaria",
    "cotonarmo": "cotonar",
    "cotonarmos": "cotonar",
    "cotonará": "cotonar",
    "cotonarás": "cotonar",
    "cotonarão": "cotonar",
    "cotonaríamos": "cotonar",
    "cotonaríeis": "cotonar",
    "cotonas": "cotonar",
    "cotonasse": "cotonar",
    "cotonassem": "cotonar",
    "cotonasses": "cotonar",
    "cotonaste": "cotonar",
    "cotonastes": "cotonar",
    "cotonava": "cotonar",
    "cotonavam": "cotonar",
    "cotonavas": "cotonar",
    "cotone": "cotonar",
    "cotonei": "cotonar",
    "cotoneiras": "cotoneira",
    "cotoneis": "cotonar",
    "cotonem": "cotonar",
    "cotonemo": "cotonar",
    "cotonemos": "cotonar",
    "cotones": "cotonar",
    "cotonetes": "cotonete",
    "cotonicultors": "cotonicultor",
    "cotoniculturas": "cotonicultura",
    "cotono": "cotonar",
    "cotonosa": "cotonoso",
    "cotonosas": "cotonoso",
    "cotonosos": "cotonoso",
    "cotonou": "cotonar",
    "cotoná": "cotonar",
    "cotonámo": "cotonar",
    "cotonámos": "cotonar",
    "cotonáramo": "cotonar",
    "cotonáramos": "cotonar",
    "cotonárei": "cotonar",
    "cotonáreis": "cotonar",
    "cotonárias": "cotonária",
    "cotonásseis": "cotonar",
    "cotonássemos": "cotonar",
    "cotonávamo": "cotonar",
    "cotonávamos": "cotonar",
    "cotonávei": "cotonar",
    "cotonáveis": "cotonar",
    "cotonígera": "cotonígero",
    "cotonígeras": "cotonígero",
    "cotonígeros": "cotonígero",
    "cotornada": "cotornado",
    "cotornadas": "cotornado",
    "cotornados": "cotornado",
    "cotornos": "cotorno",
    "cotorosa": "cotoroso",
    "cotorosas": "cotoroso",
    "cotorosos": "cotoroso",
    "cotorária": "cotorário",
    "cotorárias": "cotorário",
    "cotorários": "cotorário",
    "cotos": "coto",
    "cotou": "cotar",
    "cotovela": "cotovelar",
    "cotovelada": "cotovelar",
    "cotoveladas": "cotovelar",
    "cotovelado": "cotovelar",
    "cotovelados": "cotovelar",
    "cotovelai": "cotovelar",
    "cotovelais": "cotovelar",
    "cotovelam": "cotovelar",
    "cotovelamo": "cotovelar",
    "cotovelamos": "cotovelar",
    "cotovelando": "cotovelar",
    "cotovelara": "cotovelar",
    "cotovelaram": "cotovelar",
    "cotovelaras": "cotovelar",
    "cotovelarde": "cotovelar",
    "cotovelardes": "cotovelar",
    "cotovelare": "cotovelar",
    "cotovelarei": "cotovelar",
    "cotovelareis": "cotovelar",
    "cotovelarem": "cotovelar",
    "cotovelaremos": "cotovelar",
    "cotovelares": "cotovelar",
    "cotovelaria": "cotovelar",
    "cotovelariam": "cotovelar",
    "cotovelarias": "cotovelar",
    "cotovelarmo": "cotovelar",
    "cotovelarmos": "cotovelar",
    "cotovelará": "cotovelar",
    "cotovelarás": "cotovelar",
    "cotovelarão": "cotovelar",
    "cotovelaríamos": "cotovelar",
    "cotovelaríeis": "cotovelar",
    "cotovelas": "cotovelar",
    "cotovelasse": "cotovelar",
    "cotovelassem": "cotovelar",
    "cotovelasses": "cotovelar",
    "cotovelaste": "cotovelar",
    "cotovelastes": "cotovelar",
    "cotovelava": "cotovelar",
    "cotovelavam": "cotovelar",
    "cotovelavas": "cotovelar",
    "cotovele": "cotovelar",
    "cotovelei": "cotovelar",
    "cotoveleis": "cotovelar",
    "cotovelem": "cotovelar",
    "cotovelemo": "cotovelar",
    "cotovelemos": "cotovelar",
    "cotoveles": "cotovelar",
    "cotovelo": "cotovelar",
    "cotovelos": "cotovelo",
    "cotovelou": "cotovelar",
    "cotovelá": "cotovelar",
    "cotovelámo": "cotovelar",
    "cotovelámos": "cotovelar",
    "cotoveláramo": "cotovelar",
    "cotoveláramos": "cotovelar",
    "cotovelárei": "cotovelar",
    "cotoveláreis": "cotovelar",
    "cotovelásseis": "cotovelar",
    "cotovelássemos": "cotovelar",
    "cotovelávamo": "cotovelar",
    "cotovelávamos": "cotovelar",
    "cotovelávei": "cotovelar",
    "cotoveláveis": "cotovelar",
    "cotovelões": "cotovelão",
    "cotovias": "cotovia",
    "coturnos": "coturno",
    "cotá": "cotar",
    "cotámo": "cotar",
    "cotámos": "cotar",
    "cotáramo": "cotar",
    "cotáramos": "cotar",
    "cotárei": "cotar",
    "cotáreis": "cotar",
    "cotásseis": "cotar",
    "cotássemos": "cotar",
    "cotávamo": "cotar",
    "cotávamos": "cotar",
    "cotávei": "cotar",
    "cotáveis": "cotável",
    "cotículas": "cotícula",
    "cotídea": "cotídeo",
    "cotídeas": "cotídeo",
    "cotídeos": "cotídeo",
    "cotíngidas": "cotíngida",
    "cotós": "cotó",
    "cotões": "cotão",
    "coube": "caber",
    "coubemo": "caber",
    "coubemos": "caber",
    "couber": "caber",
    "coubera": "caber",
    "couberam": "caber",
    "couberas": "caber",
    "couberdes": "caber",
    "couberem": "caber",
    "couberes": "caber",
    "coubermos": "caber",
    "coubesse": "caber",
    "coubessem": "caber",
    "coubesses": "caber",
    "coubeste": "caber",
    "coubestes": "caber",
    "coubéramo": "caber",
    "coubéramos": "caber",
    "coubéreis": "caber",
    "coubésseis": "caber",
    "coubéssemos": "caber",
    "couceada": "coucear",
    "couceadas": "coucear",
    "couceado": "coucear",
    "couceados": "coucear",
    "couceai": "coucear",
    "couceais": "coucear",
    "couceamo": "coucear",
    "couceamos": "coucear",
    "couceando": "coucear",
    "couceara": "coucear",
    "coucearam": "coucear",
    "coucearas": "coucear",
    "coucearde": "coucear",
    "couceardes": "coucear",
    "couceare": "coucear",
    "coucearei": "coucear",
    "couceareis": "coucear",
    "coucearem": "coucear",
    "coucearemos": "coucear",
    "couceares": "coucear",
    "coucearia": "coucear",
    "couceariam": "coucear",
    "coucearias": "coucear",
    "coucearmo": "coucear",
    "coucearmos": "coucear",
    "couceará": "coucear",
    "coucearás": "coucear",
    "coucearão": "coucear",
    "coucearíamos": "coucear",
    "coucearíeis": "coucear",
    "couceasse": "coucear",
    "couceassem": "coucear",
    "couceasses": "coucear",
    "couceaste": "coucear",
    "couceastes": "coucear",
    "couceava": "coucear",
    "couceavam": "coucear",
    "couceavas": "coucear",
    "couceei": "coucear",
    "couceeis": "coucear",
    "couceemo": "coucear",
    "couceemos": "coucear",
    "couceia": "coucear",
    "couceiam": "coucear",
    "couceias": "coucear",
    "couceie": "coucear",
    "couceiem": "coucear",
    "couceies": "coucear",
    "couceio": "coucear",
    "couceira": "couceiro",
    "couceiras": "couceiro",
    "couceiristas": "couceirista",
    "couceiros": "couceiro",
    "coucelos": "coucelo",
    "couceou": "coucear",
    "couces": "couce",
    "couceá": "coucear",
    "couceámo": "coucear",
    "couceámos": "coucear",
    "couceáramo": "coucear",
    "couceáramos": "coucear",
    "couceárei": "coucear",
    "couceáreis": "coucear",
    "couceásseis": "coucear",
    "couceássemos": "coucear",
    "couceávamo": "coucear",
    "couceávamos": "coucear",
    "couceávei": "coucear",
    "couceáveis": "coucear",
    "coucões": "coucão",
    "coudeis": "coudel",
    "coudelarias": "coudelaria",
    "coudilhos": "coudilho",
    "coudélica": "coudélico",
    "coudélicas": "coudélico",
    "coudélicos": "coudélico",
    "coulombs": "coulomb",
    "courace": "couraçar",
    "couracei": "couraçar",
    "couraceiros": "couraceiro",
    "couraceis": "couraçar",
    "couracem": "couraçar",
    "couracemo": "couraçar",
    "couracemos": "couraçar",
    "couraces": "couraçar",
    "courachos": "couracho",
    "couramas": "courama",
    "couras": "coura",
    "couratas": "courata",
    "couratos": "courato",
    "couraça": "couraçar",
    "couraçada": "couraçar",
    "couraçadas": "couraçar",
    "couraçado": "couraçar",
    "couraçados": "couraçar",
    "couraçai": "couraçar",
    "couraçais": "couraçar",
    "couraçam": "couraçar",
    "couraçamo": "couraçar",
    "couraçamos": "couraçar",
    "couraçando": "couraçar",
    "couraçara": "couraçar",
    "couraçaram": "couraçar",
    "couraçaras": "couraçar",
    "couraçarde": "couraçar",
    "couraçardes": "couraçar",
    "couraçare": "couraçar",
    "couraçarei": "couraçar",
    "couraçareis": "couraçar",
    "couraçarem": "couraçar",
    "couraçaremos": "couraçar",
    "couraçares": "couraçar",
    "couraçaria": "couraçar",
    "couraçariam": "couraçar",
    "couraçarias": "couraçar",
    "couraçarmo": "couraçar",
    "couraçarmos": "couraçar",
    "couraçará": "couraçar",
    "couraçarás": "couraçar",
    "couraçarão": "couraçar",
    "couraçaríamos": "couraçar",
    "couraçaríeis": "couraçar",
    "couraças": "couraçar",
    "couraçasse": "couraçar",
    "couraçassem": "couraçar",
    "couraçasses": "couraçar",
    "couraçaste": "couraçar",
    "couraçastes": "couraçar",
    "couraçava": "couraçar",
    "couraçavam": "couraçar",
    "couraçavas": "couraçar",
    "couraço": "couraçar",
    "couraçou": "couraçar",
    "couraçá": "couraçar",
    "couraçámo": "couraçar",
    "couraçámos": "couraçar",
    "couraçáramo": "couraçar",
    "couraçáramos": "couraçar",
    "couraçárei": "couraçar",
    "couraçáreis": "couraçar",
    "couraçásseis": "couraçar",
    "couraçássemos": "couraçar",
    "couraçávamo": "couraçar",
    "couraçávamos": "couraçar",
    "couraçávei": "couraçar",
    "couraçáveis": "couraçar",
    "coureiros": "coureiro",
    "courela": "courelar",
    "courelada": "courelar",
    "coureladas": "courelar",
    "courelado": "courelar",
    "courelados": "courelar",
    "courelai": "courelar",
    "courelais": "courelar",
    "courelam": "courelar",
    "courelamo": "courelar",
    "courelamos": "courelar",
    "courelando": "courelar",
    "courelara": "courelar",
    "courelaram": "courelar",
    "courelaras": "courelar",
    "courelarde": "courelar",
    "courelardes": "courelar",
    "courelare": "courelar",
    "courelarei": "courelar",
    "courelareis": "courelar",
    "courelarem": "courelar",
    "courelaremos": "courelar",
    "courelares": "courelar",
    "courelaria": "courelar",
    "courelariam": "courelar",
    "courelarias": "courelar",
    "courelarmo": "courelar",
    "courelarmos": "courelar",
    "courelará": "courelar",
    "courelarás": "courelar",
    "courelarão": "courelar",
    "courelaríamos": "courelar",
    "courelaríeis": "courelar",
    "courelas": "courelar",
    "courelasse": "courelar",
    "courelassem": "courelar",
    "courelasses": "courelar",
    "courelaste": "courelar",
    "courelastes": "courelar",
    "courelava": "courelar",
    "courelavam": "courelar",
    "courelavas": "courelar",
    "courele": "courelar",
    "courelei": "courelar",
    "coureleiros": "coureleiro",
    "coureleis": "courelar",
    "courelem": "courelar",
    "courelemo": "courelar",
    "courelemos": "courelar",
    "coureles": "courelar",
    "courelo": "courelar",
    "courelou": "courelar",
    "courelá": "courelar",
    "courelámo": "courelar",
    "courelámos": "courelar",
    "coureláramo": "courelar",
    "coureláramos": "courelar",
    "courelárei": "courelar",
    "coureláreis": "courelar",
    "courelásseis": "courelar",
    "courelássemos": "courelar",
    "courelávamo": "courelar",
    "courelávamos": "courelar",
    "courelávei": "courelar",
    "coureláveis": "courelar",
    "courona": "courão",
    "couronas": "courão",
    "couros": "couro",
    "courts": "court",
    "courões": "courão",
    "cousadas": "cousada",
    "cousas": "cousa",
    "cousicas": "cousica",
    "cousichos": "cousicho",
    "cousos": "couso",
    "coussos": "cousso",
    "couta": "coutar",
    "coutada": "coutar",
    "coutadas": "coutar",
    "coutado": "coutar",
    "coutados": "coutar",
    "coutai": "coutar",
    "coutais": "coutar",
    "coutam": "coutar",
    "coutamentos": "coutamento",
    "coutamo": "coutar",
    "coutamos": "coutar",
    "coutando": "coutar",
    "coutara": "coutar",
    "coutaram": "coutar",
    "coutaras": "coutar",
    "coutarde": "coutar",
    "coutardes": "coutar",
    "coutare": "coutar",
    "coutarei": "coutar",
    "coutareis": "coutar",
    "coutarem": "coutar",
    "coutaremos": "coutar",
    "coutares": "coutar",
    "coutaria": "coutar",
    "coutariam": "coutar",
    "coutarias": "coutaria",
    "coutarmo": "coutar",
    "coutarmos": "coutar",
    "coutará": "coutar",
    "coutarás": "coutar",
    "coutarão": "coutar",
    "coutaríamos": "coutar",
    "coutaríeis": "coutar",
    "coutas": "coutar",
    "coutasse": "coutar",
    "coutassem": "coutar",
    "coutasses": "coutar",
    "coutaste": "coutar",
    "coutastes": "coutar",
    "coutava": "coutar",
    "coutavam": "coutar",
    "coutavas": "coutar",
    "coute": "coutar",
    "coutei": "coutar",
    "couteiros": "couteiro",
    "couteis": "coutar",
    "coutelhos": "coutelho",
    "coutem": "coutar",
    "coutemo": "coutar",
    "coutemos": "coutar",
    "coutes": "coutar",
    "couto": "coutar",
    "coutos": "couto",
    "coutou": "coutar",
    "coutá": "coutar",
    "coutámo": "coutar",
    "coutámos": "coutar",
    "coutáramo": "coutar",
    "coutáramos": "coutar",
    "coutárei": "coutar",
    "coutáreis": "coutar",
    "coutásseis": "coutar",
    "coutássemos": "coutar",
    "coutávamo": "coutar",
    "coutávamos": "coutar",
    "coutávei": "coutar",
    "coutáveis": "coutar",
    "couvais": "couval",
    "couveira": "couveiro",
    "couveiras": "couveiro",
    "couveiros": "couveiro",
    "couves": "couve",
    "couvettes": "couvette",
    "couçoeiras": "couçoeira",
    "covachos": "covacho",
    "covagens": "covagem",
    "covais": "coval",
    "covardes": "covarde",
    "covardias": "covardia",
    "covas": "cova",
    "covatos": "covato",
    "coveira": "coveiro",
    "coveiras": "coveiro",
    "coveiros": "coveiro",
    "covelinas": "covelina",
    "covelites": "covelite",
    "covilhanenses": "covilhanense",
    "covilhetes": "covilhete",
    "covinha": "cova",
    "covinhas": "cova",
    "covis": "covil",
    "covita": "cova",
    "covitas": "cova",
    "covoadas": "covoada",
    "covolumes": "covolume",
    "covos": "covo",
    "cowboys": "cowboy",
    "coxa": "coxo",
    "coxais": "coxal",
    "coxalgias": "coxalgia",
    "coxas": "coxo",
    "coxazinha": "coxo",
    "coxazinhas": "coxo",
    "coxazita": "coxo",
    "coxazitas": "coxo",
    "coxeada": "coxear",
    "coxeadas": "coxear",
    "coxeado": "coxear",
    "coxeados": "coxear",
    "coxeaduras": "coxeadura",
    "coxeai": "coxear",
    "coxeais": "coxear",
    "coxeamo": "coxear",
    "coxeamos": "coxear",
    "coxeando": "coxear",
    "coxeantes": "coxeante",
    "coxeara": "coxear",
    "coxearam": "coxear",
    "coxearas": "coxear",
    "coxeardes": "coxear",
    "coxearei": "coxear",
    "coxeareis": "coxear",
    "coxearem": "coxear",
    "coxearemos": "coxear",
    "coxeares": "coxear",
    "coxearia": "coxear",
    "coxeariam": "coxear",
    "coxearias": "coxear",
    "coxearmo": "coxear",
    "coxearmos": "coxear",
    "coxeará": "coxear",
    "coxearás": "coxear",
    "coxearão": "coxear",
    "coxearíamos": "coxear",
    "coxearíeis": "coxear",
    "coxeasse": "coxear",
    "coxeassem": "coxear",
    "coxeasses": "coxear",
    "coxeaste": "coxear",
    "coxeastes": "coxear",
    "coxeava": "coxear",
    "coxeavam": "coxear",
    "coxeavas": "coxear",
    "coxeei": "coxear",
    "coxeeis": "coxear",
    "coxeemo": "coxear",
    "coxeemos": "coxear",
    "coxeia": "coxear",
    "coxeiam": "coxear",
    "coxeias": "coxear",
    "coxeie": "coxear",
    "coxeiem": "coxear",
    "coxeies": "coxear",
    "coxeio": "coxear",
    "coxeios": "coxeio",
    "coxeiras": "coxeira",
    "coxeiros": "coxeiro",
    "coxeou": "coxear",
    "coxetes": "coxete",
    "coxeámo": "coxear",
    "coxeámos": "coxear",
    "coxeáramo": "coxear",
    "coxeáramos": "coxear",
    "coxeáreis": "coxear",
    "coxeásseis": "coxear",
    "coxeássemos": "coxear",
    "coxeávamo": "coxear",
    "coxeávamos": "coxear",
    "coxeáveis": "coxear",
    "coxias": "coxia",
    "coxinha": "coxa",
    "coxinhas": "coxa",
    "coxinilhos": "coxinilho",
    "coxins": "coxim",
    "coxita": "coxa",
    "coxitas": "coxa",
    "coxofemurais": "coxofemural",
    "coxos": "coxo",
    "coxotes": "coxote",
    "coxovertebrais": "coxovertebral",
    "coxozinho": "coxo",
    "coxozinhos": "coxo",
    "coxozito": "coxo",
    "coxozitos": "coxo",
    "coxêndica": "coxêndico",
    "coxêndicas": "coxêndico",
    "coxêndicos": "coxêndico",
    "coza": "cozer",
    "cozais": "cozer",
    "cozam": "cozer",
    "cozamo": "cozer",
    "cozamos": "cozer",
    "cozas": "cozer",
    "coze": "cozer",
    "cozedeiras": "cozedeira",
    "cozedora": "cozedor",
    "cozedoras": "cozedor",
    "cozedores": "cozedor",
    "cozeduras": "cozedura",
    "cozei": "cozer",
    "cozeis": "cozer",
    "cozem": "cozer",
    "cozemo": "cozer",
    "cozemos": "cozer",
    "cozendo": "cozer",
    "cozera": "cozer",
    "cozeram": "cozer",
    "cozeras": "cozer",
    "cozerde": "cozer",
    "cozerdes": "cozer",
    "cozere": "cozer",
    "cozerei": "cozer",
    "cozereis": "cozer",
    "cozerem": "cozer",
    "cozeremos": "cozer",
    "cozeres": "cozer",
    "cozeria": "cozer",
    "cozeriam": "cozer",
    "cozerias": "cozer",
    "cozermo": "cozer",
    "cozermos": "cozer",
    "cozerá": "cozer",
    "cozerás": "cozer",
    "cozerão": "cozer",
    "cozeríamos": "cozer",
    "cozeríeis": "cozer",
    "cozes": "cozer",
    "cozesse": "cozer",
    "cozessem": "cozer",
    "cozesses": "cozer",
    "cozeste": "cozer",
    "cozestes": "cozer",
    "cozeu": "cozer",
    "cozi": "cozer",
    "cozia": "cozer",
    "coziam": "cozer",
    "cozias": "cozer",
    "cozida": "cozido",
    "cozidas": "cozido",
    "cozido": "cozer",
    "cozidos": "cozido",
    "cozimentos": "cozimento",
    "cozinha": "cozinhar",
    "cozinhada": "cozinhar",
    "cozinhadas": "cozinhar",
    "cozinhado": "cozinhar",
    "cozinhados": "cozinhar",
    "cozinhai": "cozinhar",
    "cozinhais": "cozinhar",
    "cozinham": "cozinhar",
    "cozinhamo": "cozinhar",
    "cozinhamos": "cozinhar",
    "cozinhando": "cozinhar",
    "cozinhara": "cozinhar",
    "cozinharam": "cozinhar",
    "cozinharas": "cozinhar",
    "cozinharde": "cozinhar",
    "cozinhardes": "cozinhar",
    "cozinhare": "cozinhar",
    "cozinharei": "cozinhar",
    "cozinhareis": "cozinhar",
    "cozinharem": "cozinhar",
    "cozinharemos": "cozinhar",
    "cozinhares": "cozinhar",
    "cozinharia": "cozinhar",
    "cozinhariam": "cozinhar",
    "cozinharias": "cozinhar",
    "cozinharmo": "cozinhar",
    "cozinharmos": "cozinhar",
    "cozinhará": "cozinhar",
    "cozinharás": "cozinhar",
    "cozinharão": "cozinhar",
    "cozinharíamos": "cozinhar",
    "cozinharíeis": "cozinhar",
    "cozinhas": "cozinhar",
    "cozinhasse": "cozinhar",
    "cozinhassem": "cozinhar",
    "cozinhasses": "cozinhar",
    "cozinhaste": "cozinhar",
    "cozinhastes": "cozinhar",
    "cozinhava": "cozinhar",
    "cozinhavam": "cozinhar",
    "cozinhavas": "cozinhar",
    "cozinhe": "cozinhar",
    "cozinhei": "cozinhar",
    "cozinheira": "cozinheiro",
    "cozinheiras": "cozinheiro",
    "cozinheiros": "cozinheiro",
    "cozinheis": "cozinhar",
    "cozinhem": "cozinhar",
    "cozinhemo": "cozinhar",
    "cozinhemos": "cozinhar",
    "cozinhes": "cozinhar",
    "cozinho": "cozinhar",
    "cozinhou": "cozinhar",
    "cozinhá": "cozinhar",
    "cozinhámo": "cozinhar",
    "cozinhámos": "cozinhar",
    "cozinháramo": "cozinhar",
    "cozinháramos": "cozinhar",
    "cozinhárei": "cozinhar",
    "cozinháreis": "cozinhar",
    "cozinhásseis": "cozinhar",
    "cozinhássemos": "cozinhar",
    "cozinhávamo": "cozinhar",
    "cozinhávamos": "cozinhar",
    "cozinhávei": "cozinhar",
    "cozinháveis": "cozinhável",
    "cozo": "cozer",
    "cozê": "cozer",
    "cozêramo": "cozer",
    "cozêramos": "cozer",
    "cozêrei": "cozer",
    "cozêreis": "cozer",
    "cozêsseis": "cozer",
    "cozêssemos": "cozer",
    "cozíamo": "cozer",
    "cozíamos": "cozer",
    "cozíei": "cozer",
    "cozíeis": "cozer",
    "coá": "coar",
    "coágulos": "coágulo",
    "coámo": "coar",
    "coámos": "coar",
    "coáramo": "coar",
    "coáramos": "coar",
    "coárei": "coar",
    "coáreis": "coar",
    "coásseis": "coar",
    "coássemos": "coar",
    "coávamo": "coar",
    "coávamos": "coar",
    "coávei": "coar",
    "coáveis": "coar",
    "coça": "coçar",
    "coçada": "coçar",
    "coçadas": "coçar",
    "coçadelas": "coçadela",
    "coçado": "coçar",
    "coçadoiros": "coçadoiro",
    "coçados": "coçar",
    "coçadouros": "coçadouro",
    "coçaduras": "coçadura",
    "coçai": "coçar",
    "coçais": "coçar",
    "coçam": "coçar",
    "coçamo": "coçar",
    "coçamos": "coçar",
    "coçando": "coçar",
    "coçara": "coçar",
    "coçaram": "coçar",
    "coçaras": "coçar",
    "coçarde": "coçar",
    "coçardes": "coçar",
    "coçare": "coçar",
    "coçarei": "coçar",
    "coçareis": "coçar",
    "coçarem": "coçar",
    "coçaremos": "coçar",
    "coçares": "coçar",
    "coçaria": "coçar",
    "coçariam": "coçar",
    "coçarias": "coçar",
    "coçarmo": "coçar",
    "coçarmos": "coçar",
    "coçará": "coçar",
    "coçarás": "coçar",
    "coçarão": "coçar",
    "coçaríamos": "coçar",
    "coçaríeis": "coçar",
    "coças": "coçar",
    "coçasse": "coçar",
    "coçassem": "coçar",
    "coçasses": "coçar",
    "coçaste": "coçar",
    "coçastes": "coçar",
    "coçava": "coçar",
    "coçavam": "coçar",
    "coçavas": "coçar",
    "coço": "coçar",
    "coçou": "coçar",
    "coçá": "coçar",
    "coçámo": "coçar",
    "coçámos": "coçar",
    "coçáramo": "coçar",
    "coçáramos": "coçar",
    "coçárei": "coçar",
    "coçáreis": "coçar",
    "coçásseis": "coçar",
    "coçássemos": "coçar",
    "coçávamo": "coçar",
    "coçávamos": "coçar",
    "coçávei": "coçar",
    "coçáveis": "coçar",
    "coéforos": "coéforo",
    "coíba": "coibir",
    "coíbam": "coibir",
    "coíbas": "coibir",
    "coíbe": "coibir",
    "coíbem": "coibir",
    "coíbes": "coibir",
    "coíbo": "coibir",
    "crabros": "crabro",
    "cracas": "craca",
    "crachás": "crachá",
    "crackes": "crack",
    "cracolés": "cracolé",
    "cracoviana": "cracoviano",
    "cracovianas": "cracoviano",
    "cracovianos": "cracoviano",
    "cracóviana": "cracóviano",
    "cracóvianas": "cracóviano",
    "cracóvianos": "cracóviano",
    "crancelins": "crancelim",
    "craniada": "craniado",
    "craniadas": "craniado",
    "craniados": "craniado",
    "craniana": "craniano",
    "cranianas": "craniano",
    "cranianos": "craniano",
    "cranioclásica": "cranioclásico",
    "cranioclásicas": "cranioclásico",
    "cranioclásicos": "cranioclásico",
    "cranioclástica": "cranioclástico",
    "cranioclásticas": "cranioclástico",
    "cranioclásticos": "cranioclástico",
    "craniolares": "craniolar",
    "craniologias": "craniologia",
    "craniologistas": "craniologista",
    "craniológica": "craniológico",
    "craniológicas": "craniológico",
    "craniológicos": "craniológico",
    "craniomancias": "craniomancia",
    "craniomantes": "craniomante",
    "craniometrias": "craniometria",
    "craniomântica": "craniomântico",
    "craniomânticas": "craniomântico",
    "craniomânticos": "craniomântico",
    "craniométrica": "craniométrico",
    "craniométricas": "craniométrico",
    "craniométricos": "craniométrico",
    "cranioplasias": "cranioplasia",
    "cranioplastias": "cranioplastia",
    "cranioplástica": "cranioplástico",
    "cranioplásticas": "cranioplástico",
    "cranioplásticos": "cranioplástico",
    "cranioscopias": "cranioscopia",
    "cranioscópica": "cranioscópico",
    "cranioscópicas": "cranioscópico",
    "cranioscópicos": "cranioscópico",
    "cranioscópios": "cranioscópio",
    "craniotas": "craniota",
    "craniotomias": "craniotomia",
    "craniotómica": "craniotómico",
    "craniotómicas": "craniotómico",
    "craniotómicos": "craniotómico",
    "craniozinho": "crânio",
    "craniozinhos": "crânio",
    "craniozito": "crânio",
    "craniozitos": "crânio",
    "cranióides": "cranióide",
    "cranióloga": "craniólogo",
    "craniólogas": "craniólogo",
    "craniólogos": "craniólogo",
    "craniótomos": "craniótomo",
    "crapuleada": "crapulear",
    "crapuleadas": "crapulear",
    "crapuleado": "crapulear",
    "crapuleados": "crapulear",
    "crapuleai": "crapulear",
    "crapuleais": "crapulear",
    "crapuleamo": "crapulear",
    "crapuleamos": "crapulear",
    "crapuleando": "crapulear",
    "crapuleara": "crapulear",
    "crapulearam": "crapulear",
    "crapulearas": "crapulear",
    "crapuleardes": "crapulear",
    "crapulearei": "crapulear",
    "crapuleareis": "crapulear",
    "crapulearem": "crapulear",
    "crapulearemos": "crapulear",
    "crapuleares": "crapulear",
    "crapulearia": "crapulear",
    "crapuleariam": "crapulear",
    "crapulearias": "crapulear",
    "crapulearmo": "crapulear",
    "crapulearmos": "crapulear",
    "crapuleará": "crapulear",
    "crapulearás": "crapulear",
    "crapulearão": "crapulear",
    "crapulearíamos": "crapulear",
    "crapulearíeis": "crapulear",
    "crapuleasse": "crapulear",
    "crapuleassem": "crapulear",
    "crapuleasses": "crapulear",
    "crapuleaste": "crapulear",
    "crapuleastes": "crapulear",
    "crapuleava": "crapulear",
    "crapuleavam": "crapulear",
    "crapuleavas": "crapulear",
    "crapuleei": "crapulear",
    "crapuleeis": "crapulear",
    "crapuleemo": "crapulear",
    "crapuleemos": "crapulear",
    "crapuleia": "crapulear",
    "crapuleiam": "crapulear",
    "crapuleias": "crapulear",
    "crapuleie": "crapulear",
    "crapuleiem": "crapulear",
    "crapuleies": "crapulear",
    "crapuleio": "crapulear",
    "crapuleou": "crapulear",
    "crapuleámo": "crapulear",
    "crapuleámos": "crapulear",
    "crapuleáramo": "crapulear",
    "crapuleáramos": "crapulear",
    "crapuleáreis": "crapulear",
    "crapuleásseis": "crapulear",
    "crapuleássemos": "crapulear",
    "crapuleávamo": "crapulear",
    "crapuleávamos": "crapulear",
    "crapuleáveis": "crapulear",
    "crapulosa": "crapuloso",
    "crapulosas": "crapuloso",
    "crapulosos": "crapuloso",
    "crapôs": "crapô",
    "craques": "craque",
    "crases": "crase",
    "crashes": "crash",
    "crasigráfica": "crasigráfico",
    "crasigráficas": "crasigráfico",
    "crasigráficos": "crasigráfico",
    "crasiografias": "crasiografia",
    "crasiologias": "crasiologia",
    "crasiologistas": "crasiologista",
    "crasiológica": "crasiológico",
    "crasiológicas": "crasiológico",
    "crasiológicos": "crasiológico",
    "crasióloga": "crasiólogo",
    "crasiólogas": "crasiólogo",
    "crasiólogos": "crasiólogo",
    "crassa": "crasso",
    "crassas": "crasso",
    "crassicaudes": "crassicaude",
    "crassicaules": "crassicaule",
    "crassidades": "crassidade",
    "crassidões": "crassidão",
    "crassilingues": "crassilingue",
    "crassipenes": "crassipene",
    "crassirrostra": "crassirrostro",
    "crassirrostras": "crassirrostro",
    "crassirrostros": "crassirrostro",
    "crassitudes": "crassitude",
    "crassos": "crasso",
    "crassulácea": "crassuláceo",
    "crassuláceas": "crassuláceo",
    "crassuláceos": "crassuláceo",
    "crastas": "crasta",
    "crasteira": "crasteiro",
    "crasteiras": "crasteiro",
    "crasteiros": "crasteiro",
    "crastejos": "crastejo",
    "crastos": "crasto",
    "crategos": "cratego",
    "crateras": "cratera",
    "crateriformes": "crateriforme",
    "craticula": "craticular",
    "craticulada": "craticular",
    "craticuladas": "craticular",
    "craticulado": "craticular",
    "craticulados": "craticular",
    "craticulai": "craticular",
    "craticulais": "craticular",
    "craticulam": "craticular",
    "craticulamo": "craticular",
    "craticulamos": "craticular",
    "craticulando": "craticular",
    "craticulara": "craticular",
    "craticularam": "craticular",
    "craticularas": "craticular",
    "craticularde": "craticular",
    "craticulardes": "craticular",
    "craticulare": "craticular",
    "craticularei": "craticular",
    "craticulareis": "craticular",
    "craticularem": "craticular",
    "craticularemos": "craticular",
    "craticulares": "craticular",
    "craticularia": "craticular",
    "craticulariam": "craticular",
    "craticularias": "craticular",
    "craticularmo": "craticular",
    "craticularmos": "craticular",
    "craticulará": "craticular",
    "craticularás": "craticular",
    "craticularão": "craticular",
    "craticularíamos": "craticular",
    "craticularíeis": "craticular",
    "craticulas": "craticular",
    "craticulasse": "craticular",
    "craticulassem": "craticular",
    "craticulasses": "craticular",
    "craticulaste": "craticular",
    "craticulastes": "craticular",
    "craticulava": "craticular",
    "craticulavam": "craticular",
    "craticulavas": "craticular",
    "craticulações": "craticulação",
    "craticule": "craticular",
    "craticulei": "craticular",
    "craticuleis": "craticular",
    "craticulem": "craticular",
    "craticulemo": "craticular",
    "craticulemos": "craticular",
    "craticules": "craticular",
    "craticulo": "craticular",
    "craticulou": "craticular",
    "craticulá": "craticular",
    "craticulámo": "craticular",
    "craticulámos": "craticular",
    "craticuláramo": "craticular",
    "craticuláramos": "craticular",
    "craticulárei": "craticular",
    "craticuláreis": "craticular",
    "craticulásseis": "craticular",
    "craticulássemos": "craticular",
    "craticulávamo": "craticular",
    "craticulávamos": "craticular",
    "craticulávei": "craticular",
    "craticuláveis": "craticular",
    "cratogénica": "cratogénico",
    "cratogénicas": "cratogénico",
    "cratogénicos": "cratogénico",
    "cratículas": "cratícula",
    "cratónica": "cratónico",
    "cratónicas": "cratónico",
    "cratónicos": "cratónico",
    "cratões": "cratão",
    "crava": "cravar",
    "cravada": "cravar",
    "cravadas": "cravar",
    "cravadeiras": "cravadeira",
    "cravado": "cravar",
    "cravadora": "cravador",
    "cravadoras": "cravador",
    "cravadores": "cravador",
    "cravados": "cravar",
    "cravagens": "cravagem",
    "cravai": "cravar",
    "cravais": "cravar",
    "cravam": "cravar",
    "cravamo": "cravar",
    "cravamos": "cravar",
    "cravando": "cravar",
    "cravanços": "cravanço",
    "cravara": "cravar",
    "cravaram": "cravar",
    "cravaras": "cravar",
    "cravarde": "cravar",
    "cravardes": "cravar",
    "cravare": "cravar",
    "cravarei": "cravar",
    "cravareis": "cravar",
    "cravarem": "cravar",
    "cravaremos": "cravar",
    "cravares": "cravar",
    "cravaria": "cravar",
    "cravariam": "cravar",
    "cravarias": "cravaria",
    "cravarmo": "cravar",
    "cravarmos": "cravar",
    "cravará": "cravar",
    "cravarás": "cravar",
    "cravarão": "cravar",
    "cravaríamos": "cravar",
    "cravaríeis": "cravar",
    "cravas": "cravar",
    "cravasse": "cravar",
    "cravassem": "cravar",
    "cravasses": "cravar",
    "cravaste": "cravar",
    "cravastes": "cravar",
    "cravaturas": "cravatura",
    "cravava": "cravar",
    "cravavam": "cravar",
    "cravavas": "cravar",
    "cravações": "cravação",
    "crave": "cravar",
    "cravei": "cravar",
    "craveiras": "craveira",
    "craveiros": "craveiro",
    "craveis": "cravar",
    "craveja": "cravejar",
    "cravejada": "cravejar",
    "cravejadas": "cravejar",
    "cravejado": "cravejar",
    "cravejadora": "cravejador",
    "cravejadoras": "cravejador",
    "cravejadores": "cravejador",
    "cravejados": "cravejar",
    "cravejai": "cravejar",
    "cravejais": "cravejar",
    "cravejam": "cravejar",
    "cravejamentos": "cravejamento",
    "cravejamo": "cravejar",
    "cravejamos": "cravejar",
    "cravejando": "cravejar",
    "cravejara": "cravejar",
    "cravejaram": "cravejar",
    "cravejaras": "cravejar",
    "cravejarde": "cravejar",
    "cravejardes": "cravejar",
    "cravejare": "cravejar",
    "cravejarei": "cravejar",
    "cravejareis": "cravejar",
    "cravejarem": "cravejar",
    "cravejaremos": "cravejar",
    "cravejares": "cravejar",
    "cravejaria": "cravejar",
    "cravejariam": "cravejar",
    "cravejarias": "cravejar",
    "cravejarmo": "cravejar",
    "cravejarmos": "cravejar",
    "cravejará": "cravejar",
    "cravejarás": "cravejar",
    "cravejarão": "cravejar",
    "cravejaríamos": "cravejar",
    "cravejaríeis": "cravejar",
    "cravejas": "cravejar",
    "cravejasse": "cravejar",
    "cravejassem": "cravejar",
    "cravejasses": "cravejar",
    "cravejaste": "cravejar",
    "cravejastes": "cravejar",
    "cravejava": "cravejar",
    "cravejavam": "cravejar",
    "cravejavas": "cravejar",
    "craveje": "cravejar",
    "cravejei": "cravejar",
    "cravejeis": "cravejar",
    "cravejem": "cravejar",
    "cravejemo": "cravejar",
    "cravejemos": "cravejar",
    "cravejes": "cravejar",
    "cravejo": "cravejar",
    "cravejou": "cravejar",
    "cravejá": "cravejar",
    "cravejámo": "cravejar",
    "cravejámos": "cravejar",
    "cravejáramo": "cravejar",
    "cravejáramos": "cravejar",
    "cravejárei": "cravejar",
    "cravejáreis": "cravejar",
    "cravejásseis": "cravejar",
    "cravejássemos": "cravejar",
    "cravejávamo": "cravejar",
    "cravejávamos": "cravejar",
    "cravejávei": "cravejar",
    "cravejáveis": "cravejar",
    "cravelhames": "cravelhame",
    "cravelhas": "cravelha",
    "cravelhos": "cravelho",
    "cravelinas": "cravelina",
    "cravelos": "cravelo",
    "cravem": "cravar",
    "cravemo": "cravar",
    "cravemos": "cravar",
    "craves": "cravar",
    "cravetes": "cravete",
    "cravijas": "cravija",
    "cravinas": "cravina",
    "cravineiros": "cravineiro",
    "cravinetas": "cravineta",
    "cravinho": "cravo",
    "cravinhos": "cravo",
    "cravinosa": "cravinoso",
    "cravinosas": "cravinoso",
    "cravinosos": "cravinoso",
    "craviorganistas": "craviorganista",
    "cravistas": "cravista",
    "cravito": "cravo",
    "cravitos": "cravo",
    "craviórgões": "craviórgão",
    "cravo": "cravar",
    "cravos": "cravo",
    "cravou": "cravar",
    "cravá": "cravar",
    "cravámo": "cravar",
    "cravámos": "cravar",
    "craváramo": "cravar",
    "craváramos": "cravar",
    "cravárei": "cravar",
    "craváreis": "cravar",
    "cravásseis": "cravar",
    "cravássemos": "cravar",
    "cravávamo": "cravar",
    "cravávamos": "cravar",
    "cravávei": "cravar",
    "craváveis": "cravar",
    "craúnas": "craúna",
    "creais": "crer",
    "creamo": "crer",
    "creamos": "crer",
    "creatinas": "creatina",
    "creatininas": "creatinina",
    "creatofágica": "creatofágico",
    "creatofágicas": "creatofágico",
    "creatofágicos": "creatofágico",
    "creatófaga": "creatófago",
    "creatófagas": "creatófago",
    "creatófagos": "creatófago",
    "creatófora": "creatóforo",
    "creatóforas": "creatóforo",
    "creatóforos": "creatóforo",
    "crebra": "crebro",
    "crebras": "crebro",
    "crebros": "crebro",
    "creches": "creche",
    "crede": "crer",
    "credenciabilidades": "credenciabilidade",
    "credenciada": "credenciado",
    "credenciadas": "credenciado",
    "credenciados": "credenciado",
    "credenciais": "credencial",
    "credenciamentos": "credenciamento",
    "credenciações": "credenciação",
    "credenciária": "credenciário",
    "credenciárias": "credenciário",
    "credenciários": "credenciário",
    "credes": "crer",
    "credibilidades": "credibilidade",
    "credibilizações": "credibilização",
    "credifones": "credifone",
    "credita": "creditar",
    "creditada": "creditar",
    "creditadas": "creditar",
    "creditado": "creditar",
    "creditados": "creditar",
    "creditai": "creditar",
    "creditais": "creditar",
    "creditam": "creditar",
    "creditamo": "creditar",
    "creditamos": "creditar",
    "creditando": "creditar",
    "creditara": "creditar",
    "creditaram": "creditar",
    "creditaras": "creditar",
    "creditarde": "creditar",
    "creditardes": "creditar",
    "creditare": "creditar",
    "creditarei": "creditar",
    "creditareis": "creditar",
    "creditarem": "creditar",
    "creditaremos": "creditar",
    "creditares": "creditar",
    "creditaria": "creditar",
    "creditariam": "creditar",
    "creditarias": "creditar",
    "creditarmo": "creditar",
    "creditarmos": "creditar",
    "creditará": "creditar",
    "creditarás": "creditar",
    "creditarão": "creditar",
    "creditaríamos": "creditar",
    "creditaríeis": "creditar",
    "creditas": "creditar",
    "creditasse": "creditar",
    "creditassem": "creditar",
    "creditasses": "creditar",
    "creditaste": "creditar",
    "creditastes": "creditar",
    "creditava": "creditar",
    "creditavam": "creditar",
    "creditavas": "creditar",
    "creditações": "creditação",
    "credite": "creditar",
    "creditei": "creditar",
    "crediteis": "creditar",
    "creditem": "creditar",
    "creditemo": "creditar",
    "creditemos": "creditar",
    "credites": "creditar",
    "credito": "creditar",
    "creditou": "creditar",
    "creditá": "creditar",
    "creditámo": "creditar",
    "creditámos": "creditar",
    "creditáramo": "creditar",
    "creditáramos": "creditar",
    "creditárei": "creditar",
    "creditáreis": "creditar",
    "creditásseis": "creditar",
    "creditássemos": "creditar",
    "creditávamo": "creditar",
    "creditávamos": "creditar",
    "creditávei": "creditar",
    "creditáveis": "creditável",
    "creditícia": "creditício",
    "creditícias": "creditício",
    "creditícios": "creditício",
    "creditória": "creditório",
    "creditórias": "creditório",
    "creditórios": "creditório",
    "credora": "credor",
    "credoras": "credor",
    "credores": "credor",
    "credos": "credo",
    "credulidades": "credulidade",
    "credências": "credência",
    "credíveis": "credível",
    "creia": "crer",
    "creiam": "crer",
    "creias": "crer",
    "creio": "crer",
    "crema": "cremar",
    "cremada": "cremar",
    "cremadas": "cremar",
    "cremado": "cremar",
    "cremadora": "cremador",
    "cremadoras": "cremador",
    "cremadores": "cremador",
    "cremados": "cremar",
    "cremadouros": "cremadouro",
    "cremai": "cremar",
    "cremais": "cremar",
    "cremalheiras": "cremalheira",
    "cremam": "cremar",
    "cremamo": "cremar",
    "cremamos": "cremar",
    "cremando": "cremar",
    "cremara": "cremar",
    "cremaram": "cremar",
    "cremaras": "cremar",
    "cremarde": "cremar",
    "cremardes": "cremar",
    "cremare": "cremar",
    "cremarei": "cremar",
    "cremareis": "cremar",
    "cremarem": "cremar",
    "cremaremos": "cremar",
    "cremares": "cremar",
    "cremaria": "cremar",
    "cremariam": "cremar",
    "cremarias": "cremar",
    "cremarmo": "cremar",
    "cremarmos": "cremar",
    "cremará": "cremar",
    "cremarás": "cremar",
    "cremarão": "cremar",
    "cremaríamos": "cremar",
    "cremaríeis": "cremar",
    "cremas": "cremar",
    "cremasse": "cremar",
    "cremassem": "cremar",
    "cremasses": "cremar",
    "cremaste": "cremar",
    "cremastes": "cremar",
    "crematística": "crematístico",
    "crematísticas": "crematístico",
    "crematísticos": "crematístico",
    "crematória": "crematório",
    "crematórias": "crematório",
    "crematórios": "crematório",
    "cremava": "cremar",
    "cremavam": "cremar",
    "cremavas": "cremar",
    "cremações": "cremação",
    "creme": "cremar",
    "cremei": "cremar",
    "cremeis": "cremar",
    "cremem": "cremar",
    "crememo": "cremar",
    "crememos": "cremar",
    "cremes": "creme",
    "cremnofobias": "cremnofobia",
    "cremnofóbica": "cremnofóbico",
    "cremnofóbicas": "cremnofóbico",
    "cremnofóbicos": "cremnofóbico",
    "cremnométrica": "cremnométrico",
    "cremnométricas": "cremnométrico",
    "cremnométricos": "cremnométrico",
    "cremnófoba": "cremnófobo",
    "cremnófobas": "cremnófobo",
    "cremnófobos": "cremnófobo",
    "cremo": "crer",
    "cremorenas": "cremorena",
    "cremores": "cremor",
    "cremoriza": "cremorizar",
    "cremorizada": "cremorizar",
    "cremorizadas": "cremorizar",
    "cremorizado": "cremorizar",
    "cremorizados": "cremorizar",
    "cremorizai": "cremorizar",
    "cremorizais": "cremorizar",
    "cremorizam": "cremorizar",
    "cremorizamo": "cremorizar",
    "cremorizamos": "cremorizar",
    "cremorizando": "cremorizar",
    "cremorizara": "cremorizar",
    "cremorizaram": "cremorizar",
    "cremorizaras": "cremorizar",
    "cremorizarde": "cremorizar",
    "cremorizardes": "cremorizar",
    "cremorizare": "cremorizar",
    "cremorizarei": "cremorizar",
    "cremorizareis": "cremorizar",
    "cremorizarem": "cremorizar",
    "cremorizaremos": "cremorizar",
    "cremorizares": "cremorizar",
    "cremorizaria": "cremorizar",
    "cremorizariam": "cremorizar",
    "cremorizarias": "cremorizar",
    "cremorizarmo": "cremorizar",
    "cremorizarmos": "cremorizar",
    "cremorizará": "cremorizar",
    "cremorizarás": "cremorizar",
    "cremorizarão": "cremorizar",
    "cremorizaríamos": "cremorizar",
    "cremorizaríeis": "cremorizar",
    "cremorizas": "cremorizar",
    "cremorizasse": "cremorizar",
    "cremorizassem": "cremorizar",
    "cremorizasses": "cremorizar",
    "cremorizaste": "cremorizar",
    "cremorizastes": "cremorizar",
    "cremorizava": "cremorizar",
    "cremorizavam": "cremorizar",
    "cremorizavas": "cremorizar",
    "cremorize": "cremorizar",
    "cremorizei": "cremorizar",
    "cremorizeis": "cremorizar",
    "cremorizem": "cremorizar",
    "cremorizemo": "cremorizar",
    "cremorizemos": "cremorizar",
    "cremorizes": "cremorizar",
    "cremorizo": "cremorizar",
    "cremorizou": "cremorizar",
    "cremorizá": "cremorizar",
    "cremorizámo": "cremorizar",
    "cremorizámos": "cremorizar",
    "cremorizáramo": "cremorizar",
    "cremorizáramos": "cremorizar",
    "cremorizárei": "cremorizar",
    "cremorizáreis": "cremorizar",
    "cremorizásseis": "cremorizar",
    "cremorizássemos": "cremorizar",
    "cremorizávamo": "cremorizar",
    "cremorizávamos": "cremorizar",
    "cremorizávei": "cremorizar",
    "cremorizáveis": "cremorizar",
    "cremos": "crer",
    "cremosa": "cremoso",
    "cremosas": "cremoso",
    "cremosos": "cremoso",
    "cremou": "cremar",
    "cremá": "cremar",
    "cremámo": "cremar",
    "cremámos": "cremar",
    "cremáramo": "cremar",
    "cremáramos": "cremar",
    "cremárei": "cremar",
    "cremáreis": "cremar",
    "cremásseis": "cremar",
    "cremássemos": "cremar",
    "cremávamo": "cremar",
    "cremávamos": "cremar",
    "cremávei": "cremar",
    "cremáveis": "cremar",
    "cremórica": "cremórico",
    "cremóricas": "cremórico",
    "cremóricos": "cremórico",
    "crena": "crenar",
    "crenada": "crenar",
    "crenadas": "crenar",
    "crenado": "crenar",
    "crenados": "crenar",
    "crenai": "crenar",
    "crenais": "crenar",
    "crenam": "crenar",
    "crenamo": "crenar",
    "crenamos": "crenar",
    "crenando": "crenar",
    "crenara": "crenar",
    "crenaram": "crenar",
    "crenaras": "crenar",
    "crenarde": "crenar",
    "crenardes": "crenar",
    "crenare": "crenar",
    "crenarei": "crenar",
    "crenareis": "crenar",
    "crenarem": "crenar",
    "crenaremos": "crenar",
    "crenares": "crenar",
    "crenaria": "crenar",
    "crenariam": "crenar",
    "crenarias": "crenar",
    "crenarmo": "crenar",
    "crenarmos": "crenar",
    "crenará": "crenar",
    "crenarás": "crenar",
    "crenarão": "crenar",
    "crenaríamos": "crenar",
    "crenaríeis": "crenar",
    "crenas": "crenar",
    "crenasse": "crenar",
    "crenassem": "crenar",
    "crenasses": "crenar",
    "crenaste": "crenar",
    "crenastes": "crenar",
    "crenava": "crenar",
    "crenavam": "crenar",
    "crenavas": "crenar",
    "crendeira": "crendeiro",
    "crendeiras": "crendeiro",
    "crendeiros": "crendeiro",
    "crendices": "crendice",
    "crendo": "crer",
    "crene": "crenar",
    "crenei": "crenar",
    "creneis": "crenar",
    "crenem": "crenar",
    "crenemo": "crenar",
    "crenemos": "crenar",
    "crenes": "crenar",
    "creno": "crenar",
    "crenofágica": "crenofágico",
    "crenofágicas": "crenofágico",
    "crenofágicos": "crenofágico",
    "crenolada": "crenolado",
    "crenoladas": "crenolado",
    "crenolados": "crenolado",
    "crenou": "crenar",
    "crentes": "crente",
    "crená": "crenar",
    "crenámo": "crenar",
    "crenámos": "crenar",
    "crenáramo": "crenar",
    "crenáramos": "crenar",
    "crenárei": "crenar",
    "crenáreis": "crenar",
    "crenásseis": "crenar",
    "crenássemos": "crenar",
    "crenávamo": "crenar",
    "crenávamos": "crenar",
    "crenávei": "crenar",
    "crenáveis": "crenar",
    "crenças": "crença",
    "crenófaga": "crenófago",
    "crenófagas": "crenófago",
    "crenófagos": "crenófago",
    "crenófila": "crenófilo",
    "crenófilas": "crenófilo",
    "crenófilos": "crenófilo",
    "creofagias": "creofagia",
    "creofilias": "creofilia",
    "creogenias": "creogenia",
    "creografias": "creografia",
    "creográfica": "creográfico",
    "creográficas": "creográfico",
    "creográficos": "creográfico",
    "creogénica": "creogénico",
    "creogénicas": "creogénico",
    "creogénicos": "creogénico",
    "creolinas": "creolina",
    "creosota": "creosotar",
    "creosotada": "creosotar",
    "creosotadas": "creosotar",
    "creosotado": "creosotar",
    "creosotados": "creosotar",
    "creosotagens": "creosotagem",
    "creosotai": "creosotar",
    "creosotais": "creosotar",
    "creosotam": "creosotar",
    "creosotamo": "creosotar",
    "creosotamos": "creosotar",
    "creosotando": "creosotar",
    "creosotara": "creosotar",
    "creosotaram": "creosotar",
    "creosotaras": "creosotar",
    "creosotarde": "creosotar",
    "creosotardes": "creosotar",
    "creosotare": "creosotar",
    "creosotarei": "creosotar",
    "creosotareis": "creosotar",
    "creosotarem": "creosotar",
    "creosotaremos": "creosotar",
    "creosotares": "creosotar",
    "creosotaria": "creosotar",
    "creosotariam": "creosotar",
    "creosotarias": "creosotar",
    "creosotarmo": "creosotar",
    "creosotarmos": "creosotar",
    "creosotará": "creosotar",
    "creosotarás": "creosotar",
    "creosotarão": "creosotar",
    "creosotaríamos": "creosotar",
    "creosotaríeis": "creosotar",
    "creosotas": "creosotar",
    "creosotasse": "creosotar",
    "creosotassem": "creosotar",
    "creosotasses": "creosotar",
    "creosotaste": "creosotar",
    "creosotastes": "creosotar",
    "creosotava": "creosotar",
    "creosotavam": "creosotar",
    "creosotavas": "creosotar",
    "creosote": "creosotar",
    "creosotei": "creosotar",
    "creosoteis": "creosotar",
    "creosotem": "creosotar",
    "creosotemo": "creosotar",
    "creosotemos": "creosotar",
    "creosotes": "creosotar",
    "creosoto": "creosotar",
    "creosotos": "creosoto",
    "creosotou": "creosotar",
    "creosotá": "creosotar",
    "creosotámo": "creosotar",
    "creosotámos": "creosotar",
    "creosotáramo": "creosotar",
    "creosotáramos": "creosotar",
    "creosotárei": "creosotar",
    "creosotáreis": "creosotar",
    "creosotásseis": "creosotar",
    "creosotássemos": "creosotar",
    "creosotávamo": "creosotar",
    "creosotávamos": "creosotar",
    "creosotávei": "creosotar",
    "creosotáveis": "creosotar",
    "creosótica": "creosótico",
    "creosóticas": "creosótico",
    "creosóticos": "creosótico",
    "crepes": "crepe",
    "crepita": "crepitar",
    "crepitada": "crepitar",
    "crepitadas": "crepitar",
    "crepitado": "crepitar",
    "crepitados": "crepitar",
    "crepitai": "crepitar",
    "crepitais": "crepitar",
    "crepitam": "crepitar",
    "crepitamo": "crepitar",
    "crepitamos": "crepitar",
    "crepitando": "crepitar",
    "crepitantes": "crepitante",
    "crepitara": "crepitar",
    "crepitaram": "crepitar",
    "crepitaras": "crepitar",
    "crepitardes": "crepitar",
    "crepitarei": "crepitar",
    "crepitareis": "crepitar",
    "crepitarem": "crepitar",
    "crepitaremos": "crepitar",
    "crepitares": "crepitar",
    "crepitaria": "crepitar",
    "crepitariam": "crepitar",
    "crepitarias": "crepitar",
    "crepitarmo": "crepitar",
    "crepitarmos": "crepitar",
    "crepitará": "crepitar",
    "crepitarás": "crepitar",
    "crepitarão": "crepitar",
    "crepitaríamos": "crepitar",
    "crepitaríeis": "crepitar",
    "crepitas": "crepitar",
    "crepitasse": "crepitar",
    "crepitassem": "crepitar",
    "crepitasses": "crepitar",
    "crepitaste": "crepitar",
    "crepitastes": "crepitar",
    "crepitava": "crepitar",
    "crepitavam": "crepitar",
    "crepitavas": "crepitar",
    "crepitações": "crepitação",
    "crepite": "crepitar",
    "crepitei": "crepitar",
    "crepiteis": "crepitar",
    "crepitem": "crepitar",
    "crepitemo": "crepitar",
    "crepitemos": "crepitar",
    "crepites": "crepitar",
    "crepito": "crepitar",
    "crepitosa": "crepitoso",
    "crepitosas": "crepitoso",
    "crepitosos": "crepitoso",
    "crepitou": "crepitar",
    "crepitáculos": "crepitáculo",
    "crepitámo": "crepitar",
    "crepitámos": "crepitar",
    "crepitáramo": "crepitar",
    "crepitáramos": "crepitar",
    "crepitáreis": "crepitar",
    "crepitásseis": "crepitar",
    "crepitássemos": "crepitar",
    "crepitávamo": "crepitar",
    "crepitávamos": "crepitar",
    "crepitáveis": "crepitar",
    "crepusculares": "crepuscular",
    "crepusculina": "crepusculino",
    "crepusculinas": "crepusculino",
    "crepusculinos": "crepusculino",
    "crepusculiza": "crepusculizar",
    "crepusculizada": "crepusculizar",
    "crepusculizadas": "crepusculizar",
    "crepusculizado": "crepusculizar",
    "crepusculizados": "crepusculizar",
    "crepusculizai": "crepusculizar",
    "crepusculizais": "crepusculizar",
    "crepusculizam": "crepusculizar",
    "crepusculizamo": "crepusculizar",
    "crepusculizamos": "crepusculizar",
    "crepusculizando": "crepusculizar",
    "crepusculizara": "crepusculizar",
    "crepusculizaram": "crepusculizar",
    "crepusculizaras": "crepusculizar",
    "crepusculizarde": "crepusculizar",
    "crepusculizardes": "crepusculizar",
    "crepusculizare": "crepusculizar",
    "crepusculizarei": "crepusculizar",
    "crepusculizareis": "crepusculizar",
    "crepusculizarem": "crepusculizar",
    "crepusculizaremos": "crepusculizar",
    "crepusculizares": "crepusculizar",
    "crepusculizaria": "crepusculizar",
    "crepusculizariam": "crepusculizar",
    "crepusculizarias": "crepusculizar",
    "crepusculizarmo": "crepusculizar",
    "crepusculizarmos": "crepusculizar",
    "crepusculizará": "crepusculizar",
    "crepusculizarás": "crepusculizar",
    "crepusculizarão": "crepusculizar",
    "crepusculizaríamos": "crepusculizar",
    "crepusculizaríeis": "crepusculizar",
    "crepusculizas": "crepusculizar",
    "crepusculizasse": "crepusculizar",
    "crepusculizassem": "crepusculizar",
    "crepusculizasses": "crepusculizar",
    "crepusculizaste": "crepusculizar",
    "crepusculizastes": "crepusculizar",
    "crepusculizava": "crepusculizar",
    "crepusculizavam": "crepusculizar",
    "crepusculizavas": "crepusculizar",
    "crepusculize": "crepusculizar",
    "crepusculizei": "crepusculizar",
    "crepusculizeis": "crepusculizar",
    "crepusculizem": "crepusculizar",
    "crepusculizemo": "crepusculizar",
    "crepusculizemos": "crepusculizar",
    "crepusculizes": "crepusculizar",
    "crepusculizo": "crepusculizar",
    "crepusculizou": "crepusculizar",
    "crepusculizá": "crepusculizar",
    "crepusculizámo": "crepusculizar",
    "crepusculizámos": "crepusculizar",
    "crepusculizáramo": "crepusculizar",
    "crepusculizáramos": "crepusculizar",
    "crepusculizárei": "crepusculizar",
    "crepusculizáreis": "crepusculizar",
    "crepusculizásseis": "crepusculizar",
    "crepusculizássemos": "crepusculizar",
    "crepusculizávamo": "crepusculizar",
    "crepusculizávamos": "crepusculizar",
    "crepusculizávei": "crepusculizar",
    "crepusculizáveis": "crepusculizar",
    "crepusculária": "crepusculário",
    "crepusculárias": "crepusculário",
    "crepusculários": "crepusculário",
    "crepúsculos": "crepúsculo",
    "crera": "crer",
    "creram": "crer",
    "creras": "crer",
    "crerde": "crer",
    "crerdes": "crer",
    "crere": "crer",
    "crerei": "crer",
    "crereis": "crer",
    "crerem": "crer",
    "creremos": "crer",
    "creres": "crer",
    "creria": "crer",
    "creriam": "crer",
    "crerias": "crer",
    "crermo": "crer",
    "crermos": "crer",
    "crerá": "crer",
    "crerás": "crer",
    "crerão": "crer",
    "creríamos": "crer",
    "creríeis": "crer",
    "cresce": "crescer",
    "crescei": "crescer",
    "cresceis": "crescer",
    "crescem": "crescer",
    "crescemo": "crescer",
    "crescemos": "crescer",
    "crescendo": "crescer",
    "crescendos": "crescendo",
    "crescentadas": "crescentada",
    "crescentes": "crescente",
    "crescenças": "crescença",
    "crescera": "crescer",
    "cresceram": "crescer",
    "cresceras": "crescer",
    "crescerdes": "crescer",
    "crescerei": "crescer",
    "crescereis": "crescer",
    "crescerem": "crescer",
    "cresceremos": "crescer",
    "cresceres": "crescer",
    "cresceria": "crescer",
    "cresceriam": "crescer",
    "crescerias": "crescer",
    "crescermo": "crescer",
    "crescermos": "crescer",
    "crescerá": "crescer",
    "crescerás": "crescer",
    "crescerão": "crescer",
    "cresceríamos": "crescer",
    "cresceríeis": "crescer",
    "cresces": "crescer",
    "crescesse": "crescer",
    "crescessem": "crescer",
    "crescesses": "crescer",
    "cresceste": "crescer",
    "crescestes": "crescer",
    "cresceu": "crescer",
    "cresci": "crescer",
    "crescia": "crescer",
    "cresciam": "crescer",
    "crescias": "crescer",
    "crescida": "crescido",
    "crescidas": "crescido",
    "crescidinha": "crescido",
    "crescidinhas": "crescido",
    "crescidinho": "crescido",
    "crescidinhos": "crescido",
    "crescidita": "crescido",
    "cresciditas": "crescido",
    "crescidito": "crescido",
    "cresciditos": "crescido",
    "crescido": "crescer",
    "crescidos": "crescido",
    "crescidotes": "crescidote",
    "crescidíssima": "crescido",
    "crescidíssimas": "crescido",
    "crescidíssimo": "crescido",
    "crescidíssimos": "crescido",
    "crescimentos": "crescimento",
    "crescêramo": "crescer",
    "crescêramos": "crescer",
    "crescêreis": "crescer",
    "crescêsseis": "crescer",
    "crescêssemos": "crescer",
    "crescíamo": "crescer",
    "crescíamos": "crescer",
    "crescíeis": "crescer",
    "cresma": "cresmo",
    "cresmada": "cresmado",
    "cresmadas": "cresmado",
    "cresmados": "cresmado",
    "cresmas": "cresmo",
    "cresmos": "cresmo",
    "cresmática": "cresmático",
    "cresmáticas": "cresmático",
    "cresmáticos": "cresmático",
    "crespa": "crespar",
    "crespada": "crespar",
    "crespadas": "crespar",
    "crespado": "crespar",
    "crespados": "crespar",
    "crespai": "crespar",
    "crespais": "crespar",
    "crespam": "crespar",
    "crespamo": "crespar",
    "crespamos": "crespar",
    "crespando": "crespar",
    "crespara": "crespar",
    "cresparam": "crespar",
    "cresparas": "crespar",
    "cresparde": "crespar",
    "crespardes": "crespar",
    "crespare": "crespar",
    "cresparei": "crespar",
    "crespareis": "crespar",
    "cresparem": "crespar",
    "cresparemos": "crespar",
    "crespares": "crespar",
    "cresparia": "crespar",
    "crespariam": "crespar",
    "cresparias": "crespar",
    "cresparmo": "crespar",
    "cresparmos": "crespar",
    "crespará": "crespar",
    "cresparás": "crespar",
    "cresparão": "crespar",
    "cresparíamos": "crespar",
    "cresparíeis": "crespar",
    "crespas": "crespar",
    "crespasse": "crespar",
    "crespassem": "crespar",
    "crespasses": "crespar",
    "crespaste": "crespar",
    "crespastes": "crespar",
    "crespava": "crespar",
    "crespavam": "crespar",
    "crespavas": "crespar",
    "crespe": "crespir",
    "crespei": "crespar",
    "crespeis": "crespar",
    "crespem": "crespir",
    "crespemo": "crespar",
    "crespemos": "crespar",
    "crespes": "crespir",
    "crespi": "crespir",
    "crespia": "crespir",
    "crespiam": "crespir",
    "crespias": "crespir",
    "crespida": "crespir",
    "crespidas": "crespir",
    "crespido": "crespir",
    "crespidos": "crespir",
    "crespidões": "crespidão",
    "crespimo": "crespir",
    "crespimos": "crespir",
    "crespinas": "crespina",
    "crespindo": "crespir",
    "crespira": "crespir",
    "crespiram": "crespir",
    "crespiras": "crespir",
    "crespirde": "crespir",
    "crespirdes": "crespir",
    "crespire": "crespir",
    "crespirei": "crespir",
    "crespireis": "crespir",
    "crespirem": "crespir",
    "crespiremos": "crespir",
    "crespires": "crespir",
    "crespiria": "crespir",
    "crespiriam": "crespir",
    "crespirias": "crespir",
    "crespirmo": "crespir",
    "crespirmos": "crespir",
    "crespirá": "crespir",
    "crespirás": "crespir",
    "crespirão": "crespir",
    "crespiríamos": "crespir",
    "crespiríeis": "crespir",
    "crespis": "crespir",
    "crespisse": "crespir",
    "crespissem": "crespir",
    "crespisses": "crespir",
    "crespiste": "crespir",
    "crespistes": "crespir",
    "crespiu": "crespir",
    "crespo": "crespar",
    "crespos": "crespo",
    "crespou": "crespar",
    "crespá": "crespar",
    "crespámo": "crespar",
    "crespámos": "crespar",
    "crespáramo": "crespar",
    "crespáramos": "crespar",
    "crespárei": "crespar",
    "crespáreis": "crespar",
    "crespásseis": "crespar",
    "crespássemos": "crespar",
    "crespávamo": "crespar",
    "crespávamos": "crespar",
    "crespávei": "crespar",
    "crespáveis": "crespar",
    "crespíamo": "crespir",
    "crespíamos": "crespir",
    "crespíei": "crespir",
    "crespíeis": "crespir",
    "crespíramo": "crespir",
    "crespíramos": "crespir",
    "crespírei": "crespir",
    "crespíreis": "crespir",
    "crespísseis": "crespir",
    "crespíssemos": "crespir",
    "crespões": "crespão",
    "cresse": "crer",
    "cressem": "crer",
    "cresses": "crer",
    "cresta": "crestar",
    "crestada": "crestar",
    "crestadas": "crestar",
    "crestadeiras": "crestadeira",
    "crestado": "crestar",
    "crestados": "crestar",
    "crestaduras": "crestadura",
    "crestai": "crestar",
    "crestais": "crestar",
    "crestam": "crestar",
    "crestamentos": "crestamento",
    "crestamo": "crestar",
    "crestamos": "crestar",
    "crestando": "crestar",
    "crestantes": "crestante",
    "crestara": "crestar",
    "crestaram": "crestar",
    "crestaras": "crestar",
    "crestarde": "crestar",
    "crestardes": "crestar",
    "crestare": "crestar",
    "crestarei": "crestar",
    "crestareis": "crestar",
    "crestarem": "crestar",
    "crestaremos": "crestar",
    "crestares": "crestar",
    "crestaria": "crestar",
    "crestariam": "crestar",
    "crestarias": "crestar",
    "crestarmo": "crestar",
    "crestarmos": "crestar",
    "crestará": "crestar",
    "crestarás": "crestar",
    "crestarão": "crestar",
    "crestaríamos": "crestar",
    "crestaríeis": "crestar",
    "crestas": "crestar",
    "crestasse": "crestar",
    "crestassem": "crestar",
    "crestasses": "crestar",
    "crestaste": "crestar",
    "crestastes": "crestar",
    "crestava": "crestar",
    "crestavam": "crestar",
    "crestavas": "crestar",
    "creste": "crestar",
    "crestei": "crestar",
    "cresteis": "crestar",
    "crestem": "crestar",
    "crestemo": "crestar",
    "crestemos": "crestar",
    "crestes": "crestar",
    "cresto": "crestar",
    "crestomatias": "crestomatia",
    "crestomática": "crestomático",
    "crestomáticas": "crestomático",
    "crestomáticos": "crestomático",
    "crestos": "cresto",
    "crestou": "crestar",
    "crestá": "crestar",
    "crestámo": "crestar",
    "crestámos": "crestar",
    "crestáramo": "crestar",
    "crestáramos": "crestar",
    "crestárei": "crestar",
    "crestáreis": "crestar",
    "crestásseis": "crestar",
    "crestássemos": "crestar",
    "crestávamo": "crestar",
    "crestávamos": "crestar",
    "crestávei": "crestar",
    "crestáveis": "crestar",
    "crestões": "crestão",
    "cresça": "crescer",
    "cresçais": "crescer",
    "cresçam": "crescer",
    "cresçamo": "crescer",
    "cresçamos": "crescer",
    "cresças": "crescer",
    "cresço": "crescer",
    "cresóis": "cresol",
    "cretaica": "cretaico",
    "cretaicas": "cretaico",
    "cretaicos": "cretaico",
    "cretas": "creta",
    "cretenses": "cretense",
    "cretina": "cretino",
    "cretinas": "cretino",
    "cretinices": "cretinice",
    "cretinismos": "cretinismo",
    "cretiniza": "cretinizar",
    "cretinizada": "cretinizar",
    "cretinizadas": "cretinizar",
    "cretinizado": "cretinizar",
    "cretinizados": "cretinizar",
    "cretinizai": "cretinizar",
    "cretinizais": "cretinizar",
    "cretinizam": "cretinizar",
    "cretinizamo": "cretinizar",
    "cretinizamos": "cretinizar",
    "cretinizando": "cretinizar",
    "cretinizara": "cretinizar",
    "cretinizaram": "cretinizar",
    "cretinizaras": "cretinizar",
    "cretinizarde": "cretinizar",
    "cretinizardes": "cretinizar",
    "cretinizare": "cretinizar",
    "cretinizarei": "cretinizar",
    "cretinizareis": "cretinizar",
    "cretinizarem": "cretinizar",
    "cretinizaremos": "cretinizar",
    "cretinizares": "cretinizar",
    "cretinizaria": "cretinizar",
    "cretinizariam": "cretinizar",
    "cretinizarias": "cretinizar",
    "cretinizarmo": "cretinizar",
    "cretinizarmos": "cretinizar",
    "cretinizará": "cretinizar",
    "cretinizarás": "cretinizar",
    "cretinizarão": "cretinizar",
    "cretinizaríamos": "cretinizar",
    "cretinizaríeis": "cretinizar",
    "cretinizas": "cretinizar",
    "cretinizasse": "cretinizar",
    "cretinizassem": "cretinizar",
    "cretinizasses": "cretinizar",
    "cretinizaste": "cretinizar",
    "cretinizastes": "cretinizar",
    "cretinizava": "cretinizar",
    "cretinizavam": "cretinizar",
    "cretinizavas": "cretinizar",
    "cretinizações": "cretinização",
    "cretinize": "cretinizar",
    "cretinizei": "cretinizar",
    "cretinizeis": "cretinizar",
    "cretinizem": "cretinizar",
    "cretinizemo": "cretinizar",
    "cretinizemos": "cretinizar",
    "cretinizes": "cretinizar",
    "cretinizo": "cretinizar",
    "cretinizou": "cretinizar",
    "cretinizá": "cretinizar",
    "cretinizámo": "cretinizar",
    "cretinizámos": "cretinizar",
    "cretinizáramo": "cretinizar",
    "cretinizáramos": "cretinizar",
    "cretinizárei": "cretinizar",
    "cretinizáreis": "cretinizar",
    "cretinizásseis": "cretinizar",
    "cretinizássemos": "cretinizar",
    "cretinizávamo": "cretinizar",
    "cretinizávamos": "cretinizar",
    "cretinizávei": "cretinizar",
    "cretinizáveis": "cretinizar",
    "cretinos": "cretino",
    "cretinosa": "cretinoso",
    "cretinosas": "cretinoso",
    "cretinosos": "cretinoso",
    "cretinóides": "cretinóide",
    "cretones": "cretone",
    "cretonezinho": "cretone",
    "cretonezinhos": "cretone",
    "cretonezito": "cretone",
    "cretonezitos": "cretone",
    "cretácea": "cretáceo",
    "cretáceas": "cretáceo",
    "cretáceos": "cretáceo",
    "cretácica": "cretácico",
    "cretácicas": "cretácico",
    "cretácicos": "cretácico",
    "creu": "crer",
    "creófaga": "creófago",
    "creófagas": "creófago",
    "creófagos": "creófago",
    "creófila": "creófilo",
    "creófilas": "creófilo",
    "creófilos": "creófilo",
    "cri": "crer",
    "cria": "criar",
    "criacionismos": "criacionismo",
    "criacionistas": "criacionista",
    "criada": "criar",
    "criadagens": "criadagem",
    "criadas": "criar",
    "criadeira": "criadeiro",
    "criadeiras": "criadeiro",
    "criadeiros": "criadeiro",
    "criadinha": "criado",
    "criadinhas": "criado",
    "criadinho": "criado",
    "criadinhos": "criado",
    "criadita": "criado",
    "criaditas": "criado",
    "criadito": "criado",
    "criaditos": "criado",
    "criado": "criar",
    "criadoiros": "criadoiro",
    "criadora": "criador",
    "criadoras": "criador",
    "criadores": "criador",
    "criados": "criar",
    "criadouros": "criadouro",
    "criai": "criar",
    "criais": "criar",
    "criam": "criar",
    "criamo": "criar",
    "criamos": "criar",
    "criamosa": "criamoso",
    "criamosas": "criamoso",
    "criamosos": "criamoso",
    "criancelhos": "criancelho",
    "criancices": "criancice",
    "criancinha": "criança",
    "criancinhas": "criança",
    "criancita": "criança",
    "criancitas": "criança",
    "criando": "criar",
    "criançadas": "criançada",
    "criançalhos": "criançalho",
    "crianças": "criança",
    "criançolas": "criançola",
    "crianços": "crianço",
    "criara": "criar",
    "criaram": "criar",
    "criaras": "criar",
    "criarde": "criar",
    "criardes": "criar",
    "criare": "criar",
    "criarei": "criar",
    "criareis": "criar",
    "criarem": "criar",
    "criaremos": "criar",
    "criares": "criar",
    "criaria": "criar",
    "criariam": "criar",
    "criarias": "criar",
    "criarmo": "criar",
    "criarmos": "criar",
    "criará": "criar",
    "criarás": "criar",
    "criarão": "criar",
    "criaríamos": "criar",
    "criaríeis": "criar",
    "crias": "criar",
    "criasse": "criar",
    "criassem": "criar",
    "criasses": "criar",
    "criaste": "criar",
    "criastes": "criar",
    "criativa": "criativo",
    "criativas": "criativo",
    "criatividades": "criatividade",
    "criativos": "criativo",
    "criaturas": "criatura",
    "criaturazinha": "criatura",
    "criaturazinhas": "criatura",
    "criaturazita": "criatura",
    "criaturazitas": "criatura",
    "criaturinha": "criatura",
    "criaturinhas": "criatura",
    "criaturita": "criatura",
    "criaturitas": "criatura",
    "criava": "criar",
    "criavam": "criar",
    "criavas": "criar",
    "criações": "criação",
    "cribriformes": "cribriforme",
    "cricalhas": "cricalha",
    "cricas": "crica",
    "crickets": "cricket",
    "cricris": "cricri",
    "cricóides": "cricóide",
    "crida": "crido",
    "cridas": "crido",
    "crido": "crer",
    "cridos": "crido",
    "crie": "criar",
    "criei": "criar",
    "crieis": "criar",
    "criem": "criar",
    "criemo": "criar",
    "criemos": "criar",
    "cries": "criar",
    "crimes": "crime",
    "crimina": "criminar",
    "criminada": "criminar",
    "criminadas": "criminar",
    "criminado": "criminar",
    "criminadora": "criminador",
    "criminadoras": "criminador",
    "criminadores": "criminador",
    "criminados": "criminar",
    "criminai": "criminar",
    "criminais": "criminar",
    "criminalidades": "criminalidade",
    "criminalistas": "criminalista",
    "criminaliza": "criminalizar",
    "criminalizada": "criminalizar",
    "criminalizadas": "criminalizar",
    "criminalizado": "criminalizar",
    "criminalizados": "criminalizar",
    "criminalizai": "criminalizar",
    "criminalizais": "criminalizar",
    "criminalizam": "criminalizar",
    "criminalizamo": "criminalizar",
    "criminalizamos": "criminalizar",
    "criminalizando": "criminalizar",
    "criminalizara": "criminalizar",
    "criminalizaram": "criminalizar",
    "criminalizaras": "criminalizar",
    "criminalizarde": "criminalizar",
    "criminalizardes": "criminalizar",
    "criminalizare": "criminalizar",
    "criminalizarei": "criminalizar",
    "criminalizareis": "criminalizar",
    "criminalizarem": "criminalizar",
    "criminalizaremos": "criminalizar",
    "criminalizares": "criminalizar",
    "criminalizaria": "criminalizar",
    "criminalizariam": "criminalizar",
    "criminalizarias": "criminalizar",
    "criminalizarmo": "criminalizar",
    "criminalizarmos": "criminalizar",
    "criminalizará": "criminalizar",
    "criminalizarás": "criminalizar",
    "criminalizarão": "criminalizar",
    "criminalizaríamos": "criminalizar",
    "criminalizaríeis": "criminalizar",
    "criminalizas": "criminalizar",
    "criminalizasse": "criminalizar",
    "criminalizassem": "criminalizar",
    "criminalizasses": "criminalizar",
    "criminalizaste": "criminalizar",
    "criminalizastes": "criminalizar",
    "criminalizava": "criminalizar",
    "criminalizavam": "criminalizar",
    "criminalizavas": "criminalizar",
    "criminalize": "criminalizar",
    "criminalizei": "criminalizar",
    "criminalizeis": "criminalizar",
    "criminalizem": "criminalizar",
    "criminalizemo": "criminalizar",
    "criminalizemos": "criminalizar",
    "criminalizes": "criminalizar",
    "criminalizo": "criminalizar",
    "criminalizou": "criminalizar",
    "criminalizá": "criminalizar",
    "criminalizámo": "criminalizar",
    "criminalizámos": "criminalizar",
    "criminalizáramo": "criminalizar",
    "criminalizáramos": "criminalizar",
    "criminalizárei": "criminalizar",
    "criminalizáreis": "criminalizar",
    "criminalizásseis": "criminalizar",
    "criminalizássemos": "criminalizar",
    "criminalizávamo": "criminalizar",
    "criminalizávamos": "criminalizar",
    "criminalizávei": "criminalizar",
    "criminalizáveis": "criminalizar",
    "criminam": "criminar",
    "criminamo": "criminar",
    "criminamos": "criminar",
    "criminando": "criminar",
    "criminara": "criminar",
    "criminaram": "criminar",
    "criminaras": "criminar",
    "criminarde": "criminar",
    "criminardes": "criminar",
    "criminare": "criminar",
    "criminarei": "criminar",
    "criminareis": "criminar",
    "criminarem": "criminar",
    "criminaremos": "criminar",
    "criminares": "criminar",
    "criminaria": "criminar",
    "criminariam": "criminar",
    "criminarias": "criminar",
    "criminarmo": "criminar",
    "criminarmos": "criminar",
    "criminará": "criminar",
    "criminarás": "criminar",
    "criminarão": "criminar",
    "criminaríamos": "criminar",
    "criminaríeis": "criminar",
    "criminas": "criminar",
    "criminasse": "criminar",
    "criminassem": "criminar",
    "criminasses": "criminar",
    "criminaste": "criminar",
    "criminastes": "criminar",
    "criminava": "criminar",
    "criminavam": "criminar",
    "criminavas": "criminar",
    "criminações": "criminação",
    "crimine": "criminar",
    "criminei": "criminar",
    "crimineis": "criminar",
    "criminem": "criminar",
    "criminemo": "criminar",
    "criminemos": "criminar",
    "crimines": "criminar",
    "crimino": "criminar",
    "criminologias": "criminologia",
    "criminologistas": "criminologista",
    "criminológica": "criminológico",
    "criminológicas": "criminológico",
    "criminológicos": "criminológico",
    "criminosa": "criminoso",
    "criminosas": "criminoso",
    "criminosos": "criminoso",
    "criminou": "criminar",
    "criminá": "criminar",
    "criminámo": "criminar",
    "criminámos": "criminar",
    "crimináramo": "criminar",
    "crimináramos": "criminar",
    "criminárei": "criminar",
    "crimináreis": "criminar",
    "criminásseis": "criminar",
    "criminássemos": "criminar",
    "criminávamo": "criminar",
    "criminávamos": "criminar",
    "criminávei": "criminar",
    "crimináveis": "criminável",
    "criminóloga": "criminólogo",
    "criminólogas": "criminólogo",
    "criminólogos": "criminólogo",
    "crimofilias": "crimofilia",
    "crimofobias": "crimofobia",
    "crimoterapeutas": "crimoterapeuta",
    "crimoterapias": "crimoterapia",
    "crimoterapistas": "crimoterapista",
    "crimoterapêutica": "crimoterapêutico",
    "crimoterapêuticas": "crimoterapêutico",
    "crimoterapêuticos": "crimoterapêutico",
    "crimoterápica": "crimoterápico",
    "crimoterápicas": "crimoterápico",
    "crimoterápicos": "crimoterápico",
    "crimófila": "crimófilo",
    "crimófilas": "crimófilo",
    "crimófilos": "crimófilo",
    "crimófoba": "crimófobo",
    "crimófobas": "crimófobo",
    "crimófobos": "crimófobo",
    "crinais": "crinal",
    "crinalva": "crinalvo",
    "crinalvas": "crinalvo",
    "crinalvos": "crinalvo",
    "crinas": "crina",
    "crineiras": "crineira",
    "crinicórnea": "crinicórneo",
    "crinicórneas": "crinicórneo",
    "crinicórneos": "crinicórneo",
    "criniformes": "criniforme",
    "criniparsa": "criniparso",
    "criniparsas": "criniparso",
    "criniparsos": "criniparso",
    "crinipreta": "crinipreto",
    "crinipretas": "crinipreto",
    "crinipretos": "crinipreto",
    "crinita": "crinito",
    "crinitas": "crinito",
    "crinitos": "crinito",
    "crinolinas": "crinolina",
    "crinos": "crino",
    "crináurea": "crináureo",
    "crináureas": "crináureo",
    "crináureos": "crináureo",
    "crinífera": "crinífero",
    "criníferas": "crinífero",
    "criníferos": "crinífero",
    "crinígera": "crinígero",
    "crinígeras": "crinígero",
    "crinígeros": "crinígero",
    "crinóides": "crinóide",
    "crio": "criar",
    "criobrânquia": "criobrânquio",
    "criobrânquias": "criobrânquio",
    "criobrânquica": "criobrânquico",
    "criobrânquicas": "criobrânquico",
    "criobrânquicos": "criobrânquico",
    "criobrânquios": "criobrânquio",
    "criocirúrgica": "criocirúrgico",
    "criocirúrgicas": "criocirúrgico",
    "criocirúrgicos": "criocirúrgico",
    "criocéfala": "criocéfalo",
    "criocéfalas": "criocéfalo",
    "criocéfalos": "criocéfalo",
    "criogenias": "criogenia",
    "criogénica": "criogénico",
    "criogénicas": "criogénico",
    "criogénicos": "criogénico",
    "criola": "criolo",
    "crioladas": "criolada",
    "criolas": "criolo",
    "criolazinha": "criolo",
    "criolazinhas": "criolo",
    "criolazita": "criolo",
    "criolazitas": "criolo",
    "criolites": "criolite",
    "criolona": "criolão",
    "criolonas": "criolão",
    "criolos": "criolo",
    "criolozinho": "criolo",
    "criolozinhos": "criolo",
    "criolozito": "criolo",
    "criolozitos": "criolo",
    "criolões": "criolão",
    "criometrias": "criometria",
    "criométrica": "criométrico",
    "criométricas": "criométrico",
    "criométricos": "criométrico",
    "crioscopias": "crioscopia",
    "crioscópica": "crioscópico",
    "crioscópicas": "crioscópico",
    "crioscópicos": "crioscópico",
    "crioscópios": "crioscópio",
    "criosferas": "criosfera",
    "criosférica": "criosférico",
    "criosféricas": "criosférico",
    "criosféricos": "criosférico",
    "criostatos": "criostato",
    "criostática": "criostático",
    "criostáticas": "criostático",
    "criostáticos": "criostático",
    "crioterapeutas": "crioterapeuta",
    "crioterapias": "crioterapia",
    "crioterapistas": "crioterapista",
    "crioterapêutica": "crioterapêutico",
    "crioterapêuticas": "crioterapêutico",
    "crioterapêuticos": "crioterapêutico",
    "crioterápica": "crioterápico",
    "crioterápicas": "crioterápico",
    "crioterápicos": "crioterápico",
    "criou": "criar",
    "crioula": "crioulo",
    "crioulas": "crioulo",
    "crioulizações": "crioulização",
    "crioulos": "crioulo",
    "criptas": "cripta",
    "criptobrânquios": "criptobrânquio",
    "criptocarpa": "criptocarpo",
    "criptocarpas": "criptocarpo",
    "criptocarpos": "criptocarpo",
    "criptocefalias": "criptocefalia",
    "criptocefálica": "criptocefálico",
    "criptocefálicas": "criptocefálico",
    "criptocefálicos": "criptocefálico",
    "criptocristalina": "criptocristalino",
    "criptocristalinas": "criptocristalino",
    "criptocristalinos": "criptocristalino",
    "criptocárpica": "criptocárpico",
    "criptocárpicas": "criptocárpico",
    "criptocárpicos": "criptocárpico",
    "criptocéfala": "criptocéfalo",
    "criptocéfalas": "criptocéfalo",
    "criptocéfalos": "criptocéfalo",
    "criptogamias": "criptogamia",
    "criptogenésica": "criptogenésico",
    "criptogenésicas": "criptogenésico",
    "criptogenésicos": "criptogenésico",
    "criptogenética": "criptogenético",
    "criptogenéticas": "criptogenético",
    "criptogenéticos": "criptogenético",
    "criptografias": "criptografia",
    "criptogramas": "criptograma",
    "criptogramistas": "criptogramista",
    "criptográfica": "criptográfico",
    "criptográficas": "criptográfico",
    "criptográficos": "criptográfico",
    "criptogâmica": "criptogâmico",
    "criptogâmicas": "criptogâmico",
    "criptogâmicos": "criptogâmico",
    "criptogéneses": "criptogénese",
    "criptologias": "criptologia",
    "criptologistas": "criptologista",
    "criptológica": "criptológico",
    "criptológicas": "criptológico",
    "criptológicos": "criptológico",
    "criptonímias": "criptonímia",
    "criptorquídea": "criptorquídeo",
    "criptorquídeas": "criptorquídeo",
    "criptorquídeos": "criptorquídeo",
    "criptozóica": "criptozóico",
    "criptozóicas": "criptozóico",
    "criptozóicos": "criptozóico",
    "criptógama": "criptógamo",
    "criptógamas": "criptógamo",
    "criptógamos": "criptógamo",
    "criptógena": "criptógeno",
    "criptógenas": "criptógeno",
    "criptógenos": "criptógeno",
    "criptógrafa": "criptógrafo",
    "criptógrafas": "criptógrafo",
    "criptógrafos": "criptógrafo",
    "criptóloga": "criptólogo",
    "criptólogas": "criptólogo",
    "criptólogos": "criptólogo",
    "criptónima": "criptónimo",
    "criptónimas": "criptónimo",
    "criptónimos": "criptónimo",
    "criptónomos": "criptónomo",
    "criptópodes": "criptópode",
    "crisalida": "crisalidar",
    "crisalidada": "crisalidar",
    "crisalidadas": "crisalidar",
    "crisalidado": "crisalidar",
    "crisalidados": "crisalidar",
    "crisalidai": "crisalidar",
    "crisalidais": "crisalidar",
    "crisalidam": "crisalidar",
    "crisalidamo": "crisalidar",
    "crisalidamos": "crisalidar",
    "crisalidando": "crisalidar",
    "crisalidara": "crisalidar",
    "crisalidaram": "crisalidar",
    "crisalidaras": "crisalidar",
    "crisalidardes": "crisalidar",
    "crisalidarei": "crisalidar",
    "crisalidareis": "crisalidar",
    "crisalidarem": "crisalidar",
    "crisalidaremos": "crisalidar",
    "crisalidares": "crisalidar",
    "crisalidaria": "crisalidar",
    "crisalidariam": "crisalidar",
    "crisalidarias": "crisalidar",
    "crisalidarmo": "crisalidar",
    "crisalidarmos": "crisalidar",
    "crisalidará": "crisalidar",
    "crisalidarás": "crisalidar",
    "crisalidarão": "crisalidar",
    "crisalidaríamos": "crisalidar",
    "crisalidaríeis": "crisalidar",
    "crisalidas": "crisalidar",
    "crisalidasse": "crisalidar",
    "crisalidassem": "crisalidar",
    "crisalidasses": "crisalidar",
    "crisalidaste": "crisalidar",
    "crisalidastes": "crisalidar",
    "crisalidava": "crisalidar",
    "crisalidavam": "crisalidar",
    "crisalidavas": "crisalidar",
    "crisalidações": "crisalidação",
    "crisalide": "crisalidar",
    "crisalidei": "crisalidar",
    "crisalideis": "crisalidar",
    "crisalidem": "crisalidar",
    "crisalidemo": "crisalidar",
    "crisalidemos": "crisalidar",
    "crisalides": "crisalidar",
    "crisalido": "crisalidar",
    "crisalidou": "crisalidar",
    "crisalidámo": "crisalidar",
    "crisalidámos": "crisalidar",
    "crisalidáramo": "crisalidar",
    "crisalidáramos": "crisalidar",
    "crisalidáreis": "crisalidar",
    "crisalidásseis": "crisalidar",
    "crisalidássemos": "crisalidar",
    "crisalidávamo": "crisalidar",
    "crisalidávamos": "crisalidar",
    "crisalidáveis": "crisalidar",
    "crisantos": "crisanto",
    "criselefantina": "criselefantino",
    "criselefantinas": "criselefantino",
    "criselefantinos": "criselefantino",
    "crises": "crise",
    "crisma": "crismar",
    "crismada": "crismar",
    "crismadas": "crismar",
    "crismado": "crismar",
    "crismadora": "crismador",
    "crismadoras": "crismador",
    "crismadores": "crismador",
    "crismados": "crismar",
    "crismai": "crismar",
    "crismais": "crismar",
    "crismam": "crismar",
    "crismamo": "crismar",
    "crismamos": "crismar",
    "crismando": "crismar",
    "crismara": "crismar",
    "crismaram": "crismar",
    "crismaras": "crismar",
    "crismarde": "crismar",
    "crismardes": "crismar",
    "crismare": "crismar",
    "crismarei": "crismar",
    "crismareis": "crismar",
    "crismarem": "crismar",
    "crismaremos": "crismar",
    "crismares": "crismar",
    "crismaria": "crismar",
    "crismariam": "crismar",
    "crismarias": "crismar",
    "crismarmo": "crismar",
    "crismarmos": "crismar",
    "crismará": "crismar",
    "crismarás": "crismar",
    "crismarão": "crismar",
    "crismaríamos": "crismar",
    "crismaríeis": "crismar",
    "crismas": "crismar",
    "crismasse": "crismar",
    "crismassem": "crismar",
    "crismasses": "crismar",
    "crismaste": "crismar",
    "crismastes": "crismar",
    "crismava": "crismar",
    "crismavam": "crismar",
    "crismavas": "crismar",
    "crisme": "crismar",
    "crismei": "crismar",
    "crismeis": "crismar",
    "crismem": "crismar",
    "crismemo": "crismar",
    "crismemos": "crismar",
    "crismes": "crismar",
    "crismo": "crismar",
    "crismou": "crismar",
    "crismá": "crismar",
    "crismámo": "crismar",
    "crismámos": "crismar",
    "crismáramo": "crismar",
    "crismáramos": "crismar",
    "crismárei": "crismar",
    "crismáreis": "crismar",
    "crismásseis": "crismar",
    "crismássemos": "crismar",
    "crismávamo": "crismar",
    "crismávamos": "crismar",
    "crismávei": "crismar",
    "crismáveis": "crismar",
    "crisoberilos": "crisoberilo",
    "crisocarpa": "crisocarpo",
    "crisocarpas": "crisocarpo",
    "crisocarpos": "crisocarpo",
    "crisocárpica": "crisocárpico",
    "crisocárpicas": "crisocárpico",
    "crisocárpicos": "crisocárpico",
    "crisocéfala": "crisocéfalo",
    "crisocéfalas": "crisocéfalo",
    "crisocéfalos": "crisocéfalo",
    "crisofilias": "crisofilia",
    "crisofobias": "crisofobia",
    "crisofílica": "crisofílico",
    "crisofílicas": "crisofílico",
    "crisofílicos": "crisofílico",
    "crisofóbica": "crisofóbico",
    "crisofóbicas": "crisofóbico",
    "crisofóbicos": "crisofóbico",
    "crisografias": "crisografia",
    "crisográfica": "crisográfico",
    "crisográficas": "crisográfico",
    "crisográficos": "crisográfico",
    "crisolitas": "crisolita",
    "crisolitos": "crisolito",
    "crisologias": "crisologia",
    "crisologistas": "crisologista",
    "crisológica": "crisológico",
    "crisológicas": "crisológico",
    "crisológicos": "crisológico",
    "crisopeias": "crisopeia",
    "crisopeica": "crisopeico",
    "crisopeicas": "crisopeico",
    "crisopeicos": "crisopeico",
    "crisoprasios": "crisoprasio",
    "crisoprasos": "crisopraso",
    "crisoterapeutas": "crisoterapeuta",
    "crisoterapias": "crisoterapia",
    "crisoterapistas": "crisoterapista",
    "crisoterapêutica": "crisoterapêutico",
    "crisoterapêuticas": "crisoterapêutico",
    "crisoterapêuticos": "crisoterapêutico",
    "crisoterápica": "crisoterápico",
    "crisoterápicas": "crisoterápico",
    "crisoterápicos": "crisoterápico",
    "crispa": "crispar",
    "crispada": "crispar",
    "crispadas": "crispar",
    "crispado": "crispar",
    "crispados": "crispar",
    "crispaduras": "crispadura",
    "crispadíssima": "crispado",
    "crispadíssimas": "crispado",
    "crispadíssimo": "crispado",
    "crispadíssimos": "crispado",
    "crispai": "crispar",
    "crispais": "crispar",
    "crispam": "crispar",
    "crispamentos": "crispamento",
    "crispamo": "crispar",
    "crispamos": "crispar",
    "crispando": "crispar",
    "crispantes": "crispante",
    "crispara": "crispar",
    "crisparam": "crispar",
    "crisparas": "crispar",
    "crisparde": "crispar",
    "crispardes": "crispar",
    "crispare": "crispar",
    "crisparei": "crispar",
    "crispareis": "crispar",
    "crisparem": "crispar",
    "crisparemos": "crispar",
    "crispares": "crispar",
    "crisparia": "crispar",
    "crispariam": "crispar",
    "crisparias": "crispar",
    "crisparmo": "crispar",
    "crisparmos": "crispar",
    "crispará": "crispar",
    "crisparás": "crispar",
    "crisparão": "crispar",
    "crisparíamos": "crispar",
    "crisparíeis": "crispar",
    "crispas": "crispar",
    "crispasse": "crispar",
    "crispassem": "crispar",
    "crispasses": "crispar",
    "crispaste": "crispar",
    "crispastes": "crispar",
    "crispava": "crispar",
    "crispavam": "crispar",
    "crispavas": "crispar",
    "crispações": "crispação",
    "crispe": "crispar",
    "crispei": "crispar",
    "crispeis": "crispar",
    "crispem": "crispar",
    "crispemo": "crispar",
    "crispemos": "crispar",
    "crispes": "crispar",
    "crispiflora": "crispifloro",
    "crispifloras": "crispifloro",
    "crispifloros": "crispifloro",
    "crispiforiada": "crispiforiado",
    "crispiforiadas": "crispiforiado",
    "crispiforiados": "crispiforiado",
    "crispo": "crispar",
    "crispou": "crispar",
    "crispá": "crispar",
    "crispámo": "crispar",
    "crispámos": "crispar",
    "crispáramo": "crispar",
    "crispáramos": "crispar",
    "crispárei": "crispar",
    "crispáreis": "crispar",
    "crispásseis": "crispar",
    "crispássemos": "crispar",
    "crispávamo": "crispar",
    "crispávamos": "crispar",
    "crispávei": "crispar",
    "crispáveis": "crispar",
    "cristada": "cristado",
    "cristadas": "cristado",
    "cristados": "cristado",
    "cristais": "cristal",
    "cristalarias": "cristalaria",
    "cristaleiras": "cristaleira",
    "cristalerias": "cristaleria",
    "cristalina": "cristalino",
    "cristalinas": "cristalino",
    "cristalinidades": "cristalinidade",
    "cristalinos": "cristalino",
    "cristaliza": "cristalizar",
    "cristalizada": "cristalizar",
    "cristalizadas": "cristalizar",
    "cristalizado": "cristalizar",
    "cristalizadora": "cristalizador",
    "cristalizadoras": "cristalizador",
    "cristalizadores": "cristalizador",
    "cristalizados": "cristalizar",
    "cristalizai": "cristalizar",
    "cristalizais": "cristalizar",
    "cristalizam": "cristalizar",
    "cristalizamo": "cristalizar",
    "cristalizamos": "cristalizar",
    "cristalizando": "cristalizar",
    "cristalizara": "cristalizar",
    "cristalizaram": "cristalizar",
    "cristalizaras": "cristalizar",
    "cristalizarde": "cristalizar",
    "cristalizardes": "cristalizar",
    "cristalizare": "cristalizar",
    "cristalizarei": "cristalizar",
    "cristalizareis": "cristalizar",
    "cristalizarem": "cristalizar",
    "cristalizaremos": "cristalizar",
    "cristalizares": "cristalizar",
    "cristalizaria": "cristalizar",
    "cristalizariam": "cristalizar",
    "cristalizarias": "cristalizar",
    "cristalizarmo": "cristalizar",
    "cristalizarmos": "cristalizar",
    "cristalizará": "cristalizar",
    "cristalizarás": "cristalizar",
    "cristalizarão": "cristalizar",
    "cristalizaríamos": "cristalizar",
    "cristalizaríeis": "cristalizar",
    "cristalizas": "cristalizar",
    "cristalizasse": "cristalizar",
    "cristalizassem": "cristalizar",
    "cristalizasses": "cristalizar",
    "cristalizaste": "cristalizar",
    "cristalizastes": "cristalizar",
    "cristalizava": "cristalizar",
    "cristalizavam": "cristalizar",
    "cristalizavas": "cristalizar",
    "cristalizações": "cristalização",
    "cristalize": "cristalizar",
    "cristalizei": "cristalizar",
    "cristalizeis": "cristalizar",
    "cristalizem": "cristalizar",
    "cristalizemo": "cristalizar",
    "cristalizemos": "cristalizar",
    "cristalizes": "cristalizar",
    "cristalizo": "cristalizar",
    "cristalizou": "cristalizar",
    "cristalizá": "cristalizar",
    "cristalizámo": "cristalizar",
    "cristalizámos": "cristalizar",
    "cristalizáramo": "cristalizar",
    "cristalizáramos": "cristalizar",
    "cristalizárei": "cristalizar",
    "cristalizáreis": "cristalizar",
    "cristalizásseis": "cristalizar",
    "cristalizássemos": "cristalizar",
    "cristalizávamo": "cristalizar",
    "cristalizávamos": "cristalizar",
    "cristalizávei": "cristalizar",
    "cristalizáveis": "cristalizável",
    "cristalofobias": "cristalofobia",
    "cristalofílica": "cristalofílico",
    "cristalofílicas": "cristalofílico",
    "cristalofílicos": "cristalofílico",
    "cristalofóbica": "cristalofóbico",
    "cristalofóbicas": "cristalofóbico",
    "cristalofóbicos": "cristalofóbico",
    "cristalografias": "cristalografia",
    "cristalográfica": "cristalográfico",
    "cristalográficas": "cristalográfico",
    "cristalográficos": "cristalográfico",
    "cristalologias": "cristalologia",
    "cristalologistas": "cristalologista",
    "cristalotomias": "cristalotomia",
    "cristalotómica": "cristalotómico",
    "cristalotómicas": "cristalotómico",
    "cristalotómicos": "cristalotómico",
    "cristalífera": "cristalífero",
    "cristalíferas": "cristalífero",
    "cristalíferos": "cristalífero",
    "cristalófila": "cristalófilo",
    "cristalófilas": "cristalófilo",
    "cristalófilos": "cristalófilo",
    "cristalófoba": "cristalófobo",
    "cristalófobas": "cristalófobo",
    "cristalófobos": "cristalófobo",
    "cristalófoca": "cristalófoco",
    "cristalófocas": "cristalófoco",
    "cristalófocos": "cristalófoco",
    "cristalógica": "cristalógico",
    "cristalógicas": "cristalógico",
    "cristalógicos": "cristalógico",
    "cristalógrafos": "cristalógrafo",
    "cristalóides": "cristalóide",
    "cristalóloga": "cristalólogo",
    "cristalólogas": "cristalólogo",
    "cristalólogos": "cristalólogo",
    "cristandades": "cristandade",
    "cristas": "crista",
    "cristeis": "cristel",
    "cristelos": "cristelo",
    "cristianicidas": "cristianicida",
    "cristianismos": "cristianismo",
    "cristianiza": "cristianizar",
    "cristianizada": "cristianizar",
    "cristianizadas": "cristianizar",
    "cristianizado": "cristianizar",
    "cristianizados": "cristianizar",
    "cristianizai": "cristianizar",
    "cristianizais": "cristianizar",
    "cristianizam": "cristianizar",
    "cristianizamo": "cristianizar",
    "cristianizamos": "cristianizar",
    "cristianizando": "cristianizar",
    "cristianizara": "cristianizar",
    "cristianizaram": "cristianizar",
    "cristianizaras": "cristianizar",
    "cristianizarde": "cristianizar",
    "cristianizardes": "cristianizar",
    "cristianizare": "cristianizar",
    "cristianizarei": "cristianizar",
    "cristianizareis": "cristianizar",
    "cristianizarem": "cristianizar",
    "cristianizaremos": "cristianizar",
    "cristianizares": "cristianizar",
    "cristianizaria": "cristianizar",
    "cristianizariam": "cristianizar",
    "cristianizarias": "cristianizar",
    "cristianizarmo": "cristianizar",
    "cristianizarmos": "cristianizar",
    "cristianizará": "cristianizar",
    "cristianizarás": "cristianizar",
    "cristianizarão": "cristianizar",
    "cristianizaríamos": "cristianizar",
    "cristianizaríeis": "cristianizar",
    "cristianizas": "cristianizar",
    "cristianizasse": "cristianizar",
    "cristianizassem": "cristianizar",
    "cristianizasses": "cristianizar",
    "cristianizaste": "cristianizar",
    "cristianizastes": "cristianizar",
    "cristianizava": "cristianizar",
    "cristianizavam": "cristianizar",
    "cristianizavas": "cristianizar",
    "cristianizações": "cristianização",
    "cristianize": "cristianizar",
    "cristianizei": "cristianizar",
    "cristianizeis": "cristianizar",
    "cristianizem": "cristianizar",
    "cristianizemo": "cristianizar",
    "cristianizemos": "cristianizar",
    "cristianizes": "cristianizar",
    "cristianizo": "cristianizar",
    "cristianizou": "cristianizar",
    "cristianizá": "cristianizar",
    "cristianizámo": "cristianizar",
    "cristianizámos": "cristianizar",
    "cristianizáramo": "cristianizar",
    "cristianizáramos": "cristianizar",
    "cristianizárei": "cristianizar",
    "cristianizáreis": "cristianizar",
    "cristianizásseis": "cristianizar",
    "cristianizássemos": "cristianizar",
    "cristianizávamo": "cristianizar",
    "cristianizávamos": "cristianizar",
    "cristianizávei": "cristianizar",
    "cristianizáveis": "cristianizar",
    "cristianíssima": "cristianíssimo",
    "cristianíssimas": "cristianíssimo",
    "cristianíssimos": "cristianíssimo",
    "cristofles": "cristofle",
    "cristologias": "cristologia",
    "cristologistas": "cristologista",
    "cristológica": "cristológico",
    "cristológicas": "cristológico",
    "cristológicos": "cristológico",
    "cristos": "cristo",
    "cristã": "cristão",
    "cristãos": "cristão",
    "cristãs": "cristão",
    "cristóloga": "cristólogo",
    "cristólogas": "cristólogo",
    "cristólogos": "cristólogo",
    "crisálidas": "crisálida",
    "crisálides": "crisálide",
    "crisântemos": "crisântemo",
    "crisófila": "crisófilo",
    "crisófilas": "crisófilo",
    "crisófilos": "crisófilo",
    "crisófoba": "crisófobo",
    "crisófobas": "crisófobo",
    "crisófobos": "crisófobo",
    "crisógrafos": "crisógrafo",
    "crisóis": "crisol",
    "crisóloga": "crisólogo",
    "crisólogas": "crisólogo",
    "crisólogos": "crisólogo",
    "crisóptera": "crisóptero",
    "crisópteras": "crisóptero",
    "crisópteros": "crisóptero",
    "crisóstoma": "crisóstomo",
    "crisóstomas": "crisóstomo",
    "crisóstomos": "crisóstomo",
    "criteriosa": "criterioso",
    "criteriosas": "criterioso",
    "criteriosos": "criterioso",
    "critica": "criticar",
    "criticada": "criticar",
    "criticadas": "criticar",
    "criticado": "criticar",
    "criticadora": "criticador",
    "criticadoras": "criticador",
    "criticadores": "criticador",
    "criticados": "criticar",
    "criticadíssima": "criticado",
    "criticadíssimas": "criticado",
    "criticadíssimo": "criticado",
    "criticadíssimos": "criticado",
    "criticai": "criticar",
    "criticais": "criticar",
    "criticam": "criticar",
    "criticamo": "criticar",
    "criticamos": "criticar",
    "criticando": "criticar",
    "criticantes": "criticante",
    "criticara": "criticar",
    "criticaram": "criticar",
    "criticaras": "criticar",
    "criticarde": "criticar",
    "criticardes": "criticar",
    "criticare": "criticar",
    "criticarei": "criticar",
    "criticareis": "criticar",
    "criticarem": "criticar",
    "criticaremos": "criticar",
    "criticares": "criticar",
    "criticaria": "criticar",
    "criticariam": "criticar",
    "criticarias": "criticar",
    "criticarmo": "criticar",
    "criticarmos": "criticar",
    "criticará": "criticar",
    "criticarás": "criticar",
    "criticarão": "criticar",
    "criticaríamos": "criticar",
    "criticaríeis": "criticar",
    "criticas": "criticar",
    "criticasse": "criticar",
    "criticassem": "criticar",
    "criticasses": "criticar",
    "criticaste": "criticar",
    "criticastes": "criticar",
    "criticastra": "criticastro",
    "criticastras": "criticastro",
    "criticastros": "criticastro",
    "criticava": "criticar",
    "criticavam": "criticar",
    "criticavas": "criticar",
    "criticismos": "criticismo",
    "criticistas": "criticista",
    "critico": "criticar",
    "criticou": "criticar",
    "criticá": "criticar",
    "criticámo": "criticar",
    "criticámos": "criticar",
    "criticáramo": "criticar",
    "criticáramos": "criticar",
    "criticárei": "criticar",
    "criticáreis": "criticar",
    "criticásseis": "criticar",
    "criticássemos": "criticar",
    "criticávamo": "criticar",
    "criticávamos": "criticar",
    "criticávei": "criticar",
    "criticáveis": "criticável",
    "critique": "criticar",
    "critiquei": "criticar",
    "critiqueira": "critiqueiro",
    "critiqueiras": "critiqueiro",
    "critiqueiros": "critiqueiro",
    "critiqueis": "criticar",
    "critiquem": "criticar",
    "critiquemo": "criticar",
    "critiquemos": "criticar",
    "critiques": "criticar",
    "critiquices": "critiquice",
    "critofágica": "critofágico",
    "critofágicas": "critofágico",
    "critofágicos": "critofágico",
    "critérios": "critério",
    "critófaga": "critófago",
    "critófagas": "critófago",
    "critófagos": "critófago",
    "criva": "crivar",
    "crivada": "crivar",
    "crivadas": "crivar",
    "crivado": "crivar",
    "crivados": "crivar",
    "crivai": "crivar",
    "crivais": "crivar",
    "crivam": "crivar",
    "crivamo": "crivar",
    "crivamos": "crivar",
    "crivando": "crivar",
    "crivara": "crivar",
    "crivaram": "crivar",
    "crivaras": "crivar",
    "crivarde": "crivar",
    "crivardes": "crivar",
    "crivare": "crivar",
    "crivarei": "crivar",
    "crivareis": "crivar",
    "crivarem": "crivar",
    "crivaremos": "crivar",
    "crivares": "crivar",
    "crivaria": "crivar",
    "crivariam": "crivar",
    "crivarias": "crivar",
    "crivarmo": "crivar",
    "crivarmos": "crivar",
    "crivará": "crivar",
    "crivarás": "crivar",
    "crivarão": "crivar",
    "crivaríamos": "crivar",
    "crivaríeis": "crivar",
    "crivas": "crivar",
    "crivasse": "crivar",
    "crivassem": "crivar",
    "crivasses": "crivar",
    "crivaste": "crivar",
    "crivastes": "crivar",
    "crivava": "crivar",
    "crivavam": "crivar",
    "crivavas": "crivar",
    "crivações": "crivação",
    "crive": "crivar",
    "crivei": "crivar",
    "criveiros": "criveiro",
    "criveis": "crivar",
    "crivem": "crivar",
    "crivemo": "crivar",
    "crivemos": "crivar",
    "crives": "crivar",
    "criviformes": "criviforme",
    "crivo": "crivar",
    "crivos": "crivo",
    "crivosa": "crivoso",
    "crivosas": "crivoso",
    "crivosos": "crivoso",
    "crivou": "crivar",
    "crivá": "crivar",
    "crivámo": "crivar",
    "crivámos": "crivar",
    "criváramo": "crivar",
    "criváramos": "crivar",
    "crivárei": "crivar",
    "criváreis": "crivar",
    "crivásseis": "crivar",
    "crivássemos": "crivar",
    "crivávamo": "crivar",
    "crivávamos": "crivar",
    "crivávei": "crivar",
    "criváveis": "crivar",
    "criá": "criar",
    "criámo": "criar",
    "criámos": "criar",
    "criáramo": "criar",
    "criáramos": "criar",
    "criárei": "criar",
    "criáreis": "criar",
    "criásseis": "criar",
    "criássemos": "criar",
    "criávamo": "criar",
    "criávamos": "criar",
    "criávei": "criar",
    "criáveis": "criável",
    "criólitos": "criólito",
    "croatas": "croata",
    "crocas": "croca",
    "crochés": "croché",
    "crocidismos": "crocidismo",
    "crocita": "crocitar",
    "crocitada": "crocitar",
    "crocitadas": "crocitar",
    "crocitado": "crocitar",
    "crocitados": "crocitar",
    "crocitai": "crocitar",
    "crocitais": "crocitar",
    "crocitam": "crocitar",
    "crocitamo": "crocitar",
    "crocitamos": "crocitar",
    "crocitando": "crocitar",
    "crocitantes": "crocitante",
    "crocitara": "crocitar",
    "crocitaram": "crocitar",
    "crocitaras": "crocitar",
    "crocitardes": "crocitar",
    "crocitarei": "crocitar",
    "crocitareis": "crocitar",
    "crocitarem": "crocitar",
    "crocitaremos": "crocitar",
    "crocitares": "crocitar",
    "crocitaria": "crocitar",
    "crocitariam": "crocitar",
    "crocitarias": "crocitar",
    "crocitarmo": "crocitar",
    "crocitarmos": "crocitar",
    "crocitará": "crocitar",
    "crocitarás": "crocitar",
    "crocitarão": "crocitar",
    "crocitaríamos": "crocitar",
    "crocitaríeis": "crocitar",
    "crocitas": "crocitar",
    "crocitasse": "crocitar",
    "crocitassem": "crocitar",
    "crocitasses": "crocitar",
    "crocitaste": "crocitar",
    "crocitastes": "crocitar",
    "crocitava": "crocitar",
    "crocitavam": "crocitar",
    "crocitavas": "crocitar",
    "crocite": "crocitar",
    "crocitei": "crocitar",
    "crociteis": "crocitar",
    "crocitem": "crocitar",
    "crocitemo": "crocitar",
    "crocitemos": "crocitar",
    "crocites": "crocitar",
    "crocito": "crocitar",
    "crocitos": "crocito",
    "crocitou": "crocitar",
    "crocitámo": "crocitar",
    "crocitámos": "crocitar",
    "crocitáramo": "crocitar",
    "crocitáramos": "crocitar",
    "crocitáreis": "crocitar",
    "crocitásseis": "crocitar",
    "crocitássemos": "crocitar",
    "crocitávamo": "crocitar",
    "crocitávamos": "crocitar",
    "crocitáveis": "crocitar",
    "crocodilesca": "crocodilesco",
    "crocodilescas": "crocodilesco",
    "crocodilescos": "crocodilesco",
    "crocodilianos": "crocodiliano",
    "crocodilina": "crocodilino",
    "crocodilinas": "crocodilino",
    "crocodilinos": "crocodilino",
    "crocodilos": "crocodilo",
    "crocodilídea": "crocodilídeo",
    "crocodilídeas": "crocodilídeo",
    "crocodilídeos": "crocodilídeo",
    "crocodílidas": "crocodílida",
    "crocálidas": "crocálida",
    "crocípedes": "crocípede",
    "croissanterias": "croissanteria",
    "croissants": "croissant",
    "croma": "cromar",
    "cromada": "cromar",
    "cromadas": "cromar",
    "cromado": "cromar",
    "cromados": "cromar",
    "cromagens": "cromagem",
    "cromai": "cromar",
    "cromais": "cromar",
    "cromam": "cromar",
    "cromamo": "cromar",
    "cromamos": "cromar",
    "cromando": "cromar",
    "cromara": "cromar",
    "cromaram": "cromar",
    "cromaras": "cromar",
    "cromarde": "cromar",
    "cromardes": "cromar",
    "cromare": "cromar",
    "cromarei": "cromar",
    "cromareis": "cromar",
    "cromarem": "cromar",
    "cromaremos": "cromar",
    "cromares": "cromar",
    "cromaria": "cromar",
    "cromariam": "cromar",
    "cromarias": "cromar",
    "cromarmo": "cromar",
    "cromarmos": "cromar",
    "cromará": "cromar",
    "cromarás": "cromar",
    "cromarão": "cromar",
    "cromaríamos": "cromar",
    "cromaríeis": "cromar",
    "cromas": "cromar",
    "cromasse": "cromar",
    "cromassem": "cromar",
    "cromasses": "cromar",
    "cromaste": "cromar",
    "cromastes": "cromar",
    "cromatias": "cromatia",
    "cromatinas": "cromatina",
    "cromatismos": "cromatismo",
    "cromatiza": "cromatizar",
    "cromatizada": "cromatizar",
    "cromatizadas": "cromatizar",
    "cromatizado": "cromatizar",
    "cromatizados": "cromatizar",
    "cromatizai": "cromatizar",
    "cromatizais": "cromatizar",
    "cromatizam": "cromatizar",
    "cromatizamo": "cromatizar",
    "cromatizamos": "cromatizar",
    "cromatizando": "cromatizar",
    "cromatizara": "cromatizar",
    "cromatizaram": "cromatizar",
    "cromatizaras": "cromatizar",
    "cromatizarde": "cromatizar",
    "cromatizardes": "cromatizar",
    "cromatizare": "cromatizar",
    "cromatizarei": "cromatizar",
    "cromatizareis": "cromatizar",
    "cromatizarem": "cromatizar",
    "cromatizaremos": "cromatizar",
    "cromatizares": "cromatizar",
    "cromatizaria": "cromatizar",
    "cromatizariam": "cromatizar",
    "cromatizarias": "cromatizar",
    "cromatizarmo": "cromatizar",
    "cromatizarmos": "cromatizar",
    "cromatizará": "cromatizar",
    "cromatizarás": "cromatizar",
    "cromatizarão": "cromatizar",
    "cromatizaríamos": "cromatizar",
    "cromatizaríeis": "cromatizar",
    "cromatizas": "cromatizar",
    "cromatizasse": "cromatizar",
    "cromatizassem": "cromatizar",
    "cromatizasses": "cromatizar",
    "cromatizaste": "cromatizar",
    "cromatizastes": "cromatizar",
    "cromatizava": "cromatizar",
    "cromatizavam": "cromatizar",
    "cromatizavas": "cromatizar",
    "cromatize": "cromatizar",
    "cromatizei": "cromatizar",
    "cromatizeis": "cromatizar",
    "cromatizem": "cromatizar",
    "cromatizemo": "cromatizar",
    "cromatizemos": "cromatizar",
    "cromatizes": "cromatizar",
    "cromatizo": "cromatizar",
    "cromatizou": "cromatizar",
    "cromatizá": "cromatizar",
    "cromatizámo": "cromatizar",
    "cromatizámos": "cromatizar",
    "cromatizáramo": "cromatizar",
    "cromatizáramos": "cromatizar",
    "cromatizárei": "cromatizar",
    "cromatizáreis": "cromatizar",
    "cromatizásseis": "cromatizar",
    "cromatizássemos": "cromatizar",
    "cromatizávamo": "cromatizar",
    "cromatizávamos": "cromatizar",
    "cromatizávei": "cromatizar",
    "cromatizáveis": "cromatizar",
    "cromatoblastos": "cromatoblasto",
    "cromatografias": "cromatografia",
    "cromatográfica": "cromatográfico",
    "cromatográficas": "cromatográfico",
    "cromatográficos": "cromatográfico",
    "cromatos": "cromato",
    "cromatoscopias": "cromatoscopia",
    "cromatoscópica": "cromatoscópico",
    "cromatoscópicas": "cromatoscópico",
    "cromatoscópicos": "cromatoscópico",
    "cromatoscópios": "cromatoscópio",
    "cromatídeos": "cromatídeo",
    "cromatócitos": "cromatócito",
    "cromatófaga": "cromatófago",
    "cromatófagas": "cromatófago",
    "cromatófagos": "cromatófago",
    "cromava": "cromar",
    "cromavam": "cromar",
    "cromavas": "cromar",
    "crome": "cromar",
    "cromei": "cromar",
    "cromeis": "cromel",
    "cromem": "cromar",
    "cromemo": "cromar",
    "cromemos": "cromar",
    "cromes": "cromar",
    "cromias": "cromia",
    "cromites": "cromite",
    "cromo": "cromar",
    "cromoblastos": "cromoblasto",
    "cromofilias": "cromofilia",
    "cromofobias": "cromofobia",
    "cromofotografias": "cromofotografia",
    "cromofílica": "cromofílico",
    "cromofílicas": "cromofílico",
    "cromofílicos": "cromofílico",
    "cromofóbica": "cromofóbico",
    "cromofóbicas": "cromofóbico",
    "cromofóbicos": "cromofóbico",
    "cromogéneses": "cromogénese",
    "cromogénica": "cromogénico",
    "cromogénicas": "cromogénico",
    "cromogénicos": "cromogénico",
    "cromoleucitos": "cromoleucito",
    "cromolitografias": "cromolitografia",
    "cromolitográfica": "cromolitográfico",
    "cromolitográficas": "cromolitográfico",
    "cromolitográficos": "cromolitográfico",
    "cromonemas": "cromonema",
    "cromoplastas": "cromoplasta",
    "cromoplastídios": "cromoplastídio",
    "cromos": "cromo",
    "cromosferas": "cromosfera",
    "cromosférica": "cromosférico",
    "cromosféricas": "cromosférico",
    "cromosféricos": "cromosférico",
    "cromossomas": "cromossoma",
    "cromossomopatias": "cromossomopatia",
    "cromossomos": "cromossomo",
    "cromossomática": "cromossomático",
    "cromossomáticas": "cromossomático",
    "cromossomáticos": "cromossomático",
    "cromossómica": "cromossómico",
    "cromossómicas": "cromossómico",
    "cromossómicos": "cromossómico",
    "cromoterapeutas": "cromoterapeuta",
    "cromoterapias": "cromoterapia",
    "cromoterapistas": "cromoterapista",
    "cromoterapêutica": "cromoterapêutico",
    "cromoterapêuticas": "cromoterapêutico",
    "cromoterapêuticos": "cromoterapêutico",
    "cromoterápica": "cromoterápico",
    "cromoterápicas": "cromoterápico",
    "cromoterápicos": "cromoterápico",
    "cromotipias": "cromotipia",
    "cromotipografias": "cromotipografia",
    "cromotipográfica": "cromotipográfico",
    "cromotipográficas": "cromotipográfico",
    "cromotipográficos": "cromotipográfico",
    "cromotográfica": "cromotográfico",
    "cromotográficas": "cromotográfico",
    "cromotográficos": "cromotográfico",
    "cromotípica": "cromotípico",
    "cromotípicas": "cromotípico",
    "cromotípicos": "cromotípico",
    "cromou": "cromar",
    "cromá": "cromar",
    "cromámo": "cromar",
    "cromámos": "cromar",
    "cromáramo": "cromar",
    "cromáramos": "cromar",
    "cromárei": "cromar",
    "cromáreis": "cromar",
    "cromásseis": "cromar",
    "cromássemos": "cromar",
    "cromática": "cromático",
    "cromáticas": "cromático",
    "cromáticos": "cromático",
    "cromávamo": "cromar",
    "cromávamos": "cromar",
    "cromávei": "cromar",
    "cromáveis": "cromar",
    "cromídias": "cromídia",
    "cromídios": "cromídio",
    "cromófila": "cromófilo",
    "cromófilas": "cromófilo",
    "cromófilos": "cromófilo",
    "cromófoba": "cromófobo",
    "cromófobas": "cromófobo",
    "cromófobos": "cromófobo",
    "cromófora": "cromóforo",
    "cromóforas": "cromóforo",
    "cromóforos": "cromóforo",
    "cromómeros": "cromómero",
    "cronhadas": "cronhada",
    "cronhas": "cronha",
    "cronica": "cronicar",
    "cronicada": "cronicar",
    "cronicadas": "cronicar",
    "cronicado": "cronicar",
    "cronicados": "cronicar",
    "cronicai": "cronicar",
    "cronicais": "cronicar",
    "cronicam": "cronicar",
    "cronicamo": "cronicar",
    "cronicamos": "cronicar",
    "cronicando": "cronicar",
    "cronicara": "cronicar",
    "cronicaram": "cronicar",
    "cronicaras": "cronicar",
    "cronicarde": "cronicar",
    "cronicardes": "cronicar",
    "cronicare": "cronicar",
    "cronicarei": "cronicar",
    "cronicareis": "cronicar",
    "cronicarem": "cronicar",
    "cronicaremos": "cronicar",
    "cronicares": "cronicar",
    "cronicaria": "cronicar",
    "cronicariam": "cronicar",
    "cronicarias": "cronicar",
    "cronicarmo": "cronicar",
    "cronicarmos": "cronicar",
    "cronicará": "cronicar",
    "cronicarás": "cronicar",
    "cronicarão": "cronicar",
    "cronicaríamos": "cronicar",
    "cronicaríeis": "cronicar",
    "cronicas": "cronicar",
    "cronicasse": "cronicar",
    "cronicassem": "cronicar",
    "cronicasses": "cronicar",
    "cronicaste": "cronicar",
    "cronicastes": "cronicar",
    "cronicava": "cronicar",
    "cronicavam": "cronicar",
    "cronicavas": "cronicar",
    "cronicidades": "cronicidade",
    "cronico": "cronicar",
    "cronicou": "cronicar",
    "cronicá": "cronicar",
    "cronicámo": "cronicar",
    "cronicámos": "cronicar",
    "cronicáramo": "cronicar",
    "cronicáramos": "cronicar",
    "cronicárei": "cronicar",
    "cronicáreis": "cronicar",
    "cronicásseis": "cronicar",
    "cronicássemos": "cronicar",
    "cronicávamo": "cronicar",
    "cronicávamos": "cronicar",
    "cronicávei": "cronicar",
    "cronicáveis": "cronicar",
    "cronicões": "cronicão",
    "cronique": "cronicar",
    "croniquei": "cronicar",
    "croniqueira": "croniqueiro",
    "croniqueiras": "croniqueiro",
    "croniqueiros": "croniqueiro",
    "croniqueis": "cronicar",
    "croniquem": "cronicar",
    "croniquemo": "cronicar",
    "croniquemos": "cronicar",
    "croniques": "cronicar",
    "croniquiza": "croniquizar",
    "croniquizada": "croniquizar",
    "croniquizadas": "croniquizar",
    "croniquizado": "croniquizar",
    "croniquizados": "croniquizar",
    "croniquizai": "croniquizar",
    "croniquizais": "croniquizar",
    "croniquizam": "croniquizar",
    "croniquizamo": "croniquizar",
    "croniquizamos": "croniquizar",
    "croniquizando": "croniquizar",
    "croniquizara": "croniquizar",
    "croniquizaram": "croniquizar",
    "croniquizaras": "croniquizar",
    "croniquizarde": "croniquizar",
    "croniquizardes": "croniquizar",
    "croniquizare": "croniquizar",
    "croniquizarei": "croniquizar",
    "croniquizareis": "croniquizar",
    "croniquizarem": "croniquizar",
    "croniquizaremos": "croniquizar",
    "croniquizares": "croniquizar",
    "croniquizaria": "croniquizar",
    "croniquizariam": "croniquizar",
    "croniquizarias": "croniquizar",
    "croniquizarmo": "croniquizar",
    "croniquizarmos": "croniquizar",
    "croniquizará": "croniquizar",
    "croniquizarás": "croniquizar",
    "croniquizarão": "croniquizar",
    "croniquizaríamos": "croniquizar",
    "croniquizaríeis": "croniquizar",
    "croniquizas": "croniquizar",
    "croniquizasse": "croniquizar",
    "croniquizassem": "croniquizar",
    "croniquizasses": "croniquizar",
    "croniquizaste": "croniquizar",
    "croniquizastes": "croniquizar",
    "croniquizava": "croniquizar",
    "croniquizavam": "croniquizar",
    "croniquizavas": "croniquizar",
    "croniquize": "croniquizar",
    "croniquizei": "croniquizar",
    "croniquizeis": "croniquizar",
    "croniquizem": "croniquizar",
    "croniquizemo": "croniquizar",
    "croniquizemos": "croniquizar",
    "croniquizes": "croniquizar",
    "croniquizo": "croniquizar",
    "croniquizou": "croniquizar",
    "croniquizá": "croniquizar",
    "croniquizámo": "croniquizar",
    "croniquizámos": "croniquizar",
    "croniquizáramo": "croniquizar",
    "croniquizáramos": "croniquizar",
    "croniquizárei": "croniquizar",
    "croniquizáreis": "croniquizar",
    "croniquizásseis": "croniquizar",
    "croniquizássemos": "croniquizar",
    "croniquizávamo": "croniquizar",
    "croniquizávamos": "croniquizar",
    "croniquizávei": "croniquizar",
    "croniquizáveis": "croniquizar",
    "cronistas": "cronista",
    "cronografias": "cronografia",
    "cronogramas": "cronograma",
    "cronográfica": "cronográfico",
    "cronográficas": "cronográfico",
    "cronográficos": "cronográfico",
    "cronologias": "cronologia",
    "cronologistas": "cronologista",
    "cronológica": "cronológico",
    "cronológicas": "cronológico",
    "cronológicos": "cronológico",
    "cronometra": "cronometrar",
    "cronometrada": "cronometrar",
    "cronometradas": "cronometrar",
    "cronometrado": "cronometrar",
    "cronometrados": "cronometrar",
    "cronometragens": "cronometragem",
    "cronometrai": "cronometrar",
    "cronometrais": "cronometrar",
    "cronometram": "cronometrar",
    "cronometramo": "cronometrar",
    "cronometramos": "cronometrar",
    "cronometrando": "cronometrar",
    "cronometrara": "cronometrar",
    "cronometraram": "cronometrar",
    "cronometraras": "cronometrar",
    "cronometrarde": "cronometrar",
    "cronometrardes": "cronometrar",
    "cronometrare": "cronometrar",
    "cronometrarei": "cronometrar",
    "cronometrareis": "cronometrar",
    "cronometrarem": "cronometrar",
    "cronometraremos": "cronometrar",
    "cronometrares": "cronometrar",
    "cronometraria": "cronometrar",
    "cronometrariam": "cronometrar",
    "cronometrarias": "cronometrar",
    "cronometrarmo": "cronometrar",
    "cronometrarmos": "cronometrar",
    "cronometrará": "cronometrar",
    "cronometrarás": "cronometrar",
    "cronometrarão": "cronometrar",
    "cronometraríamos": "cronometrar",
    "cronometraríeis": "cronometrar",
    "cronometras": "cronometrar",
    "cronometrasse": "cronometrar",
    "cronometrassem": "cronometrar",
    "cronometrasses": "cronometrar",
    "cronometraste": "cronometrar",
    "cronometrastes": "cronometrar",
    "cronometrava": "cronometrar",
    "cronometravam": "cronometrar",
    "cronometravas": "cronometrar",
    "cronometre": "cronometrar",
    "cronometrei": "cronometrar",
    "cronometreis": "cronometrar",
    "cronometrem": "cronometrar",
    "cronometremo": "cronometrar",
    "cronometremos": "cronometrar",
    "cronometres": "cronometrar",
    "cronometrias": "cronometria",
    "cronometristas": "cronometrista",
    "cronometro": "cronometrar",
    "cronometrou": "cronometrar",
    "cronometrá": "cronometrar",
    "cronometrámo": "cronometrar",
    "cronometrámos": "cronometrar",
    "cronometráramo": "cronometrar",
    "cronometráramos": "cronometrar",
    "cronometrárei": "cronometrar",
    "cronometráreis": "cronometrar",
    "cronometrásseis": "cronometrar",
    "cronometrássemos": "cronometrar",
    "cronometrávamo": "cronometrar",
    "cronometrávamos": "cronometrar",
    "cronometrávei": "cronometrar",
    "cronometráveis": "cronometrar",
    "cronométrica": "cronométrico",
    "cronométricas": "cronométrico",
    "cronométricos": "cronométrico",
    "crononímias": "crononímia",
    "crononímica": "crononímico",
    "crononímicas": "crononímico",
    "crononímicos": "crononímico",
    "cronoscópica": "cronoscópico",
    "cronoscópicas": "cronoscópico",
    "cronoscópicos": "cronoscópico",
    "cronoscópios": "cronoscópio",
    "cronotrões": "cronotrão",
    "cronógrafos": "cronógrafo",
    "cronóloga": "cronólogo",
    "cronólogas": "cronólogo",
    "cronólogos": "cronólogo",
    "cronómetros": "cronómetro",
    "cronónimos": "cronónimo",
    "croques": "croque",
    "croquetes": "croquete",
    "crostas": "crosta",
    "crostos": "crosto",
    "crotalídea": "crotalídeo",
    "crotalídeas": "crotalídeo",
    "crotalídeos": "crotalídeo",
    "crotalóides": "crotalóide",
    "crotálidas": "crotálida",
    "croácia": "croácio",
    "croácias": "croácio",
    "croácios": "croácio",
    "croças": "croça",
    "crua": "cru",
    "cruas": "cru",
    "crucia": "cruciar",
    "cruciada": "cruciar",
    "cruciadas": "cruciar",
    "cruciado": "cruciar",
    "cruciadora": "cruciador",
    "cruciadoras": "cruciador",
    "cruciadores": "cruciador",
    "cruciados": "cruciar",
    "cruciai": "cruciar",
    "cruciais": "cruciar",
    "cruciam": "cruciar",
    "cruciamo": "cruciar",
    "cruciamos": "cruciar",
    "cruciando": "cruciar",
    "cruciantes": "cruciante",
    "cruciara": "cruciar",
    "cruciaram": "cruciar",
    "cruciaras": "cruciar",
    "cruciarde": "cruciar",
    "cruciardes": "cruciar",
    "cruciare": "cruciar",
    "cruciarei": "cruciar",
    "cruciareis": "cruciar",
    "cruciarem": "cruciar",
    "cruciaremos": "cruciar",
    "cruciares": "cruciar",
    "cruciaria": "cruciar",
    "cruciariam": "cruciar",
    "cruciarias": "cruciar",
    "cruciarmo": "cruciar",
    "cruciarmos": "cruciar",
    "cruciará": "cruciar",
    "cruciarás": "cruciar",
    "cruciarão": "cruciar",
    "cruciaríamos": "cruciar",
    "cruciaríeis": "cruciar",
    "crucias": "cruciar",
    "cruciasse": "cruciar",
    "cruciassem": "cruciar",
    "cruciasses": "cruciar",
    "cruciaste": "cruciar",
    "cruciastes": "cruciar",
    "cruciava": "cruciar",
    "cruciavam": "cruciar",
    "cruciavas": "cruciar",
    "cruciações": "cruciação",
    "crucie": "cruciar",
    "cruciei": "cruciar",
    "crucieis": "cruciar",
    "cruciem": "cruciar",
    "cruciemo": "cruciar",
    "cruciemos": "cruciar",
    "crucies": "cruciar",
    "cruciferária": "cruciferário",
    "cruciferárias": "cruciferário",
    "cruciferários": "cruciferário",
    "crucifica": "crucificar",
    "crucificada": "crucificar",
    "crucificadas": "crucificar",
    "crucificado": "crucificar",
    "crucificadora": "crucificador",
    "crucificadoras": "crucificador",
    "crucificadores": "crucificador",
    "crucificados": "crucificar",
    "crucificai": "crucificar",
    "crucificais": "crucificar",
    "crucificam": "crucificar",
    "crucificamo": "crucificar",
    "crucificamos": "crucificar",
    "crucificando": "crucificar",
    "crucificara": "crucificar",
    "crucificaram": "crucificar",
    "crucificaras": "crucificar",
    "crucificarde": "crucificar",
    "crucificardes": "crucificar",
    "crucificare": "crucificar",
    "crucificarei": "crucificar",
    "crucificareis": "crucificar",
    "crucificarem": "crucificar",
    "crucificaremos": "crucificar",
    "crucificares": "crucificar",
    "crucificaria": "crucificar",
    "crucificariam": "crucificar",
    "crucificarias": "crucificar",
    "crucificarmo": "crucificar",
    "crucificarmos": "crucificar",
    "crucificará": "crucificar",
    "crucificarás": "crucificar",
    "crucificarão": "crucificar",
    "crucificaríamos": "crucificar",
    "crucificaríeis": "crucificar",
    "crucificas": "crucificar",
    "crucificasse": "crucificar",
    "crucificassem": "crucificar",
    "crucificasses": "crucificar",
    "crucificaste": "crucificar",
    "crucificastes": "crucificar",
    "crucificava": "crucificar",
    "crucificavam": "crucificar",
    "crucificavas": "crucificar",
    "crucificações": "crucificação",
    "crucifico": "crucificar",
    "crucificou": "crucificar",
    "crucificá": "crucificar",
    "crucificámo": "crucificar",
    "crucificámos": "crucificar",
    "crucificáramo": "crucificar",
    "crucificáramos": "crucificar",
    "crucificárei": "crucificar",
    "crucificáreis": "crucificar",
    "crucificásseis": "crucificar",
    "crucificássemos": "crucificar",
    "crucificávamo": "crucificar",
    "crucificávamos": "crucificar",
    "crucificávei": "crucificar",
    "crucificáveis": "crucificar",
    "crucifique": "crucificar",
    "crucifiquei": "crucificar",
    "crucifiqueis": "crucificar",
    "crucifiquem": "crucificar",
    "crucifiquemo": "crucificar",
    "crucifiquemos": "crucificar",
    "crucifiques": "crucificar",
    "crucifixos": "crucifixo",
    "crucifixões": "crucifixão",
    "cruciformes": "cruciforme",
    "crucigia": "crucigiar",
    "crucigiada": "crucigiar",
    "crucigiadas": "crucigiar",
    "crucigiado": "crucigiar",
    "crucigiados": "crucigiar",
    "crucigiai": "crucigiar",
    "crucigiais": "crucigiar",
    "crucigiam": "crucigiar",
    "crucigiamo": "crucigiar",
    "crucigiamos": "crucigiar",
    "crucigiando": "crucigiar",
    "crucigiara": "crucigiar",
    "crucigiaram": "crucigiar",
    "crucigiaras": "crucigiar",
    "crucigiarde": "crucigiar",
    "crucigiardes": "crucigiar",
    "crucigiare": "crucigiar",
    "crucigiarei": "crucigiar",
    "crucigiareis": "crucigiar",
    "crucigiarem": "crucigiar",
    "crucigiaremos": "crucigiar",
    "crucigiares": "crucigiar",
    "crucigiaria": "crucigiar",
    "crucigiariam": "crucigiar",
    "crucigiarias": "crucigiar",
    "crucigiarmo": "crucigiar",
    "crucigiarmos": "crucigiar",
    "crucigiará": "crucigiar",
    "crucigiarás": "crucigiar",
    "crucigiarão": "crucigiar",
    "crucigiaríamos": "crucigiar",
    "crucigiaríeis": "crucigiar",
    "crucigias": "crucigiar",
    "crucigiasse": "crucigiar",
    "crucigiassem": "crucigiar",
    "crucigiasses": "crucigiar",
    "crucigiaste": "crucigiar",
    "crucigiastes": "crucigiar",
    "crucigiava": "crucigiar",
    "crucigiavam": "crucigiar",
    "crucigiavas": "crucigiar",
    "crucigie": "crucigiar",
    "crucigiei": "crucigiar",
    "crucigieis": "crucigiar",
    "crucigiem": "crucigiar",
    "crucigiemo": "crucigiar",
    "crucigiemos": "crucigiar",
    "crucigies": "crucigiar",
    "crucigio": "crucigiar",
    "crucigiou": "crucigiar",
    "crucigiá": "crucigiar",
    "crucigiámo": "crucigiar",
    "crucigiámos": "crucigiar",
    "crucigiáramo": "crucigiar",
    "crucigiáramos": "crucigiar",
    "crucigiárei": "crucigiar",
    "crucigiáreis": "crucigiar",
    "crucigiásseis": "crucigiar",
    "crucigiássemos": "crucigiar",
    "crucigiávamo": "crucigiar",
    "crucigiávamos": "crucigiar",
    "crucigiávei": "crucigiar",
    "crucigiáveis": "crucigiar",
    "crucio": "cruciar",
    "cruciou": "cruciar",
    "crucirrostra": "crucirrostro",
    "crucirrostras": "crucirrostro",
    "crucirrostros": "crucirrostro",
    "cruciá": "cruciar",
    "cruciámo": "cruciar",
    "cruciámos": "cruciar",
    "cruciáramo": "cruciar",
    "cruciáramos": "cruciar",
    "cruciárei": "cruciar",
    "cruciáreis": "cruciar",
    "cruciária": "cruciário",
    "cruciárias": "cruciário",
    "cruciários": "cruciário",
    "cruciásseis": "cruciar",
    "cruciássemos": "cruciar",
    "cruciávamo": "cruciar",
    "cruciávamos": "cruciar",
    "cruciávei": "cruciar",
    "cruciáveis": "cruciar",
    "crucífera": "crucífero",
    "crucíferas": "crucífero",
    "crucíferos": "crucífero",
    "crucígera": "crucígero",
    "crucígeras": "crucígero",
    "crucígeros": "crucígero",
    "crudelíssima": "cruel",
    "crudelíssimas": "cruel",
    "crudelíssimo": "cruel",
    "crudelíssimos": "cruel",
    "crudes": "crude",
    "crudivoristas": "crudivorista",
    "crudívora": "crudívoro",
    "crudívoras": "crudívoro",
    "crudívoros": "crudívoro",
    "crueiras": "crueira",
    "crueldades": "crueldade",
    "cruenta": "cruentar",
    "cruentada": "cruentar",
    "cruentadas": "cruentar",
    "cruentado": "cruentar",
    "cruentados": "cruentar",
    "cruentai": "cruentar",
    "cruentais": "cruentar",
    "cruentam": "cruentar",
    "cruentamo": "cruentar",
    "cruentamos": "cruentar",
    "cruentando": "cruentar",
    "cruentara": "cruentar",
    "cruentaram": "cruentar",
    "cruentaras": "cruentar",
    "cruentarde": "cruentar",
    "cruentardes": "cruentar",
    "cruentare": "cruentar",
    "cruentarei": "cruentar",
    "cruentareis": "cruentar",
    "cruentarem": "cruentar",
    "cruentaremos": "cruentar",
    "cruentares": "cruentar",
    "cruentaria": "cruentar",
    "cruentariam": "cruentar",
    "cruentarias": "cruentar",
    "cruentarmo": "cruentar",
    "cruentarmos": "cruentar",
    "cruentará": "cruentar",
    "cruentarás": "cruentar",
    "cruentarão": "cruentar",
    "cruentaríamos": "cruentar",
    "cruentaríeis": "cruentar",
    "cruentas": "cruentar",
    "cruentasse": "cruentar",
    "cruentassem": "cruentar",
    "cruentasses": "cruentar",
    "cruentaste": "cruentar",
    "cruentastes": "cruentar",
    "cruentava": "cruentar",
    "cruentavam": "cruentar",
    "cruentavas": "cruentar",
    "cruentações": "cruentação",
    "cruente": "cruentar",
    "cruentei": "cruentar",
    "cruenteis": "cruentar",
    "cruentem": "cruentar",
    "cruentemo": "cruentar",
    "cruentemos": "cruentar",
    "cruentes": "cruentar",
    "cruento": "cruentar",
    "cruentou": "cruentar",
    "cruentá": "cruentar",
    "cruentámo": "cruentar",
    "cruentámos": "cruentar",
    "cruentáramo": "cruentar",
    "cruentáramos": "cruentar",
    "cruentárei": "cruentar",
    "cruentáreis": "cruentar",
    "cruentásseis": "cruentar",
    "cruentássemos": "cruentar",
    "cruentávamo": "cruentar",
    "cruentávamos": "cruentar",
    "cruentávei": "cruentar",
    "cruentáveis": "cruentar",
    "cruezas": "crueza",
    "cruores": "cruor",
    "cruorinas": "cruorina",
    "crupes": "crupe",
    "crupiões": "crupião",
    "crurais": "crural",
    "crurenta": "crurento",
    "crurentas": "crurento",
    "crurentos": "crurento",
    "crurifrágios": "crurifrágio",
    "crus": "cru",
    "crustaceologias": "crustaceologia",
    "crustaceológica": "crustaceológico",
    "crustaceológicas": "crustaceológico",
    "crustaceológicos": "crustaceológico",
    "crustaceóloga": "crustaceólogo",
    "crustaceólogas": "crustaceólogo",
    "crustaceólogos": "crustaceólogo",
    "crustaciologistas": "crustaciologista",
    "crustas": "crusta",
    "crustácea": "crustáceo",
    "crustáceas": "crustáceo",
    "crustáceos": "crustáceo",
    "cruza": "cruzar",
    "cruzada": "cruzar",
    "cruzadas": "cruzar",
    "cruzado": "cruzar",
    "cruzadora": "cruzador",
    "cruzadoras": "cruzador",
    "cruzadores": "cruzador",
    "cruzados": "cruzar",
    "cruzai": "cruzar",
    "cruzais": "cruzar",
    "cruzam": "cruzar",
    "cruzamentos": "cruzamento",
    "cruzamo": "cruzar",
    "cruzamos": "cruzar",
    "cruzando": "cruzar",
    "cruzantes": "cruzante",
    "cruzara": "cruzar",
    "cruzaram": "cruzar",
    "cruzaras": "cruzar",
    "cruzarde": "cruzar",
    "cruzardes": "cruzar",
    "cruzare": "cruzar",
    "cruzarei": "cruzar",
    "cruzareis": "cruzar",
    "cruzarem": "cruzar",
    "cruzaremos": "cruzar",
    "cruzares": "cruzar",
    "cruzaria": "cruzar",
    "cruzariam": "cruzar",
    "cruzarias": "cruzar",
    "cruzarmo": "cruzar",
    "cruzarmos": "cruzar",
    "cruzará": "cruzar",
    "cruzarás": "cruzar",
    "cruzarão": "cruzar",
    "cruzaríamos": "cruzar",
    "cruzaríeis": "cruzar",
    "cruzas": "cruzar",
    "cruzasse": "cruzar",
    "cruzassem": "cruzar",
    "cruzasses": "cruzar",
    "cruzaste": "cruzar",
    "cruzastes": "cruzar",
    "cruzava": "cruzar",
    "cruzavam": "cruzar",
    "cruzavas": "cruzar",
    "cruze": "cruzar",
    "cruzei": "cruzar",
    "cruzeira": "cruzeiro",
    "cruzeiras": "cruzeiro",
    "cruzeiros": "cruzeiro",
    "cruzeis": "cruzar",
    "cruzem": "cruzar",
    "cruzemo": "cruzar",
    "cruzemos": "cruzar",
    "cruzes": "cruzar",
    "cruzetada": "cruzetado",
    "cruzetadas": "cruzetado",
    "cruzetados": "cruzetado",
    "cruzetas": "cruzeta",
    "cruzinha": "cruz",
    "cruzinhas": "cruz",
    "cruzita": "cruz",
    "cruzitas": "cruz",
    "cruzo": "cruzar",
    "cruzou": "cruzar",
    "cruzá": "cruzar",
    "cruzámo": "cruzar",
    "cruzámos": "cruzar",
    "cruzáramo": "cruzar",
    "cruzáramos": "cruzar",
    "cruzárei": "cruzar",
    "cruzáreis": "cruzar",
    "cruzásseis": "cruzar",
    "cruzássemos": "cruzar",
    "cruzávamo": "cruzar",
    "cruzávamos": "cruzar",
    "cruzávei": "cruzar",
    "cruzáveis": "cruzável",
    "cruéis": "cruel",
    "crápulas": "crápula",
    "crásica": "crásico",
    "crásicas": "crásico",
    "crásicos": "crásico",
    "crástica": "crástico",
    "crásticas": "crástico",
    "crásticos": "crástico",
    "crânios": "crânio",
    "créditos": "crédito",
    "crédula": "crédulo",
    "crédulas": "crédulo",
    "crédulos": "crédulo",
    "crépida": "crépido",
    "crépidas": "crépido",
    "crépidos": "crépido",
    "crés": "cré",
    "créscimos": "créscimo",
    "crética": "crético",
    "créticas": "crético",
    "créticos": "crético",
    "crê": "crer",
    "crêem": "crer",
    "crêramo": "crer",
    "crêramos": "crer",
    "crêrei": "crer",
    "crêreis": "crer",
    "crês": "crer",
    "crêsseis": "crer",
    "crêssemos": "crer",
    "críamo": "crer",
    "críamos": "crer",
    "críei": "crer",
    "críeis": "crer",
    "críptica": "críptico",
    "crípticas": "críptico",
    "crípticos": "críptico",
    "críquetes": "críquete",
    "crística": "crístico",
    "crísticas": "crístico",
    "crísticos": "crístico",
    "crítica": "crítico",
    "críticas": "crítico",
    "críticos": "crítico",
    "críveis": "crível",
    "crócea": "cróceo",
    "cróceas": "cróceo",
    "cróceos": "cróceo",
    "crócida": "crócido",
    "crócidas": "crócido",
    "crócidos": "crócido",
    "crómica": "crómico",
    "crómicas": "crómico",
    "crómicos": "crómico",
    "crómios": "crómio",
    "crónica": "crónico",
    "crónicas": "crónico",
    "crónicos": "crónico",
    "crós": "cró",
    "crótalos": "crótalo",
    "crúzia": "crúzio",
    "crúzias": "crúzio",
    "crúzios": "crúzio",
    "ctenodontes": "ctenodonte",
    "ctenócera": "ctenócero",
    "ctenóceras": "ctenócero",
    "ctenóceros": "ctenócero",
    "ctenófora": "ctenóforo",
    "ctenóforas": "ctenóforo",
    "ctenóforos": "ctenóforo",
    "cténófora": "cténóforo",
    "cténóforas": "cténóforo",
    "cténóforos": "cténóforo",
    "ctónia": "ctónio",
    "ctónias": "ctónio",
    "ctónica": "ctónico",
    "ctónicas": "ctónico",
    "ctónicos": "ctónico",
    "ctónios": "ctónio",
    "cuadas": "cuada",
    "cuamatas": "cuamata",
    "cuanhamas": "cuanhama",
    "cuapadas": "cuapada",
    "cuba": "cubar",
    "cubada": "cubar",
    "cubadas": "cubar",
    "cubado": "cubar",
    "cubados": "cubar",
    "cubagens": "cubagem",
    "cubai": "cubar",
    "cubais": "cubar",
    "cubam": "cubar",
    "cubamo": "cubar",
    "cubamos": "cubar",
    "cubana": "cubano",
    "cubanas": "cubano",
    "cubando": "cubar",
    "cubanos": "cubano",
    "cubara": "cubar",
    "cubaram": "cubar",
    "cubaras": "cubar",
    "cubarde": "cubar",
    "cubardes": "cubar",
    "cubare": "cubar",
    "cubarei": "cubar",
    "cubareis": "cubar",
    "cubarem": "cubar",
    "cubaremos": "cubar",
    "cubares": "cubar",
    "cubaria": "cubar",
    "cubariam": "cubar",
    "cubarias": "cubar",
    "cubarmo": "cubar",
    "cubarmos": "cubar",
    "cubará": "cubar",
    "cubarás": "cubar",
    "cubarão": "cubar",
    "cubaríamos": "cubar",
    "cubaríeis": "cubar",
    "cubas": "cubar",
    "cubasse": "cubar",
    "cubassem": "cubar",
    "cubasses": "cubar",
    "cubaste": "cubar",
    "cubastes": "cubar",
    "cubatas": "cubata",
    "cubaturas": "cubatura",
    "cubava": "cubar",
    "cubavam": "cubar",
    "cubavas": "cubar",
    "cube": "cubar",
    "cubebas": "cubeba",
    "cubebeiras": "cubebeira",
    "cubei": "cubar",
    "cubeis": "cubar",
    "cubelos": "cubelo",
    "cubem": "cubar",
    "cubemo": "cubar",
    "cubemos": "cubar",
    "cubes": "cubar",
    "cubica": "cubicar",
    "cubicada": "cubicar",
    "cubicadas": "cubicar",
    "cubicado": "cubicar",
    "cubicados": "cubicar",
    "cubicagens": "cubicagem",
    "cubicai": "cubicar",
    "cubicais": "cubicar",
    "cubicam": "cubicar",
    "cubicamo": "cubicar",
    "cubicamos": "cubicar",
    "cubicando": "cubicar",
    "cubicara": "cubicar",
    "cubicaram": "cubicar",
    "cubicaras": "cubicar",
    "cubicarde": "cubicar",
    "cubicardes": "cubicar",
    "cubicare": "cubicar",
    "cubicarei": "cubicar",
    "cubicareis": "cubicar",
    "cubicarem": "cubicar",
    "cubicaremos": "cubicar",
    "cubicares": "cubicar",
    "cubicaria": "cubicar",
    "cubicariam": "cubicar",
    "cubicarias": "cubicar",
    "cubicarmo": "cubicar",
    "cubicarmos": "cubicar",
    "cubicará": "cubicar",
    "cubicarás": "cubicar",
    "cubicarão": "cubicar",
    "cubicaríamos": "cubicar",
    "cubicaríeis": "cubicar",
    "cubicas": "cubicar",
    "cubicasse": "cubicar",
    "cubicassem": "cubicar",
    "cubicasses": "cubicar",
    "cubicaste": "cubicar",
    "cubicastes": "cubicar",
    "cubicava": "cubicar",
    "cubicavam": "cubicar",
    "cubicavas": "cubicar",
    "cubico": "cubicar",
    "cubicou": "cubicar",
    "cubiculares": "cubicular",
    "cubiculários": "cubiculário",
    "cubicá": "cubicar",
    "cubicámo": "cubicar",
    "cubicámos": "cubicar",
    "cubicáramo": "cubicar",
    "cubicáramos": "cubicar",
    "cubicárei": "cubicar",
    "cubicáreis": "cubicar",
    "cubicásseis": "cubicar",
    "cubicássemos": "cubicar",
    "cubicávamo": "cubicar",
    "cubicávamos": "cubicar",
    "cubicávei": "cubicar",
    "cubicáveis": "cubicar",
    "cubiformes": "cubiforme",
    "cubique": "cubicar",
    "cubiquei": "cubicar",
    "cubiqueis": "cubicar",
    "cubiquem": "cubicar",
    "cubiquemo": "cubicar",
    "cubiquemos": "cubicar",
    "cubiques": "cubicar",
    "cubismos": "cubismo",
    "cubistas": "cubista",
    "cubitais": "cubital",
    "cubo": "cubar",
    "cubomancias": "cubomancia",
    "cubomanias": "cubomania",
    "cubomantes": "cubomante",
    "cubomaníaca": "cubomaníaco",
    "cubomaníacas": "cubomaníaco",
    "cubomaníacos": "cubomaníaco",
    "cubomântica": "cubomântico",
    "cubomânticas": "cubomântico",
    "cubomânticos": "cubomântico",
    "cubos": "cubo",
    "cubou": "cubar",
    "cubra": "cobrir",
    "cubrais": "cobrir",
    "cubram": "cobrir",
    "cubramo": "cobrir",
    "cubramos": "cobrir",
    "cubras": "cobrir",
    "cubro": "cobrir",
    "cubá": "cubar",
    "cubámo": "cubar",
    "cubámos": "cubar",
    "cubáramo": "cubar",
    "cubáramos": "cubar",
    "cubárei": "cubar",
    "cubáreis": "cubar",
    "cubásseis": "cubar",
    "cubássemos": "cubar",
    "cubávamo": "cubar",
    "cubávamos": "cubar",
    "cubávei": "cubar",
    "cubáveis": "cubar",
    "cubículos": "cubículo",
    "cubóides": "cubóide",
    "cuca": "cucar",
    "cucada": "cucar",
    "cucadas": "cucar",
    "cucado": "cucar",
    "cucados": "cucar",
    "cucai": "cucar",
    "cucais": "cucar",
    "cucam": "cucar",
    "cucamo": "cucar",
    "cucamos": "cucar",
    "cucando": "cucar",
    "cucara": "cucar",
    "cucaram": "cucar",
    "cucaras": "cucar",
    "cucarde": "cucar",
    "cucardes": "cucar",
    "cucare": "cucar",
    "cucarei": "cucar",
    "cucareis": "cucar",
    "cucarem": "cucar",
    "cucaremos": "cucar",
    "cucares": "cucar",
    "cucaria": "cucar",
    "cucariam": "cucar",
    "cucarias": "cucar",
    "cucarmo": "cucar",
    "cucarmos": "cucar",
    "cucará": "cucar",
    "cucarás": "cucar",
    "cucarão": "cucar",
    "cucaríamos": "cucar",
    "cucaríeis": "cucar",
    "cucas": "cucar",
    "cucasse": "cucar",
    "cucassem": "cucar",
    "cucasses": "cucar",
    "cucaste": "cucar",
    "cucastes": "cucar",
    "cucava": "cucar",
    "cucavam": "cucar",
    "cucavas": "cucar",
    "cucharras": "cucharra",
    "cuches": "cuche",
    "cuchilhas": "cuchilha",
    "cuchilhos": "cuchilho",
    "cucis": "cuci",
    "cucióferas": "cuciófera",
    "cuco": "cucar",
    "cucos": "cuco",
    "cucou": "cucar",
    "cuculifólia": "cuculifólio",
    "cuculifólias": "cuculifólio",
    "cuculifólios": "cuculifólio",
    "cuculos": "cuculo",
    "cuculídea": "cuculídeo",
    "cuculídeas": "cuculídeo",
    "cuculídeos": "cuculídeo",
    "cuculífera": "cuculífero",
    "cuculíferas": "cuculífero",
    "cuculíferos": "cuculífero",
    "cucumbelas": "cucumbela",
    "cucumbitáceas": "cucumbitácea",
    "cucumiformes": "cucumiforme",
    "cucurbita": "cucurbitar",
    "cucurbitada": "cucurbitar",
    "cucurbitadas": "cucurbitar",
    "cucurbitado": "cucurbitar",
    "cucurbitados": "cucurbitar",
    "cucurbitai": "cucurbitar",
    "cucurbitais": "cucurbitar",
    "cucurbitam": "cucurbitar",
    "cucurbitamo": "cucurbitar",
    "cucurbitamos": "cucurbitar",
    "cucurbitando": "cucurbitar",
    "cucurbitara": "cucurbitar",
    "cucurbitaram": "cucurbitar",
    "cucurbitaras": "cucurbitar",
    "cucurbitardes": "cucurbitar",
    "cucurbitarei": "cucurbitar",
    "cucurbitareis": "cucurbitar",
    "cucurbitarem": "cucurbitar",
    "cucurbitaremos": "cucurbitar",
    "cucurbitares": "cucurbitar",
    "cucurbitaria": "cucurbitar",
    "cucurbitariam": "cucurbitar",
    "cucurbitarias": "cucurbitar",
    "cucurbitarmo": "cucurbitar",
    "cucurbitarmos": "cucurbitar",
    "cucurbitará": "cucurbitar",
    "cucurbitarás": "cucurbitar",
    "cucurbitarão": "cucurbitar",
    "cucurbitaríamos": "cucurbitar",
    "cucurbitaríeis": "cucurbitar",
    "cucurbitas": "cucurbitar",
    "cucurbitasse": "cucurbitar",
    "cucurbitassem": "cucurbitar",
    "cucurbitasses": "cucurbitar",
    "cucurbitaste": "cucurbitar",
    "cucurbitastes": "cucurbitar",
    "cucurbitava": "cucurbitar",
    "cucurbitavam": "cucurbitar",
    "cucurbitavas": "cucurbitar",
    "cucurbite": "cucurbitar",
    "cucurbitei": "cucurbitar",
    "cucurbiteis": "cucurbitar",
    "cucurbitem": "cucurbitar",
    "cucurbitemo": "cucurbitar",
    "cucurbitemos": "cucurbitar",
    "cucurbites": "cucurbitar",
    "cucurbitina": "cucurbitino",
    "cucurbitinas": "cucurbitino",
    "cucurbitinos": "cucurbitino",
    "cucurbito": "cucurbitar",
    "cucurbitou": "cucurbitar",
    "cucurbitácea": "cucurbitáceo",
    "cucurbitáceas": "cucurbitáceo",
    "cucurbitáceos": "cucurbitáceo",
    "cucurbitámo": "cucurbitar",
    "cucurbitámos": "cucurbitar",
    "cucurbitáramo": "cucurbitar",
    "cucurbitáramos": "cucurbitar",
    "cucurbitáreis": "cucurbitar",
    "cucurbitásseis": "cucurbitar",
    "cucurbitássemos": "cucurbitar",
    "cucurbitávamo": "cucurbitar",
    "cucurbitávamos": "cucurbitar",
    "cucurbitáveis": "cucurbitar",
    "cucurica": "cucuricar",
    "cucuricada": "cucuricar",
    "cucuricadas": "cucuricar",
    "cucuricado": "cucuricar",
    "cucuricados": "cucuricar",
    "cucuricais": "cucuricar",
    "cucuricam": "cucuricar",
    "cucuricamo": "cucuricar",
    "cucuricamos": "cucuricar",
    "cucuricando": "cucuricar",
    "cucuricara": "cucuricar",
    "cucuricaram": "cucuricar",
    "cucuricaras": "cucuricar",
    "cucuricardes": "cucuricar",
    "cucuricarei": "cucuricar",
    "cucuricareis": "cucuricar",
    "cucuricarem": "cucuricar",
    "cucuricaremos": "cucuricar",
    "cucuricares": "cucuricar",
    "cucuricaria": "cucuricar",
    "cucuricariam": "cucuricar",
    "cucuricarias": "cucuricar",
    "cucuricarmo": "cucuricar",
    "cucuricarmos": "cucuricar",
    "cucuricará": "cucuricar",
    "cucuricarás": "cucuricar",
    "cucuricarão": "cucuricar",
    "cucuricaríamos": "cucuricar",
    "cucuricaríeis": "cucuricar",
    "cucuricas": "cucuricar",
    "cucuricasse": "cucuricar",
    "cucuricassem": "cucuricar",
    "cucuricasses": "cucuricar",
    "cucuricaste": "cucuricar",
    "cucuricastes": "cucuricar",
    "cucuricava": "cucuricar",
    "cucuricavam": "cucuricar",
    "cucuricavas": "cucuricar",
    "cucurico": "cucuricar",
    "cucuricou": "cucuricar",
    "cucuricámo": "cucuricar",
    "cucuricámos": "cucuricar",
    "cucuricáramo": "cucuricar",
    "cucuricáramos": "cucuricar",
    "cucuricáreis": "cucuricar",
    "cucuricásseis": "cucuricar",
    "cucuricássemos": "cucuricar",
    "cucuricávamo": "cucuricar",
    "cucuricávamos": "cucuricar",
    "cucuricáveis": "cucuricar",
    "cucurique": "cucuricar",
    "cucuriquei": "cucuricar",
    "cucuriqueis": "cucuricar",
    "cucuriquem": "cucuricar",
    "cucuriquemos": "cucuricar",
    "cucuriques": "cucuricar",
    "cucá": "cucar",
    "cucámo": "cucar",
    "cucámos": "cucar",
    "cucáramo": "cucar",
    "cucáramos": "cucar",
    "cucárei": "cucar",
    "cucáreis": "cucar",
    "cucásseis": "cucar",
    "cucássemos": "cucar",
    "cucávamo": "cucar",
    "cucávamos": "cucar",
    "cucávei": "cucar",
    "cucáveis": "cucar",
    "cucúlidas": "cucúlida",
    "cucúmbitas": "cucúmbita",
    "cuecas": "cueca",
    "cueiros": "cueiro",
    "cuiadas": "cuiada",
    "cuiadeira": "cuiadeiro",
    "cuiadeiras": "cuiadeiro",
    "cuiadeiros": "cuiadeiro",
    "cuias": "cuia",
    "cuida": "cuidar",
    "cuidada": "cuidar",
    "cuidadas": "cuidar",
    "cuidado": "cuidar",
    "cuidadora": "cuidador",
    "cuidadoras": "cuidador",
    "cuidadores": "cuidador",
    "cuidados": "cuidar",
    "cuidadosa": "cuidadoso",
    "cuidadosas": "cuidadoso",
    "cuidadosos": "cuidadoso",
    "cuidadíssima": "cuidado",
    "cuidadíssimas": "cuidado",
    "cuidadíssimo": "cuidado",
    "cuidadíssimos": "cuidado",
    "cuidai": "cuidar",
    "cuidais": "cuidar",
    "cuidam": "cuidar",
    "cuidamo": "cuidar",
    "cuidamos": "cuidar",
    "cuidando": "cuidar",
    "cuidara": "cuidar",
    "cuidaram": "cuidar",
    "cuidaras": "cuidar",
    "cuidarde": "cuidar",
    "cuidardes": "cuidar",
    "cuidare": "cuidar",
    "cuidarei": "cuidar",
    "cuidareis": "cuidar",
    "cuidarem": "cuidar",
    "cuidaremos": "cuidar",
    "cuidares": "cuidar",
    "cuidaria": "cuidar",
    "cuidariam": "cuidar",
    "cuidarias": "cuidar",
    "cuidarmo": "cuidar",
    "cuidarmos": "cuidar",
    "cuidará": "cuidar",
    "cuidarás": "cuidar",
    "cuidarão": "cuidar",
    "cuidaríamos": "cuidar",
    "cuidaríeis": "cuidar",
    "cuidas": "cuidar",
    "cuidasse": "cuidar",
    "cuidassem": "cuidar",
    "cuidasses": "cuidar",
    "cuidaste": "cuidar",
    "cuidastes": "cuidar",
    "cuidava": "cuidar",
    "cuidavam": "cuidar",
    "cuidavas": "cuidar",
    "cuide": "cuidar",
    "cuidei": "cuidar",
    "cuideis": "cuidar",
    "cuidem": "cuidar",
    "cuidemo": "cuidar",
    "cuidemos": "cuidar",
    "cuides": "cuidar",
    "cuido": "cuidar",
    "cuidosa": "cuidoso",
    "cuidosas": "cuidoso",
    "cuidosos": "cuidoso",
    "cuidou": "cuidar",
    "cuidá": "cuidar",
    "cuidámo": "cuidar",
    "cuidámos": "cuidar",
    "cuidáramo": "cuidar",
    "cuidáramos": "cuidar",
    "cuidárei": "cuidar",
    "cuidáreis": "cuidar",
    "cuidásseis": "cuidar",
    "cuidássemos": "cuidar",
    "cuidávamo": "cuidar",
    "cuidávamos": "cuidar",
    "cuidávei": "cuidar",
    "cuidáveis": "cuidar",
    "cuieiras": "cuieira",
    "cuinca": "cuincar",
    "cuincada": "cuincar",
    "cuincadas": "cuincar",
    "cuincado": "cuincar",
    "cuincados": "cuincar",
    "cuincai": "cuincar",
    "cuincais": "cuincar",
    "cuincam": "cuincar",
    "cuincamo": "cuincar",
    "cuincamos": "cuincar",
    "cuincando": "cuincar",
    "cuincara": "cuincar",
    "cuincaram": "cuincar",
    "cuincaras": "cuincar",
    "cuincarde": "cuincar",
    "cuincardes": "cuincar",
    "cuincare": "cuincar",
    "cuincarei": "cuincar",
    "cuincareis": "cuincar",
    "cuincarem": "cuincar",
    "cuincaremos": "cuincar",
    "cuincares": "cuincar",
    "cuincaria": "cuincar",
    "cuincariam": "cuincar",
    "cuincarias": "cuincar",
    "cuincarmo": "cuincar",
    "cuincarmos": "cuincar",
    "cuincará": "cuincar",
    "cuincarás": "cuincar",
    "cuincarão": "cuincar",
    "cuincaríamos": "cuincar",
    "cuincaríeis": "cuincar",
    "cuincas": "cuincar",
    "cuincasse": "cuincar",
    "cuincassem": "cuincar",
    "cuincasses": "cuincar",
    "cuincaste": "cuincar",
    "cuincastes": "cuincar",
    "cuincava": "cuincar",
    "cuincavam": "cuincar",
    "cuincavas": "cuincar",
    "cuincha": "cuinchar",
    "cuinchada": "cuinchar",
    "cuinchadas": "cuinchar",
    "cuinchado": "cuinchar",
    "cuinchados": "cuinchar",
    "cuinchai": "cuinchar",
    "cuinchais": "cuinchar",
    "cuincham": "cuinchar",
    "cuinchamo": "cuinchar",
    "cuinchamos": "cuinchar",
    "cuinchando": "cuinchar",
    "cuinchara": "cuinchar",
    "cuincharam": "cuinchar",
    "cuincharas": "cuinchar",
    "cuincharde": "cuinchar",
    "cuinchardes": "cuinchar",
    "cuinchare": "cuinchar",
    "cuincharei": "cuinchar",
    "cuinchareis": "cuinchar",
    "cuincharem": "cuinchar",
    "cuincharemos": "cuinchar",
    "cuinchares": "cuinchar",
    "cuincharia": "cuinchar",
    "cuinchariam": "cuinchar",
    "cuincharias": "cuinchar",
    "cuincharmo": "cuinchar",
    "cuincharmos": "cuinchar",
    "cuinchará": "cuinchar",
    "cuincharás": "cuinchar",
    "cuincharão": "cuinchar",
    "cuincharíamos": "cuinchar",
    "cuincharíeis": "cuinchar",
    "cuinchas": "cuinchar",
    "cuinchasse": "cuinchar",
    "cuinchassem": "cuinchar",
    "cuinchasses": "cuinchar",
    "cuinchaste": "cuinchar",
    "cuinchastes": "cuinchar",
    "cuinchava": "cuinchar",
    "cuinchavam": "cuinchar",
    "cuinchavas": "cuinchar",
    "cuinche": "cuinchar",
    "cuinchei": "cuinchar",
    "cuincheis": "cuinchar",
    "cuinchem": "cuinchar",
    "cuinchemo": "cuinchar",
    "cuinchemos": "cuinchar",
    "cuinches": "cuinchar",
    "cuincho": "cuinchar",
    "cuinchos": "cuincho",
    "cuinchou": "cuinchar",
    "cuinchá": "cuinchar",
    "cuinchámo": "cuinchar",
    "cuinchámos": "cuinchar",
    "cuincháramo": "cuinchar",
    "cuincháramos": "cuinchar",
    "cuinchárei": "cuinchar",
    "cuincháreis": "cuinchar",
    "cuinchásseis": "cuinchar",
    "cuinchássemos": "cuinchar",
    "cuinchávamo": "cuinchar",
    "cuinchávamos": "cuinchar",
    "cuinchávei": "cuinchar",
    "cuincháveis": "cuinchar",
    "cuinco": "cuincar",
    "cuincou": "cuincar",
    "cuincá": "cuincar",
    "cuincámo": "cuincar",
    "cuincámos": "cuincar",
    "cuincáramo": "cuincar",
    "cuincáramos": "cuincar",
    "cuincárei": "cuincar",
    "cuincáreis": "cuincar",
    "cuincásseis": "cuincar",
    "cuincássemos": "cuincar",
    "cuincávamo": "cuincar",
    "cuincávamos": "cuincar",
    "cuincávei": "cuincar",
    "cuincáveis": "cuincar",
    "cuinhiras": "cuinhira",
    "cuinque": "cuincar",
    "cuinquei": "cuincar",
    "cuinqueis": "cuincar",
    "cuinquem": "cuincar",
    "cuinquemo": "cuincar",
    "cuinquemos": "cuincar",
    "cuinques": "cuincar",
    "cuins": "cuim",
    "cuisiana": "cuisiano",
    "cuisianas": "cuisiano",
    "cuisianos": "cuisiano",
    "cuitezeiras": "cuitezeira",
    "cuités": "cuité",
    "cuja": "cujo",
    "cujas": "cujo",
    "cujos": "cujo",
    "culapa": "culapar",
    "culapada": "culapar",
    "culapadas": "culapar",
    "culapado": "culapar",
    "culapados": "culapar",
    "culapai": "culapar",
    "culapais": "culapar",
    "culapam": "culapar",
    "culapamo": "culapar",
    "culapamos": "culapar",
    "culapando": "culapar",
    "culapara": "culapar",
    "culaparam": "culapar",
    "culaparas": "culapar",
    "culapardes": "culapar",
    "culaparei": "culapar",
    "culapareis": "culapar",
    "culaparem": "culapar",
    "culaparemos": "culapar",
    "culapares": "culapar",
    "culaparia": "culapar",
    "culapariam": "culapar",
    "culaparias": "culapar",
    "culaparmo": "culapar",
    "culaparmos": "culapar",
    "culapará": "culapar",
    "culaparás": "culapar",
    "culaparão": "culapar",
    "culaparíamos": "culapar",
    "culaparíeis": "culapar",
    "culapas": "culapar",
    "culapasse": "culapar",
    "culapassem": "culapar",
    "culapasses": "culapar",
    "culapaste": "culapar",
    "culapastes": "culapar",
    "culapava": "culapar",
    "culapavam": "culapar",
    "culapavas": "culapar",
    "culape": "culapar",
    "culapei": "culapar",
    "culapeis": "culapar",
    "culapem": "culapar",
    "culapemo": "culapar",
    "culapemos": "culapar",
    "culapes": "culapar",
    "culapo": "culapar",
    "culapou": "culapar",
    "culapámo": "culapar",
    "culapámos": "culapar",
    "culapáramo": "culapar",
    "culapáramos": "culapar",
    "culapáreis": "culapar",
    "culapásseis": "culapar",
    "culapássemos": "culapar",
    "culapávamo": "culapar",
    "culapávamos": "culapar",
    "culapáveis": "culapar",
    "culatra": "culatrar",
    "culatrada": "culatrar",
    "culatradas": "culatrar",
    "culatrado": "culatrar",
    "culatrados": "culatrar",
    "culatrai": "culatrar",
    "culatrais": "culatrar",
    "culatram": "culatrar",
    "culatramo": "culatrar",
    "culatramos": "culatrar",
    "culatrando": "culatrar",
    "culatrara": "culatrar",
    "culatraram": "culatrar",
    "culatraras": "culatrar",
    "culatrardes": "culatrar",
    "culatrarei": "culatrar",
    "culatrareis": "culatrar",
    "culatrarem": "culatrar",
    "culatraremos": "culatrar",
    "culatrares": "culatrar",
    "culatraria": "culatrar",
    "culatrariam": "culatrar",
    "culatrarias": "culatrar",
    "culatrarmo": "culatrar",
    "culatrarmos": "culatrar",
    "culatrará": "culatrar",
    "culatrarás": "culatrar",
    "culatrarão": "culatrar",
    "culatraríamos": "culatrar",
    "culatraríeis": "culatrar",
    "culatras": "culatrar",
    "culatrasse": "culatrar",
    "culatrassem": "culatrar",
    "culatrasses": "culatrar",
    "culatraste": "culatrar",
    "culatrastes": "culatrar",
    "culatrava": "culatrar",
    "culatravam": "culatrar",
    "culatravas": "culatrar",
    "culatre": "culatrar",
    "culatrei": "culatrar",
    "culatreiras": "culatreira",
    "culatreis": "culatrar",
    "culatrem": "culatrar",
    "culatremo": "culatrar",
    "culatremos": "culatrar",
    "culatres": "culatrar",
    "culatro": "culatrar",
    "culatronas": "culatrona",
    "culatrou": "culatrar",
    "culatrámo": "culatrar",
    "culatrámos": "culatrar",
    "culatráramo": "culatrar",
    "culatráramos": "culatrar",
    "culatráreis": "culatrar",
    "culatrásseis": "culatrar",
    "culatrássemos": "culatrar",
    "culatrávamo": "culatrar",
    "culatrávamos": "culatrar",
    "culatráveis": "culatrar",
    "culcas": "culca",
    "culcos": "culco",
    "culiciformes": "culiciforme",
    "culicídea": "culicídeo",
    "culicídeas": "culicídeo",
    "culicídeos": "culicídeo",
    "culicívora": "culicívoro",
    "culicívoras": "culicívoro",
    "culicívoros": "culicívoro",
    "culinas": "culina",
    "culinária": "culinário",
    "culinárias": "culinário",
    "culinários": "culinário",
    "culmina": "culminar",
    "culminada": "culminar",
    "culminadas": "culminar",
    "culminado": "culminar",
    "culminados": "culminar",
    "culminai": "culminar",
    "culminais": "culminar",
    "culminam": "culminar",
    "culminamo": "culminar",
    "culminamos": "culminar",
    "culminando": "culminar",
    "culminantes": "culminante",
    "culminara": "culminar",
    "culminaram": "culminar",
    "culminaras": "culminar",
    "culminardes": "culminar",
    "culminarei": "culminar",
    "culminareis": "culminar",
    "culminarem": "culminar",
    "culminaremos": "culminar",
    "culminares": "culminar",
    "culminaria": "culminar",
    "culminariam": "culminar",
    "culminarias": "culminar",
    "culminarmo": "culminar",
    "culminarmos": "culminar",
    "culminará": "culminar",
    "culminarás": "culminar",
    "culminarão": "culminar",
    "culminaríamos": "culminar",
    "culminaríeis": "culminar",
    "culminas": "culminar",
    "culminasse": "culminar",
    "culminassem": "culminar",
    "culminasses": "culminar",
    "culminaste": "culminar",
    "culminastes": "culminar",
    "culminava": "culminar",
    "culminavam": "culminar",
    "culminavas": "culminar",
    "culminações": "culminação",
    "culmine": "culminar",
    "culminei": "culminar",
    "culmineis": "culminar",
    "culminem": "culminar",
    "culminemo": "culminar",
    "culminemos": "culminar",
    "culmines": "culminar",
    "culmino": "culminar",
    "culminou": "culminar",
    "culminámo": "culminar",
    "culminámos": "culminar",
    "culmináramo": "culminar",
    "culmináramos": "culminar",
    "culmináreis": "culminar",
    "culminásseis": "culminar",
    "culminássemos": "culminar",
    "culminávamo": "culminar",
    "culminávamos": "culminar",
    "culmináveis": "culminar",
    "culminâncias": "culminância",
    "culpa": "culpar",
    "culpabilidades": "culpabilidade",
    "culpabiliza": "culpabilizar",
    "culpabilizada": "culpabilizar",
    "culpabilizadas": "culpabilizar",
    "culpabilizado": "culpabilizar",
    "culpabilizados": "culpabilizar",
    "culpabilizai": "culpabilizar",
    "culpabilizais": "culpabilizar",
    "culpabilizam": "culpabilizar",
    "culpabilizamo": "culpabilizar",
    "culpabilizamos": "culpabilizar",
    "culpabilizando": "culpabilizar",
    "culpabilizara": "culpabilizar",
    "culpabilizaram": "culpabilizar",
    "culpabilizaras": "culpabilizar",
    "culpabilizarde": "culpabilizar",
    "culpabilizardes": "culpabilizar",
    "culpabilizare": "culpabilizar",
    "culpabilizarei": "culpabilizar",
    "culpabilizareis": "culpabilizar",
    "culpabilizarem": "culpabilizar",
    "culpabilizaremos": "culpabilizar",
    "culpabilizares": "culpabilizar",
    "culpabilizaria": "culpabilizar",
    "culpabilizariam": "culpabilizar",
    "culpabilizarias": "culpabilizar",
    "culpabilizarmo": "culpabilizar",
    "culpabilizarmos": "culpabilizar",
    "culpabilizará": "culpabilizar",
    "culpabilizarás": "culpabilizar",
    "culpabilizarão": "culpabilizar",
    "culpabilizaríamos": "culpabilizar",
    "culpabilizaríeis": "culpabilizar",
    "culpabilizas": "culpabilizar",
    "culpabilizasse": "culpabilizar",
    "culpabilizassem": "culpabilizar",
    "culpabilizasses": "culpabilizar",
    "culpabilizaste": "culpabilizar",
    "culpabilizastes": "culpabilizar",
    "culpabilizava": "culpabilizar",
    "culpabilizavam": "culpabilizar",
    "culpabilizavas": "culpabilizar",
    "culpabilizações": "culpabilização",
    "culpabilize": "culpabilizar",
    "culpabilizei": "culpabilizar",
    "culpabilizeis": "culpabilizar",
    "culpabilizem": "culpabilizar",
    "culpabilizemo": "culpabilizar",
    "culpabilizemos": "culpabilizar",
    "culpabilizes": "culpabilizar",
    "culpabilizo": "culpabilizar",
    "culpabilizou": "culpabilizar",
    "culpabilizá": "culpabilizar",
    "culpabilizámo": "culpabilizar",
    "culpabilizámos": "culpabilizar",
    "culpabilizáramo": "culpabilizar",
    "culpabilizáramos": "culpabilizar",
    "culpabilizárei": "culpabilizar",
    "culpabilizáreis": "culpabilizar",
    "culpabilizásseis": "culpabilizar",
    "culpabilizássemos": "culpabilizar",
    "culpabilizávamo": "culpabilizar",
    "culpabilizávamos": "culpabilizar",
    "culpabilizávei": "culpabilizar",
    "culpabilizáveis": "culpabilizar",
    "culpada": "culpar",
    "culpadas": "culpar",
    "culpado": "culpar",
    "culpados": "culpar",
    "culpai": "culpar",
    "culpais": "culpar",
    "culpam": "culpar",
    "culpamo": "culpar",
    "culpamos": "culpar",
    "culpanda": "culpando",
    "culpandas": "culpando",
    "culpando": "culpar",
    "culpandos": "culpando",
    "culpara": "culpar",
    "culparam": "culpar",
    "culparas": "culpar",
    "culparde": "culpar",
    "culpardes": "culpar",
    "culpare": "culpar",
    "culparei": "culpar",
    "culpareis": "culpar",
    "culparem": "culpar",
    "culparemos": "culpar",
    "culpares": "culpar",
    "culparia": "culpar",
    "culpariam": "culpar",
    "culparias": "culpar",
    "culparmo": "culpar",
    "culparmos": "culpar",
    "culpará": "culpar",
    "culparás": "culpar",
    "culparão": "culpar",
    "culparíamos": "culpar",
    "culparíeis": "culpar",
    "culpas": "culpar",
    "culpasse": "culpar",
    "culpassem": "culpar",
    "culpasses": "culpar",
    "culpaste": "culpar",
    "culpastes": "culpar",
    "culpava": "culpar",
    "culpavam": "culpar",
    "culpavas": "culpar",
    "culpe": "culpar",
    "culpei": "culpar",
    "culpeis": "culpar",
    "culpem": "culpar",
    "culpemo": "culpar",
    "culpemos": "culpar",
    "culpes": "culpar",
    "culpo": "culpar",
    "culposa": "culposo",
    "culposas": "culposo",
    "culposos": "culposo",
    "culpou": "culpar",
    "culpá": "culpar",
    "culpámo": "culpar",
    "culpámos": "culpar",
    "culpáramo": "culpar",
    "culpáramos": "culpar",
    "culpárei": "culpar",
    "culpáreis": "culpar",
    "culpásseis": "culpar",
    "culpássemos": "culpar",
    "culpávamo": "culpar",
    "culpávamos": "culpar",
    "culpávei": "culpar",
    "culpáveis": "culpável",
    "culta": "culto",
    "cultas": "culto",
    "culterana": "culterano",
    "culteranas": "culterano",
    "culteranismos": "culteranismo",
    "culteranistas": "culteranista",
    "culteranos": "culterano",
    "cultiparlas": "cultiparla",
    "cultismos": "cultismo",
    "cultistas": "cultista",
    "cultiva": "cultivar",
    "cultivada": "cultivar",
    "cultivadas": "cultivar",
    "cultivado": "cultivar",
    "cultivadora": "cultivador",
    "cultivadoras": "cultivador",
    "cultivadores": "cultivador",
    "cultivados": "cultivar",
    "cultivai": "cultivar",
    "cultivais": "cultivar",
    "cultivam": "cultivar",
    "cultivamo": "cultivar",
    "cultivamos": "cultivar",
    "cultivando": "cultivar",
    "cultivara": "cultivar",
    "cultivaram": "cultivar",
    "cultivaras": "cultivar",
    "cultivarde": "cultivar",
    "cultivardes": "cultivar",
    "cultivare": "cultivar",
    "cultivarei": "cultivar",
    "cultivareis": "cultivar",
    "cultivarem": "cultivar",
    "cultivaremos": "cultivar",
    "cultivares": "cultivar",
    "cultivaria": "cultivar",
    "cultivariam": "cultivar",
    "cultivarias": "cultivar",
    "cultivarmo": "cultivar",
    "cultivarmos": "cultivar",
    "cultivará": "cultivar",
    "cultivarás": "cultivar",
    "cultivarão": "cultivar",
    "cultivaríamos": "cultivar",
    "cultivaríeis": "cultivar",
    "cultivas": "cultivar",
    "cultivasse": "cultivar",
    "cultivassem": "cultivar",
    "cultivasses": "cultivar",
    "cultivaste": "cultivar",
    "cultivastes": "cultivar",
    "cultivava": "cultivar",
    "cultivavam": "cultivar",
    "cultivavas": "cultivar",
    "cultivações": "cultivação",
    "cultive": "cultivar",
    "cultivei": "cultivar",
    "cultiveis": "cultivar",
    "cultivem": "cultivar",
    "cultivemo": "cultivar",
    "cultivemos": "cultivar",
    "cultives": "cultivar",
    "cultivo": "cultivar",
    "cultivos": "cultivo",
    "cultivou": "cultivar",
    "cultivá": "cultivar",
    "cultivámo": "cultivar",
    "cultivámos": "cultivar",
    "cultiváramo": "cultivar",
    "cultiváramos": "cultivar",
    "cultivárei": "cultivar",
    "cultiváreis": "cultivar",
    "cultivásseis": "cultivar",
    "cultivássemos": "cultivar",
    "cultivávamo": "cultivar",
    "cultivávamos": "cultivar",
    "cultivávei": "cultivar",
    "cultiváveis": "cultivável",
    "cultomanias": "cultomania",
    "cultomaníaca": "cultomaníaco",
    "cultomaníacas": "cultomaníaco",
    "cultomaníacos": "cultomaníaco",
    "cultora": "cultor",
    "cultoras": "cultor",
    "cultores": "cultor",
    "cultos": "culto",
    "cultridentrada": "cultridentrado",
    "cultridentradas": "cultridentrado",
    "cultridentrados": "cultridentrado",
    "cultrifoliada": "cultrifoliado",
    "cultrifoliadas": "cultrifoliado",
    "cultrifoliados": "cultrifoliado",
    "cultriformes": "cultriforme",
    "cultrirrostra": "cultrirrostro",
    "cultrirrostras": "cultrirrostro",
    "cultrirrostros": "cultrirrostro",
    "cultua": "cultuar",
    "cultuada": "cultuar",
    "cultuadas": "cultuar",
    "cultuado": "cultuar",
    "cultuados": "cultuar",
    "cultuai": "cultuar",
    "cultuais": "cultuar",
    "cultuam": "cultuar",
    "cultuamo": "cultuar",
    "cultuamos": "cultuar",
    "cultuando": "cultuar",
    "cultuara": "cultuar",
    "cultuaram": "cultuar",
    "cultuaras": "cultuar",
    "cultuarde": "cultuar",
    "cultuardes": "cultuar",
    "cultuare": "cultuar",
    "cultuarei": "cultuar",
    "cultuareis": "cultuar",
    "cultuarem": "cultuar",
    "cultuaremos": "cultuar",
    "cultuares": "cultuar",
    "cultuaria": "cultuar",
    "cultuariam": "cultuar",
    "cultuarias": "cultuar",
    "cultuarmo": "cultuar",
    "cultuarmos": "cultuar",
    "cultuará": "cultuar",
    "cultuarás": "cultuar",
    "cultuarão": "cultuar",
    "cultuaríamos": "cultuar",
    "cultuaríeis": "cultuar",
    "cultuas": "cultuar",
    "cultuasse": "cultuar",
    "cultuassem": "cultuar",
    "cultuasses": "cultuar",
    "cultuaste": "cultuar",
    "cultuastes": "cultuar",
    "cultuava": "cultuar",
    "cultuavam": "cultuar",
    "cultuavas": "cultuar",
    "cultue": "cultuar",
    "cultuei": "cultuar",
    "cultueis": "cultuar",
    "cultuem": "cultuar",
    "cultuemo": "cultuar",
    "cultuemos": "cultuar",
    "cultues": "cultuar",
    "cultuo": "cultuar",
    "cultuou": "cultuar",
    "culturais": "cultural",
    "culturalistas": "culturalista",
    "culturas": "cultura",
    "culturismos": "culturismo",
    "culturistas": "culturista",
    "cultuá": "cultuar",
    "cultuámo": "cultuar",
    "cultuámos": "cultuar",
    "cultuáramo": "cultuar",
    "cultuáramos": "cultuar",
    "cultuárei": "cultuar",
    "cultuáreis": "cultuar",
    "cultuásseis": "cultuar",
    "cultuássemos": "cultuar",
    "cultuávamo": "cultuar",
    "cultuávamos": "cultuar",
    "cultuávei": "cultuar",
    "cultuáveis": "cultuar",
    "culícidas": "culícida",
    "culômbia": "culômbio",
    "culômbias": "culômbio",
    "culômbios": "culômbio",
    "cumana": "cumano",
    "cumanas": "cumano",
    "cumanos": "cumano",
    "cumba": "cumbo",
    "cumbas": "cumbo",
    "cumbebas": "cumbeba",
    "cumbos": "cumbo",
    "cumeada": "cumeado",
    "cumeadas": "cumeado",
    "cumeados": "cumeado",
    "cumeeiras": "cumeeira",
    "cumes": "cume",
    "cuminais": "cuminal",
    "cumplicia": "cumpliciar",
    "cumpliciada": "cumpliciar",
    "cumpliciadas": "cumpliciar",
    "cumpliciado": "cumpliciar",
    "cumpliciados": "cumpliciar",
    "cumpliciai": "cumpliciar",
    "cumpliciais": "cumpliciar",
    "cumpliciam": "cumpliciar",
    "cumpliciamo": "cumpliciar",
    "cumpliciamos": "cumpliciar",
    "cumpliciando": "cumpliciar",
    "cumpliciara": "cumpliciar",
    "cumpliciaram": "cumpliciar",
    "cumpliciaras": "cumpliciar",
    "cumpliciarde": "cumpliciar",
    "cumpliciardes": "cumpliciar",
    "cumpliciare": "cumpliciar",
    "cumpliciarei": "cumpliciar",
    "cumpliciareis": "cumpliciar",
    "cumpliciarem": "cumpliciar",
    "cumpliciaremos": "cumpliciar",
    "cumpliciares": "cumpliciar",
    "cumpliciaria": "cumpliciar",
    "cumpliciariam": "cumpliciar",
    "cumpliciarias": "cumpliciar",
    "cumpliciarmo": "cumpliciar",
    "cumpliciarmos": "cumpliciar",
    "cumpliciará": "cumpliciar",
    "cumpliciarás": "cumpliciar",
    "cumpliciarão": "cumpliciar",
    "cumpliciaríamos": "cumpliciar",
    "cumpliciaríeis": "cumpliciar",
    "cumplicias": "cumpliciar",
    "cumpliciasse": "cumpliciar",
    "cumpliciassem": "cumpliciar",
    "cumpliciasses": "cumpliciar",
    "cumpliciaste": "cumpliciar",
    "cumpliciastes": "cumpliciar",
    "cumpliciava": "cumpliciar",
    "cumpliciavam": "cumpliciar",
    "cumpliciavas": "cumpliciar",
    "cumplicidades": "cumplicidade",
    "cumplicie": "cumpliciar",
    "cumpliciei": "cumpliciar",
    "cumplicieis": "cumpliciar",
    "cumpliciem": "cumpliciar",
    "cumpliciemo": "cumpliciar",
    "cumpliciemos": "cumpliciar",
    "cumplicies": "cumpliciar",
    "cumplicio": "cumpliciar",
    "cumpliciou": "cumpliciar",
    "cumpliciá": "cumpliciar",
    "cumpliciámo": "cumpliciar",
    "cumpliciámos": "cumpliciar",
    "cumpliciáramo": "cumpliciar",
    "cumpliciáramos": "cumpliciar",
    "cumpliciárei": "cumpliciar",
    "cumpliciáreis": "cumpliciar",
    "cumpliciásseis": "cumpliciar",
    "cumpliciássemos": "cumpliciar",
    "cumpliciávamo": "cumpliciar",
    "cumpliciávamos": "cumpliciar",
    "cumpliciávei": "cumpliciar",
    "cumpliciáveis": "cumpliciar",
    "cumpra": "cumprir",
    "cumprais": "cumprir",
    "cumpram": "cumprir",
    "cumpramo": "cumprir",
    "cumpramos": "cumprir",
    "cumpras": "cumprir",
    "cumpre": "cumprir",
    "cumprem": "cumprir",
    "cumpres": "cumprir",
    "cumpri": "cumprir",
    "cumpria": "cumprir",
    "cumpriam": "cumprir",
    "cumprias": "cumprir",
    "cumprida": "cumprir",
    "cumpridas": "cumprir",
    "cumprido": "cumprir",
    "cumpridora": "cumpridor",
    "cumpridoras": "cumpridor",
    "cumpridores": "cumpridor",
    "cumpridos": "cumprir",
    "cumprimenta": "cumprimentar",
    "cumprimentada": "cumprimentar",
    "cumprimentadas": "cumprimentar",
    "cumprimentado": "cumprimentar",
    "cumprimentadora": "cumprimentador",
    "cumprimentadoras": "cumprimentador",
    "cumprimentadores": "cumprimentador",
    "cumprimentados": "cumprimentar",
    "cumprimentai": "cumprimentar",
    "cumprimentais": "cumprimentar",
    "cumprimentam": "cumprimentar",
    "cumprimentamo": "cumprimentar",
    "cumprimentamos": "cumprimentar",
    "cumprimentando": "cumprimentar",
    "cumprimentara": "cumprimentar",
    "cumprimentaram": "cumprimentar",
    "cumprimentaras": "cumprimentar",
    "cumprimentarde": "cumprimentar",
    "cumprimentardes": "cumprimentar",
    "cumprimentare": "cumprimentar",
    "cumprimentarei": "cumprimentar",
    "cumprimentareis": "cumprimentar",
    "cumprimentarem": "cumprimentar",
    "cumprimentaremos": "cumprimentar",
    "cumprimentares": "cumprimentar",
    "cumprimentaria": "cumprimentar",
    "cumprimentariam": "cumprimentar",
    "cumprimentarias": "cumprimentar",
    "cumprimentarmo": "cumprimentar",
    "cumprimentarmos": "cumprimentar",
    "cumprimentará": "cumprimentar",
    "cumprimentarás": "cumprimentar",
    "cumprimentarão": "cumprimentar",
    "cumprimentaríamos": "cumprimentar",
    "cumprimentaríeis": "cumprimentar",
    "cumprimentas": "cumprimentar",
    "cumprimentasse": "cumprimentar",
    "cumprimentassem": "cumprimentar",
    "cumprimentasses": "cumprimentar",
    "cumprimentaste": "cumprimentar",
    "cumprimentastes": "cumprimentar",
    "cumprimentava": "cumprimentar",
    "cumprimentavam": "cumprimentar",
    "cumprimentavas": "cumprimentar",
    "cumprimente": "cumprimentar",
    "cumprimentei": "cumprimentar",
    "cumprimenteira": "cumprimenteiro",
    "cumprimenteiras": "cumprimenteiro",
    "cumprimenteiros": "cumprimenteiro",
    "cumprimenteis": "cumprimentar",
    "cumprimentem": "cumprimentar",
    "cumprimentemo": "cumprimentar",
    "cumprimentemos": "cumprimentar",
    "cumprimentes": "cumprimentar",
    "cumprimento": "cumprimentar",
    "cumprimentos": "cumprimento",
    "cumprimentou": "cumprimentar",
    "cumprimentá": "cumprimentar",
    "cumprimentámo": "cumprimentar",
    "cumprimentámos": "cumprimentar",
    "cumprimentáramo": "cumprimentar",
    "cumprimentáramos": "cumprimentar",
    "cumprimentárei": "cumprimentar",
    "cumprimentáreis": "cumprimentar",
    "cumprimentásseis": "cumprimentar",
    "cumprimentássemos": "cumprimentar",
    "cumprimentávamo": "cumprimentar",
    "cumprimentávamos": "cumprimentar",
    "cumprimentávei": "cumprimentar",
    "cumprimentáveis": "cumprimentar",
    "cumprimo": "cumprir",
    "cumprimos": "cumprir",
    "cumprindo": "cumprir",
    "cumprira": "cumprir",
    "cumpriram": "cumprir",
    "cumpriras": "cumprir",
    "cumprirde": "cumprir",
    "cumprirdes": "cumprir",
    "cumprire": "cumprir",
    "cumprirei": "cumprir",
    "cumprireis": "cumprir",
    "cumprirem": "cumprir",
    "cumpriremos": "cumprir",
    "cumprires": "cumprir",
    "cumpriria": "cumprir",
    "cumpririam": "cumprir",
    "cumpririas": "cumprir",
    "cumprirmo": "cumprir",
    "cumprirmos": "cumprir",
    "cumprirá": "cumprir",
    "cumprirás": "cumprir",
    "cumprirão": "cumprir",
    "cumpriríamos": "cumprir",
    "cumpriríeis": "cumprir",
    "cumpris": "cumprir",
    "cumprisse": "cumprir",
    "cumprissem": "cumprir",
    "cumprisses": "cumprir",
    "cumpriste": "cumprir",
    "cumpristes": "cumprir",
    "cumpriu": "cumprir",
    "cumpro": "cumprir",
    "cumpríamo": "cumprir",
    "cumpríamos": "cumprir",
    "cumpríei": "cumprir",
    "cumpríeis": "cumprir",
    "cumpríramo": "cumprir",
    "cumpríramos": "cumprir",
    "cumprírei": "cumprir",
    "cumpríreis": "cumprir",
    "cumprísseis": "cumprir",
    "cumpríssemos": "cumprir",
    "cumula": "cumular",
    "cumulada": "cumular",
    "cumuladas": "cumular",
    "cumulado": "cumular",
    "cumulados": "cumular",
    "cumulai": "cumular",
    "cumulais": "cumular",
    "cumulam": "cumular",
    "cumulamo": "cumular",
    "cumulamos": "cumular",
    "cumulando": "cumular",
    "cumulara": "cumular",
    "cumularam": "cumular",
    "cumularas": "cumular",
    "cumularde": "cumular",
    "cumulardes": "cumular",
    "cumulare": "cumular",
    "cumularei": "cumular",
    "cumulareis": "cumular",
    "cumularem": "cumular",
    "cumularemos": "cumular",
    "cumulares": "cumular",
    "cumularia": "cumular",
    "cumulariam": "cumular",
    "cumularias": "cumular",
    "cumularmo": "cumular",
    "cumularmos": "cumular",
    "cumulará": "cumular",
    "cumularás": "cumular",
    "cumularão": "cumular",
    "cumularíamos": "cumular",
    "cumularíeis": "cumular",
    "cumulas": "cumular",
    "cumulasse": "cumular",
    "cumulassem": "cumular",
    "cumulasses": "cumular",
    "cumulaste": "cumular",
    "cumulastes": "cumular",
    "cumulativa": "cumulativo",
    "cumulativas": "cumulativo",
    "cumulativos": "cumulativo",
    "cumulava": "cumular",
    "cumulavam": "cumular",
    "cumulavas": "cumular",
    "cumulações": "cumulação",
    "cumule": "cumular",
    "cumulei": "cumular",
    "cumuleis": "cumular",
    "cumulem": "cumular",
    "cumulemo": "cumular",
    "cumulemos": "cumular",
    "cumules": "cumular",
    "cumulo": "cumular",
    "cumulou": "cumular",
    "cumulá": "cumular",
    "cumulámo": "cumular",
    "cumulámos": "cumular",
    "cumuláramo": "cumular",
    "cumuláramos": "cumular",
    "cumulárei": "cumular",
    "cumuláreis": "cumular",
    "cumulásseis": "cumular",
    "cumulássemos": "cumular",
    "cumulávamo": "cumular",
    "cumulávamos": "cumular",
    "cumulávei": "cumular",
    "cumuláveis": "cumular",
    "cunctatória": "cunctatório",
    "cunctatórias": "cunctatório",
    "cunctatórios": "cunctatório",
    "cuneana": "cuneano",
    "cuneanas": "cuneano",
    "cuneanos": "cuneano",
    "cuneifoliada": "cuneifoliado",
    "cuneifoliadas": "cuneifoliado",
    "cuneifoliados": "cuneifoliado",
    "cuneiformes": "cuneiforme",
    "cuneirrostra": "cuneirrostro",
    "cuneirrostras": "cuneirrostro",
    "cuneirrostros": "cuneirrostro",
    "cunha": "cunhar",
    "cunhada": "cunhar",
    "cunhadas": "cunhar",
    "cunhadios": "cunhadio",
    "cunhado": "cunhar",
    "cunhadora": "cunhador",
    "cunhadoras": "cunhador",
    "cunhadores": "cunhador",
    "cunhados": "cunhar",
    "cunhagens": "cunhagem",
    "cunhai": "cunhar",
    "cunhais": "cunhar",
    "cunham": "cunhar",
    "cunhamo": "cunhar",
    "cunhamos": "cunhar",
    "cunhando": "cunhar",
    "cunhara": "cunhar",
    "cunharam": "cunhar",
    "cunharas": "cunhar",
    "cunharde": "cunhar",
    "cunhardes": "cunhar",
    "cunhare": "cunhar",
    "cunharei": "cunhar",
    "cunhareis": "cunhar",
    "cunharem": "cunhar",
    "cunharemos": "cunhar",
    "cunhares": "cunhar",
    "cunharia": "cunhar",
    "cunhariam": "cunhar",
    "cunharias": "cunhar",
    "cunharmo": "cunhar",
    "cunharmos": "cunhar",
    "cunhará": "cunhar",
    "cunharás": "cunhar",
    "cunharão": "cunhar",
    "cunharíamos": "cunhar",
    "cunharíeis": "cunhar",
    "cunhas": "cunhar",
    "cunhasse": "cunhar",
    "cunhassem": "cunhar",
    "cunhasses": "cunhar",
    "cunhaste": "cunhar",
    "cunhastes": "cunhar",
    "cunhava": "cunhar",
    "cunhavam": "cunhar",
    "cunhavas": "cunhar",
    "cunhe": "cunhar",
    "cunhei": "cunhar",
    "cunheiras": "cunheira",
    "cunheis": "cunhar",
    "cunhem": "cunhar",
    "cunhemo": "cunhar",
    "cunhemos": "cunhar",
    "cunhes": "cunhar",
    "cunhetes": "cunhete",
    "cunho": "cunhar",
    "cunhos": "cunho",
    "cunhou": "cunhar",
    "cunhá": "cunhar",
    "cunhámo": "cunhar",
    "cunhámos": "cunhar",
    "cunháramo": "cunhar",
    "cunháramos": "cunhar",
    "cunhárei": "cunhar",
    "cunháreis": "cunhar",
    "cunhásseis": "cunhar",
    "cunhássemos": "cunhar",
    "cunhávamo": "cunhar",
    "cunhávamos": "cunhar",
    "cunhávei": "cunhar",
    "cunháveis": "cunhar",
    "cunicultora": "cunicultor",
    "cunicultoras": "cunicultor",
    "cunicultores": "cunicultor",
    "cuniculturas": "cunicultura",
    "cunículos": "cunículo",
    "cupideiras": "cupideira",
    "cupidezes": "cupidez",
    "cupidinho": "cupido",
    "cupidinhos": "cupido",
    "cupidinosa": "cupidinoso",
    "cupidinosas": "cupidinoso",
    "cupidinosos": "cupidinoso",
    "cupidito": "cupido",
    "cupiditos": "cupido",
    "cupidos": "cupido",
    "cupidícias": "cupidícia",
    "cupidínea": "cupidíneo",
    "cupidíneas": "cupidíneo",
    "cupidíneos": "cupidíneo",
    "cupijadas": "cupijada",
    "cupins": "cupim",
    "cupinzeiros": "cupinzeiro",
    "cupressifoliada": "cupressifoliado",
    "cupressifoliadas": "cupressifoliado",
    "cupressifoliados": "cupressifoliado",
    "cupressiformes": "cupressiforme",
    "cupressina": "cupressino",
    "cupressinas": "cupressino",
    "cupressinos": "cupressino",
    "cupressácea": "cupressáceo",
    "cupressáceas": "cupressáceo",
    "cupressáceos": "cupressáceo",
    "cupressínea": "cupressíneo",
    "cupressíneas": "cupressíneo",
    "cupressíneos": "cupressíneo",
    "cupripedes": "cupripede",
    "cuprirrostros": "cuprirrostro",
    "cuprites": "cuprite",
    "cuproníqueis": "cuproníquel",
    "cuprosa": "cuproso",
    "cuprosas": "cuproso",
    "cuprosos": "cuproso",
    "cupréssea": "cuprésseo",
    "cuprésseas": "cuprésseo",
    "cuprésseos": "cuprésseo",
    "cuprífera": "cuprífero",
    "cupríferas": "cuprífero",
    "cupríferos": "cuprífero",
    "cupulada": "cupulado",
    "cupuladas": "cupulado",
    "cupulados": "cupulado",
    "cupuliformes": "cupuliforme",
    "cupulins": "cupulim",
    "cupulífera": "cupulífero",
    "cupulíferas": "cupulífero",
    "cupulíferos": "cupulífero",
    "cupés": "cupé",
    "cupões": "cupão",
    "cuque": "cucar",
    "cuquei": "cucar",
    "cuqueis": "cucar",
    "cuquem": "cucar",
    "cuquemo": "cucar",
    "cuquemos": "cucar",
    "cuques": "cucar",
    "cura": "curar",
    "curabilidades": "curabilidade",
    "curada": "curar",
    "curadas": "curar",
    "curadias": "curadia",
    "curado": "curar",
    "curadora": "curador",
    "curadoras": "curador",
    "curadores": "curador",
    "curadorias": "curadoria",
    "curados": "curar",
    "curai": "curar",
    "curais": "curar",
    "curam": "curar",
    "curamo": "curar",
    "curamos": "curar",
    "curandeira": "curandeiro",
    "curandeiras": "curandeiro",
    "curandeirismos": "curandeirismo",
    "curandeiros": "curandeiro",
    "curandices": "curandice",
    "curando": "curar",
    "curara": "curar",
    "curaram": "curar",
    "curaras": "curar",
    "curarde": "curar",
    "curardes": "curar",
    "curare": "curar",
    "curarei": "curar",
    "curareis": "curar",
    "curarem": "curar",
    "curaremos": "curar",
    "curares": "curare",
    "curaria": "curar",
    "curariam": "curar",
    "curarias": "curar",
    "curarinas": "curarina",
    "curarinações": "curarinação",
    "curariza": "curarizar",
    "curarizada": "curarizar",
    "curarizadas": "curarizar",
    "curarizado": "curarizar",
    "curarizados": "curarizar",
    "curarizai": "curarizar",
    "curarizais": "curarizar",
    "curarizam": "curarizar",
    "curarizamo": "curarizar",
    "curarizamos": "curarizar",
    "curarizando": "curarizar",
    "curarizara": "curarizar",
    "curarizaram": "curarizar",
    "curarizaras": "curarizar",
    "curarizarde": "curarizar",
    "curarizardes": "curarizar",
    "curarizare": "curarizar",
    "curarizarei": "curarizar",
    "curarizareis": "curarizar",
    "curarizarem": "curarizar",
    "curarizaremos": "curarizar",
    "curarizares": "curarizar",
    "curarizaria": "curarizar",
    "curarizariam": "curarizar",
    "curarizarias": "curarizar",
    "curarizarmo": "curarizar",
    "curarizarmos": "curarizar",
    "curarizará": "curarizar",
    "curarizarás": "curarizar",
    "curarizarão": "curarizar",
    "curarizaríamos": "curarizar",
    "curarizaríeis": "curarizar",
    "curarizas": "curarizar",
    "curarizasse": "curarizar",
    "curarizassem": "curarizar",
    "curarizasses": "curarizar",
    "curarizaste": "curarizar",
    "curarizastes": "curarizar",
    "curarizava": "curarizar",
    "curarizavam": "curarizar",
    "curarizavas": "curarizar",
    "curarize": "curarizar",
    "curarizei": "curarizar",
    "curarizeis": "curarizar",
    "curarizem": "curarizar",
    "curarizemo": "curarizar",
    "curarizemos": "curarizar",
    "curarizes": "curarizar",
    "curarizo": "curarizar",
    "curarizou": "curarizar",
    "curarizá": "curarizar",
    "curarizámo": "curarizar",
    "curarizámos": "curarizar",
    "curarizáramo": "curarizar",
    "curarizáramos": "curarizar",
    "curarizárei": "curarizar",
    "curarizáreis": "curarizar",
    "curarizásseis": "curarizar",
    "curarizássemos": "curarizar",
    "curarizávamo": "curarizar",
    "curarizávamos": "curarizar",
    "curarizávei": "curarizar",
    "curarizáveis": "curarizar",
    "curarmo": "curar",
    "curarmos": "curar",
    "curará": "curar",
    "curarás": "curar",
    "curarão": "curar",
    "curaríamos": "curar",
    "curaríeis": "curar",
    "curas": "curar",
    "curasse": "curar",
    "curassem": "curar",
    "curasses": "curar",
    "curaste": "curar",
    "curastes": "curar",
    "curatelas": "curatela",
    "curativa": "curativo",
    "curativas": "curativo",
    "curativos": "curativo",
    "curatos": "curato",
    "curava": "curar",
    "curavam": "curar",
    "curavas": "curar",
    "curações": "curação",
    "curculeânidas": "curculeânida",
    "curculeânidos": "curculeânido",
    "curculionidea": "curculionideo",
    "curculionideas": "curculionideo",
    "curculionideos": "curculionideo",
    "curculiónidas": "curculiónida",
    "curcumas": "curcuma",
    "curcuminas": "curcumina",
    "curda": "curdo",
    "curdas": "curdo",
    "curdos": "curdo",
    "cure": "curar",
    "curei": "curar",
    "cureis": "curar",
    "curem": "curar",
    "curemo": "curar",
    "curemos": "curar",
    "cures": "curar",
    "curiais": "curial",
    "curialidades": "curialidade",
    "curialismos": "curialismo",
    "curicas": "curica",
    "curies": "curie",
    "curieterapeutas": "curieterapeuta",
    "curieterapias": "curieterapia",
    "curieterapistas": "curieterapista",
    "curieterapêutica": "curieterapêutico",
    "curieterapêuticas": "curieterapêutico",
    "curieterapêuticos": "curieterapêutico",
    "curieterápica": "curieterápico",
    "curieterápicas": "curieterápico",
    "curieterápicos": "curieterápico",
    "curimbós": "curimbó",
    "curingas": "curinga",
    "curiosa": "curioso",
    "curiosas": "curioso",
    "curiosidades": "curiosidade",
    "curiosos": "curioso",
    "curiosíssima": "curioso",
    "curiosíssimas": "curioso",
    "curiosíssimo": "curioso",
    "curiosíssimos": "curioso",
    "curis": "curi",
    "curiões": "curião",
    "curiúvas": "curiúva",
    "curo": "curar",
    "curou": "curar",
    "currais": "curral",
    "curraladas": "curralada",
    "curralagens": "curralagem",
    "curraleira": "curraleiro",
    "curraleiras": "curraleiro",
    "curraleiros": "curraleiro",
    "curricula": "curriculum",
    "curriculares": "curricular",
    "curros": "curro",
    "currículos": "currículo",
    "cursa": "cursar",
    "cursada": "cursar",
    "cursadas": "cursar",
    "cursado": "cursar",
    "cursados": "cursar",
    "cursai": "cursar",
    "cursais": "cursar",
    "cursam": "cursar",
    "cursamo": "cursar",
    "cursamos": "cursar",
    "cursando": "cursar",
    "cursara": "cursar",
    "cursaram": "cursar",
    "cursaras": "cursar",
    "cursarde": "cursar",
    "cursardes": "cursar",
    "cursare": "cursar",
    "cursarei": "cursar",
    "cursareis": "cursar",
    "cursarem": "cursar",
    "cursaremos": "cursar",
    "cursares": "cursar",
    "cursaria": "cursar",
    "cursariam": "cursar",
    "cursarias": "cursar",
    "cursarmo": "cursar",
    "cursarmos": "cursar",
    "cursará": "cursar",
    "cursarás": "cursar",
    "cursarão": "cursar",
    "cursaríamos": "cursar",
    "cursaríeis": "cursar",
    "cursas": "cursar",
    "cursasse": "cursar",
    "cursassem": "cursar",
    "cursasses": "cursar",
    "cursaste": "cursar",
    "cursastes": "cursar",
    "cursava": "cursar",
    "cursavam": "cursar",
    "cursavas": "cursar",
    "curse": "cursar",
    "curseada": "cursear",
    "curseadas": "cursear",
    "curseado": "cursear",
    "curseados": "cursear",
    "curseai": "cursear",
    "curseais": "cursear",
    "curseamo": "cursear",
    "curseamos": "cursear",
    "curseando": "cursear",
    "curseara": "cursear",
    "cursearam": "cursear",
    "cursearas": "cursear",
    "curseardes": "cursear",
    "cursearei": "cursear",
    "curseareis": "cursear",
    "cursearem": "cursear",
    "cursearemos": "cursear",
    "curseares": "cursear",
    "cursearia": "cursear",
    "curseariam": "cursear",
    "cursearias": "cursear",
    "cursearmo": "cursear",
    "cursearmos": "cursear",
    "curseará": "cursear",
    "cursearás": "cursear",
    "cursearão": "cursear",
    "cursearíamos": "cursear",
    "cursearíeis": "cursear",
    "curseasse": "cursear",
    "curseassem": "cursear",
    "curseasses": "cursear",
    "curseaste": "cursear",
    "curseastes": "cursear",
    "curseava": "cursear",
    "curseavam": "cursear",
    "curseavas": "cursear",
    "curseei": "cursear",
    "curseeis": "cursear",
    "curseemo": "cursear",
    "curseemos": "cursear",
    "cursei": "cursar",
    "curseia": "cursear",
    "curseiam": "cursear",
    "curseias": "cursear",
    "curseie": "cursear",
    "curseiem": "cursear",
    "curseies": "cursear",
    "curseio": "cursear",
    "curseis": "cursar",
    "cursem": "cursar",
    "cursemo": "cursar",
    "cursemos": "cursar",
    "curseou": "cursear",
    "curses": "cursar",
    "curseámo": "cursear",
    "curseámos": "cursear",
    "curseáramo": "cursear",
    "curseáramos": "cursear",
    "curseáreis": "cursear",
    "curseásseis": "cursear",
    "curseássemos": "cursear",
    "curseávamo": "cursear",
    "curseávamos": "cursear",
    "curseáveis": "cursear",
    "cursinho": "curso",
    "cursinhos": "curso",
    "cursistas": "cursista",
    "cursito": "curso",
    "cursitos": "curso",
    "cursiva": "cursivo",
    "cursivas": "cursivo",
    "cursividades": "cursividade",
    "cursivinhos": "cursivinho",
    "cursivos": "cursivo",
    "curso": "cursar",
    "cursora": "cursor",
    "cursoras": "cursor",
    "cursores": "cursor",
    "cursos": "curso",
    "cursou": "cursar",
    "cursozinho": "curso",
    "cursozinhos": "curso",
    "cursozito": "curso",
    "cursozitos": "curso",
    "cursá": "cursar",
    "cursámo": "cursar",
    "cursámos": "cursar",
    "cursáramo": "cursar",
    "cursáramos": "cursar",
    "cursárei": "cursar",
    "cursáreis": "cursar",
    "cursásseis": "cursar",
    "cursássemos": "cursar",
    "cursávamo": "cursar",
    "cursávamos": "cursar",
    "cursávei": "cursar",
    "cursáveis": "cursável",
    "curta": "curto",
    "curtais": "curtir",
    "curtam": "curtir",
    "curtamo": "curtir",
    "curtamos": "curtir",
    "curtas": "curto",
    "curte": "curtir",
    "curtem": "curtir",
    "curtes": "curtir",
    "curtezas": "curteza",
    "curti": "curtir",
    "curtia": "curtir",
    "curtiam": "curtir",
    "curtias": "curtir",
    "curtida": "curtir",
    "curtidas": "curtir",
    "curtido": "curtir",
    "curtidoiros": "curtidoiro",
    "curtidora": "curtidor",
    "curtidoras": "curtidor",
    "curtidores": "curtidor",
    "curtidos": "curtir",
    "curtidouros": "curtidouro",
    "curtiduras": "curtidura",
    "curtimentas": "curtimenta",
    "curtimentos": "curtimento",
    "curtimo": "curtir",
    "curtimos": "curtir",
    "curtindo": "curtir",
    "curtinha": "curto",
    "curtinhas": "curto",
    "curtinho": "curto",
    "curtinhos": "curto",
    "curtira": "curtir",
    "curtiram": "curtir",
    "curtiras": "curtir",
    "curtirde": "curtir",
    "curtirdes": "curtir",
    "curtire": "curtir",
    "curtirei": "curtir",
    "curtireis": "curtir",
    "curtirem": "curtir",
    "curtiremos": "curtir",
    "curtires": "curtir",
    "curtiria": "curtir",
    "curtiriam": "curtir",
    "curtirias": "curtir",
    "curtirmo": "curtir",
    "curtirmos": "curtir",
    "curtirá": "curtir",
    "curtirás": "curtir",
    "curtirão": "curtir",
    "curtiríamos": "curtir",
    "curtiríeis": "curtir",
    "curtis": "curtir",
    "curtisse": "curtir",
    "curtissem": "curtir",
    "curtisses": "curtir",
    "curtiste": "curtir",
    "curtistes": "curtir",
    "curtita": "curto",
    "curtitas": "curto",
    "curtito": "curto",
    "curtitos": "curto",
    "curtiu": "curtir",
    "curtições": "curtição",
    "curto": "curtir",
    "curtos": "curto",
    "curtumes": "curtume",
    "curtíamo": "curtir",
    "curtíamos": "curtir",
    "curtíei": "curtir",
    "curtíeis": "curtir",
    "curtíramo": "curtir",
    "curtíramos": "curtir",
    "curtírei": "curtir",
    "curtíreis": "curtir",
    "curtísseis": "curtir",
    "curtíssemos": "curtir",
    "curtíssima": "curto",
    "curtíssimas": "curto",
    "curtíssimo": "curto",
    "curtíssimos": "curto",
    "curuis": "curul",
    "curumbas": "curumba",
    "curva": "curvo",
    "curvada": "curvar",
    "curvadas": "curvar",
    "curvado": "curvar",
    "curvados": "curvar",
    "curvai": "curvar",
    "curvais": "curvar",
    "curvam": "curvar",
    "curvamo": "curvar",
    "curvamos": "curvar",
    "curvando": "curvar",
    "curvara": "curvar",
    "curvaram": "curvar",
    "curvaras": "curvar",
    "curvarde": "curvar",
    "curvardes": "curvar",
    "curvare": "curvar",
    "curvarei": "curvar",
    "curvareis": "curvar",
    "curvarem": "curvar",
    "curvaremos": "curvar",
    "curvares": "curvar",
    "curvaria": "curvar",
    "curvariam": "curvar",
    "curvarias": "curvar",
    "curvarmo": "curvar",
    "curvarmos": "curvar",
    "curvará": "curvar",
    "curvarás": "curvar",
    "curvarão": "curvar",
    "curvaríamos": "curvar",
    "curvaríeis": "curvar",
    "curvas": "curvo",
    "curvasse": "curvar",
    "curvassem": "curvar",
    "curvasses": "curvar",
    "curvaste": "curvar",
    "curvastes": "curvar",
    "curvativa": "curvativo",
    "curvativas": "curvativo",
    "curvativos": "curvativo",
    "curvaturas": "curvatura",
    "curvava": "curvar",
    "curvavam": "curvar",
    "curvavas": "curvar",
    "curve": "curvar",
    "curvei": "curvar",
    "curveis": "curvar",
    "curveja": "curvejar",
    "curvejada": "curvejar",
    "curvejadas": "curvejar",
    "curvejado": "curvejar",
    "curvejados": "curvejar",
    "curvejai": "curvejar",
    "curvejais": "curvejar",
    "curvejam": "curvejar",
    "curvejamo": "curvejar",
    "curvejamos": "curvejar",
    "curvejando": "curvejar",
    "curvejara": "curvejar",
    "curvejaram": "curvejar",
    "curvejaras": "curvejar",
    "curvejarde": "curvejar",
    "curvejardes": "curvejar",
    "curvejare": "curvejar",
    "curvejarei": "curvejar",
    "curvejareis": "curvejar",
    "curvejarem": "curvejar",
    "curvejaremos": "curvejar",
    "curvejares": "curvejar",
    "curvejaria": "curvejar",
    "curvejariam": "curvejar",
    "curvejarias": "curvejar",
    "curvejarmo": "curvejar",
    "curvejarmos": "curvejar",
    "curvejará": "curvejar",
    "curvejarás": "curvejar",
    "curvejarão": "curvejar",
    "curvejaríamos": "curvejar",
    "curvejaríeis": "curvejar",
    "curvejas": "curvejar",
    "curvejasse": "curvejar",
    "curvejassem": "curvejar",
    "curvejasses": "curvejar",
    "curvejaste": "curvejar",
    "curvejastes": "curvejar",
    "curvejava": "curvejar",
    "curvejavam": "curvejar",
    "curvejavas": "curvejar",
    "curveje": "curvejar",
    "curvejei": "curvejar",
    "curvejeis": "curvejar",
    "curvejem": "curvejar",
    "curvejemo": "curvejar",
    "curvejemos": "curvejar",
    "curvejes": "curvejar",
    "curvejo": "curvejar",
    "curvejou": "curvejar",
    "curvejá": "curvejar",
    "curvejámo": "curvejar",
    "curvejámos": "curvejar",
    "curvejáramo": "curvejar",
    "curvejáramos": "curvejar",
    "curvejárei": "curvejar",
    "curvejáreis": "curvejar",
    "curvejásseis": "curvejar",
    "curvejássemos": "curvejar",
    "curvejávamo": "curvejar",
    "curvejávamos": "curvejar",
    "curvejávei": "curvejar",
    "curvejáveis": "curvejar",
    "curvejões": "curvejão",
    "curvem": "curvar",
    "curvemo": "curvar",
    "curvemos": "curvar",
    "curves": "curvar",
    "curvetas": "curveta",
    "curveteada": "curvetear",
    "curveteadas": "curvetear",
    "curveteado": "curvetear",
    "curveteados": "curvetear",
    "curveteai": "curvetear",
    "curveteais": "curvetear",
    "curveteamo": "curvetear",
    "curveteamos": "curvetear",
    "curveteando": "curvetear",
    "curveteara": "curvetear",
    "curvetearam": "curvetear",
    "curvetearas": "curvetear",
    "curveteardes": "curvetear",
    "curvetearei": "curvetear",
    "curveteareis": "curvetear",
    "curvetearem": "curvetear",
    "curvetearemos": "curvetear",
    "curveteares": "curvetear",
    "curvetearia": "curvetear",
    "curveteariam": "curvetear",
    "curvetearias": "curvetear",
    "curvetearmo": "curvetear",
    "curvetearmos": "curvetear",
    "curveteará": "curvetear",
    "curvetearás": "curvetear",
    "curvetearão": "curvetear",
    "curvetearíamos": "curvetear",
    "curvetearíeis": "curvetear",
    "curveteasse": "curvetear",
    "curveteassem": "curvetear",
    "curveteasses": "curvetear",
    "curveteaste": "curvetear",
    "curveteastes": "curvetear",
    "curveteava": "curvetear",
    "curveteavam": "curvetear",
    "curveteavas": "curvetear",
    "curveteei": "curvetear",
    "curveteeis": "curvetear",
    "curveteemo": "curvetear",
    "curveteemos": "curvetear",
    "curveteia": "curvetear",
    "curveteiam": "curvetear",
    "curveteias": "curvetear",
    "curveteie": "curvetear",
    "curveteiem": "curvetear",
    "curveteies": "curvetear",
    "curveteio": "curvetear",
    "curveteou": "curvetear",
    "curveteámo": "curvetear",
    "curveteámos": "curvetear",
    "curveteáramo": "curvetear",
    "curveteáramos": "curvetear",
    "curveteáreis": "curvetear",
    "curveteásseis": "curvetear",
    "curveteássemos": "curvetear",
    "curveteávamo": "curvetear",
    "curveteávamos": "curvetear",
    "curveteáveis": "curvetear",
    "curvicaudes": "curvicaude",
    "curvicórnea": "curvicórneo",
    "curvicórneas": "curvicórneo",
    "curvicórneos": "curvicórneo",
    "curvidades": "curvidade",
    "curviflora": "curvifloro",
    "curvifloras": "curvifloro",
    "curvifloros": "curvifloro",
    "curvifoliada": "curvifoliado",
    "curvifoliadas": "curvifoliado",
    "curvifoliados": "curvifoliado",
    "curvifrontes": "curvifronte",
    "curvilhões": "curvilhão",
    "curvilínea": "curvilíneo",
    "curvilíneas": "curvilíneo",
    "curvilíneos": "curvilíneo",
    "curvimetrias": "curvimetria",
    "curvimétrica": "curvimétrico",
    "curvimétricas": "curvimétrico",
    "curvimétricos": "curvimétrico",
    "curvinervada": "curvinervado",
    "curvinervadas": "curvinervado",
    "curvinervados": "curvinervado",
    "curvinha": "curva",
    "curvinhas": "curva",
    "curvinérvea": "curvinérveo",
    "curvinérveas": "curvinérveo",
    "curvinérveos": "curvinérveo",
    "curvirrostra": "curvirrostro",
    "curvirrostras": "curvirrostro",
    "curvirrostros": "curvirrostro",
    "curvita": "curva",
    "curvitas": "curva",
    "curvo": "curvar",
    "curvos": "curvo",
    "curvou": "curvar",
    "curvá": "curvar",
    "curvámo": "curvar",
    "curvámos": "curvar",
    "curváramo": "curvar",
    "curváramos": "curvar",
    "curvárei": "curvar",
    "curváreis": "curvar",
    "curvásseis": "curvar",
    "curvássemos": "curvar",
    "curvávamo": "curvar",
    "curvávamos": "curvar",
    "curvávei": "curvar",
    "curváveis": "curvar",
    "curvímetros": "curvímetro",
    "curvípedes": "curvípede",
    "curvíssima": "curvo",
    "curvíssimas": "curvo",
    "curvíssimo": "curvo",
    "curvíssimos": "curvo",
    "curá": "curar",
    "curámo": "curar",
    "curámos": "curar",
    "curáramo": "curar",
    "curáramos": "curar",
    "curárei": "curar",
    "curáreis": "curar",
    "curásseis": "curar",
    "curássemos": "curar",
    "curávamo": "curar",
    "curávamos": "curar",
    "curávei": "curar",
    "curáveis": "curável",
    "cus": "cu",
    "cuscutas": "cuscuta",
    "cuscutácea": "cuscutáceo",
    "cuscutáceas": "cuscutáceo",
    "cuscutáceos": "cuscutáceo",
    "cuscuzeira": "cuscuzeiro",
    "cuscuzeiras": "cuscuzeiro",
    "cuscuzeiros": "cuscuzeiro",
    "cuscuzes": "cuscuz",
    "cuscúcios": "cuscúcio",
    "cuspa": "cuspir",
    "cuspais": "cuspir",
    "cuspam": "cuspir",
    "cuspamo": "cuspir",
    "cuspamos": "cuspir",
    "cusparadas": "cusparada",
    "cuspas": "cuspir",
    "cuspes": "cuspe",
    "cuspi": "cuspir",
    "cuspia": "cuspir",
    "cuspiam": "cuspir",
    "cuspias": "cuspir",
    "cuspida": "cuspir",
    "cuspidada": "cuspidado",
    "cuspidadas": "cuspidado",
    "cuspidados": "cuspidado",
    "cuspidas": "cuspir",
    "cuspidata": "cuspidato",
    "cuspidatas": "cuspidato",
    "cuspidatos": "cuspidato",
    "cuspideira": "cuspideiro",
    "cuspideiras": "cuspideiro",
    "cuspideiros": "cuspideiro",
    "cuspidelas": "cuspidela",
    "cuspidiformes": "cuspidiforme",
    "cuspido": "cuspir",
    "cuspidora": "cuspidor",
    "cuspidoras": "cuspidor",
    "cuspidores": "cuspidor",
    "cuspidos": "cuspir",
    "cuspidouros": "cuspidouro",
    "cuspiduras": "cuspidura",
    "cuspidária": "cuspidário",
    "cuspidárias": "cuspidário",
    "cuspidários": "cuspidário",
    "cuspimo": "cuspir",
    "cuspimos": "cuspir",
    "cuspindo": "cuspir",
    "cuspinha": "cuspinhar",
    "cuspinhada": "cuspinhar",
    "cuspinhadas": "cuspinhar",
    "cuspinhado": "cuspinhar",
    "cuspinhadora": "cuspinhador",
    "cuspinhadoras": "cuspinhador",
    "cuspinhadores": "cuspinhador",
    "cuspinhados": "cuspinhar",
    "cuspinhai": "cuspinhar",
    "cuspinhais": "cuspinhar",
    "cuspinham": "cuspinhar",
    "cuspinhamo": "cuspinhar",
    "cuspinhamos": "cuspinhar",
    "cuspinhando": "cuspinhar",
    "cuspinhara": "cuspinhar",
    "cuspinharam": "cuspinhar",
    "cuspinharas": "cuspinhar",
    "cuspinhardes": "cuspinhar",
    "cuspinharei": "cuspinhar",
    "cuspinhareis": "cuspinhar",
    "cuspinharem": "cuspinhar",
    "cuspinharemos": "cuspinhar",
    "cuspinhares": "cuspinhar",
    "cuspinharia": "cuspinhar",
    "cuspinhariam": "cuspinhar",
    "cuspinharias": "cuspinhar",
    "cuspinharmo": "cuspinhar",
    "cuspinharmos": "cuspinhar",
    "cuspinhará": "cuspinhar",
    "cuspinharás": "cuspinhar",
    "cuspinharão": "cuspinhar",
    "cuspinharíamos": "cuspinhar",
    "cuspinharíeis": "cuspinhar",
    "cuspinhas": "cuspinhar",
    "cuspinhasse": "cuspinhar",
    "cuspinhassem": "cuspinhar",
    "cuspinhasses": "cuspinhar",
    "cuspinhaste": "cuspinhar",
    "cuspinhastes": "cuspinhar",
    "cuspinhava": "cuspinhar",
    "cuspinhavam": "cuspinhar",
    "cuspinhavas": "cuspinhar",
    "cuspinhe": "cuspinhar",
    "cuspinhei": "cuspinhar",
    "cuspinheiras": "cuspinheira",
    "cuspinheis": "cuspinhar",
    "cuspinhem": "cuspinhar",
    "cuspinhemo": "cuspinhar",
    "cuspinhemos": "cuspinhar",
    "cuspinhes": "cuspinhar",
    "cuspinho": "cuspinhar",
    "cuspinhou": "cuspinhar",
    "cuspinhámo": "cuspinhar",
    "cuspinhámos": "cuspinhar",
    "cuspinháramo": "cuspinhar",
    "cuspinháramos": "cuspinhar",
    "cuspinháreis": "cuspinhar",
    "cuspinhásseis": "cuspinhar",
    "cuspinhássemos": "cuspinhar",
    "cuspinhávamo": "cuspinhar",
    "cuspinhávamos": "cuspinhar",
    "cuspinháveis": "cuspinhar",
    "cuspira": "cuspir",
    "cuspiram": "cuspir",
    "cuspiras": "cuspir",
    "cuspirde": "cuspir",
    "cuspirdes": "cuspir",
    "cuspire": "cuspir",
    "cuspirei": "cuspir",
    "cuspireis": "cuspir",
    "cuspirem": "cuspir",
    "cuspiremos": "cuspir",
    "cuspires": "cuspir",
    "cuspiria": "cuspir",
    "cuspiriam": "cuspir",
    "cuspirias": "cuspir",
    "cuspirmo": "cuspir",
    "cuspirmos": "cuspir",
    "cuspirá": "cuspir",
    "cuspirás": "cuspir",
    "cuspirão": "cuspir",
    "cuspiríamos": "cuspir",
    "cuspiríeis": "cuspir",
    "cuspis": "cuspir",
    "cuspisse": "cuspir",
    "cuspissem": "cuspir",
    "cuspisses": "cuspir",
    "cuspiste": "cuspir",
    "cuspistes": "cuspir",
    "cuspiu": "cuspir",
    "cuspo": "cuspir",
    "cuspos": "cuspo",
    "cuspíamo": "cuspir",
    "cuspíamos": "cuspir",
    "cuspíei": "cuspir",
    "cuspíeis": "cuspir",
    "cuspíramo": "cuspir",
    "cuspíramos": "cuspir",
    "cuspírei": "cuspir",
    "cuspíreis": "cuspir",
    "cuspísseis": "cuspir",
    "cuspíssemos": "cuspir",
    "cussos": "cusso",
    "custa": "custar",
    "custada": "custar",
    "custadas": "custar",
    "custado": "custar",
    "custados": "custar",
    "custai": "custar",
    "custais": "custar",
    "custam": "custar",
    "custamo": "custar",
    "custamos": "custar",
    "custando": "custar",
    "custara": "custar",
    "custaram": "custar",
    "custaras": "custar",
    "custarde": "custar",
    "custardes": "custar",
    "custare": "custar",
    "custarei": "custar",
    "custareis": "custar",
    "custarem": "custar",
    "custaremos": "custar",
    "custares": "custar",
    "custaria": "custar",
    "custariam": "custar",
    "custarias": "custar",
    "custarmo": "custar",
    "custarmos": "custar",
    "custará": "custar",
    "custarás": "custar",
    "custarão": "custar",
    "custaríamos": "custar",
    "custaríeis": "custar",
    "custas": "custar",
    "custasse": "custar",
    "custassem": "custar",
    "custasses": "custar",
    "custaste": "custar",
    "custastes": "custar",
    "custava": "custar",
    "custavam": "custar",
    "custavas": "custar",
    "custe": "custar",
    "custeada": "custear",
    "custeadas": "custear",
    "custeado": "custear",
    "custeados": "custear",
    "custeai": "custear",
    "custeais": "custear",
    "custeamentos": "custeamento",
    "custeamo": "custear",
    "custeamos": "custear",
    "custeando": "custear",
    "custeara": "custear",
    "custearam": "custear",
    "custearas": "custear",
    "custearde": "custear",
    "custeardes": "custear",
    "custeare": "custear",
    "custearei": "custear",
    "custeareis": "custear",
    "custearem": "custear",
    "custearemos": "custear",
    "custeares": "custear",
    "custearia": "custear",
    "custeariam": "custear",
    "custearias": "custear",
    "custearmo": "custear",
    "custearmos": "custear",
    "custeará": "custear",
    "custearás": "custear",
    "custearão": "custear",
    "custearíamos": "custear",
    "custearíeis": "custear",
    "custeasse": "custear",
    "custeassem": "custear",
    "custeasses": "custear",
    "custeaste": "custear",
    "custeastes": "custear",
    "custeava": "custear",
    "custeavam": "custear",
    "custeavas": "custear",
    "custeei": "custear",
    "custeeis": "custear",
    "custeemo": "custear",
    "custeemos": "custear",
    "custei": "custar",
    "custeia": "custear",
    "custeiam": "custear",
    "custeias": "custear",
    "custeie": "custear",
    "custeiem": "custear",
    "custeies": "custear",
    "custeio": "custear",
    "custeios": "custeio",
    "custeis": "custar",
    "custem": "custar",
    "custemo": "custar",
    "custemos": "custar",
    "custeou": "custear",
    "custes": "custar",
    "custeá": "custear",
    "custeámo": "custear",
    "custeámos": "custear",
    "custeáramo": "custear",
    "custeáramos": "custear",
    "custeárei": "custear",
    "custeáreis": "custear",
    "custeásseis": "custear",
    "custeássemos": "custear",
    "custeávamo": "custear",
    "custeávamos": "custear",
    "custeávei": "custear",
    "custeáveis": "custear",
    "custo": "custar",
    "custodia": "custodiar",
    "custodiada": "custodiar",
    "custodiadas": "custodiar",
    "custodiado": "custodiar",
    "custodiados": "custodiar",
    "custodiai": "custodiar",
    "custodiais": "custodiar",
    "custodiam": "custodiar",
    "custodiamo": "custodiar",
    "custodiamos": "custodiar",
    "custodiando": "custodiar",
    "custodiara": "custodiar",
    "custodiaram": "custodiar",
    "custodiaras": "custodiar",
    "custodiarde": "custodiar",
    "custodiardes": "custodiar",
    "custodiare": "custodiar",
    "custodiarei": "custodiar",
    "custodiareis": "custodiar",
    "custodiarem": "custodiar",
    "custodiaremos": "custodiar",
    "custodiares": "custodiar",
    "custodiaria": "custodiar",
    "custodiariam": "custodiar",
    "custodiarias": "custodiar",
    "custodiarmo": "custodiar",
    "custodiarmos": "custodiar",
    "custodiará": "custodiar",
    "custodiarás": "custodiar",
    "custodiarão": "custodiar",
    "custodiaríamos": "custodiar",
    "custodiaríeis": "custodiar",
    "custodias": "custodiar",
    "custodiasse": "custodiar",
    "custodiassem": "custodiar",
    "custodiasses": "custodiar",
    "custodiaste": "custodiar",
    "custodiastes": "custodiar",
    "custodiava": "custodiar",
    "custodiavam": "custodiar",
    "custodiavas": "custodiar",
    "custodie": "custodiar",
    "custodiei": "custodiar",
    "custodieis": "custodiar",
    "custodiem": "custodiar",
    "custodiemo": "custodiar",
    "custodiemos": "custodiar",
    "custodies": "custodiar",
    "custodio": "custodiar",
    "custodiou": "custodiar",
    "custodiá": "custodiar",
    "custodiámo": "custodiar",
    "custodiámos": "custodiar",
    "custodiáramo": "custodiar",
    "custodiáramos": "custodiar",
    "custodiárei": "custodiar",
    "custodiáreis": "custodiar",
    "custodiásseis": "custodiar",
    "custodiássemos": "custodiar",
    "custodiávamo": "custodiar",
    "custodiávamos": "custodiar",
    "custodiávei": "custodiar",
    "custodiáveis": "custodiar",
    "custos": "custo",
    "custosa": "custoso",
    "custosas": "custoso",
    "custosos": "custoso",
    "custou": "custar",
    "custá": "custar",
    "custámo": "custar",
    "custámos": "custar",
    "custáramo": "custar",
    "custáramos": "custar",
    "custárei": "custar",
    "custáreis": "custar",
    "custásseis": "custar",
    "custássemos": "custar",
    "custávamo": "custar",
    "custávamos": "custar",
    "custávei": "custar",
    "custáveis": "custar",
    "custódia": "custódio",
    "custódias": "custódio",
    "custódios": "custódio",
    "cutelarias": "cutelaria",
    "cutelas": "cutela",
    "cuteleiros": "cuteleiro",
    "cutelos": "cutelo",
    "cutelões": "cutelão",
    "cutes": "cute",
    "cutias": "cutia",
    "cuticulares": "cuticular",
    "cuticulosa": "cuticuloso",
    "cuticulosas": "cuticuloso",
    "cuticulosos": "cuticuloso",
    "cutiladas": "cutilada",
    "cutilarias": "cutilaria",
    "cutileiros": "cutileiro",
    "cutilões": "cutilão",
    "cutinas": "cutina",
    "cutiniza": "cutinizar",
    "cutinizada": "cutinizar",
    "cutinizadas": "cutinizar",
    "cutinizado": "cutinizar",
    "cutinizados": "cutinizar",
    "cutinizai": "cutinizar",
    "cutinizais": "cutinizar",
    "cutinizam": "cutinizar",
    "cutinizamo": "cutinizar",
    "cutinizamos": "cutinizar",
    "cutinizando": "cutinizar",
    "cutinizara": "cutinizar",
    "cutinizaram": "cutinizar",
    "cutinizaras": "cutinizar",
    "cutinizarde": "cutinizar",
    "cutinizardes": "cutinizar",
    "cutinizare": "cutinizar",
    "cutinizarei": "cutinizar",
    "cutinizareis": "cutinizar",
    "cutinizarem": "cutinizar",
    "cutinizaremos": "cutinizar",
    "cutinizares": "cutinizar",
    "cutinizaria": "cutinizar",
    "cutinizariam": "cutinizar",
    "cutinizarias": "cutinizar",
    "cutinizarmo": "cutinizar",
    "cutinizarmos": "cutinizar",
    "cutinizará": "cutinizar",
    "cutinizarás": "cutinizar",
    "cutinizarão": "cutinizar",
    "cutinizaríamos": "cutinizar",
    "cutinizaríeis": "cutinizar",
    "cutinizas": "cutinizar",
    "cutinizasse": "cutinizar",
    "cutinizassem": "cutinizar",
    "cutinizasses": "cutinizar",
    "cutinizaste": "cutinizar",
    "cutinizastes": "cutinizar",
    "cutinizava": "cutinizar",
    "cutinizavam": "cutinizar",
    "cutinizavas": "cutinizar",
    "cutinizações": "cutinização",
    "cutinize": "cutinizar",
    "cutinizei": "cutinizar",
    "cutinizeis": "cutinizar",
    "cutinizem": "cutinizar",
    "cutinizemo": "cutinizar",
    "cutinizemos": "cutinizar",
    "cutinizes": "cutinizar",
    "cutinizo": "cutinizar",
    "cutinizou": "cutinizar",
    "cutinizá": "cutinizar",
    "cutinizámo": "cutinizar",
    "cutinizámos": "cutinizar",
    "cutinizáramo": "cutinizar",
    "cutinizáramos": "cutinizar",
    "cutinizárei": "cutinizar",
    "cutinizáreis": "cutinizar",
    "cutinizásseis": "cutinizar",
    "cutinizássemos": "cutinizar",
    "cutinizávamo": "cutinizar",
    "cutinizávamos": "cutinizar",
    "cutinizávei": "cutinizar",
    "cutinizáveis": "cutinizar",
    "cutirreações": "cutirreação",
    "cutisa": "cutisar",
    "cutisada": "cutisar",
    "cutisadas": "cutisar",
    "cutisado": "cutisar",
    "cutisados": "cutisar",
    "cutisai": "cutisar",
    "cutisais": "cutisar",
    "cutisam": "cutisar",
    "cutisamo": "cutisar",
    "cutisamos": "cutisar",
    "cutisando": "cutisar",
    "cutisara": "cutisar",
    "cutisaram": "cutisar",
    "cutisaras": "cutisar",
    "cutisarde": "cutisar",
    "cutisardes": "cutisar",
    "cutisare": "cutisar",
    "cutisarei": "cutisar",
    "cutisareis": "cutisar",
    "cutisarem": "cutisar",
    "cutisaremos": "cutisar",
    "cutisares": "cutisar",
    "cutisaria": "cutisar",
    "cutisariam": "cutisar",
    "cutisarias": "cutisar",
    "cutisarmo": "cutisar",
    "cutisarmos": "cutisar",
    "cutisará": "cutisar",
    "cutisarás": "cutisar",
    "cutisarão": "cutisar",
    "cutisaríamos": "cutisar",
    "cutisaríeis": "cutisar",
    "cutisas": "cutisar",
    "cutisasse": "cutisar",
    "cutisassem": "cutisar",
    "cutisasses": "cutisar",
    "cutisaste": "cutisar",
    "cutisastes": "cutisar",
    "cutisava": "cutisar",
    "cutisavam": "cutisar",
    "cutisavas": "cutisar",
    "cutisações": "cutisação",
    "cutise": "cutisar",
    "cutisei": "cutisar",
    "cutiseis": "cutisar",
    "cutisem": "cutisar",
    "cutisemo": "cutisar",
    "cutisemos": "cutisar",
    "cutises": "cutisar",
    "cutiso": "cutisar",
    "cutisou": "cutisar",
    "cutisá": "cutisar",
    "cutisámo": "cutisar",
    "cutisámos": "cutisar",
    "cutisáramo": "cutisar",
    "cutisáramos": "cutisar",
    "cutisárei": "cutisar",
    "cutisáreis": "cutisar",
    "cutisásseis": "cutisar",
    "cutisássemos": "cutisar",
    "cutisávamo": "cutisar",
    "cutisávamos": "cutisar",
    "cutisávei": "cutisar",
    "cutisáveis": "cutisável",
    "cutites": "cutite",
    "cutrelhas": "cutrelha",
    "cutuca": "cutucar",
    "cutucada": "cutucar",
    "cutucadas": "cutucar",
    "cutucado": "cutucar",
    "cutucados": "cutucar",
    "cutucai": "cutucar",
    "cutucais": "cutucar",
    "cutucam": "cutucar",
    "cutucamo": "cutucar",
    "cutucamos": "cutucar",
    "cutucando": "cutucar",
    "cutucara": "cutucar",
    "cutucaram": "cutucar",
    "cutucaras": "cutucar",
    "cutucarde": "cutucar",
    "cutucardes": "cutucar",
    "cutucare": "cutucar",
    "cutucarei": "cutucar",
    "cutucareis": "cutucar",
    "cutucarem": "cutucar",
    "cutucaremos": "cutucar",
    "cutucares": "cutucar",
    "cutucaria": "cutucar",
    "cutucariam": "cutucar",
    "cutucarias": "cutucar",
    "cutucarmo": "cutucar",
    "cutucarmos": "cutucar",
    "cutucará": "cutucar",
    "cutucarás": "cutucar",
    "cutucarão": "cutucar",
    "cutucaríamos": "cutucar",
    "cutucaríeis": "cutucar",
    "cutucas": "cutucar",
    "cutucasse": "cutucar",
    "cutucassem": "cutucar",
    "cutucasses": "cutucar",
    "cutucaste": "cutucar",
    "cutucastes": "cutucar",
    "cutucava": "cutucar",
    "cutucavam": "cutucar",
    "cutucavas": "cutucar",
    "cutuco": "cutucar",
    "cutucou": "cutucar",
    "cutucá": "cutucar",
    "cutucámo": "cutucar",
    "cutucámos": "cutucar",
    "cutucáramo": "cutucar",
    "cutucáramos": "cutucar",
    "cutucárei": "cutucar",
    "cutucáreis": "cutucar",
    "cutucásseis": "cutucar",
    "cutucássemos": "cutucar",
    "cutucávamo": "cutucar",
    "cutucávamos": "cutucar",
    "cutucávei": "cutucar",
    "cutucáveis": "cutucar",
    "cutucões": "cutucão",
    "cutuque": "cutucar",
    "cutuquei": "cutucar",
    "cutuqueis": "cutucar",
    "cutuquem": "cutucar",
    "cutuquemo": "cutucar",
    "cutuquemos": "cutucar",
    "cutuques": "cutucar",
    "cutânea": "cutâneo",
    "cutâneas": "cutâneo",
    "cutâneos": "cutâneo",
    "cutícolas": "cutícola",
    "cutículas": "cutícula",
    "cuvas": "cuva",
    "cuvilheira": "cuvilheiro",
    "cuvilheiras": "cuvilheiro",
    "cuvilheiros": "cuvilheiro",
    "cuviniana": "cuviniano",
    "cuvinianas": "cuviniano",
    "cuvinianos": "cuviniano",
    "cuzadas": "cuzada",
    "cuzapadas": "cuzapada",
    "cuícas": "cuíca",
    "cuís": "cuí",
    "czardas": "czarda",
    "czares": "czar",
    "czarina": "czar",
    "czarinas": "czar",
    "czarismos": "czarismo",
    "czaristas": "czarista",
    "cábreas": "cábrea",
    "cábulas": "cábula",
    "cácimos": "cácimo",
    "cádavas": "cádava",
    "cádis": "cádi",
    "cádmios": "cádmio",
    "cáfilas": "cáfila",
    "cágados": "cágado",
    "cálamos": "cálamo",
    "cálcica": "cálcico",
    "cálcicas": "cálcico",
    "cálcicos": "cálcico",
    "cálcimos": "cálcimo",
    "cálcios": "cálcio",
    "cálculos": "cálculo",
    "cálices": "cálice",
    "cálida": "cálido",
    "cálidas": "cálido",
    "cálidos": "cálido",
    "cáligas": "cáliga",
    "cálixes": "cálix",
    "cápeas": "cápea",
    "cápides": "cápide",
    "cáprea": "cápreo",
    "cápreas": "cápreo",
    "cápreos": "cápreo",
    "cápsulas": "cápsula",
    "cárabos": "cárabo",
    "cáravos": "cáravo",
    "cárbasos": "cárbaso",
    "cárceres": "cárcere",
    "cárdena": "cárdeno",
    "cárdenas": "cárdeno",
    "cárdenos": "cárdeno",
    "cárdias": "cárdia",
    "cárdica": "cárdico",
    "cárdicas": "cárdico",
    "cárdicos": "cárdico",
    "cárdidas": "cárdida",
    "cáries": "cárie",
    "cárnea": "cárneo",
    "cárneas": "cárneo",
    "cárneos": "cárneo",
    "cárpea": "cárpeo",
    "cárpeas": "cárpeo",
    "cárpeos": "cárpeo",
    "cárpica": "cárpico",
    "cárpicas": "cárpico",
    "cárpicos": "cárpico",
    "cársica": "cársico",
    "cársicas": "cársico",
    "cársicos": "cársico",
    "cárstica": "cárstico",
    "cársticas": "cárstico",
    "cársticos": "cárstico",
    "cárteres": "cárter",
    "cártulas": "cártula",
    "cáscaras": "cáscara",
    "cássias": "cássia",
    "cátara": "cátaro",
    "cátaras": "cátaro",
    "cátaros": "cátaro",
    "cátedras": "cátedra",
    "cátodos": "cátodo",
    "cáudices": "cáudice",
    "cáustica": "cáustico",
    "cáusticas": "cáustico",
    "cáusticos": "cáustico",
    "cáveas": "cávea",
    "cávias": "cávia",
    "cáçamos": "cáçamo",
    "câimbras": "câimbra",
    "câimbros": "câimbro",
    "câmaras": "câmara",
    "câmbios": "câmbio",
    "câmbrica": "câmbrico",
    "câmbricas": "câmbrico",
    "câmbricos": "câmbrico",
    "cânaves": "cânave",
    "cânceres": "câncer",
    "cândaces": "cândace",
    "cândida": "cândido",
    "cândidas": "cândido",
    "cândidos": "cândido",
    "cândis": "cândi",
    "cânforas": "cânfora",
    "cânhamos": "cânhamo",
    "cânidas": "cânida",
    "cânones": "cânone",
    "cântabra": "cântabro",
    "cântabras": "cântabro",
    "cântabros": "cântabro",
    "cântaras": "cântara",
    "cântaros": "cântaro",
    "cânticos": "cântico",
    "cânulas": "cânula",
    "cã": "cão",
    "cães": "cão",
    "cãezinhos": "cão",
    "cãezitos": "cão",
    "cãibais": "cãibal",
    "cãibas": "cãiba",
    "cãibeira": "cãibeiro",
    "cãibeiras": "cãibeiro",
    "cãibeiros": "cãibeiro",
    "cãibos": "cãibo",
    "cãibras": "cãibra",
    "cãos": "cão",
    "cãozinho": "cão",
    "cãozito": "cão",
    "cãs": "cão",
    "cédrias": "cédria",
    "cédulas": "cédula",
    "célebres": "célebre",
    "céleres": "célere",
    "célica": "célico",
    "célicas": "célico",
    "célicos": "célico",
    "céltica": "céltico",
    "célticas": "céltico",
    "célticos": "céltico",
    "células": "célula",
    "cénica": "cénico",
    "cénicas": "cénico",
    "cénicos": "cénico",
    "céptica": "céptico",
    "cépticas": "céptico",
    "cépticos": "céptico",
    "céramos": "céramo",
    "cércea": "cérceo",
    "cérceas": "cérceo",
    "cérceos": "cérceo",
    "cérea": "céreo",
    "céreas": "céreo",
    "cérebros": "cérebro",
    "céreos": "céreo",
    "cérios": "cério",
    "cérula": "cérulo",
    "cérulas": "cérulo",
    "cérulos": "cérulo",
    "cérvidas": "cérvida",
    "césares": "césar",
    "césios": "césio",
    "céspedes": "céspede",
    "céus": "céu",
    "cêntimos": "cêntimo",
    "cêntrica": "cêntrico",
    "cêntricas": "cêntrico",
    "cêntricos": "cêntrico",
    "cêntupla": "cêntuplo",
    "cêntuplas": "cêntuplo",
    "cêntuplos": "cêntuplo",
    "cês": "cê",
    "cíamos": "cíamo",
    "cíatos": "cíato",
    "cíbalos": "cíbalo",
    "cíceros": "cícero",
    "cíclades": "cíclade",
    "cíclames": "cíclame",
    "cíclica": "cíclico",
    "cíclicas": "cíclico",
    "cíclicos": "cíclico",
    "cílices": "cílice",
    "cílidas": "cílida",
    "cílios": "cílio",
    "címbalos": "címbalo",
    "cínclises": "cínclise",
    "cíndrica": "cíndrico",
    "cíndricas": "cíndrico",
    "cíndricos": "cíndrico",
    "cíngulos": "cíngulo",
    "cínica": "cínico",
    "cínicas": "cínico",
    "cínicos": "cínico",
    "cíniras": "cínira",
    "cínzea": "cínzeo",
    "cínzeas": "cínzeo",
    "cínzeos": "cínzeo",
    "cípria": "cíprio",
    "cíprias": "cíprio",
    "cíprida": "cíprido",
    "cípridas": "cíprido",
    "cípridos": "cíprido",
    "cíprios": "cíprio",
    "círcios": "círcio",
    "círculos": "círculo",
    "círios": "círio",
    "cística": "cístico",
    "císticas": "cístico",
    "císticos": "cístico",
    "cítaras": "cítara",
    "cítica": "cítico",
    "cíticas": "cítico",
    "cíticos": "cítico",
    "cítolas": "cítola",
    "cítria": "cítrio",
    "cítrias": "cítrio",
    "cítrica": "cítrico",
    "cítricas": "cítrico",
    "cítricos": "cítrico",
    "cítrios": "cítrio",
    "cívea": "cíveo",
    "cíveas": "cíveo",
    "cíveis": "cível",
    "cíveos": "cíveo",
    "cívica": "cívico",
    "cívicas": "cívico",
    "cívicos": "cívico",
    "cóccixes": "cóccix",
    "cócegas": "cócega",
    "cócleas": "cóclea",
    "cócós": "cócó",
    "códegas": "códega",
    "códexes": "códex",
    "códices": "códice",
    "códigos": "código",
    "códões": "códão",
    "cógnita": "cógnito",
    "cógnitas": "cógnito",
    "cógnitos": "cógnito",
    "cóias": "cóia",
    "cóios": "cóio",
    "cóis": "cói",
    "cóleras": "cólera",
    "cólica": "cólico",
    "cólicas": "cólico",
    "cólicos": "cólico",
    "cólofones": "cólofon",
    "cólones": "cólon",
    "cólpodes": "cólpode",
    "cólquicos": "cólquico",
    "cómica": "cómico",
    "cómicas": "cómico",
    "cómicos": "cómico",
    "cómoda": "cómodo",
    "cómodas": "cómodo",
    "cómodos": "cómodo",
    "cónegos": "cónego",
    "cónica": "cónico",
    "cónicas": "cónico",
    "cónicos": "cónico",
    "cónidas": "cónida",
    "cópias": "cópia",
    "cópulas": "cópula",
    "córculos": "córculo",
    "córiones": "córion",
    "córios": "cório",
    "córnea": "córneo",
    "córneas": "córneo",
    "córneos": "córneo",
    "córregos": "córrego",
    "córsica": "córsico",
    "córsicas": "córsico",
    "córsicos": "córsico",
    "córtices": "córtice",
    "córvidas": "córvida",
    "cósmica": "cósmico",
    "cósmicas": "cósmico",
    "cósmicos": "cósmico",
    "cótidas": "cótida",
    "cótilas": "cótila",
    "cótilos": "cótilo",
    "cóvidas": "cóvida",
    "côa": "coar",
    "côas": "coar",
    "côdeas": "côdea",
    "cômaros": "cômaro",
    "cômoros": "cômoro",
    "cômpares": "cômpar",
    "cômpitos": "cômpito",
    "cômputos": "cômputo",
    "côncava": "côncavo",
    "côncavas": "côncavo",
    "côncavos": "côncavo",
    "côndilos": "côndilo",
    "côndrula": "côndrulo",
    "côndrulas": "côndrulo",
    "côndrulos": "côndrulo",
    "côngrua": "côngruo",
    "côngruas": "côngruo",
    "côngruos": "côngruo",
    "cônjuges": "cônjuge",
    "cônscia": "cônscio",
    "cônscias": "cônscio",
    "cônscios": "cônscio",
    "cônsona": "cônsono",
    "cônsonas": "cônsono",
    "cônsonos": "cônsono",
    "cônsules": "cônsul",
    "côva": "côvo",
    "côvados": "côvado",
    "côvas": "côvo",
    "côvos": "côvo",
    "côvões": "côvão",
    "cúbica": "cúbico",
    "cúbicas": "cúbico",
    "cúbicos": "cúbico",
    "cúbitos": "cúbito",
    "cúfica": "cúfico",
    "cúficas": "cúfico",
    "cúficos": "cúfico",
    "cúmplices": "cúmplice",
    "cúmulos": "cúmulo",
    "cúneos": "cúneo",
    "cúpida": "cúpido",
    "cúpidas": "cúpido",
    "cúpidos": "cúpido",
    "cúprica": "cúprico",
    "cúpricas": "cúprico",
    "cúpricos": "cúprico",
    "cúpulas": "cúpula",
    "cúrias": "cúria",
    "cúrios": "cúrio",
    "cúrsios": "cúrsio",
    "cúspides": "cúspide",
    "dablios": "dablio",
    "dabuas": "dabua",
    "daca": "daco",
    "dacas": "daco",
    "dachas": "dacha",
    "dacitos": "dacito",
    "dacmas": "dacma",
    "dacnomanias": "dacnomania",
    "dacomas": "dacoma",
    "dacos": "daco",
    "dacotas": "dacota",
    "dacriadenites": "dacriadenite",
    "dacrioblenorreias": "dacrioblenorreia",
    "dacriocistectomias": "dacriocistectomia",
    "dacriocistites": "dacriocistite",
    "dacrióides": "dacrióide",
    "dactilada": "dactilado",
    "dactiladas": "dactilado",
    "dactilados": "dactilado",
    "dactilina": "dactilino",
    "dactilinas": "dactilino",
    "dactilinos": "dactilino",
    "dactiliografias": "dactiliografia",
    "dactiliomancias": "dactiliomancia",
    "dactiliomantes": "dactiliomante",
    "dactiliotecas": "dactilioteca",
    "dactilofasias": "dactilofasia",
    "dactilografa": "dactilografar",
    "dactilografada": "dactilografar",
    "dactilografadas": "dactilografar",
    "dactilografado": "dactilografar",
    "dactilografados": "dactilografar",
    "dactilografai": "dactilografar",
    "dactilografais": "dactilografar",
    "dactilografam": "dactilografar",
    "dactilografamo": "dactilografar",
    "dactilografamos": "dactilografar",
    "dactilografando": "dactilografar",
    "dactilografara": "dactilografar",
    "dactilografaram": "dactilografar",
    "dactilografaras": "dactilografar",
    "dactilografarde": "dactilografar",
    "dactilografardes": "dactilografar",
    "dactilografare": "dactilografar",
    "dactilografarei": "dactilografar",
    "dactilografareis": "dactilografar",
    "dactilografarem": "dactilografar",
    "dactilografaremos": "dactilografar",
    "dactilografares": "dactilografar",
    "dactilografaria": "dactilografar",
    "dactilografariam": "dactilografar",
    "dactilografarias": "dactilografar",
    "dactilografarmo": "dactilografar",
    "dactilografarmos": "dactilografar",
    "dactilografará": "dactilografar",
    "dactilografarás": "dactilografar",
    "dactilografarão": "dactilografar",
    "dactilografaríamos": "dactilografar",
    "dactilografaríeis": "dactilografar",
    "dactilografas": "dactilografar",
    "dactilografasse": "dactilografar",
    "dactilografassem": "dactilografar",
    "dactilografasses": "dactilografar",
    "dactilografaste": "dactilografar",
    "dactilografastes": "dactilografar",
    "dactilografava": "dactilografar",
    "dactilografavam": "dactilografar",
    "dactilografavas": "dactilografar",
    "dactilografe": "dactilografar",
    "dactilografei": "dactilografar",
    "dactilografeis": "dactilografar",
    "dactilografem": "dactilografar",
    "dactilografemo": "dactilografar",
    "dactilografemos": "dactilografar",
    "dactilografes": "dactilografar",
    "dactilografias": "dactilografia",
    "dactilografo": "dactilografar",
    "dactilografou": "dactilografar",
    "dactilografá": "dactilografar",
    "dactilografámo": "dactilografar",
    "dactilografámos": "dactilografar",
    "dactilografáramo": "dactilografar",
    "dactilografáramos": "dactilografar",
    "dactilografárei": "dactilografar",
    "dactilografáreis": "dactilografar",
    "dactilografásseis": "dactilografar",
    "dactilografássemos": "dactilografar",
    "dactilografávamo": "dactilografar",
    "dactilografávamos": "dactilografar",
    "dactilografávei": "dactilografar",
    "dactilografáveis": "dactilografável",
    "dactilogramas": "dactilograma",
    "dactilográfica": "dactilográfico",
    "dactilográficas": "dactilográfico",
    "dactilográficos": "dactilográfico",
    "dactilologias": "dactilologia",
    "dactilomancias": "dactilomancia",
    "dactiloscopias": "dactiloscopia",
    "dactiloscopistas": "dactiloscopista",
    "dactilotecas": "dactiloteca",
    "dactilozoários": "dactilozoário",
    "dactilífera": "dactilífero",
    "dactilíferas": "dactilífero",
    "dactilíferos": "dactilífero",
    "dactilógrafa": "dactilógrafo",
    "dactilógrafas": "dactilógrafo",
    "dactilógrafos": "dactilógrafo",
    "dactílica": "dactílico",
    "dactílicas": "dactílico",
    "dactílicos": "dactílico",
    "dada": "dar",
    "dadanes": "dadane",
    "dadas": "dar",
    "dadaísmos": "dadaísmo",
    "dadaístas": "dadaísta",
    "dadeiras": "dadeira",
    "dadiva": "dadivar",
    "dadivada": "dadivar",
    "dadivadas": "dadivar",
    "dadivado": "dadivar",
    "dadivados": "dadivar",
    "dadivai": "dadivar",
    "dadivais": "dadivar",
    "dadivam": "dadivar",
    "dadivamo": "dadivar",
    "dadivamos": "dadivar",
    "dadivando": "dadivar",
    "dadivara": "dadivar",
    "dadivaram": "dadivar",
    "dadivaras": "dadivar",
    "dadivarde": "dadivar",
    "dadivardes": "dadivar",
    "dadivare": "dadivar",
    "dadivarei": "dadivar",
    "dadivareis": "dadivar",
    "dadivarem": "dadivar",
    "dadivaremos": "dadivar",
    "dadivares": "dadivar",
    "dadivaria": "dadivar",
    "dadivariam": "dadivar",
    "dadivarias": "dadivar",
    "dadivarmo": "dadivar",
    "dadivarmos": "dadivar",
    "dadivará": "dadivar",
    "dadivarás": "dadivar",
    "dadivarão": "dadivar",
    "dadivaríamos": "dadivar",
    "dadivaríeis": "dadivar",
    "dadivas": "dadivar",
    "dadivasse": "dadivar",
    "dadivassem": "dadivar",
    "dadivasses": "dadivar",
    "dadivaste": "dadivar",
    "dadivastes": "dadivar",
    "dadivava": "dadivar",
    "dadivavam": "dadivar",
    "dadivavas": "dadivar",
    "dadive": "dadivar",
    "dadivei": "dadivar",
    "dadiveis": "dadivar",
    "dadivem": "dadivar",
    "dadivemo": "dadivar",
    "dadivemos": "dadivar",
    "dadives": "dadivar",
    "dadivo": "dadivar",
    "dadivosa": "dadivoso",
    "dadivosas": "dadivoso",
    "dadivosos": "dadivoso",
    "dadivou": "dadivar",
    "dadivá": "dadivar",
    "dadivámo": "dadivar",
    "dadivámos": "dadivar",
    "dadiváramo": "dadivar",
    "dadiváramos": "dadivar",
    "dadivárei": "dadivar",
    "dadiváreis": "dadivar",
    "dadivásseis": "dadivar",
    "dadivássemos": "dadivar",
    "dadivávamo": "dadivar",
    "dadivávamos": "dadivar",
    "dadivávei": "dadivar",
    "dadiváveis": "dadivar",
    "dado": "dar",
    "dadora": "dador",
    "dadoras": "dador",
    "dadores": "dador",
    "dados": "dar",
    "dafnites": "dafnite",
    "dafnácea": "dafnáceo",
    "dafnáceas": "dafnáceo",
    "dafnáceos": "dafnáceo",
    "dafnéfora": "dafnéforo",
    "dafnéforas": "dafnéforo",
    "dafnéforos": "dafnéforo",
    "dafnídeas": "dafnídea",
    "dafnídeos": "dafnídeo",
    "daguerreotipa": "daguerreotipar",
    "daguerreotipada": "daguerreotipar",
    "daguerreotipadas": "daguerreotipar",
    "daguerreotipado": "daguerreotipar",
    "daguerreotipados": "daguerreotipar",
    "daguerreotipai": "daguerreotipar",
    "daguerreotipais": "daguerreotipar",
    "daguerreotipam": "daguerreotipar",
    "daguerreotipamo": "daguerreotipar",
    "daguerreotipamos": "daguerreotipar",
    "daguerreotipando": "daguerreotipar",
    "daguerreotipara": "daguerreotipar",
    "daguerreotiparam": "daguerreotipar",
    "daguerreotiparas": "daguerreotipar",
    "daguerreotiparde": "daguerreotipar",
    "daguerreotipardes": "daguerreotipar",
    "daguerreotipare": "daguerreotipar",
    "daguerreotiparei": "daguerreotipar",
    "daguerreotipareis": "daguerreotipar",
    "daguerreotiparem": "daguerreotipar",
    "daguerreotiparemos": "daguerreotipar",
    "daguerreotipares": "daguerreotipar",
    "daguerreotiparia": "daguerreotipar",
    "daguerreotipariam": "daguerreotipar",
    "daguerreotiparias": "daguerreotipar",
    "daguerreotiparmo": "daguerreotipar",
    "daguerreotiparmos": "daguerreotipar",
    "daguerreotipará": "daguerreotipar",
    "daguerreotiparás": "daguerreotipar",
    "daguerreotiparão": "daguerreotipar",
    "daguerreotiparíamos": "daguerreotipar",
    "daguerreotiparíeis": "daguerreotipar",
    "daguerreotipas": "daguerreotipar",
    "daguerreotipasse": "daguerreotipar",
    "daguerreotipassem": "daguerreotipar",
    "daguerreotipasses": "daguerreotipar",
    "daguerreotipaste": "daguerreotipar",
    "daguerreotipastes": "daguerreotipar",
    "daguerreotipava": "daguerreotipar",
    "daguerreotipavam": "daguerreotipar",
    "daguerreotipavas": "daguerreotipar",
    "daguerreotipe": "daguerreotipar",
    "daguerreotipei": "daguerreotipar",
    "daguerreotipeis": "daguerreotipar",
    "daguerreotipem": "daguerreotipar",
    "daguerreotipemo": "daguerreotipar",
    "daguerreotipemos": "daguerreotipar",
    "daguerreotipes": "daguerreotipar",
    "daguerreotipias": "daguerreotipia",
    "daguerreotipo": "daguerreotipar",
    "daguerreotipou": "daguerreotipar",
    "daguerreotipá": "daguerreotipar",
    "daguerreotipámo": "daguerreotipar",
    "daguerreotipámos": "daguerreotipar",
    "daguerreotipáramo": "daguerreotipar",
    "daguerreotipáramos": "daguerreotipar",
    "daguerreotipárei": "daguerreotipar",
    "daguerreotipáreis": "daguerreotipar",
    "daguerreotipásseis": "daguerreotipar",
    "daguerreotipássemos": "daguerreotipar",
    "daguerreotipávamo": "daguerreotipar",
    "daguerreotipávamos": "daguerreotipar",
    "daguerreotipávei": "daguerreotipar",
    "daguerreotipáveis": "daguerreotipar",
    "daguerreótipos": "daguerreótipo",
    "dai": "dar",
    "daimiados": "daimiado",
    "daimiatos": "daimiato",
    "daiquiris": "daiquiri",
    "dais": "dar",
    "dalas": "dala",
    "dalinas": "dalina",
    "dalmanites": "dalmanite",
    "dalmáticas": "dalmática",
    "daltonismos": "daltonismo",
    "daltónica": "daltónico",
    "daltónicas": "daltónico",
    "daltónicos": "daltónico",
    "daltônica": "daltônico",
    "daltônicas": "daltônico",
    "daltônicos": "daltônico",
    "damacuris": "damacuri",
    "damanenses": "damanense",
    "damarias": "damaria",
    "damas": "dama",
    "damascena": "damasceno",
    "damascenas": "damasceno",
    "damascenos": "damasceno",
    "damascos": "damasco",
    "damasqueiros": "damasqueiro",
    "damasquilhos": "damasquilho",
    "damasquina": "damasquino",
    "damasquinada": "damasquinar",
    "damasquinadas": "damasquinar",
    "damasquinado": "damasquinar",
    "damasquinados": "damasquinar",
    "damasquinagens": "damasquinagem",
    "damasquinai": "damasquinar",
    "damasquinais": "damasquinar",
    "damasquinam": "damasquinar",
    "damasquinamo": "damasquinar",
    "damasquinamos": "damasquinar",
    "damasquinando": "damasquinar",
    "damasquinara": "damasquinar",
    "damasquinaram": "damasquinar",
    "damasquinaras": "damasquinar",
    "damasquinarde": "damasquinar",
    "damasquinardes": "damasquinar",
    "damasquinare": "damasquinar",
    "damasquinarei": "damasquinar",
    "damasquinareis": "damasquinar",
    "damasquinarem": "damasquinar",
    "damasquinaremos": "damasquinar",
    "damasquinares": "damasquinar",
    "damasquinaria": "damasquinar",
    "damasquinariam": "damasquinar",
    "damasquinarias": "damasquinaria",
    "damasquinarmo": "damasquinar",
    "damasquinarmos": "damasquinar",
    "damasquinará": "damasquinar",
    "damasquinarás": "damasquinar",
    "damasquinarão": "damasquinar",
    "damasquinaríamos": "damasquinar",
    "damasquinaríeis": "damasquinar",
    "damasquinas": "damasquino",
    "damasquinasse": "damasquinar",
    "damasquinassem": "damasquinar",
    "damasquinasses": "damasquinar",
    "damasquinaste": "damasquinar",
    "damasquinastes": "damasquinar",
    "damasquinava": "damasquinar",
    "damasquinavam": "damasquinar",
    "damasquinavas": "damasquinar",
    "damasquine": "damasquinar",
    "damasquinei": "damasquinar",
    "damasquineis": "damasquinar",
    "damasquinem": "damasquinar",
    "damasquinemo": "damasquinar",
    "damasquinemos": "damasquinar",
    "damasquines": "damasquinar",
    "damasquino": "damasquinar",
    "damasquinos": "damasquino",
    "damasquinou": "damasquinar",
    "damasquiná": "damasquinar",
    "damasquinámo": "damasquinar",
    "damasquinámos": "damasquinar",
    "damasquináramo": "damasquinar",
    "damasquináramos": "damasquinar",
    "damasquinárei": "damasquinar",
    "damasquináreis": "damasquinar",
    "damasquinásseis": "damasquinar",
    "damasquinássemos": "damasquinar",
    "damasquinávamo": "damasquinar",
    "damasquinávamos": "damasquinar",
    "damasquinávei": "damasquinar",
    "damasquináveis": "damasquinar",
    "damaísmos": "damaísmo",
    "damianistas": "damianista",
    "damices": "damice",
    "damismos": "damismo",
    "damo": "dar",
    "damos": "dar",
    "dana": "danar",
    "danada": "danar",
    "danadas": "danar",
    "danado": "danar",
    "danadora": "danador",
    "danadoras": "danador",
    "danadores": "danador",
    "danados": "danar",
    "danadíssima": "danado",
    "danadíssimas": "danado",
    "danadíssimo": "danado",
    "danadíssimos": "danado",
    "danai": "danar",
    "danaidas": "danaida",
    "danaides": "danaide",
    "danais": "danar",
    "danam": "danar",
    "danamentos": "danamento",
    "danamo": "danar",
    "danamos": "danar",
    "danando": "danar",
    "danara": "danar",
    "danaram": "danar",
    "danaras": "danar",
    "danarde": "danar",
    "danardes": "danar",
    "danare": "danar",
    "danarei": "danar",
    "danareis": "danar",
    "danarem": "danar",
    "danaremos": "danar",
    "danares": "danar",
    "danaria": "danar",
    "danariam": "danar",
    "danarias": "danar",
    "danarmo": "danar",
    "danarmos": "danar",
    "danará": "danar",
    "danarás": "danar",
    "danarão": "danar",
    "danaríamos": "danar",
    "danaríeis": "danar",
    "danas": "danar",
    "danasse": "danar",
    "danassem": "danar",
    "danasses": "danar",
    "danaste": "danar",
    "danastes": "danar",
    "danava": "danar",
    "danavam": "danar",
    "danavas": "danar",
    "danações": "danação",
    "dance": "dançar",
    "dancei": "dançar",
    "danceis": "dançar",
    "dancem": "dançar",
    "dancemo": "dançar",
    "dancemos": "dançar",
    "dances": "dançar",
    "dancings": "dancing",
    "dandies": "dandy",
    "dandina": "dandinar",
    "dandinada": "dandinar",
    "dandinadas": "dandinar",
    "dandinado": "dandinar",
    "dandinados": "dandinar",
    "dandinai": "dandinar",
    "dandinais": "dandinar",
    "dandinam": "dandinar",
    "dandinamo": "dandinar",
    "dandinamos": "dandinar",
    "dandinando": "dandinar",
    "dandinara": "dandinar",
    "dandinaram": "dandinar",
    "dandinaras": "dandinar",
    "dandinardes": "dandinar",
    "dandinarei": "dandinar",
    "dandinareis": "dandinar",
    "dandinarem": "dandinar",
    "dandinaremos": "dandinar",
    "dandinares": "dandinar",
    "dandinaria": "dandinar",
    "dandinariam": "dandinar",
    "dandinarias": "dandinar",
    "dandinarmo": "dandinar",
    "dandinarmos": "dandinar",
    "dandinará": "dandinar",
    "dandinarás": "dandinar",
    "dandinarão": "dandinar",
    "dandinaríamos": "dandinar",
    "dandinaríeis": "dandinar",
    "dandinas": "dandinar",
    "dandinasse": "dandinar",
    "dandinassem": "dandinar",
    "dandinasses": "dandinar",
    "dandinaste": "dandinar",
    "dandinastes": "dandinar",
    "dandinava": "dandinar",
    "dandinavam": "dandinar",
    "dandinavas": "dandinar",
    "dandine": "dandinar",
    "dandinei": "dandinar",
    "dandineis": "dandinar",
    "dandinem": "dandinar",
    "dandinemo": "dandinar",
    "dandinemos": "dandinar",
    "dandines": "dandinar",
    "dandino": "dandinar",
    "dandinou": "dandinar",
    "dandinámo": "dandinar",
    "dandinámos": "dandinar",
    "dandináramo": "dandinar",
    "dandináramos": "dandinar",
    "dandináreis": "dandinar",
    "dandinásseis": "dandinar",
    "dandinássemos": "dandinar",
    "dandinávamo": "dandinar",
    "dandinávamos": "dandinar",
    "dandináveis": "dandinar",
    "dandismos": "dandismo",
    "dando": "dar",
    "dandões": "dandão",
    "dane": "danar",
    "danei": "danar",
    "daneis": "danar",
    "danem": "danar",
    "danemo": "danar",
    "danemos": "danar",
    "danes": "danar",
    "danifica": "danificar",
    "danificada": "danificar",
    "danificadas": "danificar",
    "danificado": "danificar",
    "danificadora": "danificador",
    "danificadoras": "danificador",
    "danificadores": "danificador",
    "danificados": "danificar",
    "danificai": "danificar",
    "danificais": "danificar",
    "danificam": "danificar",
    "danificamo": "danificar",
    "danificamos": "danificar",
    "danificando": "danificar",
    "danificara": "danificar",
    "danificaram": "danificar",
    "danificaras": "danificar",
    "danificarde": "danificar",
    "danificardes": "danificar",
    "danificare": "danificar",
    "danificarei": "danificar",
    "danificareis": "danificar",
    "danificarem": "danificar",
    "danificaremos": "danificar",
    "danificares": "danificar",
    "danificaria": "danificar",
    "danificariam": "danificar",
    "danificarias": "danificar",
    "danificarmo": "danificar",
    "danificarmos": "danificar",
    "danificará": "danificar",
    "danificarás": "danificar",
    "danificarão": "danificar",
    "danificaríamos": "danificar",
    "danificaríeis": "danificar",
    "danificas": "danificar",
    "danificasse": "danificar",
    "danificassem": "danificar",
    "danificasses": "danificar",
    "danificaste": "danificar",
    "danificastes": "danificar",
    "danificava": "danificar",
    "danificavam": "danificar",
    "danificavas": "danificar",
    "danificações": "danificação",
    "danifico": "danificar",
    "danificou": "danificar",
    "danificá": "danificar",
    "danificámo": "danificar",
    "danificámos": "danificar",
    "danificáramo": "danificar",
    "danificáramos": "danificar",
    "danificárei": "danificar",
    "danificáreis": "danificar",
    "danificásseis": "danificar",
    "danificássemos": "danificar",
    "danificávamo": "danificar",
    "danificávamos": "danificar",
    "danificávei": "danificar",
    "danificáveis": "danificável",
    "danifique": "danificar",
    "danifiquei": "danificar",
    "danifiqueis": "danificar",
    "danifiquem": "danificar",
    "danifiquemo": "danificar",
    "danifiquemos": "danificar",
    "danifiques": "danificar",
    "daninha": "daninho",
    "daninhada": "daninhar",
    "daninhadas": "daninhar",
    "daninhado": "daninhar",
    "daninhados": "daninhar",
    "daninhai": "daninhar",
    "daninhais": "daninhar",
    "daninham": "daninhar",
    "daninhamo": "daninhar",
    "daninhamos": "daninhar",
    "daninhando": "daninhar",
    "daninhara": "daninhar",
    "daninharam": "daninhar",
    "daninharas": "daninhar",
    "daninharde": "daninhar",
    "daninhardes": "daninhar",
    "daninhare": "daninhar",
    "daninharei": "daninhar",
    "daninhareis": "daninhar",
    "daninharem": "daninhar",
    "daninharemos": "daninhar",
    "daninhares": "daninhar",
    "daninharia": "daninhar",
    "daninhariam": "daninhar",
    "daninharias": "daninhar",
    "daninharmo": "daninhar",
    "daninharmos": "daninhar",
    "daninhará": "daninhar",
    "daninharás": "daninhar",
    "daninharão": "daninhar",
    "daninharíamos": "daninhar",
    "daninharíeis": "daninhar",
    "daninhas": "daninho",
    "daninhasse": "daninhar",
    "daninhassem": "daninhar",
    "daninhasses": "daninhar",
    "daninhaste": "daninhar",
    "daninhastes": "daninhar",
    "daninhava": "daninhar",
    "daninhavam": "daninhar",
    "daninhavas": "daninhar",
    "daninhe": "daninhar",
    "daninhei": "daninhar",
    "daninheis": "daninhar",
    "daninhem": "daninhar",
    "daninhemo": "daninhar",
    "daninhemos": "daninhar",
    "daninhes": "daninhar",
    "daninho": "daninhar",
    "daninhos": "daninho",
    "daninhou": "daninhar",
    "daninhá": "daninhar",
    "daninhámo": "daninhar",
    "daninhámos": "daninhar",
    "daninháramo": "daninhar",
    "daninháramos": "daninhar",
    "daninhárei": "daninhar",
    "daninháreis": "daninhar",
    "daninhásseis": "daninhar",
    "daninhássemos": "daninhar",
    "daninhávamo": "daninhar",
    "daninhávamos": "daninhar",
    "daninhávei": "daninhar",
    "daninháveis": "daninhar",
    "dano": "danar",
    "danos": "dano",
    "danosa": "danoso",
    "danosas": "danoso",
    "danosos": "danoso",
    "danou": "danar",
    "dantesca": "dantesco",
    "dantescas": "dantesco",
    "dantescos": "dantesco",
    "danubiana": "danubiano",
    "danubianas": "danubiano",
    "danubianos": "danubiano",
    "daná": "danar",
    "danámo": "danar",
    "danámos": "danar",
    "danáramo": "danar",
    "danáramos": "danar",
    "danárei": "danar",
    "danáreis": "danar",
    "danásseis": "danar",
    "danássemos": "danar",
    "danávamo": "danar",
    "danávamos": "danar",
    "danávei": "danar",
    "danáveis": "danar",
    "dança": "dançar",
    "dançada": "dançar",
    "dançadas": "dançar",
    "dançadeira": "dançador",
    "dançadeiras": "dançador",
    "dançado": "dançar",
    "dançadora": "dançador",
    "dançadoras": "dançador",
    "dançadores": "dançador",
    "dançados": "dançar",
    "dançai": "dançar",
    "dançais": "dançar",
    "dançam": "dançar",
    "dançamo": "dançar",
    "dançamos": "dançar",
    "dançando": "dançar",
    "dançantes": "dançante",
    "dançara": "dançar",
    "dançaram": "dançar",
    "dançaras": "dançar",
    "dançarde": "dançar",
    "dançardes": "dançar",
    "dançare": "dançar",
    "dançarei": "dançar",
    "dançareis": "dançar",
    "dançarem": "dançar",
    "dançaremos": "dançar",
    "dançares": "dançar",
    "dançaria": "dançar",
    "dançariam": "dançar",
    "dançarias": "dançar",
    "dançarina": "dançarino",
    "dançarinas": "dançarino",
    "dançarinos": "dançarino",
    "dançarmo": "dançar",
    "dançarmos": "dançar",
    "dançarolas": "dançarola",
    "dançará": "dançar",
    "dançarás": "dançar",
    "dançarão": "dançar",
    "dançaríamos": "dançar",
    "dançaríeis": "dançar",
    "danças": "dançar",
    "dançasse": "dançar",
    "dançassem": "dançar",
    "dançasses": "dançar",
    "dançaste": "dançar",
    "dançastes": "dançar",
    "dançatas": "dançata",
    "dançatrizes": "dançatriz",
    "dançava": "dançar",
    "dançavam": "dançar",
    "dançavas": "dançar",
    "danço": "dançar",
    "dançou": "dançar",
    "dançá": "dançar",
    "dançámo": "dançar",
    "dançámos": "dançar",
    "dançáramo": "dançar",
    "dançáramos": "dançar",
    "dançárei": "dançar",
    "dançáreis": "dançar",
    "dançásseis": "dançar",
    "dançássemos": "dançar",
    "dançávamo": "dançar",
    "dançávamos": "dançar",
    "dançávei": "dançar",
    "dançáveis": "dançável",
    "danífica": "danífico",
    "daníficas": "danífico",
    "daníficos": "danífico",
    "dapiferatos": "dapiferato",
    "dapíferos": "dapífero",
    "darandinas": "darandina",
    "darbismos": "darbismo",
    "darbistas": "darbista",
    "darda": "dardar",
    "dardada": "dardar",
    "dardadas": "dardar",
    "dardado": "dardar",
    "dardados": "dardar",
    "dardai": "dardar",
    "dardais": "dardar",
    "dardam": "dardar",
    "dardamo": "dardar",
    "dardamos": "dardar",
    "dardando": "dardar",
    "dardara": "dardar",
    "dardaram": "dardar",
    "dardaras": "dardar",
    "dardarde": "dardar",
    "dardardes": "dardar",
    "dardare": "dardar",
    "dardarei": "dardar",
    "dardareis": "dardar",
    "dardarem": "dardar",
    "dardaremos": "dardar",
    "dardares": "dardar",
    "dardaria": "dardar",
    "dardariam": "dardar",
    "dardarias": "dardar",
    "dardarmo": "dardar",
    "dardarmos": "dardar",
    "dardará": "dardar",
    "dardarás": "dardar",
    "dardarão": "dardar",
    "dardaríamos": "dardar",
    "dardaríeis": "dardar",
    "dardas": "dardar",
    "dardasse": "dardar",
    "dardassem": "dardar",
    "dardasses": "dardar",
    "dardaste": "dardar",
    "dardastes": "dardar",
    "dardava": "dardar",
    "dardavam": "dardar",
    "dardavas": "dardar",
    "darde": "dardar",
    "dardei": "dardar",
    "dardeis": "dardar",
    "dardeja": "dardejar",
    "dardejada": "dardejar",
    "dardejadas": "dardejar",
    "dardejado": "dardejar",
    "dardejados": "dardejar",
    "dardejai": "dardejar",
    "dardejais": "dardejar",
    "dardejam": "dardejar",
    "dardejamentos": "dardejamento",
    "dardejamo": "dardejar",
    "dardejamos": "dardejar",
    "dardejando": "dardejar",
    "dardejantes": "dardejante",
    "dardejara": "dardejar",
    "dardejaram": "dardejar",
    "dardejaras": "dardejar",
    "dardejarde": "dardejar",
    "dardejardes": "dardejar",
    "dardejare": "dardejar",
    "dardejarei": "dardejar",
    "dardejareis": "dardejar",
    "dardejarem": "dardejar",
    "dardejaremos": "dardejar",
    "dardejares": "dardejar",
    "dardejaria": "dardejar",
    "dardejariam": "dardejar",
    "dardejarias": "dardejar",
    "dardejarmo": "dardejar",
    "dardejarmos": "dardejar",
    "dardejará": "dardejar",
    "dardejarás": "dardejar",
    "dardejarão": "dardejar",
    "dardejaríamos": "dardejar",
    "dardejaríeis": "dardejar",
    "dardejas": "dardejar",
    "dardejasse": "dardejar",
    "dardejassem": "dardejar",
    "dardejasses": "dardejar",
    "dardejaste": "dardejar",
    "dardejastes": "dardejar",
    "dardejava": "dardejar",
    "dardejavam": "dardejar",
    "dardejavas": "dardejar",
    "dardeje": "dardejar",
    "dardejei": "dardejar",
    "dardejeis": "dardejar",
    "dardejem": "dardejar",
    "dardejemo": "dardejar",
    "dardejemos": "dardejar",
    "dardejes": "dardejar",
    "dardejo": "dardejar",
    "dardejou": "dardejar",
    "dardejá": "dardejar",
    "dardejámo": "dardejar",
    "dardejámos": "dardejar",
    "dardejáramo": "dardejar",
    "dardejáramos": "dardejar",
    "dardejárei": "dardejar",
    "dardejáreis": "dardejar",
    "dardejásseis": "dardejar",
    "dardejássemos": "dardejar",
    "dardejávamo": "dardejar",
    "dardejávamos": "dardejar",
    "dardejávei": "dardejar",
    "dardejáveis": "dardejar",
    "dardem": "dardar",
    "dardemo": "dardar",
    "dardemos": "dardar",
    "dardes": "dardar",
    "dardo": "dardar",
    "dardos": "dardo",
    "dardou": "dardar",
    "dardá": "dardar",
    "dardámo": "dardar",
    "dardámos": "dardar",
    "dardáramo": "dardar",
    "dardáramos": "dardar",
    "dardárei": "dardar",
    "dardáreis": "dardar",
    "dardásseis": "dardar",
    "dardássemos": "dardar",
    "dardávamo": "dardar",
    "dardávamos": "dardar",
    "dardávei": "dardar",
    "dardáveis": "dardar",
    "dardânia": "dardânio",
    "dardânias": "dardânio",
    "dardânios": "dardânio",
    "dare": "dar",
    "darei": "dar",
    "dareis": "dar",
    "darem": "dar",
    "daremos": "dar",
    "dares": "dar",
    "daria": "dar",
    "dariam": "dar",
    "darias": "dar",
    "darmadeiras": "darmadeira",
    "darmo": "dar",
    "darmos": "dar",
    "dartos": "darto",
    "dartrosa": "dartroso",
    "dartrosas": "dartroso",
    "dartrosos": "dartroso",
    "darwinismos": "darwinismo",
    "darwinistas": "darwinista",
    "dará": "dar",
    "darás": "dar",
    "darão": "dar",
    "daríamos": "dar",
    "daríeis": "dar",
    "dasipodídeos": "dasipodídeo",
    "dasipódidas": "dasipódida",
    "dasiurídeos": "dasiurídeo",
    "dasiúridas": "dasiúrida",
    "dasípodes": "dasípode",
    "data": "datar",
    "datada": "datar",
    "datadas": "datar",
    "datado": "datar",
    "datadora": "datador",
    "datadoras": "datador",
    "datadores": "datador",
    "datados": "datar",
    "datai": "datar",
    "datais": "datar",
    "datam": "datar",
    "datamo": "datar",
    "datamos": "datar",
    "datando": "datar",
    "datara": "datar",
    "dataram": "datar",
    "dataras": "datar",
    "datarde": "datar",
    "datardes": "datar",
    "datare": "datar",
    "datarei": "datar",
    "datareis": "datar",
    "datarem": "datar",
    "dataremos": "datar",
    "datares": "datar",
    "dataria": "datar",
    "datariam": "datar",
    "datarias": "dataria",
    "datarmo": "datar",
    "datarmos": "datar",
    "datará": "datar",
    "datarás": "datar",
    "datarão": "datar",
    "dataríamos": "datar",
    "dataríeis": "datar",
    "datas": "datar",
    "datasse": "datar",
    "datassem": "datar",
    "datasses": "datar",
    "dataste": "datar",
    "datastes": "datar",
    "datava": "datar",
    "datavam": "datar",
    "datavas": "datar",
    "datações": "datação",
    "date": "datar",
    "datei": "datar",
    "dateis": "datar",
    "datem": "datar",
    "datemo": "datar",
    "datemos": "datar",
    "dates": "datar",
    "datilada": "datilado",
    "datiladas": "datilado",
    "datilados": "datilado",
    "datileiras": "datileira",
    "datiscinas": "datiscina",
    "datiscáceas": "datiscácea",
    "datismos": "datismo",
    "dativa": "dativo",
    "dativas": "dativo",
    "dativos": "dativo",
    "dato": "datar",
    "datolites": "datolite",
    "datou": "datar",
    "daturas": "datura",
    "daturismos": "daturismo",
    "datá": "datar",
    "datámo": "datar",
    "datámos": "datar",
    "datáramo": "datar",
    "datáramos": "datar",
    "datárei": "datar",
    "datáreis": "datar",
    "datários": "datário",
    "datásseis": "datar",
    "datássemos": "datar",
    "datávamo": "datar",
    "datávamos": "datar",
    "datávei": "datar",
    "datáveis": "datar",
    "datíscea": "datísceo",
    "datísceas": "datísceo",
    "datísceos": "datísceo",
    "dauciformes": "dauciforme",
    "daucíneas": "daucínea",
    "dava": "dar",
    "davam": "dar",
    "davas": "dar",
    "davídica": "davídico",
    "davídicas": "davídico",
    "davídicos": "davídico",
    "dações": "dação",
    "deados": "deado",
    "dealba": "dealbar",
    "dealbada": "dealbar",
    "dealbadas": "dealbar",
    "dealbado": "dealbar",
    "dealbados": "dealbar",
    "dealbai": "dealbar",
    "dealbais": "dealbar",
    "dealbam": "dealbar",
    "dealbamo": "dealbar",
    "dealbamos": "dealbar",
    "dealbando": "dealbar",
    "dealbara": "dealbar",
    "dealbaram": "dealbar",
    "dealbaras": "dealbar",
    "dealbarde": "dealbar",
    "dealbardes": "dealbar",
    "dealbare": "dealbar",
    "dealbarei": "dealbar",
    "dealbareis": "dealbar",
    "dealbarem": "dealbar",
    "dealbaremos": "dealbar",
    "dealbares": "dealbar",
    "dealbaria": "dealbar",
    "dealbariam": "dealbar",
    "dealbarias": "dealbar",
    "dealbarmo": "dealbar",
    "dealbarmos": "dealbar",
    "dealbará": "dealbar",
    "dealbarás": "dealbar",
    "dealbarão": "dealbar",
    "dealbaríamos": "dealbar",
    "dealbaríeis": "dealbar",
    "dealbas": "dealbar",
    "dealbasse": "dealbar",
    "dealbassem": "dealbar",
    "dealbasses": "dealbar",
    "dealbaste": "dealbar",
    "dealbastes": "dealbar",
    "dealbava": "dealbar",
    "dealbavam": "dealbar",
    "dealbavas": "dealbar",
    "dealbações": "dealbação",
    "dealbe": "dealbar",
    "dealbei": "dealbar",
    "dealbeis": "dealbar",
    "dealbem": "dealbar",
    "dealbemo": "dealbar",
    "dealbemos": "dealbar",
    "dealbes": "dealbar",
    "dealbo": "dealbar",
    "dealbos": "dealbo",
    "dealbou": "dealbar",
    "dealbá": "dealbar",
    "dealbámo": "dealbar",
    "dealbámos": "dealbar",
    "dealbáramo": "dealbar",
    "dealbáramos": "dealbar",
    "dealbárei": "dealbar",
    "dealbáreis": "dealbar",
    "dealbásseis": "dealbar",
    "dealbássemos": "dealbar",
    "dealbávamo": "dealbar",
    "dealbávamos": "dealbar",
    "dealbávei": "dealbar",
    "dealbáveis": "dealbar",
    "deambula": "deambular",
    "deambulada": "deambular",
    "deambuladas": "deambular",
    "deambulado": "deambular",
    "deambuladora": "deambulador",
    "deambuladoras": "deambulador",
    "deambuladores": "deambulador",
    "deambulados": "deambular",
    "deambulai": "deambular",
    "deambulais": "deambular",
    "deambulam": "deambular",
    "deambulamo": "deambular",
    "deambulamos": "deambular",
    "deambulando": "deambular",
    "deambulantes": "deambulante",
    "deambulara": "deambular",
    "deambularam": "deambular",
    "deambularas": "deambular",
    "deambulardes": "deambular",
    "deambularei": "deambular",
    "deambulareis": "deambular",
    "deambularem": "deambular",
    "deambularemos": "deambular",
    "deambulares": "deambular",
    "deambularia": "deambular",
    "deambulariam": "deambular",
    "deambularias": "deambular",
    "deambularmo": "deambular",
    "deambularmos": "deambular",
    "deambulará": "deambular",
    "deambularás": "deambular",
    "deambularão": "deambular",
    "deambularíamos": "deambular",
    "deambularíeis": "deambular",
    "deambulas": "deambular",
    "deambulasse": "deambular",
    "deambulassem": "deambular",
    "deambulasses": "deambular",
    "deambulaste": "deambular",
    "deambulastes": "deambular",
    "deambulatória": "deambulatório",
    "deambulatórias": "deambulatório",
    "deambulatórios": "deambulatório",
    "deambulava": "deambular",
    "deambulavam": "deambular",
    "deambulavas": "deambular",
    "deambulações": "deambulação",
    "deambule": "deambular",
    "deambulei": "deambular",
    "deambuleis": "deambular",
    "deambulem": "deambular",
    "deambulemo": "deambular",
    "deambulemos": "deambular",
    "deambules": "deambular",
    "deambulismos": "deambulismo",
    "deambulo": "deambular",
    "deambulou": "deambular",
    "deambulámo": "deambular",
    "deambulámos": "deambular",
    "deambuláramo": "deambular",
    "deambuláramos": "deambular",
    "deambuláreis": "deambular",
    "deambulásseis": "deambular",
    "deambulássemos": "deambular",
    "deambulávamo": "deambular",
    "deambulávamos": "deambular",
    "deambuláveis": "deambular",
    "dearticula": "dearticular",
    "dearticulada": "dearticular",
    "dearticuladas": "dearticular",
    "dearticulado": "dearticular",
    "dearticulados": "dearticular",
    "dearticulai": "dearticular",
    "dearticulais": "dearticular",
    "dearticulam": "dearticular",
    "dearticulamo": "dearticular",
    "dearticulamos": "dearticular",
    "dearticulando": "dearticular",
    "dearticulara": "dearticular",
    "dearticularam": "dearticular",
    "dearticularas": "dearticular",
    "dearticularde": "dearticular",
    "dearticulardes": "dearticular",
    "dearticulare": "dearticular",
    "dearticularei": "dearticular",
    "dearticulareis": "dearticular",
    "dearticularem": "dearticular",
    "dearticularemos": "dearticular",
    "dearticulares": "dearticular",
    "dearticularia": "dearticular",
    "dearticulariam": "dearticular",
    "dearticularias": "dearticular",
    "dearticularmo": "dearticular",
    "dearticularmos": "dearticular",
    "dearticulará": "dearticular",
    "dearticularás": "dearticular",
    "dearticularão": "dearticular",
    "dearticularíamos": "dearticular",
    "dearticularíeis": "dearticular",
    "dearticulas": "dearticular",
    "dearticulasse": "dearticular",
    "dearticulassem": "dearticular",
    "dearticulasses": "dearticular",
    "dearticulaste": "dearticular",
    "dearticulastes": "dearticular",
    "dearticulava": "dearticular",
    "dearticulavam": "dearticular",
    "dearticulavas": "dearticular",
    "dearticulações": "dearticulação",
    "dearticule": "dearticular",
    "dearticulei": "dearticular",
    "dearticuleis": "dearticular",
    "dearticulem": "dearticular",
    "dearticulemo": "dearticular",
    "dearticulemos": "dearticular",
    "dearticules": "dearticular",
    "dearticulo": "dearticular",
    "dearticulou": "dearticular",
    "dearticulá": "dearticular",
    "dearticulámo": "dearticular",
    "dearticulámos": "dearticular",
    "dearticuláramo": "dearticular",
    "dearticuláramos": "dearticular",
    "dearticulárei": "dearticular",
    "dearticuláreis": "dearticular",
    "dearticulásseis": "dearticular",
    "dearticulássemos": "dearticular",
    "dearticulávamo": "dearticular",
    "dearticulávamos": "dearticular",
    "dearticulávei": "dearticular",
    "dearticuláveis": "dearticular",
    "debagas": "debaga",
    "debalações": "debalação",
    "debanda": "debandar",
    "debandada": "debandar",
    "debandadas": "debandar",
    "debandado": "debandar",
    "debandados": "debandar",
    "debandai": "debandar",
    "debandais": "debandar",
    "debandam": "debandar",
    "debandamo": "debandar",
    "debandamos": "debandar",
    "debandando": "debandar",
    "debandara": "debandar",
    "debandaram": "debandar",
    "debandaras": "debandar",
    "debandardes": "debandar",
    "debandarei": "debandar",
    "debandareis": "debandar",
    "debandarem": "debandar",
    "debandaremos": "debandar",
    "debandares": "debandar",
    "debandaria": "debandar",
    "debandariam": "debandar",
    "debandarias": "debandar",
    "debandarmo": "debandar",
    "debandarmos": "debandar",
    "debandará": "debandar",
    "debandarás": "debandar",
    "debandarão": "debandar",
    "debandaríamos": "debandar",
    "debandaríeis": "debandar",
    "debandas": "debandar",
    "debandasse": "debandar",
    "debandassem": "debandar",
    "debandasses": "debandar",
    "debandaste": "debandar",
    "debandastes": "debandar",
    "debandava": "debandar",
    "debandavam": "debandar",
    "debandavas": "debandar",
    "debande": "debandar",
    "debandei": "debandar",
    "debandeis": "debandar",
    "debandem": "debandar",
    "debandemo": "debandar",
    "debandemos": "debandar",
    "debandes": "debandar",
    "debando": "debandar",
    "debandou": "debandar",
    "debandámo": "debandar",
    "debandámos": "debandar",
    "debandáramo": "debandar",
    "debandáramos": "debandar",
    "debandáreis": "debandar",
    "debandásseis": "debandar",
    "debandássemos": "debandar",
    "debandávamo": "debandar",
    "debandávamos": "debandar",
    "debandáveis": "debandar",
    "debata": "debater",
    "debatais": "debater",
    "debatam": "debater",
    "debatamo": "debater",
    "debatamos": "debater",
    "debatas": "debater",
    "debate": "debater",
    "debatei": "debater",
    "debateis": "debater",
    "debatem": "debater",
    "debatemo": "debater",
    "debatemos": "debater",
    "debatendo": "debater",
    "debatera": "debater",
    "debateram": "debater",
    "debateras": "debater",
    "debaterde": "debater",
    "debaterdes": "debater",
    "debatere": "debater",
    "debaterei": "debater",
    "debatereis": "debater",
    "debaterem": "debater",
    "debateremos": "debater",
    "debateres": "debater",
    "debateria": "debater",
    "debateriam": "debater",
    "debaterias": "debater",
    "debatermo": "debater",
    "debatermos": "debater",
    "debaterá": "debater",
    "debaterás": "debater",
    "debaterão": "debater",
    "debateríamos": "debater",
    "debateríeis": "debater",
    "debates": "debater",
    "debatesse": "debater",
    "debatessem": "debater",
    "debatesses": "debater",
    "debateste": "debater",
    "debatestes": "debater",
    "debateu": "debater",
    "debati": "debater",
    "debatia": "debater",
    "debatiam": "debater",
    "debatias": "debater",
    "debatida": "debatido",
    "debatidas": "debatido",
    "debatidiça": "debatidiço",
    "debatidiças": "debatidiço",
    "debatidiços": "debatidiço",
    "debatido": "debater",
    "debatidos": "debatido",
    "debato": "debater",
    "debatê": "debater",
    "debatêramo": "debater",
    "debatêramos": "debater",
    "debatêrei": "debater",
    "debatêreis": "debater",
    "debatêsseis": "debater",
    "debatêssemos": "debater",
    "debatíamo": "debater",
    "debatíamos": "debater",
    "debatíei": "debater",
    "debatíeis": "debater",
    "debatíveis": "debatível",
    "debela": "debelar",
    "debelada": "debelar",
    "debeladas": "debelar",
    "debelado": "debelar",
    "debeladora": "debelador",
    "debeladoras": "debelador",
    "debeladores": "debelador",
    "debelados": "debelar",
    "debelai": "debelar",
    "debelais": "debelar",
    "debelam": "debelar",
    "debelamo": "debelar",
    "debelamos": "debelar",
    "debelando": "debelar",
    "debelara": "debelar",
    "debelaram": "debelar",
    "debelaras": "debelar",
    "debelarde": "debelar",
    "debelardes": "debelar",
    "debelare": "debelar",
    "debelarei": "debelar",
    "debelareis": "debelar",
    "debelarem": "debelar",
    "debelaremos": "debelar",
    "debelares": "debelar",
    "debelaria": "debelar",
    "debelariam": "debelar",
    "debelarias": "debelar",
    "debelarmo": "debelar",
    "debelarmos": "debelar",
    "debelará": "debelar",
    "debelarás": "debelar",
    "debelarão": "debelar",
    "debelaríamos": "debelar",
    "debelaríeis": "debelar",
    "debelas": "debelar",
    "debelasse": "debelar",
    "debelassem": "debelar",
    "debelasses": "debelar",
    "debelaste": "debelar",
    "debelastes": "debelar",
    "debelatória": "debelatório",
    "debelatórias": "debelatório",
    "debelatórios": "debelatório",
    "debelava": "debelar",
    "debelavam": "debelar",
    "debelavas": "debelar",
    "debelações": "debelação",
    "debele": "debelar",
    "debelei": "debelar",
    "debeleis": "debelar",
    "debelem": "debelar",
    "debelemo": "debelar",
    "debelemos": "debelar",
    "debeles": "debelar",
    "debelo": "debelar",
    "debelou": "debelar",
    "debelá": "debelar",
    "debelámo": "debelar",
    "debelámos": "debelar",
    "debeláramo": "debelar",
    "debeláramos": "debelar",
    "debelárei": "debelar",
    "debeláreis": "debelar",
    "debelásseis": "debelar",
    "debelássemos": "debelar",
    "debelávamo": "debelar",
    "debelávamos": "debelar",
    "debelávei": "debelar",
    "debeláveis": "debelar",
    "debica": "debicar",
    "debicada": "debicar",
    "debicadas": "debicar",
    "debicado": "debicar",
    "debicadora": "debicador",
    "debicadoras": "debicador",
    "debicadores": "debicador",
    "debicados": "debicar",
    "debicais": "debicar",
    "debicam": "debicar",
    "debicamo": "debicar",
    "debicamos": "debicar",
    "debicando": "debicar",
    "debicara": "debicar",
    "debicaram": "debicar",
    "debicaras": "debicar",
    "debicardes": "debicar",
    "debicarei": "debicar",
    "debicareis": "debicar",
    "debicarem": "debicar",
    "debicaremos": "debicar",
    "debicares": "debicar",
    "debicaria": "debicar",
    "debicariam": "debicar",
    "debicarias": "debicar",
    "debicarmo": "debicar",
    "debicarmos": "debicar",
    "debicará": "debicar",
    "debicarás": "debicar",
    "debicarão": "debicar",
    "debicaríamos": "debicar",
    "debicaríeis": "debicar",
    "debicas": "debicar",
    "debicasse": "debicar",
    "debicassem": "debicar",
    "debicasses": "debicar",
    "debicaste": "debicar",
    "debicastes": "debicar",
    "debicava": "debicar",
    "debicavam": "debicar",
    "debicavas": "debicar",
    "debico": "debicar",
    "debicou": "debicar",
    "debicámo": "debicar",
    "debicámos": "debicar",
    "debicáramo": "debicar",
    "debicáramos": "debicar",
    "debicáreis": "debicar",
    "debicásseis": "debicar",
    "debicássemos": "debicar",
    "debicávamo": "debicar",
    "debicávamos": "debicar",
    "debicáveis": "debicar",
    "debilidades": "debilidade",
    "debilita": "debilitar",
    "debilitada": "debilitar",
    "debilitadas": "debilitar",
    "debilitado": "debilitar",
    "debilitadora": "debilitador",
    "debilitadoras": "debilitador",
    "debilitadores": "debilitador",
    "debilitados": "debilitar",
    "debilitadíssima": "debilitado",
    "debilitadíssimas": "debilitado",
    "debilitadíssimo": "debilitado",
    "debilitadíssimos": "debilitado",
    "debilitai": "debilitar",
    "debilitais": "debilitar",
    "debilitam": "debilitar",
    "debilitamentos": "debilitamento",
    "debilitamo": "debilitar",
    "debilitamos": "debilitar",
    "debilitando": "debilitar",
    "debilitantes": "debilitante",
    "debilitara": "debilitar",
    "debilitaram": "debilitar",
    "debilitaras": "debilitar",
    "debilitarde": "debilitar",
    "debilitardes": "debilitar",
    "debilitare": "debilitar",
    "debilitarei": "debilitar",
    "debilitareis": "debilitar",
    "debilitarem": "debilitar",
    "debilitaremos": "debilitar",
    "debilitares": "debilitar",
    "debilitaria": "debilitar",
    "debilitariam": "debilitar",
    "debilitarias": "debilitar",
    "debilitarmo": "debilitar",
    "debilitarmos": "debilitar",
    "debilitará": "debilitar",
    "debilitarás": "debilitar",
    "debilitarão": "debilitar",
    "debilitaríamos": "debilitar",
    "debilitaríeis": "debilitar",
    "debilitas": "debilitar",
    "debilitasse": "debilitar",
    "debilitassem": "debilitar",
    "debilitasses": "debilitar",
    "debilitaste": "debilitar",
    "debilitastes": "debilitar",
    "debilitava": "debilitar",
    "debilitavam": "debilitar",
    "debilitavas": "debilitar",
    "debilitações": "debilitação",
    "debilite": "debilitar",
    "debilitei": "debilitar",
    "debiliteis": "debilitar",
    "debilitem": "debilitar",
    "debilitemo": "debilitar",
    "debilitemos": "debilitar",
    "debilites": "debilitar",
    "debilito": "debilitar",
    "debilitou": "debilitar",
    "debilitá": "debilitar",
    "debilitámo": "debilitar",
    "debilitámos": "debilitar",
    "debilitáramo": "debilitar",
    "debilitáramos": "debilitar",
    "debilitárei": "debilitar",
    "debilitáreis": "debilitar",
    "debilitásseis": "debilitar",
    "debilitássemos": "debilitar",
    "debilitávamo": "debilitar",
    "debilitávamos": "debilitar",
    "debilitávei": "debilitar",
    "debilitáveis": "debilitável",
    "debique": "debicar",
    "debiquei": "debicar",
    "debiqueira": "debiqueiro",
    "debiqueiras": "debiqueiro",
    "debiqueiros": "debiqueiro",
    "debiqueis": "debicar",
    "debiquem": "debicar",
    "debiquemos": "debicar",
    "debiques": "debique",
    "debita": "debitar",
    "debitada": "debitar",
    "debitadas": "debitar",
    "debitado": "debitar",
    "debitados": "debitar",
    "debitai": "debitar",
    "debitais": "debitar",
    "debitam": "debitar",
    "debitamo": "debitar",
    "debitamos": "debitar",
    "debitando": "debitar",
    "debitara": "debitar",
    "debitaram": "debitar",
    "debitaras": "debitar",
    "debitarde": "debitar",
    "debitardes": "debitar",
    "debitare": "debitar",
    "debitarei": "debitar",
    "debitareis": "debitar",
    "debitarem": "debitar",
    "debitaremos": "debitar",
    "debitares": "debitar",
    "debitaria": "debitar",
    "debitariam": "debitar",
    "debitarias": "debitar",
    "debitarmo": "debitar",
    "debitarmos": "debitar",
    "debitará": "debitar",
    "debitarás": "debitar",
    "debitarão": "debitar",
    "debitaríamos": "debitar",
    "debitaríeis": "debitar",
    "debitas": "debitar",
    "debitasse": "debitar",
    "debitassem": "debitar",
    "debitasses": "debitar",
    "debitaste": "debitar",
    "debitastes": "debitar",
    "debitava": "debitar",
    "debitavam": "debitar",
    "debitavas": "debitar",
    "debite": "debitar",
    "debitei": "debitar",
    "debiteis": "debitar",
    "debitem": "debitar",
    "debitemo": "debitar",
    "debitemos": "debitar",
    "debites": "debitar",
    "debito": "debitar",
    "debitou": "debitar",
    "debitá": "debitar",
    "debitámo": "debitar",
    "debitámos": "debitar",
    "debitáramo": "debitar",
    "debitáramos": "debitar",
    "debitárei": "debitar",
    "debitáreis": "debitar",
    "debitásseis": "debitar",
    "debitássemos": "debitar",
    "debitávamo": "debitar",
    "debitávamos": "debitar",
    "debitávei": "debitar",
    "debitáveis": "debitar",
    "deblatera": "deblaterar",
    "deblaterada": "deblaterar",
    "deblateradas": "deblaterar",
    "deblaterado": "deblaterar",
    "deblaterados": "deblaterar",
    "deblaterai": "deblaterar",
    "deblaterais": "deblaterar",
    "deblateram": "deblaterar",
    "deblateramo": "deblaterar",
    "deblateramos": "deblaterar",
    "deblaterando": "deblaterar",
    "deblaterara": "deblaterar",
    "deblateraram": "deblaterar",
    "deblateraras": "deblaterar",
    "deblaterardes": "deblaterar",
    "deblaterarei": "deblaterar",
    "deblaterareis": "deblaterar",
    "deblaterarem": "deblaterar",
    "deblateraremos": "deblaterar",
    "deblaterares": "deblaterar",
    "deblateraria": "deblaterar",
    "deblaterariam": "deblaterar",
    "deblaterarias": "deblaterar",
    "deblaterarmo": "deblaterar",
    "deblaterarmos": "deblaterar",
    "deblaterará": "deblaterar",
    "deblaterarás": "deblaterar",
    "deblaterarão": "deblaterar",
    "deblateraríamos": "deblaterar",
    "deblateraríeis": "deblaterar",
    "deblateras": "deblaterar",
    "deblaterasse": "deblaterar",
    "deblaterassem": "deblaterar",
    "deblaterasses": "deblaterar",
    "deblateraste": "deblaterar",
    "deblaterastes": "deblaterar",
    "deblaterava": "deblaterar",
    "deblateravam": "deblaterar",
    "deblateravas": "deblaterar",
    "deblaterações": "deblateração",
    "deblatere": "deblaterar",
    "deblaterei": "deblaterar",
    "deblatereis": "deblaterar",
    "deblaterem": "deblaterar",
    "deblateremo": "deblaterar",
    "deblateremos": "deblaterar",
    "deblateres": "deblaterar",
    "deblatero": "deblaterar",
    "deblaterou": "deblaterar",
    "deblaterámo": "deblaterar",
    "deblaterámos": "deblaterar",
    "deblateráramo": "deblaterar",
    "deblateráramos": "deblaterar",
    "deblateráreis": "deblaterar",
    "deblaterásseis": "deblaterar",
    "deblaterássemos": "deblaterar",
    "deblaterávamo": "deblaterar",
    "deblaterávamos": "deblaterar",
    "deblateráveis": "deblaterar",
    "debloqueada": "debloquear",
    "debloqueadas": "debloquear",
    "debloqueado": "debloquear",
    "debloqueados": "debloquear",
    "debloqueai": "debloquear",
    "debloqueais": "debloquear",
    "debloqueamo": "debloquear",
    "debloqueamos": "debloquear",
    "debloqueando": "debloquear",
    "debloqueara": "debloquear",
    "debloquearam": "debloquear",
    "debloquearas": "debloquear",
    "debloquearde": "debloquear",
    "debloqueardes": "debloquear",
    "debloqueare": "debloquear",
    "debloquearei": "debloquear",
    "debloqueareis": "debloquear",
    "debloquearem": "debloquear",
    "debloquearemos": "debloquear",
    "debloqueares": "debloquear",
    "debloquearia": "debloquear",
    "debloqueariam": "debloquear",
    "debloquearias": "debloquear",
    "debloquearmo": "debloquear",
    "debloquearmos": "debloquear",
    "debloqueará": "debloquear",
    "debloquearás": "debloquear",
    "debloquearão": "debloquear",
    "debloquearíamos": "debloquear",
    "debloquearíeis": "debloquear",
    "debloqueasse": "debloquear",
    "debloqueassem": "debloquear",
    "debloqueasses": "debloquear",
    "debloqueaste": "debloquear",
    "debloqueastes": "debloquear",
    "debloqueava": "debloquear",
    "debloqueavam": "debloquear",
    "debloqueavas": "debloquear",
    "debloqueei": "debloquear",
    "debloqueeis": "debloquear",
    "debloqueemo": "debloquear",
    "debloqueemos": "debloquear",
    "debloqueia": "debloquear",
    "debloqueiam": "debloquear",
    "debloqueias": "debloquear",
    "debloqueie": "debloquear",
    "debloqueiem": "debloquear",
    "debloqueies": "debloquear",
    "debloqueio": "debloquear",
    "debloqueou": "debloquear",
    "debloqueá": "debloquear",
    "debloqueámo": "debloquear",
    "debloqueámos": "debloquear",
    "debloqueáramo": "debloquear",
    "debloqueáramos": "debloquear",
    "debloqueárei": "debloquear",
    "debloqueáreis": "debloquear",
    "debloqueásseis": "debloquear",
    "debloqueássemos": "debloquear",
    "debloqueávamo": "debloquear",
    "debloqueávamos": "debloquear",
    "debloqueávei": "debloquear",
    "debloqueáveis": "debloquear",
    "debocha": "debochar",
    "debochada": "debochar",
    "debochadas": "debochar",
    "debochado": "debochar",
    "debochados": "debochar",
    "debochai": "debochar",
    "debochais": "debochar",
    "debocham": "debochar",
    "debochamo": "debochar",
    "debochamos": "debochar",
    "debochando": "debochar",
    "debochara": "debochar",
    "debocharam": "debochar",
    "debocharas": "debochar",
    "debocharde": "debochar",
    "debochardes": "debochar",
    "debochare": "debochar",
    "debocharei": "debochar",
    "debochareis": "debochar",
    "debocharem": "debochar",
    "debocharemos": "debochar",
    "debochares": "debochar",
    "debocharia": "debochar",
    "debochariam": "debochar",
    "debocharias": "debochar",
    "debocharmo": "debochar",
    "debocharmos": "debochar",
    "debochará": "debochar",
    "debocharás": "debochar",
    "debocharão": "debochar",
    "debocharíamos": "debochar",
    "debocharíeis": "debochar",
    "debochas": "debochar",
    "debochasse": "debochar",
    "debochassem": "debochar",
    "debochasses": "debochar",
    "debochaste": "debochar",
    "debochastes": "debochar",
    "debochava": "debochar",
    "debochavam": "debochar",
    "debochavas": "debochar",
    "deboche": "debochar",
    "debochei": "debochar",
    "debocheis": "debochar",
    "debochem": "debochar",
    "debochemo": "debochar",
    "debochemos": "debochar",
    "deboches": "deboche",
    "debocho": "debochar",
    "debochou": "debochar",
    "debochá": "debochar",
    "debochámo": "debochar",
    "debochámos": "debochar",
    "debocháramo": "debochar",
    "debocháramos": "debochar",
    "debochárei": "debochar",
    "debocháreis": "debochar",
    "debochásseis": "debochar",
    "debochássemos": "debochar",
    "debochávamo": "debochar",
    "debochávamos": "debochar",
    "debochávei": "debochar",
    "debocháveis": "debochar",
    "deborca": "deborcar",
    "deborcada": "deborcar",
    "deborcadas": "deborcar",
    "deborcado": "deborcar",
    "deborcados": "deborcar",
    "deborcai": "deborcar",
    "deborcais": "deborcar",
    "deborcam": "deborcar",
    "deborcamo": "deborcar",
    "deborcamos": "deborcar",
    "deborcando": "deborcar",
    "deborcara": "deborcar",
    "deborcaram": "deborcar",
    "deborcaras": "deborcar",
    "deborcarde": "deborcar",
    "deborcardes": "deborcar",
    "deborcare": "deborcar",
    "deborcarei": "deborcar",
    "deborcareis": "deborcar",
    "deborcarem": "deborcar",
    "deborcaremos": "deborcar",
    "deborcares": "deborcar",
    "deborcaria": "deborcar",
    "deborcariam": "deborcar",
    "deborcarias": "deborcar",
    "deborcarmo": "deborcar",
    "deborcarmos": "deborcar",
    "deborcará": "deborcar",
    "deborcarás": "deborcar",
    "deborcarão": "deborcar",
    "deborcaríamos": "deborcar",
    "deborcaríeis": "deborcar",
    "deborcas": "deborcar",
    "deborcasse": "deborcar",
    "deborcassem": "deborcar",
    "deborcasses": "deborcar",
    "deborcaste": "deborcar",
    "deborcastes": "deborcar",
    "deborcava": "deborcar",
    "deborcavam": "deborcar",
    "deborcavas": "deborcar",
    "deborco": "deborcar",
    "deborcou": "deborcar",
    "deborcá": "deborcar",
    "deborcámo": "deborcar",
    "deborcámos": "deborcar",
    "deborcáramo": "deborcar",
    "deborcáramos": "deborcar",
    "deborcárei": "deborcar",
    "deborcáreis": "deborcar",
    "deborcásseis": "deborcar",
    "deborcássemos": "deborcar",
    "deborcávamo": "deborcar",
    "deborcávamos": "deborcar",
    "deborcávei": "deborcar",
    "deborcáveis": "deborcar",
    "deborque": "deborcar",
    "deborquei": "deborcar",
    "deborqueis": "deborcar",
    "deborquem": "deborcar",
    "deborquemo": "deborcar",
    "deborquemos": "deborcar",
    "deborques": "deborcar",
    "debota": "debotar",
    "debotada": "debotar",
    "debotadas": "debotar",
    "debotado": "debotar",
    "debotados": "debotar",
    "debotai": "debotar",
    "debotais": "debotar",
    "debotam": "debotar",
    "debotamo": "debotar",
    "debotamos": "debotar",
    "debotando": "debotar",
    "debotara": "debotar",
    "debotaram": "debotar",
    "debotaras": "debotar",
    "debotarde": "debotar",
    "debotardes": "debotar",
    "debotare": "debotar",
    "debotarei": "debotar",
    "debotareis": "debotar",
    "debotarem": "debotar",
    "debotaremos": "debotar",
    "debotares": "debotar",
    "debotaria": "debotar",
    "debotariam": "debotar",
    "debotarias": "debotar",
    "debotarmo": "debotar",
    "debotarmos": "debotar",
    "debotará": "debotar",
    "debotarás": "debotar",
    "debotarão": "debotar",
    "debotaríamos": "debotar",
    "debotaríeis": "debotar",
    "debotas": "debotar",
    "debotasse": "debotar",
    "debotassem": "debotar",
    "debotasses": "debotar",
    "debotaste": "debotar",
    "debotastes": "debotar",
    "debotava": "debotar",
    "debotavam": "debotar",
    "debotavas": "debotar",
    "debote": "debotar",
    "debotei": "debotar",
    "deboteis": "debotar",
    "debotem": "debotar",
    "debotemo": "debotar",
    "debotemos": "debotar",
    "debotes": "debotar",
    "deboto": "debotar",
    "debotou": "debotar",
    "debotá": "debotar",
    "debotámo": "debotar",
    "debotámos": "debotar",
    "debotáramo": "debotar",
    "debotáramos": "debotar",
    "debotárei": "debotar",
    "debotáreis": "debotar",
    "debotásseis": "debotar",
    "debotássemos": "debotar",
    "debotávamo": "debotar",
    "debotávamos": "debotar",
    "debotávei": "debotar",
    "debotáveis": "debotar",
    "debouce": "debouçar",
    "deboucei": "debouçar",
    "debouceis": "debouçar",
    "deboucem": "debouçar",
    "deboucemo": "debouçar",
    "deboucemos": "debouçar",
    "debouces": "debouçar",
    "debouça": "debouçar",
    "debouçada": "debouçar",
    "debouçadas": "debouçar",
    "debouçado": "debouçar",
    "debouçados": "debouçar",
    "debouçai": "debouçar",
    "debouçais": "debouçar",
    "debouçam": "debouçar",
    "debouçamo": "debouçar",
    "debouçamos": "debouçar",
    "debouçando": "debouçar",
    "debouçara": "debouçar",
    "debouçaram": "debouçar",
    "debouçaras": "debouçar",
    "debouçarde": "debouçar",
    "debouçardes": "debouçar",
    "debouçare": "debouçar",
    "debouçarei": "debouçar",
    "debouçareis": "debouçar",
    "debouçarem": "debouçar",
    "debouçaremos": "debouçar",
    "debouçares": "debouçar",
    "debouçaria": "debouçar",
    "debouçariam": "debouçar",
    "debouçarias": "debouçar",
    "debouçarmo": "debouçar",
    "debouçarmos": "debouçar",
    "debouçará": "debouçar",
    "debouçarás": "debouçar",
    "debouçarão": "debouçar",
    "debouçaríamos": "debouçar",
    "debouçaríeis": "debouçar",
    "debouças": "debouçar",
    "debouçasse": "debouçar",
    "debouçassem": "debouçar",
    "debouçasses": "debouçar",
    "debouçaste": "debouçar",
    "debouçastes": "debouçar",
    "debouçava": "debouçar",
    "debouçavam": "debouçar",
    "debouçavas": "debouçar",
    "debouço": "debouçar",
    "debouçou": "debouçar",
    "debouçá": "debouçar",
    "debouçámo": "debouçar",
    "debouçámos": "debouçar",
    "debouçáramo": "debouçar",
    "debouçáramos": "debouçar",
    "debouçárei": "debouçar",
    "debouçáreis": "debouçar",
    "debouçásseis": "debouçar",
    "debouçássemos": "debouçar",
    "debouçávamo": "debouçar",
    "debouçávamos": "debouçar",
    "debouçávei": "debouçar",
    "debouçáveis": "debouçar",
    "debroadeiras": "debroadeira",
    "debrua": "debruar",
    "debruada": "debruar",
    "debruadas": "debruar",
    "debruado": "debruar",
    "debruados": "debruar",
    "debruai": "debruar",
    "debruais": "debruar",
    "debruam": "debruar",
    "debruamo": "debruar",
    "debruamos": "debruar",
    "debruando": "debruar",
    "debruara": "debruar",
    "debruaram": "debruar",
    "debruaras": "debruar",
    "debruarde": "debruar",
    "debruardes": "debruar",
    "debruare": "debruar",
    "debruarei": "debruar",
    "debruareis": "debruar",
    "debruarem": "debruar",
    "debruaremos": "debruar",
    "debruares": "debruar",
    "debruaria": "debruar",
    "debruariam": "debruar",
    "debruarias": "debruar",
    "debruarmo": "debruar",
    "debruarmos": "debruar",
    "debruará": "debruar",
    "debruarás": "debruar",
    "debruarão": "debruar",
    "debruaríamos": "debruar",
    "debruaríeis": "debruar",
    "debruas": "debruar",
    "debruasse": "debruar",
    "debruassem": "debruar",
    "debruasses": "debruar",
    "debruaste": "debruar",
    "debruastes": "debruar",
    "debruava": "debruar",
    "debruavam": "debruar",
    "debruavas": "debruar",
    "debruce": "debruçar",
    "debrucei": "debruçar",
    "debruceis": "debruçar",
    "debrucem": "debruçar",
    "debrucemo": "debruçar",
    "debrucemos": "debruçar",
    "debruces": "debruçar",
    "debrue": "debruar",
    "debruei": "debruar",
    "debrueis": "debruar",
    "debruem": "debruar",
    "debruemo": "debruar",
    "debruemos": "debruar",
    "debrues": "debruar",
    "debruns": "debrum",
    "debruo": "debruar",
    "debruou": "debruar",
    "debruá": "debruar",
    "debruámo": "debruar",
    "debruámos": "debruar",
    "debruáramo": "debruar",
    "debruáramos": "debruar",
    "debruárei": "debruar",
    "debruáreis": "debruar",
    "debruásseis": "debruar",
    "debruássemos": "debruar",
    "debruávamo": "debruar",
    "debruávamos": "debruar",
    "debruávei": "debruar",
    "debruáveis": "debruar",
    "debruça": "debruçar",
    "debruçada": "debruçar",
    "debruçadas": "debruçar",
    "debruçado": "debruçar",
    "debruçados": "debruçar",
    "debruçai": "debruçar",
    "debruçais": "debruçar",
    "debruçam": "debruçar",
    "debruçamo": "debruçar",
    "debruçamos": "debruçar",
    "debruçando": "debruçar",
    "debruçara": "debruçar",
    "debruçaram": "debruçar",
    "debruçaras": "debruçar",
    "debruçarde": "debruçar",
    "debruçardes": "debruçar",
    "debruçare": "debruçar",
    "debruçarei": "debruçar",
    "debruçareis": "debruçar",
    "debruçarem": "debruçar",
    "debruçaremos": "debruçar",
    "debruçares": "debruçar",
    "debruçaria": "debruçar",
    "debruçariam": "debruçar",
    "debruçarias": "debruçar",
    "debruçarmo": "debruçar",
    "debruçarmos": "debruçar",
    "debruçará": "debruçar",
    "debruçarás": "debruçar",
    "debruçarão": "debruçar",
    "debruçaríamos": "debruçar",
    "debruçaríeis": "debruçar",
    "debruças": "debruçar",
    "debruçasse": "debruçar",
    "debruçassem": "debruçar",
    "debruçasses": "debruçar",
    "debruçaste": "debruçar",
    "debruçastes": "debruçar",
    "debruçava": "debruçar",
    "debruçavam": "debruçar",
    "debruçavas": "debruçar",
    "debruço": "debruçar",
    "debruçou": "debruçar",
    "debruçá": "debruçar",
    "debruçámo": "debruçar",
    "debruçámos": "debruçar",
    "debruçáramo": "debruçar",
    "debruçáramos": "debruçar",
    "debruçárei": "debruçar",
    "debruçáreis": "debruçar",
    "debruçásseis": "debruçar",
    "debruçássemos": "debruçar",
    "debruçávamo": "debruçar",
    "debruçávamos": "debruçar",
    "debruçávei": "debruçar",
    "debruçáveis": "debruçar",
    "debulha": "debulhar",
    "debulhada": "debulhar",
    "debulhadas": "debulhar",
    "debulhadeiras": "debulhadeira",
    "debulhado": "debulhar",
    "debulhadora": "debulhador",
    "debulhadoras": "debulhadora",
    "debulhadores": "debulhador",
    "debulhados": "debulhar",
    "debulhai": "debulhar",
    "debulhais": "debulhar",
    "debulham": "debulhar",
    "debulhamo": "debulhar",
    "debulhamos": "debulhar",
    "debulhando": "debulhar",
    "debulhara": "debulhar",
    "debulharam": "debulhar",
    "debulharas": "debulhar",
    "debulharde": "debulhar",
    "debulhardes": "debulhar",
    "debulhare": "debulhar",
    "debulharei": "debulhar",
    "debulhareis": "debulhar",
    "debulharem": "debulhar",
    "debulharemos": "debulhar",
    "debulhares": "debulhar",
    "debulharia": "debulhar",
    "debulhariam": "debulhar",
    "debulharias": "debulhar",
    "debulharmo": "debulhar",
    "debulharmos": "debulhar",
    "debulhará": "debulhar",
    "debulharás": "debulhar",
    "debulharão": "debulhar",
    "debulharíamos": "debulhar",
    "debulharíeis": "debulhar",
    "debulhas": "debulhar",
    "debulhasse": "debulhar",
    "debulhassem": "debulhar",
    "debulhasses": "debulhar",
    "debulhaste": "debulhar",
    "debulhastes": "debulhar",
    "debulhava": "debulhar",
    "debulhavam": "debulhar",
    "debulhavas": "debulhar",
    "debulhe": "debulhar",
    "debulhei": "debulhar",
    "debulheis": "debulhar",
    "debulhem": "debulhar",
    "debulhemo": "debulhar",
    "debulhemos": "debulhar",
    "debulhes": "debulhar",
    "debulho": "debulhar",
    "debulhos": "debulho",
    "debulhou": "debulhar",
    "debulhá": "debulhar",
    "debulhámo": "debulhar",
    "debulhámos": "debulhar",
    "debulháramo": "debulhar",
    "debulháramos": "debulhar",
    "debulhárei": "debulhar",
    "debulháreis": "debulhar",
    "debulhásseis": "debulhar",
    "debulhássemos": "debulhar",
    "debulhávamo": "debulhar",
    "debulhávamos": "debulhar",
    "debulhávei": "debulhar",
    "debulháveis": "debulhar",
    "debuta": "debutar",
    "debutada": "debutar",
    "debutadas": "debutar",
    "debutado": "debutar",
    "debutados": "debutar",
    "debutai": "debutar",
    "debutais": "debutar",
    "debutam": "debutar",
    "debutamo": "debutar",
    "debutamos": "debutar",
    "debutando": "debutar",
    "debutantes": "debutante",
    "debutara": "debutar",
    "debutaram": "debutar",
    "debutaras": "debutar",
    "debutardes": "debutar",
    "debutarei": "debutar",
    "debutareis": "debutar",
    "debutarem": "debutar",
    "debutaremos": "debutar",
    "debutares": "debutar",
    "debutaria": "debutar",
    "debutariam": "debutar",
    "debutarias": "debutar",
    "debutarmo": "debutar",
    "debutarmos": "debutar",
    "debutará": "debutar",
    "debutarás": "debutar",
    "debutarão": "debutar",
    "debutaríamos": "debutar",
    "debutaríeis": "debutar",
    "debutas": "debutar",
    "debutasse": "debutar",
    "debutassem": "debutar",
    "debutasses": "debutar",
    "debutaste": "debutar",
    "debutastes": "debutar",
    "debutava": "debutar",
    "debutavam": "debutar",
    "debutavas": "debutar",
    "debute": "debutar",
    "debutei": "debutar",
    "debuteis": "debutar",
    "debutem": "debutar",
    "debutemo": "debutar",
    "debutemos": "debutar",
    "debutes": "debute",
    "debuto": "debutar",
    "debutou": "debutar",
    "debutámo": "debutar",
    "debutámos": "debutar",
    "debutáramo": "debutar",
    "debutáramos": "debutar",
    "debutáreis": "debutar",
    "debutásseis": "debutar",
    "debutássemos": "debutar",
    "debutávamo": "debutar",
    "debutávamos": "debutar",
    "debutáveis": "debutar",
    "debuxa": "debuxar",
    "debuxada": "debuxar",
    "debuxadas": "debuxar",
    "debuxado": "debuxar",
    "debuxadora": "debuxador",
    "debuxadoras": "debuxador",
    "debuxadores": "debuxador",
    "debuxados": "debuxar",
    "debuxai": "debuxar",
    "debuxais": "debuxar",
    "debuxam": "debuxar",
    "debuxamo": "debuxar",
    "debuxamos": "debuxar",
    "debuxando": "debuxar",
    "debuxantes": "debuxante",
    "debuxara": "debuxar",
    "debuxaram": "debuxar",
    "debuxaras": "debuxar",
    "debuxarde": "debuxar",
    "debuxardes": "debuxar",
    "debuxare": "debuxar",
    "debuxarei": "debuxar",
    "debuxareis": "debuxar",
    "debuxarem": "debuxar",
    "debuxaremos": "debuxar",
    "debuxares": "debuxar",
    "debuxaria": "debuxar",
    "debuxariam": "debuxar",
    "debuxarias": "debuxar",
    "debuxarmo": "debuxar",
    "debuxarmos": "debuxar",
    "debuxará": "debuxar",
    "debuxarás": "debuxar",
    "debuxarão": "debuxar",
    "debuxaríamos": "debuxar",
    "debuxaríeis": "debuxar",
    "debuxas": "debuxar",
    "debuxasse": "debuxar",
    "debuxassem": "debuxar",
    "debuxasses": "debuxar",
    "debuxaste": "debuxar",
    "debuxastes": "debuxar",
    "debuxava": "debuxar",
    "debuxavam": "debuxar",
    "debuxavas": "debuxar",
    "debuxe": "debuxar",
    "debuxei": "debuxar",
    "debuxeis": "debuxar",
    "debuxem": "debuxar",
    "debuxemo": "debuxar",
    "debuxemos": "debuxar",
    "debuxes": "debuxar",
    "debuxo": "debuxar",
    "debuxos": "debuxo",
    "debuxou": "debuxar",
    "debuxá": "debuxar",
    "debuxámo": "debuxar",
    "debuxámos": "debuxar",
    "debuxáramo": "debuxar",
    "debuxáramos": "debuxar",
    "debuxárei": "debuxar",
    "debuxáreis": "debuxar",
    "debuxásseis": "debuxar",
    "debuxássemos": "debuxar",
    "debuxávamo": "debuxar",
    "debuxávamos": "debuxar",
    "debuxávei": "debuxar",
    "debuxáveis": "debuxar",
    "decadentes": "decadente",
    "decadentismos": "decadentismo",
    "decadentistas": "decadentista",
    "decadistas": "decadista",
    "decadáctila": "decadáctilo",
    "decadáctilas": "decadáctilo",
    "decadáctilos": "decadáctilo",
    "decadências": "decadência",
    "decaem": "decair",
    "decagonais": "decagonal",
    "decagramas": "decagrama",
    "decai": "decair",
    "decaia": "decair",
    "decaiais": "decair",
    "decaiam": "decair",
    "decaiamo": "decair",
    "decaiamos": "decair",
    "decaias": "decair",
    "decaimentos": "decaimento",
    "decaindo": "decair",
    "decaio": "decair",
    "decairdes": "decair",
    "decairei": "decair",
    "decaireis": "decair",
    "decairemos": "decair",
    "decairia": "decair",
    "decairiam": "decair",
    "decairias": "decair",
    "decairmo": "decair",
    "decairmos": "decair",
    "decairá": "decair",
    "decairás": "decair",
    "decairão": "decair",
    "decairíamos": "decair",
    "decairíeis": "decair",
    "decais": "decair",
    "decaiu": "decair",
    "decalagens": "decalagem",
    "decalca": "decalcar",
    "decalcada": "decalcar",
    "decalcadas": "decalcar",
    "decalcado": "decalcar",
    "decalcados": "decalcar",
    "decalcai": "decalcar",
    "decalcais": "decalcar",
    "decalcam": "decalcar",
    "decalcamo": "decalcar",
    "decalcamos": "decalcar",
    "decalcando": "decalcar",
    "decalcara": "decalcar",
    "decalcaram": "decalcar",
    "decalcaras": "decalcar",
    "decalcarde": "decalcar",
    "decalcardes": "decalcar",
    "decalcare": "decalcar",
    "decalcarei": "decalcar",
    "decalcareis": "decalcar",
    "decalcarem": "decalcar",
    "decalcaremos": "decalcar",
    "decalcares": "decalcar",
    "decalcaria": "decalcar",
    "decalcariam": "decalcar",
    "decalcarias": "decalcar",
    "decalcarmo": "decalcar",
    "decalcarmos": "decalcar",
    "decalcará": "decalcar",
    "decalcarás": "decalcar",
    "decalcarão": "decalcar",
    "decalcaríamos": "decalcar",
    "decalcaríeis": "decalcar",
    "decalcas": "decalcar",
    "decalcasse": "decalcar",
    "decalcassem": "decalcar",
    "decalcasses": "decalcar",
    "decalcaste": "decalcar",
    "decalcastes": "decalcar",
    "decalcava": "decalcar",
    "decalcavam": "decalcar",
    "decalcavas": "decalcar",
    "decalco": "decalcar",
    "decalcomanias": "decalcomania",
    "decalcos": "decalco",
    "decalcou": "decalcar",
    "decalcá": "decalcar",
    "decalcámo": "decalcar",
    "decalcámos": "decalcar",
    "decalcáramo": "decalcar",
    "decalcáramos": "decalcar",
    "decalcárei": "decalcar",
    "decalcáreis": "decalcar",
    "decalcásseis": "decalcar",
    "decalcássemos": "decalcar",
    "decalcávamo": "decalcar",
    "decalcávamos": "decalcar",
    "decalcávei": "decalcar",
    "decalcáveis": "decalcar",
    "decalescências": "decalescência",
    "decalitros": "decalitro",
    "decalque": "decalcar",
    "decalquei": "decalcar",
    "decalqueis": "decalcar",
    "decalquem": "decalcar",
    "decalquemo": "decalcar",
    "decalquemos": "decalcar",
    "decalques": "decalque",
    "decalva": "decalvar",
    "decalvada": "decalvar",
    "decalvadas": "decalvar",
    "decalvado": "decalvar",
    "decalvados": "decalvar",
    "decalvai": "decalvar",
    "decalvais": "decalvar",
    "decalvam": "decalvar",
    "decalvamo": "decalvar",
    "decalvamos": "decalvar",
    "decalvando": "decalvar",
    "decalvantes": "decalvante",
    "decalvara": "decalvar",
    "decalvaram": "decalvar",
    "decalvaras": "decalvar",
    "decalvarde": "decalvar",
    "decalvardes": "decalvar",
    "decalvare": "decalvar",
    "decalvarei": "decalvar",
    "decalvareis": "decalvar",
    "decalvarem": "decalvar",
    "decalvaremos": "decalvar",
    "decalvares": "decalvar",
    "decalvaria": "decalvar",
    "decalvariam": "decalvar",
    "decalvarias": "decalvar",
    "decalvarmo": "decalvar",
    "decalvarmos": "decalvar",
    "decalvará": "decalvar",
    "decalvarás": "decalvar",
    "decalvarão": "decalvar",
    "decalvaríamos": "decalvar",
    "decalvaríeis": "decalvar",
    "decalvas": "decalvar",
    "decalvasse": "decalvar",
    "decalvassem": "decalvar",
    "decalvasses": "decalvar",
    "decalvaste": "decalvar",
    "decalvastes": "decalvar",
    "decalvava": "decalvar",
    "decalvavam": "decalvar",
    "decalvavas": "decalvar",
    "decalvações": "decalvação",
    "decalve": "decalvar",
    "decalvei": "decalvar",
    "decalveis": "decalvar",
    "decalvem": "decalvar",
    "decalvemo": "decalvar",
    "decalvemos": "decalvar",
    "decalves": "decalvar",
    "decalvo": "decalvar",
    "decalvou": "decalvar",
    "decalvá": "decalvar",
    "decalvámo": "decalvar",
    "decalvámos": "decalvar",
    "decalváramo": "decalvar",
    "decalváramos": "decalvar",
    "decalvárei": "decalvar",
    "decalváreis": "decalvar",
    "decalvásseis": "decalvar",
    "decalvássemos": "decalvar",
    "decalvávamo": "decalvar",
    "decalvávamos": "decalvar",
    "decalvávei": "decalvar",
    "decalváveis": "decalvar",
    "decamecónica": "decamecónico",
    "decamecónicas": "decamecónico",
    "decamecónicos": "decamecónico",
    "decampa": "decampar",
    "decampada": "decampar",
    "decampadas": "decampar",
    "decampado": "decampar",
    "decampados": "decampar",
    "decampai": "decampar",
    "decampais": "decampar",
    "decampam": "decampar",
    "decampamentos": "decampamento",
    "decampamo": "decampar",
    "decampamos": "decampar",
    "decampando": "decampar",
    "decampara": "decampar",
    "decamparam": "decampar",
    "decamparas": "decampar",
    "decampardes": "decampar",
    "decamparei": "decampar",
    "decampareis": "decampar",
    "decamparem": "decampar",
    "decamparemos": "decampar",
    "decampares": "decampar",
    "decamparia": "decampar",
    "decampariam": "decampar",
    "decamparias": "decampar",
    "decamparmo": "decampar",
    "decamparmos": "decampar",
    "decampará": "decampar",
    "decamparás": "decampar",
    "decamparão": "decampar",
    "decamparíamos": "decampar",
    "decamparíeis": "decampar",
    "decampas": "decampar",
    "decampasse": "decampar",
    "decampassem": "decampar",
    "decampasses": "decampar",
    "decampaste": "decampar",
    "decampastes": "decampar",
    "decampava": "decampar",
    "decampavam": "decampar",
    "decampavas": "decampar",
    "decampe": "decampar",
    "decampei": "decampar",
    "decampeis": "decampar",
    "decampem": "decampar",
    "decampemo": "decampar",
    "decampemos": "decampar",
    "decampes": "decampar",
    "decampo": "decampar",
    "decampou": "decampar",
    "decampámo": "decampar",
    "decampámos": "decampar",
    "decampáramo": "decampar",
    "decampáramos": "decampar",
    "decampáreis": "decampar",
    "decampásseis": "decampar",
    "decampássemos": "decampar",
    "decampávamo": "decampar",
    "decampávamos": "decampar",
    "decampáveis": "decampar",
    "decana": "decano",
    "decanados": "decanado",
    "decanais": "decanal",
    "decanas": "decano",
    "decanatos": "decanato",
    "decandra": "decandro",
    "decandras": "decandro",
    "decandrias": "decandria",
    "decandros": "decandro",
    "decangulares": "decangular",
    "decanias": "decania",
    "decanos": "decano",
    "decanta": "decantar",
    "decantada": "decantar",
    "decantadas": "decantar",
    "decantado": "decantar",
    "decantados": "decantar",
    "decantai": "decantar",
    "decantais": "decantar",
    "decantam": "decantar",
    "decantamo": "decantar",
    "decantamos": "decantar",
    "decantando": "decantar",
    "decantara": "decantar",
    "decantaram": "decantar",
    "decantaras": "decantar",
    "decantarde": "decantar",
    "decantardes": "decantar",
    "decantare": "decantar",
    "decantarei": "decantar",
    "decantareis": "decantar",
    "decantarem": "decantar",
    "decantaremos": "decantar",
    "decantares": "decantar",
    "decantaria": "decantar",
    "decantariam": "decantar",
    "decantarias": "decantar",
    "decantarmo": "decantar",
    "decantarmos": "decantar",
    "decantará": "decantar",
    "decantarás": "decantar",
    "decantarão": "decantar",
    "decantaríamos": "decantar",
    "decantaríeis": "decantar",
    "decantas": "decantar",
    "decantasse": "decantar",
    "decantassem": "decantar",
    "decantasses": "decantar",
    "decantaste": "decantar",
    "decantastes": "decantar",
    "decantava": "decantar",
    "decantavam": "decantar",
    "decantavas": "decantar",
    "decantações": "decantação",
    "decante": "decantar",
    "decantei": "decantar",
    "decanteis": "decantar",
    "decantem": "decantar",
    "decantemo": "decantar",
    "decantemos": "decantar",
    "decantes": "decantar",
    "decanto": "decantar",
    "decantou": "decantar",
    "decantá": "decantar",
    "decantámo": "decantar",
    "decantámos": "decantar",
    "decantáramo": "decantar",
    "decantáramos": "decantar",
    "decantárei": "decantar",
    "decantáreis": "decantar",
    "decantásseis": "decantar",
    "decantássemos": "decantar",
    "decantávamo": "decantar",
    "decantávamos": "decantar",
    "decantávei": "decantar",
    "decantáveis": "decantar",
    "decapa": "decapar",
    "decapada": "decapar",
    "decapadas": "decapar",
    "decapado": "decapar",
    "decapados": "decapar",
    "decapagens": "decapagem",
    "decapai": "decapar",
    "decapais": "decapar",
    "decapam": "decapar",
    "decapamo": "decapar",
    "decapamos": "decapar",
    "decapando": "decapar",
    "decapantes": "decapante",
    "decapara": "decapar",
    "decaparam": "decapar",
    "decaparas": "decapar",
    "decaparde": "decapar",
    "decapardes": "decapar",
    "decapare": "decapar",
    "decaparei": "decapar",
    "decapareis": "decapar",
    "decaparem": "decapar",
    "decaparemos": "decapar",
    "decapares": "decapar",
    "decaparia": "decapar",
    "decapariam": "decapar",
    "decaparias": "decapar",
    "decaparmo": "decapar",
    "decaparmos": "decapar",
    "decapará": "decapar",
    "decaparás": "decapar",
    "decaparão": "decapar",
    "decaparíamos": "decapar",
    "decaparíeis": "decapar",
    "decapas": "decapar",
    "decapasse": "decapar",
    "decapassem": "decapar",
    "decapasses": "decapar",
    "decapaste": "decapar",
    "decapastes": "decapar",
    "decapava": "decapar",
    "decapavam": "decapar",
    "decapavas": "decapar",
    "decape": "decapar",
    "decapei": "decapar",
    "decapeis": "decapar",
    "decapem": "decapar",
    "decapemo": "decapar",
    "decapemos": "decapar",
    "decapes": "decapar",
    "decapetaliada": "decapetaliado",
    "decapetaliadas": "decapetaliado",
    "decapetaliados": "decapetaliado",
    "decapita": "decapitar",
    "decapitada": "decapitar",
    "decapitadas": "decapitar",
    "decapitado": "decapitar",
    "decapitados": "decapitar",
    "decapitai": "decapitar",
    "decapitais": "decapitar",
    "decapitam": "decapitar",
    "decapitamo": "decapitar",
    "decapitamos": "decapitar",
    "decapitando": "decapitar",
    "decapitara": "decapitar",
    "decapitaram": "decapitar",
    "decapitaras": "decapitar",
    "decapitarde": "decapitar",
    "decapitardes": "decapitar",
    "decapitare": "decapitar",
    "decapitarei": "decapitar",
    "decapitareis": "decapitar",
    "decapitarem": "decapitar",
    "decapitaremos": "decapitar",
    "decapitares": "decapitar",
    "decapitaria": "decapitar",
    "decapitariam": "decapitar",
    "decapitarias": "decapitar",
    "decapitarmo": "decapitar",
    "decapitarmos": "decapitar",
    "decapitará": "decapitar",
    "decapitarás": "decapitar",
    "decapitarão": "decapitar",
    "decapitaríamos": "decapitar",
    "decapitaríeis": "decapitar",
    "decapitas": "decapitar",
    "decapitasse": "decapitar",
    "decapitassem": "decapitar",
    "decapitasses": "decapitar",
    "decapitaste": "decapitar",
    "decapitastes": "decapitar",
    "decapitava": "decapitar",
    "decapitavam": "decapitar",
    "decapitavas": "decapitar",
    "decapitações": "decapitação",
    "decapite": "decapitar",
    "decapitei": "decapitar",
    "decapiteis": "decapitar",
    "decapitem": "decapitar",
    "decapitemo": "decapitar",
    "decapitemos": "decapitar",
    "decapites": "decapitar",
    "decapito": "decapitar",
    "decapitou": "decapitar",
    "decapitá": "decapitar",
    "decapitámo": "decapitar",
    "decapitámos": "decapitar",
    "decapitáramo": "decapitar",
    "decapitáramos": "decapitar",
    "decapitárei": "decapitar",
    "decapitáreis": "decapitar",
    "decapitásseis": "decapitar",
    "decapitássemos": "decapitar",
    "decapitávamo": "decapitar",
    "decapitávamos": "decapitar",
    "decapitávei": "decapitar",
    "decapitáveis": "decapitar",
    "decapo": "decapar",
    "decapou": "decapar",
    "decapá": "decapar",
    "decapámo": "decapar",
    "decapámos": "decapar",
    "decapáramo": "decapar",
    "decapáramos": "decapar",
    "decapárei": "decapar",
    "decapáreis": "decapar",
    "decapásseis": "decapar",
    "decapássemos": "decapar",
    "decapávamo": "decapar",
    "decapávamos": "decapar",
    "decapávei": "decapar",
    "decapáveis": "decapar",
    "decapétala": "decapétalo",
    "decapétalas": "decapétalo",
    "decapétalos": "decapétalo",
    "decassilábica": "decassilábico",
    "decassilábicas": "decassilábico",
    "decassilábicos": "decassilábico",
    "decassílados": "decassílado",
    "decasteres": "decastere",
    "decastilos": "decastilo",
    "decastérios": "decastério",
    "decatlonistas": "decatlonista",
    "decatlos": "decatlo",
    "decaédrica": "decaédrico",
    "decaédricas": "decaédrico",
    "decaédricos": "decaédrico",
    "decaédros": "decaédro",
    "decaí": "decair",
    "decaía": "decair",
    "decaíam": "decair",
    "decaíamo": "decair",
    "decaíamos": "decair",
    "decaías": "decair",
    "decaída": "decair",
    "decaídas": "decair",
    "decaído": "decair",
    "decaídos": "decair",
    "decaíeis": "decair",
    "decaímo": "decair",
    "decaímos": "decair",
    "decaíra": "decair",
    "decaíram": "decair",
    "decaíramo": "decair",
    "decaíramos": "decair",
    "decaíras": "decair",
    "decaíreis": "decair",
    "decaírem": "decair",
    "decaíres": "decair",
    "decaís": "decair",
    "decaísse": "decair",
    "decaísseis": "decair",
    "decaíssem": "decair",
    "decaíssemos": "decair",
    "decaísses": "decair",
    "decaíste": "decair",
    "decaístes": "decair",
    "decemestrais": "decemestral",
    "decemestres": "decemestre",
    "decemparta": "decempartir",
    "decempartais": "decempartir",
    "decempartam": "decempartir",
    "decempartamo": "decempartir",
    "decempartamos": "decempartir",
    "decempartas": "decempartir",
    "decemparte": "decempartir",
    "decempartem": "decempartir",
    "decempartes": "decempartir",
    "decemparti": "decempartir",
    "decempartia": "decempartir",
    "decempartiam": "decempartir",
    "decempartias": "decempartir",
    "decempartida": "decempartir",
    "decempartidas": "decempartir",
    "decempartido": "decempartir",
    "decempartidos": "decempartir",
    "decempartimo": "decempartir",
    "decempartimos": "decempartir",
    "decempartindo": "decempartir",
    "decempartira": "decempartir",
    "decempartiram": "decempartir",
    "decempartiras": "decempartir",
    "decempartirde": "decempartir",
    "decempartirdes": "decempartir",
    "decempartire": "decempartir",
    "decempartirei": "decempartir",
    "decempartireis": "decempartir",
    "decempartirem": "decempartir",
    "decempartiremos": "decempartir",
    "decempartires": "decempartir",
    "decempartiria": "decempartir",
    "decempartiriam": "decempartir",
    "decempartirias": "decempartir",
    "decempartirmo": "decempartir",
    "decempartirmos": "decempartir",
    "decempartirá": "decempartir",
    "decempartirás": "decempartir",
    "decempartirão": "decempartir",
    "decempartiríamos": "decempartir",
    "decempartiríeis": "decempartir",
    "decempartis": "decempartir",
    "decempartisse": "decempartir",
    "decempartissem": "decempartir",
    "decempartisses": "decempartir",
    "decempartiste": "decempartir",
    "decempartistes": "decempartir",
    "decempartiu": "decempartir",
    "decemparto": "decempartir",
    "decempartíamo": "decempartir",
    "decempartíamos": "decempartir",
    "decempartíei": "decempartir",
    "decempartíeis": "decempartir",
    "decempartíramo": "decempartir",
    "decempartíramos": "decempartir",
    "decempartírei": "decempartir",
    "decempartíreis": "decempartir",
    "decempartísseis": "decempartir",
    "decempartíssemos": "decempartir",
    "decenais": "decenal",
    "decendiais": "decendial",
    "decentes": "decente",
    "decentraliza": "decentralizar",
    "decentralizada": "decentralizar",
    "decentralizadas": "decentralizar",
    "decentralizado": "decentralizar",
    "decentralizadora": "decentralizador",
    "decentralizadoras": "decentralizador",
    "decentralizadores": "decentralizador",
    "decentralizados": "decentralizar",
    "decentralizai": "decentralizar",
    "decentralizais": "decentralizar",
    "decentralizam": "decentralizar",
    "decentralizamo": "decentralizar",
    "decentralizamos": "decentralizar",
    "decentralizando": "decentralizar",
    "decentralizara": "decentralizar",
    "decentralizaram": "decentralizar",
    "decentralizaras": "decentralizar",
    "decentralizarde": "decentralizar",
    "decentralizardes": "decentralizar",
    "decentralizare": "decentralizar",
    "decentralizarei": "decentralizar",
    "decentralizareis": "decentralizar",
    "decentralizarem": "decentralizar",
    "decentralizaremos": "decentralizar",
    "decentralizares": "decentralizar",
    "decentralizaria": "decentralizar",
    "decentralizariam": "decentralizar",
    "decentralizarias": "decentralizar",
    "decentralizarmo": "decentralizar",
    "decentralizarmos": "decentralizar",
    "decentralizará": "decentralizar",
    "decentralizarás": "decentralizar",
    "decentralizarão": "decentralizar",
    "decentralizaríamos": "decentralizar",
    "decentralizaríeis": "decentralizar",
    "decentralizas": "decentralizar",
    "decentralizasse": "decentralizar",
    "decentralizassem": "decentralizar",
    "decentralizasses": "decentralizar",
    "decentralizaste": "decentralizar",
    "decentralizastes": "decentralizar",
    "decentralizava": "decentralizar",
    "decentralizavam": "decentralizar",
    "decentralizavas": "decentralizar",
    "decentralizações": "decentralização",
    "decentralize": "decentralizar",
    "decentralizei": "decentralizar",
    "decentralizeis": "decentralizar",
    "decentralizem": "decentralizar",
    "decentralizemo": "decentralizar",
    "decentralizemos": "decentralizar",
    "decentralizes": "decentralizar",
    "decentralizo": "decentralizar",
    "decentralizou": "decentralizar",
    "decentralizá": "decentralizar",
    "decentralizámo": "decentralizar",
    "decentralizámos": "decentralizar",
    "decentralizáramo": "decentralizar",
    "decentralizáramos": "decentralizar",
    "decentralizárei": "decentralizar",
    "decentralizáreis": "decentralizar",
    "decentralizásseis": "decentralizar",
    "decentralizássemos": "decentralizar",
    "decentralizávamo": "decentralizar",
    "decentralizávamos": "decentralizar",
    "decentralizávei": "decentralizar",
    "decentralizáveis": "decentralizável",
    "decenvirais": "decenviral",
    "decenviratos": "decenvirato",
    "decenária": "decenário",
    "decenárias": "decenário",
    "decenários": "decenário",
    "decepa": "decepar",
    "decepada": "decepar",
    "decepadas": "decepar",
    "decepado": "decepar",
    "decepadora": "decepador",
    "decepadoras": "decepador",
    "decepadores": "decepador",
    "decepados": "decepar",
    "decepagens": "decepagem",
    "decepai": "decepar",
    "decepais": "decepar",
    "decepam": "decepar",
    "decepamentos": "decepamento",
    "decepamo": "decepar",
    "decepamos": "decepar",
    "decepando": "decepar",
    "decepara": "decepar",
    "deceparam": "decepar",
    "deceparas": "decepar",
    "deceparde": "decepar",
    "decepardes": "decepar",
    "decepare": "decepar",
    "deceparei": "decepar",
    "decepareis": "decepar",
    "deceparem": "decepar",
    "deceparemos": "decepar",
    "decepares": "decepar",
    "deceparia": "decepar",
    "decepariam": "decepar",
    "deceparias": "decepar",
    "deceparmo": "decepar",
    "deceparmos": "decepar",
    "decepará": "decepar",
    "deceparás": "decepar",
    "deceparão": "decepar",
    "deceparíamos": "decepar",
    "deceparíeis": "decepar",
    "decepas": "decepar",
    "decepasse": "decepar",
    "decepassem": "decepar",
    "decepasses": "decepar",
    "decepaste": "decepar",
    "decepastes": "decepar",
    "decepava": "decepar",
    "decepavam": "decepar",
    "decepavas": "decepar",
    "decepciona": "decepcionar",
    "decepcionada": "decepcionar",
    "decepcionadas": "decepcionar",
    "decepcionado": "decepcionar",
    "decepcionados": "decepcionar",
    "decepcionadíssima": "decepcionado",
    "decepcionadíssimas": "decepcionado",
    "decepcionadíssimo": "decepcionado",
    "decepcionadíssimos": "decepcionado",
    "decepcionai": "decepcionar",
    "decepcionais": "decepcionar",
    "decepcionam": "decepcionar",
    "decepcionamo": "decepcionar",
    "decepcionamos": "decepcionar",
    "decepcionando": "decepcionar",
    "decepcionantes": "decepcionante",
    "decepcionara": "decepcionar",
    "decepcionaram": "decepcionar",
    "decepcionaras": "decepcionar",
    "decepcionarde": "decepcionar",
    "decepcionardes": "decepcionar",
    "decepcionare": "decepcionar",
    "decepcionarei": "decepcionar",
    "decepcionareis": "decepcionar",
    "decepcionarem": "decepcionar",
    "decepcionaremos": "decepcionar",
    "decepcionares": "decepcionar",
    "decepcionaria": "decepcionar",
    "decepcionariam": "decepcionar",
    "decepcionarias": "decepcionar",
    "decepcionarmo": "decepcionar",
    "decepcionarmos": "decepcionar",
    "decepcionará": "decepcionar",
    "decepcionarás": "decepcionar",
    "decepcionarão": "decepcionar",
    "decepcionaríamos": "decepcionar",
    "decepcionaríeis": "decepcionar",
    "decepcionas": "decepcionar",
    "decepcionasse": "decepcionar",
    "decepcionassem": "decepcionar",
    "decepcionasses": "decepcionar",
    "decepcionaste": "decepcionar",
    "decepcionastes": "decepcionar",
    "decepcionava": "decepcionar",
    "decepcionavam": "decepcionar",
    "decepcionavas": "decepcionar",
    "decepcione": "decepcionar",
    "decepcionei": "decepcionar",
    "decepcioneis": "decepcionar",
    "decepcionem": "decepcionar",
    "decepcionemo": "decepcionar",
    "decepcionemos": "decepcionar",
    "decepciones": "decepcionar",
    "decepciono": "decepcionar",
    "decepcionou": "decepcionar",
    "decepcioná": "decepcionar",
    "decepcionámo": "decepcionar",
    "decepcionámos": "decepcionar",
    "decepcionáramo": "decepcionar",
    "decepcionáramos": "decepcionar",
    "decepcionárei": "decepcionar",
    "decepcionáreis": "decepcionar",
    "decepcionásseis": "decepcionar",
    "decepcionássemos": "decepcionar",
    "decepcionávamo": "decepcionar",
    "decepcionávamos": "decepcionar",
    "decepcionávei": "decepcionar",
    "decepcionáveis": "decepcionável",
    "decepe": "decepar",
    "decepei": "decepar",
    "decepeis": "decepar",
    "decepem": "decepar",
    "decepemo": "decepar",
    "decepemos": "decepar",
    "decepes": "decepar",
    "decepo": "decepar",
    "decepou": "decepar",
    "deceptiva": "deceptivo",
    "deceptivas": "deceptivo",
    "deceptivos": "deceptivo",
    "decepá": "decepar",
    "decepámo": "decepar",
    "decepámos": "decepar",
    "decepáramo": "decepar",
    "decepáramos": "decepar",
    "decepárei": "decepar",
    "decepáreis": "decepar",
    "decepásseis": "decepar",
    "decepássemos": "decepar",
    "decepávamo": "decepar",
    "decepávamos": "decepar",
    "decepávei": "decepar",
    "decepáveis": "decepar",
    "decepções": "decepção",
    "decerta": "decertar",
    "decertada": "decertar",
    "decertadas": "decertar",
    "decertado": "decertar",
    "decertados": "decertar",
    "decertai": "decertar",
    "decertais": "decertar",
    "decertam": "decertar",
    "decertamo": "decertar",
    "decertamos": "decertar",
    "decertando": "decertar",
    "decertara": "decertar",
    "decertaram": "decertar",
    "decertaras": "decertar",
    "decertardes": "decertar",
    "decertarei": "decertar",
    "decertareis": "decertar",
    "decertarem": "decertar",
    "decertaremos": "decertar",
    "decertares": "decertar",
    "decertaria": "decertar",
    "decertariam": "decertar",
    "decertarias": "decertar",
    "decertarmo": "decertar",
    "decertarmos": "decertar",
    "decertará": "decertar",
    "decertarás": "decertar",
    "decertarão": "decertar",
    "decertaríamos": "decertar",
    "decertaríeis": "decertar",
    "decertas": "decertar",
    "decertasse": "decertar",
    "decertassem": "decertar",
    "decertasses": "decertar",
    "decertaste": "decertar",
    "decertastes": "decertar",
    "decertava": "decertar",
    "decertavam": "decertar",
    "decertavas": "decertar",
    "decerte": "decertar",
    "decertei": "decertar",
    "decerteis": "decertar",
    "decertem": "decertar",
    "decertemo": "decertar",
    "decertemos": "decertar",
    "decertes": "decertar",
    "decerto": "decertar",
    "decertou": "decertar",
    "decertámo": "decertar",
    "decertámos": "decertar",
    "decertáramo": "decertar",
    "decertáramos": "decertar",
    "decertáreis": "decertar",
    "decertásseis": "decertar",
    "decertássemos": "decertar",
    "decertávamo": "decertar",
    "decertávamos": "decertar",
    "decertáveis": "decertar",
    "decessos": "decesso",
    "decibéis": "decibel",
    "decida": "decidir",
    "decidais": "decidir",
    "decidam": "decidir",
    "decidamo": "decidir",
    "decidamos": "decidir",
    "decidas": "decidir",
    "decide": "decidir",
    "decidem": "decidir",
    "decides": "decidir",
    "decidi": "decidir",
    "decidia": "decidir",
    "decidiam": "decidir",
    "decidias": "decidir",
    "decidida": "decidir",
    "decididas": "decidir",
    "decidido": "decidir",
    "decididos": "decidir",
    "decididíssima": "decidido",
    "decididíssimas": "decidido",
    "decididíssimo": "decidido",
    "decididíssimos": "decidido",
    "decidimo": "decidir",
    "decidimos": "decidir",
    "decidindo": "decidir",
    "decidira": "decidir",
    "decidiram": "decidir",
    "decidiras": "decidir",
    "decidirde": "decidir",
    "decidirdes": "decidir",
    "decidire": "decidir",
    "decidirei": "decidir",
    "decidireis": "decidir",
    "decidirem": "decidir",
    "decidiremos": "decidir",
    "decidires": "decidir",
    "decidiria": "decidir",
    "decidiriam": "decidir",
    "decidirias": "decidir",
    "decidirmo": "decidir",
    "decidirmos": "decidir",
    "decidirá": "decidir",
    "decidirás": "decidir",
    "decidirão": "decidir",
    "decidiríamos": "decidir",
    "decidiríeis": "decidir",
    "decidis": "decidir",
    "decidisse": "decidir",
    "decidissem": "decidir",
    "decidisses": "decidir",
    "decidiste": "decidir",
    "decidistes": "decidir",
    "decidiu": "decidir",
    "decido": "decidir",
    "decidua": "deciduo",
    "deciduada": "deciduado",
    "deciduadas": "deciduado",
    "deciduados": "deciduado",
    "deciduas": "deciduo",
    "deciduomas": "deciduoma",
    "deciduos": "deciduo",
    "decidíamo": "decidir",
    "decidíamos": "decidir",
    "decidíei": "decidir",
    "decidíeis": "decidir",
    "decidíramo": "decidir",
    "decidíramos": "decidir",
    "decidírei": "decidir",
    "decidíreis": "decidir",
    "decidísseis": "decidir",
    "decidíssemos": "decidir",
    "decifra": "decifrar",
    "decifrada": "decifrar",
    "decifradas": "decifrar",
    "decifrado": "decifrar",
    "decifradora": "decifrador",
    "decifradoras": "decifrador",
    "decifradores": "decifrador",
    "decifrados": "decifrar",
    "decifrai": "decifrar",
    "decifrais": "decifrar",
    "decifram": "decifrar",
    "deciframentos": "deciframento",
    "deciframo": "decifrar",
    "deciframos": "decifrar",
    "decifrando": "decifrar",
    "decifrara": "decifrar",
    "decifraram": "decifrar",
    "decifraras": "decifrar",
    "decifrarde": "decifrar",
    "decifrardes": "decifrar",
    "decifrare": "decifrar",
    "decifrarei": "decifrar",
    "decifrareis": "decifrar",
    "decifrarem": "decifrar",
    "decifraremos": "decifrar",
    "decifrares": "decifrar",
    "decifraria": "decifrar",
    "decifrariam": "decifrar",
    "decifrarias": "decifrar",
    "decifrarmo": "decifrar",
    "decifrarmos": "decifrar",
    "decifrará": "decifrar",
    "decifrarás": "decifrar",
    "decifrarão": "decifrar",
    "decifraríamos": "decifrar",
    "decifraríeis": "decifrar",
    "decifras": "decifrar",
    "decifrasse": "decifrar",
    "decifrassem": "decifrar",
    "decifrasses": "decifrar",
    "decifraste": "decifrar",
    "decifrastes": "decifrar",
    "decifrava": "decifrar",
    "decifravam": "decifrar",
    "decifravas": "decifrar",
    "decifrações": "decifração",
    "decifre": "decifrar",
    "decifrei": "decifrar",
    "decifreis": "decifrar",
    "decifrem": "decifrar",
    "decifremo": "decifrar",
    "decifremos": "decifrar",
    "decifres": "decifrar",
    "decifro": "decifrar",
    "decifrou": "decifrar",
    "decifrá": "decifrar",
    "decifrámo": "decifrar",
    "decifrámos": "decifrar",
    "decifráramo": "decifrar",
    "decifráramos": "decifrar",
    "decifrárei": "decifrar",
    "decifráreis": "decifrar",
    "decifrásseis": "decifrar",
    "decifrássemos": "decifrar",
    "decifrávamo": "decifrar",
    "decifrávamos": "decifrar",
    "decifrávei": "decifrar",
    "decifráveis": "decifrável",
    "decigrados": "decigrado",
    "decigramas": "decigrama",
    "decilitragens": "decilitragem",
    "decilitreira": "decilitreiro",
    "decilitreiras": "decilitreiro",
    "decilitreiros": "decilitreiro",
    "decilitros": "decilitro",
    "decima": "decimar",
    "decimada": "decimar",
    "decimadas": "decimar",
    "decimado": "decimar",
    "decimados": "decimar",
    "decimai": "decimar",
    "decimais": "decimar",
    "decimalidades": "decimalidade",
    "decimalizações": "decimalização",
    "decimam": "decimar",
    "decimamo": "decimar",
    "decimamos": "decimar",
    "decimando": "decimar",
    "decimara": "decimar",
    "decimaram": "decimar",
    "decimaras": "decimar",
    "decimarde": "decimar",
    "decimardes": "decimar",
    "decimare": "decimar",
    "decimarei": "decimar",
    "decimareis": "decimar",
    "decimarem": "decimar",
    "decimaremos": "decimar",
    "decimares": "decimar",
    "decimaria": "decimar",
    "decimariam": "decimar",
    "decimarias": "decimar",
    "decimarmo": "decimar",
    "decimarmos": "decimar",
    "decimará": "decimar",
    "decimarás": "decimar",
    "decimarão": "decimar",
    "decimaríamos": "decimar",
    "decimaríeis": "decimar",
    "decimas": "decimar",
    "decimasse": "decimar",
    "decimassem": "decimar",
    "decimasses": "decimar",
    "decimaste": "decimar",
    "decimastes": "decimar",
    "decimava": "decimar",
    "decimavam": "decimar",
    "decimavas": "decimar",
    "decime": "decimar",
    "decimei": "decimar",
    "decimeis": "decimar",
    "decimem": "decimar",
    "decimemo": "decimar",
    "decimemos": "decimar",
    "decimes": "decimar",
    "decimo": "decimar",
    "decimou": "decimar",
    "decimá": "decimar",
    "decimámo": "decimar",
    "decimámos": "decimar",
    "decimáramo": "decimar",
    "decimáramos": "decimar",
    "decimárei": "decimar",
    "decimáreis": "decimar",
    "decimásseis": "decimar",
    "decimássemos": "decimar",
    "decimávamo": "decimar",
    "decimávamos": "decimar",
    "decimávei": "decimar",
    "decimáveis": "decimável",
    "decis": "decil",
    "decisiva": "decisivo",
    "decisivas": "decisivo",
    "decisivos": "decisivo",
    "decisora": "decisor",
    "decisoras": "decisor",
    "decisores": "decisor",
    "decisseculares": "decissecular",
    "decisteres": "decistere",
    "decistéreos": "decistéreo",
    "decisória": "decisório",
    "decisórias": "decisório",
    "decisórios": "decisório",
    "decisões": "decisão",
    "declama": "declamar",
    "declamada": "declamar",
    "declamadas": "declamar",
    "declamado": "declamar",
    "declamadora": "declamador",
    "declamadoras": "declamador",
    "declamadores": "declamador",
    "declamados": "declamar",
    "declamai": "declamar",
    "declamais": "declamar",
    "declamam": "declamar",
    "declamamo": "declamar",
    "declamamos": "declamar",
    "declamando": "declamar",
    "declamantes": "declamante",
    "declamara": "declamar",
    "declamaram": "declamar",
    "declamaras": "declamar",
    "declamarde": "declamar",
    "declamardes": "declamar",
    "declamare": "declamar",
    "declamarei": "declamar",
    "declamareis": "declamar",
    "declamarem": "declamar",
    "declamaremos": "declamar",
    "declamares": "declamar",
    "declamaria": "declamar",
    "declamariam": "declamar",
    "declamarias": "declamar",
    "declamarmo": "declamar",
    "declamarmos": "declamar",
    "declamará": "declamar",
    "declamarás": "declamar",
    "declamarão": "declamar",
    "declamaríamos": "declamar",
    "declamaríeis": "declamar",
    "declamas": "declamar",
    "declamasse": "declamar",
    "declamassem": "declamar",
    "declamasses": "declamar",
    "declamaste": "declamar",
    "declamastes": "declamar",
    "declamativa": "declamativo",
    "declamativas": "declamativo",
    "declamativos": "declamativo",
    "declamatória": "declamatório",
    "declamatórias": "declamatório",
    "declamatórios": "declamatório",
    "declamava": "declamar",
    "declamavam": "declamar",
    "declamavas": "declamar",
    "declamações": "declamação",
    "declame": "declamar",
    "declamei": "declamar",
    "declameis": "declamar",
    "declamem": "declamar",
    "declamemo": "declamar",
    "declamemos": "declamar",
    "declames": "declamar",
    "declamo": "declamar",
    "declamou": "declamar",
    "declamá": "declamar",
    "declamámo": "declamar",
    "declamámos": "declamar",
    "declamáramo": "declamar",
    "declamáramos": "declamar",
    "declamárei": "declamar",
    "declamáreis": "declamar",
    "declamásseis": "declamar",
    "declamássemos": "declamar",
    "declamávamo": "declamar",
    "declamávamos": "declamar",
    "declamávei": "declamar",
    "declamáveis": "declamar",
    "declara": "declarar",
    "declarada": "declarar",
    "declaradas": "declarar",
    "declarado": "declarar",
    "declaradora": "declarador",
    "declaradoras": "declarador",
    "declaradores": "declarador",
    "declarados": "declarar",
    "declarai": "declarar",
    "declarais": "declarar",
    "declaram": "declarar",
    "declaramo": "declarar",
    "declaramos": "declarar",
    "declarando": "declarar",
    "declarantes": "declarante",
    "declarara": "declarar",
    "declararam": "declarar",
    "declararas": "declarar",
    "declararde": "declarar",
    "declarardes": "declarar",
    "declarare": "declarar",
    "declararei": "declarar",
    "declarareis": "declarar",
    "declararem": "declarar",
    "declararemos": "declarar",
    "declarares": "declarar",
    "declararia": "declarar",
    "declarariam": "declarar",
    "declararias": "declarar",
    "declararmo": "declarar",
    "declararmos": "declarar",
    "declarará": "declarar",
    "declararás": "declarar",
    "declararão": "declarar",
    "declararíamos": "declarar",
    "declararíeis": "declarar",
    "declaras": "declarar",
    "declarasse": "declarar",
    "declarassem": "declarar",
    "declarasses": "declarar",
    "declaraste": "declarar",
    "declarastes": "declarar",
    "declarativa": "declarativo",
    "declarativas": "declarativo",
    "declarativos": "declarativo",
    "declaratória": "declaratório",
    "declaratórias": "declaratório",
    "declaratórios": "declaratório",
    "declarava": "declarar",
    "declaravam": "declarar",
    "declaravas": "declarar",
    "declarações": "declaração",
    "declare": "declarar",
    "declarei": "declarar",
    "declareis": "declarar",
    "declarem": "declarar",
    "declaremo": "declarar",
    "declaremos": "declarar",
    "declares": "declarar",
    "declaro": "declarar",
    "declarou": "declarar",
    "declará": "declarar",
    "declarámo": "declarar",
    "declarámos": "declarar",
    "declaráramo": "declarar",
    "declaráramos": "declarar",
    "declarárei": "declarar",
    "declaráreis": "declarar",
    "declarásseis": "declarar",
    "declarássemos": "declarar",
    "declarávamo": "declarar",
    "declarávamos": "declarar",
    "declarávei": "declarar",
    "declaráveis": "declarável",
    "declina": "declinar",
    "declinada": "declinar",
    "declinadas": "declinar",
    "declinado": "declinar",
    "declinadora": "declinador",
    "declinadoras": "declinador",
    "declinadores": "declinador",
    "declinados": "declinar",
    "declinai": "declinar",
    "declinais": "declinar",
    "declinam": "declinar",
    "declinamo": "declinar",
    "declinamos": "declinar",
    "declinando": "declinar",
    "declinantes": "declinante",
    "declinara": "declinar",
    "declinaram": "declinar",
    "declinaras": "declinar",
    "declinarde": "declinar",
    "declinardes": "declinar",
    "declinare": "declinar",
    "declinarei": "declinar",
    "declinareis": "declinar",
    "declinarem": "declinar",
    "declinaremos": "declinar",
    "declinares": "declinar",
    "declinaria": "declinar",
    "declinariam": "declinar",
    "declinarias": "declinar",
    "declinarmo": "declinar",
    "declinarmos": "declinar",
    "declinará": "declinar",
    "declinarás": "declinar",
    "declinarão": "declinar",
    "declinaríamos": "declinar",
    "declinaríeis": "declinar",
    "declinas": "declinar",
    "declinasse": "declinar",
    "declinassem": "declinar",
    "declinasses": "declinar",
    "declinaste": "declinar",
    "declinastes": "declinar",
    "declinativa": "declinativo",
    "declinativas": "declinativo",
    "declinativos": "declinativo",
    "declinatória": "declinatório",
    "declinatórias": "declinatório",
    "declinatórios": "declinatório",
    "declinava": "declinar",
    "declinavam": "declinar",
    "declinavas": "declinar",
    "declinações": "declinação",
    "decline": "declinar",
    "declinei": "declinar",
    "declineis": "declinar",
    "declinem": "declinar",
    "declinemo": "declinar",
    "declinemos": "declinar",
    "declines": "declinar",
    "declino": "declinar",
    "declinou": "declinar",
    "decliná": "declinar",
    "declinámo": "declinar",
    "declinámos": "declinar",
    "declináramo": "declinar",
    "declináramos": "declinar",
    "declinárei": "declinar",
    "declináreis": "declinar",
    "declinásseis": "declinar",
    "declinássemos": "declinar",
    "declinávamo": "declinar",
    "declinávamos": "declinar",
    "declinávei": "declinar",
    "declináveis": "declinável",
    "declinómetros": "declinómetro",
    "decliva": "declivar",
    "declivada": "declivar",
    "declivadas": "declivar",
    "declivado": "declivar",
    "declivados": "declivar",
    "declivai": "declivar",
    "declivais": "declivar",
    "declivam": "declivar",
    "declivamo": "declivar",
    "declivamos": "declivar",
    "declivando": "declivar",
    "declivara": "declivar",
    "declivaram": "declivar",
    "declivaras": "declivar",
    "declivardes": "declivar",
    "declivarei": "declivar",
    "declivareis": "declivar",
    "declivarem": "declivar",
    "declivaremos": "declivar",
    "declivares": "declivar",
    "declivaria": "declivar",
    "declivariam": "declivar",
    "declivarias": "declivar",
    "declivarmo": "declivar",
    "declivarmos": "declivar",
    "declivará": "declivar",
    "declivarás": "declivar",
    "declivarão": "declivar",
    "declivaríamos": "declivar",
    "declivaríeis": "declivar",
    "declivas": "declivar",
    "declivasse": "declivar",
    "declivassem": "declivar",
    "declivasses": "declivar",
    "declivaste": "declivar",
    "declivastes": "declivar",
    "declivava": "declivar",
    "declivavam": "declivar",
    "declivavas": "declivar",
    "declive": "declivar",
    "declivei": "declivar",
    "decliveis": "declivar",
    "declivem": "declivar",
    "declivemo": "declivar",
    "declivemos": "declivar",
    "declives": "declive",
    "declividades": "declividade",
    "declivo": "declivar",
    "declivosa": "declivoso",
    "declivosas": "declivoso",
    "declivosos": "declivoso",
    "declivou": "declivar",
    "declivámo": "declivar",
    "declivámos": "declivar",
    "decliváramo": "declivar",
    "decliváramos": "declivar",
    "decliváreis": "declivar",
    "declivásseis": "declivar",
    "declivássemos": "declivar",
    "declivávamo": "declivar",
    "declivávamos": "declivar",
    "decliváveis": "declivar",
    "declínios": "declínio",
    "declívios": "declívio",
    "decoadas": "decoada",
    "decoctos": "decocto",
    "decocções": "decocção",
    "decolagems": "decolagem",
    "decompomo": "decompor",
    "decompomos": "decompor",
    "decomponde": "decompor",
    "decompondes": "decompor",
    "decompondo": "decompor",
    "decomponentes": "decomponente",
    "decomponha": "decompor",
    "decomponhais": "decompor",
    "decomponham": "decompor",
    "decomponhamo": "decompor",
    "decomponhamos": "decompor",
    "decomponhas": "decompor",
    "decomponho": "decompor",
    "decomponibilidades": "decomponibilidade",
    "decomponíveis": "decomponível",
    "decomporde": "decompor",
    "decompordes": "decompor",
    "decompore": "decompor",
    "decomporei": "decompor",
    "decomporeis": "decompor",
    "decomporem": "decompor",
    "decomporemos": "decompor",
    "decompores": "decompor",
    "decomporia": "decompor",
    "decomporiam": "decompor",
    "decomporias": "decompor",
    "decompormo": "decompor",
    "decompormos": "decompor",
    "decomporá": "decompor",
    "decomporás": "decompor",
    "decomporão": "decompor",
    "decomporíamos": "decompor",
    "decomporíeis": "decompor",
    "decomposições": "decomposição",
    "decomposta": "decomposto",
    "decompostas": "decomposto",
    "decomposto": "decompor",
    "decompostos": "decomposto",
    "decompunha": "decompor",
    "decompunham": "decompor",
    "decompunhas": "decompor",
    "decompus": "decompor",
    "decompusemo": "decompor",
    "decompusemos": "decompor",
    "decompuser": "decompor",
    "decompusera": "decompor",
    "decompuseram": "decompor",
    "decompuseras": "decompor",
    "decompuserdes": "decompor",
    "decompuserem": "decompor",
    "decompuseres": "decompor",
    "decompusermos": "decompor",
    "decompusesse": "decompor",
    "decompusessem": "decompor",
    "decompusesses": "decompor",
    "decompuseste": "decompor",
    "decompusestes": "decompor",
    "decompuséramo": "decompor",
    "decompuséramos": "decompor",
    "decompusérei": "decompor",
    "decompuséreis": "decompor",
    "decompusésseis": "decompor",
    "decompuséssemos": "decompor",
    "decompô": "decompor",
    "decompôs": "decompor",
    "decompõe": "decompor",
    "decompõem": "decompor",
    "decompões": "decompor",
    "decompúnhamo": "decompor",
    "decompúnhamos": "decompor",
    "decompúnhei": "decompor",
    "decompúnheis": "decompor",
    "decora": "decorar",
    "decorada": "decorar",
    "decoradas": "decorar",
    "decorado": "decorar",
    "decoradora": "decorador",
    "decoradoras": "decorador",
    "decoradores": "decorador",
    "decorados": "decorar",
    "decorai": "decorar",
    "decorais": "decorar",
    "decoram": "decorar",
    "decoramo": "decorar",
    "decoramos": "decorar",
    "decorando": "decorar",
    "decorara": "decorar",
    "decoraram": "decorar",
    "decoraras": "decorar",
    "decorarde": "decorar",
    "decorardes": "decorar",
    "decorare": "decorar",
    "decorarei": "decorar",
    "decorareis": "decorar",
    "decorarem": "decorar",
    "decoraremos": "decorar",
    "decorares": "decorar",
    "decoraria": "decorar",
    "decorariam": "decorar",
    "decorarias": "decorar",
    "decorarmo": "decorar",
    "decorarmos": "decorar",
    "decorará": "decorar",
    "decorarás": "decorar",
    "decorarão": "decorar",
    "decoraríamos": "decorar",
    "decoraríeis": "decorar",
    "decoras": "decorar",
    "decorasse": "decorar",
    "decorassem": "decorar",
    "decorasses": "decorar",
    "decoraste": "decorar",
    "decorastes": "decorar",
    "decorativa": "decorativo",
    "decorativas": "decorativo",
    "decorativos": "decorativo",
    "decorava": "decorar",
    "decoravam": "decorar",
    "decoravas": "decorar",
    "decorações": "decoração",
    "decore": "decorar",
    "decorei": "decorar",
    "decoreis": "decorar",
    "decorem": "decorar",
    "decoremo": "decorar",
    "decoremos": "decorar",
    "decores": "decorar",
    "decoro": "decorar",
    "decoros": "decoro",
    "decorosa": "decoroso",
    "decorosas": "decoroso",
    "decorosos": "decoroso",
    "decorou": "decorar",
    "decorra": "decorrer",
    "decorrais": "decorrer",
    "decorram": "decorrer",
    "decorramo": "decorrer",
    "decorramos": "decorrer",
    "decorras": "decorrer",
    "decorre": "decorrer",
    "decorrei": "decorrer",
    "decorreis": "decorrer",
    "decorrem": "decorrer",
    "decorremo": "decorrer",
    "decorremos": "decorrer",
    "decorrendo": "decorrer",
    "decorrentes": "decorrente",
    "decorrera": "decorrer",
    "decorreram": "decorrer",
    "decorreras": "decorrer",
    "decorrerdes": "decorrer",
    "decorrerei": "decorrer",
    "decorrereis": "decorrer",
    "decorrerem": "decorrer",
    "decorreremos": "decorrer",
    "decorreres": "decorrer",
    "decorreria": "decorrer",
    "decorreriam": "decorrer",
    "decorrerias": "decorrer",
    "decorrermo": "decorrer",
    "decorrermos": "decorrer",
    "decorrerá": "decorrer",
    "decorrerás": "decorrer",
    "decorrerão": "decorrer",
    "decorreríamos": "decorrer",
    "decorreríeis": "decorrer",
    "decorres": "decorrer",
    "decorresse": "decorrer",
    "decorressem": "decorrer",
    "decorresses": "decorrer",
    "decorreste": "decorrer",
    "decorrestes": "decorrer",
    "decorreu": "decorrer",
    "decorri": "decorrer",
    "decorria": "decorrer",
    "decorriam": "decorrer",
    "decorrias": "decorrer",
    "decorrida": "decorrido",
    "decorridas": "decorrido",
    "decorrido": "decorrer",
    "decorridos": "decorrido",
    "decorro": "decorrer",
    "decorrêramo": "decorrer",
    "decorrêramos": "decorrer",
    "decorrêreis": "decorrer",
    "decorrêsseis": "decorrer",
    "decorrêssemos": "decorrer",
    "decorríamo": "decorrer",
    "decorríamos": "decorrer",
    "decorríeis": "decorrer",
    "decortica": "decorticar",
    "decorticada": "decorticar",
    "decorticadas": "decorticar",
    "decorticado": "decorticar",
    "decorticados": "decorticar",
    "decorticai": "decorticar",
    "decorticais": "decorticar",
    "decorticam": "decorticar",
    "decorticamo": "decorticar",
    "decorticamos": "decorticar",
    "decorticando": "decorticar",
    "decorticara": "decorticar",
    "decorticaram": "decorticar",
    "decorticaras": "decorticar",
    "decorticarde": "decorticar",
    "decorticardes": "decorticar",
    "decorticare": "decorticar",
    "decorticarei": "decorticar",
    "decorticareis": "decorticar",
    "decorticarem": "decorticar",
    "decorticaremos": "decorticar",
    "decorticares": "decorticar",
    "decorticaria": "decorticar",
    "decorticariam": "decorticar",
    "decorticarias": "decorticar",
    "decorticarmo": "decorticar",
    "decorticarmos": "decorticar",
    "decorticará": "decorticar",
    "decorticarás": "decorticar",
    "decorticarão": "decorticar",
    "decorticaríamos": "decorticar",
    "decorticaríeis": "decorticar",
    "decorticas": "decorticar",
    "decorticasse": "decorticar",
    "decorticassem": "decorticar",
    "decorticasses": "decorticar",
    "decorticaste": "decorticar",
    "decorticastes": "decorticar",
    "decorticava": "decorticar",
    "decorticavam": "decorticar",
    "decorticavas": "decorticar",
    "decorticações": "decorticação",
    "decortico": "decorticar",
    "decorticou": "decorticar",
    "decorticá": "decorticar",
    "decorticámo": "decorticar",
    "decorticámos": "decorticar",
    "decorticáramo": "decorticar",
    "decorticáramos": "decorticar",
    "decorticárei": "decorticar",
    "decorticáreis": "decorticar",
    "decorticásseis": "decorticar",
    "decorticássemos": "decorticar",
    "decorticávamo": "decorticar",
    "decorticávamos": "decorticar",
    "decorticávei": "decorticar",
    "decorticáveis": "decorticar",
    "decortique": "decorticar",
    "decortiquei": "decorticar",
    "decortiqueis": "decorticar",
    "decortiquem": "decorticar",
    "decortiquemo": "decorticar",
    "decortiquemos": "decorticar",
    "decortiques": "decorticar",
    "decorá": "decorar",
    "decorámo": "decorar",
    "decorámos": "decorar",
    "decoráramo": "decorar",
    "decoráramos": "decorar",
    "decorárei": "decorar",
    "decoráreis": "decorar",
    "decorásseis": "decorar",
    "decorássemos": "decorar",
    "decorávamo": "decorar",
    "decorávamos": "decorar",
    "decorávei": "decorar",
    "decoráveis": "decorável",
    "decorências": "decorência",
    "decota": "decotar",
    "decotada": "decotar",
    "decotadas": "decotar",
    "decotado": "decotar",
    "decotadora": "decotador",
    "decotadoras": "decotador",
    "decotadores": "decotador",
    "decotados": "decotar",
    "decotadíssima": "decotado",
    "decotadíssimas": "decotado",
    "decotadíssimo": "decotado",
    "decotadíssimos": "decotado",
    "decotai": "decotar",
    "decotais": "decotar",
    "decotam": "decotar",
    "decotamo": "decotar",
    "decotamos": "decotar",
    "decotando": "decotar",
    "decotara": "decotar",
    "decotaram": "decotar",
    "decotaras": "decotar",
    "decotarde": "decotar",
    "decotardes": "decotar",
    "decotare": "decotar",
    "decotarei": "decotar",
    "decotareis": "decotar",
    "decotarem": "decotar",
    "decotaremos": "decotar",
    "decotares": "decotar",
    "decotaria": "decotar",
    "decotariam": "decotar",
    "decotarias": "decotar",
    "decotarmo": "decotar",
    "decotarmos": "decotar",
    "decotará": "decotar",
    "decotarás": "decotar",
    "decotarão": "decotar",
    "decotaríamos": "decotar",
    "decotaríeis": "decotar",
    "decotas": "decotar",
    "decotasse": "decotar",
    "decotassem": "decotar",
    "decotasses": "decotar",
    "decotaste": "decotar",
    "decotastes": "decotar",
    "decotava": "decotar",
    "decotavam": "decotar",
    "decotavas": "decotar",
    "decote": "decotar",
    "decotei": "decotar",
    "decoteis": "decotar",
    "decotem": "decotar",
    "decotemo": "decotar",
    "decotemos": "decotar",
    "decotes": "decote",
    "decoto": "decotar",
    "decotou": "decotar",
    "decotá": "decotar",
    "decotámo": "decotar",
    "decotámos": "decotar",
    "decotáramo": "decotar",
    "decotáramos": "decotar",
    "decotárei": "decotar",
    "decotáreis": "decotar",
    "decotásseis": "decotar",
    "decotássemos": "decotar",
    "decotávamo": "decotar",
    "decotávamos": "decotar",
    "decotávei": "decotar",
    "decotáveis": "decotar",
    "decrementada": "decrementado",
    "decrementadas": "decrementado",
    "decrementados": "decrementado",
    "decrementos": "decremento",
    "decrepita": "decrepitar",
    "decrepitada": "decrepitar",
    "decrepitadas": "decrepitar",
    "decrepitado": "decrepitar",
    "decrepitados": "decrepitar",
    "decrepitai": "decrepitar",
    "decrepitais": "decrepitar",
    "decrepitam": "decrepitar",
    "decrepitamo": "decrepitar",
    "decrepitamos": "decrepitar",
    "decrepitando": "decrepitar",
    "decrepitara": "decrepitar",
    "decrepitaram": "decrepitar",
    "decrepitaras": "decrepitar",
    "decrepitardes": "decrepitar",
    "decrepitarei": "decrepitar",
    "decrepitareis": "decrepitar",
    "decrepitarem": "decrepitar",
    "decrepitaremos": "decrepitar",
    "decrepitares": "decrepitar",
    "decrepitaria": "decrepitar",
    "decrepitariam": "decrepitar",
    "decrepitarias": "decrepitar",
    "decrepitarmo": "decrepitar",
    "decrepitarmos": "decrepitar",
    "decrepitará": "decrepitar",
    "decrepitarás": "decrepitar",
    "decrepitarão": "decrepitar",
    "decrepitaríamos": "decrepitar",
    "decrepitaríeis": "decrepitar",
    "decrepitas": "decrepitar",
    "decrepitasse": "decrepitar",
    "decrepitassem": "decrepitar",
    "decrepitasses": "decrepitar",
    "decrepitaste": "decrepitar",
    "decrepitastes": "decrepitar",
    "decrepitava": "decrepitar",
    "decrepitavam": "decrepitar",
    "decrepitavas": "decrepitar",
    "decrepitações": "decrepitação",
    "decrepite": "decrepitar",
    "decrepitei": "decrepitar",
    "decrepiteis": "decrepitar",
    "decrepitem": "decrepitar",
    "decrepitemo": "decrepitar",
    "decrepitemos": "decrepitar",
    "decrepites": "decrepitar",
    "decrepito": "decrepitar",
    "decrepitou": "decrepitar",
    "decrepitudes": "decrepitude",
    "decrepitámo": "decrepitar",
    "decrepitámos": "decrepitar",
    "decrepitáramo": "decrepitar",
    "decrepitáramos": "decrepitar",
    "decrepitáreis": "decrepitar",
    "decrepitásseis": "decrepitar",
    "decrepitássemos": "decrepitar",
    "decrepitávamo": "decrepitar",
    "decrepitávamos": "decrepitar",
    "decrepitáveis": "decrepitar",
    "decresce": "decrescer",
    "decrescei": "decrescer",
    "decresceis": "decrescer",
    "decrescem": "decrescer",
    "decrescemo": "decrescer",
    "decrescemos": "decrescer",
    "decrescendo": "decrescer",
    "decrescendos": "decrescendo",
    "decrescentes": "decrescente",
    "decrescenças": "decrescença",
    "decrescera": "decrescer",
    "decresceram": "decrescer",
    "decresceras": "decrescer",
    "decrescerdes": "decrescer",
    "decrescerei": "decrescer",
    "decrescereis": "decrescer",
    "decrescerem": "decrescer",
    "decresceremos": "decrescer",
    "decresceres": "decrescer",
    "decresceria": "decrescer",
    "decresceriam": "decrescer",
    "decrescerias": "decrescer",
    "decrescermo": "decrescer",
    "decrescermos": "decrescer",
    "decrescerá": "decrescer",
    "decrescerás": "decrescer",
    "decrescerão": "decrescer",
    "decresceríamos": "decrescer",
    "decresceríeis": "decrescer",
    "decresces": "decrescer",
    "decrescesse": "decrescer",
    "decrescessem": "decrescer",
    "decrescesses": "decrescer",
    "decresceste": "decrescer",
    "decrescestes": "decrescer",
    "decresceu": "decrescer",
    "decresci": "decrescer",
    "decrescia": "decrescer",
    "decresciam": "decrescer",
    "decrescias": "decrescer",
    "decrescida": "decrescer",
    "decrescidas": "decrescer",
    "decrescido": "decrescer",
    "decrescidos": "decrescer",
    "decrescimentos": "decrescimento",
    "decrescêramo": "decrescer",
    "decrescêramos": "decrescer",
    "decrescêreis": "decrescer",
    "decrescêsseis": "decrescer",
    "decrescêssemos": "decrescer",
    "decrescíamo": "decrescer",
    "decrescíamos": "decrescer",
    "decrescíeis": "decrescer",
    "decresça": "decrescer",
    "decresçais": "decrescer",
    "decresçam": "decrescer",
    "decresçamo": "decrescer",
    "decresçamos": "decrescer",
    "decresças": "decrescer",
    "decresço": "decrescer",
    "decreta": "decretar",
    "decretada": "decretar",
    "decretadas": "decretar",
    "decretado": "decretar",
    "decretadora": "decretador",
    "decretadoras": "decretador",
    "decretadores": "decretador",
    "decretados": "decretar",
    "decretadíssima": "decretado",
    "decretadíssimas": "decretado",
    "decretadíssimo": "decretado",
    "decretadíssimos": "decretado",
    "decretai": "decretar",
    "decretais": "decretar",
    "decretalistas": "decretalista",
    "decretam": "decretar",
    "decretamo": "decretar",
    "decretamos": "decretar",
    "decretando": "decretar",
    "decretara": "decretar",
    "decretaram": "decretar",
    "decretaras": "decretar",
    "decretarde": "decretar",
    "decretardes": "decretar",
    "decretare": "decretar",
    "decretarei": "decretar",
    "decretareis": "decretar",
    "decretarem": "decretar",
    "decretaremos": "decretar",
    "decretares": "decretar",
    "decretaria": "decretar",
    "decretariam": "decretar",
    "decretarias": "decretar",
    "decretarmo": "decretar",
    "decretarmos": "decretar",
    "decretará": "decretar",
    "decretarás": "decretar",
    "decretarão": "decretar",
    "decretaríamos": "decretar",
    "decretaríeis": "decretar",
    "decretas": "decretar",
    "decretasse": "decretar",
    "decretassem": "decretar",
    "decretasses": "decretar",
    "decretaste": "decretar",
    "decretastes": "decretar",
    "decretava": "decretar",
    "decretavam": "decretar",
    "decretavas": "decretar",
    "decretações": "decretação",
    "decrete": "decretar",
    "decretei": "decretar",
    "decreteis": "decretar",
    "decretem": "decretar",
    "decretemo": "decretar",
    "decretemos": "decretar",
    "decretes": "decretar",
    "decreto": "decretar",
    "decretos": "decreto",
    "decretou": "decretar",
    "decretá": "decretar",
    "decretámo": "decretar",
    "decretámos": "decretar",
    "decretáramo": "decretar",
    "decretáramos": "decretar",
    "decretárei": "decretar",
    "decretáreis": "decretar",
    "decretásseis": "decretar",
    "decretássemos": "decretar",
    "decretávamo": "decretar",
    "decretávamos": "decretar",
    "decretávei": "decretar",
    "decretáveis": "decretável",
    "decretória": "decretório",
    "decretórias": "decretório",
    "decretórios": "decretório",
    "decriptações": "decriptação",
    "decrua": "decruar",
    "decruada": "decruar",
    "decruadas": "decruar",
    "decruado": "decruar",
    "decruados": "decruar",
    "decruagens": "decruagem",
    "decruai": "decruar",
    "decruais": "decruar",
    "decruam": "decruar",
    "decruamo": "decruar",
    "decruamos": "decruar",
    "decruando": "decruar",
    "decruara": "decruar",
    "decruaram": "decruar",
    "decruaras": "decruar",
    "decruarde": "decruar",
    "decruardes": "decruar",
    "decruare": "decruar",
    "decruarei": "decruar",
    "decruareis": "decruar",
    "decruarem": "decruar",
    "decruaremos": "decruar",
    "decruares": "decruar",
    "decruaria": "decruar",
    "decruariam": "decruar",
    "decruarias": "decruar",
    "decruarmo": "decruar",
    "decruarmos": "decruar",
    "decruará": "decruar",
    "decruarás": "decruar",
    "decruarão": "decruar",
    "decruaríamos": "decruar",
    "decruaríeis": "decruar",
    "decruas": "decruar",
    "decruasse": "decruar",
    "decruassem": "decruar",
    "decruasses": "decruar",
    "decruaste": "decruar",
    "decruastes": "decruar",
    "decruava": "decruar",
    "decruavam": "decruar",
    "decruavas": "decruar",
    "decrue": "decruar",
    "decruei": "decruar",
    "decrueis": "decruar",
    "decruem": "decruar",
    "decruemo": "decruar",
    "decruemos": "decruar",
    "decrues": "decruar",
    "decruo": "decruar",
    "decruou": "decruar",
    "decruá": "decruar",
    "decruámo": "decruar",
    "decruámos": "decruar",
    "decruáramo": "decruar",
    "decruáramos": "decruar",
    "decruárei": "decruar",
    "decruáreis": "decruar",
    "decruásseis": "decruar",
    "decruássemos": "decruar",
    "decruávamo": "decruar",
    "decruávamos": "decruar",
    "decruávei": "decruar",
    "decruáveis": "decruar",
    "decrépita": "decrépito",
    "decrépitas": "decrépito",
    "decrépitos": "decrépito",
    "decréscimos": "decréscimo",
    "decubitária": "decubitário",
    "decubitárias": "decubitário",
    "decubitários": "decubitário",
    "decumana": "decumano",
    "decumanas": "decumano",
    "decumanos": "decumano",
    "decumbentes": "decumbente",
    "decupla": "decuplo",
    "decuplada": "decuplar",
    "decupladas": "decuplar",
    "decuplado": "decuplar",
    "decuplados": "decuplar",
    "decuplai": "decuplar",
    "decuplais": "decuplar",
    "decuplam": "decuplar",
    "decuplamo": "decuplar",
    "decuplamos": "decuplar",
    "decuplando": "decuplar",
    "decuplara": "decuplar",
    "decuplaram": "decuplar",
    "decuplaras": "decuplar",
    "decuplarde": "decuplar",
    "decuplardes": "decuplar",
    "decuplare": "decuplar",
    "decuplarei": "decuplar",
    "decuplareis": "decuplar",
    "decuplarem": "decuplar",
    "decuplaremos": "decuplar",
    "decuplares": "decuplar",
    "decuplaria": "decuplar",
    "decuplariam": "decuplar",
    "decuplarias": "decuplar",
    "decuplarmo": "decuplar",
    "decuplarmos": "decuplar",
    "decuplará": "decuplar",
    "decuplarás": "decuplar",
    "decuplarão": "decuplar",
    "decuplaríamos": "decuplar",
    "decuplaríeis": "decuplar",
    "decuplas": "decuplo",
    "decuplasse": "decuplar",
    "decuplassem": "decuplar",
    "decuplasses": "decuplar",
    "decuplaste": "decuplar",
    "decuplastes": "decuplar",
    "decuplava": "decuplar",
    "decuplavam": "decuplar",
    "decuplavas": "decuplar",
    "decuple": "decuplar",
    "decuplei": "decuplar",
    "decupleis": "decuplar",
    "decuplem": "decuplar",
    "decuplemo": "decuplar",
    "decuplemos": "decuplar",
    "decuples": "decuplar",
    "decuplica": "decuplicar",
    "decuplicada": "decuplicar",
    "decuplicadas": "decuplicar",
    "decuplicado": "decuplicar",
    "decuplicados": "decuplicar",
    "decuplicai": "decuplicar",
    "decuplicais": "decuplicar",
    "decuplicam": "decuplicar",
    "decuplicamo": "decuplicar",
    "decuplicamos": "decuplicar",
    "decuplicando": "decuplicar",
    "decuplicara": "decuplicar",
    "decuplicaram": "decuplicar",
    "decuplicaras": "decuplicar",
    "decuplicarde": "decuplicar",
    "decuplicardes": "decuplicar",
    "decuplicare": "decuplicar",
    "decuplicarei": "decuplicar",
    "decuplicareis": "decuplicar",
    "decuplicarem": "decuplicar",
    "decuplicaremos": "decuplicar",
    "decuplicares": "decuplicar",
    "decuplicaria": "decuplicar",
    "decuplicariam": "decuplicar",
    "decuplicarias": "decuplicar",
    "decuplicarmo": "decuplicar",
    "decuplicarmos": "decuplicar",
    "decuplicará": "decuplicar",
    "decuplicarás": "decuplicar",
    "decuplicarão": "decuplicar",
    "decuplicaríamos": "decuplicar",
    "decuplicaríeis": "decuplicar",
    "decuplicas": "decuplicar",
    "decuplicasse": "decuplicar",
    "decuplicassem": "decuplicar",
    "decuplicasses": "decuplicar",
    "decuplicaste": "decuplicar",
    "decuplicastes": "decuplicar",
    "decuplicava": "decuplicar",
    "decuplicavam": "decuplicar",
    "decuplicavas": "decuplicar",
    "decuplico": "decuplicar",
    "decuplicou": "decuplicar",
    "decuplicá": "decuplicar",
    "decuplicámo": "decuplicar",
    "decuplicámos": "decuplicar",
    "decuplicáramo": "decuplicar",
    "decuplicáramos": "decuplicar",
    "decuplicárei": "decuplicar",
    "decuplicáreis": "decuplicar",
    "decuplicásseis": "decuplicar",
    "decuplicássemos": "decuplicar",
    "decuplicávamo": "decuplicar",
    "decuplicávamos": "decuplicar",
    "decuplicávei": "decuplicar",
    "decuplicáveis": "decuplicar",
    "decuplique": "decuplicar",
    "decupliquei": "decuplicar",
    "decupliqueis": "decuplicar",
    "decupliquem": "decuplicar",
    "decupliquemo": "decuplicar",
    "decupliquemos": "decuplicar",
    "decupliques": "decuplicar",
    "decuplo": "decuplar",
    "decuplos": "decuplo",
    "decuplou": "decuplar",
    "decuplá": "decuplar",
    "decuplámo": "decuplar",
    "decuplámos": "decuplar",
    "decupláramo": "decuplar",
    "decupláramos": "decuplar",
    "decuplárei": "decuplar",
    "decupláreis": "decuplar",
    "decuplásseis": "decuplar",
    "decuplássemos": "decuplar",
    "decuplávamo": "decuplar",
    "decuplávamos": "decuplar",
    "decuplávei": "decuplar",
    "decupláveis": "decuplar",
    "decuriados": "decuriado",
    "decuriatos": "decuriato",
    "decurioa": "decurião",
    "decurioas": "decurião",
    "decuriões": "decurião",
    "decursiva": "decursivo",
    "decursivas": "decursivo",
    "decursivos": "decursivo",
    "decursos": "decurso",
    "decussa": "decussar",
    "decussada": "decussar",
    "decussadas": "decussar",
    "decussado": "decussar",
    "decussados": "decussar",
    "decussai": "decussar",
    "decussais": "decussar",
    "decussam": "decussar",
    "decussamo": "decussar",
    "decussamos": "decussar",
    "decussando": "decussar",
    "decussara": "decussar",
    "decussaram": "decussar",
    "decussaras": "decussar",
    "decussarde": "decussar",
    "decussardes": "decussar",
    "decussare": "decussar",
    "decussarei": "decussar",
    "decussareis": "decussar",
    "decussarem": "decussar",
    "decussaremos": "decussar",
    "decussares": "decussar",
    "decussaria": "decussar",
    "decussariam": "decussar",
    "decussarias": "decussar",
    "decussarmo": "decussar",
    "decussarmos": "decussar",
    "decussará": "decussar",
    "decussarás": "decussar",
    "decussarão": "decussar",
    "decussaríamos": "decussar",
    "decussaríeis": "decussar",
    "decussas": "decussar",
    "decussasse": "decussar",
    "decussassem": "decussar",
    "decussasses": "decussar",
    "decussaste": "decussar",
    "decussastes": "decussar",
    "decussava": "decussar",
    "decussavam": "decussar",
    "decussavas": "decussar",
    "decusse": "decussar",
    "decussei": "decussar",
    "decusseis": "decussar",
    "decussem": "decussar",
    "decussemo": "decussar",
    "decussemos": "decussar",
    "decusses": "decussar",
    "decusso": "decussar",
    "decussou": "decussar",
    "decussá": "decussar",
    "decussámo": "decussar",
    "decussámos": "decussar",
    "decussáramo": "decussar",
    "decussáramos": "decussar",
    "decussárei": "decussar",
    "decussáreis": "decussar",
    "decussásseis": "decussar",
    "decussássemos": "decussar",
    "decussávamo": "decussar",
    "decussávamos": "decussar",
    "decussávei": "decussar",
    "decussáveis": "decussar",
    "decágonos": "decágono",
    "decálogos": "decálogo",
    "decápodes": "decápode",
    "decâmetros": "decâmetro",
    "decânica": "decânico",
    "decânicas": "decânico",
    "decânicos": "decânico",
    "decénios": "decénio",
    "decêmpedas": "decêmpeda",
    "decências": "decência",
    "decêndios": "decêndio",
    "decênviros": "decênviro",
    "decíduas": "decídua",
    "decímetros": "decímetro",
    "decúbitos": "decúbito",
    "decúrias": "decúria",
    "dedadas": "dedada",
    "dedais": "dedal",
    "dedaleiras": "dedaleira",
    "dedecora": "dedecorar",
    "dedecorada": "dedecorar",
    "dedecoradas": "dedecorar",
    "dedecorado": "dedecorar",
    "dedecorados": "dedecorar",
    "dedecorai": "dedecorar",
    "dedecorais": "dedecorar",
    "dedecoram": "dedecorar",
    "dedecoramo": "dedecorar",
    "dedecoramos": "dedecorar",
    "dedecorando": "dedecorar",
    "dedecorara": "dedecorar",
    "dedecoraram": "dedecorar",
    "dedecoraras": "dedecorar",
    "dedecorarde": "dedecorar",
    "dedecorardes": "dedecorar",
    "dedecorare": "dedecorar",
    "dedecorarei": "dedecorar",
    "dedecorareis": "dedecorar",
    "dedecorarem": "dedecorar",
    "dedecoraremos": "dedecorar",
    "dedecorares": "dedecorar",
    "dedecoraria": "dedecorar",
    "dedecorariam": "dedecorar",
    "dedecorarias": "dedecorar",
    "dedecorarmo": "dedecorar",
    "dedecorarmos": "dedecorar",
    "dedecorará": "dedecorar",
    "dedecorarás": "dedecorar",
    "dedecorarão": "dedecorar",
    "dedecoraríamos": "dedecorar",
    "dedecoraríeis": "dedecorar",
    "dedecoras": "dedecorar",
    "dedecorasse": "dedecorar",
    "dedecorassem": "dedecorar",
    "dedecorasses": "dedecorar",
    "dedecoraste": "dedecorar",
    "dedecorastes": "dedecorar",
    "dedecorava": "dedecorar",
    "dedecoravam": "dedecorar",
    "dedecoravas": "dedecorar",
    "dedecore": "dedecorar",
    "dedecorei": "dedecorar",
    "dedecoreis": "dedecorar",
    "dedecorem": "dedecorar",
    "dedecoremo": "dedecorar",
    "dedecoremos": "dedecorar",
    "dedecores": "dedecorar",
    "dedecoro": "dedecorar",
    "dedecorou": "dedecorar",
    "dedecorá": "dedecorar",
    "dedecorámo": "dedecorar",
    "dedecorámos": "dedecorar",
    "dedecoráramo": "dedecorar",
    "dedecoráramos": "dedecorar",
    "dedecorárei": "dedecorar",
    "dedecoráreis": "dedecorar",
    "dedecorásseis": "dedecorar",
    "dedecorássemos": "dedecorar",
    "dedecorávamo": "dedecorar",
    "dedecorávamos": "dedecorar",
    "dedecorávei": "dedecorar",
    "dedecoráveis": "dedecorar",
    "dedeiras": "dedeira",
    "dedica": "dedicar",
    "dedicada": "dedicar",
    "dedicadas": "dedicar",
    "dedicado": "dedicar",
    "dedicadora": "dedicador",
    "dedicadoras": "dedicador",
    "dedicadores": "dedicador",
    "dedicados": "dedicar",
    "dedicadíssima": "dedicado",
    "dedicadíssimas": "dedicado",
    "dedicadíssimo": "dedicado",
    "dedicadíssimos": "dedicado",
    "dedicai": "dedicar",
    "dedicais": "dedicar",
    "dedicam": "dedicar",
    "dedicamo": "dedicar",
    "dedicamos": "dedicar",
    "dedicando": "dedicar",
    "dedicara": "dedicar",
    "dedicaram": "dedicar",
    "dedicaras": "dedicar",
    "dedicarde": "dedicar",
    "dedicardes": "dedicar",
    "dedicare": "dedicar",
    "dedicarei": "dedicar",
    "dedicareis": "dedicar",
    "dedicarem": "dedicar",
    "dedicaremos": "dedicar",
    "dedicares": "dedicar",
    "dedicaria": "dedicar",
    "dedicariam": "dedicar",
    "dedicarias": "dedicar",
    "dedicarmo": "dedicar",
    "dedicarmos": "dedicar",
    "dedicará": "dedicar",
    "dedicarás": "dedicar",
    "dedicarão": "dedicar",
    "dedicaríamos": "dedicar",
    "dedicaríeis": "dedicar",
    "dedicas": "dedicar",
    "dedicasse": "dedicar",
    "dedicassem": "dedicar",
    "dedicasses": "dedicar",
    "dedicaste": "dedicar",
    "dedicastes": "dedicar",
    "dedicatórias": "dedicatória",
    "dedicava": "dedicar",
    "dedicavam": "dedicar",
    "dedicavas": "dedicar",
    "dedicações": "dedicação",
    "dedico": "dedicar",
    "dedicou": "dedicar",
    "dedicá": "dedicar",
    "dedicámo": "dedicar",
    "dedicámos": "dedicar",
    "dedicáramo": "dedicar",
    "dedicáramos": "dedicar",
    "dedicárei": "dedicar",
    "dedicáreis": "dedicar",
    "dedicásseis": "dedicar",
    "dedicássemos": "dedicar",
    "dedicávamo": "dedicar",
    "dedicávamos": "dedicar",
    "dedicávei": "dedicar",
    "dedicáveis": "dedicável",
    "dedigna": "dedignar",
    "dedignada": "dedignar",
    "dedignadas": "dedignar",
    "dedignado": "dedignar",
    "dedignados": "dedignar",
    "dedignai": "dedignar",
    "dedignais": "dedignar",
    "dedignam": "dedignar",
    "dedignamo": "dedignar",
    "dedignamos": "dedignar",
    "dedignando": "dedignar",
    "dedignara": "dedignar",
    "dedignaram": "dedignar",
    "dedignaras": "dedignar",
    "dedignarde": "dedignar",
    "dedignardes": "dedignar",
    "dedignare": "dedignar",
    "dedignarei": "dedignar",
    "dedignareis": "dedignar",
    "dedignarem": "dedignar",
    "dedignaremos": "dedignar",
    "dedignares": "dedignar",
    "dedignaria": "dedignar",
    "dedignariam": "dedignar",
    "dedignarias": "dedignar",
    "dedignarmo": "dedignar",
    "dedignarmos": "dedignar",
    "dedignará": "dedignar",
    "dedignarás": "dedignar",
    "dedignarão": "dedignar",
    "dedignaríamos": "dedignar",
    "dedignaríeis": "dedignar",
    "dedignas": "dedignar",
    "dedignasse": "dedignar",
    "dedignassem": "dedignar",
    "dedignasses": "dedignar",
    "dedignaste": "dedignar",
    "dedignastes": "dedignar",
    "dedignava": "dedignar",
    "dedignavam": "dedignar",
    "dedignavas": "dedignar",
    "dedignações": "dedignação",
    "dedigne": "dedignar",
    "dedignei": "dedignar",
    "dedigneis": "dedignar",
    "dedignem": "dedignar",
    "dedignemo": "dedignar",
    "dedignemos": "dedignar",
    "dedignes": "dedignar",
    "dedigno": "dedignar",
    "dedignou": "dedignar",
    "dedigná": "dedignar",
    "dedignámo": "dedignar",
    "dedignámos": "dedignar",
    "dedignáramo": "dedignar",
    "dedignáramos": "dedignar",
    "dedignárei": "dedignar",
    "dedignáreis": "dedignar",
    "dedignásseis": "dedignar",
    "dedignássemos": "dedignar",
    "dedignávamo": "dedignar",
    "dedignávamos": "dedignar",
    "dedignávei": "dedignar",
    "dedignáveis": "dedignar",
    "dedilha": "dedilhar",
    "dedilhada": "dedilhar",
    "dedilhadas": "dedilhar",
    "dedilhado": "dedilhar",
    "dedilhados": "dedilhar",
    "dedilhai": "dedilhar",
    "dedilhais": "dedilhar",
    "dedilham": "dedilhar",
    "dedilhamentos": "dedilhamento",
    "dedilhamo": "dedilhar",
    "dedilhamos": "dedilhar",
    "dedilhando": "dedilhar",
    "dedilhara": "dedilhar",
    "dedilharam": "dedilhar",
    "dedilharas": "dedilhar",
    "dedilharde": "dedilhar",
    "dedilhardes": "dedilhar",
    "dedilhare": "dedilhar",
    "dedilharei": "dedilhar",
    "dedilhareis": "dedilhar",
    "dedilharem": "dedilhar",
    "dedilharemos": "dedilhar",
    "dedilhares": "dedilhar",
    "dedilharia": "dedilhar",
    "dedilhariam": "dedilhar",
    "dedilharias": "dedilhar",
    "dedilharmo": "dedilhar",
    "dedilharmos": "dedilhar",
    "dedilhará": "dedilhar",
    "dedilharás": "dedilhar",
    "dedilharão": "dedilhar",
    "dedilharíamos": "dedilhar",
    "dedilharíeis": "dedilhar",
    "dedilhas": "dedilhar",
    "dedilhasse": "dedilhar",
    "dedilhassem": "dedilhar",
    "dedilhasses": "dedilhar",
    "dedilhaste": "dedilhar",
    "dedilhastes": "dedilhar",
    "dedilhava": "dedilhar",
    "dedilhavam": "dedilhar",
    "dedilhavas": "dedilhar",
    "dedilhações": "dedilhação",
    "dedilhe": "dedilhar",
    "dedilhei": "dedilhar",
    "dedilheis": "dedilhar",
    "dedilhem": "dedilhar",
    "dedilhemo": "dedilhar",
    "dedilhemos": "dedilhar",
    "dedilhes": "dedilhar",
    "dedilho": "dedilhar",
    "dedilhou": "dedilhar",
    "dedilhá": "dedilhar",
    "dedilhámo": "dedilhar",
    "dedilhámos": "dedilhar",
    "dedilháramo": "dedilhar",
    "dedilháramos": "dedilhar",
    "dedilhárei": "dedilhar",
    "dedilháreis": "dedilhar",
    "dedilhásseis": "dedilhar",
    "dedilhássemos": "dedilhar",
    "dedilhávamo": "dedilhar",
    "dedilhávamos": "dedilhar",
    "dedilhávei": "dedilhar",
    "dedilháveis": "dedilhar",
    "dedinho": "dedo",
    "dedinhos": "dedo",
    "dedique": "dedicar",
    "dediquei": "dedicar",
    "dediqueis": "dedicar",
    "dediquem": "dedicar",
    "dediquemo": "dedicar",
    "dediquemos": "dedicar",
    "dediques": "dedicar",
    "dedito": "dedo",
    "deditos": "dedo",
    "dedos": "dedo",
    "deducentes": "deducente",
    "deducionais": "deducional",
    "dedutiva": "dedutivo",
    "dedutivas": "dedutivo",
    "dedutivos": "dedutivo",
    "dedutíveis": "dedutível",
    "deduz": "deduzir",
    "deduza": "deduzir",
    "deduzais": "deduzir",
    "deduzam": "deduzir",
    "deduzamo": "deduzir",
    "deduzamos": "deduzir",
    "deduzas": "deduzir",
    "deduze": "deduzir",
    "deduzem": "deduzir",
    "deduzes": "deduzir",
    "deduzi": "deduzir",
    "deduzia": "deduzir",
    "deduziam": "deduzir",
    "deduzias": "deduzir",
    "deduzida": "deduzir",
    "deduzidas": "deduzir",
    "deduzido": "deduzir",
    "deduzidos": "deduzir",
    "deduzimo": "deduzir",
    "deduzimos": "deduzir",
    "deduzindo": "deduzir",
    "deduzira": "deduzir",
    "deduziram": "deduzir",
    "deduziras": "deduzir",
    "deduzirde": "deduzir",
    "deduzirdes": "deduzir",
    "deduzire": "deduzir",
    "deduzirei": "deduzir",
    "deduzireis": "deduzir",
    "deduzirem": "deduzir",
    "deduziremos": "deduzir",
    "deduzires": "deduzir",
    "deduziria": "deduzir",
    "deduziriam": "deduzir",
    "deduzirias": "deduzir",
    "deduzirmo": "deduzir",
    "deduzirmos": "deduzir",
    "deduzirá": "deduzir",
    "deduzirás": "deduzir",
    "deduzirão": "deduzir",
    "deduziríamos": "deduzir",
    "deduziríeis": "deduzir",
    "deduzis": "deduzir",
    "deduzisse": "deduzir",
    "deduzissem": "deduzir",
    "deduzisses": "deduzir",
    "deduziste": "deduzir",
    "deduzistes": "deduzir",
    "deduziu": "deduzir",
    "deduzo": "deduzir",
    "deduzíamo": "deduzir",
    "deduzíamos": "deduzir",
    "deduzíei": "deduzir",
    "deduzíeis": "deduzir",
    "deduzíramo": "deduzir",
    "deduzíramos": "deduzir",
    "deduzírei": "deduzir",
    "deduzíreis": "deduzir",
    "deduzísseis": "deduzir",
    "deduzíssemos": "deduzir",
    "deduzíveis": "deduzível",
    "deduções": "dedução",
    "dedálea": "dedáleo",
    "dedáleas": "dedáleo",
    "dedáleos": "dedáleo",
    "dedálica": "dedálico",
    "dedálicas": "dedálico",
    "dedálicos": "dedálico",
    "defeca": "defecar",
    "defecada": "defecar",
    "defecadas": "defecar",
    "defecado": "defecar",
    "defecadores": "defecador",
    "defecados": "defecar",
    "defecais": "defecar",
    "defecam": "defecar",
    "defecamo": "defecar",
    "defecamos": "defecar",
    "defecando": "defecar",
    "defecara": "defecar",
    "defecaram": "defecar",
    "defecaras": "defecar",
    "defecardes": "defecar",
    "defecarei": "defecar",
    "defecareis": "defecar",
    "defecarem": "defecar",
    "defecaremos": "defecar",
    "defecares": "defecar",
    "defecaria": "defecar",
    "defecariam": "defecar",
    "defecarias": "defecar",
    "defecarmo": "defecar",
    "defecarmos": "defecar",
    "defecará": "defecar",
    "defecarás": "defecar",
    "defecarão": "defecar",
    "defecaríamos": "defecar",
    "defecaríeis": "defecar",
    "defecas": "defecar",
    "defecasse": "defecar",
    "defecassem": "defecar",
    "defecasses": "defecar",
    "defecaste": "defecar",
    "defecastes": "defecar",
    "defecatória": "defecatório",
    "defecatórias": "defecatório",
    "defecatórios": "defecatório",
    "defecava": "defecar",
    "defecavam": "defecar",
    "defecavas": "defecar",
    "defecações": "defecação",
    "defeco": "defecar",
    "defecou": "defecar",
    "defectibilidades": "defectibilidade",
    "defectiva": "defectivo",
    "defectivas": "defectivo",
    "defectividades": "defectividade",
    "defectivos": "defectivo",
    "defectíveis": "defectível",
    "defecámo": "defecar",
    "defecámos": "defecar",
    "defecáramo": "defecar",
    "defecáramos": "defecar",
    "defecáreis": "defecar",
    "defecásseis": "defecar",
    "defecássemos": "defecar",
    "defecávamo": "defecar",
    "defecávamos": "defecar",
    "defecáveis": "defecar",
    "defecções": "defecção",
    "defeitos": "defeito",
    "defeituosa": "defeituoso",
    "defeituosas": "defeituoso",
    "defeituosos": "defeituoso",
    "defenda": "defender",
    "defendais": "defender",
    "defendam": "defender",
    "defendamo": "defender",
    "defendamos": "defender",
    "defendas": "defender",
    "defende": "defender",
    "defendei": "defender",
    "defendeis": "defender",
    "defendem": "defender",
    "defendemo": "defender",
    "defendemos": "defender",
    "defendendo": "defender",
    "defendera": "defender",
    "defenderam": "defender",
    "defenderas": "defender",
    "defenderde": "defender",
    "defenderdes": "defender",
    "defendere": "defender",
    "defenderei": "defender",
    "defendereis": "defender",
    "defenderem": "defender",
    "defenderemos": "defender",
    "defenderes": "defender",
    "defenderia": "defender",
    "defenderiam": "defender",
    "defenderias": "defender",
    "defendermo": "defender",
    "defendermos": "defender",
    "defenderá": "defender",
    "defenderás": "defender",
    "defenderão": "defender",
    "defenderíamos": "defender",
    "defenderíeis": "defender",
    "defendes": "defender",
    "defendesse": "defender",
    "defendessem": "defender",
    "defendesses": "defender",
    "defendeste": "defender",
    "defendestes": "defender",
    "defendeu": "defender",
    "defendi": "defender",
    "defendia": "defender",
    "defendiam": "defender",
    "defendias": "defender",
    "defendida": "defendido",
    "defendidas": "defendido",
    "defendido": "defender",
    "defendidos": "defendido",
    "defendimentos": "defendimento",
    "defendo": "defender",
    "defendê": "defender",
    "defendêramo": "defender",
    "defendêramos": "defender",
    "defendêrei": "defender",
    "defendêreis": "defender",
    "defendêsseis": "defender",
    "defendêssemos": "defender",
    "defendíamo": "defender",
    "defendíamos": "defender",
    "defendíei": "defender",
    "defendíeis": "defender",
    "defendíveis": "defendível",
    "defenestra": "defenestrar",
    "defenestrada": "defenestrar",
    "defenestradas": "defenestrar",
    "defenestrado": "defenestrar",
    "defenestrados": "defenestrar",
    "defenestrai": "defenestrar",
    "defenestrais": "defenestrar",
    "defenestram": "defenestrar",
    "defenestramo": "defenestrar",
    "defenestramos": "defenestrar",
    "defenestrando": "defenestrar",
    "defenestrara": "defenestrar",
    "defenestraram": "defenestrar",
    "defenestraras": "defenestrar",
    "defenestrarde": "defenestrar",
    "defenestrardes": "defenestrar",
    "defenestrare": "defenestrar",
    "defenestrarei": "defenestrar",
    "defenestrareis": "defenestrar",
    "defenestrarem": "defenestrar",
    "defenestraremos": "defenestrar",
    "defenestrares": "defenestrar",
    "defenestraria": "defenestrar",
    "defenestrariam": "defenestrar",
    "defenestrarias": "defenestrar",
    "defenestrarmo": "defenestrar",
    "defenestrarmos": "defenestrar",
    "defenestrará": "defenestrar",
    "defenestrarás": "defenestrar",
    "defenestrarão": "defenestrar",
    "defenestraríamos": "defenestrar",
    "defenestraríeis": "defenestrar",
    "defenestras": "defenestrar",
    "defenestrasse": "defenestrar",
    "defenestrassem": "defenestrar",
    "defenestrasses": "defenestrar",
    "defenestraste": "defenestrar",
    "defenestrastes": "defenestrar",
    "defenestrava": "defenestrar",
    "defenestravam": "defenestrar",
    "defenestravas": "defenestrar",
    "defenestrações": "defenestração",
    "defenestre": "defenestrar",
    "defenestrei": "defenestrar",
    "defenestreis": "defenestrar",
    "defenestrem": "defenestrar",
    "defenestremo": "defenestrar",
    "defenestremos": "defenestrar",
    "defenestres": "defenestrar",
    "defenestro": "defenestrar",
    "defenestrou": "defenestrar",
    "defenestrá": "defenestrar",
    "defenestrámo": "defenestrar",
    "defenestrámos": "defenestrar",
    "defenestráramo": "defenestrar",
    "defenestráramos": "defenestrar",
    "defenestrárei": "defenestrar",
    "defenestráreis": "defenestrar",
    "defenestrásseis": "defenestrar",
    "defenestrássemos": "defenestrar",
    "defenestrávamo": "defenestrar",
    "defenestrávamos": "defenestrar",
    "defenestrávei": "defenestrar",
    "defenestráveis": "defenestrar",
    "defensa": "defensar",
    "defensada": "defensar",
    "defensadas": "defensar",
    "defensado": "defensar",
    "defensados": "defensar",
    "defensai": "defensar",
    "defensais": "defensar",
    "defensam": "defensar",
    "defensamo": "defensar",
    "defensamos": "defensar",
    "defensando": "defensar",
    "defensara": "defensar",
    "defensaram": "defensar",
    "defensaras": "defensar",
    "defensarde": "defensar",
    "defensardes": "defensar",
    "defensare": "defensar",
    "defensarei": "defensar",
    "defensareis": "defensar",
    "defensarem": "defensar",
    "defensaremos": "defensar",
    "defensares": "defensar",
    "defensaria": "defensar",
    "defensariam": "defensar",
    "defensarias": "defensar",
    "defensarmo": "defensar",
    "defensarmos": "defensar",
    "defensará": "defensar",
    "defensarás": "defensar",
    "defensarão": "defensar",
    "defensaríamos": "defensar",
    "defensaríeis": "defensar",
    "defensas": "defensar",
    "defensasse": "defensar",
    "defensassem": "defensar",
    "defensasses": "defensar",
    "defensaste": "defensar",
    "defensastes": "defensar",
    "defensava": "defensar",
    "defensavam": "defensar",
    "defensavas": "defensar",
    "defense": "defensar",
    "defensei": "defensar",
    "defenseis": "defensar",
    "defensem": "defensar",
    "defensemo": "defensar",
    "defensemos": "defensar",
    "defenses": "defensar",
    "defensiva": "defensivo",
    "defensivas": "defensivo",
    "defensivos": "defensivo",
    "defenso": "defensar",
    "defensora": "defensor",
    "defensoras": "defensor",
    "defensores": "defensor",
    "defensou": "defensar",
    "defensá": "defensar",
    "defensámo": "defensar",
    "defensámos": "defensar",
    "defensáramo": "defensar",
    "defensáramos": "defensar",
    "defensárei": "defensar",
    "defensáreis": "defensar",
    "defensásseis": "defensar",
    "defensássemos": "defensar",
    "defensávamo": "defensar",
    "defensávamos": "defensar",
    "defensávei": "defensar",
    "defensáveis": "defensável",
    "defensíveis": "defensível",
    "defensória": "defensório",
    "defensórias": "defensório",
    "defensórios": "defensório",
    "defensões": "defensão",
    "defeque": "defecar",
    "defequei": "defecar",
    "defequeis": "defecar",
    "defequem": "defecar",
    "defequemos": "defecar",
    "defeques": "defecar",
    "defera": "deferir",
    "deferais": "deferir",
    "deferam": "deferir",
    "deferamo": "deferir",
    "deferamos": "deferir",
    "deferas": "deferir",
    "defere": "deferir",
    "deferem": "deferir",
    "deferenciais": "deferencial",
    "deferentes": "deferente",
    "deferes": "deferir",
    "deferi": "deferir",
    "deferia": "deferir",
    "deferiam": "deferir",
    "deferias": "deferir",
    "deferida": "deferir",
    "deferidas": "deferir",
    "deferido": "deferir",
    "deferidos": "deferir",
    "deferimentos": "deferimento",
    "deferimo": "deferir",
    "deferimos": "deferir",
    "deferindo": "deferir",
    "deferira": "deferir",
    "deferiram": "deferir",
    "deferiras": "deferir",
    "deferirde": "deferir",
    "deferirdes": "deferir",
    "deferire": "deferir",
    "deferirei": "deferir",
    "deferireis": "deferir",
    "deferirem": "deferir",
    "deferiremos": "deferir",
    "deferires": "deferir",
    "deferiria": "deferir",
    "defeririam": "deferir",
    "deferirias": "deferir",
    "deferirmo": "deferir",
    "deferirmos": "deferir",
    "deferirá": "deferir",
    "deferirás": "deferir",
    "deferirão": "deferir",
    "deferiríamos": "deferir",
    "deferiríeis": "deferir",
    "deferis": "deferir",
    "deferisse": "deferir",
    "deferissem": "deferir",
    "deferisses": "deferir",
    "deferiste": "deferir",
    "deferistes": "deferir",
    "deferiu": "deferir",
    "defero": "deferir",
    "defervescentes": "defervescente",
    "defervescências": "defervescência",
    "deferências": "deferência",
    "deferíamo": "deferir",
    "deferíamos": "deferir",
    "deferíei": "deferir",
    "deferíeis": "deferir",
    "deferíramo": "deferir",
    "deferíramos": "deferir",
    "deferírei": "deferir",
    "deferíreis": "deferir",
    "deferísseis": "deferir",
    "deferíssemos": "deferir",
    "deferíveis": "deferível",
    "defesa": "defeso",
    "defesas": "defeso",
    "defesos": "defeso",
    "defessa": "defesso",
    "defessas": "defesso",
    "defessos": "defesso",
    "deficienciazinha": "deficiência",
    "deficienciazinhas": "deficiência",
    "deficienciazita": "deficiência",
    "deficienciazitas": "deficiência",
    "deficientes": "deficiente",
    "deficitária": "deficitário",
    "deficitárias": "deficitário",
    "deficitários": "deficitário",
    "deficiências": "deficiência",
    "defina": "definir",
    "definais": "definir",
    "definam": "definir",
    "definamo": "definir",
    "definamos": "definir",
    "definas": "definir",
    "define": "definir",
    "definem": "definir",
    "defines": "definir",
    "definha": "definhar",
    "definhada": "definhar",
    "definhadas": "definhar",
    "definhado": "definhar",
    "definhados": "definhar",
    "definhai": "definhar",
    "definhais": "definhar",
    "definham": "definhar",
    "definhamentos": "definhamento",
    "definhamo": "definhar",
    "definhamos": "definhar",
    "definhando": "definhar",
    "definhara": "definhar",
    "definharam": "definhar",
    "definharas": "definhar",
    "definhardes": "definhar",
    "definharei": "definhar",
    "definhareis": "definhar",
    "definharem": "definhar",
    "definharemos": "definhar",
    "definhares": "definhar",
    "definharia": "definhar",
    "definhariam": "definhar",
    "definharias": "definhar",
    "definharmo": "definhar",
    "definharmos": "definhar",
    "definhará": "definhar",
    "definharás": "definhar",
    "definharão": "definhar",
    "definharíamos": "definhar",
    "definharíeis": "definhar",
    "definhas": "definhar",
    "definhasse": "definhar",
    "definhassem": "definhar",
    "definhasses": "definhar",
    "definhaste": "definhar",
    "definhastes": "definhar",
    "definhava": "definhar",
    "definhavam": "definhar",
    "definhavas": "definhar",
    "definhe": "definhar",
    "definhei": "definhar",
    "definheis": "definhar",
    "definhem": "definhar",
    "definhemo": "definhar",
    "definhemos": "definhar",
    "definhes": "definhar",
    "definho": "definhar",
    "definhou": "definhar",
    "definhámo": "definhar",
    "definhámos": "definhar",
    "definháramo": "definhar",
    "definháramos": "definhar",
    "definháreis": "definhar",
    "definhásseis": "definhar",
    "definhássemos": "definhar",
    "definhávamo": "definhar",
    "definhávamos": "definhar",
    "definháveis": "definhar",
    "defini": "definir",
    "definia": "definir",
    "definiam": "definir",
    "definias": "definir",
    "definibilidades": "definibilidade",
    "definida": "definir",
    "definidas": "definir",
    "definido": "definir",
    "definidora": "definidor",
    "definidoras": "definidor",
    "definidores": "definidor",
    "definidos": "definir",
    "definimo": "definir",
    "definimos": "definir",
    "definindo": "definir",
    "definira": "definir",
    "definiram": "definir",
    "definiras": "definir",
    "definirde": "definir",
    "definirdes": "definir",
    "definire": "definir",
    "definirei": "definir",
    "definireis": "definir",
    "definirem": "definir",
    "definiremos": "definir",
    "definires": "definir",
    "definiria": "definir",
    "definiriam": "definir",
    "definirias": "definir",
    "definirmo": "definir",
    "definirmos": "definir",
    "definirá": "definir",
    "definirás": "definir",
    "definirão": "definir",
    "definiríamos": "definir",
    "definiríeis": "definir",
    "definis": "definir",
    "definisse": "definir",
    "definissem": "definir",
    "definisses": "definir",
    "definiste": "definir",
    "definistes": "definir",
    "definitiva": "definitivo",
    "definitivas": "definitivo",
    "definitivos": "definitivo",
    "definitórios": "definitório",
    "definiu": "definir",
    "definições": "definição",
    "defino": "definir",
    "definíamo": "definir",
    "definíamos": "definir",
    "definíei": "definir",
    "definíeis": "definir",
    "definíramo": "definir",
    "definíramos": "definir",
    "definírei": "definir",
    "definíreis": "definir",
    "definísseis": "definir",
    "definíssemos": "definir",
    "definíveis": "definível",
    "deflacciona": "deflaccionar",
    "deflaccionada": "deflaccionar",
    "deflaccionadas": "deflaccionar",
    "deflaccionado": "deflaccionar",
    "deflaccionados": "deflaccionar",
    "deflaccionai": "deflaccionar",
    "deflaccionais": "deflaccionar",
    "deflaccionam": "deflaccionar",
    "deflaccionamo": "deflaccionar",
    "deflaccionamos": "deflaccionar",
    "deflaccionando": "deflaccionar",
    "deflaccionara": "deflaccionar",
    "deflaccionaram": "deflaccionar",
    "deflaccionaras": "deflaccionar",
    "deflaccionarde": "deflaccionar",
    "deflaccionardes": "deflaccionar",
    "deflaccionare": "deflaccionar",
    "deflaccionarei": "deflaccionar",
    "deflaccionareis": "deflaccionar",
    "deflaccionarem": "deflaccionar",
    "deflaccionaremos": "deflaccionar",
    "deflaccionares": "deflaccionar",
    "deflaccionaria": "deflaccionar",
    "deflaccionariam": "deflaccionar",
    "deflaccionarias": "deflaccionar",
    "deflaccionarmo": "deflaccionar",
    "deflaccionarmos": "deflaccionar",
    "deflaccionará": "deflaccionar",
    "deflaccionarás": "deflaccionar",
    "deflaccionarão": "deflaccionar",
    "deflaccionaríamos": "deflaccionar",
    "deflaccionaríeis": "deflaccionar",
    "deflaccionas": "deflaccionar",
    "deflaccionasse": "deflaccionar",
    "deflaccionassem": "deflaccionar",
    "deflaccionasses": "deflaccionar",
    "deflaccionaste": "deflaccionar",
    "deflaccionastes": "deflaccionar",
    "deflaccionava": "deflaccionar",
    "deflaccionavam": "deflaccionar",
    "deflaccionavas": "deflaccionar",
    "deflaccione": "deflaccionar",
    "deflaccionei": "deflaccionar",
    "deflaccioneis": "deflaccionar",
    "deflaccionem": "deflaccionar",
    "deflaccionemo": "deflaccionar",
    "deflaccionemos": "deflaccionar",
    "deflacciones": "deflaccionar",
    "deflacciono": "deflaccionar",
    "deflaccionou": "deflaccionar",
    "deflaccioná": "deflaccionar",
    "deflaccionámo": "deflaccionar",
    "deflaccionámos": "deflaccionar",
    "deflaccionáramo": "deflaccionar",
    "deflaccionáramos": "deflaccionar",
    "deflaccionárei": "deflaccionar",
    "deflaccionáreis": "deflaccionar",
    "deflaccionásseis": "deflaccionar",
    "deflaccionássemos": "deflaccionar",
    "deflaccionávamo": "deflaccionar",
    "deflaccionávamos": "deflaccionar",
    "deflaccionávei": "deflaccionar",
    "deflaccionáveis": "deflaccionar",
    "deflacionismos": "deflacionismo",
    "deflacionistas": "deflacionista",
    "deflagra": "deflagrar",
    "deflagrada": "deflagrar",
    "deflagradas": "deflagrar",
    "deflagrado": "deflagrar",
    "deflagrados": "deflagrar",
    "deflagrai": "deflagrar",
    "deflagrais": "deflagrar",
    "deflagram": "deflagrar",
    "deflagramo": "deflagrar",
    "deflagramos": "deflagrar",
    "deflagrando": "deflagrar",
    "deflagrantes": "deflagrante",
    "deflagrara": "deflagrar",
    "deflagraram": "deflagrar",
    "deflagraras": "deflagrar",
    "deflagrardes": "deflagrar",
    "deflagrarei": "deflagrar",
    "deflagrareis": "deflagrar",
    "deflagrarem": "deflagrar",
    "deflagraremos": "deflagrar",
    "deflagrares": "deflagrar",
    "deflagraria": "deflagrar",
    "deflagrariam": "deflagrar",
    "deflagrarias": "deflagrar",
    "deflagrarmo": "deflagrar",
    "deflagrarmos": "deflagrar",
    "deflagrará": "deflagrar",
    "deflagrarás": "deflagrar",
    "deflagrarão": "deflagrar",
    "deflagraríamos": "deflagrar",
    "deflagraríeis": "deflagrar",
    "deflagras": "deflagrar",
    "deflagrasse": "deflagrar",
    "deflagrassem": "deflagrar",
    "deflagrasses": "deflagrar",
    "deflagraste": "deflagrar",
    "deflagrastes": "deflagrar",
    "deflagrava": "deflagrar",
    "deflagravam": "deflagrar",
    "deflagravas": "deflagrar",
    "deflagrações": "deflagração",
    "deflagre": "deflagrar",
    "deflagrei": "deflagrar",
    "deflagreis": "deflagrar",
    "deflagrem": "deflagrar",
    "deflagremo": "deflagrar",
    "deflagremos": "deflagrar",
    "deflagres": "deflagrar",
    "deflagro": "deflagrar",
    "deflagrou": "deflagrar",
    "deflagrámo": "deflagrar",
    "deflagrámos": "deflagrar",
    "deflagráramo": "deflagrar",
    "deflagráramos": "deflagrar",
    "deflagráreis": "deflagrar",
    "deflagrásseis": "deflagrar",
    "deflagrássemos": "deflagrar",
    "deflagrávamo": "deflagrar",
    "deflagrávamos": "deflagrar",
    "deflagráveis": "deflagrar",
    "deflações": "deflação",
    "deflecte": "deflectir",
    "deflectem": "deflectir",
    "deflectes": "deflectir",
    "deflecti": "deflectir",
    "deflectia": "deflectir",
    "deflectiam": "deflectir",
    "deflectias": "deflectir",
    "deflectida": "deflectir",
    "deflectidas": "deflectir",
    "deflectido": "deflectir",
    "deflectidos": "deflectir",
    "deflectimo": "deflectir",
    "deflectimos": "deflectir",
    "deflectindo": "deflectir",
    "deflectira": "deflectir",
    "deflectiram": "deflectir",
    "deflectiras": "deflectir",
    "deflectirde": "deflectir",
    "deflectirdes": "deflectir",
    "deflectire": "deflectir",
    "deflectirei": "deflectir",
    "deflectireis": "deflectir",
    "deflectirem": "deflectir",
    "deflectiremos": "deflectir",
    "deflectires": "deflectir",
    "deflectiria": "deflectir",
    "deflectiriam": "deflectir",
    "deflectirias": "deflectir",
    "deflectirmo": "deflectir",
    "deflectirmos": "deflectir",
    "deflectirá": "deflectir",
    "deflectirás": "deflectir",
    "deflectirão": "deflectir",
    "deflectiríamos": "deflectir",
    "deflectiríeis": "deflectir",
    "deflectis": "deflectir",
    "deflectisse": "deflectir",
    "deflectissem": "deflectir",
    "deflectisses": "deflectir",
    "deflectiste": "deflectir",
    "deflectistes": "deflectir",
    "deflectiu": "deflectir",
    "deflectores": "deflector",
    "deflectíamo": "deflectir",
    "deflectíamos": "deflectir",
    "deflectíei": "deflectir",
    "deflectíeis": "deflectir",
    "deflectíramo": "deflectir",
    "deflectíramos": "deflectir",
    "deflectírei": "deflectir",
    "deflectíreis": "deflectir",
    "deflectísseis": "deflectir",
    "deflectíssemos": "deflectir",
    "deflegma": "deflegmar",
    "deflegmada": "deflegmar",
    "deflegmadas": "deflegmar",
    "deflegmado": "deflegmar",
    "deflegmadores": "deflegmador",
    "deflegmados": "deflegmar",
    "deflegmai": "deflegmar",
    "deflegmais": "deflegmar",
    "deflegmam": "deflegmar",
    "deflegmamo": "deflegmar",
    "deflegmamos": "deflegmar",
    "deflegmando": "deflegmar",
    "deflegmara": "deflegmar",
    "deflegmaram": "deflegmar",
    "deflegmaras": "deflegmar",
    "deflegmarde": "deflegmar",
    "deflegmardes": "deflegmar",
    "deflegmare": "deflegmar",
    "deflegmarei": "deflegmar",
    "deflegmareis": "deflegmar",
    "deflegmarem": "deflegmar",
    "deflegmaremos": "deflegmar",
    "deflegmares": "deflegmar",
    "deflegmaria": "deflegmar",
    "deflegmariam": "deflegmar",
    "deflegmarias": "deflegmar",
    "deflegmarmo": "deflegmar",
    "deflegmarmos": "deflegmar",
    "deflegmará": "deflegmar",
    "deflegmarás": "deflegmar",
    "deflegmarão": "deflegmar",
    "deflegmaríamos": "deflegmar",
    "deflegmaríeis": "deflegmar",
    "deflegmas": "deflegmar",
    "deflegmasse": "deflegmar",
    "deflegmassem": "deflegmar",
    "deflegmasses": "deflegmar",
    "deflegmaste": "deflegmar",
    "deflegmastes": "deflegmar",
    "deflegmava": "deflegmar",
    "deflegmavam": "deflegmar",
    "deflegmavas": "deflegmar",
    "deflegmações": "deflegmação",
    "deflegme": "deflegmar",
    "deflegmei": "deflegmar",
    "deflegmeis": "deflegmar",
    "deflegmem": "deflegmar",
    "deflegmemo": "deflegmar",
    "deflegmemos": "deflegmar",
    "deflegmes": "deflegmar",
    "deflegmo": "deflegmar",
    "deflegmou": "deflegmar",
    "deflegmá": "deflegmar",
    "deflegmámo": "deflegmar",
    "deflegmámos": "deflegmar",
    "deflegmáramo": "deflegmar",
    "deflegmáramos": "deflegmar",
    "deflegmárei": "deflegmar",
    "deflegmáreis": "deflegmar",
    "deflegmásseis": "deflegmar",
    "deflegmássemos": "deflegmar",
    "deflegmávamo": "deflegmar",
    "deflegmávamos": "deflegmar",
    "deflegmávei": "deflegmar",
    "deflegmáveis": "deflegmar",
    "deflexões": "deflexão",
    "deflicta": "deflectir",
    "deflictais": "deflectir",
    "deflictam": "deflectir",
    "deflictamo": "deflectir",
    "deflictamos": "deflectir",
    "deflictas": "deflectir",
    "deflicto": "deflectir",
    "deflora": "deflorar",
    "deflorada": "deflorar",
    "defloradas": "deflorar",
    "deflorado": "deflorar",
    "defloradores": "deflorador",
    "deflorados": "deflorar",
    "deflorai": "deflorar",
    "deflorais": "deflorar",
    "defloram": "deflorar",
    "defloramentos": "defloramento",
    "defloramo": "deflorar",
    "defloramos": "deflorar",
    "deflorando": "deflorar",
    "deflorara": "deflorar",
    "defloraram": "deflorar",
    "defloraras": "deflorar",
    "deflorarde": "deflorar",
    "deflorardes": "deflorar",
    "deflorare": "deflorar",
    "deflorarei": "deflorar",
    "deflorareis": "deflorar",
    "deflorarem": "deflorar",
    "defloraremos": "deflorar",
    "deflorares": "deflorar",
    "defloraria": "deflorar",
    "deflorariam": "deflorar",
    "deflorarias": "deflorar",
    "deflorarmo": "deflorar",
    "deflorarmos": "deflorar",
    "deflorará": "deflorar",
    "deflorarás": "deflorar",
    "deflorarão": "deflorar",
    "defloraríamos": "deflorar",
    "defloraríeis": "deflorar",
    "defloras": "deflorar",
    "deflorasse": "deflorar",
    "deflorassem": "deflorar",
    "deflorasses": "deflorar",
    "defloraste": "deflorar",
    "deflorastes": "deflorar",
    "deflorava": "deflorar",
    "defloravam": "deflorar",
    "defloravas": "deflorar",
    "deflorações": "defloração",
    "deflore": "deflorar",
    "deflorei": "deflorar",
    "defloreis": "deflorar",
    "deflorem": "deflorar",
    "defloremo": "deflorar",
    "defloremos": "deflorar",
    "deflores": "deflorar",
    "defloro": "deflorar",
    "deflorou": "deflorar",
    "deflorá": "deflorar",
    "deflorámo": "deflorar",
    "deflorámos": "deflorar",
    "defloráramo": "deflorar",
    "defloráramos": "deflorar",
    "deflorárei": "deflorar",
    "defloráreis": "deflorar",
    "deflorásseis": "deflorar",
    "deflorássemos": "deflorar",
    "deflorávamo": "deflorar",
    "deflorávamos": "deflorar",
    "deflorávei": "deflorar",
    "defloráveis": "deflorar",
    "deflua": "defluir",
    "defluais": "defluir",
    "defluam": "defluir",
    "defluamo": "defluir",
    "defluamos": "defluir",
    "defluas": "defluir",
    "defluem": "defluir",
    "deflui": "defluir",
    "defluindo": "defluir",
    "defluirdes": "defluir",
    "defluirei": "defluir",
    "defluireis": "defluir",
    "defluiremos": "defluir",
    "defluiria": "defluir",
    "defluiriam": "defluir",
    "defluirias": "defluir",
    "defluirmo": "defluir",
    "defluirmos": "defluir",
    "defluirá": "defluir",
    "defluirás": "defluir",
    "defluirão": "defluir",
    "defluiríamos": "defluir",
    "defluiríeis": "defluir",
    "defluis": "defluir",
    "defluiu": "defluir",
    "defluo": "defluir",
    "defluxeiras": "defluxeira",
    "defluxos": "defluxo",
    "defluxões": "defluxão",
    "defluências": "defluência",
    "defluí": "defluir",
    "defluía": "defluir",
    "defluíam": "defluir",
    "defluíamo": "defluir",
    "defluíamos": "defluir",
    "defluías": "defluir",
    "defluída": "defluir",
    "defluídas": "defluir",
    "defluído": "defluir",
    "defluídos": "defluir",
    "defluíeis": "defluir",
    "defluímo": "defluir",
    "defluímos": "defluir",
    "defluíra": "defluir",
    "defluíram": "defluir",
    "defluíramo": "defluir",
    "defluíramos": "defluir",
    "defluíras": "defluir",
    "defluíreis": "defluir",
    "defluírem": "defluir",
    "defluíres": "defluir",
    "defluís": "defluir",
    "defluísse": "defluir",
    "defluísseis": "defluir",
    "defluíssem": "defluir",
    "defluíssemos": "defluir",
    "defluísses": "defluir",
    "defluíste": "defluir",
    "defluístes": "defluir",
    "deflúvios": "deflúvio",
    "deforma": "deformar",
    "deformada": "deformar",
    "deformadas": "deformar",
    "deformado": "deformar",
    "deformadora": "deformador",
    "deformadoras": "deformador",
    "deformadores": "deformador",
    "deformados": "deformar",
    "deformai": "deformar",
    "deformais": "deformar",
    "deformam": "deformar",
    "deformamo": "deformar",
    "deformamos": "deformar",
    "deformando": "deformar",
    "deformara": "deformar",
    "deformaram": "deformar",
    "deformaras": "deformar",
    "deformarde": "deformar",
    "deformardes": "deformar",
    "deformare": "deformar",
    "deformarei": "deformar",
    "deformareis": "deformar",
    "deformarem": "deformar",
    "deformaremos": "deformar",
    "deformares": "deformar",
    "deformaria": "deformar",
    "deformariam": "deformar",
    "deformarias": "deformar",
    "deformarmo": "deformar",
    "deformarmos": "deformar",
    "deformará": "deformar",
    "deformarás": "deformar",
    "deformarão": "deformar",
    "deformaríamos": "deformar",
    "deformaríeis": "deformar",
    "deformas": "deformar",
    "deformasse": "deformar",
    "deformassem": "deformar",
    "deformasses": "deformar",
    "deformaste": "deformar",
    "deformastes": "deformar",
    "deformatória": "deformatório",
    "deformatórias": "deformatório",
    "deformatórios": "deformatório",
    "deformava": "deformar",
    "deformavam": "deformar",
    "deformavas": "deformar",
    "deformações": "deformação",
    "deforme": "deformar",
    "deformei": "deformar",
    "deformeis": "deformar",
    "deformem": "deformar",
    "deformemo": "deformar",
    "deformemos": "deformar",
    "deformes": "deforme",
    "deformidades": "deformidade",
    "deformo": "deformar",
    "deformou": "deformar",
    "deformá": "deformar",
    "deformámo": "deformar",
    "deformámos": "deformar",
    "deformáramo": "deformar",
    "deformáramos": "deformar",
    "deformárei": "deformar",
    "deformáreis": "deformar",
    "deformásseis": "deformar",
    "deformássemos": "deformar",
    "deformávamo": "deformar",
    "deformávamos": "deformar",
    "deformávei": "deformar",
    "deformáveis": "deformável",
    "defrauda": "defraudar",
    "defraudada": "defraudar",
    "defraudadas": "defraudar",
    "defraudado": "defraudar",
    "defraudadora": "defraudador",
    "defraudadoras": "defraudador",
    "defraudadores": "defraudador",
    "defraudados": "defraudar",
    "defraudai": "defraudar",
    "defraudais": "defraudar",
    "defraudam": "defraudar",
    "defraudamentos": "defraudamento",
    "defraudamo": "defraudar",
    "defraudamos": "defraudar",
    "defraudando": "defraudar",
    "defraudara": "defraudar",
    "defraudaram": "defraudar",
    "defraudaras": "defraudar",
    "defraudarde": "defraudar",
    "defraudardes": "defraudar",
    "defraudare": "defraudar",
    "defraudarei": "defraudar",
    "defraudareis": "defraudar",
    "defraudarem": "defraudar",
    "defraudaremos": "defraudar",
    "defraudares": "defraudar",
    "defraudaria": "defraudar",
    "defraudariam": "defraudar",
    "defraudarias": "defraudar",
    "defraudarmo": "defraudar",
    "defraudarmos": "defraudar",
    "defraudará": "defraudar",
    "defraudarás": "defraudar",
    "defraudarão": "defraudar",
    "defraudaríamos": "defraudar",
    "defraudaríeis": "defraudar",
    "defraudas": "defraudar",
    "defraudasse": "defraudar",
    "defraudassem": "defraudar",
    "defraudasses": "defraudar",
    "defraudaste": "defraudar",
    "defraudastes": "defraudar",
    "defraudava": "defraudar",
    "defraudavam": "defraudar",
    "defraudavas": "defraudar",
    "defraudações": "defraudação",
    "defraude": "defraudar",
    "defraudei": "defraudar",
    "defraudeis": "defraudar",
    "defraudem": "defraudar",
    "defraudemo": "defraudar",
    "defraudemos": "defraudar",
    "defraudes": "defraudar",
    "defraudo": "defraudar",
    "defraudou": "defraudar",
    "defraudá": "defraudar",
    "defraudámo": "defraudar",
    "defraudámos": "defraudar",
    "defraudáramo": "defraudar",
    "defraudáramos": "defraudar",
    "defraudárei": "defraudar",
    "defraudáreis": "defraudar",
    "defraudásseis": "defraudar",
    "defraudássemos": "defraudar",
    "defraudávamo": "defraudar",
    "defraudávamos": "defraudar",
    "defraudávei": "defraudar",
    "defraudáveis": "defraudável",
    "defronta": "defrontar",
    "defrontada": "defrontar",
    "defrontadas": "defrontar",
    "defrontado": "defrontar",
    "defrontados": "defrontar",
    "defrontai": "defrontar",
    "defrontais": "defrontar",
    "defrontam": "defrontar",
    "defrontamo": "defrontar",
    "defrontamos": "defrontar",
    "defrontando": "defrontar",
    "defrontantes": "defrontante",
    "defrontara": "defrontar",
    "defrontaram": "defrontar",
    "defrontaras": "defrontar",
    "defrontarde": "defrontar",
    "defrontardes": "defrontar",
    "defrontare": "defrontar",
    "defrontarei": "defrontar",
    "defrontareis": "defrontar",
    "defrontarem": "defrontar",
    "defrontaremos": "defrontar",
    "defrontares": "defrontar",
    "defrontaria": "defrontar",
    "defrontariam": "defrontar",
    "defrontarias": "defrontar",
    "defrontarmo": "defrontar",
    "defrontarmos": "defrontar",
    "defrontará": "defrontar",
    "defrontarás": "defrontar",
    "defrontarão": "defrontar",
    "defrontaríamos": "defrontar",
    "defrontaríeis": "defrontar",
    "defrontas": "defrontar",
    "defrontasse": "defrontar",
    "defrontassem": "defrontar",
    "defrontasses": "defrontar",
    "defrontaste": "defrontar",
    "defrontastes": "defrontar",
    "defrontava": "defrontar",
    "defrontavam": "defrontar",
    "defrontavas": "defrontar",
    "defrontações": "defrontação",
    "defronte": "defrontar",
    "defrontei": "defrontar",
    "defronteis": "defrontar",
    "defrontem": "defrontar",
    "defrontemo": "defrontar",
    "defrontemos": "defrontar",
    "defrontes": "defrontar",
    "defronto": "defrontar",
    "defrontou": "defrontar",
    "defrontá": "defrontar",
    "defrontámo": "defrontar",
    "defrontámos": "defrontar",
    "defrontáramo": "defrontar",
    "defrontáramos": "defrontar",
    "defrontárei": "defrontar",
    "defrontáreis": "defrontar",
    "defrontásseis": "defrontar",
    "defrontássemos": "defrontar",
    "defrontávamo": "defrontar",
    "defrontávamos": "defrontar",
    "defrontávei": "defrontar",
    "defrontáveis": "defrontar",
    "defuma": "defumar",
    "defumada": "defumar",
    "defumadas": "defumar",
    "defumadelas": "defumadela",
    "defumado": "defumar",
    "defumadoiros": "defumadoiro",
    "defumadora": "defumador",
    "defumadoras": "defumador",
    "defumadores": "defumador",
    "defumados": "defumar",
    "defumadouros": "defumadouro",
    "defumaduras": "defumadura",
    "defumai": "defumar",
    "defumais": "defumar",
    "defumam": "defumar",
    "defumamo": "defumar",
    "defumamos": "defumar",
    "defumando": "defumar",
    "defumara": "defumar",
    "defumaram": "defumar",
    "defumaras": "defumar",
    "defumarde": "defumar",
    "defumardes": "defumar",
    "defumare": "defumar",
    "defumarei": "defumar",
    "defumareis": "defumar",
    "defumarem": "defumar",
    "defumaremos": "defumar",
    "defumares": "defumar",
    "defumaria": "defumar",
    "defumariam": "defumar",
    "defumarias": "defumar",
    "defumarmo": "defumar",
    "defumarmos": "defumar",
    "defumará": "defumar",
    "defumarás": "defumar",
    "defumarão": "defumar",
    "defumaríamos": "defumar",
    "defumaríeis": "defumar",
    "defumas": "defumar",
    "defumasse": "defumar",
    "defumassem": "defumar",
    "defumasses": "defumar",
    "defumaste": "defumar",
    "defumastes": "defumar",
    "defumava": "defumar",
    "defumavam": "defumar",
    "defumavas": "defumar",
    "defumações": "defumação",
    "defume": "defumar",
    "defumei": "defumar",
    "defumeis": "defumar",
    "defumem": "defumar",
    "defumemo": "defumar",
    "defumemos": "defumar",
    "defumes": "defumar",
    "defumo": "defumar",
    "defumou": "defumar",
    "defumá": "defumar",
    "defumámo": "defumar",
    "defumámos": "defumar",
    "defumáramo": "defumar",
    "defumáramos": "defumar",
    "defumárei": "defumar",
    "defumáreis": "defumar",
    "defumásseis": "defumar",
    "defumássemos": "defumar",
    "defumávamo": "defumar",
    "defumávamos": "defumar",
    "defumávei": "defumar",
    "defumáveis": "defumar",
    "defunta": "defunto",
    "defuntas": "defunto",
    "defunteira": "defunteiro",
    "defunteiras": "defunteiro",
    "defunteiros": "defunteiro",
    "defuntos": "defunto",
    "defunções": "defunção",
    "degasta": "degastar",
    "degastada": "degastar",
    "degastadas": "degastar",
    "degastado": "degastar",
    "degastadora": "degastador",
    "degastadoras": "degastador",
    "degastadores": "degastador",
    "degastados": "degastar",
    "degastai": "degastar",
    "degastais": "degastar",
    "degastam": "degastar",
    "degastamo": "degastar",
    "degastamos": "degastar",
    "degastando": "degastar",
    "degastara": "degastar",
    "degastaram": "degastar",
    "degastaras": "degastar",
    "degastarde": "degastar",
    "degastardes": "degastar",
    "degastare": "degastar",
    "degastarei": "degastar",
    "degastareis": "degastar",
    "degastarem": "degastar",
    "degastaremos": "degastar",
    "degastares": "degastar",
    "degastaria": "degastar",
    "degastariam": "degastar",
    "degastarias": "degastar",
    "degastarmo": "degastar",
    "degastarmos": "degastar",
    "degastará": "degastar",
    "degastarás": "degastar",
    "degastarão": "degastar",
    "degastaríamos": "degastar",
    "degastaríeis": "degastar",
    "degastas": "degastar",
    "degastasse": "degastar",
    "degastassem": "degastar",
    "degastasses": "degastar",
    "degastaste": "degastar",
    "degastastes": "degastar",
    "degastava": "degastar",
    "degastavam": "degastar",
    "degastavas": "degastar",
    "degaste": "degastar",
    "degastei": "degastar",
    "degasteis": "degastar",
    "degastem": "degastar",
    "degastemo": "degastar",
    "degastemos": "degastar",
    "degastes": "degastar",
    "degasto": "degastar",
    "degastou": "degastar",
    "degastá": "degastar",
    "degastámo": "degastar",
    "degastámos": "degastar",
    "degastáramo": "degastar",
    "degastáramos": "degastar",
    "degastárei": "degastar",
    "degastáreis": "degastar",
    "degastásseis": "degastar",
    "degastássemos": "degastar",
    "degastávamo": "degastar",
    "degastávamos": "degastar",
    "degastávei": "degastar",
    "degastáveis": "degastar",
    "degela": "degelar",
    "degelada": "degelar",
    "degeladas": "degelar",
    "degelado": "degelar",
    "degeladora": "degelador",
    "degeladoras": "degelador",
    "degeladores": "degelador",
    "degelados": "degelar",
    "degelai": "degelar",
    "degelais": "degelar",
    "degelam": "degelar",
    "degelamo": "degelar",
    "degelamos": "degelar",
    "degelando": "degelar",
    "degelara": "degelar",
    "degelaram": "degelar",
    "degelaras": "degelar",
    "degelardes": "degelar",
    "degelarei": "degelar",
    "degelareis": "degelar",
    "degelarem": "degelar",
    "degelaremos": "degelar",
    "degelares": "degelar",
    "degelaria": "degelar",
    "degelariam": "degelar",
    "degelarias": "degelar",
    "degelarmo": "degelar",
    "degelarmos": "degelar",
    "degelará": "degelar",
    "degelarás": "degelar",
    "degelarão": "degelar",
    "degelaríamos": "degelar",
    "degelaríeis": "degelar",
    "degelas": "degelar",
    "degelasse": "degelar",
    "degelassem": "degelar",
    "degelasses": "degelar",
    "degelaste": "degelar",
    "degelastes": "degelar",
    "degelava": "degelar",
    "degelavam": "degelar",
    "degelavas": "degelar",
    "degele": "degelar",
    "degelei": "degelar",
    "degeleis": "degelar",
    "degelem": "degelar",
    "degelemo": "degelar",
    "degelemos": "degelar",
    "degeles": "degelar",
    "degelo": "degelar",
    "degelos": "degelo",
    "degelou": "degelar",
    "degelámo": "degelar",
    "degelámos": "degelar",
    "degeláramo": "degelar",
    "degeláramos": "degelar",
    "degeláreis": "degelar",
    "degelásseis": "degelar",
    "degelássemos": "degelar",
    "degelávamo": "degelar",
    "degelávamos": "degelar",
    "degeláveis": "degelar",
    "degenera": "degenerar",
    "degenerada": "degenerar",
    "degeneradas": "degenerar",
    "degenerado": "degenerar",
    "degenerados": "degenerar",
    "degeneradíssima": "degenerado",
    "degeneradíssimas": "degenerado",
    "degeneradíssimo": "degenerado",
    "degeneradíssimos": "degenerado",
    "degenerai": "degenerar",
    "degenerais": "degenerar",
    "degeneram": "degenerar",
    "degeneramo": "degenerar",
    "degeneramos": "degenerar",
    "degenerando": "degenerar",
    "degenerara": "degenerar",
    "degeneraram": "degenerar",
    "degeneraras": "degenerar",
    "degenerardes": "degenerar",
    "degenerarei": "degenerar",
    "degenerareis": "degenerar",
    "degenerarem": "degenerar",
    "degeneraremos": "degenerar",
    "degenerares": "degenerar",
    "degeneraria": "degenerar",
    "degenerariam": "degenerar",
    "degenerarias": "degenerar",
    "degenerarmo": "degenerar",
    "degenerarmos": "degenerar",
    "degenerará": "degenerar",
    "degenerarás": "degenerar",
    "degenerarão": "degenerar",
    "degeneraríamos": "degenerar",
    "degeneraríeis": "degenerar",
    "degeneras": "degenerar",
    "degenerasse": "degenerar",
    "degenerassem": "degenerar",
    "degenerasses": "degenerar",
    "degeneraste": "degenerar",
    "degenerastes": "degenerar",
    "degenerativa": "degenerativo",
    "degenerativas": "degenerativo",
    "degenerativos": "degenerativo",
    "degenerava": "degenerar",
    "degeneravam": "degenerar",
    "degeneravas": "degenerar",
    "degenerações": "degeneração",
    "degenere": "degenerar",
    "degenerei": "degenerar",
    "degenereis": "degenerar",
    "degenerem": "degenerar",
    "degeneremo": "degenerar",
    "degeneremos": "degenerar",
    "degeneres": "degenerar",
    "degenerescentes": "degenerescente",
    "degenerescências": "degenerescência",
    "degenero": "degenerar",
    "degenerou": "degenerar",
    "degenerámo": "degenerar",
    "degenerámos": "degenerar",
    "degeneráramo": "degenerar",
    "degeneráramos": "degenerar",
    "degeneráreis": "degenerar",
    "degenerásseis": "degenerar",
    "degenerássemos": "degenerar",
    "degenerávamo": "degenerar",
    "degenerávamos": "degenerar",
    "degeneráveis": "degenerar",
    "deglabrações": "deglabração",
    "degladia": "degladiar",
    "degladiada": "degladiar",
    "degladiadas": "degladiar",
    "degladiado": "degladiar",
    "degladiados": "degladiar",
    "degladiai": "degladiar",
    "degladiais": "degladiar",
    "degladiam": "degladiar",
    "degladiamo": "degladiar",
    "degladiamos": "degladiar",
    "degladiando": "degladiar",
    "degladiara": "degladiar",
    "degladiaram": "degladiar",
    "degladiaras": "degladiar",
    "degladiarde": "degladiar",
    "degladiardes": "degladiar",
    "degladiare": "degladiar",
    "degladiarei": "degladiar",
    "degladiareis": "degladiar",
    "degladiarem": "degladiar",
    "degladiaremos": "degladiar",
    "degladiares": "degladiar",
    "degladiaria": "degladiar",
    "degladiariam": "degladiar",
    "degladiarias": "degladiar",
    "degladiarmo": "degladiar",
    "degladiarmos": "degladiar",
    "degladiará": "degladiar",
    "degladiarás": "degladiar",
    "degladiarão": "degladiar",
    "degladiaríamos": "degladiar",
    "degladiaríeis": "degladiar",
    "degladias": "degladiar",
    "degladiasse": "degladiar",
    "degladiassem": "degladiar",
    "degladiasses": "degladiar",
    "degladiaste": "degladiar",
    "degladiastes": "degladiar",
    "degladiava": "degladiar",
    "degladiavam": "degladiar",
    "degladiavas": "degladiar",
    "degladie": "degladiar",
    "degladiei": "degladiar",
    "degladieis": "degladiar",
    "degladiem": "degladiar",
    "degladiemo": "degladiar",
    "degladiemos": "degladiar",
    "degladies": "degladiar",
    "degladio": "degladiar",
    "degladiou": "degladiar",
    "degladiá": "degladiar",
    "degladiámo": "degladiar",
    "degladiámos": "degladiar",
    "degladiáramo": "degladiar",
    "degladiáramos": "degladiar",
    "degladiárei": "degladiar",
    "degladiáreis": "degladiar",
    "degladiásseis": "degladiar",
    "degladiássemos": "degladiar",
    "degladiávamo": "degladiar",
    "degladiávamos": "degladiar",
    "degladiávei": "degladiar",
    "degladiáveis": "degladiar",
    "deglobulizações": "deglobulização",
    "degluta": "deglutir",
    "deglutais": "deglutir",
    "deglutam": "deglutir",
    "deglutamo": "deglutir",
    "deglutamos": "deglutir",
    "deglutas": "deglutir",
    "deglute": "deglutir",
    "deglutem": "deglutir",
    "deglutes": "deglutir",
    "degluti": "deglutir",
    "deglutia": "deglutir",
    "deglutiam": "deglutir",
    "deglutias": "deglutir",
    "deglutida": "deglutir",
    "deglutidas": "deglutir",
    "deglutido": "deglutir",
    "deglutidos": "deglutir",
    "deglutimo": "deglutir",
    "deglutimos": "deglutir",
    "deglutinações": "deglutinação",
    "deglutindo": "deglutir",
    "deglutira": "deglutir",
    "deglutiram": "deglutir",
    "deglutiras": "deglutir",
    "deglutirde": "deglutir",
    "deglutirdes": "deglutir",
    "deglutire": "deglutir",
    "deglutirei": "deglutir",
    "deglutireis": "deglutir",
    "deglutirem": "deglutir",
    "deglutiremos": "deglutir",
    "deglutires": "deglutir",
    "deglutiria": "deglutir",
    "deglutiriam": "deglutir",
    "deglutirias": "deglutir",
    "deglutirmo": "deglutir",
    "deglutirmos": "deglutir",
    "deglutirá": "deglutir",
    "deglutirás": "deglutir",
    "deglutirão": "deglutir",
    "deglutiríamos": "deglutir",
    "deglutiríeis": "deglutir",
    "deglutis": "deglutir",
    "deglutisse": "deglutir",
    "deglutissem": "deglutir",
    "deglutisses": "deglutir",
    "deglutiste": "deglutir",
    "deglutistes": "deglutir",
    "deglutiu": "deglutir",
    "deglutições": "deglutição",
    "degluto": "deglutir",
    "deglutíamo": "deglutir",
    "deglutíamos": "deglutir",
    "deglutíei": "deglutir",
    "deglutíeis": "deglutir",
    "deglutíramo": "deglutir",
    "deglutíramos": "deglutir",
    "deglutírei": "deglutir",
    "deglutíreis": "deglutir",
    "deglutísseis": "deglutir",
    "deglutíssemos": "deglutir",
    "degola": "degolar",
    "degolada": "degolar",
    "degoladas": "degolar",
    "degolado": "degolar",
    "degoladoiros": "degoladoiro",
    "degoladora": "degolador",
    "degoladoras": "degolador",
    "degoladores": "degolador",
    "degolados": "degolar",
    "degoladouros": "degoladouro",
    "degoladuras": "degoladura",
    "degolai": "degolar",
    "degolais": "degolar",
    "degolam": "degolar",
    "degolamo": "degolar",
    "degolamos": "degolar",
    "degolando": "degolar",
    "degolara": "degolar",
    "degolaram": "degolar",
    "degolaras": "degolar",
    "degolarde": "degolar",
    "degolardes": "degolar",
    "degolare": "degolar",
    "degolarei": "degolar",
    "degolareis": "degolar",
    "degolarem": "degolar",
    "degolaremos": "degolar",
    "degolares": "degolar",
    "degolaria": "degolar",
    "degolariam": "degolar",
    "degolarias": "degolar",
    "degolarmo": "degolar",
    "degolarmos": "degolar",
    "degolará": "degolar",
    "degolarás": "degolar",
    "degolarão": "degolar",
    "degolaríamos": "degolar",
    "degolaríeis": "degolar",
    "degolas": "degolar",
    "degolasse": "degolar",
    "degolassem": "degolar",
    "degolasses": "degolar",
    "degolaste": "degolar",
    "degolastes": "degolar",
    "degolava": "degolar",
    "degolavam": "degolar",
    "degolavas": "degolar",
    "degolações": "degolação",
    "degole": "degolar",
    "degolei": "degolar",
    "degoleis": "degolar",
    "degolem": "degolar",
    "degolemo": "degolar",
    "degolemos": "degolar",
    "degoles": "degolar",
    "degolo": "degolar",
    "degolos": "degolo",
    "degolou": "degolar",
    "degolá": "degolar",
    "degolámo": "degolar",
    "degolámos": "degolar",
    "degoláramo": "degolar",
    "degoláramos": "degolar",
    "degolárei": "degolar",
    "degoláreis": "degolar",
    "degolásseis": "degolar",
    "degolássemos": "degolar",
    "degolávamo": "degolar",
    "degolávamos": "degolar",
    "degolávei": "degolar",
    "degoláveis": "degolar",
    "degrada": "degradar",
    "degradada": "degradar",
    "degradadas": "degradar",
    "degradado": "degradar",
    "degradadora": "degradador",
    "degradadoras": "degradador",
    "degradadores": "degradador",
    "degradados": "degradar",
    "degradai": "degradar",
    "degradais": "degradar",
    "degradam": "degradar",
    "degradamentos": "degradamento",
    "degradamo": "degradar",
    "degradamos": "degradar",
    "degradando": "degradar",
    "degradantes": "degradante",
    "degradara": "degradar",
    "degradaram": "degradar",
    "degradaras": "degradar",
    "degradarde": "degradar",
    "degradardes": "degradar",
    "degradare": "degradar",
    "degradarei": "degradar",
    "degradareis": "degradar",
    "degradarem": "degradar",
    "degradaremos": "degradar",
    "degradares": "degradar",
    "degradaria": "degradar",
    "degradariam": "degradar",
    "degradarias": "degradar",
    "degradarmo": "degradar",
    "degradarmos": "degradar",
    "degradará": "degradar",
    "degradarás": "degradar",
    "degradarão": "degradar",
    "degradaríamos": "degradar",
    "degradaríeis": "degradar",
    "degradas": "degradar",
    "degradasse": "degradar",
    "degradassem": "degradar",
    "degradasses": "degradar",
    "degradaste": "degradar",
    "degradastes": "degradar",
    "degradava": "degradar",
    "degradavam": "degradar",
    "degradavas": "degradar",
    "degradações": "degradação",
    "degrade": "degradar",
    "degradei": "degradar",
    "degradeis": "degradar",
    "degradem": "degradar",
    "degrademo": "degradar",
    "degrademos": "degradar",
    "degrades": "degradar",
    "degrado": "degradar",
    "degradou": "degradar",
    "degradá": "degradar",
    "degradámo": "degradar",
    "degradámos": "degradar",
    "degradáramo": "degradar",
    "degradáramos": "degradar",
    "degradárei": "degradar",
    "degradáreis": "degradar",
    "degradásseis": "degradar",
    "degradássemos": "degradar",
    "degradávamo": "degradar",
    "degradávamos": "degradar",
    "degradávei": "degradar",
    "degradáveis": "degradável",
    "degrana": "degranar",
    "degranada": "degranar",
    "degranadas": "degranar",
    "degranadeiras": "degranadeira",
    "degranado": "degranar",
    "degranados": "degranar",
    "degranai": "degranar",
    "degranais": "degranar",
    "degranam": "degranar",
    "degranamo": "degranar",
    "degranamos": "degranar",
    "degranando": "degranar",
    "degranara": "degranar",
    "degranaram": "degranar",
    "degranaras": "degranar",
    "degranarde": "degranar",
    "degranardes": "degranar",
    "degranare": "degranar",
    "degranarei": "degranar",
    "degranareis": "degranar",
    "degranarem": "degranar",
    "degranaremos": "degranar",
    "degranares": "degranar",
    "degranaria": "degranar",
    "degranariam": "degranar",
    "degranarias": "degranar",
    "degranarmo": "degranar",
    "degranarmos": "degranar",
    "degranará": "degranar",
    "degranarás": "degranar",
    "degranarão": "degranar",
    "degranaríamos": "degranar",
    "degranaríeis": "degranar",
    "degranas": "degranar",
    "degranasse": "degranar",
    "degranassem": "degranar",
    "degranasses": "degranar",
    "degranaste": "degranar",
    "degranastes": "degranar",
    "degranava": "degranar",
    "degranavam": "degranar",
    "degranavas": "degranar",
    "degrane": "degranar",
    "degranei": "degranar",
    "degraneis": "degranar",
    "degranem": "degranar",
    "degranemo": "degranar",
    "degranemos": "degranar",
    "degranes": "degranar",
    "degrano": "degranar",
    "degranou": "degranar",
    "degraná": "degranar",
    "degranámo": "degranar",
    "degranámos": "degranar",
    "degranáramo": "degranar",
    "degranáramos": "degranar",
    "degranárei": "degranar",
    "degranáreis": "degranar",
    "degranásseis": "degranar",
    "degranássemos": "degranar",
    "degranávamo": "degranar",
    "degranávamos": "degranar",
    "degranávei": "degranar",
    "degranáveis": "degranar",
    "degraus": "degrau",
    "degrauzecos": "degrauzeco",
    "degreda": "degredar",
    "degredada": "degredar",
    "degredadas": "degredar",
    "degredado": "degredar",
    "degredados": "degredar",
    "degredai": "degredar",
    "degredais": "degredar",
    "degredam": "degredar",
    "degredamo": "degredar",
    "degredamos": "degredar",
    "degredando": "degredar",
    "degredara": "degredar",
    "degredaram": "degredar",
    "degredaras": "degredar",
    "degredarde": "degredar",
    "degredardes": "degredar",
    "degredare": "degredar",
    "degredarei": "degredar",
    "degredareis": "degredar",
    "degredarem": "degredar",
    "degredaremos": "degredar",
    "degredares": "degredar",
    "degredaria": "degredar",
    "degredariam": "degredar",
    "degredarias": "degredar",
    "degredarmo": "degredar",
    "degredarmos": "degredar",
    "degredará": "degredar",
    "degredarás": "degredar",
    "degredarão": "degredar",
    "degredaríamos": "degredar",
    "degredaríeis": "degredar",
    "degredas": "degredar",
    "degredasse": "degredar",
    "degredassem": "degredar",
    "degredasses": "degredar",
    "degredaste": "degredar",
    "degredastes": "degredar",
    "degredava": "degredar",
    "degredavam": "degredar",
    "degredavas": "degredar",
    "degrede": "degredar",
    "degredei": "degredar",
    "degredeis": "degredar",
    "degredem": "degredar",
    "degredemo": "degredar",
    "degredemos": "degredar",
    "degredes": "degredar",
    "degredo": "degredar",
    "degredos": "degredo",
    "degredou": "degredar",
    "degredá": "degredar",
    "degredámo": "degredar",
    "degredámos": "degredar",
    "degredáramo": "degredar",
    "degredáramos": "degredar",
    "degredárei": "degredar",
    "degredáreis": "degredar",
    "degredásseis": "degredar",
    "degredássemos": "degredar",
    "degredávamo": "degredar",
    "degredávamos": "degredar",
    "degredávei": "degredar",
    "degredáveis": "degredar",
    "degressiva": "degressivo",
    "degressivas": "degressivo",
    "degressivos": "degressivo",
    "degusta": "degustar",
    "degustada": "degustar",
    "degustadas": "degustar",
    "degustado": "degustar",
    "degustados": "degustar",
    "degustai": "degustar",
    "degustais": "degustar",
    "degustam": "degustar",
    "degustamo": "degustar",
    "degustamos": "degustar",
    "degustando": "degustar",
    "degustara": "degustar",
    "degustaram": "degustar",
    "degustaras": "degustar",
    "degustarde": "degustar",
    "degustardes": "degustar",
    "degustare": "degustar",
    "degustarei": "degustar",
    "degustareis": "degustar",
    "degustarem": "degustar",
    "degustaremos": "degustar",
    "degustares": "degustar",
    "degustaria": "degustar",
    "degustariam": "degustar",
    "degustarias": "degustar",
    "degustarmo": "degustar",
    "degustarmos": "degustar",
    "degustará": "degustar",
    "degustarás": "degustar",
    "degustarão": "degustar",
    "degustaríamos": "degustar",
    "degustaríeis": "degustar",
    "degustas": "degustar",
    "degustasse": "degustar",
    "degustassem": "degustar",
    "degustasses": "degustar",
    "degustaste": "degustar",
    "degustastes": "degustar",
    "degustava": "degustar",
    "degustavam": "degustar",
    "degustavas": "degustar",
    "degustações": "degustação",
    "deguste": "degustar",
    "degustei": "degustar",
    "degusteis": "degustar",
    "degustem": "degustar",
    "degustemo": "degustar",
    "degustemos": "degustar",
    "degustes": "degustar",
    "degusto": "degustar",
    "degustou": "degustar",
    "degustá": "degustar",
    "degustámo": "degustar",
    "degustámos": "degustar",
    "degustáramo": "degustar",
    "degustáramos": "degustar",
    "degustárei": "degustar",
    "degustáreis": "degustar",
    "degustásseis": "degustar",
    "degustássemos": "degustar",
    "degustávamo": "degustar",
    "degustávamos": "degustar",
    "degustávei": "degustar",
    "degustáveis": "degustar",
    "dei": "dar",
    "deias": "deia",
    "deicidas": "deicida",
    "deicídios": "deicídio",
    "deidades": "deidade",
    "deifica": "deificar",
    "deificada": "deificar",
    "deificadas": "deificar",
    "deificado": "deificar",
    "deificadora": "deificador",
    "deificadoras": "deificador",
    "deificadores": "deificador",
    "deificados": "deificar",
    "deificai": "deificar",
    "deificais": "deificar",
    "deificam": "deificar",
    "deificamo": "deificar",
    "deificamos": "deificar",
    "deificando": "deificar",
    "deificara": "deificar",
    "deificaram": "deificar",
    "deificaras": "deificar",
    "deificarde": "deificar",
    "deificardes": "deificar",
    "deificare": "deificar",
    "deificarei": "deificar",
    "deificareis": "deificar",
    "deificarem": "deificar",
    "deificaremos": "deificar",
    "deificares": "deificar",
    "deificaria": "deificar",
    "deificariam": "deificar",
    "deificarias": "deificar",
    "deificarmo": "deificar",
    "deificarmos": "deificar",
    "deificará": "deificar",
    "deificarás": "deificar",
    "deificarão": "deificar",
    "deificaríamos": "deificar",
    "deificaríeis": "deificar",
    "deificas": "deificar",
    "deificasse": "deificar",
    "deificassem": "deificar",
    "deificasses": "deificar",
    "deificaste": "deificar",
    "deificastes": "deificar",
    "deificava": "deificar",
    "deificavam": "deificar",
    "deificavas": "deificar",
    "deificações": "deificação",
    "deifico": "deificar",
    "deificou": "deificar",
    "deificá": "deificar",
    "deificámo": "deificar",
    "deificámos": "deificar",
    "deificáramo": "deificar",
    "deificáramos": "deificar",
    "deificárei": "deificar",
    "deificáreis": "deificar",
    "deificásseis": "deificar",
    "deificássemos": "deificar",
    "deificávamo": "deificar",
    "deificávamos": "deificar",
    "deificávei": "deificar",
    "deificáveis": "deificar",
    "deifique": "deificar",
    "deifiquei": "deificar",
    "deifiqueis": "deificar",
    "deifiquem": "deificar",
    "deifiquemo": "deificar",
    "deifiquemos": "deificar",
    "deifiques": "deificar",
    "deiformes": "deiforme",
    "deinflamada": "deinflamado",
    "deinflamadas": "deinflamado",
    "deinflamados": "deinflamado",
    "deis": "dar",
    "deiscentes": "deiscente",
    "deiscências": "deiscência",
    "deita": "deitar",
    "deitada": "deitar",
    "deitadas": "deitar",
    "deitadinha": "deitado",
    "deitadinhas": "deitado",
    "deitadinho": "deitado",
    "deitadinhos": "deitado",
    "deitadita": "deitado",
    "deitaditas": "deitado",
    "deitadito": "deitado",
    "deitaditos": "deitado",
    "deitado": "deitar",
    "deitados": "deitar",
    "deitai": "deitar",
    "deitais": "deitar",
    "deitam": "deitar",
    "deitamo": "deitar",
    "deitamos": "deitar",
    "deitando": "deitar",
    "deitara": "deitar",
    "deitaram": "deitar",
    "deitaras": "deitar",
    "deitarde": "deitar",
    "deitardes": "deitar",
    "deitare": "deitar",
    "deitarei": "deitar",
    "deitareis": "deitar",
    "deitarem": "deitar",
    "deitaremos": "deitar",
    "deitares": "deitar",
    "deitaria": "deitar",
    "deitariam": "deitar",
    "deitarias": "deitar",
    "deitarmo": "deitar",
    "deitarmos": "deitar",
    "deitará": "deitar",
    "deitarás": "deitar",
    "deitarão": "deitar",
    "deitaríamos": "deitar",
    "deitaríeis": "deitar",
    "deitas": "deitar",
    "deitasse": "deitar",
    "deitassem": "deitar",
    "deitasses": "deitar",
    "deitaste": "deitar",
    "deitastes": "deitar",
    "deitava": "deitar",
    "deitavam": "deitar",
    "deitavas": "deitar",
    "deite": "deitar",
    "deitei": "deitar",
    "deiteis": "deitar",
    "deitem": "deitar",
    "deitemo": "deitar",
    "deitemos": "deitar",
    "deites": "deitar",
    "deito": "deitar",
    "deitou": "deitar",
    "deitá": "deitar",
    "deitámo": "deitar",
    "deitámos": "deitar",
    "deitáramo": "deitar",
    "deitáramos": "deitar",
    "deitárei": "deitar",
    "deitáreis": "deitar",
    "deitásseis": "deitar",
    "deitássemos": "deitar",
    "deitávamo": "deitar",
    "deitávamos": "deitar",
    "deitávei": "deitar",
    "deitáveis": "deitar",
    "deixa": "deixar",
    "deixada": "deixar",
    "deixadas": "deixar",
    "deixado": "deixar",
    "deixados": "deixar",
    "deixai": "deixar",
    "deixais": "deixar",
    "deixam": "deixar",
    "deixamo": "deixar",
    "deixamos": "deixar",
    "deixando": "deixar",
    "deixara": "deixar",
    "deixaram": "deixar",
    "deixaras": "deixar",
    "deixarde": "deixar",
    "deixardes": "deixar",
    "deixare": "deixar",
    "deixarei": "deixar",
    "deixareis": "deixar",
    "deixarem": "deixar",
    "deixaremos": "deixar",
    "deixares": "deixar",
    "deixaria": "deixar",
    "deixariam": "deixar",
    "deixarias": "deixar",
    "deixarmo": "deixar",
    "deixarmos": "deixar",
    "deixará": "deixar",
    "deixarás": "deixar",
    "deixarão": "deixar",
    "deixaríamos": "deixar",
    "deixaríeis": "deixar",
    "deixas": "deixar",
    "deixasse": "deixar",
    "deixassem": "deixar",
    "deixasses": "deixar",
    "deixaste": "deixar",
    "deixastes": "deixar",
    "deixava": "deixar",
    "deixavam": "deixar",
    "deixavas": "deixar",
    "deixações": "deixação",
    "deixe": "deixar",
    "deixei": "deixar",
    "deixeis": "deixar",
    "deixem": "deixar",
    "deixemo": "deixar",
    "deixemos": "deixar",
    "deixes": "deixar",
    "deixo": "deixar",
    "deixou": "deixar",
    "deixá": "deixar",
    "deixámo": "deixar",
    "deixámos": "deixar",
    "deixáramo": "deixar",
    "deixáramos": "deixar",
    "deixárei": "deixar",
    "deixáreis": "deixar",
    "deixásseis": "deixar",
    "deixássemos": "deixar",
    "deixávamo": "deixar",
    "deixávamos": "deixar",
    "deixávei": "deixar",
    "deixáveis": "deixar",
    "dejecta": "dejectar",
    "dejectada": "dejectar",
    "dejectadas": "dejectar",
    "dejectado": "dejectar",
    "dejectados": "dejectar",
    "dejectai": "dejectar",
    "dejectais": "dejectar",
    "dejectam": "dejectar",
    "dejectamo": "dejectar",
    "dejectamos": "dejectar",
    "dejectando": "dejectar",
    "dejectara": "dejectar",
    "dejectaram": "dejectar",
    "dejectaras": "dejectar",
    "dejectarde": "dejectar",
    "dejectardes": "dejectar",
    "dejectare": "dejectar",
    "dejectarei": "dejectar",
    "dejectareis": "dejectar",
    "dejectarem": "dejectar",
    "dejectaremos": "dejectar",
    "dejectares": "dejectar",
    "dejectaria": "dejectar",
    "dejectariam": "dejectar",
    "dejectarias": "dejectar",
    "dejectarmo": "dejectar",
    "dejectarmos": "dejectar",
    "dejectará": "dejectar",
    "dejectarás": "dejectar",
    "dejectarão": "dejectar",
    "dejectaríamos": "dejectar",
    "dejectaríeis": "dejectar",
    "dejectas": "dejectar",
    "dejectasse": "dejectar",
    "dejectassem": "dejectar",
    "dejectasses": "dejectar",
    "dejectaste": "dejectar",
    "dejectastes": "dejectar",
    "dejectava": "dejectar",
    "dejectavam": "dejectar",
    "dejectavas": "dejectar",
    "dejecte": "dejectar",
    "dejectei": "dejectar",
    "dejecteis": "dejectar",
    "dejectem": "dejectar",
    "dejectemo": "dejectar",
    "dejectemos": "dejectar",
    "dejectes": "dejectar",
    "dejecto": "dejectar",
    "dejectos": "dejecto",
    "dejectou": "dejectar",
    "dejectá": "dejectar",
    "dejectámo": "dejectar",
    "dejectámos": "dejectar",
    "dejectáramo": "dejectar",
    "dejectáramos": "dejectar",
    "dejectárei": "dejectar",
    "dejectáreis": "dejectar",
    "dejectásseis": "dejectar",
    "dejectássemos": "dejectar",
    "dejectávamo": "dejectar",
    "dejectávamos": "dejectar",
    "dejectávei": "dejectar",
    "dejectáveis": "dejectar",
    "dejectórios": "dejectório",
    "dejecções": "dejecção",
    "dejejua": "dejejuar",
    "dejejuada": "dejejuar",
    "dejejuadas": "dejejuar",
    "dejejuado": "dejejuar",
    "dejejuadoiros": "dejejuadoiro",
    "dejejuados": "dejejuar",
    "dejejuadouros": "dejejuadouro",
    "dejejuai": "dejejuar",
    "dejejuais": "dejejuar",
    "dejejuam": "dejejuar",
    "dejejuamo": "dejejuar",
    "dejejuamos": "dejejuar",
    "dejejuando": "dejejuar",
    "dejejuara": "dejejuar",
    "dejejuaram": "dejejuar",
    "dejejuaras": "dejejuar",
    "dejejuardes": "dejejuar",
    "dejejuarei": "dejejuar",
    "dejejuareis": "dejejuar",
    "dejejuarem": "dejejuar",
    "dejejuaremos": "dejejuar",
    "dejejuares": "dejejuar",
    "dejejuaria": "dejejuar",
    "dejejuariam": "dejejuar",
    "dejejuarias": "dejejuar",
    "dejejuarmo": "dejejuar",
    "dejejuarmos": "dejejuar",
    "dejejuará": "dejejuar",
    "dejejuarás": "dejejuar",
    "dejejuarão": "dejejuar",
    "dejejuaríamos": "dejejuar",
    "dejejuaríeis": "dejejuar",
    "dejejuas": "dejejuar",
    "dejejuasse": "dejejuar",
    "dejejuassem": "dejejuar",
    "dejejuasses": "dejejuar",
    "dejejuaste": "dejejuar",
    "dejejuastes": "dejejuar",
    "dejejuava": "dejejuar",
    "dejejuavam": "dejejuar",
    "dejejuavas": "dejejuar",
    "dejejue": "dejejuar",
    "dejejuei": "dejejuar",
    "dejejueis": "dejejuar",
    "dejejuem": "dejejuar",
    "dejejuemo": "dejejuar",
    "dejejuemos": "dejejuar",
    "dejejues": "dejejuar",
    "dejejuns": "dejejum",
    "dejejuo": "dejejuar",
    "dejejuou": "dejejuar",
    "dejejuámo": "dejejuar",
    "dejejuámos": "dejejuar",
    "dejejuáramo": "dejejuar",
    "dejejuáramos": "dejejuar",
    "dejejuáreis": "dejejuar",
    "dejejuásseis": "dejejuar",
    "dejejuássemos": "dejejuar",
    "dejejuávamo": "dejejuar",
    "dejejuávamos": "dejejuar",
    "dejejuáveis": "dejejuar",
    "dejuas": "dejua",
    "dejungida": "dejungido",
    "dejungidas": "dejungido",
    "dejungidos": "dejungido",
    "delamba": "delamber",
    "delambais": "delamber",
    "delambam": "delamber",
    "delambamo": "delamber",
    "delambamos": "delamber",
    "delambas": "delamber",
    "delambe": "delamber",
    "delambei": "delamber",
    "delambeis": "delamber",
    "delambem": "delamber",
    "delambemo": "delamber",
    "delambemos": "delamber",
    "delambendo": "delamber",
    "delambera": "delamber",
    "delamberam": "delamber",
    "delamberas": "delamber",
    "delamberde": "delamber",
    "delamberdes": "delamber",
    "delambere": "delamber",
    "delamberei": "delamber",
    "delambereis": "delamber",
    "delamberem": "delamber",
    "delamberemos": "delamber",
    "delamberes": "delamber",
    "delamberia": "delamber",
    "delamberiam": "delamber",
    "delamberias": "delamber",
    "delambermo": "delamber",
    "delambermos": "delamber",
    "delamberá": "delamber",
    "delamberás": "delamber",
    "delamberão": "delamber",
    "delamberíamos": "delamber",
    "delamberíeis": "delamber",
    "delambes": "delamber",
    "delambesse": "delamber",
    "delambessem": "delamber",
    "delambesses": "delamber",
    "delambeste": "delamber",
    "delambestes": "delamber",
    "delambeu": "delamber",
    "delambi": "delamber",
    "delambia": "delamber",
    "delambiam": "delamber",
    "delambias": "delamber",
    "delambida": "delambido",
    "delambidas": "delambido",
    "delambido": "delamber",
    "delambidos": "delambido",
    "delambo": "delamber",
    "delambê": "delamber",
    "delambêramo": "delamber",
    "delambêramos": "delamber",
    "delambêrei": "delamber",
    "delambêreis": "delamber",
    "delambêsseis": "delamber",
    "delambêssemos": "delamber",
    "delambíamo": "delamber",
    "delambíamos": "delamber",
    "delambíei": "delamber",
    "delambíeis": "delamber",
    "delapida": "delapidar",
    "delapidada": "delapidar",
    "delapidadas": "delapidar",
    "delapidado": "delapidar",
    "delapidados": "delapidar",
    "delapidai": "delapidar",
    "delapidais": "delapidar",
    "delapidam": "delapidar",
    "delapidamo": "delapidar",
    "delapidamos": "delapidar",
    "delapidando": "delapidar",
    "delapidara": "delapidar",
    "delapidaram": "delapidar",
    "delapidaras": "delapidar",
    "delapidarde": "delapidar",
    "delapidardes": "delapidar",
    "delapidare": "delapidar",
    "delapidarei": "delapidar",
    "delapidareis": "delapidar",
    "delapidarem": "delapidar",
    "delapidaremos": "delapidar",
    "delapidares": "delapidar",
    "delapidaria": "delapidar",
    "delapidariam": "delapidar",
    "delapidarias": "delapidar",
    "delapidarmo": "delapidar",
    "delapidarmos": "delapidar",
    "delapidará": "delapidar",
    "delapidarás": "delapidar",
    "delapidarão": "delapidar",
    "delapidaríamos": "delapidar",
    "delapidaríeis": "delapidar",
    "delapidas": "delapidar",
    "delapidasse": "delapidar",
    "delapidassem": "delapidar",
    "delapidasses": "delapidar",
    "delapidaste": "delapidar",
    "delapidastes": "delapidar",
    "delapidava": "delapidar",
    "delapidavam": "delapidar",
    "delapidavas": "delapidar",
    "delapidações": "delapidação",
    "delapide": "delapidar",
    "delapidei": "delapidar",
    "delapideis": "delapidar",
    "delapidem": "delapidar",
    "delapidemo": "delapidar",
    "delapidemos": "delapidar",
    "delapides": "delapidar",
    "delapido": "delapidar",
    "delapidou": "delapidar",
    "delapidá": "delapidar",
    "delapidámo": "delapidar",
    "delapidámos": "delapidar",
    "delapidáramo": "delapidar",
    "delapidáramos": "delapidar",
    "delapidárei": "delapidar",
    "delapidáreis": "delapidar",
    "delapidásseis": "delapidar",
    "delapidássemos": "delapidar",
    "delapidávamo": "delapidar",
    "delapidávamos": "delapidar",
    "delapidávei": "delapidar",
    "delapidáveis": "delapidável",
    "delata": "delatar",
    "delatada": "delatar",
    "delatadas": "delatar",
    "delatado": "delatar",
    "delatados": "delatar",
    "delatai": "delatar",
    "delatais": "delatar",
    "delatam": "delatar",
    "delatamo": "delatar",
    "delatamos": "delatar",
    "delatando": "delatar",
    "delatara": "delatar",
    "delataram": "delatar",
    "delataras": "delatar",
    "delatarde": "delatar",
    "delatardes": "delatar",
    "delatare": "delatar",
    "delatarei": "delatar",
    "delatareis": "delatar",
    "delatarem": "delatar",
    "delataremos": "delatar",
    "delatares": "delatar",
    "delataria": "delatar",
    "delatariam": "delatar",
    "delatarias": "delatar",
    "delatarmo": "delatar",
    "delatarmos": "delatar",
    "delatará": "delatar",
    "delatarás": "delatar",
    "delatarão": "delatar",
    "delataríamos": "delatar",
    "delataríeis": "delatar",
    "delatas": "delatar",
    "delatasse": "delatar",
    "delatassem": "delatar",
    "delatasses": "delatar",
    "delataste": "delatar",
    "delatastes": "delatar",
    "delatava": "delatar",
    "delatavam": "delatar",
    "delatavas": "delatar",
    "delate": "delatar",
    "delatei": "delatar",
    "delateis": "delatar",
    "delatem": "delatar",
    "delatemo": "delatar",
    "delatemos": "delatar",
    "delates": "delatar",
    "delato": "delatar",
    "delatora": "delator",
    "delatoras": "delator",
    "delatores": "delator",
    "delatou": "delatar",
    "delatá": "delatar",
    "delatámo": "delatar",
    "delatámos": "delatar",
    "delatáramo": "delatar",
    "delatáramos": "delatar",
    "delatárei": "delatar",
    "delatáreis": "delatar",
    "delatásseis": "delatar",
    "delatássemos": "delatar",
    "delatávamo": "delatar",
    "delatávamos": "delatar",
    "delatávei": "delatar",
    "delatáveis": "delatar",
    "delatória": "delatório",
    "delatórias": "delatório",
    "delatórios": "delatório",
    "delações": "delação",
    "delega": "delegar",
    "delegacias": "delegacia",
    "delegada": "delegar",
    "delegadas": "delegar",
    "delegado": "delegar",
    "delegados": "delegar",
    "delegai": "delegar",
    "delegais": "delegar",
    "delegam": "delegar",
    "delegamo": "delegar",
    "delegamos": "delegar",
    "delegando": "delegar",
    "delegantes": "delegante",
    "delegara": "delegar",
    "delegaram": "delegar",
    "delegaras": "delegar",
    "delegarde": "delegar",
    "delegardes": "delegar",
    "delegare": "delegar",
    "delegarei": "delegar",
    "delegareis": "delegar",
    "delegarem": "delegar",
    "delegaremos": "delegar",
    "delegares": "delegar",
    "delegaria": "delegar",
    "delegariam": "delegar",
    "delegarias": "delegar",
    "delegarmo": "delegar",
    "delegarmos": "delegar",
    "delegará": "delegar",
    "delegarás": "delegar",
    "delegarão": "delegar",
    "delegaríamos": "delegar",
    "delegaríeis": "delegar",
    "delegas": "delegar",
    "delegasse": "delegar",
    "delegassem": "delegar",
    "delegasses": "delegar",
    "delegaste": "delegar",
    "delegastes": "delegar",
    "delegatária": "delegatário",
    "delegatárias": "delegatário",
    "delegatários": "delegatário",
    "delegava": "delegar",
    "delegavam": "delegar",
    "delegavas": "delegar",
    "delegações": "delegação",
    "delego": "delegar",
    "delegou": "delegar",
    "delegue": "delegar",
    "deleguei": "delegar",
    "delegueis": "delegar",
    "deleguem": "delegar",
    "deleguemo": "delegar",
    "deleguemos": "delegar",
    "delegues": "delegar",
    "delegá": "delegar",
    "delegámo": "delegar",
    "delegámos": "delegar",
    "delegáramo": "delegar",
    "delegáramos": "delegar",
    "delegárei": "delegar",
    "delegáreis": "delegar",
    "delegásseis": "delegar",
    "delegássemos": "delegar",
    "delegávamo": "delegar",
    "delegávamos": "delegar",
    "delegávei": "delegar",
    "delegáveis": "delegável",
    "deleita": "deleitar",
    "deleitada": "deleitar",
    "deleitadas": "deleitar",
    "deleitado": "deleitar",
    "deleitados": "deleitar",
    "deleitadíssima": "deleitado",
    "deleitadíssimas": "deleitado",
    "deleitadíssimo": "deleitado",
    "deleitadíssimos": "deleitado",
    "deleitai": "deleitar",
    "deleitais": "deleitar",
    "deleitam": "deleitar",
    "deleitamentos": "deleitamento",
    "deleitamo": "deleitar",
    "deleitamos": "deleitar",
    "deleitando": "deleitar",
    "deleitantes": "deleitante",
    "deleitara": "deleitar",
    "deleitaram": "deleitar",
    "deleitaras": "deleitar",
    "deleitarde": "deleitar",
    "deleitardes": "deleitar",
    "deleitare": "deleitar",
    "deleitarei": "deleitar",
    "deleitareis": "deleitar",
    "deleitarem": "deleitar",
    "deleitaremos": "deleitar",
    "deleitares": "deleitar",
    "deleitaria": "deleitar",
    "deleitariam": "deleitar",
    "deleitarias": "deleitar",
    "deleitarmo": "deleitar",
    "deleitarmos": "deleitar",
    "deleitará": "deleitar",
    "deleitarás": "deleitar",
    "deleitarão": "deleitar",
    "deleitaríamos": "deleitar",
    "deleitaríeis": "deleitar",
    "deleitas": "deleitar",
    "deleitasse": "deleitar",
    "deleitassem": "deleitar",
    "deleitasses": "deleitar",
    "deleitaste": "deleitar",
    "deleitastes": "deleitar",
    "deleitava": "deleitar",
    "deleitavam": "deleitar",
    "deleitavas": "deleitar",
    "deleitações": "deleitação",
    "deleite": "deleitar",
    "deleitei": "deleitar",
    "deleiteis": "deleitar",
    "deleitem": "deleitar",
    "deleitemo": "deleitar",
    "deleitemos": "deleitar",
    "deleites": "deleite",
    "deleito": "deleitar",
    "deleitosa": "deleitoso",
    "deleitosas": "deleitoso",
    "deleitosos": "deleitoso",
    "deleitou": "deleitar",
    "deleitá": "deleitar",
    "deleitámo": "deleitar",
    "deleitámos": "deleitar",
    "deleitáramo": "deleitar",
    "deleitáramos": "deleitar",
    "deleitárei": "deleitar",
    "deleitáreis": "deleitar",
    "deleitásseis": "deleitar",
    "deleitássemos": "deleitar",
    "deleitávamo": "deleitar",
    "deleitávamos": "deleitar",
    "deleitávei": "deleitar",
    "deleitáveis": "deleitável",
    "deletreada": "deletreado",
    "deletreadas": "deletreado",
    "deletreados": "deletreado",
    "deletéria": "deletério",
    "deletérias": "deletério",
    "deletérios": "deletério",
    "delfinados": "delfinado",
    "delfinatos": "delfinato",
    "delfinesa": "delfinês",
    "delfinesas": "delfinês",
    "delfineses": "delfinês",
    "delfininas": "delfinina",
    "delfins": "delfim",
    "delfinídeos": "delfinídeo",
    "delfínidas": "delfínida",
    "delgada": "delgado",
    "delgadas": "delgado",
    "delgadezas": "delgadeza",
    "delgadinha": "delgado",
    "delgadinhas": "delgado",
    "delgadinho": "delgado",
    "delgadinhos": "delgado",
    "delgadita": "delgado",
    "delgaditas": "delgado",
    "delgadito": "delgado",
    "delgaditos": "delgado",
    "delgados": "delgado",
    "deliba": "delibar",
    "delibada": "delibar",
    "delibadas": "delibar",
    "delibado": "delibar",
    "delibados": "delibar",
    "delibai": "delibar",
    "delibais": "delibar",
    "delibam": "delibar",
    "delibamo": "delibar",
    "delibamos": "delibar",
    "delibando": "delibar",
    "delibara": "delibar",
    "delibaram": "delibar",
    "delibaras": "delibar",
    "delibarde": "delibar",
    "delibardes": "delibar",
    "delibare": "delibar",
    "delibarei": "delibar",
    "delibareis": "delibar",
    "delibarem": "delibar",
    "delibaremos": "delibar",
    "delibares": "delibar",
    "delibaria": "delibar",
    "delibariam": "delibar",
    "delibarias": "delibar",
    "delibarmo": "delibar",
    "delibarmos": "delibar",
    "delibará": "delibar",
    "delibarás": "delibar",
    "delibarão": "delibar",
    "delibaríamos": "delibar",
    "delibaríeis": "delibar",
    "delibas": "delibar",
    "delibasse": "delibar",
    "delibassem": "delibar",
    "delibasses": "delibar",
    "delibaste": "delibar",
    "delibastes": "delibar",
    "delibava": "delibar",
    "delibavam": "delibar",
    "delibavas": "delibar",
    "delibações": "delibação",
    "delibe": "delibar",
    "delibei": "delibar",
    "delibeis": "delibar",
    "delibem": "delibar",
    "delibemo": "delibar",
    "delibemos": "delibar",
    "delibera": "deliberar",
    "deliberada": "deliberar",
    "deliberadas": "deliberar",
    "deliberado": "deliberar",
    "deliberados": "deliberar",
    "deliberai": "deliberar",
    "deliberais": "deliberar",
    "deliberam": "deliberar",
    "deliberamo": "deliberar",
    "deliberamos": "deliberar",
    "deliberando": "deliberar",
    "deliberantes": "deliberante",
    "deliberara": "deliberar",
    "deliberaram": "deliberar",
    "deliberaras": "deliberar",
    "deliberarde": "deliberar",
    "deliberardes": "deliberar",
    "deliberare": "deliberar",
    "deliberarei": "deliberar",
    "deliberareis": "deliberar",
    "deliberarem": "deliberar",
    "deliberaremos": "deliberar",
    "deliberares": "deliberar",
    "deliberaria": "deliberar",
    "deliberariam": "deliberar",
    "deliberarias": "deliberar",
    "deliberarmo": "deliberar",
    "deliberarmos": "deliberar",
    "deliberará": "deliberar",
    "deliberarás": "deliberar",
    "deliberarão": "deliberar",
    "deliberaríamos": "deliberar",
    "deliberaríeis": "deliberar",
    "deliberas": "deliberar",
    "deliberasse": "deliberar",
    "deliberassem": "deliberar",
    "deliberasses": "deliberar",
    "deliberaste": "deliberar",
    "deliberastes": "deliberar",
    "deliberativa": "deliberativo",
    "deliberativas": "deliberativo",
    "deliberativos": "deliberativo",
    "deliberava": "deliberar",
    "deliberavam": "deliberar",
    "deliberavas": "deliberar",
    "deliberações": "deliberação",
    "delibere": "deliberar",
    "deliberei": "deliberar",
    "delibereis": "deliberar",
    "deliberem": "deliberar",
    "deliberemo": "deliberar",
    "deliberemos": "deliberar",
    "deliberes": "deliberar",
    "delibero": "deliberar",
    "deliberou": "deliberar",
    "deliberá": "deliberar",
    "deliberámo": "deliberar",
    "deliberámos": "deliberar",
    "deliberáramo": "deliberar",
    "deliberáramos": "deliberar",
    "deliberárei": "deliberar",
    "deliberáreis": "deliberar",
    "deliberásseis": "deliberar",
    "deliberássemos": "deliberar",
    "deliberávamo": "deliberar",
    "deliberávamos": "deliberar",
    "deliberávei": "deliberar",
    "deliberáveis": "deliberar",
    "delibes": "delibar",
    "delibo": "delibar",
    "delibou": "delibar",
    "delibá": "delibar",
    "delibámo": "delibar",
    "delibámos": "delibar",
    "delibáramo": "delibar",
    "delibáramos": "delibar",
    "delibárei": "delibar",
    "delibáreis": "delibar",
    "delibásseis": "delibar",
    "delibássemos": "delibar",
    "delibávamo": "delibar",
    "delibávamos": "delibar",
    "delibávei": "delibar",
    "delibáveis": "delibar",
    "delicada": "delicado",
    "delicadas": "delicado",
    "delicadezas": "delicadeza",
    "delicadinha": "delicado",
    "delicadinhas": "delicado",
    "delicadinho": "delicado",
    "delicadinhos": "delicado",
    "delicadita": "delicado",
    "delicaditas": "delicado",
    "delicadito": "delicado",
    "delicaditos": "delicado",
    "delicados": "delicado",
    "delicadíssima": "delicado",
    "delicadíssimas": "delicado",
    "delicadíssimo": "delicado",
    "delicadíssimos": "delicado",
    "delicia": "deliciar",
    "deliciada": "deliciar",
    "deliciadas": "deliciar",
    "deliciado": "deliciar",
    "deliciados": "deliciar",
    "deliciai": "deliciar",
    "deliciais": "deliciar",
    "deliciam": "deliciar",
    "deliciamo": "deliciar",
    "deliciamos": "deliciar",
    "deliciando": "deliciar",
    "deliciara": "deliciar",
    "deliciaram": "deliciar",
    "deliciaras": "deliciar",
    "deliciarde": "deliciar",
    "deliciardes": "deliciar",
    "deliciare": "deliciar",
    "deliciarei": "deliciar",
    "deliciareis": "deliciar",
    "deliciarem": "deliciar",
    "deliciaremos": "deliciar",
    "deliciares": "deliciar",
    "deliciaria": "deliciar",
    "deliciariam": "deliciar",
    "deliciarias": "deliciar",
    "deliciarmo": "deliciar",
    "deliciarmos": "deliciar",
    "deliciará": "deliciar",
    "deliciarás": "deliciar",
    "deliciarão": "deliciar",
    "deliciaríamos": "deliciar",
    "deliciaríeis": "deliciar",
    "delicias": "deliciar",
    "deliciasse": "deliciar",
    "deliciassem": "deliciar",
    "deliciasses": "deliciar",
    "deliciaste": "deliciar",
    "deliciastes": "deliciar",
    "deliciava": "deliciar",
    "deliciavam": "deliciar",
    "deliciavas": "deliciar",
    "delicie": "deliciar",
    "deliciei": "deliciar",
    "delicieis": "deliciar",
    "deliciem": "deliciar",
    "deliciemo": "deliciar",
    "deliciemos": "deliciar",
    "delicies": "deliciar",
    "delicio": "deliciar",
    "deliciosa": "delicioso",
    "deliciosas": "delicioso",
    "deliciosos": "delicioso",
    "deliciou": "deliciar",
    "deliciá": "deliciar",
    "deliciámo": "deliciar",
    "deliciámos": "deliciar",
    "deliciáramo": "deliciar",
    "deliciáramos": "deliciar",
    "deliciárei": "deliciar",
    "deliciáreis": "deliciar",
    "deliciásseis": "deliciar",
    "deliciássemos": "deliciar",
    "deliciávamo": "deliciar",
    "deliciávamos": "deliciar",
    "deliciávei": "deliciar",
    "deliciáveis": "deliciar",
    "delida": "delido",
    "delidas": "delido",
    "delidos": "delido",
    "deliga": "deligar",
    "deligada": "deligar",
    "deligadas": "deligar",
    "deligado": "deligar",
    "deligados": "deligar",
    "deligai": "deligar",
    "deligais": "deligar",
    "deligam": "deligar",
    "deligamo": "deligar",
    "deligamos": "deligar",
    "deligando": "deligar",
    "deligara": "deligar",
    "deligaram": "deligar",
    "deligaras": "deligar",
    "deligarde": "deligar",
    "deligardes": "deligar",
    "deligare": "deligar",
    "deligarei": "deligar",
    "deligareis": "deligar",
    "deligarem": "deligar",
    "deligaremos": "deligar",
    "deligares": "deligar",
    "deligaria": "deligar",
    "deligariam": "deligar",
    "deligarias": "deligar",
    "deligarmo": "deligar",
    "deligarmos": "deligar",
    "deligará": "deligar",
    "deligarás": "deligar",
    "deligarão": "deligar",
    "deligaríamos": "deligar",
    "deligaríeis": "deligar",
    "deligas": "deligar",
    "deligasse": "deligar",
    "deligassem": "deligar",
    "deligasses": "deligar",
    "deligaste": "deligar",
    "deligastes": "deligar",
    "deligava": "deligar",
    "deligavam": "deligar",
    "deligavas": "deligar",
    "deligações": "deligação",
    "deligo": "deligar",
    "deligou": "deligar",
    "deligue": "deligar",
    "deliguei": "deligar",
    "deligueis": "deligar",
    "deliguem": "deligar",
    "deliguemo": "deligar",
    "deliguemos": "deligar",
    "deligues": "deligar",
    "deligá": "deligar",
    "deligámo": "deligar",
    "deligámos": "deligar",
    "deligáramo": "deligar",
    "deligáramos": "deligar",
    "deligárei": "deligar",
    "deligáreis": "deligar",
    "deligásseis": "deligar",
    "deligássemos": "deligar",
    "deligávamo": "deligar",
    "deligávamos": "deligar",
    "deligávei": "deligar",
    "deligáveis": "deligar",
    "delimita": "delimitar",
    "delimitada": "delimitar",
    "delimitadas": "delimitar",
    "delimitado": "delimitar",
    "delimitadora": "delimitador",
    "delimitadoras": "delimitador",
    "delimitadores": "delimitador",
    "delimitados": "delimitar",
    "delimitai": "delimitar",
    "delimitais": "delimitar",
    "delimitam": "delimitar",
    "delimitamo": "delimitar",
    "delimitamos": "delimitar",
    "delimitando": "delimitar",
    "delimitara": "delimitar",
    "delimitaram": "delimitar",
    "delimitaras": "delimitar",
    "delimitarde": "delimitar",
    "delimitardes": "delimitar",
    "delimitare": "delimitar",
    "delimitarei": "delimitar",
    "delimitareis": "delimitar",
    "delimitarem": "delimitar",
    "delimitaremos": "delimitar",
    "delimitares": "delimitar",
    "delimitaria": "delimitar",
    "delimitariam": "delimitar",
    "delimitarias": "delimitar",
    "delimitarmo": "delimitar",
    "delimitarmos": "delimitar",
    "delimitará": "delimitar",
    "delimitarás": "delimitar",
    "delimitarão": "delimitar",
    "delimitaríamos": "delimitar",
    "delimitaríeis": "delimitar",
    "delimitas": "delimitar",
    "delimitasse": "delimitar",
    "delimitassem": "delimitar",
    "delimitasses": "delimitar",
    "delimitaste": "delimitar",
    "delimitastes": "delimitar",
    "delimitativa": "delimitativo",
    "delimitativas": "delimitativo",
    "delimitativos": "delimitativo",
    "delimitava": "delimitar",
    "delimitavam": "delimitar",
    "delimitavas": "delimitar",
    "delimitações": "delimitação",
    "delimite": "delimitar",
    "delimitei": "delimitar",
    "delimiteis": "delimitar",
    "delimitem": "delimitar",
    "delimitemo": "delimitar",
    "delimitemos": "delimitar",
    "delimites": "delimitar",
    "delimito": "delimitar",
    "delimitou": "delimitar",
    "delimitá": "delimitar",
    "delimitámo": "delimitar",
    "delimitámos": "delimitar",
    "delimitáramo": "delimitar",
    "delimitáramos": "delimitar",
    "delimitárei": "delimitar",
    "delimitáreis": "delimitar",
    "delimitásseis": "delimitar",
    "delimitássemos": "delimitar",
    "delimitávamo": "delimitar",
    "delimitávamos": "delimitar",
    "delimitávei": "delimitar",
    "delimitáveis": "delimitável",
    "delineada": "delinear",
    "delineadas": "delinear",
    "delineado": "delinear",
    "delineadora": "delineador",
    "delineadoras": "delineador",
    "delineadores": "delineador",
    "delineados": "delinear",
    "delineai": "delinear",
    "delineais": "delinear",
    "delineamentos": "delineamento",
    "delineamo": "delinear",
    "delineamos": "delinear",
    "delineando": "delinear",
    "delineara": "delinear",
    "delinearam": "delinear",
    "delinearas": "delinear",
    "delinearde": "delinear",
    "delineardes": "delinear",
    "delineare": "delinear",
    "delinearei": "delinear",
    "delineareis": "delinear",
    "delinearem": "delinear",
    "delinearemos": "delinear",
    "delineares": "delinear",
    "delinearia": "delinear",
    "delineariam": "delinear",
    "delinearias": "delinear",
    "delinearmo": "delinear",
    "delinearmos": "delinear",
    "delineará": "delinear",
    "delinearás": "delinear",
    "delinearão": "delinear",
    "delinearíamos": "delinear",
    "delinearíeis": "delinear",
    "delineasse": "delinear",
    "delineassem": "delinear",
    "delineasses": "delinear",
    "delineaste": "delinear",
    "delineastes": "delinear",
    "delineativa": "delineativo",
    "delineativas": "delineativo",
    "delineativos": "delineativo",
    "delineava": "delinear",
    "delineavam": "delinear",
    "delineavas": "delinear",
    "delineações": "delineação",
    "delineei": "delinear",
    "delineeis": "delinear",
    "delineemo": "delinear",
    "delineemos": "delinear",
    "delineia": "delinear",
    "delineiam": "delinear",
    "delineias": "delinear",
    "delineie": "delinear",
    "delineiem": "delinear",
    "delineies": "delinear",
    "delineio": "delinear",
    "delineou": "delinear",
    "delineá": "delinear",
    "delineámo": "delinear",
    "delineámos": "delinear",
    "delineáramo": "delinear",
    "delineáramos": "delinear",
    "delineárei": "delinear",
    "delineáreis": "delinear",
    "delineásseis": "delinear",
    "delineássemos": "delinear",
    "delineávamo": "delinear",
    "delineávamos": "delinear",
    "delineávei": "delinear",
    "delineáveis": "delinear",
    "delinqua": "delinquir",
    "delinquais": "delinquir",
    "delinquam": "delinquir",
    "delinquamo": "delinquir",
    "delinquamos": "delinquir",
    "delinquas": "delinquir",
    "delinquentes": "delinquente",
    "delinqui": "delinquir",
    "delinquia": "delinquir",
    "delinquiam": "delinquir",
    "delinquias": "delinquir",
    "delinquida": "delinquir",
    "delinquidas": "delinquir",
    "delinquido": "delinquir",
    "delinquidos": "delinquir",
    "delinquimo": "delinquir",
    "delinquimos": "delinquir",
    "delinquindo": "delinquir",
    "delinquira": "delinquir",
    "delinquiram": "delinquir",
    "delinquiras": "delinquir",
    "delinquirde": "delinquir",
    "delinquirdes": "delinquir",
    "delinquire": "delinquir",
    "delinquirei": "delinquir",
    "delinquireis": "delinquir",
    "delinquirem": "delinquir",
    "delinquiremos": "delinquir",
    "delinquires": "delinquir",
    "delinquiria": "delinquir",
    "delinquiriam": "delinquir",
    "delinquirias": "delinquir",
    "delinquirmo": "delinquir",
    "delinquirmos": "delinquir",
    "delinquirá": "delinquir",
    "delinquirás": "delinquir",
    "delinquirão": "delinquir",
    "delinquiríamos": "delinquir",
    "delinquiríeis": "delinquir",
    "delinquis": "delinquir",
    "delinquisse": "delinquir",
    "delinquissem": "delinquir",
    "delinquisses": "delinquir",
    "delinquiste": "delinquir",
    "delinquistes": "delinquir",
    "delinquiu": "delinquir",
    "delinquo": "delinquir",
    "delinquências": "delinquência",
    "delinquíamo": "delinquir",
    "delinquíamos": "delinquir",
    "delinquíei": "delinquir",
    "delinquíeis": "delinquir",
    "delinquíramo": "delinquir",
    "delinquíramos": "delinquir",
    "delinquírei": "delinquir",
    "delinquíreis": "delinquir",
    "delinquísseis": "delinquir",
    "delinquíssemos": "delinquir",
    "delinqúa": "delinquir",
    "delinqúas": "delinquir",
    "delinqúe": "delinquir",
    "delinqúem": "delinquir",
    "delinqúi": "delinquir",
    "delinqúis": "delinquir",
    "deliqua": "deliquar",
    "deliquada": "deliquar",
    "deliquadas": "deliquar",
    "deliquado": "deliquar",
    "deliquados": "deliquar",
    "deliquai": "deliquar",
    "deliquais": "deliquar",
    "deliquam": "deliquar",
    "deliquamo": "deliquar",
    "deliquamos": "deliquar",
    "deliquando": "deliquar",
    "deliquara": "deliquar",
    "deliquaram": "deliquar",
    "deliquaras": "deliquar",
    "deliquarde": "deliquar",
    "deliquardes": "deliquar",
    "deliquare": "deliquar",
    "deliquarei": "deliquar",
    "deliquareis": "deliquar",
    "deliquarem": "deliquar",
    "deliquaremos": "deliquar",
    "deliquares": "deliquar",
    "deliquaria": "deliquar",
    "deliquariam": "deliquar",
    "deliquarias": "deliquar",
    "deliquarmo": "deliquar",
    "deliquarmos": "deliquar",
    "deliquará": "deliquar",
    "deliquarás": "deliquar",
    "deliquarão": "deliquar",
    "deliquaríamos": "deliquar",
    "deliquaríeis": "deliquar",
    "deliquas": "deliquar",
    "deliquasse": "deliquar",
    "deliquassem": "deliquar",
    "deliquasses": "deliquar",
    "deliquaste": "deliquar",
    "deliquastes": "deliquar",
    "deliquava": "deliquar",
    "deliquavam": "deliquar",
    "deliquavas": "deliquar",
    "deliquei": "deliquar",
    "deliqueis": "deliquar",
    "deliquemo": "deliquar",
    "deliquemos": "deliquar",
    "deliques": "deliquar",
    "deliquesce": "deliquescer",
    "deliquescei": "deliquescer",
    "deliquesceis": "deliquescer",
    "deliquescem": "deliquescer",
    "deliquescemo": "deliquescer",
    "deliquescemos": "deliquescer",
    "deliquescendo": "deliquescer",
    "deliquescentes": "deliquescente",
    "deliquescera": "deliquescer",
    "deliquesceram": "deliquescer",
    "deliquesceras": "deliquescer",
    "deliquescerdes": "deliquescer",
    "deliquescerei": "deliquescer",
    "deliquescereis": "deliquescer",
    "deliquescerem": "deliquescer",
    "deliquesceremos": "deliquescer",
    "deliquesceres": "deliquescer",
    "deliquesceria": "deliquescer",
    "deliquesceriam": "deliquescer",
    "deliquescerias": "deliquescer",
    "deliquescermo": "deliquescer",
    "deliquescermos": "deliquescer",
    "deliquescerá": "deliquescer",
    "deliquescerás": "deliquescer",
    "deliquescerão": "deliquescer",
    "deliquesceríamos": "deliquescer",
    "deliquesceríeis": "deliquescer",
    "deliquesces": "deliquescer",
    "deliquescesse": "deliquescer",
    "deliquescessem": "deliquescer",
    "deliquescesses": "deliquescer",
    "deliquesceste": "deliquescer",
    "deliquescestes": "deliquescer",
    "deliquesceu": "deliquescer",
    "deliquesci": "deliquescer",
    "deliquescia": "deliquescer",
    "deliquesciam": "deliquescer",
    "deliquescias": "deliquescer",
    "deliquescida": "deliquescer",
    "deliquescidas": "deliquescer",
    "deliquescido": "deliquescer",
    "deliquescidos": "deliquescer",
    "deliquescências": "deliquescência",
    "deliquescêramo": "deliquescer",
    "deliquescêramos": "deliquescer",
    "deliquescêreis": "deliquescer",
    "deliquescêsseis": "deliquescer",
    "deliquescêssemos": "deliquescer",
    "deliquescíamo": "deliquescer",
    "deliquescíamos": "deliquescer",
    "deliquescíeis": "deliquescer",
    "deliquesça": "deliquescer",
    "deliquesçais": "deliquescer",
    "deliquesçam": "deliquescer",
    "deliquesçamo": "deliquescer",
    "deliquesçamos": "deliquescer",
    "deliquesças": "deliquescer",
    "deliquesço": "deliquescer",
    "deliquo": "deliquar",
    "deliquou": "deliquar",
    "deliquá": "deliquar",
    "deliquámo": "deliquar",
    "deliquámos": "deliquar",
    "deliquáramo": "deliquar",
    "deliquáramos": "deliquar",
    "deliquárei": "deliquar",
    "deliquáreis": "deliquar",
    "deliquásseis": "deliquar",
    "deliquássemos": "deliquar",
    "deliquávamo": "deliquar",
    "deliquávamos": "deliquar",
    "deliquávei": "deliquar",
    "deliquáveis": "deliquar",
    "deliqúe": "deliquar",
    "deliqúem": "deliquar",
    "deliqúes": "deliquar",
    "delira": "delirar",
    "delirada": "delirar",
    "deliradas": "delirar",
    "delirado": "delirar",
    "delirados": "delirar",
    "delirai": "delirar",
    "delirais": "delirar",
    "deliram": "delirar",
    "deliramo": "delirar",
    "deliramos": "delirar",
    "delirando": "delirar",
    "delirantes": "delirante",
    "delirara": "delirar",
    "deliraram": "delirar",
    "deliraras": "delirar",
    "delirardes": "delirar",
    "delirarei": "delirar",
    "delirareis": "delirar",
    "delirarem": "delirar",
    "deliraremos": "delirar",
    "delirares": "delirar",
    "deliraria": "delirar",
    "delirariam": "delirar",
    "delirarias": "delirar",
    "delirarmo": "delirar",
    "delirarmos": "delirar",
    "delirará": "delirar",
    "delirarás": "delirar",
    "delirarão": "delirar",
    "deliraríamos": "delirar",
    "deliraríeis": "delirar",
    "deliras": "delirar",
    "delirasse": "delirar",
    "delirassem": "delirar",
    "delirasses": "delirar",
    "deliraste": "delirar",
    "delirastes": "delirar",
    "delirava": "delirar",
    "deliravam": "delirar",
    "deliravas": "delirar",
    "delire": "delirar",
    "delirei": "delirar",
    "delireis": "delirar",
    "delirem": "delirar",
    "deliremo": "delirar",
    "deliremos": "delirar",
    "delires": "delirar",
    "deliro": "delirar",
    "delirou": "delirar",
    "delirámo": "delirar",
    "delirámos": "delirar",
    "deliráramo": "delirar",
    "deliráramos": "delirar",
    "deliráreis": "delirar",
    "delirásseis": "delirar",
    "delirássemos": "delirar",
    "delirávamo": "delirar",
    "delirávamos": "delirar",
    "deliráveis": "delirar",
    "delitos": "delito",
    "delituosa": "delituoso",
    "delituosas": "delituoso",
    "delituosos": "delituoso",
    "delivra": "delivrar",
    "delivrada": "delivrar",
    "delivradas": "delivrar",
    "delivrado": "delivrar",
    "delivrados": "delivrar",
    "delivrai": "delivrar",
    "delivrais": "delivrar",
    "delivram": "delivrar",
    "delivramentos": "delivramento",
    "delivramo": "delivrar",
    "delivramos": "delivrar",
    "delivrando": "delivrar",
    "delivrara": "delivrar",
    "delivraram": "delivrar",
    "delivraras": "delivrar",
    "delivrarde": "delivrar",
    "delivrardes": "delivrar",
    "delivrare": "delivrar",
    "delivrarei": "delivrar",
    "delivrareis": "delivrar",
    "delivrarem": "delivrar",
    "delivraremos": "delivrar",
    "delivrares": "delivrar",
    "delivraria": "delivrar",
    "delivrariam": "delivrar",
    "delivrarias": "delivrar",
    "delivrarmo": "delivrar",
    "delivrarmos": "delivrar",
    "delivrará": "delivrar",
    "delivrarás": "delivrar",
    "delivrarão": "delivrar",
    "delivraríamos": "delivrar",
    "delivraríeis": "delivrar",
    "delivras": "delivrar",
    "delivrasse": "delivrar",
    "delivrassem": "delivrar",
    "delivrasses": "delivrar",
    "delivraste": "delivrar",
    "delivrastes": "delivrar",
    "delivrava": "delivrar",
    "delivravam": "delivrar",
    "delivravas": "delivrar",
    "delivrações": "delivração",
    "delivre": "delivrar",
    "delivrei": "delivrar",
    "delivreis": "delivrar",
    "delivrem": "delivrar",
    "delivremo": "delivrar",
    "delivremos": "delivrar",
    "delivres": "delivrar",
    "delivro": "delivrar",
    "delivrou": "delivrar",
    "delivrá": "delivrar",
    "delivrámo": "delivrar",
    "delivrámos": "delivrar",
    "delivráramo": "delivrar",
    "delivráramos": "delivrar",
    "delivrárei": "delivrar",
    "delivráreis": "delivrar",
    "delivrásseis": "delivrar",
    "delivrássemos": "delivrar",
    "delivrávamo": "delivrar",
    "delivrávamos": "delivrar",
    "delivrávei": "delivrar",
    "delivráveis": "delivrar",
    "delonga": "delongar",
    "delongada": "delongar",
    "delongadas": "delongar",
    "delongado": "delongar",
    "delongadora": "delongador",
    "delongadoras": "delongador",
    "delongadores": "delongador",
    "delongados": "delongar",
    "delongai": "delongar",
    "delongais": "delongar",
    "delongam": "delongar",
    "delongamo": "delongar",
    "delongamos": "delongar",
    "delongando": "delongar",
    "delongara": "delongar",
    "delongaram": "delongar",
    "delongaras": "delongar",
    "delongarde": "delongar",
    "delongardes": "delongar",
    "delongare": "delongar",
    "delongarei": "delongar",
    "delongareis": "delongar",
    "delongarem": "delongar",
    "delongaremos": "delongar",
    "delongares": "delongar",
    "delongaria": "delongar",
    "delongariam": "delongar",
    "delongarias": "delongar",
    "delongarmo": "delongar",
    "delongarmos": "delongar",
    "delongará": "delongar",
    "delongarás": "delongar",
    "delongarão": "delongar",
    "delongaríamos": "delongar",
    "delongaríeis": "delongar",
    "delongas": "delongar",
    "delongasse": "delongar",
    "delongassem": "delongar",
    "delongasses": "delongar",
    "delongaste": "delongar",
    "delongastes": "delongar",
    "delongava": "delongar",
    "delongavam": "delongar",
    "delongavas": "delongar",
    "delongo": "delongar",
    "delongou": "delongar",
    "delongue": "delongar",
    "delonguei": "delongar",
    "delongueis": "delongar",
    "delonguem": "delongar",
    "delonguemo": "delongar",
    "delonguemos": "delongar",
    "delongues": "delongar",
    "delongá": "delongar",
    "delongámo": "delongar",
    "delongámos": "delongar",
    "delongáramo": "delongar",
    "delongáramos": "delongar",
    "delongárei": "delongar",
    "delongáreis": "delongar",
    "delongásseis": "delongar",
    "delongássemos": "delongar",
    "delongávamo": "delongar",
    "delongávamos": "delongar",
    "delongávei": "delongar",
    "delongáveis": "delongar",
    "deltaica": "deltaico",
    "deltaicas": "deltaico",
    "deltaicos": "deltaico",
    "deltas": "delta",
    "deltoedros": "deltoedro",
    "deltoidais": "deltoidal",
    "deltoides": "deltoide",
    "deltóidea": "deltóideo",
    "deltóideas": "deltóideo",
    "deltóideos": "deltóideo",
    "deltóides": "deltóide",
    "delubros": "delubro",
    "delusa": "deluso",
    "delusas": "deluso",
    "delusos": "deluso",
    "delusória": "delusório",
    "delusórias": "delusório",
    "delusórios": "delusório",
    "deléveis": "delével",
    "delícias": "delícia",
    "delínqua": "delinquir",
    "delínquam": "delinquir",
    "delínquas": "delinquir",
    "delínque": "delinquir",
    "delínquem": "delinquir",
    "delínques": "delinquir",
    "delínquo": "delinquir",
    "delíquios": "delíquio",
    "delírios": "delírio",
    "demagoga": "demagogo",
    "demagogas": "demagogo",
    "demagogias": "demagogia",
    "demagogices": "demagogice",
    "demagogismos": "demagogismo",
    "demagogistas": "demagogista",
    "demagogos": "demagogo",
    "demagógica": "demagógico",
    "demagógicas": "demagógico",
    "demagógicos": "demagógico",
    "demanda": "demandar",
    "demandada": "demandar",
    "demandadas": "demandar",
    "demandado": "demandar",
    "demandadora": "demandador",
    "demandadoras": "demandador",
    "demandadores": "demandador",
    "demandados": "demandar",
    "demandai": "demandar",
    "demandais": "demandar",
    "demandam": "demandar",
    "demandamo": "demandar",
    "demandamos": "demandar",
    "demandando": "demandar",
    "demandantes": "demandante",
    "demandara": "demandar",
    "demandaram": "demandar",
    "demandaras": "demandar",
    "demandarde": "demandar",
    "demandardes": "demandar",
    "demandare": "demandar",
    "demandarei": "demandar",
    "demandareis": "demandar",
    "demandarem": "demandar",
    "demandaremos": "demandar",
    "demandares": "demandar",
    "demandaria": "demandar",
    "demandariam": "demandar",
    "demandarias": "demandar",
    "demandarmo": "demandar",
    "demandarmos": "demandar",
    "demandará": "demandar",
    "demandarás": "demandar",
    "demandarão": "demandar",
    "demandaríamos": "demandar",
    "demandaríeis": "demandar",
    "demandas": "demandar",
    "demandasse": "demandar",
    "demandassem": "demandar",
    "demandasses": "demandar",
    "demandaste": "demandar",
    "demandastes": "demandar",
    "demandava": "demandar",
    "demandavam": "demandar",
    "demandavas": "demandar",
    "demande": "demandar",
    "demandei": "demandar",
    "demandeis": "demandar",
    "demandem": "demandar",
    "demandemo": "demandar",
    "demandemos": "demandar",
    "demandes": "demandar",
    "demandistas": "demandista",
    "demando": "demandar",
    "demandona": "demandão",
    "demandonas": "demandão",
    "demandou": "demandar",
    "demandá": "demandar",
    "demandámo": "demandar",
    "demandámos": "demandar",
    "demandáramo": "demandar",
    "demandáramos": "demandar",
    "demandárei": "demandar",
    "demandáreis": "demandar",
    "demandásseis": "demandar",
    "demandássemos": "demandar",
    "demandávamo": "demandar",
    "demandávamos": "demandar",
    "demandávei": "demandar",
    "demandáveis": "demandar",
    "demandões": "demandão",
    "demarca": "demarcar",
    "demarcada": "demarcar",
    "demarcadas": "demarcar",
    "demarcado": "demarcar",
    "demarcadora": "demarcador",
    "demarcadoras": "demarcador",
    "demarcadores": "demarcador",
    "demarcados": "demarcar",
    "demarcai": "demarcar",
    "demarcais": "demarcar",
    "demarcam": "demarcar",
    "demarcamo": "demarcar",
    "demarcamos": "demarcar",
    "demarcando": "demarcar",
    "demarcara": "demarcar",
    "demarcaram": "demarcar",
    "demarcaras": "demarcar",
    "demarcarde": "demarcar",
    "demarcardes": "demarcar",
    "demarcare": "demarcar",
    "demarcarei": "demarcar",
    "demarcareis": "demarcar",
    "demarcarem": "demarcar",
    "demarcaremos": "demarcar",
    "demarcares": "demarcar",
    "demarcaria": "demarcar",
    "demarcariam": "demarcar",
    "demarcarias": "demarcar",
    "demarcarmo": "demarcar",
    "demarcarmos": "demarcar",
    "demarcará": "demarcar",
    "demarcarás": "demarcar",
    "demarcarão": "demarcar",
    "demarcaríamos": "demarcar",
    "demarcaríeis": "demarcar",
    "demarcas": "demarcar",
    "demarcasse": "demarcar",
    "demarcassem": "demarcar",
    "demarcasses": "demarcar",
    "demarcaste": "demarcar",
    "demarcastes": "demarcar",
    "demarcativa": "demarcativo",
    "demarcativas": "demarcativo",
    "demarcativos": "demarcativo",
    "demarcatória": "demarcatório",
    "demarcatórias": "demarcatório",
    "demarcatórios": "demarcatório",
    "demarcava": "demarcar",
    "demarcavam": "demarcar",
    "demarcavas": "demarcar",
    "demarcações": "demarcação",
    "demarco": "demarcar",
    "demarcou": "demarcar",
    "demarcá": "demarcar",
    "demarcámo": "demarcar",
    "demarcámos": "demarcar",
    "demarcáramo": "demarcar",
    "demarcáramos": "demarcar",
    "demarcárei": "demarcar",
    "demarcáreis": "demarcar",
    "demarcásseis": "demarcar",
    "demarcássemos": "demarcar",
    "demarcávamo": "demarcar",
    "demarcávamos": "demarcar",
    "demarcávei": "demarcar",
    "demarcáveis": "demarcável",
    "demarque": "demarcar",
    "demarquei": "demarcar",
    "demarqueis": "demarcar",
    "demarquem": "demarcar",
    "demarquemo": "demarcar",
    "demarquemos": "demarcar",
    "demarques": "demarcar",
    "demasia": "demasiar",
    "demasiada": "demasiar",
    "demasiadas": "demasiar",
    "demasiado": "demasiar",
    "demasiados": "demasiar",
    "demasiai": "demasiar",
    "demasiais": "demasiar",
    "demasiam": "demasiar",
    "demasiamo": "demasiar",
    "demasiamos": "demasiar",
    "demasiando": "demasiar",
    "demasiara": "demasiar",
    "demasiaram": "demasiar",
    "demasiaras": "demasiar",
    "demasiarde": "demasiar",
    "demasiardes": "demasiar",
    "demasiare": "demasiar",
    "demasiarei": "demasiar",
    "demasiareis": "demasiar",
    "demasiarem": "demasiar",
    "demasiaremos": "demasiar",
    "demasiares": "demasiar",
    "demasiaria": "demasiar",
    "demasiariam": "demasiar",
    "demasiarias": "demasiar",
    "demasiarmo": "demasiar",
    "demasiarmos": "demasiar",
    "demasiará": "demasiar",
    "demasiarás": "demasiar",
    "demasiarão": "demasiar",
    "demasiaríamos": "demasiar",
    "demasiaríeis": "demasiar",
    "demasias": "demasiar",
    "demasiasse": "demasiar",
    "demasiassem": "demasiar",
    "demasiasses": "demasiar",
    "demasiaste": "demasiar",
    "demasiastes": "demasiar",
    "demasiava": "demasiar",
    "demasiavam": "demasiar",
    "demasiavas": "demasiar",
    "demasie": "demasiar",
    "demasiei": "demasiar",
    "demasieis": "demasiar",
    "demasiem": "demasiar",
    "demasiemo": "demasiar",
    "demasiemos": "demasiar",
    "demasies": "demasiar",
    "demasio": "demasiar",
    "demasiou": "demasiar",
    "demasiá": "demasiar",
    "demasiámo": "demasiar",
    "demasiámos": "demasiar",
    "demasiáramo": "demasiar",
    "demasiáramos": "demasiar",
    "demasiárei": "demasiar",
    "demasiáreis": "demasiar",
    "demasiásseis": "demasiar",
    "demasiássemos": "demasiar",
    "demasiávamo": "demasiar",
    "demasiávamos": "demasiar",
    "demasiávei": "demasiar",
    "demasiáveis": "demasiar",
    "demba": "dembo",
    "dembados": "dembado",
    "dembas": "dembo",
    "dembes": "dembe",
    "dembos": "dembo",
    "demenciais": "demencial",
    "dementa": "dementar",
    "dementada": "dementar",
    "dementadas": "dementar",
    "dementado": "dementar",
    "dementados": "dementar",
    "dementai": "dementar",
    "dementais": "dementar",
    "dementam": "dementar",
    "dementamo": "dementar",
    "dementamos": "dementar",
    "dementando": "dementar",
    "dementara": "dementar",
    "dementaram": "dementar",
    "dementaras": "dementar",
    "dementarde": "dementar",
    "dementardes": "dementar",
    "dementare": "dementar",
    "dementarei": "dementar",
    "dementareis": "dementar",
    "dementarem": "dementar",
    "dementaremos": "dementar",
    "dementares": "dementar",
    "dementaria": "dementar",
    "dementariam": "dementar",
    "dementarias": "dementar",
    "dementarmo": "dementar",
    "dementarmos": "dementar",
    "dementará": "dementar",
    "dementarás": "dementar",
    "dementarão": "dementar",
    "dementaríamos": "dementar",
    "dementaríeis": "dementar",
    "dementas": "dementar",
    "dementasse": "dementar",
    "dementassem": "dementar",
    "dementasses": "dementar",
    "dementaste": "dementar",
    "dementastes": "dementar",
    "dementava": "dementar",
    "dementavam": "dementar",
    "dementavas": "dementar",
    "dementações": "dementação",
    "demente": "dementar",
    "dementei": "dementar",
    "dementeis": "dementar",
    "dementem": "dementar",
    "dementemo": "dementar",
    "dementemos": "dementar",
    "dementes": "demente",
    "demento": "dementar",
    "dementou": "dementar",
    "dementá": "dementar",
    "dementámo": "dementar",
    "dementámos": "dementar",
    "dementáramo": "dementar",
    "dementáramos": "dementar",
    "dementárei": "dementar",
    "dementáreis": "dementar",
    "dementásseis": "dementar",
    "dementássemos": "dementar",
    "dementávamo": "dementar",
    "dementávamos": "dementar",
    "dementávei": "dementar",
    "dementáveis": "dementar",
    "demeritória": "demeritório",
    "demeritórias": "demeritório",
    "demeritórios": "demeritório",
    "demissa": "demisso",
    "demissas": "demisso",
    "demissibilidades": "demissibilidade",
    "demissionária": "demissionário",
    "demissionárias": "demissionário",
    "demissionários": "demissionário",
    "demissora": "demissor",
    "demissoras": "demissor",
    "demissores": "demissor",
    "demissos": "demisso",
    "demissíveis": "demissível",
    "demissória": "demissório",
    "demissórias": "demissório",
    "demissórios": "demissório",
    "demissões": "demissão",
    "demita": "demitir",
    "demitais": "demitir",
    "demitam": "demitir",
    "demitamo": "demitir",
    "demitamos": "demitir",
    "demitas": "demitir",
    "demite": "demitir",
    "demitem": "demitir",
    "demitentes": "demitente",
    "demites": "demitir",
    "demiti": "demitir",
    "demitia": "demitir",
    "demitiam": "demitir",
    "demitias": "demitir",
    "demitida": "demitir",
    "demitidas": "demitir",
    "demitido": "demitir",
    "demitidos": "demitir",
    "demitimo": "demitir",
    "demitimos": "demitir",
    "demitindo": "demitir",
    "demitira": "demitir",
    "demitiram": "demitir",
    "demitiras": "demitir",
    "demitirde": "demitir",
    "demitirdes": "demitir",
    "demitire": "demitir",
    "demitirei": "demitir",
    "demitireis": "demitir",
    "demitirem": "demitir",
    "demitiremos": "demitir",
    "demitires": "demitir",
    "demitiria": "demitir",
    "demitiriam": "demitir",
    "demitirias": "demitir",
    "demitirmo": "demitir",
    "demitirmos": "demitir",
    "demitirá": "demitir",
    "demitirás": "demitir",
    "demitirão": "demitir",
    "demitiríamos": "demitir",
    "demitiríeis": "demitir",
    "demitis": "demitir",
    "demitisse": "demitir",
    "demitissem": "demitir",
    "demitisses": "demitir",
    "demitiste": "demitir",
    "demitistes": "demitir",
    "demitiu": "demitir",
    "demito": "demitir",
    "demitíamo": "demitir",
    "demitíamos": "demitir",
    "demitíei": "demitir",
    "demitíeis": "demitir",
    "demitíramo": "demitir",
    "demitíramos": "demitir",
    "demitírei": "demitir",
    "demitíreis": "demitir",
    "demitísseis": "demitir",
    "demitíssemos": "demitir",
    "demiurga": "demiurgo",
    "demiurgas": "demiurgo",
    "demiurgos": "demiurgo",
    "demiúrgica": "demiúrgico",
    "demiúrgicas": "demiúrgico",
    "demiúrgicos": "demiúrgico",
    "demo": "dar",
    "democracias": "democracia",
    "democratas": "democrata",
    "democraticidades": "democraticidade",
    "democratismos": "democratismo",
    "democratiza": "democratizar",
    "democratizada": "democratizar",
    "democratizadas": "democratizar",
    "democratizado": "democratizar",
    "democratizados": "democratizar",
    "democratizai": "democratizar",
    "democratizais": "democratizar",
    "democratizam": "democratizar",
    "democratizamo": "democratizar",
    "democratizamos": "democratizar",
    "democratizando": "democratizar",
    "democratizantes": "democratizante",
    "democratizara": "democratizar",
    "democratizaram": "democratizar",
    "democratizaras": "democratizar",
    "democratizarde": "democratizar",
    "democratizardes": "democratizar",
    "democratizare": "democratizar",
    "democratizarei": "democratizar",
    "democratizareis": "democratizar",
    "democratizarem": "democratizar",
    "democratizaremos": "democratizar",
    "democratizares": "democratizar",
    "democratizaria": "democratizar",
    "democratizariam": "democratizar",
    "democratizarias": "democratizar",
    "democratizarmo": "democratizar",
    "democratizarmos": "democratizar",
    "democratizará": "democratizar",
    "democratizarás": "democratizar",
    "democratizarão": "democratizar",
    "democratizaríamos": "democratizar",
    "democratizaríeis": "democratizar",
    "democratizas": "democratizar",
    "democratizasse": "democratizar",
    "democratizassem": "democratizar",
    "democratizasses": "democratizar",
    "democratizaste": "democratizar",
    "democratizastes": "democratizar",
    "democratizava": "democratizar",
    "democratizavam": "democratizar",
    "democratizavas": "democratizar",
    "democratizações": "democratização",
    "democratize": "democratizar",
    "democratizei": "democratizar",
    "democratizeis": "democratizar",
    "democratizem": "democratizar",
    "democratizemo": "democratizar",
    "democratizemos": "democratizar",
    "democratizes": "democratizar",
    "democratizo": "democratizar",
    "democratizou": "democratizar",
    "democratizá": "democratizar",
    "democratizámo": "democratizar",
    "democratizámos": "democratizar",
    "democratizáramo": "democratizar",
    "democratizáramos": "democratizar",
    "democratizárei": "democratizar",
    "democratizáreis": "democratizar",
    "democratizásseis": "democratizar",
    "democratizássemos": "democratizar",
    "democratizávamo": "democratizar",
    "democratizávamos": "democratizar",
    "democratizávei": "democratizar",
    "democratizáveis": "democratizável",
    "democrática": "democrático",
    "democráticas": "democrático",
    "democráticos": "democrático",
    "demofilias": "demofilia",
    "demografa": "demografar",
    "demografada": "demografar",
    "demografadas": "demografar",
    "demografado": "demografar",
    "demografados": "demografar",
    "demografai": "demografar",
    "demografais": "demografar",
    "demografam": "demografar",
    "demografamo": "demografar",
    "demografamos": "demografar",
    "demografando": "demografar",
    "demografara": "demografar",
    "demografaram": "demografar",
    "demografaras": "demografar",
    "demografarde": "demografar",
    "demografardes": "demografar",
    "demografare": "demografar",
    "demografarei": "demografar",
    "demografareis": "demografar",
    "demografarem": "demografar",
    "demografaremos": "demografar",
    "demografares": "demografar",
    "demografaria": "demografar",
    "demografariam": "demografar",
    "demografarias": "demografar",
    "demografarmo": "demografar",
    "demografarmos": "demografar",
    "demografará": "demografar",
    "demografarás": "demografar",
    "demografarão": "demografar",
    "demografaríamos": "demografar",
    "demografaríeis": "demografar",
    "demografas": "demografar",
    "demografasse": "demografar",
    "demografassem": "demografar",
    "demografasses": "demografar",
    "demografaste": "demografar",
    "demografastes": "demografar",
    "demografava": "demografar",
    "demografavam": "demografar",
    "demografavas": "demografar",
    "demografe": "demografar",
    "demografei": "demografar",
    "demografeis": "demografar",
    "demografem": "demografar",
    "demografemo": "demografar",
    "demografemos": "demografar",
    "demografes": "demografar",
    "demografias": "demografia",
    "demografo": "demografar",
    "demografou": "demografar",
    "demografá": "demografar",
    "demografámo": "demografar",
    "demografámos": "demografar",
    "demografáramo": "demografar",
    "demografáramos": "demografar",
    "demografárei": "demografar",
    "demografáreis": "demografar",
    "demografásseis": "demografar",
    "demografássemos": "demografar",
    "demografávamo": "demografar",
    "demografávamos": "demografar",
    "demografávei": "demografar",
    "demografáveis": "demografar",
    "demográfica": "demográfico",
    "demográficas": "demográfico",
    "demográficos": "demográfico",
    "demola": "demolir",
    "demolais": "demolir",
    "demolam": "demolir",
    "demolamo": "demolir",
    "demolamos": "demolir",
    "demolas": "demolir",
    "demole": "demolir",
    "demolem": "demolir",
    "demoles": "demolir",
    "demolha": "demolhar",
    "demolhada": "demolhar",
    "demolhadas": "demolhar",
    "demolhado": "demolhar",
    "demolhados": "demolhar",
    "demolhai": "demolhar",
    "demolhais": "demolhar",
    "demolham": "demolhar",
    "demolhamo": "demolhar",
    "demolhamos": "demolhar",
    "demolhando": "demolhar",
    "demolhara": "demolhar",
    "demolharam": "demolhar",
    "demolharas": "demolhar",
    "demolharde": "demolhar",
    "demolhardes": "demolhar",
    "demolhare": "demolhar",
    "demolharei": "demolhar",
    "demolhareis": "demolhar",
    "demolharem": "demolhar",
    "demolharemos": "demolhar",
    "demolhares": "demolhar",
    "demolharia": "demolhar",
    "demolhariam": "demolhar",
    "demolharias": "demolhar",
    "demolharmo": "demolhar",
    "demolharmos": "demolhar",
    "demolhará": "demolhar",
    "demolharás": "demolhar",
    "demolharão": "demolhar",
    "demolharíamos": "demolhar",
    "demolharíeis": "demolhar",
    "demolhas": "demolhar",
    "demolhasse": "demolhar",
    "demolhassem": "demolhar",
    "demolhasses": "demolhar",
    "demolhaste": "demolhar",
    "demolhastes": "demolhar",
    "demolhava": "demolhar",
    "demolhavam": "demolhar",
    "demolhavas": "demolhar",
    "demolhe": "demolhar",
    "demolhei": "demolhar",
    "demolheis": "demolhar",
    "demolhem": "demolhar",
    "demolhemo": "demolhar",
    "demolhemos": "demolhar",
    "demolhes": "demolhar",
    "demolho": "demolhar",
    "demolhou": "demolhar",
    "demolhá": "demolhar",
    "demolhámo": "demolhar",
    "demolhámos": "demolhar",
    "demolháramo": "demolhar",
    "demolháramos": "demolhar",
    "demolhárei": "demolhar",
    "demolháreis": "demolhar",
    "demolhásseis": "demolhar",
    "demolhássemos": "demolhar",
    "demolhávamo": "demolhar",
    "demolhávamos": "demolhar",
    "demolhávei": "demolhar",
    "demolháveis": "demolhar",
    "demoli": "demolir",
    "demolia": "demolir",
    "demoliam": "demolir",
    "demolias": "demolir",
    "demolida": "demolir",
    "demolidas": "demolir",
    "demolido": "demolir",
    "demolidora": "demolidor",
    "demolidoras": "demolidor",
    "demolidores": "demolidor",
    "demolidos": "demolir",
    "demolimo": "demolir",
    "demolimos": "demolir",
    "demolindo": "demolir",
    "demolira": "demolir",
    "demoliram": "demolir",
    "demoliras": "demolir",
    "demolirde": "demolir",
    "demolirdes": "demolir",
    "demolire": "demolir",
    "demolirei": "demolir",
    "demolireis": "demolir",
    "demolirem": "demolir",
    "demoliremos": "demolir",
    "demolires": "demolir",
    "demoliria": "demolir",
    "demoliriam": "demolir",
    "demolirias": "demolir",
    "demolirmo": "demolir",
    "demolirmos": "demolir",
    "demolirá": "demolir",
    "demolirás": "demolir",
    "demolirão": "demolir",
    "demoliríamos": "demolir",
    "demoliríeis": "demolir",
    "demolis": "demolir",
    "demolisse": "demolir",
    "demolissem": "demolir",
    "demolisses": "demolir",
    "demoliste": "demolir",
    "demolistes": "demolir",
    "demolitória": "demolitório",
    "demolitórias": "demolitório",
    "demolitórios": "demolitório",
    "demoliu": "demolir",
    "demolições": "demolição",
    "demolo": "demolir",
    "demolíamo": "demolir",
    "demolíamos": "demolir",
    "demolíei": "demolir",
    "demolíeis": "demolir",
    "demolíramo": "demolir",
    "demolíramos": "demolir",
    "demolírei": "demolir",
    "demolíreis": "demolir",
    "demolísseis": "demolir",
    "demolíssemos": "demolir",
    "demolíveis": "demolível",
    "demonarcas": "demonarca",
    "demonetes": "demonete",
    "demonetiza": "demonetizar",
    "demonetizada": "demonetizar",
    "demonetizadas": "demonetizar",
    "demonetizado": "demonetizar",
    "demonetizados": "demonetizar",
    "demonetizai": "demonetizar",
    "demonetizais": "demonetizar",
    "demonetizam": "demonetizar",
    "demonetizamo": "demonetizar",
    "demonetizamos": "demonetizar",
    "demonetizando": "demonetizar",
    "demonetizara": "demonetizar",
    "demonetizaram": "demonetizar",
    "demonetizaras": "demonetizar",
    "demonetizarde": "demonetizar",
    "demonetizardes": "demonetizar",
    "demonetizare": "demonetizar",
    "demonetizarei": "demonetizar",
    "demonetizareis": "demonetizar",
    "demonetizarem": "demonetizar",
    "demonetizaremos": "demonetizar",
    "demonetizares": "demonetizar",
    "demonetizaria": "demonetizar",
    "demonetizariam": "demonetizar",
    "demonetizarias": "demonetizar",
    "demonetizarmo": "demonetizar",
    "demonetizarmos": "demonetizar",
    "demonetizará": "demonetizar",
    "demonetizarás": "demonetizar",
    "demonetizarão": "demonetizar",
    "demonetizaríamos": "demonetizar",
    "demonetizaríeis": "demonetizar",
    "demonetizas": "demonetizar",
    "demonetizasse": "demonetizar",
    "demonetizassem": "demonetizar",
    "demonetizasses": "demonetizar",
    "demonetizaste": "demonetizar",
    "demonetizastes": "demonetizar",
    "demonetizava": "demonetizar",
    "demonetizavam": "demonetizar",
    "demonetizavas": "demonetizar",
    "demonetizações": "demonetização",
    "demonetize": "demonetizar",
    "demonetizei": "demonetizar",
    "demonetizeis": "demonetizar",
    "demonetizem": "demonetizar",
    "demonetizemo": "demonetizar",
    "demonetizemos": "demonetizar",
    "demonetizes": "demonetizar",
    "demonetizo": "demonetizar",
    "demonetizou": "demonetizar",
    "demonetizá": "demonetizar",
    "demonetizámo": "demonetizar",
    "demonetizámos": "demonetizar",
    "demonetizáramo": "demonetizar",
    "demonetizáramos": "demonetizar",
    "demonetizárei": "demonetizar",
    "demonetizáreis": "demonetizar",
    "demonetizásseis": "demonetizar",
    "demonetizássemos": "demonetizar",
    "demonetizávamo": "demonetizar",
    "demonetizávamos": "demonetizar",
    "demonetizávei": "demonetizar",
    "demonetizáveis": "demonetizar",
    "demonicos": "demonico",
    "demonifúgios": "demonifúgio",
    "demoninharias": "demoninharia",
    "demoniomanias": "demoniomania",
    "demoniomaníaca": "demoniomaníaco",
    "demoniomaníacas": "demoniomaníaco",
    "demoniomaníacos": "demoniomaníaco",
    "demonismos": "demonismo",
    "demonistas": "demonista",
    "demonocracias": "demonocracia",
    "demonografias": "demonografia",
    "demonográfica": "demonográfico",
    "demonográficas": "demonográfico",
    "demonográficos": "demonográfico",
    "demonolatrias": "demonolatria",
    "demonologias": "demonologia",
    "demonológica": "demonológico",
    "demonológicas": "demonológico",
    "demonológicos": "demonológico",
    "demonomancias": "demonomancia",
    "demonomaniaca": "demonomaniaco",
    "demonomaniacas": "demonomaniaco",
    "demonomaniacos": "demonomaniaco",
    "demonomanias": "demonomania",
    "demonopatas": "demonopata",
    "demonopatias": "demonopatia",
    "demonstra": "demonstrar",
    "demonstrabilidades": "demonstrabilidade",
    "demonstrada": "demonstrar",
    "demonstradas": "demonstrar",
    "demonstrado": "demonstrar",
    "demonstradora": "demonstrador",
    "demonstradoras": "demonstrador",
    "demonstradores": "demonstrador",
    "demonstrados": "demonstrar",
    "demonstrai": "demonstrar",
    "demonstrais": "demonstrar",
    "demonstram": "demonstrar",
    "demonstramo": "demonstrar",
    "demonstramos": "demonstrar",
    "demonstrando": "demonstrar",
    "demonstrantes": "demonstrante",
    "demonstrara": "demonstrar",
    "demonstraram": "demonstrar",
    "demonstraras": "demonstrar",
    "demonstrarde": "demonstrar",
    "demonstrardes": "demonstrar",
    "demonstrare": "demonstrar",
    "demonstrarei": "demonstrar",
    "demonstrareis": "demonstrar",
    "demonstrarem": "demonstrar",
    "demonstraremos": "demonstrar",
    "demonstrares": "demonstrar",
    "demonstraria": "demonstrar",
    "demonstrariam": "demonstrar",
    "demonstrarias": "demonstrar",
    "demonstrarmo": "demonstrar",
    "demonstrarmos": "demonstrar",
    "demonstrará": "demonstrar",
    "demonstrarás": "demonstrar",
    "demonstrarão": "demonstrar",
    "demonstraríamos": "demonstrar",
    "demonstraríeis": "demonstrar",
    "demonstras": "demonstrar",
    "demonstrasse": "demonstrar",
    "demonstrassem": "demonstrar",
    "demonstrasses": "demonstrar",
    "demonstraste": "demonstrar",
    "demonstrastes": "demonstrar",
    "demonstrativa": "demonstrativo",
    "demonstrativas": "demonstrativo",
    "demonstrativos": "demonstrativo",
    "demonstrava": "demonstrar",
    "demonstravam": "demonstrar",
    "demonstravas": "demonstrar",
    "demonstrações": "demonstração",
    "demonstre": "demonstrar",
    "demonstrei": "demonstrar",
    "demonstreis": "demonstrar",
    "demonstrem": "demonstrar",
    "demonstremo": "demonstrar",
    "demonstremos": "demonstrar",
    "demonstres": "demonstrar",
    "demonstro": "demonstrar",
    "demonstrou": "demonstrar",
    "demonstrá": "demonstrar",
    "demonstrámo": "demonstrar",
    "demonstrámos": "demonstrar",
    "demonstráramo": "demonstrar",
    "demonstráramos": "demonstrar",
    "demonstrárei": "demonstrar",
    "demonstráreis": "demonstrar",
    "demonstrásseis": "demonstrar",
    "demonstrássemos": "demonstrar",
    "demonstrávamo": "demonstrar",
    "demonstrávamos": "demonstrar",
    "demonstrávei": "demonstrar",
    "demonstráveis": "demonstrável",
    "demoníaca": "demoníaco",
    "demoníacas": "demoníaco",
    "demoníacos": "demoníaco",
    "demonífuga": "demonífugo",
    "demonífugas": "demonífugo",
    "demonífugos": "demonífugo",
    "demonógrafos": "demonógrafo",
    "demonólatras": "demonólatra",
    "demonólogos": "demonólogo",
    "demonómana": "demonómano",
    "demonómanas": "demonómano",
    "demonómanos": "demonómano",
    "demopsicologias": "demopsicologia",
    "demopsicológica": "demopsicológico",
    "demopsicológicas": "demopsicológico",
    "demopsicológicos": "demopsicológico",
    "demopsicóloga": "demopsicólogo",
    "demopsicólogas": "demopsicólogo",
    "demopsicólogos": "demopsicólogo",
    "demora": "demorar",
    "demorada": "demorar",
    "demoradas": "demorar",
    "demorado": "demorar",
    "demorados": "demorar",
    "demorai": "demorar",
    "demorais": "demorar",
    "demoram": "demorar",
    "demoramo": "demorar",
    "demoramos": "demorar",
    "demorando": "demorar",
    "demorara": "demorar",
    "demoraram": "demorar",
    "demoraras": "demorar",
    "demorarde": "demorar",
    "demorardes": "demorar",
    "demorare": "demorar",
    "demorarei": "demorar",
    "demorareis": "demorar",
    "demorarem": "demorar",
    "demoraremos": "demorar",
    "demorares": "demorar",
    "demoraria": "demorar",
    "demorariam": "demorar",
    "demorarias": "demorar",
    "demorarmo": "demorar",
    "demorarmos": "demorar",
    "demorará": "demorar",
    "demorarás": "demorar",
    "demorarão": "demorar",
    "demoraríamos": "demorar",
    "demoraríeis": "demorar",
    "demoras": "demorar",
    "demorasse": "demorar",
    "demorassem": "demorar",
    "demorasses": "demorar",
    "demoraste": "demorar",
    "demorastes": "demorar",
    "demorava": "demorar",
    "demoravam": "demorar",
    "demoravas": "demorar",
    "demore": "demorar",
    "demorei": "demorar",
    "demoreis": "demorar",
    "demorem": "demorar",
    "demoremo": "demorar",
    "demoremos": "demorar",
    "demores": "demorar",
    "demoro": "demorar",
    "demorosa": "demoroso",
    "demorosas": "demoroso",
    "demorosos": "demoroso",
    "demorou": "demorar",
    "demorá": "demorar",
    "demorámo": "demorar",
    "demorámos": "demorar",
    "demoráramo": "demorar",
    "demoráramos": "demorar",
    "demorárei": "demorar",
    "demoráreis": "demorar",
    "demorásseis": "demorar",
    "demorássemos": "demorar",
    "demorávamo": "demorar",
    "demorávamos": "demorar",
    "demorávei": "demorar",
    "demoráveis": "demorar",
    "demos": "demo",
    "demostra": "demostrar",
    "demostrada": "demostrar",
    "demostradas": "demostrar",
    "demostrado": "demostrar",
    "demostradora": "demostrador",
    "demostradoras": "demostrador",
    "demostradores": "demostrador",
    "demostrados": "demostrar",
    "demostrai": "demostrar",
    "demostrais": "demostrar",
    "demostram": "demostrar",
    "demostramo": "demostrar",
    "demostramos": "demostrar",
    "demostrando": "demostrar",
    "demostrara": "demostrar",
    "demostraram": "demostrar",
    "demostraras": "demostrar",
    "demostrarde": "demostrar",
    "demostrardes": "demostrar",
    "demostrare": "demostrar",
    "demostrarei": "demostrar",
    "demostrareis": "demostrar",
    "demostrarem": "demostrar",
    "demostraremos": "demostrar",
    "demostrares": "demostrar",
    "demostraria": "demostrar",
    "demostrariam": "demostrar",
    "demostrarias": "demostrar",
    "demostrarmo": "demostrar",
    "demostrarmos": "demostrar",
    "demostrará": "demostrar",
    "demostrarás": "demostrar",
    "demostrarão": "demostrar",
    "demostraríamos": "demostrar",
    "demostraríeis": "demostrar",
    "demostras": "demostrar",
    "demostrasse": "demostrar",
    "demostrassem": "demostrar",
    "demostrasses": "demostrar",
    "demostraste": "demostrar",
    "demostrastes": "demostrar",
    "demostrativa": "demostrativo",
    "demostrativas": "demostrativo",
    "demostrativos": "demostrativo",
    "demostrava": "demostrar",
    "demostravam": "demostrar",
    "demostravas": "demostrar",
    "demostrações": "demostração",
    "demostre": "demostrar",
    "demostrei": "demostrar",
    "demostreis": "demostrar",
    "demostrem": "demostrar",
    "demostremo": "demostrar",
    "demostremos": "demostrar",
    "demostres": "demostrar",
    "demostro": "demostrar",
    "demostrou": "demostrar",
    "demostrá": "demostrar",
    "demostrámo": "demostrar",
    "demostrámos": "demostrar",
    "demostráramo": "demostrar",
    "demostráramos": "demostrar",
    "demostrárei": "demostrar",
    "demostráreis": "demostrar",
    "demostrásseis": "demostrar",
    "demostrássemos": "demostrar",
    "demostrávamo": "demostrar",
    "demostrávamos": "demostrar",
    "demostrávei": "demostrar",
    "demostráveis": "demostrar",
    "demostémica": "demostémico",
    "demostémicas": "demostémico",
    "demostémicos": "demostémico",
    "demova": "demover",
    "demovais": "demover",
    "demovam": "demover",
    "demovamo": "demover",
    "demovamos": "demover",
    "demovas": "demover",
    "demove": "demover",
    "demovei": "demover",
    "demoveis": "demover",
    "demovem": "demover",
    "demovemo": "demover",
    "demovemos": "demover",
    "demovendo": "demover",
    "demovera": "demover",
    "demoveram": "demover",
    "demoveras": "demover",
    "demoverde": "demover",
    "demoverdes": "demover",
    "demovere": "demover",
    "demoverei": "demover",
    "demovereis": "demover",
    "demoverem": "demover",
    "demoveremos": "demover",
    "demoveres": "demover",
    "demoveria": "demover",
    "demoveriam": "demover",
    "demoverias": "demover",
    "demovermo": "demover",
    "demovermos": "demover",
    "demoverá": "demover",
    "demoverás": "demover",
    "demoverão": "demover",
    "demoveríamos": "demover",
    "demoveríeis": "demover",
    "demoves": "demover",
    "demovesse": "demover",
    "demovessem": "demover",
    "demovesses": "demover",
    "demoveste": "demover",
    "demovestes": "demover",
    "demoveu": "demover",
    "demovi": "demover",
    "demovia": "demover",
    "demoviam": "demover",
    "demovias": "demover",
    "demovida": "demovido",
    "demovidas": "demovido",
    "demovido": "demover",
    "demovidos": "demovido",
    "demovimentos": "demovimento",
    "demovo": "demover",
    "demovê": "demover",
    "demovêramo": "demover",
    "demovêramos": "demover",
    "demovêrei": "demover",
    "demovêreis": "demover",
    "demovêsseis": "demover",
    "demovêssemos": "demover",
    "demovíamo": "demover",
    "demovíamos": "demover",
    "demovíei": "demover",
    "demovíeis": "demover",
    "demovíveis": "demovível",
    "demuda": "demudar",
    "demudada": "demudar",
    "demudadas": "demudar",
    "demudado": "demudar",
    "demudados": "demudar",
    "demudai": "demudar",
    "demudais": "demudar",
    "demudam": "demudar",
    "demudamo": "demudar",
    "demudamos": "demudar",
    "demudando": "demudar",
    "demudanças": "demudança",
    "demudara": "demudar",
    "demudaram": "demudar",
    "demudaras": "demudar",
    "demudarde": "demudar",
    "demudardes": "demudar",
    "demudare": "demudar",
    "demudarei": "demudar",
    "demudareis": "demudar",
    "demudarem": "demudar",
    "demudaremos": "demudar",
    "demudares": "demudar",
    "demudaria": "demudar",
    "demudariam": "demudar",
    "demudarias": "demudar",
    "demudarmo": "demudar",
    "demudarmos": "demudar",
    "demudará": "demudar",
    "demudarás": "demudar",
    "demudarão": "demudar",
    "demudaríamos": "demudar",
    "demudaríeis": "demudar",
    "demudas": "demudar",
    "demudasse": "demudar",
    "demudassem": "demudar",
    "demudasses": "demudar",
    "demudaste": "demudar",
    "demudastes": "demudar",
    "demudava": "demudar",
    "demudavam": "demudar",
    "demudavas": "demudar",
    "demude": "demudar",
    "demudei": "demudar",
    "demudeis": "demudar",
    "demudem": "demudar",
    "demudemo": "demudar",
    "demudemos": "demudar",
    "demudes": "demudar",
    "demudo": "demudar",
    "demudou": "demudar",
    "demudá": "demudar",
    "demudámo": "demudar",
    "demudámos": "demudar",
    "demudáramo": "demudar",
    "demudáramos": "demudar",
    "demudárei": "demudar",
    "demudáreis": "demudar",
    "demudásseis": "demudar",
    "demudássemos": "demudar",
    "demudávamo": "demudar",
    "demudávamos": "demudar",
    "demudávei": "demudar",
    "demudáveis": "demudar",
    "demulcentes": "demulcente",
    "demãos": "demão",
    "demérita": "demérito",
    "deméritas": "demérito",
    "deméritos": "demérito",
    "demências": "demência",
    "demófila": "demófilo",
    "demófilas": "demófilo",
    "demófilos": "demófilo",
    "demófoba": "demófobo",
    "demófobas": "demófobo",
    "demófobos": "demófobo",
    "demógrafa": "demógrafo",
    "demógrafas": "demógrafo",
    "demógrafos": "demógrafo",
    "demónios": "demónio",
    "demótica": "demótico",
    "demóticas": "demótico",
    "demóticos": "demótico",
    "dendens": "dendem",
    "dendezeiros": "dendezeiro",
    "dendos": "dendo",
    "dendrites": "dendrite",
    "dendritos": "dendrito",
    "dendrobatas": "dendrobata",
    "dendroclastas": "dendroclasta",
    "dendroclastias": "dendroclastia",
    "dendrocronologias": "dendrocronologia",
    "dendrofaga": "dendrofago",
    "dendrofagas": "dendrofago",
    "dendrofagias": "dendrofagia",
    "dendrofagos": "dendrofago",
    "dendrofila": "dendrofilo",
    "dendrofilas": "dendrofilo",
    "dendrofilias": "dendrofilia",
    "dendrofilos": "dendrofilo",
    "dendrofoba": "dendrofobo",
    "dendrofobas": "dendrofobo",
    "dendrofobias": "dendrofobia",
    "dendrofobos": "dendrofobo",
    "dendrografias": "dendrografia",
    "dendrografos": "dendrografo",
    "dendrolatrias": "dendrolatria",
    "dendrologias": "dendrologia",
    "dendrologistas": "dendrologista",
    "dendromancias": "dendromancia",
    "dendrólatras": "dendrólatra",
    "dendrólitos": "dendrólito",
    "dendróloga": "dendrólogo",
    "dendrólogas": "dendrólogo",
    "dendrólogos": "dendrólogo",
    "dendrómetros": "dendrómetro",
    "dendês": "dendê",
    "denega": "denegar",
    "denegada": "denegar",
    "denegadas": "denegar",
    "denegado": "denegar",
    "denegados": "denegar",
    "denegai": "denegar",
    "denegais": "denegar",
    "denegam": "denegar",
    "denegamo": "denegar",
    "denegamos": "denegar",
    "denegando": "denegar",
    "denegara": "denegar",
    "denegaram": "denegar",
    "denegaras": "denegar",
    "denegarde": "denegar",
    "denegardes": "denegar",
    "denegare": "denegar",
    "denegarei": "denegar",
    "denegareis": "denegar",
    "denegarem": "denegar",
    "denegaremos": "denegar",
    "denegares": "denegar",
    "denegaria": "denegar",
    "denegariam": "denegar",
    "denegarias": "denegar",
    "denegarmo": "denegar",
    "denegarmos": "denegar",
    "denegará": "denegar",
    "denegarás": "denegar",
    "denegarão": "denegar",
    "denegaríamos": "denegar",
    "denegaríeis": "denegar",
    "denegas": "denegar",
    "denegasse": "denegar",
    "denegassem": "denegar",
    "denegasses": "denegar",
    "denegaste": "denegar",
    "denegastes": "denegar",
    "denegava": "denegar",
    "denegavam": "denegar",
    "denegavas": "denegar",
    "denegações": "denegação",
    "denego": "denegar",
    "denegou": "denegar",
    "denegrece": "denegrecer",
    "denegrecei": "denegrecer",
    "denegreceis": "denegrecer",
    "denegrecem": "denegrecer",
    "denegrecemo": "denegrecer",
    "denegrecemos": "denegrecer",
    "denegrecendo": "denegrecer",
    "denegrecera": "denegrecer",
    "denegreceram": "denegrecer",
    "denegreceras": "denegrecer",
    "denegrecerde": "denegrecer",
    "denegrecerdes": "denegrecer",
    "denegrecere": "denegrecer",
    "denegrecerei": "denegrecer",
    "denegrecereis": "denegrecer",
    "denegrecerem": "denegrecer",
    "denegreceremos": "denegrecer",
    "denegreceres": "denegrecer",
    "denegreceria": "denegrecer",
    "denegreceriam": "denegrecer",
    "denegrecerias": "denegrecer",
    "denegrecermo": "denegrecer",
    "denegrecermos": "denegrecer",
    "denegrecerá": "denegrecer",
    "denegrecerás": "denegrecer",
    "denegrecerão": "denegrecer",
    "denegreceríamos": "denegrecer",
    "denegreceríeis": "denegrecer",
    "denegreces": "denegrecer",
    "denegrecesse": "denegrecer",
    "denegrecessem": "denegrecer",
    "denegrecesses": "denegrecer",
    "denegreceste": "denegrecer",
    "denegrecestes": "denegrecer",
    "denegreceu": "denegrecer",
    "denegreci": "denegrecer",
    "denegrecia": "denegrecer",
    "denegreciam": "denegrecer",
    "denegrecias": "denegrecer",
    "denegrecida": "denegrecer",
    "denegrecidas": "denegrecer",
    "denegrecido": "denegrecer",
    "denegrecidos": "denegrecer",
    "denegrecê": "denegrecer",
    "denegrecêramo": "denegrecer",
    "denegrecêramos": "denegrecer",
    "denegrecêrei": "denegrecer",
    "denegrecêreis": "denegrecer",
    "denegrecêsseis": "denegrecer",
    "denegrecêssemos": "denegrecer",
    "denegrecíamo": "denegrecer",
    "denegrecíamos": "denegrecer",
    "denegrecíei": "denegrecer",
    "denegrecíeis": "denegrecer",
    "denegreça": "denegrecer",
    "denegreçais": "denegrecer",
    "denegreçam": "denegrecer",
    "denegreçamo": "denegrecer",
    "denegreçamos": "denegrecer",
    "denegreças": "denegrecer",
    "denegreço": "denegrecer",
    "denegri": "denegrir",
    "denegria": "denegrir",
    "denegriam": "denegrir",
    "denegrias": "denegrir",
    "denegrida": "denegrir",
    "denegridas": "denegrir",
    "denegrido": "denegrir",
    "denegridora": "denegridor",
    "denegridoras": "denegridor",
    "denegridores": "denegridor",
    "denegridos": "denegrir",
    "denegrimo": "denegrir",
    "denegrimos": "denegrir",
    "denegrindo": "denegrir",
    "denegrira": "denegrir",
    "denegriram": "denegrir",
    "denegriras": "denegrir",
    "denegrirde": "denegrir",
    "denegrirdes": "denegrir",
    "denegrire": "denegrir",
    "denegrirei": "denegrir",
    "denegrireis": "denegrir",
    "denegrirem": "denegrir",
    "denegriremos": "denegrir",
    "denegrires": "denegrir",
    "denegriria": "denegrir",
    "denegririam": "denegrir",
    "denegririas": "denegrir",
    "denegrirmo": "denegrir",
    "denegrirmos": "denegrir",
    "denegrirá": "denegrir",
    "denegrirás": "denegrir",
    "denegrirão": "denegrir",
    "denegriríamos": "denegrir",
    "denegriríeis": "denegrir",
    "denegris": "denegrir",
    "denegrisse": "denegrir",
    "denegrissem": "denegrir",
    "denegrisses": "denegrir",
    "denegriste": "denegrir",
    "denegristes": "denegrir",
    "denegriu": "denegrir",
    "denegríamo": "denegrir",
    "denegríamos": "denegrir",
    "denegríei": "denegrir",
    "denegríeis": "denegrir",
    "denegríramo": "denegrir",
    "denegríramos": "denegrir",
    "denegrírei": "denegrir",
    "denegríreis": "denegrir",
    "denegrísseis": "denegrir",
    "denegríssemos": "denegrir",
    "denegríveis": "denegrível",
    "denegue": "denegar",
    "deneguei": "denegar",
    "denegueis": "denegar",
    "deneguem": "denegar",
    "deneguemo": "denegar",
    "deneguemos": "denegar",
    "denegues": "denegar",
    "denegá": "denegar",
    "denegámo": "denegar",
    "denegámos": "denegar",
    "denegáramo": "denegar",
    "denegáramos": "denegar",
    "denegárei": "denegar",
    "denegáreis": "denegar",
    "denegásseis": "denegar",
    "denegássemos": "denegar",
    "denegávamo": "denegar",
    "denegávamos": "denegar",
    "denegávei": "denegar",
    "denegáveis": "denegar",
    "dengosa": "dengoso",
    "dengosas": "dengoso",
    "dengosos": "dengoso",
    "dengues": "dengue",
    "denguices": "denguice",
    "denguins": "denguim",
    "denigativa": "denigativo",
    "denigativas": "denigativo",
    "denigativos": "denigativo",
    "denigra": "denigrir",
    "denigrais": "denigrir",
    "denigram": "denigrir",
    "denigramo": "denigrir",
    "denigramos": "denigrir",
    "denigras": "denigrir",
    "denigrações": "denigração",
    "denigre": "denigrir",
    "denigrem": "denigrir",
    "denigres": "denigrir",
    "denigri": "denigrir",
    "denigria": "denigrir",
    "denigriam": "denigrir",
    "denigrias": "denigrir",
    "denigrida": "denigrir",
    "denigridas": "denigrir",
    "denigrido": "denigrir",
    "denigridos": "denigrir",
    "denigrimo": "denigrir",
    "denigrimos": "denigrir",
    "denigrindo": "denigrir",
    "denigrira": "denigrir",
    "denigriram": "denigrir",
    "denigriras": "denigrir",
    "denigrirde": "denigrir",
    "denigrirdes": "denigrir",
    "denigrire": "denigrir",
    "denigrirei": "denigrir",
    "denigrireis": "denigrir",
    "denigrirem": "denigrir",
    "denigriremos": "denigrir",
    "denigrires": "denigrir",
    "denigriria": "denigrir",
    "denigririam": "denigrir",
    "denigririas": "denigrir",
    "denigrirmo": "denigrir",
    "denigrirmos": "denigrir",
    "denigrirá": "denigrir",
    "denigrirás": "denigrir",
    "denigrirão": "denigrir",
    "denigriríamos": "denigrir",
    "denigriríeis": "denigrir",
    "denigris": "denigrir",
    "denigrisse": "denigrir",
    "denigrissem": "denigrir",
    "denigrisses": "denigrir",
    "denigriste": "denigrir",
    "denigristes": "denigrir",
    "denigriu": "denigrir",
    "denigro": "denigrir",
    "denigríamo": "denigrir",
    "denigríamos": "denigrir",
    "denigríei": "denigrir",
    "denigríeis": "denigrir",
    "denigríramo": "denigrir",
    "denigríramos": "denigrir",
    "denigrírei": "denigrir",
    "denigríreis": "denigrir",
    "denigrísseis": "denigrir",
    "denigríssemos": "denigrir",
    "denoda": "denodar",
    "denodada": "denodar",
    "denodadas": "denodar",
    "denodado": "denodar",
    "denodados": "denodar",
    "denodai": "denodar",
    "denodais": "denodar",
    "denodam": "denodar",
    "denodamo": "denodar",
    "denodamos": "denodar",
    "denodando": "denodar",
    "denodara": "denodar",
    "denodaram": "denodar",
    "denodaras": "denodar",
    "denodarde": "denodar",
    "denodardes": "denodar",
    "denodare": "denodar",
    "denodarei": "denodar",
    "denodareis": "denodar",
    "denodarem": "denodar",
    "denodaremos": "denodar",
    "denodares": "denodar",
    "denodaria": "denodar",
    "denodariam": "denodar",
    "denodarias": "denodar",
    "denodarmo": "denodar",
    "denodarmos": "denodar",
    "denodará": "denodar",
    "denodarás": "denodar",
    "denodarão": "denodar",
    "denodaríamos": "denodar",
    "denodaríeis": "denodar",
    "denodas": "denodar",
    "denodasse": "denodar",
    "denodassem": "denodar",
    "denodasses": "denodar",
    "denodaste": "denodar",
    "denodastes": "denodar",
    "denodava": "denodar",
    "denodavam": "denodar",
    "denodavas": "denodar",
    "denode": "denodar",
    "denodei": "denodar",
    "denodeis": "denodar",
    "denodem": "denodar",
    "denodemo": "denodar",
    "denodemos": "denodar",
    "denodes": "denodar",
    "denodo": "denodar",
    "denodos": "denodo",
    "denodou": "denodar",
    "denodá": "denodar",
    "denodámo": "denodar",
    "denodámos": "denodar",
    "denodáramo": "denodar",
    "denodáramos": "denodar",
    "denodárei": "denodar",
    "denodáreis": "denodar",
    "denodásseis": "denodar",
    "denodássemos": "denodar",
    "denodávamo": "denodar",
    "denodávamos": "denodar",
    "denodávei": "denodar",
    "denodáveis": "denodar",
    "denomina": "denominar",
    "denominada": "denominar",
    "denominadas": "denominar",
    "denominado": "denominar",
    "denominadora": "denominador",
    "denominadoras": "denominador",
    "denominadores": "denominador",
    "denominados": "denominar",
    "denominai": "denominar",
    "denominais": "denominar",
    "denominam": "denominar",
    "denominamo": "denominar",
    "denominamos": "denominar",
    "denominando": "denominar",
    "denominara": "denominar",
    "denominaram": "denominar",
    "denominaras": "denominar",
    "denominarde": "denominar",
    "denominardes": "denominar",
    "denominare": "denominar",
    "denominarei": "denominar",
    "denominareis": "denominar",
    "denominarem": "denominar",
    "denominaremos": "denominar",
    "denominares": "denominar",
    "denominaria": "denominar",
    "denominariam": "denominar",
    "denominarias": "denominar",
    "denominarmo": "denominar",
    "denominarmos": "denominar",
    "denominará": "denominar",
    "denominarás": "denominar",
    "denominarão": "denominar",
    "denominaríamos": "denominar",
    "denominaríeis": "denominar",
    "denominas": "denominar",
    "denominasse": "denominar",
    "denominassem": "denominar",
    "denominasses": "denominar",
    "denominaste": "denominar",
    "denominastes": "denominar",
    "denominativa": "denominativo",
    "denominativas": "denominativo",
    "denominativos": "denominativo",
    "denominava": "denominar",
    "denominavam": "denominar",
    "denominavas": "denominar",
    "denominações": "denominação",
    "denomine": "denominar",
    "denominei": "denominar",
    "denomineis": "denominar",
    "denominem": "denominar",
    "denominemo": "denominar",
    "denominemos": "denominar",
    "denomines": "denominar",
    "denomino": "denominar",
    "denominou": "denominar",
    "denominá": "denominar",
    "denominámo": "denominar",
    "denominámos": "denominar",
    "denomináramo": "denominar",
    "denomináramos": "denominar",
    "denominárei": "denominar",
    "denomináreis": "denominar",
    "denominásseis": "denominar",
    "denominássemos": "denominar",
    "denominávamo": "denominar",
    "denominávamos": "denominar",
    "denominávei": "denominar",
    "denomináveis": "denominável",
    "denota": "denotar",
    "denotada": "denotar",
    "denotadas": "denotar",
    "denotado": "denotar",
    "denotadora": "denotador",
    "denotadoras": "denotador",
    "denotadores": "denotador",
    "denotados": "denotar",
    "denotai": "denotar",
    "denotais": "denotar",
    "denotam": "denotar",
    "denotamo": "denotar",
    "denotamos": "denotar",
    "denotando": "denotar",
    "denotara": "denotar",
    "denotaram": "denotar",
    "denotaras": "denotar",
    "denotarde": "denotar",
    "denotardes": "denotar",
    "denotare": "denotar",
    "denotarei": "denotar",
    "denotareis": "denotar",
    "denotarem": "denotar",
    "denotaremos": "denotar",
    "denotares": "denotar",
    "denotaria": "denotar",
    "denotariam": "denotar",
    "denotarias": "denotar",
    "denotarmo": "denotar",
    "denotarmos": "denotar",
    "denotará": "denotar",
    "denotarás": "denotar",
    "denotarão": "denotar",
    "denotaríamos": "denotar",
    "denotaríeis": "denotar",
    "denotas": "denotar",
    "denotasse": "denotar",
    "denotassem": "denotar",
    "denotasses": "denotar",
    "denotaste": "denotar",
    "denotastes": "denotar",
    "denotava": "denotar",
    "denotavam": "denotar",
    "denotavas": "denotar",
    "denotações": "denotação",
    "denote": "denotar",
    "denotei": "denotar",
    "denoteis": "denotar",
    "denotem": "denotar",
    "denotemo": "denotar",
    "denotemos": "denotar",
    "denotes": "denotar",
    "denoto": "denotar",
    "denotou": "denotar",
    "denotá": "denotar",
    "denotámo": "denotar",
    "denotámos": "denotar",
    "denotáramo": "denotar",
    "denotáramos": "denotar",
    "denotárei": "denotar",
    "denotáreis": "denotar",
    "denotásseis": "denotar",
    "denotássemos": "denotar",
    "denotávamo": "denotar",
    "denotávamos": "denotar",
    "denotávei": "denotar",
    "denotáveis": "denotar",
    "densa": "denso",
    "densada": "densar",
    "densadas": "densar",
    "densado": "densar",
    "densados": "densar",
    "densai": "densar",
    "densais": "densar",
    "densam": "densar",
    "densamo": "densar",
    "densamos": "densar",
    "densando": "densar",
    "densara": "densar",
    "densaram": "densar",
    "densaras": "densar",
    "densarde": "densar",
    "densardes": "densar",
    "densare": "densar",
    "densarei": "densar",
    "densareis": "densar",
    "densarem": "densar",
    "densaremos": "densar",
    "densares": "densar",
    "densaria": "densar",
    "densariam": "densar",
    "densarias": "densar",
    "densarmo": "densar",
    "densarmos": "densar",
    "densará": "densar",
    "densarás": "densar",
    "densarão": "densar",
    "densaríamos": "densar",
    "densaríeis": "densar",
    "densas": "denso",
    "densasse": "densar",
    "densassem": "densar",
    "densasses": "densar",
    "densaste": "densar",
    "densastes": "densar",
    "densava": "densar",
    "densavam": "densar",
    "densavas": "densar",
    "dense": "densar",
    "densei": "densar",
    "denseis": "densar",
    "densem": "densar",
    "densemo": "densar",
    "densemos": "densar",
    "denses": "densar",
    "densidades": "densidade",
    "densiflora": "densifloro",
    "densifloras": "densifloro",
    "densifloros": "densifloro",
    "densifoliada": "densifoliado",
    "densifoliadas": "densifoliado",
    "densifoliados": "densifoliado",
    "densimetrias": "densimetria",
    "denso": "densar",
    "densos": "denso",
    "densou": "densar",
    "densá": "densar",
    "densámo": "densar",
    "densámos": "densar",
    "densáramo": "densar",
    "densáramos": "densar",
    "densárei": "densar",
    "densáreis": "densar",
    "densásseis": "densar",
    "densássemos": "densar",
    "densávamo": "densar",
    "densávamos": "densar",
    "densávei": "densar",
    "densáveis": "densar",
    "densímetros": "densímetro",
    "denta": "dentar",
    "dentada": "dentar",
    "dentadas": "dentar",
    "dentadinha": "dentada",
    "dentadinhas": "dentada",
    "dentadita": "dentada",
    "dentaditas": "dentada",
    "dentado": "dentar",
    "dentados": "dentar",
    "dentaduras": "dentadura",
    "dentai": "dentar",
    "dentais": "dentar",
    "dentalgias": "dentalgia",
    "dentam": "dentar",
    "dentamo": "dentar",
    "dentamos": "dentar",
    "dentando": "dentar",
    "dentara": "dentar",
    "dentaram": "dentar",
    "dentaras": "dentar",
    "dentarde": "dentar",
    "dentardes": "dentar",
    "dentare": "dentar",
    "dentarei": "dentar",
    "dentareis": "dentar",
    "dentarem": "dentar",
    "dentaremos": "dentar",
    "dentares": "dentar",
    "dentaria": "dentar",
    "dentariam": "dentar",
    "dentarias": "dentar",
    "dentarmo": "dentar",
    "dentarmos": "dentar",
    "dentará": "dentar",
    "dentarás": "dentar",
    "dentarão": "dentar",
    "dentaríamos": "dentar",
    "dentaríeis": "dentar",
    "dentas": "dentar",
    "dentasse": "dentar",
    "dentassem": "dentar",
    "dentasses": "dentar",
    "dentaste": "dentar",
    "dentastes": "dentar",
    "dentava": "dentar",
    "dentavam": "dentar",
    "dentavas": "dentar",
    "dente": "dentar",
    "denteada": "dentear",
    "denteadas": "dentear",
    "denteado": "dentear",
    "denteados": "dentear",
    "denteai": "dentear",
    "denteais": "dentear",
    "denteamo": "dentear",
    "denteamos": "dentear",
    "denteando": "dentear",
    "denteara": "dentear",
    "dentearam": "dentear",
    "dentearas": "dentear",
    "dentearde": "dentear",
    "denteardes": "dentear",
    "denteare": "dentear",
    "dentearei": "dentear",
    "denteareis": "dentear",
    "dentearem": "dentear",
    "dentearemos": "dentear",
    "denteares": "dentear",
    "dentearia": "dentear",
    "denteariam": "dentear",
    "dentearias": "dentear",
    "dentearmo": "dentear",
    "dentearmos": "dentear",
    "denteará": "dentear",
    "dentearás": "dentear",
    "dentearão": "dentear",
    "dentearíamos": "dentear",
    "dentearíeis": "dentear",
    "denteasse": "dentear",
    "denteassem": "dentear",
    "denteasses": "dentear",
    "denteaste": "dentear",
    "denteastes": "dentear",
    "denteava": "dentear",
    "denteavam": "dentear",
    "denteavas": "dentear",
    "denteações": "denteação",
    "dentebruns": "dentebrum",
    "dentebruras": "dentebrura",
    "denteei": "dentear",
    "denteeis": "dentear",
    "denteemo": "dentear",
    "denteemos": "dentear",
    "dentei": "dentar",
    "denteia": "dentear",
    "denteiam": "dentear",
    "denteias": "dentear",
    "denteie": "dentear",
    "denteiem": "dentear",
    "denteies": "dentear",
    "denteio": "dentear",
    "denteiras": "denteira",
    "denteis": "dentar",
    "denteletes": "dentelete",
    "dentelhas": "dentelha",
    "dentelos": "dentelo",
    "dentelárias": "dentelária",
    "dentem": "dentar",
    "dentemo": "dentar",
    "dentemos": "dentar",
    "denteou": "dentear",
    "dentes": "dente",
    "denteá": "dentear",
    "denteámo": "dentear",
    "denteámos": "dentear",
    "denteáramo": "dentear",
    "denteáramos": "dentear",
    "denteárei": "dentear",
    "denteáreis": "dentear",
    "denteásseis": "dentear",
    "denteássemos": "dentear",
    "denteávamo": "dentear",
    "denteávamos": "dentear",
    "denteávei": "dentear",
    "denteáveis": "dentear",
    "denticulada": "denticulado",
    "denticuladas": "denticulado",
    "denticulados": "denticulado",
    "denticulares": "denticular",
    "denticórnea": "denticórneo",
    "denticórneas": "denticórneo",
    "denticórneos": "denticórneo",
    "dentiformes": "dentiforme",
    "dentifrícios": "dentifrício",
    "dentilabiais": "dentilabial",
    "dentilhas": "dentilha",
    "dentilhões": "dentilhão",
    "dentilárias": "dentilária",
    "dentinas": "dentina",
    "dentinho": "dente",
    "dentinhos": "dente",
    "dentirrostra": "dentirrostro",
    "dentirrostras": "dentirrostro",
    "dentirrostros": "dentirrostro",
    "dentistas": "dentista",
    "dentito": "dente",
    "dentitos": "dente",
    "dentições": "dentição",
    "dento": "dentar",
    "dentolabiais": "dentolabial",
    "dentolas": "dentola",
    "dentolinguais": "dentolingual",
    "dentoneiras": "dentoneira",
    "dentou": "dentar",
    "dentuda": "dentudo",
    "dentudas": "dentudo",
    "dentudos": "dentudo",
    "dentuças": "dentuça",
    "dentá": "dentar",
    "dentálios": "dentálio",
    "dentámo": "dentar",
    "dentámos": "dentar",
    "dentáramo": "dentar",
    "dentáramos": "dentar",
    "dentárei": "dentar",
    "dentáreis": "dentar",
    "dentária": "dentário",
    "dentárias": "dentário",
    "dentários": "dentário",
    "dentásseis": "dentar",
    "dentássemos": "dentar",
    "dentávamo": "dentar",
    "dentávamos": "dentar",
    "dentávei": "dentar",
    "dentáveis": "dentar",
    "dentéis": "dentel",
    "dentículos": "dentículo",
    "dentífrica": "dentífrico",
    "dentífricas": "dentífrico",
    "dentífricos": "dentífrico",
    "dentígera": "dentígero",
    "dentígeras": "dentígero",
    "dentígeros": "dentígero",
    "dentípodes": "dentípode",
    "dentões": "dentão",
    "denuda": "denudar",
    "denudada": "denudar",
    "denudadas": "denudar",
    "denudado": "denudar",
    "denudados": "denudar",
    "denudai": "denudar",
    "denudais": "denudar",
    "denudam": "denudar",
    "denudamo": "denudar",
    "denudamos": "denudar",
    "denudando": "denudar",
    "denudara": "denudar",
    "denudaram": "denudar",
    "denudaras": "denudar",
    "denudarde": "denudar",
    "denudardes": "denudar",
    "denudare": "denudar",
    "denudarei": "denudar",
    "denudareis": "denudar",
    "denudarem": "denudar",
    "denudaremos": "denudar",
    "denudares": "denudar",
    "denudaria": "denudar",
    "denudariam": "denudar",
    "denudarias": "denudar",
    "denudarmo": "denudar",
    "denudarmos": "denudar",
    "denudará": "denudar",
    "denudarás": "denudar",
    "denudarão": "denudar",
    "denudaríamos": "denudar",
    "denudaríeis": "denudar",
    "denudas": "denudar",
    "denudasse": "denudar",
    "denudassem": "denudar",
    "denudasses": "denudar",
    "denudaste": "denudar",
    "denudastes": "denudar",
    "denudava": "denudar",
    "denudavam": "denudar",
    "denudavas": "denudar",
    "denudações": "denudação",
    "denude": "denudar",
    "denudei": "denudar",
    "denudeis": "denudar",
    "denudem": "denudar",
    "denudemo": "denudar",
    "denudemos": "denudar",
    "denudes": "denudar",
    "denudo": "denudar",
    "denudou": "denudar",
    "denudá": "denudar",
    "denudámo": "denudar",
    "denudámos": "denudar",
    "denudáramo": "denudar",
    "denudáramos": "denudar",
    "denudárei": "denudar",
    "denudáreis": "denudar",
    "denudásseis": "denudar",
    "denudássemos": "denudar",
    "denudávamo": "denudar",
    "denudávamos": "denudar",
    "denudávei": "denudar",
    "denudáveis": "denudar",
    "denuncia": "denunciar",
    "denunciada": "denunciar",
    "denunciadas": "denunciar",
    "denunciado": "denunciar",
    "denunciadora": "denunciador",
    "denunciadoras": "denunciador",
    "denunciadores": "denunciador",
    "denunciados": "denunciar",
    "denunciai": "denunciar",
    "denunciais": "denunciar",
    "denunciam": "denunciar",
    "denunciamo": "denunciar",
    "denunciamos": "denunciar",
    "denunciando": "denunciar",
    "denunciantes": "denunciante",
    "denunciara": "denunciar",
    "denunciaram": "denunciar",
    "denunciaras": "denunciar",
    "denunciarde": "denunciar",
    "denunciardes": "denunciar",
    "denunciare": "denunciar",
    "denunciarei": "denunciar",
    "denunciareis": "denunciar",
    "denunciarem": "denunciar",
    "denunciaremos": "denunciar",
    "denunciares": "denunciar",
    "denunciaria": "denunciar",
    "denunciariam": "denunciar",
    "denunciarias": "denunciar",
    "denunciarmo": "denunciar",
    "denunciarmos": "denunciar",
    "denunciará": "denunciar",
    "denunciarás": "denunciar",
    "denunciarão": "denunciar",
    "denunciaríamos": "denunciar",
    "denunciaríeis": "denunciar",
    "denuncias": "denunciar",
    "denunciasse": "denunciar",
    "denunciassem": "denunciar",
    "denunciasses": "denunciar",
    "denunciaste": "denunciar",
    "denunciastes": "denunciar",
    "denunciativa": "denunciativo",
    "denunciativas": "denunciativo",
    "denunciativos": "denunciativo",
    "denunciatória": "denunciatório",
    "denunciatórias": "denunciatório",
    "denunciatórios": "denunciatório",
    "denunciava": "denunciar",
    "denunciavam": "denunciar",
    "denunciavas": "denunciar",
    "denunciações": "denunciação",
    "denuncie": "denunciar",
    "denunciei": "denunciar",
    "denuncieis": "denunciar",
    "denunciem": "denunciar",
    "denunciemo": "denunciar",
    "denunciemos": "denunciar",
    "denuncies": "denunciar",
    "denuncio": "denunciar",
    "denunciou": "denunciar",
    "denunciá": "denunciar",
    "denunciámo": "denunciar",
    "denunciámos": "denunciar",
    "denunciáramo": "denunciar",
    "denunciáramos": "denunciar",
    "denunciárei": "denunciar",
    "denunciáreis": "denunciar",
    "denunciásseis": "denunciar",
    "denunciássemos": "denunciar",
    "denunciávamo": "denunciar",
    "denunciávamos": "denunciar",
    "denunciávei": "denunciar",
    "denunciáveis": "denunciável",
    "denuntrientes": "denuntriente",
    "denutra": "denutrir",
    "denutrais": "denutrir",
    "denutram": "denutrir",
    "denutramo": "denutrir",
    "denutramos": "denutrir",
    "denutras": "denutrir",
    "denutre": "denutrir",
    "denutrem": "denutrir",
    "denutres": "denutrir",
    "denutri": "denutrir",
    "denutria": "denutrir",
    "denutriam": "denutrir",
    "denutrias": "denutrir",
    "denutrida": "denutrir",
    "denutridas": "denutrir",
    "denutrido": "denutrir",
    "denutridos": "denutrir",
    "denutrimo": "denutrir",
    "denutrimos": "denutrir",
    "denutrindo": "denutrir",
    "denutrira": "denutrir",
    "denutriram": "denutrir",
    "denutriras": "denutrir",
    "denutrirde": "denutrir",
    "denutrirdes": "denutrir",
    "denutrire": "denutrir",
    "denutrirei": "denutrir",
    "denutrireis": "denutrir",
    "denutrirem": "denutrir",
    "denutriremos": "denutrir",
    "denutrires": "denutrir",
    "denutriria": "denutrir",
    "denutririam": "denutrir",
    "denutririas": "denutrir",
    "denutrirmo": "denutrir",
    "denutrirmos": "denutrir",
    "denutrirá": "denutrir",
    "denutrirás": "denutrir",
    "denutrirão": "denutrir",
    "denutriríamos": "denutrir",
    "denutriríeis": "denutrir",
    "denutris": "denutrir",
    "denutrisse": "denutrir",
    "denutrissem": "denutrir",
    "denutrisses": "denutrir",
    "denutriste": "denutrir",
    "denutristes": "denutrir",
    "denutriu": "denutrir",
    "denutrições": "denutrição",
    "denutro": "denutrir",
    "denutruida": "denutruido",
    "denutruidas": "denutruido",
    "denutruidos": "denutruido",
    "denutríamo": "denutrir",
    "denutríamos": "denutrir",
    "denutríei": "denutrir",
    "denutríeis": "denutrir",
    "denutríramo": "denutrir",
    "denutríramos": "denutrir",
    "denutrírei": "denutrir",
    "denutríreis": "denutrir",
    "denutrísseis": "denutrir",
    "denutríssemos": "denutrir",
    "denária": "denário",
    "denárias": "denário",
    "denários": "denário",
    "denúncias": "denúncia",
    "deodáctila": "deodáctilo",
    "deodáctilas": "deodáctilo",
    "deodáctilos": "deodáctilo",
    "deontologias": "deontologia",
    "deontologismos": "deontologismo",
    "deontológica": "deontológico",
    "deontológicas": "deontológico",
    "deontológicos": "deontológico",
    "deoperculada": "deoperculado",
    "deoperculadas": "deoperculado",
    "deoperculados": "deoperculado",
    "depara": "deparar",
    "deparada": "deparar",
    "deparadas": "deparar",
    "deparado": "deparar",
    "deparadora": "deparador",
    "deparadoras": "deparador",
    "deparadores": "deparador",
    "deparados": "deparar",
    "deparai": "deparar",
    "deparais": "deparar",
    "deparam": "deparar",
    "deparamo": "deparar",
    "deparamos": "deparar",
    "deparando": "deparar",
    "deparara": "deparar",
    "depararam": "deparar",
    "depararas": "deparar",
    "depararde": "deparar",
    "deparardes": "deparar",
    "deparare": "deparar",
    "depararei": "deparar",
    "deparareis": "deparar",
    "depararem": "deparar",
    "depararemos": "deparar",
    "deparares": "deparar",
    "depararia": "deparar",
    "deparariam": "deparar",
    "depararias": "deparar",
    "depararmo": "deparar",
    "depararmos": "deparar",
    "deparará": "deparar",
    "depararás": "deparar",
    "depararão": "deparar",
    "depararíamos": "deparar",
    "depararíeis": "deparar",
    "deparas": "deparar",
    "deparasse": "deparar",
    "deparassem": "deparar",
    "deparasses": "deparar",
    "deparaste": "deparar",
    "deparastes": "deparar",
    "deparava": "deparar",
    "deparavam": "deparar",
    "deparavas": "deparar",
    "depare": "deparar",
    "deparei": "deparar",
    "depareis": "deparar",
    "deparem": "deparar",
    "deparemo": "deparar",
    "deparemos": "deparar",
    "depares": "deparar",
    "deparo": "deparar",
    "deparou": "deparar",
    "departa": "departir",
    "departais": "departir",
    "departam": "departir",
    "departamentais": "departamental",
    "departamentos": "departamento",
    "departamo": "departir",
    "departamos": "departir",
    "departas": "departir",
    "departe": "departir",
    "departem": "departir",
    "departes": "departir",
    "departi": "departir",
    "departia": "departir",
    "departiam": "departir",
    "departias": "departir",
    "departida": "departir",
    "departidas": "departir",
    "departido": "departir",
    "departidos": "departir",
    "departimentos": "departimento",
    "departimo": "departir",
    "departimos": "departir",
    "departindo": "departir",
    "departira": "departir",
    "departiram": "departir",
    "departiras": "departir",
    "departirde": "departir",
    "departirdes": "departir",
    "departire": "departir",
    "departirei": "departir",
    "departireis": "departir",
    "departirem": "departir",
    "departiremos": "departir",
    "departires": "departir",
    "departiria": "departir",
    "departiriam": "departir",
    "departirias": "departir",
    "departirmo": "departir",
    "departirmos": "departir",
    "departirá": "departir",
    "departirás": "departir",
    "departirão": "departir",
    "departiríamos": "departir",
    "departiríeis": "departir",
    "departis": "departir",
    "departisse": "departir",
    "departissem": "departir",
    "departisses": "departir",
    "departiste": "departir",
    "departistes": "departir",
    "departiu": "departir",
    "departições": "departição",
    "departo": "departir",
    "departíamo": "departir",
    "departíamos": "departir",
    "departíei": "departir",
    "departíeis": "departir",
    "departíramo": "departir",
    "departíramos": "departir",
    "departírei": "departir",
    "departíreis": "departir",
    "departísseis": "departir",
    "departíssemos": "departir",
    "depará": "deparar",
    "deparámo": "deparar",
    "deparámos": "deparar",
    "deparáramo": "deparar",
    "deparáramos": "deparar",
    "deparárei": "deparar",
    "deparáreis": "deparar",
    "deparásseis": "deparar",
    "deparássemos": "deparar",
    "deparávamo": "deparar",
    "deparávamos": "deparar",
    "deparávei": "deparar",
    "deparáveis": "deparável",
    "depascentes": "depascente",
    "depaupera": "depauperar",
    "depauperada": "depauperar",
    "depauperadas": "depauperar",
    "depauperado": "depauperar",
    "depauperadora": "depauperador",
    "depauperadoras": "depauperador",
    "depauperadores": "depauperador",
    "depauperados": "depauperar",
    "depauperai": "depauperar",
    "depauperais": "depauperar",
    "depauperam": "depauperar",
    "depauperamentos": "depauperamento",
    "depauperamo": "depauperar",
    "depauperamos": "depauperar",
    "depauperando": "depauperar",
    "depauperantes": "depauperante",
    "depauperara": "depauperar",
    "depauperaram": "depauperar",
    "depauperaras": "depauperar",
    "depauperarde": "depauperar",
    "depauperardes": "depauperar",
    "depauperare": "depauperar",
    "depauperarei": "depauperar",
    "depauperareis": "depauperar",
    "depauperarem": "depauperar",
    "depauperaremos": "depauperar",
    "depauperares": "depauperar",
    "depauperaria": "depauperar",
    "depauperariam": "depauperar",
    "depauperarias": "depauperar",
    "depauperarmo": "depauperar",
    "depauperarmos": "depauperar",
    "depauperará": "depauperar",
    "depauperarás": "depauperar",
    "depauperarão": "depauperar",
    "depauperaríamos": "depauperar",
    "depauperaríeis": "depauperar",
    "depauperas": "depauperar",
    "depauperasse": "depauperar",
    "depauperassem": "depauperar",
    "depauperasses": "depauperar",
    "depauperaste": "depauperar",
    "depauperastes": "depauperar",
    "depauperava": "depauperar",
    "depauperavam": "depauperar",
    "depauperavas": "depauperar",
    "depauperações": "depauperação",
    "depaupere": "depauperar",
    "depauperei": "depauperar",
    "depaupereis": "depauperar",
    "depauperem": "depauperar",
    "depauperemo": "depauperar",
    "depauperemos": "depauperar",
    "depauperes": "depauperar",
    "depaupero": "depauperar",
    "depauperou": "depauperar",
    "depauperá": "depauperar",
    "depauperámo": "depauperar",
    "depauperámos": "depauperar",
    "depauperáramo": "depauperar",
    "depauperáramos": "depauperar",
    "depauperárei": "depauperar",
    "depauperáreis": "depauperar",
    "depauperásseis": "depauperar",
    "depauperássemos": "depauperar",
    "depauperávamo": "depauperar",
    "depauperávamos": "depauperar",
    "depauperávei": "depauperar",
    "depauperáveis": "depauperar",
    "depena": "depenar",
    "depenada": "depenar",
    "depenadas": "depenar",
    "depenadinha": "depenado",
    "depenadinhas": "depenado",
    "depenadinho": "depenado",
    "depenadinhos": "depenado",
    "depenadita": "depenado",
    "depenaditas": "depenado",
    "depenadito": "depenado",
    "depenaditos": "depenado",
    "depenado": "depenar",
    "depenados": "depenar",
    "depenai": "depenar",
    "depenais": "depenar",
    "depenam": "depenar",
    "depenamo": "depenar",
    "depenamos": "depenar",
    "depenando": "depenar",
    "depenara": "depenar",
    "depenaram": "depenar",
    "depenaras": "depenar",
    "depenarde": "depenar",
    "depenardes": "depenar",
    "depenare": "depenar",
    "depenarei": "depenar",
    "depenareis": "depenar",
    "depenarem": "depenar",
    "depenaremos": "depenar",
    "depenares": "depenar",
    "depenaria": "depenar",
    "depenariam": "depenar",
    "depenarias": "depenar",
    "depenarmo": "depenar",
    "depenarmos": "depenar",
    "depenará": "depenar",
    "depenarás": "depenar",
    "depenarão": "depenar",
    "depenaríamos": "depenar",
    "depenaríeis": "depenar",
    "depenas": "depenar",
    "depenasse": "depenar",
    "depenassem": "depenar",
    "depenasses": "depenar",
    "depenaste": "depenar",
    "depenastes": "depenar",
    "depenava": "depenar",
    "depenavam": "depenar",
    "depenavas": "depenar",
    "dependa": "depender",
    "dependais": "depender",
    "dependam": "depender",
    "dependamo": "depender",
    "dependamos": "depender",
    "dependas": "depender",
    "depende": "depender",
    "dependei": "depender",
    "dependeis": "depender",
    "dependem": "depender",
    "dependemo": "depender",
    "dependemos": "depender",
    "dependendo": "depender",
    "dependentes": "dependente",
    "dependera": "depender",
    "dependeram": "depender",
    "dependeras": "depender",
    "dependerdes": "depender",
    "dependerei": "depender",
    "dependereis": "depender",
    "dependerem": "depender",
    "dependeremos": "depender",
    "dependeres": "depender",
    "dependeria": "depender",
    "dependeriam": "depender",
    "dependerias": "depender",
    "dependermo": "depender",
    "dependermos": "depender",
    "dependerá": "depender",
    "dependerás": "depender",
    "dependerão": "depender",
    "dependeríamos": "depender",
    "dependeríeis": "depender",
    "dependes": "depender",
    "dependesse": "depender",
    "dependessem": "depender",
    "dependesses": "depender",
    "dependeste": "depender",
    "dependestes": "depender",
    "dependeu": "depender",
    "dependi": "depender",
    "dependia": "depender",
    "dependiam": "depender",
    "dependias": "depender",
    "dependida": "depender",
    "dependidas": "depender",
    "dependido": "depender",
    "dependidos": "depender",
    "dependo": "depender",
    "dependura": "dependurar",
    "dependurada": "dependurar",
    "dependuradas": "dependurar",
    "dependurado": "dependurar",
    "dependurados": "dependurar",
    "dependurai": "dependurar",
    "dependurais": "dependurar",
    "dependuram": "dependurar",
    "dependuramo": "dependurar",
    "dependuramos": "dependurar",
    "dependurando": "dependurar",
    "dependurara": "dependurar",
    "dependuraram": "dependurar",
    "dependuraras": "dependurar",
    "dependurarde": "dependurar",
    "dependurardes": "dependurar",
    "dependurare": "dependurar",
    "dependurarei": "dependurar",
    "dependurareis": "dependurar",
    "dependurarem": "dependurar",
    "dependuraremos": "dependurar",
    "dependurares": "dependurar",
    "dependuraria": "dependurar",
    "dependurariam": "dependurar",
    "dependurarias": "dependurar",
    "dependurarmo": "dependurar",
    "dependurarmos": "dependurar",
    "dependurará": "dependurar",
    "dependurarás": "dependurar",
    "dependurarão": "dependurar",
    "dependuraríamos": "dependurar",
    "dependuraríeis": "dependurar",
    "dependuras": "dependurar",
    "dependurasse": "dependurar",
    "dependurassem": "dependurar",
    "dependurasses": "dependurar",
    "dependuraste": "dependurar",
    "dependurastes": "dependurar",
    "dependurava": "dependurar",
    "dependuravam": "dependurar",
    "dependuravas": "dependurar",
    "dependure": "dependurar",
    "dependurei": "dependurar",
    "dependureis": "dependurar",
    "dependurem": "dependurar",
    "dependuremo": "dependurar",
    "dependuremos": "dependurar",
    "dependures": "dependurar",
    "dependuro": "dependurar",
    "dependurou": "dependurar",
    "dependurá": "dependurar",
    "dependurámo": "dependurar",
    "dependurámos": "dependurar",
    "dependuráramo": "dependurar",
    "dependuráramos": "dependurar",
    "dependurárei": "dependurar",
    "dependuráreis": "dependurar",
    "dependurásseis": "dependurar",
    "dependurássemos": "dependurar",
    "dependurávamo": "dependurar",
    "dependurávamos": "dependurar",
    "dependurávei": "dependurar",
    "dependuráveis": "dependurável",
    "dependências": "dependência",
    "dependêramo": "depender",
    "dependêramos": "depender",
    "dependêreis": "depender",
    "dependêsseis": "depender",
    "dependêssemos": "depender",
    "dependíamo": "depender",
    "dependíamos": "depender",
    "dependíeis": "depender",
    "depene": "depenar",
    "depenei": "depenar",
    "depeneis": "depenar",
    "depenem": "depenar",
    "depenemo": "depenar",
    "depenemos": "depenar",
    "depenes": "depenar",
    "depenica": "depenicar",
    "depenicada": "depenicar",
    "depenicadas": "depenicar",
    "depenicado": "depenicar",
    "depenicados": "depenicar",
    "depenicai": "depenicar",
    "depenicais": "depenicar",
    "depenicam": "depenicar",
    "depenicamo": "depenicar",
    "depenicamos": "depenicar",
    "depenicando": "depenicar",
    "depenicara": "depenicar",
    "depenicaram": "depenicar",
    "depenicaras": "depenicar",
    "depenicarde": "depenicar",
    "depenicardes": "depenicar",
    "depenicare": "depenicar",
    "depenicarei": "depenicar",
    "depenicareis": "depenicar",
    "depenicarem": "depenicar",
    "depenicaremos": "depenicar",
    "depenicares": "depenicar",
    "depenicaria": "depenicar",
    "depenicariam": "depenicar",
    "depenicarias": "depenicar",
    "depenicarmo": "depenicar",
    "depenicarmos": "depenicar",
    "depenicará": "depenicar",
    "depenicarás": "depenicar",
    "depenicarão": "depenicar",
    "depenicaríamos": "depenicar",
    "depenicaríeis": "depenicar",
    "depenicas": "depenicar",
    "depenicasse": "depenicar",
    "depenicassem": "depenicar",
    "depenicasses": "depenicar",
    "depenicaste": "depenicar",
    "depenicastes": "depenicar",
    "depenicava": "depenicar",
    "depenicavam": "depenicar",
    "depenicavas": "depenicar",
    "depenico": "depenicar",
    "depenicou": "depenicar",
    "depenicá": "depenicar",
    "depenicámo": "depenicar",
    "depenicámos": "depenicar",
    "depenicáramo": "depenicar",
    "depenicáramos": "depenicar",
    "depenicárei": "depenicar",
    "depenicáreis": "depenicar",
    "depenicásseis": "depenicar",
    "depenicássemos": "depenicar",
    "depenicávamo": "depenicar",
    "depenicávamos": "depenicar",
    "depenicávei": "depenicar",
    "depenicáveis": "depenicar",
    "depenique": "depenicar",
    "depeniquei": "depenicar",
    "depeniqueis": "depenicar",
    "depeniquem": "depenicar",
    "depeniquemo": "depenicar",
    "depeniquemos": "depenicar",
    "depeniques": "depenicar",
    "depeno": "depenar",
    "depenomanias": "depenomania",
    "depenou": "depenar",
    "depená": "depenar",
    "depenámo": "depenar",
    "depenámos": "depenar",
    "depenáramo": "depenar",
    "depenáramos": "depenar",
    "depenárei": "depenar",
    "depenáreis": "depenar",
    "depenásseis": "depenar",
    "depenássemos": "depenar",
    "depenávamo": "depenar",
    "depenávamos": "depenar",
    "depenávei": "depenar",
    "depenáveis": "depenar",
    "deperda": "deperder",
    "deperdais": "deperder",
    "deperdam": "deperder",
    "deperdamo": "deperder",
    "deperdamos": "deperder",
    "deperdas": "deperder",
    "deperde": "deperder",
    "deperdei": "deperder",
    "deperdeis": "deperder",
    "deperdem": "deperder",
    "deperdemo": "deperder",
    "deperdemos": "deperder",
    "deperdendo": "deperder",
    "deperdera": "deperder",
    "deperderam": "deperder",
    "deperderas": "deperder",
    "deperderde": "deperder",
    "deperderdes": "deperder",
    "deperdere": "deperder",
    "deperderei": "deperder",
    "deperdereis": "deperder",
    "deperderem": "deperder",
    "deperderemos": "deperder",
    "deperderes": "deperder",
    "deperderia": "deperder",
    "deperderiam": "deperder",
    "deperderias": "deperder",
    "deperdermo": "deperder",
    "deperdermos": "deperder",
    "deperderá": "deperder",
    "deperderás": "deperder",
    "deperderão": "deperder",
    "deperderíamos": "deperder",
    "deperderíeis": "deperder",
    "deperdes": "deperder",
    "deperdesse": "deperder",
    "deperdessem": "deperder",
    "deperdesses": "deperder",
    "deperdeste": "deperder",
    "deperdestes": "deperder",
    "deperdeu": "deperder",
    "deperdi": "deperder",
    "deperdia": "deperder",
    "deperdiam": "deperder",
    "deperdias": "deperder",
    "deperdida": "deperder",
    "deperdidas": "deperder",
    "deperdido": "deperder",
    "deperdidos": "deperder",
    "deperdo": "deperder",
    "deperdê": "deperder",
    "deperdêramo": "deperder",
    "deperdêramos": "deperder",
    "deperdêrei": "deperder",
    "deperdêreis": "deperder",
    "deperdêsseis": "deperder",
    "deperdêssemos": "deperder",
    "deperdíamo": "deperder",
    "deperdíamos": "deperder",
    "deperdíei": "deperder",
    "deperdíeis": "deperder",
    "deperece": "deperecer",
    "deperecei": "deperecer",
    "depereceis": "deperecer",
    "deperecem": "deperecer",
    "deperecemo": "deperecer",
    "deperecemos": "deperecer",
    "deperecendo": "deperecer",
    "deperecera": "deperecer",
    "depereceram": "deperecer",
    "depereceras": "deperecer",
    "deperecerdes": "deperecer",
    "deperecerei": "deperecer",
    "deperecereis": "deperecer",
    "deperecerem": "deperecer",
    "depereceremos": "deperecer",
    "depereceres": "deperecer",
    "depereceria": "deperecer",
    "depereceriam": "deperecer",
    "deperecerias": "deperecer",
    "deperecermo": "deperecer",
    "deperecermos": "deperecer",
    "deperecerá": "deperecer",
    "deperecerás": "deperecer",
    "deperecerão": "deperecer",
    "depereceríamos": "deperecer",
    "depereceríeis": "deperecer",
    "depereces": "deperecer",
    "deperecesse": "deperecer",
    "deperecessem": "deperecer",
    "deperecesses": "deperecer",
    "depereceste": "deperecer",
    "deperecestes": "deperecer",
    "depereceu": "deperecer",
    "depereci": "deperecer",
    "deperecia": "deperecer",
    "depereciam": "deperecer",
    "deperecias": "deperecer",
    "deperecida": "deperecer",
    "deperecidas": "deperecer",
    "deperecido": "deperecer",
    "deperecidos": "deperecer",
    "deperecimentos": "deperecimento",
    "deperecêramo": "deperecer",
    "deperecêramos": "deperecer",
    "deperecêreis": "deperecer",
    "deperecêsseis": "deperecer",
    "deperecêssemos": "deperecer",
    "deperecíamo": "deperecer",
    "deperecíamos": "deperecer",
    "deperecíeis": "deperecer",
    "depereça": "deperecer",
    "depereçais": "deperecer",
    "depereçam": "deperecer",
    "depereçamo": "deperecer",
    "depereçamos": "deperecer",
    "depereças": "deperecer",
    "depereço": "deperecer",
    "depila": "depilar",
    "depilada": "depilar",
    "depiladas": "depilar",
    "depilado": "depilar",
    "depiladora": "depilador",
    "depiladoras": "depilador",
    "depiladores": "depilador",
    "depilados": "depilar",
    "depilai": "depilar",
    "depilais": "depilar",
    "depilam": "depilar",
    "depilamo": "depilar",
    "depilamos": "depilar",
    "depilando": "depilar",
    "depilara": "depilar",
    "depilaram": "depilar",
    "depilaras": "depilar",
    "depilarde": "depilar",
    "depilardes": "depilar",
    "depilare": "depilar",
    "depilarei": "depilar",
    "depilareis": "depilar",
    "depilarem": "depilar",
    "depilaremos": "depilar",
    "depilares": "depilar",
    "depilaria": "depilar",
    "depilariam": "depilar",
    "depilarias": "depilar",
    "depilarmo": "depilar",
    "depilarmos": "depilar",
    "depilará": "depilar",
    "depilarás": "depilar",
    "depilarão": "depilar",
    "depilaríamos": "depilar",
    "depilaríeis": "depilar",
    "depilas": "depilar",
    "depilasse": "depilar",
    "depilassem": "depilar",
    "depilasses": "depilar",
    "depilaste": "depilar",
    "depilastes": "depilar",
    "depilatória": "depilatório",
    "depilatórias": "depilatório",
    "depilatórios": "depilatório",
    "depilava": "depilar",
    "depilavam": "depilar",
    "depilavas": "depilar",
    "depilações": "depilação",
    "depile": "depilar",
    "depilei": "depilar",
    "depileis": "depilar",
    "depilem": "depilar",
    "depilemo": "depilar",
    "depilemos": "depilar",
    "depiles": "depilar",
    "depilo": "depilar",
    "depilou": "depilar",
    "depilá": "depilar",
    "depilámo": "depilar",
    "depilámos": "depilar",
    "depiláramo": "depilar",
    "depiláramos": "depilar",
    "depilárei": "depilar",
    "depiláreis": "depilar",
    "depilásseis": "depilar",
    "depilássemos": "depilar",
    "depilávamo": "depilar",
    "depilávamos": "depilar",
    "depilávei": "depilar",
    "depiláveis": "depilar",
    "depletiva": "depletivo",
    "depletivas": "depletivo",
    "depletivos": "depletivo",
    "depleções": "depleção",
    "deplora": "deplorar",
    "deplorada": "deplorar",
    "deploradas": "deplorar",
    "deplorado": "deplorar",
    "deploradora": "deplorador",
    "deploradoras": "deplorador",
    "deploradores": "deplorador",
    "deplorados": "deplorar",
    "deplorai": "deplorar",
    "deplorais": "deplorar",
    "deploram": "deplorar",
    "deploramo": "deplorar",
    "deploramos": "deplorar",
    "deploranda": "deplorando",
    "deplorandas": "deplorando",
    "deplorando": "deplorar",
    "deplorandos": "deplorando",
    "deplorara": "deplorar",
    "deploraram": "deplorar",
    "deploraras": "deplorar",
    "deplorarde": "deplorar",
    "deplorardes": "deplorar",
    "deplorare": "deplorar",
    "deplorarei": "deplorar",
    "deplorareis": "deplorar",
    "deplorarem": "deplorar",
    "deploraremos": "deplorar",
    "deplorares": "deplorar",
    "deploraria": "deplorar",
    "deplorariam": "deplorar",
    "deplorarias": "deplorar",
    "deplorarmo": "deplorar",
    "deplorarmos": "deplorar",
    "deplorará": "deplorar",
    "deplorarás": "deplorar",
    "deplorarão": "deplorar",
    "deploraríamos": "deplorar",
    "deploraríeis": "deplorar",
    "deploras": "deplorar",
    "deplorasse": "deplorar",
    "deplorassem": "deplorar",
    "deplorasses": "deplorar",
    "deploraste": "deplorar",
    "deplorastes": "deplorar",
    "deplorativa": "deplorativo",
    "deplorativas": "deplorativo",
    "deplorativos": "deplorativo",
    "deploratória": "deploratório",
    "deploratórias": "deploratório",
    "deploratórios": "deploratório",
    "deplorava": "deplorar",
    "deploravam": "deplorar",
    "deploravas": "deplorar",
    "deplorações": "deploração",
    "deplore": "deplorar",
    "deplorei": "deplorar",
    "deploreis": "deplorar",
    "deplorem": "deplorar",
    "deploremo": "deplorar",
    "deploremos": "deplorar",
    "deplores": "deplorar",
    "deploro": "deplorar",
    "deplorou": "deplorar",
    "deplorá": "deplorar",
    "deplorámo": "deplorar",
    "deplorámos": "deplorar",
    "deploráramo": "deplorar",
    "deploráramos": "deplorar",
    "deplorárei": "deplorar",
    "deploráreis": "deplorar",
    "deplorásseis": "deplorar",
    "deplorássemos": "deplorar",
    "deplorávamo": "deplorar",
    "deplorávamos": "deplorar",
    "deplorávei": "deplorar",
    "deploráveis": "deplorável",
    "depluma": "deplumar",
    "deplumada": "deplumar",
    "deplumadas": "deplumar",
    "deplumado": "deplumar",
    "deplumados": "deplumar",
    "deplumai": "deplumar",
    "deplumais": "deplumar",
    "deplumam": "deplumar",
    "deplumamo": "deplumar",
    "deplumamos": "deplumar",
    "deplumando": "deplumar",
    "deplumara": "deplumar",
    "deplumaram": "deplumar",
    "deplumaras": "deplumar",
    "deplumarde": "deplumar",
    "deplumardes": "deplumar",
    "deplumare": "deplumar",
    "deplumarei": "deplumar",
    "deplumareis": "deplumar",
    "deplumarem": "deplumar",
    "deplumaremos": "deplumar",
    "deplumares": "deplumar",
    "deplumaria": "deplumar",
    "deplumariam": "deplumar",
    "deplumarias": "deplumar",
    "deplumarmo": "deplumar",
    "deplumarmos": "deplumar",
    "deplumará": "deplumar",
    "deplumarás": "deplumar",
    "deplumarão": "deplumar",
    "deplumaríamos": "deplumar",
    "deplumaríeis": "deplumar",
    "deplumas": "deplumar",
    "deplumasse": "deplumar",
    "deplumassem": "deplumar",
    "deplumasses": "deplumar",
    "deplumaste": "deplumar",
    "deplumastes": "deplumar",
    "deplumava": "deplumar",
    "deplumavam": "deplumar",
    "deplumavas": "deplumar",
    "deplume": "deplumar",
    "deplumei": "deplumar",
    "deplumeis": "deplumar",
    "deplumem": "deplumar",
    "deplumemo": "deplumar",
    "deplumemos": "deplumar",
    "deplumes": "deplumar",
    "deplumo": "deplumar",
    "deplumou": "deplumar",
    "deplumá": "deplumar",
    "deplumámo": "deplumar",
    "deplumámos": "deplumar",
    "deplumáramo": "deplumar",
    "deplumáramos": "deplumar",
    "deplumárei": "deplumar",
    "deplumáreis": "deplumar",
    "deplumásseis": "deplumar",
    "deplumássemos": "deplumar",
    "deplumávamo": "deplumar",
    "deplumávamos": "deplumar",
    "deplumávei": "deplumar",
    "deplumáveis": "deplumar",
    "depoentes": "depoente",
    "depoimentos": "depoimento",
    "depolariza": "depolarizar",
    "depolarizada": "depolarizar",
    "depolarizadas": "depolarizar",
    "depolarizado": "depolarizar",
    "depolarizados": "depolarizar",
    "depolarizai": "depolarizar",
    "depolarizais": "depolarizar",
    "depolarizam": "depolarizar",
    "depolarizamo": "depolarizar",
    "depolarizamos": "depolarizar",
    "depolarizando": "depolarizar",
    "depolarizara": "depolarizar",
    "depolarizaram": "depolarizar",
    "depolarizaras": "depolarizar",
    "depolarizarde": "depolarizar",
    "depolarizardes": "depolarizar",
    "depolarizare": "depolarizar",
    "depolarizarei": "depolarizar",
    "depolarizareis": "depolarizar",
    "depolarizarem": "depolarizar",
    "depolarizaremos": "depolarizar",
    "depolarizares": "depolarizar",
    "depolarizaria": "depolarizar",
    "depolarizariam": "depolarizar",
    "depolarizarias": "depolarizar",
    "depolarizarmo": "depolarizar",
    "depolarizarmos": "depolarizar",
    "depolarizará": "depolarizar",
    "depolarizarás": "depolarizar",
    "depolarizarão": "depolarizar",
    "depolarizaríamos": "depolarizar",
    "depolarizaríeis": "depolarizar",
    "depolarizas": "depolarizar",
    "depolarizasse": "depolarizar",
    "depolarizassem": "depolarizar",
    "depolarizasses": "depolarizar",
    "depolarizaste": "depolarizar",
    "depolarizastes": "depolarizar",
    "depolarizava": "depolarizar",
    "depolarizavam": "depolarizar",
    "depolarizavas": "depolarizar",
    "depolarizações": "depolarização",
    "depolarize": "depolarizar",
    "depolarizei": "depolarizar",
    "depolarizeis": "depolarizar",
    "depolarizem": "depolarizar",
    "depolarizemo": "depolarizar",
    "depolarizemos": "depolarizar",
    "depolarizes": "depolarizar",
    "depolarizo": "depolarizar",
    "depolarizou": "depolarizar",
    "depolarizá": "depolarizar",
    "depolarizámo": "depolarizar",
    "depolarizámos": "depolarizar",
    "depolarizáramo": "depolarizar",
    "depolarizáramos": "depolarizar",
    "depolarizárei": "depolarizar",
    "depolarizáreis": "depolarizar",
    "depolarizásseis": "depolarizar",
    "depolarizássemos": "depolarizar",
    "depolarizávamo": "depolarizar",
    "depolarizávamos": "depolarizar",
    "depolarizávei": "depolarizar",
    "depolarizáveis": "depolarizar",
    "depomo": "depor",
    "depomos": "depor",
    "deponde": "depor",
    "depondes": "depor",
    "depondo": "depor",
    "deponha": "depor",
    "deponhais": "depor",
    "deponham": "depor",
    "deponhamo": "depor",
    "deponhamos": "depor",
    "deponhas": "depor",
    "deponho": "depor",
    "deponências": "deponência",
    "depopula": "depopular",
    "depopulada": "depopular",
    "depopuladas": "depopular",
    "depopulado": "depopular",
    "depopulados": "depopular",
    "depopulai": "depopular",
    "depopulais": "depopular",
    "depopulam": "depopular",
    "depopulamo": "depopular",
    "depopulamos": "depopular",
    "depopulando": "depopular",
    "depopulara": "depopular",
    "depopularam": "depopular",
    "depopularas": "depopular",
    "depopularde": "depopular",
    "depopulardes": "depopular",
    "depopulare": "depopular",
    "depopularei": "depopular",
    "depopulareis": "depopular",
    "depopularem": "depopular",
    "depopularemos": "depopular",
    "depopulares": "depopular",
    "depopularia": "depopular",
    "depopulariam": "depopular",
    "depopularias": "depopular",
    "depopularmo": "depopular",
    "depopularmos": "depopular",
    "depopulará": "depopular",
    "depopularás": "depopular",
    "depopularão": "depopular",
    "depopularíamos": "depopular",
    "depopularíeis": "depopular",
    "depopulas": "depopular",
    "depopulasse": "depopular",
    "depopulassem": "depopular",
    "depopulasses": "depopular",
    "depopulaste": "depopular",
    "depopulastes": "depopular",
    "depopulava": "depopular",
    "depopulavam": "depopular",
    "depopulavas": "depopular",
    "depopulações": "depopulação",
    "depopule": "depopular",
    "depopulei": "depopular",
    "depopuleis": "depopular",
    "depopulem": "depopular",
    "depopulemo": "depopular",
    "depopulemos": "depopular",
    "depopules": "depopular",
    "depopulo": "depopular",
    "depopulou": "depopular",
    "depopulá": "depopular",
    "depopulámo": "depopular",
    "depopulámos": "depopular",
    "depopuláramo": "depopular",
    "depopuláramos": "depopular",
    "depopulárei": "depopular",
    "depopuláreis": "depopular",
    "depopulásseis": "depopular",
    "depopulássemos": "depopular",
    "depopulávamo": "depopular",
    "depopulávamos": "depopular",
    "depopulávei": "depopular",
    "depopuláveis": "depopular",
    "deporde": "depor",
    "depordes": "depor",
    "depore": "depor",
    "deporei": "depor",
    "deporeis": "depor",
    "deporem": "depor",
    "deporemos": "depor",
    "depores": "depor",
    "deporia": "depor",
    "deporiam": "depor",
    "deporias": "depor",
    "depormo": "depor",
    "depormos": "depor",
    "deporta": "deportar",
    "deportada": "deportar",
    "deportadas": "deportar",
    "deportado": "deportar",
    "deportados": "deportar",
    "deportai": "deportar",
    "deportais": "deportar",
    "deportam": "deportar",
    "deportamo": "deportar",
    "deportamos": "deportar",
    "deportando": "deportar",
    "deportara": "deportar",
    "deportaram": "deportar",
    "deportaras": "deportar",
    "deportarde": "deportar",
    "deportardes": "deportar",
    "deportare": "deportar",
    "deportarei": "deportar",
    "deportareis": "deportar",
    "deportarem": "deportar",
    "deportaremos": "deportar",
    "deportares": "deportar",
    "deportaria": "deportar",
    "deportariam": "deportar",
    "deportarias": "deportar",
    "deportarmo": "deportar",
    "deportarmos": "deportar",
    "deportará": "deportar",
    "deportarás": "deportar",
    "deportarão": "deportar",
    "deportaríamos": "deportar",
    "deportaríeis": "deportar",
    "deportas": "deportar",
    "deportasse": "deportar",
    "deportassem": "deportar",
    "deportasses": "deportar",
    "deportaste": "deportar",
    "deportastes": "deportar",
    "deportava": "deportar",
    "deportavam": "deportar",
    "deportavas": "deportar",
    "deportações": "deportação",
    "deporte": "deportar",
    "deportei": "deportar",
    "deporteis": "deportar",
    "deportem": "deportar",
    "deportemo": "deportar",
    "deportemos": "deportar",
    "deportes": "deportar",
    "deporto": "deportar",
    "deportou": "deportar",
    "deportá": "deportar",
    "deportámo": "deportar",
    "deportámos": "deportar",
    "deportáramo": "deportar",
    "deportáramos": "deportar",
    "deportárei": "deportar",
    "deportáreis": "deportar",
    "deportásseis": "deportar",
    "deportássemos": "deportar",
    "deportávamo": "deportar",
    "deportávamos": "deportar",
    "deportávei": "deportar",
    "deportáveis": "deportável",
    "deporá": "depor",
    "deporás": "depor",
    "deporão": "depor",
    "deporíamos": "depor",
    "deporíeis": "depor",
    "deposita": "depositar",
    "depositada": "depositar",
    "depositadas": "depositar",
    "depositado": "depositar",
    "depositadora": "depositador",
    "depositadoras": "depositador",
    "depositadores": "depositador",
    "depositados": "depositar",
    "depositai": "depositar",
    "depositais": "depositar",
    "depositam": "depositar",
    "depositamo": "depositar",
    "depositamos": "depositar",
    "depositando": "depositar",
    "depositantes": "depositante",
    "depositara": "depositar",
    "depositaram": "depositar",
    "depositaras": "depositar",
    "depositarde": "depositar",
    "depositardes": "depositar",
    "depositare": "depositar",
    "depositarei": "depositar",
    "depositareis": "depositar",
    "depositarem": "depositar",
    "depositaremos": "depositar",
    "depositares": "depositar",
    "depositaria": "depositar",
    "depositariam": "depositar",
    "depositarias": "depositar",
    "depositarmo": "depositar",
    "depositarmos": "depositar",
    "depositará": "depositar",
    "depositarás": "depositar",
    "depositarão": "depositar",
    "depositaríamos": "depositar",
    "depositaríeis": "depositar",
    "depositas": "depositar",
    "depositasse": "depositar",
    "depositassem": "depositar",
    "depositasses": "depositar",
    "depositaste": "depositar",
    "depositastes": "depositar",
    "depositava": "depositar",
    "depositavam": "depositar",
    "depositavas": "depositar",
    "deposite": "depositar",
    "depositei": "depositar",
    "depositeis": "depositar",
    "depositem": "depositar",
    "depositemo": "depositar",
    "depositemos": "depositar",
    "deposites": "depositar",
    "deposito": "depositar",
    "depositou": "depositar",
    "depositá": "depositar",
    "depositámo": "depositar",
    "depositámos": "depositar",
    "depositáramo": "depositar",
    "depositáramos": "depositar",
    "depositárei": "depositar",
    "depositáreis": "depositar",
    "depositária": "depositário",
    "depositárias": "depositário",
    "depositários": "depositário",
    "depositásseis": "depositar",
    "depositássemos": "depositar",
    "depositávamo": "depositar",
    "depositávamos": "depositar",
    "depositávei": "depositar",
    "depositáveis": "depositável",
    "deposições": "deposição",
    "deposta": "deposto",
    "depostas": "deposto",
    "deposto": "depor",
    "depostos": "deposto",
    "depoências": "depoência",
    "deprava": "depravar",
    "depravada": "depravar",
    "depravadas": "depravar",
    "depravado": "depravar",
    "depravadora": "depravador",
    "depravadoras": "depravador",
    "depravadores": "depravador",
    "depravados": "depravar",
    "depravadíssima": "depravado",
    "depravadíssimas": "depravado",
    "depravadíssimo": "depravado",
    "depravadíssimos": "depravado",
    "depravai": "depravar",
    "depravais": "depravar",
    "depravam": "depravar",
    "depravamo": "depravar",
    "depravamos": "depravar",
    "depravando": "depravar",
    "depravara": "depravar",
    "depravaram": "depravar",
    "depravaras": "depravar",
    "depravarde": "depravar",
    "depravardes": "depravar",
    "depravare": "depravar",
    "depravarei": "depravar",
    "depravareis": "depravar",
    "depravarem": "depravar",
    "depravaremos": "depravar",
    "depravares": "depravar",
    "depravaria": "depravar",
    "depravariam": "depravar",
    "depravarias": "depravar",
    "depravarmo": "depravar",
    "depravarmos": "depravar",
    "depravará": "depravar",
    "depravarás": "depravar",
    "depravarão": "depravar",
    "depravaríamos": "depravar",
    "depravaríeis": "depravar",
    "depravas": "depravar",
    "depravasse": "depravar",
    "depravassem": "depravar",
    "depravasses": "depravar",
    "depravaste": "depravar",
    "depravastes": "depravar",
    "depravava": "depravar",
    "depravavam": "depravar",
    "depravavas": "depravar",
    "depravações": "depravação",
    "deprave": "depravar",
    "depravei": "depravar",
    "depraveis": "depravar",
    "depravem": "depravar",
    "depravemo": "depravar",
    "depravemos": "depravar",
    "depraves": "depravar",
    "depravo": "depravar",
    "depravou": "depravar",
    "depravá": "depravar",
    "depravámo": "depravar",
    "depravámos": "depravar",
    "depraváramo": "depravar",
    "depraváramos": "depravar",
    "depravárei": "depravar",
    "depraváreis": "depravar",
    "depravásseis": "depravar",
    "depravássemos": "depravar",
    "depravávamo": "depravar",
    "depravávamos": "depravar",
    "depravávei": "depravar",
    "depraváveis": "depravar",
    "deprecada": "deprecado",
    "deprecadas": "deprecado",
    "deprecados": "deprecado",
    "deprecantes": "deprecante",
    "deprecatas": "deprecata",
    "deprecativa": "deprecativo",
    "deprecativas": "deprecativo",
    "deprecativos": "deprecativo",
    "deprecatória": "deprecatório",
    "deprecatórias": "deprecatório",
    "deprecatórios": "deprecatório",
    "deprecações": "deprecação",
    "deprecia": "depreciar",
    "depreciada": "depreciar",
    "depreciadas": "depreciar",
    "depreciado": "depreciar",
    "depreciadora": "depreciador",
    "depreciadoras": "depreciador",
    "depreciadores": "depreciador",
    "depreciados": "depreciar",
    "depreciai": "depreciar",
    "depreciais": "depreciar",
    "depreciam": "depreciar",
    "depreciamo": "depreciar",
    "depreciamos": "depreciar",
    "depreciando": "depreciar",
    "depreciara": "depreciar",
    "depreciaram": "depreciar",
    "depreciaras": "depreciar",
    "depreciarde": "depreciar",
    "depreciardes": "depreciar",
    "depreciare": "depreciar",
    "depreciarei": "depreciar",
    "depreciareis": "depreciar",
    "depreciarem": "depreciar",
    "depreciaremos": "depreciar",
    "depreciares": "depreciar",
    "depreciaria": "depreciar",
    "depreciariam": "depreciar",
    "depreciarias": "depreciar",
    "depreciarmo": "depreciar",
    "depreciarmos": "depreciar",
    "depreciará": "depreciar",
    "depreciarás": "depreciar",
    "depreciarão": "depreciar",
    "depreciaríamos": "depreciar",
    "depreciaríeis": "depreciar",
    "deprecias": "depreciar",
    "depreciasse": "depreciar",
    "depreciassem": "depreciar",
    "depreciasses": "depreciar",
    "depreciaste": "depreciar",
    "depreciastes": "depreciar",
    "depreciativa": "depreciativo",
    "depreciativas": "depreciativo",
    "depreciativos": "depreciativo",
    "depreciava": "depreciar",
    "depreciavam": "depreciar",
    "depreciavas": "depreciar",
    "depreciações": "depreciação",
    "deprecie": "depreciar",
    "depreciei": "depreciar",
    "deprecieis": "depreciar",
    "depreciem": "depreciar",
    "depreciemo": "depreciar",
    "depreciemos": "depreciar",
    "deprecies": "depreciar",
    "deprecio": "depreciar",
    "depreciou": "depreciar",
    "depreciá": "depreciar",
    "depreciámo": "depreciar",
    "depreciámos": "depreciar",
    "depreciáramo": "depreciar",
    "depreciáramos": "depreciar",
    "depreciárei": "depreciar",
    "depreciáreis": "depreciar",
    "depreciásseis": "depreciar",
    "depreciássemos": "depreciar",
    "depreciávamo": "depreciar",
    "depreciávamos": "depreciar",
    "depreciávei": "depreciar",
    "depreciáveis": "depreciável",
    "depreda": "depredar",
    "depredada": "depredar",
    "depredadas": "depredar",
    "depredado": "depredar",
    "depredadora": "depredador",
    "depredadoras": "depredador",
    "depredadores": "depredador",
    "depredados": "depredar",
    "depredai": "depredar",
    "depredais": "depredar",
    "depredam": "depredar",
    "depredamo": "depredar",
    "depredamos": "depredar",
    "depredando": "depredar",
    "depredara": "depredar",
    "depredaram": "depredar",
    "depredaras": "depredar",
    "depredarde": "depredar",
    "depredardes": "depredar",
    "depredare": "depredar",
    "depredarei": "depredar",
    "depredareis": "depredar",
    "depredarem": "depredar",
    "depredaremos": "depredar",
    "depredares": "depredar",
    "depredaria": "depredar",
    "depredariam": "depredar",
    "depredarias": "depredar",
    "depredarmo": "depredar",
    "depredarmos": "depredar",
    "depredará": "depredar",
    "depredarás": "depredar",
    "depredarão": "depredar",
    "depredaríamos": "depredar",
    "depredaríeis": "depredar",
    "depredas": "depredar",
    "depredasse": "depredar",
    "depredassem": "depredar",
    "depredasses": "depredar",
    "depredaste": "depredar",
    "depredastes": "depredar",
    "depredativa": "depredativo",
    "depredativas": "depredativo",
    "depredativos": "depredativo",
    "depredatória": "depredatório",
    "depredatórias": "depredatório",
    "depredatórios": "depredatório",
    "depredava": "depredar",
    "depredavam": "depredar",
    "depredavas": "depredar",
    "depredações": "depredação",
    "deprede": "depredar",
    "depredei": "depredar",
    "depredeis": "depredar",
    "depredem": "depredar",
    "depredemo": "depredar",
    "depredemos": "depredar",
    "depredes": "depredar",
    "depredo": "depredar",
    "depredou": "depredar",
    "depredá": "depredar",
    "depredámo": "depredar",
    "depredámos": "depredar",
    "depredáramo": "depredar",
    "depredáramos": "depredar",
    "depredárei": "depredar",
    "depredáreis": "depredar",
    "depredásseis": "depredar",
    "depredássemos": "depredar",
    "depredávamo": "depredar",
    "depredávamos": "depredar",
    "depredávei": "depredar",
    "depredáveis": "depredar",
    "depreenda": "depreender",
    "depreendais": "depreender",
    "depreendam": "depreender",
    "depreendamo": "depreender",
    "depreendamos": "depreender",
    "depreendas": "depreender",
    "depreende": "depreender",
    "depreendei": "depreender",
    "depreendeis": "depreender",
    "depreendem": "depreender",
    "depreendemo": "depreender",
    "depreendemos": "depreender",
    "depreendendo": "depreender",
    "depreendera": "depreender",
    "depreenderam": "depreender",
    "depreenderas": "depreender",
    "depreenderde": "depreender",
    "depreenderdes": "depreender",
    "depreendere": "depreender",
    "depreenderei": "depreender",
    "depreendereis": "depreender",
    "depreenderem": "depreender",
    "depreenderemos": "depreender",
    "depreenderes": "depreender",
    "depreenderia": "depreender",
    "depreenderiam": "depreender",
    "depreenderias": "depreender",
    "depreendermo": "depreender",
    "depreendermos": "depreender",
    "depreenderá": "depreender",
    "depreenderás": "depreender",
    "depreenderão": "depreender",
    "depreenderíamos": "depreender",
    "depreenderíeis": "depreender",
    "depreendes": "depreender",
    "depreendesse": "depreender",
    "depreendessem": "depreender",
    "depreendesses": "depreender",
    "depreendeste": "depreender",
    "depreendestes": "depreender",
    "depreendeu": "depreender",
    "depreendi": "depreender",
    "depreendia": "depreender",
    "depreendiam": "depreender",
    "depreendias": "depreender",
    "depreendida": "depreendido",
    "depreendidas": "depreendido",
    "depreendido": "depreender",
    "depreendidos": "depreendido",
    "depreendo": "depreender",
    "depreendê": "depreender",
    "depreendêramo": "depreender",
    "depreendêramos": "depreender",
    "depreendêrei": "depreender",
    "depreendêreis": "depreender",
    "depreendêsseis": "depreender",
    "depreendêssemos": "depreender",
    "depreendíamo": "depreender",
    "depreendíamos": "depreender",
    "depreendíei": "depreender",
    "depreendíeis": "depreender",
    "depreensões": "depreensão",
    "depressinha": "depressa",
    "depressionária": "depressionário",
    "depressionárias": "depressionário",
    "depressionários": "depressionário",
    "depressita": "depressa",
    "depressiva": "depressivo",
    "depressivas": "depressivo",
    "depressivos": "depressivo",
    "depressora": "depressor",
    "depressoras": "depressor",
    "depressores": "depressor",
    "depressíssimo": "depressa",
    "depressíveis": "depressível",
    "depressões": "depressão",
    "deprima": "deprimir",
    "deprimais": "deprimir",
    "deprimam": "deprimir",
    "deprimamo": "deprimir",
    "deprimamos": "deprimir",
    "deprimas": "deprimir",
    "deprime": "deprimir",
    "deprimem": "deprimir",
    "deprimentes": "deprimente",
    "deprimes": "deprimir",
    "deprimi": "deprimir",
    "deprimia": "deprimir",
    "deprimiam": "deprimir",
    "deprimias": "deprimir",
    "deprimida": "deprimir",
    "deprimidas": "deprimir",
    "deprimido": "deprimir",
    "deprimidos": "deprimir",
    "deprimidíssima": "deprimido",
    "deprimidíssimas": "deprimido",
    "deprimidíssimo": "deprimido",
    "deprimidíssimos": "deprimido",
    "deprimimo": "deprimir",
    "deprimimos": "deprimir",
    "deprimindo": "deprimir",
    "deprimira": "deprimir",
    "deprimiram": "deprimir",
    "deprimiras": "deprimir",
    "deprimirde": "deprimir",
    "deprimirdes": "deprimir",
    "deprimire": "deprimir",
    "deprimirei": "deprimir",
    "deprimireis": "deprimir",
    "deprimirem": "deprimir",
    "deprimiremos": "deprimir",
    "deprimires": "deprimir",
    "deprimiria": "deprimir",
    "deprimiriam": "deprimir",
    "deprimirias": "deprimir",
    "deprimirmo": "deprimir",
    "deprimirmos": "deprimir",
    "deprimirá": "deprimir",
    "deprimirás": "deprimir",
    "deprimirão": "deprimir",
    "deprimiríamos": "deprimir",
    "deprimiríeis": "deprimir",
    "deprimis": "deprimir",
    "deprimisse": "deprimir",
    "deprimissem": "deprimir",
    "deprimisses": "deprimir",
    "deprimiste": "deprimir",
    "deprimistes": "deprimir",
    "deprimiu": "deprimir",
    "deprimo": "deprimir",
    "deprimências": "deprimência",
    "deprimíamo": "deprimir",
    "deprimíamos": "deprimir",
    "deprimíei": "deprimir",
    "deprimíeis": "deprimir",
    "deprimíramo": "deprimir",
    "deprimíramos": "deprimir",
    "deprimírei": "deprimir",
    "deprimíreis": "deprimir",
    "deprimísseis": "deprimir",
    "deprimíssemos": "deprimir",
    "depunha": "depor",
    "depunham": "depor",
    "depunhas": "depor",
    "depura": "depurar",
    "depurada": "depurar",
    "depuradas": "depurar",
    "depurado": "depurar",
    "depuradora": "depurador",
    "depuradoras": "depurador",
    "depuradores": "depurador",
    "depurados": "depurar",
    "depurai": "depurar",
    "depurais": "depurar",
    "depuram": "depurar",
    "depuramo": "depurar",
    "depuramos": "depurar",
    "depurando": "depurar",
    "depurantes": "depurante",
    "depurara": "depurar",
    "depuraram": "depurar",
    "depuraras": "depurar",
    "depurarde": "depurar",
    "depurardes": "depurar",
    "depurare": "depurar",
    "depurarei": "depurar",
    "depurareis": "depurar",
    "depurarem": "depurar",
    "depuraremos": "depurar",
    "depurares": "depurar",
    "depuraria": "depurar",
    "depurariam": "depurar",
    "depurarias": "depurar",
    "depurarmo": "depurar",
    "depurarmos": "depurar",
    "depurará": "depurar",
    "depurarás": "depurar",
    "depurarão": "depurar",
    "depuraríamos": "depurar",
    "depuraríeis": "depurar",
    "depuras": "depurar",
    "depurasse": "depurar",
    "depurassem": "depurar",
    "depurasses": "depurar",
    "depuraste": "depurar",
    "depurastes": "depurar",
    "depurativa": "depurativo",
    "depurativas": "depurativo",
    "depurativos": "depurativo",
    "depuratória": "depuratório",
    "depuratórias": "depuratório",
    "depuratórios": "depuratório",
    "depurava": "depurar",
    "depuravam": "depurar",
    "depuravas": "depurar",
    "depurações": "depuração",
    "depure": "depurar",
    "depurei": "depurar",
    "depureis": "depurar",
    "depurem": "depurar",
    "depuremo": "depurar",
    "depuremos": "depurar",
    "depures": "depurar",
    "depuro": "depurar",
    "depurou": "depurar",
    "depurá": "depurar",
    "depurámo": "depurar",
    "depurámos": "depurar",
    "depuráramo": "depurar",
    "depuráramos": "depurar",
    "depurárei": "depurar",
    "depuráreis": "depurar",
    "depurásseis": "depurar",
    "depurássemos": "depurar",
    "depurávamo": "depurar",
    "depurávamos": "depurar",
    "depurávei": "depurar",
    "depuráveis": "depurar",
    "depus": "depor",
    "depusemo": "depor",
    "depusemos": "depor",
    "depuser": "depor",
    "depusera": "depor",
    "depuseram": "depor",
    "depuseras": "depor",
    "depuserdes": "depor",
    "depuserem": "depor",
    "depuseres": "depor",
    "depusermos": "depor",
    "depusesse": "depor",
    "depusessem": "depor",
    "depusesses": "depor",
    "depuseste": "depor",
    "depusestes": "depor",
    "depuséramo": "depor",
    "depuséramos": "depor",
    "depusérei": "depor",
    "depuséreis": "depor",
    "depusésseis": "depor",
    "depuséssemos": "depor",
    "deputa": "deputar",
    "deputada": "deputar",
    "deputadas": "deputar",
    "deputado": "deputar",
    "deputados": "deputar",
    "deputai": "deputar",
    "deputais": "deputar",
    "deputam": "deputar",
    "deputamo": "deputar",
    "deputamos": "deputar",
    "deputando": "deputar",
    "deputara": "deputar",
    "deputaram": "deputar",
    "deputaras": "deputar",
    "deputarde": "deputar",
    "deputardes": "deputar",
    "deputare": "deputar",
    "deputarei": "deputar",
    "deputareis": "deputar",
    "deputarem": "deputar",
    "deputaremos": "deputar",
    "deputares": "deputar",
    "deputaria": "deputar",
    "deputariam": "deputar",
    "deputarias": "deputar",
    "deputarmo": "deputar",
    "deputarmos": "deputar",
    "deputará": "deputar",
    "deputarás": "deputar",
    "deputarão": "deputar",
    "deputaríamos": "deputar",
    "deputaríeis": "deputar",
    "deputas": "deputar",
    "deputasse": "deputar",
    "deputassem": "deputar",
    "deputasses": "deputar",
    "deputaste": "deputar",
    "deputastes": "deputar",
    "deputava": "deputar",
    "deputavam": "deputar",
    "deputavas": "deputar",
    "deputações": "deputação",
    "depute": "deputar",
    "deputei": "deputar",
    "deputeis": "deputar",
    "deputem": "deputar",
    "deputemo": "deputar",
    "deputemos": "deputar",
    "deputes": "deputar",
    "deputo": "deputar",
    "deputou": "deputar",
    "deputá": "deputar",
    "deputámo": "deputar",
    "deputámos": "deputar",
    "deputáramo": "deputar",
    "deputáramos": "deputar",
    "deputárei": "deputar",
    "deputáreis": "deputar",
    "deputásseis": "deputar",
    "deputássemos": "deputar",
    "deputávamo": "deputar",
    "deputávamos": "deputar",
    "deputávei": "deputar",
    "deputáveis": "deputar",
    "depósitos": "depósito",
    "depô": "depor",
    "depôs": "depor",
    "depõe": "depor",
    "depõem": "depor",
    "depões": "depor",
    "depúnhamo": "depor",
    "depúnhamos": "depor",
    "depúnhei": "depor",
    "depúnheis": "depor",
    "dequitaduras": "dequitadura",
    "dequitações": "dequitação",
    "dequites": "dequite",
    "dera": "dar",
    "deradelfa": "deradelfo",
    "deradelfas": "deradelfo",
    "deradelfias": "deradelfia",
    "deradelfos": "deradelfo",
    "deram": "dar",
    "deras": "dar",
    "derisória": "derisório",
    "derisórias": "derisório",
    "derisórios": "derisório",
    "derisões": "derisão",
    "deriva": "derivar",
    "derivada": "derivar",
    "derivadas": "derivar",
    "derivado": "derivar",
    "derivados": "derivar",
    "derivai": "derivar",
    "derivais": "derivar",
    "derivam": "derivar",
    "derivamo": "derivar",
    "derivamos": "derivar",
    "derivando": "derivar",
    "derivantes": "derivante",
    "derivara": "derivar",
    "derivaram": "derivar",
    "derivaras": "derivar",
    "derivarde": "derivar",
    "derivardes": "derivar",
    "derivare": "derivar",
    "derivarei": "derivar",
    "derivareis": "derivar",
    "derivarem": "derivar",
    "derivaremos": "derivar",
    "derivares": "derivar",
    "derivaria": "derivar",
    "derivariam": "derivar",
    "derivarias": "derivar",
    "derivarmo": "derivar",
    "derivarmos": "derivar",
    "derivará": "derivar",
    "derivarás": "derivar",
    "derivarão": "derivar",
    "derivaríamos": "derivar",
    "derivaríeis": "derivar",
    "derivas": "derivar",
    "derivasse": "derivar",
    "derivassem": "derivar",
    "derivasses": "derivar",
    "derivaste": "derivar",
    "derivastes": "derivar",
    "derivativa": "derivativo",
    "derivativas": "derivativo",
    "derivativos": "derivativo",
    "derivatória": "derivatório",
    "derivatórias": "derivatório",
    "derivatórios": "derivatório",
    "derivava": "derivar",
    "derivavam": "derivar",
    "derivavas": "derivar",
    "derivações": "derivação",
    "derive": "derivar",
    "derivei": "derivar",
    "deriveis": "derivar",
    "derivem": "derivar",
    "derivemo": "derivar",
    "derivemos": "derivar",
    "derives": "derivar",
    "derivo": "derivar",
    "derivou": "derivar",
    "derivá": "derivar",
    "derivámo": "derivar",
    "derivámos": "derivar",
    "deriváramo": "derivar",
    "deriváramos": "derivar",
    "derivárei": "derivar",
    "deriváreis": "derivar",
    "derivásseis": "derivar",
    "derivássemos": "derivar",
    "derivávamo": "derivar",
    "derivávamos": "derivar",
    "derivávei": "derivar",
    "deriváveis": "derivável",
    "dermalgias": "dermalgia",
    "dermas": "derma",
    "dermatites": "dermatite",
    "dermatofobias": "dermatofobia",
    "dermatografias": "dermatografia",
    "dermatologias": "dermatologia",
    "dermatologistas": "dermatologista",
    "dermatológica": "dermatológico",
    "dermatológicas": "dermatológico",
    "dermatológicos": "dermatológico",
    "dermatoplastias": "dermatoplastia",
    "dermatoses": "dermatose",
    "dermatoterapias": "dermatoterapia",
    "dermatotomias": "dermatotomia",
    "dermatóides": "dermatóide",
    "dermatópteros": "dermatóptero",
    "dermes": "derme",
    "dermites": "dermite",
    "dermopapilogramas": "dermopapilograma",
    "dermoterapias": "dermoterapia",
    "dermápteros": "dermáptero",
    "dermática": "dermático",
    "dermáticas": "dermático",
    "dermáticos": "dermático",
    "dermóides": "dermóide",
    "dermópteros": "dermóptero",
    "derrabada": "derrabado",
    "derrabadas": "derrabado",
    "derrabados": "derrabado",
    "derrabanhos": "derrabanho",
    "derradeira": "derradeiro",
    "derradeiras": "derradeiro",
    "derradeiros": "derradeiro",
    "derrama": "derramar",
    "derramada": "derramar",
    "derramadas": "derramar",
    "derramado": "derramar",
    "derramadora": "derramador",
    "derramadoras": "derramador",
    "derramadores": "derramador",
    "derramados": "derramar",
    "derramai": "derramar",
    "derramais": "derramar",
    "derramam": "derramar",
    "derramamentos": "derramamento",
    "derramamo": "derramar",
    "derramamos": "derramar",
    "derramando": "derramar",
    "derramara": "derramar",
    "derramaram": "derramar",
    "derramaras": "derramar",
    "derramarde": "derramar",
    "derramardes": "derramar",
    "derramare": "derramar",
    "derramarei": "derramar",
    "derramareis": "derramar",
    "derramarem": "derramar",
    "derramaremos": "derramar",
    "derramares": "derramar",
    "derramaria": "derramar",
    "derramariam": "derramar",
    "derramarias": "derramar",
    "derramarmo": "derramar",
    "derramarmos": "derramar",
    "derramará": "derramar",
    "derramarás": "derramar",
    "derramarão": "derramar",
    "derramaríamos": "derramar",
    "derramaríeis": "derramar",
    "derramas": "derramar",
    "derramasse": "derramar",
    "derramassem": "derramar",
    "derramasses": "derramar",
    "derramaste": "derramar",
    "derramastes": "derramar",
    "derramava": "derramar",
    "derramavam": "derramar",
    "derramavas": "derramar",
    "derramações": "derramação",
    "derrame": "derramar",
    "derramei": "derramar",
    "derrameis": "derramar",
    "derramem": "derramar",
    "derramemo": "derramar",
    "derramemos": "derramar",
    "derrames": "derrame",
    "derramo": "derramar",
    "derramou": "derramar",
    "derramá": "derramar",
    "derramámo": "derramar",
    "derramámos": "derramar",
    "derramáramo": "derramar",
    "derramáramos": "derramar",
    "derramárei": "derramar",
    "derramáreis": "derramar",
    "derramásseis": "derramar",
    "derramássemos": "derramar",
    "derramávamo": "derramar",
    "derramávamos": "derramar",
    "derramávei": "derramar",
    "derramáveis": "derramar",
    "derranca": "derrancar",
    "derrancada": "derrancar",
    "derrancadas": "derrancar",
    "derrancado": "derrancar",
    "derrancados": "derrancar",
    "derrancai": "derrancar",
    "derrancais": "derrancar",
    "derrancam": "derrancar",
    "derrancamentos": "derrancamento",
    "derrancamo": "derrancar",
    "derrancamos": "derrancar",
    "derrancando": "derrancar",
    "derrancara": "derrancar",
    "derrancaram": "derrancar",
    "derrancaras": "derrancar",
    "derrancarde": "derrancar",
    "derrancardes": "derrancar",
    "derrancare": "derrancar",
    "derrancarei": "derrancar",
    "derrancareis": "derrancar",
    "derrancarem": "derrancar",
    "derrancaremos": "derrancar",
    "derrancares": "derrancar",
    "derrancaria": "derrancar",
    "derrancariam": "derrancar",
    "derrancarias": "derrancar",
    "derrancarmo": "derrancar",
    "derrancarmos": "derrancar",
    "derrancará": "derrancar",
    "derrancarás": "derrancar",
    "derrancarão": "derrancar",
    "derrancaríamos": "derrancar",
    "derrancaríeis": "derrancar",
    "derrancas": "derrancar",
    "derrancasse": "derrancar",
    "derrancassem": "derrancar",
    "derrancasses": "derrancar",
    "derrancaste": "derrancar",
    "derrancastes": "derrancar",
    "derrancava": "derrancar",
    "derrancavam": "derrancar",
    "derrancavas": "derrancar",
    "derranco": "derrancar",
    "derrancos": "derranco",
    "derrancou": "derrancar",
    "derrancá": "derrancar",
    "derrancámo": "derrancar",
    "derrancámos": "derrancar",
    "derrancáramo": "derrancar",
    "derrancáramos": "derrancar",
    "derrancárei": "derrancar",
    "derrancáreis": "derrancar",
    "derrancásseis": "derrancar",
    "derrancássemos": "derrancar",
    "derrancávamo": "derrancar",
    "derrancávamos": "derrancar",
    "derrancávei": "derrancar",
    "derrancáveis": "derrancar",
    "derranque": "derrancar",
    "derranquei": "derrancar",
    "derranqueis": "derrancar",
    "derranquem": "derrancar",
    "derranquemo": "derrancar",
    "derranquemos": "derrancar",
    "derranques": "derranque",
    "derrapa": "derrapar",
    "derrapada": "derrapar",
    "derrapadas": "derrapar",
    "derrapado": "derrapar",
    "derrapados": "derrapar",
    "derrapagens": "derrapagem",
    "derrapai": "derrapar",
    "derrapais": "derrapar",
    "derrapam": "derrapar",
    "derrapamo": "derrapar",
    "derrapamos": "derrapar",
    "derrapando": "derrapar",
    "derrapara": "derrapar",
    "derraparam": "derrapar",
    "derraparas": "derrapar",
    "derrapardes": "derrapar",
    "derraparei": "derrapar",
    "derrapareis": "derrapar",
    "derraparem": "derrapar",
    "derraparemos": "derrapar",
    "derrapares": "derrapar",
    "derraparia": "derrapar",
    "derrapariam": "derrapar",
    "derraparias": "derrapar",
    "derraparmo": "derrapar",
    "derraparmos": "derrapar",
    "derrapará": "derrapar",
    "derraparás": "derrapar",
    "derraparão": "derrapar",
    "derraparíamos": "derrapar",
    "derraparíeis": "derrapar",
    "derrapas": "derrapar",
    "derrapasse": "derrapar",
    "derrapassem": "derrapar",
    "derrapasses": "derrapar",
    "derrapaste": "derrapar",
    "derrapastes": "derrapar",
    "derrapava": "derrapar",
    "derrapavam": "derrapar",
    "derrapavas": "derrapar",
    "derrape": "derrapar",
    "derrapei": "derrapar",
    "derrapeis": "derrapar",
    "derrapem": "derrapar",
    "derrapemo": "derrapar",
    "derrapemos": "derrapar",
    "derrapes": "derrapar",
    "derrapo": "derrapar",
    "derrapou": "derrapar",
    "derrapámo": "derrapar",
    "derrapámos": "derrapar",
    "derrapáramo": "derrapar",
    "derrapáramos": "derrapar",
    "derrapáreis": "derrapar",
    "derrapásseis": "derrapar",
    "derrapássemos": "derrapar",
    "derrapávamo": "derrapar",
    "derrapávamos": "derrapar",
    "derrapáveis": "derrapar",
    "derreada": "derrear",
    "derreadas": "derrear",
    "derreadelas": "derreadela",
    "derreado": "derrear",
    "derreadora": "derreador",
    "derreadoras": "derreador",
    "derreadores": "derreador",
    "derreados": "derrear",
    "derreadíssima": "derreado",
    "derreadíssimas": "derreado",
    "derreadíssimo": "derreado",
    "derreadíssimos": "derreado",
    "derreai": "derrear",
    "derreais": "derrear",
    "derreamentos": "derreamento",
    "derreamo": "derrear",
    "derreamos": "derrear",
    "derreando": "derrear",
    "derreara": "derrear",
    "derrearam": "derrear",
    "derrearas": "derrear",
    "derrearde": "derrear",
    "derreardes": "derrear",
    "derreare": "derrear",
    "derrearei": "derrear",
    "derreareis": "derrear",
    "derrearem": "derrear",
    "derrearemos": "derrear",
    "derreares": "derrear",
    "derrearia": "derrear",
    "derreariam": "derrear",
    "derrearias": "derrear",
    "derrearmo": "derrear",
    "derrearmos": "derrear",
    "derreará": "derrear",
    "derrearás": "derrear",
    "derrearão": "derrear",
    "derrearíamos": "derrear",
    "derrearíeis": "derrear",
    "derreasse": "derrear",
    "derreassem": "derrear",
    "derreasses": "derrear",
    "derreaste": "derrear",
    "derreastes": "derrear",
    "derreava": "derrear",
    "derreavam": "derrear",
    "derreavas": "derrear",
    "derreei": "derrear",
    "derreeis": "derrear",
    "derreemo": "derrear",
    "derreemos": "derrear",
    "derreia": "derrear",
    "derreiam": "derrear",
    "derreias": "derreia",
    "derreie": "derrear",
    "derreiem": "derrear",
    "derreies": "derrear",
    "derreigada": "derreigado",
    "derreigadas": "derreigado",
    "derreigados": "derreigado",
    "derreio": "derrear",
    "derreios": "derreio",
    "derrelicta": "derrelicto",
    "derrelictas": "derrelicto",
    "derrelictos": "derrelicto",
    "derrelicções": "derrelicção",
    "derrengada": "derrengado",
    "derrengadas": "derrengado",
    "derrengados": "derrengado",
    "derrengos": "derrengo",
    "derrengues": "derrengue",
    "derreou": "derrear",
    "derreta": "derreter",
    "derretais": "derreter",
    "derretam": "derreter",
    "derretamo": "derreter",
    "derretamos": "derreter",
    "derretas": "derreter",
    "derrete": "derreter",
    "derreteduras": "derretedura",
    "derretei": "derreter",
    "derreteis": "derreter",
    "derretem": "derreter",
    "derretemo": "derreter",
    "derretemos": "derreter",
    "derretendo": "derreter",
    "derretera": "derreter",
    "derreteram": "derreter",
    "derreteras": "derreter",
    "derreterde": "derreter",
    "derreterdes": "derreter",
    "derretere": "derreter",
    "derreterei": "derreter",
    "derretereis": "derreter",
    "derreterem": "derreter",
    "derreteremos": "derreter",
    "derreteres": "derreter",
    "derreteria": "derreter",
    "derreteriam": "derreter",
    "derreterias": "derreter",
    "derretermo": "derreter",
    "derretermos": "derreter",
    "derreterá": "derreter",
    "derreterás": "derreter",
    "derreterão": "derreter",
    "derreteríamos": "derreter",
    "derreteríeis": "derreter",
    "derretes": "derreter",
    "derretesse": "derreter",
    "derretessem": "derreter",
    "derretesses": "derreter",
    "derreteste": "derreter",
    "derretestes": "derreter",
    "derreteu": "derreter",
    "derreti": "derreter",
    "derretia": "derreter",
    "derretiam": "derreter",
    "derretias": "derreter",
    "derretida": "derretido",
    "derretidas": "derretido",
    "derretidinha": "derretido",
    "derretidinhas": "derretido",
    "derretidinho": "derretido",
    "derretidinhos": "derretido",
    "derretidita": "derretido",
    "derretiditas": "derretido",
    "derretidito": "derretido",
    "derretiditos": "derretido",
    "derretido": "derreter",
    "derretidos": "derretido",
    "derretidíssima": "derretido",
    "derretidíssimas": "derretido",
    "derretidíssimo": "derretido",
    "derretidíssimos": "derretido",
    "derretimentos": "derretimento",
    "derreto": "derreter",
    "derretê": "derreter",
    "derretêramo": "derreter",
    "derretêramos": "derreter",
    "derretêrei": "derreter",
    "derretêreis": "derreter",
    "derretêsseis": "derreter",
    "derretêssemos": "derreter",
    "derretíamo": "derreter",
    "derretíamos": "derreter",
    "derretíei": "derreter",
    "derretíeis": "derreter",
    "derreá": "derrear",
    "derreámo": "derrear",
    "derreámos": "derrear",
    "derreáramo": "derrear",
    "derreáramos": "derrear",
    "derreárei": "derrear",
    "derreáreis": "derrear",
    "derreásseis": "derrear",
    "derreássemos": "derrear",
    "derreávamo": "derrear",
    "derreávamos": "derrear",
    "derreávei": "derrear",
    "derreáveis": "derrear",
    "derriba": "derribar",
    "derribada": "derribar",
    "derribadas": "derribar",
    "derribado": "derribar",
    "derribadora": "derribador",
    "derribadoras": "derribador",
    "derribadores": "derribador",
    "derribados": "derribar",
    "derribai": "derribar",
    "derribais": "derribar",
    "derribam": "derribar",
    "derribamentos": "derribamento",
    "derribamo": "derribar",
    "derribamos": "derribar",
    "derribando": "derribar",
    "derribara": "derribar",
    "derribaram": "derribar",
    "derribaras": "derribar",
    "derribarde": "derribar",
    "derribardes": "derribar",
    "derribare": "derribar",
    "derribarei": "derribar",
    "derribareis": "derribar",
    "derribarem": "derribar",
    "derribaremos": "derribar",
    "derribares": "derribar",
    "derribaria": "derribar",
    "derribariam": "derribar",
    "derribarias": "derribar",
    "derribarmo": "derribar",
    "derribarmos": "derribar",
    "derribará": "derribar",
    "derribarás": "derribar",
    "derribarão": "derribar",
    "derribaríamos": "derribar",
    "derribaríeis": "derribar",
    "derribas": "derribar",
    "derribasse": "derribar",
    "derribassem": "derribar",
    "derribasses": "derribar",
    "derribaste": "derribar",
    "derribastes": "derribar",
    "derribava": "derribar",
    "derribavam": "derribar",
    "derribavas": "derribar",
    "derribe": "derribar",
    "derribei": "derribar",
    "derribeis": "derribar",
    "derribem": "derribar",
    "derribemo": "derribar",
    "derribemos": "derribar",
    "derribes": "derribar",
    "derribo": "derribar",
    "derribou": "derribar",
    "derribá": "derribar",
    "derribámo": "derribar",
    "derribámos": "derribar",
    "derribáramo": "derribar",
    "derribáramos": "derribar",
    "derribárei": "derribar",
    "derribáreis": "derribar",
    "derribásseis": "derribar",
    "derribássemos": "derribar",
    "derribávamo": "derribar",
    "derribávamos": "derribar",
    "derribávei": "derribar",
    "derribáveis": "derribar",
    "derrice": "derriçar",
    "derricei": "derriçar",
    "derriceis": "derriçar",
    "derricem": "derriçar",
    "derricemo": "derriçar",
    "derricemos": "derriçar",
    "derrices": "derriçar",
    "derriscada": "derriscado",
    "derriscadas": "derriscado",
    "derriscados": "derriscado",
    "derriscas": "derrisca",
    "derrisões": "derrisão",
    "derriça": "derriçar",
    "derriçada": "derriçar",
    "derriçadas": "derriçar",
    "derriçado": "derriçar",
    "derriçadora": "derriçador",
    "derriçadoras": "derriçador",
    "derriçadores": "derriçador",
    "derriçados": "derriçar",
    "derriçagens": "derriçagem",
    "derriçai": "derriçar",
    "derriçais": "derriçar",
    "derriçam": "derriçar",
    "derriçamo": "derriçar",
    "derriçamos": "derriçar",
    "derriçando": "derriçar",
    "derriçara": "derriçar",
    "derriçaram": "derriçar",
    "derriçaras": "derriçar",
    "derriçarde": "derriçar",
    "derriçardes": "derriçar",
    "derriçare": "derriçar",
    "derriçarei": "derriçar",
    "derriçareis": "derriçar",
    "derriçarem": "derriçar",
    "derriçaremos": "derriçar",
    "derriçares": "derriçar",
    "derriçaria": "derriçar",
    "derriçariam": "derriçar",
    "derriçarias": "derriçar",
    "derriçarmo": "derriçar",
    "derriçarmos": "derriçar",
    "derriçará": "derriçar",
    "derriçarás": "derriçar",
    "derriçarão": "derriçar",
    "derriçaríamos": "derriçar",
    "derriçaríeis": "derriçar",
    "derriças": "derriçar",
    "derriçasse": "derriçar",
    "derriçassem": "derriçar",
    "derriçasses": "derriçar",
    "derriçaste": "derriçar",
    "derriçastes": "derriçar",
    "derriçava": "derriçar",
    "derriçavam": "derriçar",
    "derriçavas": "derriçar",
    "derriço": "derriçar",
    "derriços": "derriço",
    "derriçou": "derriçar",
    "derriçá": "derriçar",
    "derriçámo": "derriçar",
    "derriçámos": "derriçar",
    "derriçáramo": "derriçar",
    "derriçáramos": "derriçar",
    "derriçárei": "derriçar",
    "derriçáreis": "derriçar",
    "derriçásseis": "derriçar",
    "derriçássemos": "derriçar",
    "derriçávamo": "derriçar",
    "derriçávamos": "derriçar",
    "derriçávei": "derriçar",
    "derriçáveis": "derriçar",
    "derroca": "derrocar",
    "derrocada": "derrocar",
    "derrocadas": "derrocar",
    "derrocado": "derrocar",
    "derrocadora": "derrocador",
    "derrocadoras": "derrocador",
    "derrocadores": "derrocador",
    "derrocados": "derrocar",
    "derrocai": "derrocar",
    "derrocais": "derrocar",
    "derrocam": "derrocar",
    "derrocamentos": "derrocamento",
    "derrocamo": "derrocar",
    "derrocamos": "derrocar",
    "derrocando": "derrocar",
    "derrocara": "derrocar",
    "derrocaram": "derrocar",
    "derrocaras": "derrocar",
    "derrocarde": "derrocar",
    "derrocardes": "derrocar",
    "derrocare": "derrocar",
    "derrocarei": "derrocar",
    "derrocareis": "derrocar",
    "derrocarem": "derrocar",
    "derrocaremos": "derrocar",
    "derrocares": "derrocar",
    "derrocaria": "derrocar",
    "derrocariam": "derrocar",
    "derrocarias": "derrocar",
    "derrocarmo": "derrocar",
    "derrocarmos": "derrocar",
    "derrocará": "derrocar",
    "derrocarás": "derrocar",
    "derrocarão": "derrocar",
    "derrocaríamos": "derrocar",
    "derrocaríeis": "derrocar",
    "derrocas": "derrocar",
    "derrocasse": "derrocar",
    "derrocassem": "derrocar",
    "derrocasses": "derrocar",
    "derrocaste": "derrocar",
    "derrocastes": "derrocar",
    "derrocava": "derrocar",
    "derrocavam": "derrocar",
    "derrocavas": "derrocar",
    "derrocações": "derrocação",
    "derroco": "derrocar",
    "derrocou": "derrocar",
    "derrocá": "derrocar",
    "derrocámo": "derrocar",
    "derrocámos": "derrocar",
    "derrocáramo": "derrocar",
    "derrocáramos": "derrocar",
    "derrocárei": "derrocar",
    "derrocáreis": "derrocar",
    "derrocásseis": "derrocar",
    "derrocássemos": "derrocar",
    "derrocávamo": "derrocar",
    "derrocávamos": "derrocar",
    "derrocávei": "derrocar",
    "derrocáveis": "derrocar",
    "derroga": "derrogar",
    "derrogada": "derrogar",
    "derrogadas": "derrogar",
    "derrogado": "derrogar",
    "derrogadora": "derrogador",
    "derrogadoras": "derrogador",
    "derrogadores": "derrogador",
    "derrogados": "derrogar",
    "derrogai": "derrogar",
    "derrogais": "derrogar",
    "derrogam": "derrogar",
    "derrogamentos": "derrogamento",
    "derrogamo": "derrogar",
    "derrogamos": "derrogar",
    "derrogando": "derrogar",
    "derrogantes": "derrogante",
    "derrogara": "derrogar",
    "derrogaram": "derrogar",
    "derrogaras": "derrogar",
    "derrogarde": "derrogar",
    "derrogardes": "derrogar",
    "derrogare": "derrogar",
    "derrogarei": "derrogar",
    "derrogareis": "derrogar",
    "derrogarem": "derrogar",
    "derrogaremos": "derrogar",
    "derrogares": "derrogar",
    "derrogaria": "derrogar",
    "derrogariam": "derrogar",
    "derrogarias": "derrogar",
    "derrogarmo": "derrogar",
    "derrogarmos": "derrogar",
    "derrogará": "derrogar",
    "derrogarás": "derrogar",
    "derrogarão": "derrogar",
    "derrogaríamos": "derrogar",
    "derrogaríeis": "derrogar",
    "derrogas": "derrogar",
    "derrogasse": "derrogar",
    "derrogassem": "derrogar",
    "derrogasses": "derrogar",
    "derrogaste": "derrogar",
    "derrogastes": "derrogar",
    "derrogatória": "derrogatório",
    "derrogatórias": "derrogatório",
    "derrogatórios": "derrogatório",
    "derrogava": "derrogar",
    "derrogavam": "derrogar",
    "derrogavas": "derrogar",
    "derrogações": "derrogação",
    "derrogo": "derrogar",
    "derrogou": "derrogar",
    "derrogue": "derrogar",
    "derroguei": "derrogar",
    "derrogueis": "derrogar",
    "derroguem": "derrogar",
    "derroguemo": "derrogar",
    "derroguemos": "derrogar",
    "derrogues": "derrogar",
    "derrogá": "derrogar",
    "derrogámo": "derrogar",
    "derrogámos": "derrogar",
    "derrogáramo": "derrogar",
    "derrogáramos": "derrogar",
    "derrogárei": "derrogar",
    "derrogáreis": "derrogar",
    "derrogásseis": "derrogar",
    "derrogássemos": "derrogar",
    "derrogávamo": "derrogar",
    "derrogávamos": "derrogar",
    "derrogávei": "derrogar",
    "derrogáveis": "derrogar",
    "derroque": "derrocar",
    "derroquei": "derrocar",
    "derroqueis": "derrocar",
    "derroquem": "derrocar",
    "derroquemo": "derrocar",
    "derroquemos": "derrocar",
    "derroques": "derrocar",
    "derrota": "derrotar",
    "derrotada": "derrotar",
    "derrotadas": "derrotar",
    "derrotado": "derrotar",
    "derrotadora": "derrotador",
    "derrotadoras": "derrotador",
    "derrotadores": "derrotador",
    "derrotados": "derrotar",
    "derrotai": "derrotar",
    "derrotais": "derrotar",
    "derrotam": "derrotar",
    "derrotamentos": "derrotamento",
    "derrotamo": "derrotar",
    "derrotamos": "derrotar",
    "derrotando": "derrotar",
    "derrotara": "derrotar",
    "derrotaram": "derrotar",
    "derrotaras": "derrotar",
    "derrotarde": "derrotar",
    "derrotardes": "derrotar",
    "derrotare": "derrotar",
    "derrotarei": "derrotar",
    "derrotareis": "derrotar",
    "derrotarem": "derrotar",
    "derrotaremos": "derrotar",
    "derrotares": "derrotar",
    "derrotaria": "derrotar",
    "derrotariam": "derrotar",
    "derrotarias": "derrotar",
    "derrotarmo": "derrotar",
    "derrotarmos": "derrotar",
    "derrotará": "derrotar",
    "derrotarás": "derrotar",
    "derrotarão": "derrotar",
    "derrotaríamos": "derrotar",
    "derrotaríeis": "derrotar",
    "derrotas": "derrotar",
    "derrotasse": "derrotar",
    "derrotassem": "derrotar",
    "derrotasses": "derrotar",
    "derrotaste": "derrotar",
    "derrotastes": "derrotar",
    "derrotava": "derrotar",
    "derrotavam": "derrotar",
    "derrotavas": "derrotar",
    "derrote": "derrotar",
    "derrotei": "derrotar",
    "derroteiros": "derroteiro",
    "derroteis": "derrotar",
    "derrotem": "derrotar",
    "derrotemo": "derrotar",
    "derrotemos": "derrotar",
    "derrotes": "derrote",
    "derrotismos": "derrotismo",
    "derrotistas": "derrotista",
    "derroto": "derrotar",
    "derrotou": "derrotar",
    "derrotá": "derrotar",
    "derrotámo": "derrotar",
    "derrotámos": "derrotar",
    "derrotáramo": "derrotar",
    "derrotáramos": "derrotar",
    "derrotárei": "derrotar",
    "derrotáreis": "derrotar",
    "derrotásseis": "derrotar",
    "derrotássemos": "derrotar",
    "derrotávamo": "derrotar",
    "derrotávamos": "derrotar",
    "derrotávei": "derrotar",
    "derrotáveis": "derrotável",
    "derrua": "derruir",
    "derruais": "derruir",
    "derruam": "derruir",
    "derruamo": "derruir",
    "derruamos": "derruir",
    "derruas": "derruir",
    "derruba": "derrubar",
    "derrubada": "derrubar",
    "derrubadas": "derrubar",
    "derrubado": "derrubar",
    "derrubadora": "derrubador",
    "derrubadoras": "derrubador",
    "derrubadores": "derrubador",
    "derrubados": "derrubar",
    "derrubai": "derrubar",
    "derrubais": "derrubar",
    "derrubam": "derrubar",
    "derrubamentos": "derrubamento",
    "derrubamo": "derrubar",
    "derrubamos": "derrubar",
    "derrubando": "derrubar",
    "derrubara": "derrubar",
    "derrubaram": "derrubar",
    "derrubaras": "derrubar",
    "derrubarde": "derrubar",
    "derrubardes": "derrubar",
    "derrubare": "derrubar",
    "derrubarei": "derrubar",
    "derrubareis": "derrubar",
    "derrubarem": "derrubar",
    "derrubaremos": "derrubar",
    "derrubares": "derrubar",
    "derrubaria": "derrubar",
    "derrubariam": "derrubar",
    "derrubarias": "derrubar",
    "derrubarmo": "derrubar",
    "derrubarmos": "derrubar",
    "derrubará": "derrubar",
    "derrubarás": "derrubar",
    "derrubarão": "derrubar",
    "derrubaríamos": "derrubar",
    "derrubaríeis": "derrubar",
    "derrubas": "derrubar",
    "derrubasse": "derrubar",
    "derrubassem": "derrubar",
    "derrubasses": "derrubar",
    "derrubaste": "derrubar",
    "derrubastes": "derrubar",
    "derrubava": "derrubar",
    "derrubavam": "derrubar",
    "derrubavas": "derrubar",
    "derrube": "derrubar",
    "derrubei": "derrubar",
    "derrubeis": "derrubar",
    "derrubem": "derrubar",
    "derrubemo": "derrubar",
    "derrubemos": "derrubar",
    "derrubes": "derrube",
    "derrubo": "derrubar",
    "derrubou": "derrubar",
    "derrubá": "derrubar",
    "derrubámo": "derrubar",
    "derrubámos": "derrubar",
    "derrubáramo": "derrubar",
    "derrubáramos": "derrubar",
    "derrubárei": "derrubar",
    "derrubáreis": "derrubar",
    "derrubásseis": "derrubar",
    "derrubássemos": "derrubar",
    "derrubávamo": "derrubar",
    "derrubávamos": "derrubar",
    "derrubávei": "derrubar",
    "derrubáveis": "derrubável",
    "derruem": "derruir",
    "derrui": "derruir",
    "derruida": "derruido",
    "derruidas": "derruido",
    "derruidora": "derruidor",
    "derruidoras": "derruidor",
    "derruidores": "derruidor",
    "derruidos": "derruido",
    "derruimentos": "derruimento",
    "derruindo": "derruir",
    "derruirde": "derruir",
    "derruirdes": "derruir",
    "derruirei": "derruir",
    "derruireis": "derruir",
    "derruiremos": "derruir",
    "derruiria": "derruir",
    "derruiriam": "derruir",
    "derruirias": "derruir",
    "derruirmo": "derruir",
    "derruirmos": "derruir",
    "derruirá": "derruir",
    "derruirás": "derruir",
    "derruirão": "derruir",
    "derruiríamos": "derruir",
    "derruiríeis": "derruir",
    "derruis": "derruir",
    "derruiu": "derruir",
    "derruições": "derruição",
    "derruo": "derruir",
    "derruí": "derruir",
    "derruía": "derruir",
    "derruíam": "derruir",
    "derruíamo": "derruir",
    "derruíamos": "derruir",
    "derruías": "derruir",
    "derruída": "derruir",
    "derruídas": "derruir",
    "derruído": "derruir",
    "derruídos": "derruir",
    "derruíei": "derruir",
    "derruíeis": "derruir",
    "derruímo": "derruir",
    "derruímos": "derruir",
    "derruíra": "derruir",
    "derruíram": "derruir",
    "derruíramo": "derruir",
    "derruíramos": "derruir",
    "derruíras": "derruir",
    "derruíre": "derruir",
    "derruírei": "derruir",
    "derruíreis": "derruir",
    "derruírem": "derruir",
    "derruíres": "derruir",
    "derruís": "derruir",
    "derruísse": "derruir",
    "derruísseis": "derruir",
    "derruíssem": "derruir",
    "derruíssemos": "derruir",
    "derruísses": "derruir",
    "derruíste": "derruir",
    "derruístes": "derruir",
    "dervises": "dervis",
    "dervixes": "dervixe",
    "desaba": "desabar",
    "desabada": "desabar",
    "desabadas": "desabar",
    "desabado": "desabar",
    "desabados": "desabar",
    "desabafa": "desabafar",
    "desabafada": "desabafar",
    "desabafadas": "desabafar",
    "desabafado": "desabafar",
    "desabafados": "desabafar",
    "desabafai": "desabafar",
    "desabafais": "desabafar",
    "desabafam": "desabafar",
    "desabafamentos": "desabafamento",
    "desabafamo": "desabafar",
    "desabafamos": "desabafar",
    "desabafando": "desabafar",
    "desabafara": "desabafar",
    "desabafaram": "desabafar",
    "desabafaras": "desabafar",
    "desabafarde": "desabafar",
    "desabafardes": "desabafar",
    "desabafare": "desabafar",
    "desabafarei": "desabafar",
    "desabafareis": "desabafar",
    "desabafarem": "desabafar",
    "desabafaremos": "desabafar",
    "desabafares": "desabafar",
    "desabafaria": "desabafar",
    "desabafariam": "desabafar",
    "desabafarias": "desabafar",
    "desabafarmo": "desabafar",
    "desabafarmos": "desabafar",
    "desabafará": "desabafar",
    "desabafarás": "desabafar",
    "desabafarão": "desabafar",
    "desabafaríamos": "desabafar",
    "desabafaríeis": "desabafar",
    "desabafas": "desabafar",
    "desabafasse": "desabafar",
    "desabafassem": "desabafar",
    "desabafasses": "desabafar",
    "desabafaste": "desabafar",
    "desabafastes": "desabafar",
    "desabafava": "desabafar",
    "desabafavam": "desabafar",
    "desabafavas": "desabafar",
    "desabafe": "desabafar",
    "desabafei": "desabafar",
    "desabafeis": "desabafar",
    "desabafem": "desabafar",
    "desabafemo": "desabafar",
    "desabafemos": "desabafar",
    "desabafes": "desabafar",
    "desabafo": "desabafar",
    "desabafos": "desabafo",
    "desabafou": "desabafar",
    "desabafá": "desabafar",
    "desabafámo": "desabafar",
    "desabafámos": "desabafar",
    "desabafáramo": "desabafar",
    "desabafáramos": "desabafar",
    "desabafárei": "desabafar",
    "desabafáreis": "desabafar",
    "desabafásseis": "desabafar",
    "desabafássemos": "desabafar",
    "desabafávamo": "desabafar",
    "desabafávamos": "desabafar",
    "desabafávei": "desabafar",
    "desabafáveis": "desabafar",
    "desabai": "desabar",
    "desabais": "desabar",
    "desabala": "desabalar",
    "desabalada": "desabalar",
    "desabaladas": "desabalar",
    "desabalado": "desabalar",
    "desabalados": "desabalar",
    "desabalai": "desabalar",
    "desabalais": "desabalar",
    "desabalam": "desabalar",
    "desabalamo": "desabalar",
    "desabalamos": "desabalar",
    "desabalando": "desabalar",
    "desabalara": "desabalar",
    "desabalaram": "desabalar",
    "desabalaras": "desabalar",
    "desabalardes": "desabalar",
    "desabalarei": "desabalar",
    "desabalareis": "desabalar",
    "desabalarem": "desabalar",
    "desabalaremos": "desabalar",
    "desabalares": "desabalar",
    "desabalaria": "desabalar",
    "desabalariam": "desabalar",
    "desabalarias": "desabalar",
    "desabalarmo": "desabalar",
    "desabalarmos": "desabalar",
    "desabalará": "desabalar",
    "desabalarás": "desabalar",
    "desabalarão": "desabalar",
    "desabalaríamos": "desabalar",
    "desabalaríeis": "desabalar",
    "desabalas": "desabalar",
    "desabalasse": "desabalar",
    "desabalassem": "desabalar",
    "desabalasses": "desabalar",
    "desabalaste": "desabalar",
    "desabalastes": "desabalar",
    "desabalava": "desabalar",
    "desabalavam": "desabalar",
    "desabalavas": "desabalar",
    "desabale": "desabalar",
    "desabalei": "desabalar",
    "desabaleis": "desabalar",
    "desabalem": "desabalar",
    "desabalemo": "desabalar",
    "desabalemos": "desabalar",
    "desabales": "desabalar",
    "desabalo": "desabalar",
    "desabalou": "desabalar",
    "desabalroa": "desabalroar",
    "desabalroada": "desabalroar",
    "desabalroadas": "desabalroar",
    "desabalroado": "desabalroar",
    "desabalroados": "desabalroar",
    "desabalroai": "desabalroar",
    "desabalroais": "desabalroar",
    "desabalroam": "desabalroar",
    "desabalroamo": "desabalroar",
    "desabalroamos": "desabalroar",
    "desabalroando": "desabalroar",
    "desabalroara": "desabalroar",
    "desabalroaram": "desabalroar",
    "desabalroaras": "desabalroar",
    "desabalroarde": "desabalroar",
    "desabalroardes": "desabalroar",
    "desabalroare": "desabalroar",
    "desabalroarei": "desabalroar",
    "desabalroareis": "desabalroar",
    "desabalroarem": "desabalroar",
    "desabalroaremos": "desabalroar",
    "desabalroares": "desabalroar",
    "desabalroaria": "desabalroar",
    "desabalroariam": "desabalroar",
    "desabalroarias": "desabalroar",
    "desabalroarmo": "desabalroar",
    "desabalroarmos": "desabalroar",
    "desabalroará": "desabalroar",
    "desabalroarás": "desabalroar",
    "desabalroarão": "desabalroar",
    "desabalroaríamos": "desabalroar",
    "desabalroaríeis": "desabalroar",
    "desabalroas": "desabalroar",
    "desabalroasse": "desabalroar",
    "desabalroassem": "desabalroar",
    "desabalroasses": "desabalroar",
    "desabalroaste": "desabalroar",
    "desabalroastes": "desabalroar",
    "desabalroava": "desabalroar",
    "desabalroavam": "desabalroar",
    "desabalroavas": "desabalroar",
    "desabalroe": "desabalroar",
    "desabalroei": "desabalroar",
    "desabalroeis": "desabalroar",
    "desabalroem": "desabalroar",
    "desabalroemo": "desabalroar",
    "desabalroemos": "desabalroar",
    "desabalroes": "desabalroar",
    "desabalroo": "desabalroar",
    "desabalroou": "desabalroar",
    "desabalroá": "desabalroar",
    "desabalroámo": "desabalroar",
    "desabalroámos": "desabalroar",
    "desabalroáramo": "desabalroar",
    "desabalroáramos": "desabalroar",
    "desabalroárei": "desabalroar",
    "desabalroáreis": "desabalroar",
    "desabalroásseis": "desabalroar",
    "desabalroássemos": "desabalroar",
    "desabalroávamo": "desabalroar",
    "desabalroávamos": "desabalroar",
    "desabalroávei": "desabalroar",
    "desabalroáveis": "desabalroar",
    "desabalámo": "desabalar",
    "desabalámos": "desabalar",
    "desabaláramo": "desabalar",
    "desabaláramos": "desabalar",
    "desabaláreis": "desabalar",
    "desabalásseis": "desabalar",
    "desabalássemos": "desabalar",
    "desabalávamo": "desabalar",
    "desabalávamos": "desabalar",
    "desabaláveis": "desabalar",
    "desabam": "desabar",
    "desabamentos": "desabamento",
    "desabamo": "desabar",
    "desabamos": "desabar",
    "desabando": "desabar",
    "desabara": "desabar",
    "desabaram": "desabar",
    "desabaras": "desabar",
    "desabardes": "desabar",
    "desabarei": "desabar",
    "desabareis": "desabar",
    "desabarem": "desabar",
    "desabaremos": "desabar",
    "desabares": "desabar",
    "desabaria": "desabar",
    "desabariam": "desabar",
    "desabarias": "desabar",
    "desabarmo": "desabar",
    "desabarmos": "desabar",
    "desabará": "desabar",
    "desabarás": "desabar",
    "desabarão": "desabar",
    "desabaríamos": "desabar",
    "desabaríeis": "desabar",
    "desabas": "desabar",
    "desabasse": "desabar",
    "desabassem": "desabar",
    "desabasses": "desabar",
    "desabastada": "desabastado",
    "desabastadas": "desabastado",
    "desabastados": "desabastado",
    "desabaste": "desabar",
    "desabastecida": "desabastecido",
    "desabastecidas": "desabastecido",
    "desabastecidos": "desabastecido",
    "desabastes": "desabar",
    "desabava": "desabar",
    "desabavam": "desabar",
    "desabavas": "desabar",
    "desabe": "desabar",
    "desabei": "desabar",
    "desabeira": "desabeirar",
    "desabeirada": "desabeirar",
    "desabeiradas": "desabeirar",
    "desabeirado": "desabeirar",
    "desabeirados": "desabeirar",
    "desabeirai": "desabeirar",
    "desabeirais": "desabeirar",
    "desabeiram": "desabeirar",
    "desabeiramo": "desabeirar",
    "desabeiramos": "desabeirar",
    "desabeirando": "desabeirar",
    "desabeirara": "desabeirar",
    "desabeiraram": "desabeirar",
    "desabeiraras": "desabeirar",
    "desabeirarde": "desabeirar",
    "desabeirardes": "desabeirar",
    "desabeirare": "desabeirar",
    "desabeirarei": "desabeirar",
    "desabeirareis": "desabeirar",
    "desabeirarem": "desabeirar",
    "desabeiraremos": "desabeirar",
    "desabeirares": "desabeirar",
    "desabeiraria": "desabeirar",
    "desabeirariam": "desabeirar",
    "desabeirarias": "desabeirar",
    "desabeirarmo": "desabeirar",
    "desabeirarmos": "desabeirar",
    "desabeirará": "desabeirar",
    "desabeirarás": "desabeirar",
    "desabeirarão": "desabeirar",
    "desabeiraríamos": "desabeirar",
    "desabeiraríeis": "desabeirar",
    "desabeiras": "desabeirar",
    "desabeirasse": "desabeirar",
    "desabeirassem": "desabeirar",
    "desabeirasses": "desabeirar",
    "desabeiraste": "desabeirar",
    "desabeirastes": "desabeirar",
    "desabeirava": "desabeirar",
    "desabeiravam": "desabeirar",
    "desabeiravas": "desabeirar",
    "desabeire": "desabeirar",
    "desabeirei": "desabeirar",
    "desabeireis": "desabeirar",
    "desabeirem": "desabeirar",
    "desabeiremo": "desabeirar",
    "desabeiremos": "desabeirar",
    "desabeires": "desabeirar",
    "desabeiro": "desabeirar",
    "desabeirou": "desabeirar",
    "desabeirá": "desabeirar",
    "desabeirámo": "desabeirar",
    "desabeirámos": "desabeirar",
    "desabeiráramo": "desabeirar",
    "desabeiráramos": "desabeirar",
    "desabeirárei": "desabeirar",
    "desabeiráreis": "desabeirar",
    "desabeirásseis": "desabeirar",
    "desabeirássemos": "desabeirar",
    "desabeirávamo": "desabeirar",
    "desabeirávamos": "desabeirar",
    "desabeirávei": "desabeirar",
    "desabeiráveis": "desabeirar",
    "desabeis": "desabar",
    "desabelha": "desabelhar",
    "desabelhada": "desabelhar",
    "desabelhadas": "desabelhar",
    "desabelhado": "desabelhar",
    "desabelhados": "desabelhar",
    "desabelhai": "desabelhar",
    "desabelhais": "desabelhar",
    "desabelham": "desabelhar",
    "desabelhamentos": "desabelhamento",
    "desabelhamo": "desabelhar",
    "desabelhamos": "desabelhar",
    "desabelhando": "desabelhar",
    "desabelhara": "desabelhar",
    "desabelharam": "desabelhar",
    "desabelharas": "desabelhar",
    "desabelharde": "desabelhar",
    "desabelhardes": "desabelhar",
    "desabelhare": "desabelhar",
    "desabelharei": "desabelhar",
    "desabelhareis": "desabelhar",
    "desabelharem": "desabelhar",
    "desabelharemos": "desabelhar",
    "desabelhares": "desabelhar",
    "desabelharia": "desabelhar",
    "desabelhariam": "desabelhar",
    "desabelharias": "desabelhar",
    "desabelharmo": "desabelhar",
    "desabelharmos": "desabelhar",
    "desabelhará": "desabelhar",
    "desabelharás": "desabelhar",
    "desabelharão": "desabelhar",
    "desabelharíamos": "desabelhar",
    "desabelharíeis": "desabelhar",
    "desabelhas": "desabelhar",
    "desabelhasse": "desabelhar",
    "desabelhassem": "desabelhar",
    "desabelhasses": "desabelhar",
    "desabelhaste": "desabelhar",
    "desabelhastes": "desabelhar",
    "desabelhava": "desabelhar",
    "desabelhavam": "desabelhar",
    "desabelhavas": "desabelhar",
    "desabelhe": "desabelhar",
    "desabelhei": "desabelhar",
    "desabelheis": "desabelhar",
    "desabelhem": "desabelhar",
    "desabelhemo": "desabelhar",
    "desabelhemos": "desabelhar",
    "desabelhes": "desabelhar",
    "desabelho": "desabelhar",
    "desabelhos": "desabelho",
    "desabelhou": "desabelhar",
    "desabelhá": "desabelhar",
    "desabelhámo": "desabelhar",
    "desabelhámos": "desabelhar",
    "desabelháramo": "desabelhar",
    "desabelháramos": "desabelhar",
    "desabelhárei": "desabelhar",
    "desabelháreis": "desabelhar",
    "desabelhásseis": "desabelhar",
    "desabelhássemos": "desabelhar",
    "desabelhávamo": "desabelhar",
    "desabelhávamos": "desabelhar",
    "desabelhávei": "desabelhar",
    "desabelháveis": "desabelhar",
    "desabem": "desabar",
    "desabemo": "desabar",
    "desabemos": "desabar",
    "desabes": "desabe",
    "desabilidades": "desabilidade",
    "desabilita": "desabilitar",
    "desabilitada": "desabilitar",
    "desabilitadas": "desabilitar",
    "desabilitado": "desabilitar",
    "desabilitados": "desabilitar",
    "desabilitai": "desabilitar",
    "desabilitais": "desabilitar",
    "desabilitam": "desabilitar",
    "desabilitamo": "desabilitar",
    "desabilitamos": "desabilitar",
    "desabilitando": "desabilitar",
    "desabilitara": "desabilitar",
    "desabilitaram": "desabilitar",
    "desabilitaras": "desabilitar",
    "desabilitarde": "desabilitar",
    "desabilitardes": "desabilitar",
    "desabilitare": "desabilitar",
    "desabilitarei": "desabilitar",
    "desabilitareis": "desabilitar",
    "desabilitarem": "desabilitar",
    "desabilitaremos": "desabilitar",
    "desabilitares": "desabilitar",
    "desabilitaria": "desabilitar",
    "desabilitariam": "desabilitar",
    "desabilitarias": "desabilitar",
    "desabilitarmo": "desabilitar",
    "desabilitarmos": "desabilitar",
    "desabilitará": "desabilitar",
    "desabilitarás": "desabilitar",
    "desabilitarão": "desabilitar",
    "desabilitaríamos": "desabilitar",
    "desabilitaríeis": "desabilitar",
    "desabilitas": "desabilitar",
    "desabilitasse": "desabilitar",
    "desabilitassem": "desabilitar",
    "desabilitasses": "desabilitar",
    "desabilitaste": "desabilitar",
    "desabilitastes": "desabilitar",
    "desabilitava": "desabilitar",
    "desabilitavam": "desabilitar",
    "desabilitavas": "desabilitar",
    "desabilite": "desabilitar",
    "desabilitei": "desabilitar",
    "desabiliteis": "desabilitar",
    "desabilitem": "desabilitar",
    "desabilitemo": "desabilitar",
    "desabilitemos": "desabilitar",
    "desabilites": "desabilitar",
    "desabilito": "desabilitar",
    "desabilitou": "desabilitar",
    "desabilitá": "desabilitar",
    "desabilitámo": "desabilitar",
    "desabilitámos": "desabilitar",
    "desabilitáramo": "desabilitar",
    "desabilitáramos": "desabilitar",
    "desabilitárei": "desabilitar",
    "desabilitáreis": "desabilitar",
    "desabilitásseis": "desabilitar",
    "desabilitássemos": "desabilitar",
    "desabilitávamo": "desabilitar",
    "desabilitávamos": "desabilitar",
    "desabilitávei": "desabilitar",
    "desabilitáveis": "desabilitar",
    "desabita": "desabitar",
    "desabitada": "desabitar",
    "desabitadas": "desabitar",
    "desabitado": "desabitar",
    "desabitados": "desabitar",
    "desabitai": "desabitar",
    "desabitais": "desabitar",
    "desabitam": "desabitar",
    "desabitamo": "desabitar",
    "desabitamos": "desabitar",
    "desabitando": "desabitar",
    "desabitara": "desabitar",
    "desabitaram": "desabitar",
    "desabitaras": "desabitar",
    "desabitarde": "desabitar",
    "desabitardes": "desabitar",
    "desabitare": "desabitar",
    "desabitarei": "desabitar",
    "desabitareis": "desabitar",
    "desabitarem": "desabitar",
    "desabitaremos": "desabitar",
    "desabitares": "desabitar",
    "desabitaria": "desabitar",
    "desabitariam": "desabitar",
    "desabitarias": "desabitar",
    "desabitarmo": "desabitar",
    "desabitarmos": "desabitar",
    "desabitará": "desabitar",
    "desabitarás": "desabitar",
    "desabitarão": "desabitar",
    "desabitaríamos": "desabitar",
    "desabitaríeis": "desabitar",
    "desabitas": "desabitar",
    "desabitasse": "desabitar",
    "desabitassem": "desabitar",
    "desabitasses": "desabitar",
    "desabitaste": "desabitar",
    "desabitastes": "desabitar",
    "desabitava": "desabitar",
    "desabitavam": "desabitar",
    "desabitavas": "desabitar",
    "desabite": "desabitar",
    "desabitei": "desabitar",
    "desabiteis": "desabitar",
    "desabitem": "desabitar",
    "desabitemo": "desabitar",
    "desabitemos": "desabitar",
    "desabites": "desabitar",
    "desabito": "desabitar",
    "desabitou": "desabitar",
    "desabitua": "desabituar",
    "desabituada": "desabituar",
    "desabituadas": "desabituar",
    "desabituado": "desabituar",
    "desabituados": "desabituar",
    "desabituai": "desabituar",
    "desabituais": "desabituar",
    "desabituam": "desabituar",
    "desabituamo": "desabituar",
    "desabituamos": "desabituar",
    "desabituando": "desabituar",
    "desabituara": "desabituar",
    "desabituaram": "desabituar",
    "desabituaras": "desabituar",
    "desabituarde": "desabituar",
    "desabituardes": "desabituar",
    "desabituare": "desabituar",
    "desabituarei": "desabituar",
    "desabituareis": "desabituar",
    "desabituarem": "desabituar",
    "desabituaremos": "desabituar",
    "desabituares": "desabituar",
    "desabituaria": "desabituar",
    "desabituariam": "desabituar",
    "desabituarias": "desabituar",
    "desabituarmo": "desabituar",
    "desabituarmos": "desabituar",
    "desabituará": "desabituar",
    "desabituarás": "desabituar",
    "desabituarão": "desabituar",
    "desabituaríamos": "desabituar",
    "desabituaríeis": "desabituar",
    "desabituas": "desabituar",
    "desabituasse": "desabituar",
    "desabituassem": "desabituar",
    "desabituasses": "desabituar",
    "desabituaste": "desabituar",
    "desabituastes": "desabituar",
    "desabituava": "desabituar",
    "desabituavam": "desabituar",
    "desabituavas": "desabituar",
    "desabituações": "desabituação",
    "desabitue": "desabituar",
    "desabituei": "desabituar",
    "desabitueis": "desabituar",
    "desabituem": "desabituar",
    "desabituemo": "desabituar",
    "desabituemos": "desabituar",
    "desabitues": "desabituar",
    "desabituo": "desabituar",
    "desabituou": "desabituar",
    "desabituá": "desabituar",
    "desabituámo": "desabituar",
    "desabituámos": "desabituar",
    "desabituáramo": "desabituar",
    "desabituáramos": "desabituar",
    "desabituárei": "desabituar",
    "desabituáreis": "desabituar",
    "desabituásseis": "desabituar",
    "desabituássemos": "desabituar",
    "desabituávamo": "desabituar",
    "desabituávamos": "desabituar",
    "desabituávei": "desabituar",
    "desabituáveis": "desabituar",
    "desabitá": "desabitar",
    "desabitámo": "desabitar",
    "desabitámos": "desabitar",
    "desabitáramo": "desabitar",
    "desabitáramos": "desabitar",
    "desabitárei": "desabitar",
    "desabitáreis": "desabitar",
    "desabitásseis": "desabitar",
    "desabitássemos": "desabitar",
    "desabitávamo": "desabitar",
    "desabitávamos": "desabitar",
    "desabitávei": "desabitar",
    "desabitáveis": "desabitar",
    "desabo": "desabar",
    "desabona": "desabonar",
    "desabonada": "desabonar",
    "desabonadas": "desabonar",
    "desabonado": "desabonar",
    "desabonadora": "desabonador",
    "desabonadoras": "desabonador",
    "desabonadores": "desabonador",
    "desabonados": "desabonar",
    "desabonai": "desabonar",
    "desabonais": "desabonar",
    "desabonam": "desabonar",
    "desabonamo": "desabonar",
    "desabonamos": "desabonar",
    "desabonando": "desabonar",
    "desabonara": "desabonar",
    "desabonaram": "desabonar",
    "desabonaras": "desabonar",
    "desabonarde": "desabonar",
    "desabonardes": "desabonar",
    "desabonare": "desabonar",
    "desabonarei": "desabonar",
    "desabonareis": "desabonar",
    "desabonarem": "desabonar",
    "desabonaremos": "desabonar",
    "desabonares": "desabonar",
    "desabonaria": "desabonar",
    "desabonariam": "desabonar",
    "desabonarias": "desabonar",
    "desabonarmo": "desabonar",
    "desabonarmos": "desabonar",
    "desabonará": "desabonar",
    "desabonarás": "desabonar",
    "desabonarão": "desabonar",
    "desabonaríamos": "desabonar",
    "desabonaríeis": "desabonar",
    "desabonas": "desabonar",
    "desabonasse": "desabonar",
    "desabonassem": "desabonar",
    "desabonasses": "desabonar",
    "desabonaste": "desabonar",
    "desabonastes": "desabonar",
    "desabonava": "desabonar",
    "desabonavam": "desabonar",
    "desabonavas": "desabonar",
    "desabone": "desabonar",
    "desabonei": "desabonar",
    "desaboneis": "desabonar",
    "desabonem": "desabonar",
    "desabonemo": "desabonar",
    "desabonemos": "desabonar",
    "desabones": "desabonar",
    "desabono": "desabonar",
    "desabonos": "desabono",
    "desabonou": "desabonar",
    "desaboná": "desabonar",
    "desabonámo": "desabonar",
    "desabonámos": "desabonar",
    "desabonáramo": "desabonar",
    "desabonáramos": "desabonar",
    "desabonárei": "desabonar",
    "desabonáreis": "desabonar",
    "desabonásseis": "desabonar",
    "desabonássemos": "desabonar",
    "desabonávamo": "desabonar",
    "desabonávamos": "desabonar",
    "desabonávei": "desabonar",
    "desabonáveis": "desabonar",
    "desaborda": "desabordar",
    "desabordada": "desabordar",
    "desabordadas": "desabordar",
    "desabordado": "desabordar",
    "desabordados": "desabordar",
    "desabordai": "desabordar",
    "desabordais": "desabordar",
    "desabordam": "desabordar",
    "desabordamo": "desabordar",
    "desabordamos": "desabordar",
    "desabordando": "desabordar",
    "desabordara": "desabordar",
    "desabordaram": "desabordar",
    "desabordaras": "desabordar",
    "desabordarde": "desabordar",
    "desabordardes": "desabordar",
    "desabordare": "desabordar",
    "desabordarei": "desabordar",
    "desabordareis": "desabordar",
    "desabordarem": "desabordar",
    "desabordaremos": "desabordar",
    "desabordares": "desabordar",
    "desabordaria": "desabordar",
    "desabordariam": "desabordar",
    "desabordarias": "desabordar",
    "desabordarmo": "desabordar",
    "desabordarmos": "desabordar",
    "desabordará": "desabordar",
    "desabordarás": "desabordar",
    "desabordarão": "desabordar",
    "desabordaríamos": "desabordar",
    "desabordaríeis": "desabordar",
    "desabordas": "desabordar",
    "desabordasse": "desabordar",
    "desabordassem": "desabordar",
    "desabordasses": "desabordar",
    "desabordaste": "desabordar",
    "desabordastes": "desabordar",
    "desabordava": "desabordar",
    "desabordavam": "desabordar",
    "desabordavas": "desabordar",
    "desaborde": "desabordar",
    "desabordei": "desabordar",
    "desabordeis": "desabordar",
    "desabordem": "desabordar",
    "desabordemo": "desabordar",
    "desabordemos": "desabordar",
    "desabordes": "desabordar",
    "desabordo": "desabordar",
    "desabordou": "desabordar",
    "desabordá": "desabordar",
    "desabordámo": "desabordar",
    "desabordámos": "desabordar",
    "desabordáramo": "desabordar",
    "desabordáramos": "desabordar",
    "desabordárei": "desabordar",
    "desabordáreis": "desabordar",
    "desabordásseis": "desabordar",
    "desabordássemos": "desabordar",
    "desabordávamo": "desabordar",
    "desabordávamos": "desabordar",
    "desabordávei": "desabordar",
    "desabordáveis": "desabordar",
    "desaborizada": "desaborizado",
    "desaborizadas": "desaborizado",
    "desaborizados": "desaborizado",
    "desaborrece": "desaborrecer",
    "desaborrecei": "desaborrecer",
    "desaborreceis": "desaborrecer",
    "desaborrecem": "desaborrecer",
    "desaborrecemo": "desaborrecer",
    "desaborrecemos": "desaborrecer",
    "desaborrecendo": "desaborrecer",
    "desaborrecera": "desaborrecer",
    "desaborreceram": "desaborrecer",
    "desaborreceras": "desaborrecer",
    "desaborrecerde": "desaborrecer",
    "desaborrecerdes": "desaborrecer",
    "desaborrecere": "desaborrecer",
    "desaborrecerei": "desaborrecer",
    "desaborrecereis": "desaborrecer",
    "desaborrecerem": "desaborrecer",
    "desaborreceremos": "desaborrecer",
    "desaborreceres": "desaborrecer",
    "desaborreceria": "desaborrecer",
    "desaborreceriam": "desaborrecer",
    "desaborrecerias": "desaborrecer",
    "desaborrecermo": "desaborrecer",
    "desaborrecermos": "desaborrecer",
    "desaborrecerá": "desaborrecer",
    "desaborrecerás": "desaborrecer",
    "desaborrecerão": "desaborrecer",
    "desaborreceríamos": "desaborrecer",
    "desaborreceríeis": "desaborrecer",
    "desaborreces": "desaborrecer",
    "desaborrecesse": "desaborrecer",
    "desaborrecessem": "desaborrecer",
    "desaborrecesses": "desaborrecer",
    "desaborreceste": "desaborrecer",
    "desaborrecestes": "desaborrecer",
    "desaborreceu": "desaborrecer",
    "desaborreci": "desaborrecer",
    "desaborrecia": "desaborrecer",
    "desaborreciam": "desaborrecer",
    "desaborrecias": "desaborrecer",
    "desaborrecida": "desaborrecido",
    "desaborrecidas": "desaborrecido",
    "desaborrecido": "desaborrecer",
    "desaborrecidos": "desaborrecido",
    "desaborrecê": "desaborrecer",
    "desaborrecêramo": "desaborrecer",
    "desaborrecêramos": "desaborrecer",
    "desaborrecêrei": "desaborrecer",
    "desaborrecêreis": "desaborrecer",
    "desaborrecêsseis": "desaborrecer",
    "desaborrecêssemos": "desaborrecer",
    "desaborrecíamo": "desaborrecer",
    "desaborrecíamos": "desaborrecer",
    "desaborrecíei": "desaborrecer",
    "desaborrecíeis": "desaborrecer",
    "desaborreça": "desaborrecer",
    "desaborreçais": "desaborrecer",
    "desaborreçam": "desaborrecer",
    "desaborreçamo": "desaborrecer",
    "desaborreçamos": "desaborrecer",
    "desaborreças": "desaborrecer",
    "desaborreço": "desaborrecer",
    "desabotoa": "desabotoar",
    "desabotoada": "desabotoar",
    "desabotoadas": "desabotoar",
    "desabotoado": "desabotoar",
    "desabotoados": "desabotoar",
    "desabotoaduras": "desabotoadura",
    "desabotoai": "desabotoar",
    "desabotoais": "desabotoar",
    "desabotoam": "desabotoar",
    "desabotoamentos": "desabotoamento",
    "desabotoamo": "desabotoar",
    "desabotoamos": "desabotoar",
    "desabotoando": "desabotoar",
    "desabotoara": "desabotoar",
    "desabotoaram": "desabotoar",
    "desabotoaras": "desabotoar",
    "desabotoarde": "desabotoar",
    "desabotoardes": "desabotoar",
    "desabotoare": "desabotoar",
    "desabotoarei": "desabotoar",
    "desabotoareis": "desabotoar",
    "desabotoarem": "desabotoar",
    "desabotoaremos": "desabotoar",
    "desabotoares": "desabotoar",
    "desabotoaria": "desabotoar",
    "desabotoariam": "desabotoar",
    "desabotoarias": "desabotoar",
    "desabotoarmo": "desabotoar",
    "desabotoarmos": "desabotoar",
    "desabotoará": "desabotoar",
    "desabotoarás": "desabotoar",
    "desabotoarão": "desabotoar",
    "desabotoaríamos": "desabotoar",
    "desabotoaríeis": "desabotoar",
    "desabotoas": "desabotoar",
    "desabotoasse": "desabotoar",
    "desabotoassem": "desabotoar",
    "desabotoasses": "desabotoar",
    "desabotoaste": "desabotoar",
    "desabotoastes": "desabotoar",
    "desabotoava": "desabotoar",
    "desabotoavam": "desabotoar",
    "desabotoavas": "desabotoar",
    "desabotoe": "desabotoar",
    "desabotoei": "desabotoar",
    "desabotoeis": "desabotoar",
    "desabotoem": "desabotoar",
    "desabotoemo": "desabotoar",
    "desabotoemos": "desabotoar",
    "desabotoes": "desabotoar",
    "desabotoo": "desabotoar",
    "desabotoou": "desabotoar",
    "desabotoá": "desabotoar",
    "desabotoámo": "desabotoar",
    "desabotoámos": "desabotoar",
    "desabotoáramo": "desabotoar",
    "desabotoáramos": "desabotoar",
    "desabotoárei": "desabotoar",
    "desabotoáreis": "desabotoar",
    "desabotoásseis": "desabotoar",
    "desabotoássemos": "desabotoar",
    "desabotoávamo": "desabotoar",
    "desabotoávamos": "desabotoar",
    "desabotoávei": "desabotoar",
    "desabotoáveis": "desabotoar",
    "desabou": "desabar",
    "desabra": "desabrir",
    "desabrace": "desabraçar",
    "desabracei": "desabraçar",
    "desabraceis": "desabraçar",
    "desabracem": "desabraçar",
    "desabracemo": "desabraçar",
    "desabracemos": "desabraçar",
    "desabraces": "desabraçar",
    "desabrais": "desabrir",
    "desabram": "desabrir",
    "desabramo": "desabrir",
    "desabramos": "desabrir",
    "desabras": "desabrir",
    "desabraça": "desabraçar",
    "desabraçada": "desabraçar",
    "desabraçadas": "desabraçar",
    "desabraçado": "desabraçar",
    "desabraçados": "desabraçar",
    "desabraçai": "desabraçar",
    "desabraçais": "desabraçar",
    "desabraçam": "desabraçar",
    "desabraçamo": "desabraçar",
    "desabraçamos": "desabraçar",
    "desabraçando": "desabraçar",
    "desabraçara": "desabraçar",
    "desabraçaram": "desabraçar",
    "desabraçaras": "desabraçar",
    "desabraçarde": "desabraçar",
    "desabraçardes": "desabraçar",
    "desabraçare": "desabraçar",
    "desabraçarei": "desabraçar",
    "desabraçareis": "desabraçar",
    "desabraçarem": "desabraçar",
    "desabraçaremos": "desabraçar",
    "desabraçares": "desabraçar",
    "desabraçaria": "desabraçar",
    "desabraçariam": "desabraçar",
    "desabraçarias": "desabraçar",
    "desabraçarmo": "desabraçar",
    "desabraçarmos": "desabraçar",
    "desabraçará": "desabraçar",
    "desabraçarás": "desabraçar",
    "desabraçarão": "desabraçar",
    "desabraçaríamos": "desabraçar",
    "desabraçaríeis": "desabraçar",
    "desabraças": "desabraçar",
    "desabraçasse": "desabraçar",
    "desabraçassem": "desabraçar",
    "desabraçasses": "desabraçar",
    "desabraçaste": "desabraçar",
    "desabraçastes": "desabraçar",
    "desabraçava": "desabraçar",
    "desabraçavam": "desabraçar",
    "desabraçavas": "desabraçar",
    "desabraço": "desabraçar",
    "desabraçou": "desabraçar",
    "desabraçá": "desabraçar",
    "desabraçámo": "desabraçar",
    "desabraçámos": "desabraçar",
    "desabraçáramo": "desabraçar",
    "desabraçáramos": "desabraçar",
    "desabraçárei": "desabraçar",
    "desabraçáreis": "desabraçar",
    "desabraçásseis": "desabraçar",
    "desabraçássemos": "desabraçar",
    "desabraçávamo": "desabraçar",
    "desabraçávamos": "desabraçar",
    "desabraçávei": "desabraçar",
    "desabraçáveis": "desabraçar",
    "desabre": "desabrir",
    "desabrem": "desabrir",
    "desabres": "desabrir",
    "desabri": "desabrir",
    "desabria": "desabrir",
    "desabriam": "desabrir",
    "desabrias": "desabrir",
    "desabrida": "desabrir",
    "desabridas": "desabrir",
    "desabrido": "desabrir",
    "desabridos": "desabrir",
    "desabriga": "desabrigar",
    "desabrigada": "desabrigar",
    "desabrigadas": "desabrigar",
    "desabrigado": "desabrigar",
    "desabrigados": "desabrigar",
    "desabrigai": "desabrigar",
    "desabrigais": "desabrigar",
    "desabrigam": "desabrigar",
    "desabrigamo": "desabrigar",
    "desabrigamos": "desabrigar",
    "desabrigando": "desabrigar",
    "desabrigara": "desabrigar",
    "desabrigaram": "desabrigar",
    "desabrigaras": "desabrigar",
    "desabrigarde": "desabrigar",
    "desabrigardes": "desabrigar",
    "desabrigare": "desabrigar",
    "desabrigarei": "desabrigar",
    "desabrigareis": "desabrigar",
    "desabrigarem": "desabrigar",
    "desabrigaremos": "desabrigar",
    "desabrigares": "desabrigar",
    "desabrigaria": "desabrigar",
    "desabrigariam": "desabrigar",
    "desabrigarias": "desabrigar",
    "desabrigarmo": "desabrigar",
    "desabrigarmos": "desabrigar",
    "desabrigará": "desabrigar",
    "desabrigarás": "desabrigar",
    "desabrigarão": "desabrigar",
    "desabrigaríamos": "desabrigar",
    "desabrigaríeis": "desabrigar",
    "desabrigas": "desabrigar",
    "desabrigasse": "desabrigar",
    "desabrigassem": "desabrigar",
    "desabrigasses": "desabrigar",
    "desabrigaste": "desabrigar",
    "desabrigastes": "desabrigar",
    "desabrigava": "desabrigar",
    "desabrigavam": "desabrigar",
    "desabrigavas": "desabrigar",
    "desabrigo": "desabrigar",
    "desabrigos": "desabrigo",
    "desabrigou": "desabrigar",
    "desabrigue": "desabrigar",
    "desabriguei": "desabrigar",
    "desabrigueis": "desabrigar",
    "desabriguem": "desabrigar",
    "desabriguemo": "desabrigar",
    "desabriguemos": "desabrigar",
    "desabrigues": "desabrigar",
    "desabrigá": "desabrigar",
    "desabrigámo": "desabrigar",
    "desabrigámos": "desabrigar",
    "desabrigáramo": "desabrigar",
    "desabrigáramos": "desabrigar",
    "desabrigárei": "desabrigar",
    "desabrigáreis": "desabrigar",
    "desabrigásseis": "desabrigar",
    "desabrigássemos": "desabrigar",
    "desabrigávamo": "desabrigar",
    "desabrigávamos": "desabrigar",
    "desabrigávei": "desabrigar",
    "desabrigáveis": "desabrigar",
    "desabrimentos": "desabrimento",
    "desabrimo": "desabrir",
    "desabrimos": "desabrir",
    "desabrindo": "desabrir",
    "desabrira": "desabrir",
    "desabriram": "desabrir",
    "desabriras": "desabrir",
    "desabrirde": "desabrir",
    "desabrirdes": "desabrir",
    "desabrire": "desabrir",
    "desabrirei": "desabrir",
    "desabrireis": "desabrir",
    "desabrirem": "desabrir",
    "desabriremos": "desabrir",
    "desabrires": "desabrir",
    "desabriria": "desabrir",
    "desabririam": "desabrir",
    "desabririas": "desabrir",
    "desabrirmo": "desabrir",
    "desabrirmos": "desabrir",
    "desabrirá": "desabrir",
    "desabrirás": "desabrir",
    "desabrirão": "desabrir",
    "desabriríamos": "desabrir",
    "desabriríeis": "desabrir",
    "desabris": "desabrir",
    "desabrisse": "desabrir",
    "desabrissem": "desabrir",
    "desabrisses": "desabrir",
    "desabriste": "desabrir",
    "desabristes": "desabrir",
    "desabriu": "desabrir",
    "desabro": "desabrir",
    "desabrocha": "desabrochar",
    "desabrochada": "desabrochar",
    "desabrochadas": "desabrochar",
    "desabrochado": "desabrochar",
    "desabrochados": "desabrochar",
    "desabrochai": "desabrochar",
    "desabrochais": "desabrochar",
    "desabrocham": "desabrochar",
    "desabrochamentos": "desabrochamento",
    "desabrochamo": "desabrochar",
    "desabrochamos": "desabrochar",
    "desabrochando": "desabrochar",
    "desabrochara": "desabrochar",
    "desabrocharam": "desabrochar",
    "desabrocharas": "desabrochar",
    "desabrocharde": "desabrochar",
    "desabrochardes": "desabrochar",
    "desabrochare": "desabrochar",
    "desabrocharei": "desabrochar",
    "desabrochareis": "desabrochar",
    "desabrocharem": "desabrochar",
    "desabrocharemos": "desabrochar",
    "desabrochares": "desabrochar",
    "desabrocharia": "desabrochar",
    "desabrochariam": "desabrochar",
    "desabrocharias": "desabrochar",
    "desabrocharmo": "desabrochar",
    "desabrocharmos": "desabrochar",
    "desabrochará": "desabrochar",
    "desabrocharás": "desabrochar",
    "desabrocharão": "desabrochar",
    "desabrocharíamos": "desabrochar",
    "desabrocharíeis": "desabrochar",
    "desabrochas": "desabrochar",
    "desabrochasse": "desabrochar",
    "desabrochassem": "desabrochar",
    "desabrochasses": "desabrochar",
    "desabrochaste": "desabrochar",
    "desabrochastes": "desabrochar",
    "desabrochava": "desabrochar",
    "desabrochavam": "desabrochar",
    "desabrochavas": "desabrochar",
    "desabroche": "desabrochar",
    "desabrochei": "desabrochar",
    "desabrocheis": "desabrochar",
    "desabrochem": "desabrochar",
    "desabrochemo": "desabrochar",
    "desabrochemos": "desabrochar",
    "desabroches": "desabrochar",
    "desabrocho": "desabrochar",
    "desabrochou": "desabrochar",
    "desabrochá": "desabrochar",
    "desabrochámo": "desabrochar",
    "desabrochámos": "desabrochar",
    "desabrocháramo": "desabrochar",
    "desabrocháramos": "desabrochar",
    "desabrochárei": "desabrochar",
    "desabrocháreis": "desabrochar",
    "desabrochásseis": "desabrochar",
    "desabrochássemos": "desabrochar",
    "desabrochávamo": "desabrochar",
    "desabrochávamos": "desabrochar",
    "desabrochávei": "desabrochar",
    "desabrocháveis": "desabrochar",
    "desabrolha": "desabrolhar",
    "desabrolhada": "desabrolhar",
    "desabrolhadas": "desabrolhar",
    "desabrolhado": "desabrolhar",
    "desabrolhados": "desabrolhar",
    "desabrolhai": "desabrolhar",
    "desabrolhais": "desabrolhar",
    "desabrolham": "desabrolhar",
    "desabrolhamo": "desabrolhar",
    "desabrolhamos": "desabrolhar",
    "desabrolhando": "desabrolhar",
    "desabrolhara": "desabrolhar",
    "desabrolharam": "desabrolhar",
    "desabrolharas": "desabrolhar",
    "desabrolhardes": "desabrolhar",
    "desabrolharei": "desabrolhar",
    "desabrolhareis": "desabrolhar",
    "desabrolharem": "desabrolhar",
    "desabrolharemos": "desabrolhar",
    "desabrolhares": "desabrolhar",
    "desabrolharia": "desabrolhar",
    "desabrolhariam": "desabrolhar",
    "desabrolharias": "desabrolhar",
    "desabrolharmo": "desabrolhar",
    "desabrolharmos": "desabrolhar",
    "desabrolhará": "desabrolhar",
    "desabrolharás": "desabrolhar",
    "desabrolharão": "desabrolhar",
    "desabrolharíamos": "desabrolhar",
    "desabrolharíeis": "desabrolhar",
    "desabrolhas": "desabrolhar",
    "desabrolhasse": "desabrolhar",
    "desabrolhassem": "desabrolhar",
    "desabrolhasses": "desabrolhar",
    "desabrolhaste": "desabrolhar",
    "desabrolhastes": "desabrolhar",
    "desabrolhava": "desabrolhar",
    "desabrolhavam": "desabrolhar",
    "desabrolhavas": "desabrolhar",
    "desabrolhe": "desabrolhar",
    "desabrolhei": "desabrolhar",
    "desabrolheis": "desabrolhar",
    "desabrolhem": "desabrolhar",
    "desabrolhemo": "desabrolhar",
    "desabrolhemos": "desabrolhar",
    "desabrolhes": "desabrolhar",
    "desabrolho": "desabrolhar",
    "desabrolhou": "desabrolhar",
    "desabrolhámo": "desabrolhar",
    "desabrolhámos": "desabrolhar",
    "desabrolháramo": "desabrolhar",
    "desabrolháramos": "desabrolhar",
    "desabrolháreis": "desabrolhar",
    "desabrolhásseis": "desabrolhar",
    "desabrolhássemos": "desabrolhar",
    "desabrolhávamo": "desabrolhar",
    "desabrolhávamos": "desabrolhar",
    "desabrolháveis": "desabrolhar",
    "desabríamo": "desabrir",
    "desabríamos": "desabrir",
    "desabríei": "desabrir",
    "desabríeis": "desabrir",
    "desabríramo": "desabrir",
    "desabríramos": "desabrir",
    "desabrírei": "desabrir",
    "desabríreis": "desabrir",
    "desabrísseis": "desabrir",
    "desabríssemos": "desabrir",
    "desabusa": "desabusar",
    "desabusada": "desabusar",
    "desabusadas": "desabusar",
    "desabusado": "desabusar",
    "desabusados": "desabusar",
    "desabusai": "desabusar",
    "desabusais": "desabusar",
    "desabusam": "desabusar",
    "desabusamo": "desabusar",
    "desabusamos": "desabusar",
    "desabusando": "desabusar",
    "desabusara": "desabusar",
    "desabusaram": "desabusar",
    "desabusaras": "desabusar",
    "desabusarde": "desabusar",
    "desabusardes": "desabusar",
    "desabusare": "desabusar",
    "desabusarei": "desabusar",
    "desabusareis": "desabusar",
    "desabusarem": "desabusar",
    "desabusaremos": "desabusar",
    "desabusares": "desabusar",
    "desabusaria": "desabusar",
    "desabusariam": "desabusar",
    "desabusarias": "desabusar",
    "desabusarmo": "desabusar",
    "desabusarmos": "desabusar",
    "desabusará": "desabusar",
    "desabusarás": "desabusar",
    "desabusarão": "desabusar",
    "desabusaríamos": "desabusar",
    "desabusaríeis": "desabusar",
    "desabusas": "desabusar",
    "desabusasse": "desabusar",
    "desabusassem": "desabusar",
    "desabusasses": "desabusar",
    "desabusaste": "desabusar",
    "desabusastes": "desabusar",
    "desabusava": "desabusar",
    "desabusavam": "desabusar",
    "desabusavas": "desabusar",
    "desabuse": "desabusar",
    "desabusei": "desabusar",
    "desabuseis": "desabusar",
    "desabusem": "desabusar",
    "desabusemo": "desabusar",
    "desabusemos": "desabusar",
    "desabuses": "desabusar",
    "desabuso": "desabusar",
    "desabusos": "desabuso",
    "desabusou": "desabusar",
    "desabusá": "desabusar",
    "desabusámo": "desabusar",
    "desabusámos": "desabusar",
    "desabusáramo": "desabusar",
    "desabusáramos": "desabusar",
    "desabusárei": "desabusar",
    "desabusáreis": "desabusar",
    "desabusásseis": "desabusar",
    "desabusássemos": "desabusar",
    "desabusávamo": "desabusar",
    "desabusávamos": "desabusar",
    "desabusávei": "desabusar",
    "desabusáveis": "desabusar",
    "desabámo": "desabar",
    "desabámos": "desabar",
    "desabáramo": "desabar",
    "desabáramos": "desabar",
    "desabáreis": "desabar",
    "desabásseis": "desabar",
    "desabássemos": "desabar",
    "desabávamo": "desabar",
    "desabávamos": "desabar",
    "desabáveis": "desabar",
    "desacama": "desacamar",
    "desacamada": "desacamar",
    "desacamadas": "desacamar",
    "desacamado": "desacamar",
    "desacamados": "desacamar",
    "desacamai": "desacamar",
    "desacamais": "desacamar",
    "desacamam": "desacamar",
    "desacamamo": "desacamar",
    "desacamamos": "desacamar",
    "desacamando": "desacamar",
    "desacamara": "desacamar",
    "desacamarada": "desacamaradar",
    "desacamaradada": "desacamaradar",
    "desacamaradadas": "desacamaradar",
    "desacamaradado": "desacamaradar",
    "desacamaradados": "desacamaradar",
    "desacamaradai": "desacamaradar",
    "desacamaradais": "desacamaradar",
    "desacamaradam": "desacamaradar",
    "desacamaradamo": "desacamaradar",
    "desacamaradamos": "desacamaradar",
    "desacamaradando": "desacamaradar",
    "desacamaradara": "desacamaradar",
    "desacamaradaram": "desacamaradar",
    "desacamaradaras": "desacamaradar",
    "desacamaradarde": "desacamaradar",
    "desacamaradardes": "desacamaradar",
    "desacamaradare": "desacamaradar",
    "desacamaradarei": "desacamaradar",
    "desacamaradareis": "desacamaradar",
    "desacamaradarem": "desacamaradar",
    "desacamaradaremos": "desacamaradar",
    "desacamaradares": "desacamaradar",
    "desacamaradaria": "desacamaradar",
    "desacamaradariam": "desacamaradar",
    "desacamaradarias": "desacamaradar",
    "desacamaradarmo": "desacamaradar",
    "desacamaradarmos": "desacamaradar",
    "desacamaradará": "desacamaradar",
    "desacamaradarás": "desacamaradar",
    "desacamaradarão": "desacamaradar",
    "desacamaradaríamos": "desacamaradar",
    "desacamaradaríeis": "desacamaradar",
    "desacamaradas": "desacamaradar",
    "desacamaradasse": "desacamaradar",
    "desacamaradassem": "desacamaradar",
    "desacamaradasses": "desacamaradar",
    "desacamaradaste": "desacamaradar",
    "desacamaradastes": "desacamaradar",
    "desacamaradava": "desacamaradar",
    "desacamaradavam": "desacamaradar",
    "desacamaradavas": "desacamaradar",
    "desacamarade": "desacamaradar",
    "desacamaradei": "desacamaradar",
    "desacamaradeis": "desacamaradar",
    "desacamaradem": "desacamaradar",
    "desacamarademo": "desacamaradar",
    "desacamarademos": "desacamaradar",
    "desacamarades": "desacamaradar",
    "desacamarado": "desacamaradar",
    "desacamaradou": "desacamaradar",
    "desacamaradá": "desacamaradar",
    "desacamaradámo": "desacamaradar",
    "desacamaradámos": "desacamaradar",
    "desacamaradáramo": "desacamaradar",
    "desacamaradáramos": "desacamaradar",
    "desacamaradárei": "desacamaradar",
    "desacamaradáreis": "desacamaradar",
    "desacamaradásseis": "desacamaradar",
    "desacamaradássemos": "desacamaradar",
    "desacamaradávamo": "desacamaradar",
    "desacamaradávamos": "desacamaradar",
    "desacamaradávei": "desacamaradar",
    "desacamaradáveis": "desacamaradar",
    "desacamaram": "desacamar",
    "desacamaras": "desacamar",
    "desacamarde": "desacamar",
    "desacamardes": "desacamar",
    "desacamare": "desacamar",
    "desacamarei": "desacamar",
    "desacamareis": "desacamar",
    "desacamarem": "desacamar",
    "desacamaremos": "desacamar",
    "desacamares": "desacamar",
    "desacamaria": "desacamar",
    "desacamariam": "desacamar",
    "desacamarias": "desacamar",
    "desacamarmo": "desacamar",
    "desacamarmos": "desacamar",
    "desacamará": "desacamar",
    "desacamarás": "desacamar",
    "desacamarão": "desacamar",
    "desacamaríamos": "desacamar",
    "desacamaríeis": "desacamar",
    "desacamas": "desacamar",
    "desacamasse": "desacamar",
    "desacamassem": "desacamar",
    "desacamasses": "desacamar",
    "desacamaste": "desacamar",
    "desacamastes": "desacamar",
    "desacamava": "desacamar",
    "desacamavam": "desacamar",
    "desacamavas": "desacamar",
    "desacame": "desacamar",
    "desacamei": "desacamar",
    "desacameis": "desacamar",
    "desacamem": "desacamar",
    "desacamemo": "desacamar",
    "desacamemos": "desacamar",
    "desacames": "desacamar",
    "desacamo": "desacamar",
    "desacamou": "desacamar",
    "desacampa": "desacampar",
    "desacampada": "desacampar",
    "desacampadas": "desacampar",
    "desacampado": "desacampar",
    "desacampados": "desacampar",
    "desacampai": "desacampar",
    "desacampais": "desacampar",
    "desacampam": "desacampar",
    "desacampamo": "desacampar",
    "desacampamos": "desacampar",
    "desacampando": "desacampar",
    "desacampara": "desacampar",
    "desacamparam": "desacampar",
    "desacamparas": "desacampar",
    "desacampardes": "desacampar",
    "desacamparei": "desacampar",
    "desacampareis": "desacampar",
    "desacamparem": "desacampar",
    "desacamparemos": "desacampar",
    "desacampares": "desacampar",
    "desacamparia": "desacampar",
    "desacampariam": "desacampar",
    "desacamparias": "desacampar",
    "desacamparmo": "desacampar",
    "desacamparmos": "desacampar",
    "desacampará": "desacampar",
    "desacamparás": "desacampar",
    "desacamparão": "desacampar",
    "desacamparíamos": "desacampar",
    "desacamparíeis": "desacampar",
    "desacampas": "desacampar",
    "desacampasse": "desacampar",
    "desacampassem": "desacampar",
    "desacampasses": "desacampar",
    "desacampaste": "desacampar",
    "desacampastes": "desacampar",
    "desacampava": "desacampar",
    "desacampavam": "desacampar",
    "desacampavas": "desacampar",
    "desacampe": "desacampar",
    "desacampei": "desacampar",
    "desacampeis": "desacampar",
    "desacampem": "desacampar",
    "desacampemo": "desacampar",
    "desacampemos": "desacampar",
    "desacampes": "desacampar",
    "desacampo": "desacampar",
    "desacampou": "desacampar",
    "desacampámo": "desacampar",
    "desacampámos": "desacampar",
    "desacampáramo": "desacampar",
    "desacampáramos": "desacampar",
    "desacampáreis": "desacampar",
    "desacampásseis": "desacampar",
    "desacampássemos": "desacampar",
    "desacampávamo": "desacampar",
    "desacampávamos": "desacampar",
    "desacampáveis": "desacampar",
    "desacamá": "desacamar",
    "desacamámo": "desacamar",
    "desacamámos": "desacamar",
    "desacamáramo": "desacamar",
    "desacamáramos": "desacamar",
    "desacamárei": "desacamar",
    "desacamáreis": "desacamar",
    "desacamásseis": "desacamar",
    "desacamássemos": "desacamar",
    "desacamávamo": "desacamar",
    "desacamávamos": "desacamar",
    "desacamávei": "desacamar",
    "desacamáveis": "desacamar",
    "desacanalha": "desacanalhar",
    "desacanalhada": "desacanalhar",
    "desacanalhadas": "desacanalhar",
    "desacanalhado": "desacanalhar",
    "desacanalhados": "desacanalhar",
    "desacanalhai": "desacanalhar",
    "desacanalhais": "desacanalhar",
    "desacanalham": "desacanalhar",
    "desacanalhamo": "desacanalhar",
    "desacanalhamos": "desacanalhar",
    "desacanalhando": "desacanalhar",
    "desacanalhara": "desacanalhar",
    "desacanalharam": "desacanalhar",
    "desacanalharas": "desacanalhar",
    "desacanalharde": "desacanalhar",
    "desacanalhardes": "desacanalhar",
    "desacanalhare": "desacanalhar",
    "desacanalharei": "desacanalhar",
    "desacanalhareis": "desacanalhar",
    "desacanalharem": "desacanalhar",
    "desacanalharemos": "desacanalhar",
    "desacanalhares": "desacanalhar",
    "desacanalharia": "desacanalhar",
    "desacanalhariam": "desacanalhar",
    "desacanalharias": "desacanalhar",
    "desacanalharmo": "desacanalhar",
    "desacanalharmos": "desacanalhar",
    "desacanalhará": "desacanalhar",
    "desacanalharás": "desacanalhar",
    "desacanalharão": "desacanalhar",
    "desacanalharíamos": "desacanalhar",
    "desacanalharíeis": "desacanalhar",
    "desacanalhas": "desacanalhar",
    "desacanalhasse": "desacanalhar",
    "desacanalhassem": "desacanalhar",
    "desacanalhasses": "desacanalhar",
    "desacanalhaste": "desacanalhar",
    "desacanalhastes": "desacanalhar",
    "desacanalhava": "desacanalhar",
    "desacanalhavam": "desacanalhar",
    "desacanalhavas": "desacanalhar",
    "desacanalhe": "desacanalhar",
    "desacanalhei": "desacanalhar",
    "desacanalheis": "desacanalhar",
    "desacanalhem": "desacanalhar",
    "desacanalhemo": "desacanalhar",
    "desacanalhemos": "desacanalhar",
    "desacanalhes": "desacanalhar",
    "desacanalho": "desacanalhar",
    "desacanalhou": "desacanalhar",
    "desacanalhá": "desacanalhar",
    "desacanalhámo": "desacanalhar",
    "desacanalhámos": "desacanalhar",
    "desacanalháramo": "desacanalhar",
    "desacanalháramos": "desacanalhar",
    "desacanalhárei": "desacanalhar",
    "desacanalháreis": "desacanalhar",
    "desacanalhásseis": "desacanalhar",
    "desacanalhássemos": "desacanalhar",
    "desacanalhávamo": "desacanalhar",
    "desacanalhávamos": "desacanalhar",
    "desacanalhávei": "desacanalhar",
    "desacanalháveis": "desacanalhar",
    "desacanha": "desacanhar",
    "desacanhada": "desacanhar",
    "desacanhadas": "desacanhar",
    "desacanhado": "desacanhar",
    "desacanhados": "desacanhar",
    "desacanhai": "desacanhar",
    "desacanhais": "desacanhar",
    "desacanham": "desacanhar",
    "desacanhamentos": "desacanhamento",
    "desacanhamo": "desacanhar",
    "desacanhamos": "desacanhar",
    "desacanhando": "desacanhar",
    "desacanhara": "desacanhar",
    "desacanharam": "desacanhar",
    "desacanharas": "desacanhar",
    "desacanharde": "desacanhar",
    "desacanhardes": "desacanhar",
    "desacanhare": "desacanhar",
    "desacanharei": "desacanhar",
    "desacanhareis": "desacanhar",
    "desacanharem": "desacanhar",
    "desacanharemos": "desacanhar",
    "desacanhares": "desacanhar",
    "desacanharia": "desacanhar",
    "desacanhariam": "desacanhar",
    "desacanharias": "desacanhar",
    "desacanharmo": "desacanhar",
    "desacanharmos": "desacanhar",
    "desacanhará": "desacanhar",
    "desacanharás": "desacanhar",
    "desacanharão": "desacanhar",
    "desacanharíamos": "desacanhar",
    "desacanharíeis": "desacanhar",
    "desacanhas": "desacanhar",
    "desacanhasse": "desacanhar",
    "desacanhassem": "desacanhar",
    "desacanhasses": "desacanhar",
    "desacanhaste": "desacanhar",
    "desacanhastes": "desacanhar",
    "desacanhava": "desacanhar",
    "desacanhavam": "desacanhar",
    "desacanhavas": "desacanhar",
    "desacanhe": "desacanhar",
    "desacanhei": "desacanhar",
    "desacanheis": "desacanhar",
    "desacanhem": "desacanhar",
    "desacanhemo": "desacanhar",
    "desacanhemos": "desacanhar",
    "desacanhes": "desacanhar",
    "desacanho": "desacanhar",
    "desacanhou": "desacanhar",
    "desacanhá": "desacanhar",
    "desacanhámo": "desacanhar",
    "desacanhámos": "desacanhar",
    "desacanháramo": "desacanhar",
    "desacanháramos": "desacanhar",
    "desacanhárei": "desacanhar",
    "desacanháreis": "desacanhar",
    "desacanhásseis": "desacanhar",
    "desacanhássemos": "desacanhar",
    "desacanhávamo": "desacanhar",
    "desacanhávamos": "desacanhar",
    "desacanhávei": "desacanhar",
    "desacanháveis": "desacanhar",
    "desacasala": "desacasalar",
    "desacasalada": "desacasalar",
    "desacasaladas": "desacasalar",
    "desacasalado": "desacasalar",
    "desacasalados": "desacasalar",
    "desacasalai": "desacasalar",
    "desacasalais": "desacasalar",
    "desacasalam": "desacasalar",
    "desacasalamo": "desacasalar",
    "desacasalamos": "desacasalar",
    "desacasalando": "desacasalar",
    "desacasalara": "desacasalar",
    "desacasalaram": "desacasalar",
    "desacasalaras": "desacasalar",
    "desacasalarde": "desacasalar",
    "desacasalardes": "desacasalar",
    "desacasalare": "desacasalar",
    "desacasalarei": "desacasalar",
    "desacasalareis": "desacasalar",
    "desacasalarem": "desacasalar",
    "desacasalaremos": "desacasalar",
    "desacasalares": "desacasalar",
    "desacasalaria": "desacasalar",
    "desacasalariam": "desacasalar",
    "desacasalarias": "desacasalar",
    "desacasalarmo": "desacasalar",
    "desacasalarmos": "desacasalar",
    "desacasalará": "desacasalar",
    "desacasalarás": "desacasalar",
    "desacasalarão": "desacasalar",
    "desacasalaríamos": "desacasalar",
    "desacasalaríeis": "desacasalar",
    "desacasalas": "desacasalar",
    "desacasalasse": "desacasalar",
    "desacasalassem": "desacasalar",
    "desacasalasses": "desacasalar",
    "desacasalaste": "desacasalar",
    "desacasalastes": "desacasalar",
    "desacasalava": "desacasalar",
    "desacasalavam": "desacasalar",
    "desacasalavas": "desacasalar",
    "desacasale": "desacasalar",
    "desacasalei": "desacasalar",
    "desacasaleis": "desacasalar",
    "desacasalem": "desacasalar",
    "desacasalemo": "desacasalar",
    "desacasalemos": "desacasalar",
    "desacasales": "desacasalar",
    "desacasalo": "desacasalar",
    "desacasalou": "desacasalar",
    "desacasalá": "desacasalar",
    "desacasalámo": "desacasalar",
    "desacasalámos": "desacasalar",
    "desacasaláramo": "desacasalar",
    "desacasaláramos": "desacasalar",
    "desacasalárei": "desacasalar",
    "desacasaláreis": "desacasalar",
    "desacasalásseis": "desacasalar",
    "desacasalássemos": "desacasalar",
    "desacasalávamo": "desacasalar",
    "desacasalávamos": "desacasalar",
    "desacasalávei": "desacasalar",
    "desacasaláveis": "desacasalar",
    "desacastelhanáveis": "desacastelhanável",
    "desacata": "desacatar",
    "desacatada": "desacatar",
    "desacatadas": "desacatar",
    "desacatado": "desacatar",
    "desacatados": "desacatar",
    "desacatai": "desacatar",
    "desacatais": "desacatar",
    "desacatam": "desacatar",
    "desacatamentos": "desacatamento",
    "desacatamo": "desacatar",
    "desacatamos": "desacatar",
    "desacatando": "desacatar",
    "desacatara": "desacatar",
    "desacataram": "desacatar",
    "desacataras": "desacatar",
    "desacatarde": "desacatar",
    "desacatardes": "desacatar",
    "desacatare": "desacatar",
    "desacatarei": "desacatar",
    "desacatareis": "desacatar",
    "desacatarem": "desacatar",
    "desacataremos": "desacatar",
    "desacatares": "desacatar",
    "desacataria": "desacatar",
    "desacatariam": "desacatar",
    "desacatarias": "desacatar",
    "desacatarmo": "desacatar",
    "desacatarmos": "desacatar",
    "desacatará": "desacatar",
    "desacatarás": "desacatar",
    "desacatarão": "desacatar",
    "desacataríamos": "desacatar",
    "desacataríeis": "desacatar",
    "desacatas": "desacatar",
    "desacatasse": "desacatar",
    "desacatassem": "desacatar",
    "desacatasses": "desacatar",
    "desacataste": "desacatar",
    "desacatastes": "desacatar",
    "desacatava": "desacatar",
    "desacatavam": "desacatar",
    "desacatavas": "desacatar",
    "desacate": "desacatar",
    "desacatei": "desacatar",
    "desacateis": "desacatar",
    "desacatem": "desacatar",
    "desacatemo": "desacatar",
    "desacatemos": "desacatar",
    "desacates": "desacatar",
    "desacato": "desacatar",
    "desacatos": "desacato",
    "desacatou": "desacatar",
    "desacatá": "desacatar",
    "desacatámo": "desacatar",
    "desacatámos": "desacatar",
    "desacatáramo": "desacatar",
    "desacatáramos": "desacatar",
    "desacatárei": "desacatar",
    "desacatáreis": "desacatar",
    "desacatásseis": "desacatar",
    "desacatássemos": "desacatar",
    "desacatávamo": "desacatar",
    "desacatávamos": "desacatar",
    "desacatávei": "desacatar",
    "desacatáveis": "desacatar",
    "desacaudilhada": "desacaudilhado",
    "desacaudilhadas": "desacaudilhado",
    "desacaudilhados": "desacaudilhado",
    "desacautela": "desacautelar",
    "desacautelada": "desacautelar",
    "desacauteladas": "desacautelar",
    "desacautelado": "desacautelar",
    "desacautelados": "desacautelar",
    "desacautelai": "desacautelar",
    "desacautelais": "desacautelar",
    "desacautelam": "desacautelar",
    "desacautelamo": "desacautelar",
    "desacautelamos": "desacautelar",
    "desacautelando": "desacautelar",
    "desacautelara": "desacautelar",
    "desacautelaram": "desacautelar",
    "desacautelaras": "desacautelar",
    "desacautelarde": "desacautelar",
    "desacautelardes": "desacautelar",
    "desacautelare": "desacautelar",
    "desacautelarei": "desacautelar",
    "desacautelareis": "desacautelar",
    "desacautelarem": "desacautelar",
    "desacautelaremos": "desacautelar",
    "desacautelares": "desacautelar",
    "desacautelaria": "desacautelar",
    "desacautelariam": "desacautelar",
    "desacautelarias": "desacautelar",
    "desacautelarmo": "desacautelar",
    "desacautelarmos": "desacautelar",
    "desacautelará": "desacautelar",
    "desacautelarás": "desacautelar",
    "desacautelarão": "desacautelar",
    "desacautelaríamos": "desacautelar",
    "desacautelaríeis": "desacautelar",
    "desacautelas": "desacautelar",
    "desacautelasse": "desacautelar",
    "desacautelassem": "desacautelar",
    "desacautelasses": "desacautelar",
    "desacautelaste": "desacautelar",
    "desacautelastes": "desacautelar",
    "desacautelava": "desacautelar",
    "desacautelavam": "desacautelar",
    "desacautelavas": "desacautelar",
    "desacautele": "desacautelar",
    "desacautelei": "desacautelar",
    "desacauteleis": "desacautelar",
    "desacautelem": "desacautelar",
    "desacautelemo": "desacautelar",
    "desacautelemos": "desacautelar",
    "desacauteles": "desacautelar",
    "desacautelo": "desacautelar",
    "desacautelou": "desacautelar",
    "desacautelá": "desacautelar",
    "desacautelámo": "desacautelar",
    "desacautelámos": "desacautelar",
    "desacauteláramo": "desacautelar",
    "desacauteláramos": "desacautelar",
    "desacautelárei": "desacautelar",
    "desacauteláreis": "desacautelar",
    "desacautelásseis": "desacautelar",
    "desacautelássemos": "desacautelar",
    "desacautelávamo": "desacautelar",
    "desacautelávamos": "desacautelar",
    "desacautelávei": "desacautelar",
    "desacauteláveis": "desacautelar",
    "desacavala": "desacavalar",
    "desacavalada": "desacavalar",
    "desacavaladas": "desacavalar",
    "desacavalado": "desacavalar",
    "desacavalados": "desacavalar",
    "desacavalai": "desacavalar",
    "desacavalais": "desacavalar",
    "desacavalam": "desacavalar",
    "desacavalamo": "desacavalar",
    "desacavalamos": "desacavalar",
    "desacavalando": "desacavalar",
    "desacavalara": "desacavalar",
    "desacavalaram": "desacavalar",
    "desacavalaras": "desacavalar",
    "desacavalarde": "desacavalar",
    "desacavalardes": "desacavalar",
    "desacavalare": "desacavalar",
    "desacavalarei": "desacavalar",
    "desacavalareis": "desacavalar",
    "desacavalarem": "desacavalar",
    "desacavalaremos": "desacavalar",
    "desacavalares": "desacavalar",
    "desacavalaria": "desacavalar",
    "desacavalariam": "desacavalar",
    "desacavalarias": "desacavalar",
    "desacavalarmo": "desacavalar",
    "desacavalarmos": "desacavalar",
    "desacavalará": "desacavalar",
    "desacavalarás": "desacavalar",
    "desacavalarão": "desacavalar",
    "desacavalaríamos": "desacavalar",
    "desacavalaríeis": "desacavalar",
    "desacavalas": "desacavalar",
    "desacavalasse": "desacavalar",
    "desacavalassem": "desacavalar",
    "desacavalasses": "desacavalar",
    "desacavalaste": "desacavalar",
    "desacavalastes": "desacavalar",
    "desacavalava": "desacavalar",
    "desacavalavam": "desacavalar",
    "desacavalavas": "desacavalar",
    "desacavale": "desacavalar",
    "desacavalei": "desacavalar",
    "desacavaleis": "desacavalar",
    "desacavalem": "desacavalar",
    "desacavalemo": "desacavalar",
    "desacavalemos": "desacavalar",
    "desacavales": "desacavalar",
    "desacavalo": "desacavalar",
    "desacavalou": "desacavalar",
    "desacavalá": "desacavalar",
    "desacavalámo": "desacavalar",
    "desacavalámos": "desacavalar",
    "desacavaláramo": "desacavalar",
    "desacavaláramos": "desacavalar",
    "desacavalárei": "desacavalar",
    "desacavaláreis": "desacavalar",
    "desacavalásseis": "desacavalar",
    "desacavalássemos": "desacavalar",
    "desacavalávamo": "desacavalar",
    "desacavalávamos": "desacavalar",
    "desacavalávei": "desacavalar",
    "desacavaláveis": "desacavalar",
    "desaceita": "desaceitar",
    "desaceitada": "desaceitar",
    "desaceitadas": "desaceitar",
    "desaceitado": "desaceitar",
    "desaceitados": "desaceitar",
    "desaceitai": "desaceitar",
    "desaceitais": "desaceitar",
    "desaceitam": "desaceitar",
    "desaceitamo": "desaceitar",
    "desaceitamos": "desaceitar",
    "desaceitando": "desaceitar",
    "desaceitara": "desaceitar",
    "desaceitaram": "desaceitar",
    "desaceitaras": "desaceitar",
    "desaceitarde": "desaceitar",
    "desaceitardes": "desaceitar",
    "desaceitare": "desaceitar",
    "desaceitarei": "desaceitar",
    "desaceitareis": "desaceitar",
    "desaceitarem": "desaceitar",
    "desaceitaremos": "desaceitar",
    "desaceitares": "desaceitar",
    "desaceitaria": "desaceitar",
    "desaceitariam": "desaceitar",
    "desaceitarias": "desaceitar",
    "desaceitarmo": "desaceitar",
    "desaceitarmos": "desaceitar",
    "desaceitará": "desaceitar",
    "desaceitarás": "desaceitar",
    "desaceitarão": "desaceitar",
    "desaceitaríamos": "desaceitar",
    "desaceitaríeis": "desaceitar",
    "desaceitas": "desaceitar",
    "desaceitasse": "desaceitar",
    "desaceitassem": "desaceitar",
    "desaceitasses": "desaceitar",
    "desaceitaste": "desaceitar",
    "desaceitastes": "desaceitar",
    "desaceitava": "desaceitar",
    "desaceitavam": "desaceitar",
    "desaceitavas": "desaceitar",
    "desaceite": "desaceitar",
    "desaceitei": "desaceitar",
    "desaceiteis": "desaceitar",
    "desaceitem": "desaceitar",
    "desaceitemo": "desaceitar",
    "desaceitemos": "desaceitar",
    "desaceites": "desaceite",
    "desaceito": "desaceitar",
    "desaceitou": "desaceitar",
    "desaceitá": "desaceitar",
    "desaceitámo": "desaceitar",
    "desaceitámos": "desaceitar",
    "desaceitáramo": "desaceitar",
    "desaceitáramos": "desaceitar",
    "desaceitárei": "desaceitar",
    "desaceitáreis": "desaceitar",
    "desaceitásseis": "desaceitar",
    "desaceitássemos": "desaceitar",
    "desaceitávamo": "desaceitar",
    "desaceitávamos": "desaceitar",
    "desaceitávei": "desaceitar",
    "desaceitáveis": "desaceitar",
    "desacelera": "desacelerar",
    "desacelerada": "desacelerar",
    "desaceleradas": "desacelerar",
    "desacelerado": "desacelerar",
    "desacelerados": "desacelerar",
    "desacelerai": "desacelerar",
    "desacelerais": "desacelerar",
    "desaceleram": "desacelerar",
    "desaceleramentos": "desaceleramento",
    "desaceleramo": "desacelerar",
    "desaceleramos": "desacelerar",
    "desacelerando": "desacelerar",
    "desacelerara": "desacelerar",
    "desaceleraram": "desacelerar",
    "desaceleraras": "desacelerar",
    "desacelerarde": "desacelerar",
    "desacelerardes": "desacelerar",
    "desacelerare": "desacelerar",
    "desacelerarei": "desacelerar",
    "desacelerareis": "desacelerar",
    "desacelerarem": "desacelerar",
    "desaceleraremos": "desacelerar",
    "desacelerares": "desacelerar",
    "desaceleraria": "desacelerar",
    "desacelerariam": "desacelerar",
    "desacelerarias": "desacelerar",
    "desacelerarmo": "desacelerar",
    "desacelerarmos": "desacelerar",
    "desacelerará": "desacelerar",
    "desacelerarás": "desacelerar",
    "desacelerarão": "desacelerar",
    "desaceleraríamos": "desacelerar",
    "desaceleraríeis": "desacelerar",
    "desaceleras": "desacelerar",
    "desacelerasse": "desacelerar",
    "desacelerassem": "desacelerar",
    "desacelerasses": "desacelerar",
    "desaceleraste": "desacelerar",
    "desacelerastes": "desacelerar",
    "desacelerava": "desacelerar",
    "desaceleravam": "desacelerar",
    "desaceleravas": "desacelerar",
    "desacelerações": "desaceleração",
    "desacelere": "desacelerar",
    "desacelerei": "desacelerar",
    "desacelereis": "desacelerar",
    "desacelerem": "desacelerar",
    "desaceleremo": "desacelerar",
    "desaceleremos": "desacelerar",
    "desaceleres": "desacelerar",
    "desacelero": "desacelerar",
    "desacelerou": "desacelerar",
    "desacelerá": "desacelerar",
    "desacelerámo": "desacelerar",
    "desacelerámos": "desacelerar",
    "desaceleráramo": "desacelerar",
    "desaceleráramos": "desacelerar",
    "desacelerárei": "desacelerar",
    "desaceleráreis": "desacelerar",
    "desacelerásseis": "desacelerar",
    "desacelerássemos": "desacelerar",
    "desacelerávamo": "desacelerar",
    "desacelerávamos": "desacelerar",
    "desacelerávei": "desacelerar",
    "desaceleráveis": "desacelerar",
    "desacentua": "desacentuar",
    "desacentuada": "desacentuar",
    "desacentuadas": "desacentuar",
    "desacentuado": "desacentuar",
    "desacentuados": "desacentuar",
    "desacentuai": "desacentuar",
    "desacentuais": "desacentuar",
    "desacentuam": "desacentuar",
    "desacentuamo": "desacentuar",
    "desacentuamos": "desacentuar",
    "desacentuando": "desacentuar",
    "desacentuara": "desacentuar",
    "desacentuaram": "desacentuar",
    "desacentuaras": "desacentuar",
    "desacentuarde": "desacentuar",
    "desacentuardes": "desacentuar",
    "desacentuare": "desacentuar",
    "desacentuarei": "desacentuar",
    "desacentuareis": "desacentuar",
    "desacentuarem": "desacentuar",
    "desacentuaremos": "desacentuar",
    "desacentuares": "desacentuar",
    "desacentuaria": "desacentuar",
    "desacentuariam": "desacentuar",
    "desacentuarias": "desacentuar",
    "desacentuarmo": "desacentuar",
    "desacentuarmos": "desacentuar",
    "desacentuará": "desacentuar",
    "desacentuarás": "desacentuar",
    "desacentuarão": "desacentuar",
    "desacentuaríamos": "desacentuar",
    "desacentuaríeis": "desacentuar",
    "desacentuas": "desacentuar",
    "desacentuasse": "desacentuar",
    "desacentuassem": "desacentuar",
    "desacentuasses": "desacentuar",
    "desacentuaste": "desacentuar",
    "desacentuastes": "desacentuar",
    "desacentuava": "desacentuar",
    "desacentuavam": "desacentuar",
    "desacentuavas": "desacentuar",
    "desacentue": "desacentuar",
    "desacentuei": "desacentuar",
    "desacentueis": "desacentuar",
    "desacentuem": "desacentuar",
    "desacentuemo": "desacentuar",
    "desacentuemos": "desacentuar",
    "desacentues": "desacentuar",
    "desacentuo": "desacentuar",
    "desacentuou": "desacentuar",
    "desacentuá": "desacentuar",
    "desacentuámo": "desacentuar",
    "desacentuámos": "desacentuar",
    "desacentuáramo": "desacentuar",
    "desacentuáramos": "desacentuar",
    "desacentuárei": "desacentuar",
    "desacentuáreis": "desacentuar",
    "desacentuásseis": "desacentuar",
    "desacentuássemos": "desacentuar",
    "desacentuávamo": "desacentuar",
    "desacentuávamos": "desacentuar",
    "desacentuávei": "desacentuar",
    "desacentuáveis": "desacentuar",
    "desacepilhada": "desacepilhado",
    "desacepilhadas": "desacepilhado",
    "desacepilhados": "desacepilhado",
    "desacerba": "desacerbar",
    "desacerbada": "desacerbar",
    "desacerbadas": "desacerbar",
    "desacerbado": "desacerbar",
    "desacerbados": "desacerbar",
    "desacerbai": "desacerbar",
    "desacerbais": "desacerbar",
    "desacerbam": "desacerbar",
    "desacerbamo": "desacerbar",
    "desacerbamos": "desacerbar",
    "desacerbando": "desacerbar",
    "desacerbara": "desacerbar",
    "desacerbaram": "desacerbar",
    "desacerbaras": "desacerbar",
    "desacerbarde": "desacerbar",
    "desacerbardes": "desacerbar",
    "desacerbare": "desacerbar",
    "desacerbarei": "desacerbar",
    "desacerbareis": "desacerbar",
    "desacerbarem": "desacerbar",
    "desacerbaremos": "desacerbar",
    "desacerbares": "desacerbar",
    "desacerbaria": "desacerbar",
    "desacerbariam": "desacerbar",
    "desacerbarias": "desacerbar",
    "desacerbarmo": "desacerbar",
    "desacerbarmos": "desacerbar",
    "desacerbará": "desacerbar",
    "desacerbarás": "desacerbar",
    "desacerbarão": "desacerbar",
    "desacerbaríamos": "desacerbar",
    "desacerbaríeis": "desacerbar",
    "desacerbas": "desacerbar",
    "desacerbasse": "desacerbar",
    "desacerbassem": "desacerbar",
    "desacerbasses": "desacerbar",
    "desacerbaste": "desacerbar",
    "desacerbastes": "desacerbar",
    "desacerbava": "desacerbar",
    "desacerbavam": "desacerbar",
    "desacerbavas": "desacerbar",
    "desacerbe": "desacerbar",
    "desacerbei": "desacerbar",
    "desacerbeis": "desacerbar",
    "desacerbem": "desacerbar",
    "desacerbemo": "desacerbar",
    "desacerbemos": "desacerbar",
    "desacerbes": "desacerbar",
    "desacerbo": "desacerbar",
    "desacerbou": "desacerbar",
    "desacerbá": "desacerbar",
    "desacerbámo": "desacerbar",
    "desacerbámos": "desacerbar",
    "desacerbáramo": "desacerbar",
    "desacerbáramos": "desacerbar",
    "desacerbárei": "desacerbar",
    "desacerbáreis": "desacerbar",
    "desacerbásseis": "desacerbar",
    "desacerbássemos": "desacerbar",
    "desacerbávamo": "desacerbar",
    "desacerbávamos": "desacerbar",
    "desacerbávei": "desacerbar",
    "desacerbáveis": "desacerbar",
    "desacerta": "desacertar",
    "desacertada": "desacertar",
    "desacertadas": "desacertar",
    "desacertado": "desacertar",
    "desacertados": "desacertar",
    "desacertai": "desacertar",
    "desacertais": "desacertar",
    "desacertam": "desacertar",
    "desacertamo": "desacertar",
    "desacertamos": "desacertar",
    "desacertando": "desacertar",
    "desacertara": "desacertar",
    "desacertaram": "desacertar",
    "desacertaras": "desacertar",
    "desacertarde": "desacertar",
    "desacertardes": "desacertar",
    "desacertare": "desacertar",
    "desacertarei": "desacertar",
    "desacertareis": "desacertar",
    "desacertarem": "desacertar",
    "desacertaremos": "desacertar",
    "desacertares": "desacertar",
    "desacertaria": "desacertar",
    "desacertariam": "desacertar",
    "desacertarias": "desacertar",
    "desacertarmo": "desacertar",
    "desacertarmos": "desacertar",
    "desacertará": "desacertar",
    "desacertarás": "desacertar",
    "desacertarão": "desacertar",
    "desacertaríamos": "desacertar",
    "desacertaríeis": "desacertar",
    "desacertas": "desacertar",
    "desacertasse": "desacertar",
    "desacertassem": "desacertar",
    "desacertasses": "desacertar",
    "desacertaste": "desacertar",
    "desacertastes": "desacertar",
    "desacertava": "desacertar",
    "desacertavam": "desacertar",
    "desacertavas": "desacertar",
    "desacerte": "desacertar",
    "desacertei": "desacertar",
    "desacerteis": "desacertar",
    "desacertem": "desacertar",
    "desacertemo": "desacertar",
    "desacertemos": "desacertar",
    "desacertes": "desacertar",
    "desacerto": "desacertar",
    "desacertos": "desacerto",
    "desacertou": "desacertar",
    "desacertá": "desacertar",
    "desacertámo": "desacertar",
    "desacertámos": "desacertar",
    "desacertáramo": "desacertar",
    "desacertáramos": "desacertar",
    "desacertárei": "desacertar",
    "desacertáreis": "desacertar",
    "desacertásseis": "desacertar",
    "desacertássemos": "desacertar",
    "desacertávamo": "desacertar",
    "desacertávamos": "desacertar",
    "desacertávei": "desacertar",
    "desacertáveis": "desacertar",
    "desachega": "desachegar",
    "desachegada": "desachegar",
    "desachegadas": "desachegar",
    "desachegado": "desachegar",
    "desachegados": "desachegar",
    "desachegai": "desachegar",
    "desachegais": "desachegar",
    "desachegam": "desachegar",
    "desachegamo": "desachegar",
    "desachegamos": "desachegar",
    "desachegando": "desachegar",
    "desachegara": "desachegar",
    "desachegaram": "desachegar",
    "desachegaras": "desachegar",
    "desachegarde": "desachegar",
    "desachegardes": "desachegar",
    "desachegare": "desachegar",
    "desachegarei": "desachegar",
    "desachegareis": "desachegar",
    "desachegarem": "desachegar",
    "desachegaremos": "desachegar",
    "desachegares": "desachegar",
    "desachegaria": "desachegar",
    "desachegariam": "desachegar",
    "desachegarias": "desachegar",
    "desachegarmo": "desachegar",
    "desachegarmos": "desachegar",
    "desachegará": "desachegar",
    "desachegarás": "desachegar",
    "desachegarão": "desachegar",
    "desachegaríamos": "desachegar",
    "desachegaríeis": "desachegar",
    "desachegas": "desachegar",
    "desachegasse": "desachegar",
    "desachegassem": "desachegar",
    "desachegasses": "desachegar",
    "desachegaste": "desachegar",
    "desachegastes": "desachegar",
    "desachegava": "desachegar",
    "desachegavam": "desachegar",
    "desachegavas": "desachegar",
    "desachego": "desachegar",
    "desachegou": "desachegar",
    "desachegue": "desachegar",
    "desacheguei": "desachegar",
    "desachegueis": "desachegar",
    "desacheguem": "desachegar",
    "desacheguemo": "desachegar",
    "desacheguemos": "desachegar",
    "desachegues": "desachegar",
    "desachegá": "desachegar",
    "desachegámo": "desachegar",
    "desachegámos": "desachegar",
    "desachegáramo": "desachegar",
    "desachegáramos": "desachegar",
    "desachegárei": "desachegar",
    "desachegáreis": "desachegar",
    "desachegásseis": "desachegar",
    "desachegássemos": "desachegar",
    "desachegávamo": "desachegar",
    "desachegávamos": "desachegar",
    "desachegávei": "desachegar",
    "desachegáveis": "desachegar",
    "desacidifica": "desacidificar",
    "desacidificada": "desacidificar",
    "desacidificadas": "desacidificar",
    "desacidificado": "desacidificar",
    "desacidificados": "desacidificar",
    "desacidificai": "desacidificar",
    "desacidificais": "desacidificar",
    "desacidificam": "desacidificar",
    "desacidificamo": "desacidificar",
    "desacidificamos": "desacidificar",
    "desacidificando": "desacidificar",
    "desacidificara": "desacidificar",
    "desacidificaram": "desacidificar",
    "desacidificaras": "desacidificar",
    "desacidificarde": "desacidificar",
    "desacidificardes": "desacidificar",
    "desacidificare": "desacidificar",
    "desacidificarei": "desacidificar",
    "desacidificareis": "desacidificar",
    "desacidificarem": "desacidificar",
    "desacidificaremos": "desacidificar",
    "desacidificares": "desacidificar",
    "desacidificaria": "desacidificar",
    "desacidificariam": "desacidificar",
    "desacidificarias": "desacidificar",
    "desacidificarmo": "desacidificar",
    "desacidificarmos": "desacidificar",
    "desacidificará": "desacidificar",
    "desacidificarás": "desacidificar",
    "desacidificarão": "desacidificar",
    "desacidificaríamos": "desacidificar",
    "desacidificaríeis": "desacidificar",
    "desacidificas": "desacidificar",
    "desacidificasse": "desacidificar",
    "desacidificassem": "desacidificar",
    "desacidificasses": "desacidificar",
    "desacidificaste": "desacidificar",
    "desacidificastes": "desacidificar",
    "desacidificava": "desacidificar",
    "desacidificavam": "desacidificar",
    "desacidificavas": "desacidificar",
    "desacidifico": "desacidificar",
    "desacidificou": "desacidificar",
    "desacidificá": "desacidificar",
    "desacidificámo": "desacidificar",
    "desacidificámos": "desacidificar",
    "desacidificáramo": "desacidificar",
    "desacidificáramos": "desacidificar",
    "desacidificárei": "desacidificar",
    "desacidificáreis": "desacidificar",
    "desacidificásseis": "desacidificar",
    "desacidificássemos": "desacidificar",
    "desacidificávamo": "desacidificar",
    "desacidificávamos": "desacidificar",
    "desacidificávei": "desacidificar",
    "desacidificáveis": "desacidificável",
    "desacidifique": "desacidificar",
    "desacidifiquei": "desacidificar",
    "desacidifiqueis": "desacidificar",
    "desacidifiquem": "desacidificar",
    "desacidifiquemo": "desacidificar",
    "desacidifiquemos": "desacidificar",
    "desacidifiques": "desacidificar",
    "desaclima": "desaclimar",
    "desaclimada": "desaclimar",
    "desaclimadas": "desaclimar",
    "desaclimado": "desaclimar",
    "desaclimados": "desaclimar",
    "desaclimai": "desaclimar",
    "desaclimais": "desaclimar",
    "desaclimam": "desaclimar",
    "desaclimamo": "desaclimar",
    "desaclimamos": "desaclimar",
    "desaclimando": "desaclimar",
    "desaclimara": "desaclimar",
    "desaclimaram": "desaclimar",
    "desaclimaras": "desaclimar",
    "desaclimarde": "desaclimar",
    "desaclimardes": "desaclimar",
    "desaclimare": "desaclimar",
    "desaclimarei": "desaclimar",
    "desaclimareis": "desaclimar",
    "desaclimarem": "desaclimar",
    "desaclimaremos": "desaclimar",
    "desaclimares": "desaclimar",
    "desaclimaria": "desaclimar",
    "desaclimariam": "desaclimar",
    "desaclimarias": "desaclimar",
    "desaclimarmo": "desaclimar",
    "desaclimarmos": "desaclimar",
    "desaclimará": "desaclimar",
    "desaclimarás": "desaclimar",
    "desaclimarão": "desaclimar",
    "desaclimaríamos": "desaclimar",
    "desaclimaríeis": "desaclimar",
    "desaclimas": "desaclimar",
    "desaclimasse": "desaclimar",
    "desaclimassem": "desaclimar",
    "desaclimasses": "desaclimar",
    "desaclimaste": "desaclimar",
    "desaclimastes": "desaclimar",
    "desaclimata": "desaclimatar",
    "desaclimatada": "desaclimatar",
    "desaclimatadas": "desaclimatar",
    "desaclimatado": "desaclimatar",
    "desaclimatados": "desaclimatar",
    "desaclimatai": "desaclimatar",
    "desaclimatais": "desaclimatar",
    "desaclimatam": "desaclimatar",
    "desaclimatamo": "desaclimatar",
    "desaclimatamos": "desaclimatar",
    "desaclimatando": "desaclimatar",
    "desaclimatara": "desaclimatar",
    "desaclimataram": "desaclimatar",
    "desaclimataras": "desaclimatar",
    "desaclimatarde": "desaclimatar",
    "desaclimatardes": "desaclimatar",
    "desaclimatare": "desaclimatar",
    "desaclimatarei": "desaclimatar",
    "desaclimatareis": "desaclimatar",
    "desaclimatarem": "desaclimatar",
    "desaclimataremos": "desaclimatar",
    "desaclimatares": "desaclimatar",
    "desaclimataria": "desaclimatar",
    "desaclimatariam": "desaclimatar",
    "desaclimatarias": "desaclimatar",
    "desaclimatarmo": "desaclimatar",
    "desaclimatarmos": "desaclimatar",
    "desaclimatará": "desaclimatar",
    "desaclimatarás": "desaclimatar",
    "desaclimatarão": "desaclimatar",
    "desaclimataríamos": "desaclimatar",
    "desaclimataríeis": "desaclimatar",
    "desaclimatas": "desaclimatar",
    "desaclimatasse": "desaclimatar",
    "desaclimatassem": "desaclimatar",
    "desaclimatasses": "desaclimatar",
    "desaclimataste": "desaclimatar",
    "desaclimatastes": "desaclimatar",
    "desaclimatava": "desaclimatar",
    "desaclimatavam": "desaclimatar",
    "desaclimatavas": "desaclimatar",
    "desaclimate": "desaclimatar",
    "desaclimatei": "desaclimatar",
    "desaclimateis": "desaclimatar",
    "desaclimatem": "desaclimatar",
    "desaclimatemo": "desaclimatar",
    "desaclimatemos": "desaclimatar",
    "desaclimates": "desaclimatar",
    "desaclimato": "desaclimatar",
    "desaclimatou": "desaclimatar",
    "desaclimatá": "desaclimatar",
    "desaclimatámo": "desaclimatar",
    "desaclimatámos": "desaclimatar",
    "desaclimatáramo": "desaclimatar",
    "desaclimatáramos": "desaclimatar",
    "desaclimatárei": "desaclimatar",
    "desaclimatáreis": "desaclimatar",
    "desaclimatásseis": "desaclimatar",
    "desaclimatássemos": "desaclimatar",
    "desaclimatávamo": "desaclimatar",
    "desaclimatávamos": "desaclimatar",
    "desaclimatávei": "desaclimatar",
    "desaclimatáveis": "desaclimatar",
    "desaclimava": "desaclimar",
    "desaclimavam": "desaclimar",
    "desaclimavas": "desaclimar",
    "desaclime": "desaclimar",
    "desaclimei": "desaclimar",
    "desaclimeis": "desaclimar",
    "desaclimem": "desaclimar",
    "desaclimemo": "desaclimar",
    "desaclimemos": "desaclimar",
    "desaclimes": "desaclimar",
    "desaclimo": "desaclimar",
    "desaclimou": "desaclimar",
    "desaclimá": "desaclimar",
    "desaclimámo": "desaclimar",
    "desaclimámos": "desaclimar",
    "desaclimáramo": "desaclimar",
    "desaclimáramos": "desaclimar",
    "desaclimárei": "desaclimar",
    "desaclimáreis": "desaclimar",
    "desaclimásseis": "desaclimar",
    "desaclimássemos": "desaclimar",
    "desaclimávamo": "desaclimar",
    "desaclimávamos": "desaclimar",
    "desaclimávei": "desaclimar",
    "desaclimáveis": "desaclimar",
    "desacobarda": "desacobardar",
    "desacobardada": "desacobardar",
    "desacobardadas": "desacobardar",
    "desacobardado": "desacobardar",
    "desacobardados": "desacobardar",
    "desacobardai": "desacobardar",
    "desacobardais": "desacobardar",
    "desacobardam": "desacobardar",
    "desacobardamo": "desacobardar",
    "desacobardamos": "desacobardar",
    "desacobardando": "desacobardar",
    "desacobardara": "desacobardar",
    "desacobardaram": "desacobardar",
    "desacobardaras": "desacobardar",
    "desacobardarde": "desacobardar",
    "desacobardardes": "desacobardar",
    "desacobardare": "desacobardar",
    "desacobardarei": "desacobardar",
    "desacobardareis": "desacobardar",
    "desacobardarem": "desacobardar",
    "desacobardaremos": "desacobardar",
    "desacobardares": "desacobardar",
    "desacobardaria": "desacobardar",
    "desacobardariam": "desacobardar",
    "desacobardarias": "desacobardar",
    "desacobardarmo": "desacobardar",
    "desacobardarmos": "desacobardar",
    "desacobardará": "desacobardar",
    "desacobardarás": "desacobardar",
    "desacobardarão": "desacobardar",
    "desacobardaríamos": "desacobardar",
    "desacobardaríeis": "desacobardar",
    "desacobardas": "desacobardar",
    "desacobardasse": "desacobardar",
    "desacobardassem": "desacobardar",
    "desacobardasses": "desacobardar",
    "desacobardaste": "desacobardar",
    "desacobardastes": "desacobardar",
    "desacobardava": "desacobardar",
    "desacobardavam": "desacobardar",
    "desacobardavas": "desacobardar",
    "desacobarde": "desacobardar",
    "desacobardei": "desacobardar",
    "desacobardeis": "desacobardar",
    "desacobardem": "desacobardar",
    "desacobardemo": "desacobardar",
    "desacobardemos": "desacobardar",
    "desacobardes": "desacobardar",
    "desacobardo": "desacobardar",
    "desacobardou": "desacobardar",
    "desacobardá": "desacobardar",
    "desacobardámo": "desacobardar",
    "desacobardámos": "desacobardar",
    "desacobardáramo": "desacobardar",
    "desacobardáramos": "desacobardar",
    "desacobardárei": "desacobardar",
    "desacobardáreis": "desacobardar",
    "desacobardásseis": "desacobardar",
    "desacobardássemos": "desacobardar",
    "desacobardávamo": "desacobardar",
    "desacobardávamos": "desacobardar",
    "desacobardávei": "desacobardar",
    "desacobardáveis": "desacobardar",
    "desacoimada": "desacoimado",
    "desacoimadas": "desacoimado",
    "desacoimados": "desacoimado",
    "desacoita": "desacoitar",
    "desacoitada": "desacoitar",
    "desacoitadas": "desacoitar",
    "desacoitado": "desacoitar",
    "desacoitados": "desacoitar",
    "desacoitai": "desacoitar",
    "desacoitais": "desacoitar",
    "desacoitam": "desacoitar",
    "desacoitamo": "desacoitar",
    "desacoitamos": "desacoitar",
    "desacoitando": "desacoitar",
    "desacoitara": "desacoitar",
    "desacoitaram": "desacoitar",
    "desacoitaras": "desacoitar",
    "desacoitarde": "desacoitar",
    "desacoitardes": "desacoitar",
    "desacoitare": "desacoitar",
    "desacoitarei": "desacoitar",
    "desacoitareis": "desacoitar",
    "desacoitarem": "desacoitar",
    "desacoitaremos": "desacoitar",
    "desacoitares": "desacoitar",
    "desacoitaria": "desacoitar",
    "desacoitariam": "desacoitar",
    "desacoitarias": "desacoitar",
    "desacoitarmo": "desacoitar",
    "desacoitarmos": "desacoitar",
    "desacoitará": "desacoitar",
    "desacoitarás": "desacoitar",
    "desacoitarão": "desacoitar",
    "desacoitaríamos": "desacoitar",
    "desacoitaríeis": "desacoitar",
    "desacoitas": "desacoitar",
    "desacoitasse": "desacoitar",
    "desacoitassem": "desacoitar",
    "desacoitasses": "desacoitar",
    "desacoitaste": "desacoitar",
    "desacoitastes": "desacoitar",
    "desacoitava": "desacoitar",
    "desacoitavam": "desacoitar",
    "desacoitavas": "desacoitar",
    "desacoite": "desacoitar",
    "desacoitei": "desacoitar",
    "desacoiteis": "desacoitar",
    "desacoitem": "desacoitar",
    "desacoitemo": "desacoitar",
    "desacoitemos": "desacoitar",
    "desacoites": "desacoitar",
    "desacoito": "desacoitar",
    "desacoitou": "desacoitar",
    "desacoitá": "desacoitar",
    "desacoitámo": "desacoitar",
    "desacoitámos": "desacoitar",
    "desacoitáramo": "desacoitar",
    "desacoitáramos": "desacoitar",
    "desacoitárei": "desacoitar",
    "desacoitáreis": "desacoitar",
    "desacoitásseis": "desacoitar",
    "desacoitássemos": "desacoitar",
    "desacoitávamo": "desacoitar",
    "desacoitávamos": "desacoitar",
    "desacoitávei": "desacoitar",
    "desacoitáveis": "desacoitar",
    "desacolcheta": "desacolchetar",
    "desacolchetada": "desacolchetar",
    "desacolchetadas": "desacolchetar",
    "desacolchetado": "desacolchetar",
    "desacolchetados": "desacolchetar",
    "desacolchetai": "desacolchetar",
    "desacolchetais": "desacolchetar",
    "desacolchetam": "desacolchetar",
    "desacolchetamo": "desacolchetar",
    "desacolchetamos": "desacolchetar",
    "desacolchetando": "desacolchetar",
    "desacolchetara": "desacolchetar",
    "desacolchetaram": "desacolchetar",
    "desacolchetaras": "desacolchetar",
    "desacolchetarde": "desacolchetar",
    "desacolchetardes": "desacolchetar",
    "desacolchetare": "desacolchetar",
    "desacolchetarei": "desacolchetar",
    "desacolchetareis": "desacolchetar",
    "desacolchetarem": "desacolchetar",
    "desacolchetaremos": "desacolchetar",
    "desacolchetares": "desacolchetar",
    "desacolchetaria": "desacolchetar",
    "desacolchetariam": "desacolchetar",
    "desacolchetarias": "desacolchetar",
    "desacolchetarmo": "desacolchetar",
    "desacolchetarmos": "desacolchetar",
    "desacolchetará": "desacolchetar",
    "desacolchetarás": "desacolchetar",
    "desacolchetarão": "desacolchetar",
    "desacolchetaríamos": "desacolchetar",
    "desacolchetaríeis": "desacolchetar",
    "desacolchetas": "desacolchetar",
    "desacolchetasse": "desacolchetar",
    "desacolchetassem": "desacolchetar",
    "desacolchetasses": "desacolchetar",
    "desacolchetaste": "desacolchetar",
    "desacolchetastes": "desacolchetar",
    "desacolchetava": "desacolchetar",
    "desacolchetavam": "desacolchetar",
    "desacolchetavas": "desacolchetar",
    "desacolchete": "desacolchetar",
    "desacolchetei": "desacolchetar",
    "desacolcheteis": "desacolchetar",
    "desacolchetem": "desacolchetar",
    "desacolchetemo": "desacolchetar",
    "desacolchetemos": "desacolchetar",
    "desacolchetes": "desacolchetar",
    "desacolcheto": "desacolchetar",
    "desacolchetou": "desacolchetar",
    "desacolchetá": "desacolchetar",
    "desacolchetámo": "desacolchetar",
    "desacolchetámos": "desacolchetar",
    "desacolchetáramo": "desacolchetar",
    "desacolchetáramos": "desacolchetar",
    "desacolchetárei": "desacolchetar",
    "desacolchetáreis": "desacolchetar",
    "desacolchetásseis": "desacolchetar",
    "desacolchetássemos": "desacolchetar",
    "desacolchetávamo": "desacolchetar",
    "desacolchetávamos": "desacolchetar",
    "desacolchetávei": "desacolchetar",
    "desacolchetáveis": "desacolchetar",
    "desacolchoa": "desacolchoar",
    "desacolchoada": "desacolchoar",
    "desacolchoadas": "desacolchoar",
    "desacolchoado": "desacolchoar",
    "desacolchoados": "desacolchoar",
    "desacolchoai": "desacolchoar",
    "desacolchoais": "desacolchoar",
    "desacolchoam": "desacolchoar",
    "desacolchoamo": "desacolchoar",
    "desacolchoamos": "desacolchoar",
    "desacolchoando": "desacolchoar",
    "desacolchoara": "desacolchoar",
    "desacolchoaram": "desacolchoar",
    "desacolchoaras": "desacolchoar",
    "desacolchoarde": "desacolchoar",
    "desacolchoardes": "desacolchoar",
    "desacolchoare": "desacolchoar",
    "desacolchoarei": "desacolchoar",
    "desacolchoareis": "desacolchoar",
    "desacolchoarem": "desacolchoar",
    "desacolchoaremos": "desacolchoar",
    "desacolchoares": "desacolchoar",
    "desacolchoaria": "desacolchoar",
    "desacolchoariam": "desacolchoar",
    "desacolchoarias": "desacolchoar",
    "desacolchoarmo": "desacolchoar",
    "desacolchoarmos": "desacolchoar",
    "desacolchoará": "desacolchoar",
    "desacolchoarás": "desacolchoar",
    "desacolchoarão": "desacolchoar",
    "desacolchoaríamos": "desacolchoar",
    "desacolchoaríeis": "desacolchoar",
    "desacolchoas": "desacolchoar",
    "desacolchoasse": "desacolchoar",
    "desacolchoassem": "desacolchoar",
    "desacolchoasses": "desacolchoar",
    "desacolchoaste": "desacolchoar",
    "desacolchoastes": "desacolchoar",
    "desacolchoava": "desacolchoar",
    "desacolchoavam": "desacolchoar",
    "desacolchoavas": "desacolchoar",
    "desacolchoe": "desacolchoar",
    "desacolchoei": "desacolchoar",
    "desacolchoeis": "desacolchoar",
    "desacolchoem": "desacolchoar",
    "desacolchoemo": "desacolchoar",
    "desacolchoemos": "desacolchoar",
    "desacolchoes": "desacolchoar",
    "desacolchoo": "desacolchoar",
    "desacolchoou": "desacolchoar",
    "desacolchoá": "desacolchoar",
    "desacolchoámo": "desacolchoar",
    "desacolchoámos": "desacolchoar",
    "desacolchoáramo": "desacolchoar",
    "desacolchoáramos": "desacolchoar",
    "desacolchoárei": "desacolchoar",
    "desacolchoáreis": "desacolchoar",
    "desacolchoásseis": "desacolchoar",
    "desacolchoássemos": "desacolchoar",
    "desacolchoávamo": "desacolchoar",
    "desacolchoávamos": "desacolchoar",
    "desacolchoávei": "desacolchoar",
    "desacolchoáveis": "desacolchoar",
    "desacolha": "desacolher",
    "desacolhais": "desacolher",
    "desacolham": "desacolher",
    "desacolhamo": "desacolher",
    "desacolhamos": "desacolher",
    "desacolhas": "desacolher",
    "desacolhe": "desacolher",
    "desacolhei": "desacolher",
    "desacolheis": "desacolher",
    "desacolhem": "desacolher",
    "desacolhemo": "desacolher",
    "desacolhemos": "desacolher",
    "desacolhendo": "desacolher",
    "desacolhera": "desacolher",
    "desacolheram": "desacolher",
    "desacolheras": "desacolher",
    "desacolherde": "desacolher",
    "desacolherdes": "desacolher",
    "desacolhere": "desacolher",
    "desacolherei": "desacolher",
    "desacolhereis": "desacolher",
    "desacolherem": "desacolher",
    "desacolheremos": "desacolher",
    "desacolheres": "desacolher",
    "desacolheria": "desacolher",
    "desacolheriam": "desacolher",
    "desacolherias": "desacolher",
    "desacolhermo": "desacolher",
    "desacolhermos": "desacolher",
    "desacolherá": "desacolher",
    "desacolherás": "desacolher",
    "desacolherão": "desacolher",
    "desacolheríamos": "desacolher",
    "desacolheríeis": "desacolher",
    "desacolhes": "desacolher",
    "desacolhesse": "desacolher",
    "desacolhessem": "desacolher",
    "desacolhesses": "desacolher",
    "desacolheste": "desacolher",
    "desacolhestes": "desacolher",
    "desacolheu": "desacolher",
    "desacolhi": "desacolher",
    "desacolhia": "desacolher",
    "desacolhiam": "desacolher",
    "desacolhias": "desacolher",
    "desacolhida": "desacolhido",
    "desacolhidas": "desacolhido",
    "desacolhido": "desacolher",
    "desacolhidos": "desacolhido",
    "desacolhimentos": "desacolhimento",
    "desacolho": "desacolher",
    "desacolhê": "desacolher",
    "desacolhêramo": "desacolher",
    "desacolhêramos": "desacolher",
    "desacolhêrei": "desacolher",
    "desacolhêreis": "desacolher",
    "desacolhêsseis": "desacolher",
    "desacolhêssemos": "desacolher",
    "desacolhíamo": "desacolher",
    "desacolhíamos": "desacolher",
    "desacolhíei": "desacolher",
    "desacolhíeis": "desacolher",
    "desacomoda": "desacomodar",
    "desacomodada": "desacomodar",
    "desacomodadas": "desacomodar",
    "desacomodado": "desacomodar",
    "desacomodados": "desacomodar",
    "desacomodai": "desacomodar",
    "desacomodais": "desacomodar",
    "desacomodam": "desacomodar",
    "desacomodamo": "desacomodar",
    "desacomodamos": "desacomodar",
    "desacomodando": "desacomodar",
    "desacomodara": "desacomodar",
    "desacomodaram": "desacomodar",
    "desacomodaras": "desacomodar",
    "desacomodarde": "desacomodar",
    "desacomodardes": "desacomodar",
    "desacomodare": "desacomodar",
    "desacomodarei": "desacomodar",
    "desacomodareis": "desacomodar",
    "desacomodarem": "desacomodar",
    "desacomodaremos": "desacomodar",
    "desacomodares": "desacomodar",
    "desacomodaria": "desacomodar",
    "desacomodariam": "desacomodar",
    "desacomodarias": "desacomodar",
    "desacomodarmo": "desacomodar",
    "desacomodarmos": "desacomodar",
    "desacomodará": "desacomodar",
    "desacomodarás": "desacomodar",
    "desacomodarão": "desacomodar",
    "desacomodaríamos": "desacomodar",
    "desacomodaríeis": "desacomodar",
    "desacomodas": "desacomodar",
    "desacomodasse": "desacomodar",
    "desacomodassem": "desacomodar",
    "desacomodasses": "desacomodar",
    "desacomodaste": "desacomodar",
    "desacomodastes": "desacomodar",
    "desacomodava": "desacomodar",
    "desacomodavam": "desacomodar",
    "desacomodavas": "desacomodar",
    "desacomode": "desacomodar",
    "desacomodei": "desacomodar",
    "desacomodeis": "desacomodar",
    "desacomodem": "desacomodar",
    "desacomodemo": "desacomodar",
    "desacomodemos": "desacomodar",
    "desacomodes": "desacomodar",
    "desacomodo": "desacomodar",
    "desacomodou": "desacomodar",
    "desacomodá": "desacomodar",
    "desacomodámo": "desacomodar",
    "desacomodámos": "desacomodar",
    "desacomodáramo": "desacomodar",
    "desacomodáramos": "desacomodar",
    "desacomodárei": "desacomodar",
    "desacomodáreis": "desacomodar",
    "desacomodásseis": "desacomodar",
    "desacomodássemos": "desacomodar",
    "desacomodávamo": "desacomodar",
    "desacomodávamos": "desacomodar",
    "desacomodávei": "desacomodar",
    "desacomodáveis": "desacomodar",
    "desacompanha": "desacompanhar",
    "desacompanhada": "desacompanhar",
    "desacompanhadas": "desacompanhar",
    "desacompanhado": "desacompanhar",
    "desacompanhados": "desacompanhar",
    "desacompanhai": "desacompanhar",
    "desacompanhais": "desacompanhar",
    "desacompanham": "desacompanhar",
    "desacompanhamo": "desacompanhar",
    "desacompanhamos": "desacompanhar",
    "desacompanhando": "desacompanhar",
    "desacompanhara": "desacompanhar",
    "desacompanharam": "desacompanhar",
    "desacompanharas": "desacompanhar",
    "desacompanharde": "desacompanhar",
    "desacompanhardes": "desacompanhar",
    "desacompanhare": "desacompanhar",
    "desacompanharei": "desacompanhar",
    "desacompanhareis": "desacompanhar",
    "desacompanharem": "desacompanhar",
    "desacompanharemos": "desacompanhar",
    "desacompanhares": "desacompanhar",
    "desacompanharia": "desacompanhar",
    "desacompanhariam": "desacompanhar",
    "desacompanharias": "desacompanhar",
    "desacompanharmo": "desacompanhar",
    "desacompanharmos": "desacompanhar",
    "desacompanhará": "desacompanhar",
    "desacompanharás": "desacompanhar",
    "desacompanharão": "desacompanhar",
    "desacompanharíamos": "desacompanhar",
    "desacompanharíeis": "desacompanhar",
    "desacompanhas": "desacompanhar",
    "desacompanhasse": "desacompanhar",
    "desacompanhassem": "desacompanhar",
    "desacompanhasses": "desacompanhar",
    "desacompanhaste": "desacompanhar",
    "desacompanhastes": "desacompanhar",
    "desacompanhava": "desacompanhar",
    "desacompanhavam": "desacompanhar",
    "desacompanhavas": "desacompanhar",
    "desacompanhe": "desacompanhar",
    "desacompanhei": "desacompanhar",
    "desacompanheis": "desacompanhar",
    "desacompanhem": "desacompanhar",
    "desacompanhemo": "desacompanhar",
    "desacompanhemos": "desacompanhar",
    "desacompanhes": "desacompanhar",
    "desacompanho": "desacompanhar",
    "desacompanhou": "desacompanhar",
    "desacompanhá": "desacompanhar",
    "desacompanhámo": "desacompanhar",
    "desacompanhámos": "desacompanhar",
    "desacompanháramo": "desacompanhar",
    "desacompanháramos": "desacompanhar",
    "desacompanhárei": "desacompanhar",
    "desacompanháreis": "desacompanhar",
    "desacompanhásseis": "desacompanhar",
    "desacompanhássemos": "desacompanhar",
    "desacompanhávamo": "desacompanhar",
    "desacompanhávamos": "desacompanhar",
    "desacompanhávei": "desacompanhar",
    "desacompanháveis": "desacompanhar",
    "desacompassada": "desacompassado",
    "desacompassadas": "desacompassado",
    "desacompassados": "desacompassado",
    "desaconchega": "desaconchegar",
    "desaconchegada": "desaconchegar",
    "desaconchegadas": "desaconchegar",
    "desaconchegado": "desaconchegar",
    "desaconchegados": "desaconchegar",
    "desaconchegai": "desaconchegar",
    "desaconchegais": "desaconchegar",
    "desaconchegam": "desaconchegar",
    "desaconchegamo": "desaconchegar",
    "desaconchegamos": "desaconchegar",
    "desaconchegando": "desaconchegar",
    "desaconchegara": "desaconchegar",
    "desaconchegaram": "desaconchegar",
    "desaconchegaras": "desaconchegar",
    "desaconchegarde": "desaconchegar",
    "desaconchegardes": "desaconchegar",
    "desaconchegare": "desaconchegar",
    "desaconchegarei": "desaconchegar",
    "desaconchegareis": "desaconchegar",
    "desaconchegarem": "desaconchegar",
    "desaconchegaremos": "desaconchegar",
    "desaconchegares": "desaconchegar",
    "desaconchegaria": "desaconchegar",
    "desaconchegariam": "desaconchegar",
    "desaconchegarias": "desaconchegar",
    "desaconchegarmo": "desaconchegar",
    "desaconchegarmos": "desaconchegar",
    "desaconchegará": "desaconchegar",
    "desaconchegarás": "desaconchegar",
    "desaconchegarão": "desaconchegar",
    "desaconchegaríamos": "desaconchegar",
    "desaconchegaríeis": "desaconchegar",
    "desaconchegas": "desaconchegar",
    "desaconchegasse": "desaconchegar",
    "desaconchegassem": "desaconchegar",
    "desaconchegasses": "desaconchegar",
    "desaconchegaste": "desaconchegar",
    "desaconchegastes": "desaconchegar",
    "desaconchegava": "desaconchegar",
    "desaconchegavam": "desaconchegar",
    "desaconchegavas": "desaconchegar",
    "desaconchego": "desaconchegar",
    "desaconchegou": "desaconchegar",
    "desaconchegue": "desaconchegar",
    "desaconcheguei": "desaconchegar",
    "desaconchegueis": "desaconchegar",
    "desaconcheguem": "desaconchegar",
    "desaconcheguemo": "desaconchegar",
    "desaconcheguemos": "desaconchegar",
    "desaconchegues": "desaconchegar",
    "desaconchegá": "desaconchegar",
    "desaconchegámo": "desaconchegar",
    "desaconchegámos": "desaconchegar",
    "desaconchegáramo": "desaconchegar",
    "desaconchegáramos": "desaconchegar",
    "desaconchegárei": "desaconchegar",
    "desaconchegáreis": "desaconchegar",
    "desaconchegásseis": "desaconchegar",
    "desaconchegássemos": "desaconchegar",
    "desaconchegávamo": "desaconchegar",
    "desaconchegávamos": "desaconchegar",
    "desaconchegávei": "desaconchegar",
    "desaconchegáveis": "desaconchegar",
    "desaconselha": "desaconselhar",
    "desaconselhada": "desaconselhar",
    "desaconselhadas": "desaconselhar",
    "desaconselhado": "desaconselhar",
    "desaconselhados": "desaconselhar",
    "desaconselhai": "desaconselhar",
    "desaconselhais": "desaconselhar",
    "desaconselham": "desaconselhar",
    "desaconselhamo": "desaconselhar",
    "desaconselhamos": "desaconselhar",
    "desaconselhando": "desaconselhar",
    "desaconselhara": "desaconselhar",
    "desaconselharam": "desaconselhar",
    "desaconselharas": "desaconselhar",
    "desaconselharde": "desaconselhar",
    "desaconselhardes": "desaconselhar",
    "desaconselhare": "desaconselhar",
    "desaconselharei": "desaconselhar",
    "desaconselhareis": "desaconselhar",
    "desaconselharem": "desaconselhar",
    "desaconselharemos": "desaconselhar",
    "desaconselhares": "desaconselhar",
    "desaconselharia": "desaconselhar",
    "desaconselhariam": "desaconselhar",
    "desaconselharias": "desaconselhar",
    "desaconselharmo": "desaconselhar",
    "desaconselharmos": "desaconselhar",
    "desaconselhará": "desaconselhar",
    "desaconselharás": "desaconselhar",
    "desaconselharão": "desaconselhar",
    "desaconselharíamos": "desaconselhar",
    "desaconselharíeis": "desaconselhar",
    "desaconselhas": "desaconselhar",
    "desaconselhasse": "desaconselhar",
    "desaconselhassem": "desaconselhar",
    "desaconselhasses": "desaconselhar",
    "desaconselhaste": "desaconselhar",
    "desaconselhastes": "desaconselhar",
    "desaconselhava": "desaconselhar",
    "desaconselhavam": "desaconselhar",
    "desaconselhavas": "desaconselhar",
    "desaconselhe": "desaconselhar",
    "desaconselhei": "desaconselhar",
    "desaconselheis": "desaconselhar",
    "desaconselhem": "desaconselhar",
    "desaconselhemo": "desaconselhar",
    "desaconselhemos": "desaconselhar",
    "desaconselhes": "desaconselhar",
    "desaconselho": "desaconselhar",
    "desaconselhou": "desaconselhar",
    "desaconselhá": "desaconselhar",
    "desaconselhámo": "desaconselhar",
    "desaconselhámos": "desaconselhar",
    "desaconselháramo": "desaconselhar",
    "desaconselháramos": "desaconselhar",
    "desaconselhárei": "desaconselhar",
    "desaconselháreis": "desaconselhar",
    "desaconselhásseis": "desaconselhar",
    "desaconselhássemos": "desaconselhar",
    "desaconselhávamo": "desaconselhar",
    "desaconselhávamos": "desaconselhar",
    "desaconselhávei": "desaconselhar",
    "desaconselháveis": "desaconselhável",
    "desacoplamentos": "desacoplamento",
    "desacorda": "desacordar",
    "desacordada": "desacordar",
    "desacordadas": "desacordar",
    "desacordado": "desacordar",
    "desacordados": "desacordar",
    "desacordai": "desacordar",
    "desacordais": "desacordar",
    "desacordam": "desacordar",
    "desacordamo": "desacordar",
    "desacordamos": "desacordar",
    "desacordando": "desacordar",
    "desacordantes": "desacordante",
    "desacordara": "desacordar",
    "desacordaram": "desacordar",
    "desacordaras": "desacordar",
    "desacordarde": "desacordar",
    "desacordardes": "desacordar",
    "desacordare": "desacordar",
    "desacordarei": "desacordar",
    "desacordareis": "desacordar",
    "desacordarem": "desacordar",
    "desacordaremos": "desacordar",
    "desacordares": "desacordar",
    "desacordaria": "desacordar",
    "desacordariam": "desacordar",
    "desacordarias": "desacordar",
    "desacordarmo": "desacordar",
    "desacordarmos": "desacordar",
    "desacordará": "desacordar",
    "desacordarás": "desacordar",
    "desacordarão": "desacordar",
    "desacordaríamos": "desacordar",
    "desacordaríeis": "desacordar",
    "desacordas": "desacordar",
    "desacordasse": "desacordar",
    "desacordassem": "desacordar",
    "desacordasses": "desacordar",
    "desacordaste": "desacordar",
    "desacordastes": "desacordar",
    "desacordava": "desacordar",
    "desacordavam": "desacordar",
    "desacordavas": "desacordar",
    "desacorde": "desacordar",
    "desacordei": "desacordar",
    "desacordeis": "desacordar",
    "desacordem": "desacordar",
    "desacordemo": "desacordar",
    "desacordemos": "desacordar",
    "desacordes": "desacorde",
    "desacordo": "desacordar",
    "desacordos": "desacordo",
    "desacordou": "desacordar",
    "desacordá": "desacordar",
    "desacordámo": "desacordar",
    "desacordámos": "desacordar",
    "desacordáramo": "desacordar",
    "desacordáramos": "desacordar",
    "desacordárei": "desacordar",
    "desacordáreis": "desacordar",
    "desacordásseis": "desacordar",
    "desacordássemos": "desacordar",
    "desacordávamo": "desacordar",
    "desacordávamos": "desacordar",
    "desacordávei": "desacordar",
    "desacordáveis": "desacordar",
    "desacoroçoa": "desacoroçoar",
    "desacoroçoada": "desacoroçoar",
    "desacoroçoadas": "desacoroçoar",
    "desacoroçoado": "desacoroçoar",
    "desacoroçoados": "desacoroçoar",
    "desacoroçoadíssima": "desacoroçoado",
    "desacoroçoadíssimas": "desacoroçoado",
    "desacoroçoadíssimo": "desacoroçoado",
    "desacoroçoadíssimos": "desacoroçoado",
    "desacoroçoai": "desacoroçoar",
    "desacoroçoais": "desacoroçoar",
    "desacoroçoam": "desacoroçoar",
    "desacoroçoamo": "desacoroçoar",
    "desacoroçoamos": "desacoroçoar",
    "desacoroçoando": "desacoroçoar",
    "desacoroçoara": "desacoroçoar",
    "desacoroçoaram": "desacoroçoar",
    "desacoroçoaras": "desacoroçoar",
    "desacoroçoarde": "desacoroçoar",
    "desacoroçoardes": "desacoroçoar",
    "desacoroçoare": "desacoroçoar",
    "desacoroçoarei": "desacoroçoar",
    "desacoroçoareis": "desacoroçoar",
    "desacoroçoarem": "desacoroçoar",
    "desacoroçoaremos": "desacoroçoar",
    "desacoroçoares": "desacoroçoar",
    "desacoroçoaria": "desacoroçoar",
    "desacoroçoariam": "desacoroçoar",
    "desacoroçoarias": "desacoroçoar",
    "desacoroçoarmo": "desacoroçoar",
    "desacoroçoarmos": "desacoroçoar",
    "desacoroçoará": "desacoroçoar",
    "desacoroçoarás": "desacoroçoar",
    "desacoroçoarão": "desacoroçoar",
    "desacoroçoaríamos": "desacoroçoar",
    "desacoroçoaríeis": "desacoroçoar",
    "desacoroçoas": "desacoroçoar",
    "desacoroçoasse": "desacoroçoar",
    "desacoroçoassem": "desacoroçoar",
    "desacoroçoasses": "desacoroçoar",
    "desacoroçoaste": "desacoroçoar",
    "desacoroçoastes": "desacoroçoar",
    "desacoroçoava": "desacoroçoar",
    "desacoroçoavam": "desacoroçoar",
    "desacoroçoavas": "desacoroçoar",
    "desacoroçoe": "desacoroçoar",
    "desacoroçoei": "desacoroçoar",
    "desacoroçoeis": "desacoroçoar",
    "desacoroçoem": "desacoroçoar",
    "desacoroçoemo": "desacoroçoar",
    "desacoroçoemos": "desacoroçoar",
    "desacoroçoes": "desacoroçoar",
    "desacoroçoo": "desacoroçoar",
    "desacoroçoou": "desacoroçoar",
    "desacoroçoá": "desacoroçoar",
    "desacoroçoámo": "desacoroçoar",
    "desacoroçoámos": "desacoroçoar",
    "desacoroçoáramo": "desacoroçoar",
    "desacoroçoáramos": "desacoroçoar",
    "desacoroçoárei": "desacoroçoar",
    "desacoroçoáreis": "desacoroçoar",
    "desacoroçoásseis": "desacoroçoar",
    "desacoroçoássemos": "desacoroçoar",
    "desacoroçoávamo": "desacoroçoar",
    "desacoroçoávamos": "desacoroçoar",
    "desacoroçoávei": "desacoroçoar",
    "desacoroçoáveis": "desacoroçoar",
    "desacorrenta": "desacorrentar",
    "desacorrentada": "desacorrentar",
    "desacorrentadas": "desacorrentar",
    "desacorrentado": "desacorrentar",
    "desacorrentados": "desacorrentar",
    "desacorrentai": "desacorrentar",
    "desacorrentais": "desacorrentar",
    "desacorrentam": "desacorrentar",
    "desacorrentamo": "desacorrentar",
    "desacorrentamos": "desacorrentar",
    "desacorrentando": "desacorrentar",
    "desacorrentara": "desacorrentar",
    "desacorrentaram": "desacorrentar",
    "desacorrentaras": "desacorrentar",
    "desacorrentarde": "desacorrentar",
    "desacorrentardes": "desacorrentar",
    "desacorrentare": "desacorrentar",
    "desacorrentarei": "desacorrentar",
    "desacorrentareis": "desacorrentar",
    "desacorrentarem": "desacorrentar",
    "desacorrentaremos": "desacorrentar",
    "desacorrentares": "desacorrentar",
    "desacorrentaria": "desacorrentar",
    "desacorrentariam": "desacorrentar",
    "desacorrentarias": "desacorrentar",
    "desacorrentarmo": "desacorrentar",
    "desacorrentarmos": "desacorrentar",
    "desacorrentará": "desacorrentar",
    "desacorrentarás": "desacorrentar",
    "desacorrentarão": "desacorrentar",
    "desacorrentaríamos": "desacorrentar",
    "desacorrentaríeis": "desacorrentar",
    "desacorrentas": "desacorrentar",
    "desacorrentasse": "desacorrentar",
    "desacorrentassem": "desacorrentar",
    "desacorrentasses": "desacorrentar",
    "desacorrentaste": "desacorrentar",
    "desacorrentastes": "desacorrentar",
    "desacorrentava": "desacorrentar",
    "desacorrentavam": "desacorrentar",
    "desacorrentavas": "desacorrentar",
    "desacorrente": "desacorrentar",
    "desacorrentei": "desacorrentar",
    "desacorrenteis": "desacorrentar",
    "desacorrentem": "desacorrentar",
    "desacorrentemo": "desacorrentar",
    "desacorrentemos": "desacorrentar",
    "desacorrentes": "desacorrentar",
    "desacorrento": "desacorrentar",
    "desacorrentou": "desacorrentar",
    "desacorrentá": "desacorrentar",
    "desacorrentámo": "desacorrentar",
    "desacorrentámos": "desacorrentar",
    "desacorrentáramo": "desacorrentar",
    "desacorrentáramos": "desacorrentar",
    "desacorrentárei": "desacorrentar",
    "desacorrentáreis": "desacorrentar",
    "desacorrentásseis": "desacorrentar",
    "desacorrentássemos": "desacorrentar",
    "desacorrentávamo": "desacorrentar",
    "desacorrentávamos": "desacorrentar",
    "desacorrentávei": "desacorrentar",
    "desacorrentáveis": "desacorrentar",
    "desacorçoa": "desacorçoar",
    "desacorçoada": "desacorçoar",
    "desacorçoadas": "desacorçoar",
    "desacorçoado": "desacorçoar",
    "desacorçoados": "desacorçoar",
    "desacorçoai": "desacorçoar",
    "desacorçoais": "desacorçoar",
    "desacorçoam": "desacorçoar",
    "desacorçoamo": "desacorçoar",
    "desacorçoamos": "desacorçoar",
    "desacorçoando": "desacorçoar",
    "desacorçoara": "desacorçoar",
    "desacorçoaram": "desacorçoar",
    "desacorçoaras": "desacorçoar",
    "desacorçoarde": "desacorçoar",
    "desacorçoardes": "desacorçoar",
    "desacorçoare": "desacorçoar",
    "desacorçoarei": "desacorçoar",
    "desacorçoareis": "desacorçoar",
    "desacorçoarem": "desacorçoar",
    "desacorçoaremos": "desacorçoar",
    "desacorçoares": "desacorçoar",
    "desacorçoaria": "desacorçoar",
    "desacorçoariam": "desacorçoar",
    "desacorçoarias": "desacorçoar",
    "desacorçoarmo": "desacorçoar",
    "desacorçoarmos": "desacorçoar",
    "desacorçoará": "desacorçoar",
    "desacorçoarás": "desacorçoar",
    "desacorçoarão": "desacorçoar",
    "desacorçoaríamos": "desacorçoar",
    "desacorçoaríeis": "desacorçoar",
    "desacorçoas": "desacorçoar",
    "desacorçoasse": "desacorçoar",
    "desacorçoassem": "desacorçoar",
    "desacorçoasses": "desacorçoar",
    "desacorçoaste": "desacorçoar",
    "desacorçoastes": "desacorçoar",
    "desacorçoava": "desacorçoar",
    "desacorçoavam": "desacorçoar",
    "desacorçoavas": "desacorçoar",
    "desacorçoe": "desacorçoar",
    "desacorçoei": "desacorçoar",
    "desacorçoeis": "desacorçoar",
    "desacorçoem": "desacorçoar",
    "desacorçoemo": "desacorçoar",
    "desacorçoemos": "desacorçoar",
    "desacorçoes": "desacorçoar",
    "desacorçoo": "desacorçoar",
    "desacorçoou": "desacorçoar",
    "desacorçoá": "desacorçoar",
    "desacorçoámo": "desacorçoar",
    "desacorçoámos": "desacorçoar",
    "desacorçoáramo": "desacorçoar",
    "desacorçoáramos": "desacorçoar",
    "desacorçoárei": "desacorçoar",
    "desacorçoáreis": "desacorçoar",
    "desacorçoásseis": "desacorçoar",
    "desacorçoássemos": "desacorçoar",
    "desacorçoávamo": "desacorçoar",
    "desacorçoávamos": "desacorçoar",
    "desacorçoávei": "desacorçoar",
    "desacorçoáveis": "desacorçoar",
    "desacosta": "desacostar",
    "desacostada": "desacostar",
    "desacostadas": "desacostar",
    "desacostado": "desacostar",
    "desacostados": "desacostar",
    "desacostai": "desacostar",
    "desacostais": "desacostar",
    "desacostam": "desacostar",
    "desacostamo": "desacostar",
    "desacostamos": "desacostar",
    "desacostando": "desacostar",
    "desacostara": "desacostar",
    "desacostaram": "desacostar",
    "desacostaras": "desacostar",
    "desacostarde": "desacostar",
    "desacostardes": "desacostar",
    "desacostare": "desacostar",
    "desacostarei": "desacostar",
    "desacostareis": "desacostar",
    "desacostarem": "desacostar",
    "desacostaremos": "desacostar",
    "desacostares": "desacostar",
    "desacostaria": "desacostar",
    "desacostariam": "desacostar",
    "desacostarias": "desacostar",
    "desacostarmo": "desacostar",
    "desacostarmos": "desacostar",
    "desacostará": "desacostar",
    "desacostarás": "desacostar",
    "desacostarão": "desacostar",
    "desacostaríamos": "desacostar",
    "desacostaríeis": "desacostar",
    "desacostas": "desacostar",
    "desacostasse": "desacostar",
    "desacostassem": "desacostar",
    "desacostasses": "desacostar",
    "desacostaste": "desacostar",
    "desacostastes": "desacostar",
    "desacostava": "desacostar",
    "desacostavam": "desacostar",
    "desacostavas": "desacostar",
    "desacoste": "desacostar",
    "desacostei": "desacostar",
    "desacosteis": "desacostar",
    "desacostem": "desacostar",
    "desacostemo": "desacostar",
    "desacostemos": "desacostar",
    "desacostes": "desacostar",
    "desacosto": "desacostar",
    "desacostou": "desacostar",
    "desacostuma": "desacostumar",
    "desacostumada": "desacostumar",
    "desacostumadas": "desacostumar",
    "desacostumado": "desacostumar",
    "desacostumados": "desacostumar",
    "desacostumai": "desacostumar",
    "desacostumais": "desacostumar",
    "desacostumam": "desacostumar",
    "desacostumamo": "desacostumar",
    "desacostumamos": "desacostumar",
    "desacostumando": "desacostumar",
    "desacostumara": "desacostumar",
    "desacostumaram": "desacostumar",
    "desacostumaras": "desacostumar",
    "desacostumarde": "desacostumar",
    "desacostumardes": "desacostumar",
    "desacostumare": "desacostumar",
    "desacostumarei": "desacostumar",
    "desacostumareis": "desacostumar",
    "desacostumarem": "desacostumar",
    "desacostumaremos": "desacostumar",
    "desacostumares": "desacostumar",
    "desacostumaria": "desacostumar",
    "desacostumariam": "desacostumar",
    "desacostumarias": "desacostumar",
    "desacostumarmo": "desacostumar",
    "desacostumarmos": "desacostumar",
    "desacostumará": "desacostumar",
    "desacostumarás": "desacostumar",
    "desacostumarão": "desacostumar",
    "desacostumaríamos": "desacostumar",
    "desacostumaríeis": "desacostumar",
    "desacostumas": "desacostumar",
    "desacostumasse": "desacostumar",
    "desacostumassem": "desacostumar",
    "desacostumasses": "desacostumar",
    "desacostumaste": "desacostumar",
    "desacostumastes": "desacostumar",
    "desacostumava": "desacostumar",
    "desacostumavam": "desacostumar",
    "desacostumavas": "desacostumar",
    "desacostume": "desacostumar",
    "desacostumei": "desacostumar",
    "desacostumeis": "desacostumar",
    "desacostumem": "desacostumar",
    "desacostumemo": "desacostumar",
    "desacostumemos": "desacostumar",
    "desacostumes": "desacostumar",
    "desacostumo": "desacostumar",
    "desacostumou": "desacostumar",
    "desacostumá": "desacostumar",
    "desacostumámo": "desacostumar",
    "desacostumámos": "desacostumar",
    "desacostumáramo": "desacostumar",
    "desacostumáramos": "desacostumar",
    "desacostumárei": "desacostumar",
    "desacostumáreis": "desacostumar",
    "desacostumásseis": "desacostumar",
    "desacostumássemos": "desacostumar",
    "desacostumávamo": "desacostumar",
    "desacostumávamos": "desacostumar",
    "desacostumávei": "desacostumar",
    "desacostumáveis": "desacostumar",
    "desacostá": "desacostar",
    "desacostámo": "desacostar",
    "desacostámos": "desacostar",
    "desacostáramo": "desacostar",
    "desacostáramos": "desacostar",
    "desacostárei": "desacostar",
    "desacostáreis": "desacostar",
    "desacostásseis": "desacostar",
    "desacostássemos": "desacostar",
    "desacostávamo": "desacostar",
    "desacostávamos": "desacostar",
    "desacostávei": "desacostar",
    "desacostáveis": "desacostar",
    "desacouta": "desacoutar",
    "desacoutada": "desacoutar",
    "desacoutadas": "desacoutar",
    "desacoutado": "desacoutar",
    "desacoutados": "desacoutar",
    "desacoutai": "desacoutar",
    "desacoutais": "desacoutar",
    "desacoutam": "desacoutar",
    "desacoutamo": "desacoutar",
    "desacoutamos": "desacoutar",
    "desacoutando": "desacoutar",
    "desacoutara": "desacoutar",
    "desacoutaram": "desacoutar",
    "desacoutaras": "desacoutar",
    "desacoutarde": "desacoutar",
    "desacoutardes": "desacoutar",
    "desacoutare": "desacoutar",
    "desacoutarei": "desacoutar",
    "desacoutareis": "desacoutar",
    "desacoutarem": "desacoutar",
    "desacoutaremos": "desacoutar",
    "desacoutares": "desacoutar",
    "desacoutaria": "desacoutar",
    "desacoutariam": "desacoutar",
    "desacoutarias": "desacoutar",
    "desacoutarmo": "desacoutar",
    "desacoutarmos": "desacoutar",
    "desacoutará": "desacoutar",
    "desacoutarás": "desacoutar",
    "desacoutarão": "desacoutar",
    "desacoutaríamos": "desacoutar",
    "desacoutaríeis": "desacoutar",
    "desacoutas": "desacoutar",
    "desacoutasse": "desacoutar",
    "desacoutassem": "desacoutar",
    "desacoutasses": "desacoutar",
    "desacoutaste": "desacoutar",
    "desacoutastes": "desacoutar",
    "desacoutava": "desacoutar",
    "desacoutavam": "desacoutar",
    "desacoutavas": "desacoutar",
    "desacoute": "desacoutar",
    "desacoutei": "desacoutar",
    "desacouteis": "desacoutar",
    "desacoutem": "desacoutar",
    "desacoutemo": "desacoutar",
    "desacoutemos": "desacoutar",
    "desacoutes": "desacoutar",
    "desacouto": "desacoutar",
    "desacoutou": "desacoutar",
    "desacoutá": "desacoutar",
    "desacoutámo": "desacoutar",
    "desacoutámos": "desacoutar",
    "desacoutáramo": "desacoutar",
    "desacoutáramos": "desacoutar",
    "desacoutárei": "desacoutar",
    "desacoutáreis": "desacoutar",
    "desacoutásseis": "desacoutar",
    "desacoutássemos": "desacoutar",
    "desacoutávamo": "desacoutar",
    "desacoutávamos": "desacoutar",
    "desacoutávei": "desacoutar",
    "desacoutáveis": "desacoutar",
    "desacredita": "desacreditar",
    "desacreditada": "desacreditar",
    "desacreditadas": "desacreditar",
    "desacreditado": "desacreditar",
    "desacreditadora": "desacreditador",
    "desacreditadoras": "desacreditador",
    "desacreditadores": "desacreditador",
    "desacreditados": "desacreditar",
    "desacreditai": "desacreditar",
    "desacreditais": "desacreditar",
    "desacreditam": "desacreditar",
    "desacreditamo": "desacreditar",
    "desacreditamos": "desacreditar",
    "desacreditando": "desacreditar",
    "desacreditara": "desacreditar",
    "desacreditaram": "desacreditar",
    "desacreditaras": "desacreditar",
    "desacreditarde": "desacreditar",
    "desacreditardes": "desacreditar",
    "desacreditare": "desacreditar",
    "desacreditarei": "desacreditar",
    "desacreditareis": "desacreditar",
    "desacreditarem": "desacreditar",
    "desacreditaremos": "desacreditar",
    "desacreditares": "desacreditar",
    "desacreditaria": "desacreditar",
    "desacreditariam": "desacreditar",
    "desacreditarias": "desacreditar",
    "desacreditarmo": "desacreditar",
    "desacreditarmos": "desacreditar",
    "desacreditará": "desacreditar",
    "desacreditarás": "desacreditar",
    "desacreditarão": "desacreditar",
    "desacreditaríamos": "desacreditar",
    "desacreditaríeis": "desacreditar",
    "desacreditas": "desacreditar",
    "desacreditasse": "desacreditar",
    "desacreditassem": "desacreditar",
    "desacreditasses": "desacreditar",
    "desacreditaste": "desacreditar",
    "desacreditastes": "desacreditar",
    "desacreditava": "desacreditar",
    "desacreditavam": "desacreditar",
    "desacreditavas": "desacreditar",
    "desacreditações": "desacreditação",
    "desacredite": "desacreditar",
    "desacreditei": "desacreditar",
    "desacrediteis": "desacreditar",
    "desacreditem": "desacreditar",
    "desacreditemo": "desacreditar",
    "desacreditemos": "desacreditar",
    "desacredites": "desacreditar",
    "desacredito": "desacreditar",
    "desacreditou": "desacreditar",
    "desacreditá": "desacreditar",
    "desacreditámo": "desacreditar",
    "desacreditámos": "desacreditar",
    "desacreditáramo": "desacreditar",
    "desacreditáramos": "desacreditar",
    "desacreditárei": "desacreditar",
    "desacreditáreis": "desacreditar",
    "desacreditásseis": "desacreditar",
    "desacreditássemos": "desacreditar",
    "desacreditávamo": "desacreditar",
    "desacreditávamos": "desacreditar",
    "desacreditávei": "desacreditar",
    "desacreditáveis": "desacreditar",
    "desactiva": "desactivar",
    "desactivada": "desactivar",
    "desactivadas": "desactivar",
    "desactivado": "desactivar",
    "desactivados": "desactivar",
    "desactivai": "desactivar",
    "desactivais": "desactivar",
    "desactivam": "desactivar",
    "desactivamo": "desactivar",
    "desactivamos": "desactivar",
    "desactivando": "desactivar",
    "desactivara": "desactivar",
    "desactivaram": "desactivar",
    "desactivaras": "desactivar",
    "desactivarde": "desactivar",
    "desactivardes": "desactivar",
    "desactivare": "desactivar",
    "desactivarei": "desactivar",
    "desactivareis": "desactivar",
    "desactivarem": "desactivar",
    "desactivaremos": "desactivar",
    "desactivares": "desactivar",
    "desactivaria": "desactivar",
    "desactivariam": "desactivar",
    "desactivarias": "desactivar",
    "desactivarmo": "desactivar",
    "desactivarmos": "desactivar",
    "desactivará": "desactivar",
    "desactivarás": "desactivar",
    "desactivarão": "desactivar",
    "desactivaríamos": "desactivar",
    "desactivaríeis": "desactivar",
    "desactivas": "desactivar",
    "desactivasse": "desactivar",
    "desactivassem": "desactivar",
    "desactivasses": "desactivar",
    "desactivaste": "desactivar",
    "desactivastes": "desactivar",
    "desactivava": "desactivar",
    "desactivavam": "desactivar",
    "desactivavas": "desactivar",
    "desactivações": "desactivação",
    "desactive": "desactivar",
    "desactivei": "desactivar",
    "desactiveis": "desactivar",
    "desactivem": "desactivar",
    "desactivemo": "desactivar",
    "desactivemos": "desactivar",
    "desactives": "desactivar",
    "desactivo": "desactivar",
    "desactivou": "desactivar",
    "desactivá": "desactivar",
    "desactivámo": "desactivar",
    "desactivámos": "desactivar",
    "desactiváramo": "desactivar",
    "desactiváramos": "desactivar",
    "desactivárei": "desactivar",
    "desactiváreis": "desactivar",
    "desactivásseis": "desactivar",
    "desactivássemos": "desactivar",
    "desactivávamo": "desactivar",
    "desactivávamos": "desactivar",
    "desactivávei": "desactivar",
    "desactiváveis": "desactivar",
    "desactualiza": "desactualizar",
    "desactualizada": "desactualizar",
    "desactualizadas": "desactualizar",
    "desactualizado": "desactualizar",
    "desactualizados": "desactualizar",
    "desactualizai": "desactualizar",
    "desactualizais": "desactualizar",
    "desactualizam": "desactualizar",
    "desactualizamo": "desactualizar",
    "desactualizamos": "desactualizar",
    "desactualizando": "desactualizar",
    "desactualizara": "desactualizar",
    "desactualizaram": "desactualizar",
    "desactualizaras": "desactualizar",
    "desactualizarde": "desactualizar",
    "desactualizardes": "desactualizar",
    "desactualizare": "desactualizar",
    "desactualizarei": "desactualizar",
    "desactualizareis": "desactualizar",
    "desactualizarem": "desactualizar",
    "desactualizaremos": "desactualizar",
    "desactualizares": "desactualizar",
    "desactualizaria": "desactualizar",
    "desactualizariam": "desactualizar",
    "desactualizarias": "desactualizar",
    "desactualizarmo": "desactualizar",
    "desactualizarmos": "desactualizar",
    "desactualizará": "desactualizar",
    "desactualizarás": "desactualizar",
    "desactualizarão": "desactualizar",
    "desactualizaríamos": "desactualizar",
    "desactualizaríeis": "desactualizar",
    "desactualizas": "desactualizar",
    "desactualizasse": "desactualizar",
    "desactualizassem": "desactualizar",
    "desactualizasses": "desactualizar",
    "desactualizaste": "desactualizar",
    "desactualizastes": "desactualizar",
    "desactualizava": "desactualizar",
    "desactualizavam": "desactualizar",
    "desactualizavas": "desactualizar",
    "desactualizações": "desactualização",
    "desactualize": "desactualizar",
    "desactualizei": "desactualizar",
    "desactualizeis": "desactualizar",
    "desactualizem": "desactualizar",
    "desactualizemo": "desactualizar",
    "desactualizemos": "desactualizar",
    "desactualizes": "desactualizar",
    "desactualizo": "desactualizar",
    "desactualizou": "desactualizar",
    "desactualizá": "desactualizar",
    "desactualizámo": "desactualizar",
    "desactualizámos": "desactualizar",
    "desactualizáramo": "desactualizar",
    "desactualizáramos": "desactualizar",
    "desactualizárei": "desactualizar",
    "desactualizáreis": "desactualizar",
    "desactualizásseis": "desactualizar",
    "desactualizássemos": "desactualizar",
    "desactualizávamo": "desactualizar",
    "desactualizávamos": "desactualizar",
    "desactualizávei": "desactualizar",
    "desactualizáveis": "desactualizar",
    "desacuada": "desacuado",
    "desacuadas": "desacuado",
    "desacuados": "desacuado",
    "desacumula": "desacumular",
    "desacumulada": "desacumular",
    "desacumuladas": "desacumular",
    "desacumulado": "desacumular",
    "desacumulados": "desacumular",
    "desacumulai": "desacumular",
    "desacumulais": "desacumular",
    "desacumulam": "desacumular",
    "desacumulamo": "desacumular",
    "desacumulamos": "desacumular",
    "desacumulando": "desacumular",
    "desacumulara": "desacumular",
    "desacumularam": "desacumular",
    "desacumularas": "desacumular",
    "desacumularde": "desacumular",
    "desacumulardes": "desacumular",
    "desacumulare": "desacumular",
    "desacumularei": "desacumular",
    "desacumulareis": "desacumular",
    "desacumularem": "desacumular",
    "desacumularemos": "desacumular",
    "desacumulares": "desacumular",
    "desacumularia": "desacumular",
    "desacumulariam": "desacumular",
    "desacumularias": "desacumular",
    "desacumularmo": "desacumular",
    "desacumularmos": "desacumular",
    "desacumulará": "desacumular",
    "desacumularás": "desacumular",
    "desacumularão": "desacumular",
    "desacumularíamos": "desacumular",
    "desacumularíeis": "desacumular",
    "desacumulas": "desacumular",
    "desacumulasse": "desacumular",
    "desacumulassem": "desacumular",
    "desacumulasses": "desacumular",
    "desacumulaste": "desacumular",
    "desacumulastes": "desacumular",
    "desacumulava": "desacumular",
    "desacumulavam": "desacumular",
    "desacumulavas": "desacumular",
    "desacumulações": "desacumulação",
    "desacumule": "desacumular",
    "desacumulei": "desacumular",
    "desacumuleis": "desacumular",
    "desacumulem": "desacumular",
    "desacumulemo": "desacumular",
    "desacumulemos": "desacumular",
    "desacumules": "desacumular",
    "desacumulo": "desacumular",
    "desacumulou": "desacumular",
    "desacumulá": "desacumular",
    "desacumulámo": "desacumular",
    "desacumulámos": "desacumular",
    "desacumuláramo": "desacumular",
    "desacumuláramos": "desacumular",
    "desacumulárei": "desacumular",
    "desacumuláreis": "desacumular",
    "desacumulásseis": "desacumular",
    "desacumulássemos": "desacumular",
    "desacumulávamo": "desacumular",
    "desacumulávamos": "desacumular",
    "desacumulávei": "desacumular",
    "desacumuláveis": "desacumular",
    "desacunha": "desacunhar",
    "desacunhada": "desacunhar",
    "desacunhadas": "desacunhar",
    "desacunhado": "desacunhar",
    "desacunhados": "desacunhar",
    "desacunhai": "desacunhar",
    "desacunhais": "desacunhar",
    "desacunham": "desacunhar",
    "desacunhamo": "desacunhar",
    "desacunhamos": "desacunhar",
    "desacunhando": "desacunhar",
    "desacunhara": "desacunhar",
    "desacunharam": "desacunhar",
    "desacunharas": "desacunhar",
    "desacunharde": "desacunhar",
    "desacunhardes": "desacunhar",
    "desacunhare": "desacunhar",
    "desacunharei": "desacunhar",
    "desacunhareis": "desacunhar",
    "desacunharem": "desacunhar",
    "desacunharemos": "desacunhar",
    "desacunhares": "desacunhar",
    "desacunharia": "desacunhar",
    "desacunhariam": "desacunhar",
    "desacunharias": "desacunhar",
    "desacunharmo": "desacunhar",
    "desacunharmos": "desacunhar",
    "desacunhará": "desacunhar",
    "desacunharás": "desacunhar",
    "desacunharão": "desacunhar",
    "desacunharíamos": "desacunhar",
    "desacunharíeis": "desacunhar",
    "desacunhas": "desacunhar",
    "desacunhasse": "desacunhar",
    "desacunhassem": "desacunhar",
    "desacunhasses": "desacunhar",
    "desacunhaste": "desacunhar",
    "desacunhastes": "desacunhar",
    "desacunhava": "desacunhar",
    "desacunhavam": "desacunhar",
    "desacunhavas": "desacunhar",
    "desacunhe": "desacunhar",
    "desacunhei": "desacunhar",
    "desacunheis": "desacunhar",
    "desacunhem": "desacunhar",
    "desacunhemo": "desacunhar",
    "desacunhemos": "desacunhar",
    "desacunhes": "desacunhar",
    "desacunho": "desacunhar",
    "desacunhou": "desacunhar",
    "desacunhá": "desacunhar",
    "desacunhámo": "desacunhar",
    "desacunhámos": "desacunhar",
    "desacunháramo": "desacunhar",
    "desacunháramos": "desacunhar",
    "desacunhárei": "desacunhar",
    "desacunháreis": "desacunhar",
    "desacunhásseis": "desacunhar",
    "desacunhássemos": "desacunhar",
    "desacunhávamo": "desacunhar",
    "desacunhávamos": "desacunhar",
    "desacunhávei": "desacunhar",
    "desacunháveis": "desacunhar",
    "desadapta": "desadaptar",
    "desadaptada": "desadaptar",
    "desadaptadas": "desadaptar",
    "desadaptado": "desadaptar",
    "desadaptados": "desadaptar",
    "desadaptai": "desadaptar",
    "desadaptais": "desadaptar",
    "desadaptam": "desadaptar",
    "desadaptamo": "desadaptar",
    "desadaptamos": "desadaptar",
    "desadaptando": "desadaptar",
    "desadaptara": "desadaptar",
    "desadaptaram": "desadaptar",
    "desadaptaras": "desadaptar",
    "desadaptarde": "desadaptar",
    "desadaptardes": "desadaptar",
    "desadaptare": "desadaptar",
    "desadaptarei": "desadaptar",
    "desadaptareis": "desadaptar",
    "desadaptarem": "desadaptar",
    "desadaptaremos": "desadaptar",
    "desadaptares": "desadaptar",
    "desadaptaria": "desadaptar",
    "desadaptariam": "desadaptar",
    "desadaptarias": "desadaptar",
    "desadaptarmo": "desadaptar",
    "desadaptarmos": "desadaptar",
    "desadaptará": "desadaptar",
    "desadaptarás": "desadaptar",
    "desadaptarão": "desadaptar",
    "desadaptaríamos": "desadaptar",
    "desadaptaríeis": "desadaptar",
    "desadaptas": "desadaptar",
    "desadaptasse": "desadaptar",
    "desadaptassem": "desadaptar",
    "desadaptasses": "desadaptar",
    "desadaptaste": "desadaptar",
    "desadaptastes": "desadaptar",
    "desadaptava": "desadaptar",
    "desadaptavam": "desadaptar",
    "desadaptavas": "desadaptar",
    "desadapte": "desadaptar",
    "desadaptei": "desadaptar",
    "desadapteis": "desadaptar",
    "desadaptem": "desadaptar",
    "desadaptemo": "desadaptar",
    "desadaptemos": "desadaptar",
    "desadaptes": "desadaptar",
    "desadapto": "desadaptar",
    "desadaptou": "desadaptar",
    "desadaptá": "desadaptar",
    "desadaptámo": "desadaptar",
    "desadaptámos": "desadaptar",
    "desadaptáramo": "desadaptar",
    "desadaptáramos": "desadaptar",
    "desadaptárei": "desadaptar",
    "desadaptáreis": "desadaptar",
    "desadaptásseis": "desadaptar",
    "desadaptássemos": "desadaptar",
    "desadaptávamo": "desadaptar",
    "desadaptávamos": "desadaptar",
    "desadaptávei": "desadaptar",
    "desadaptáveis": "desadaptar",
    "desadequada": "desadequado",
    "desadequadas": "desadequado",
    "desadequados": "desadequado",
    "desadequações": "desadequação",
    "desadmoesta": "desadmoestar",
    "desadmoestada": "desadmoestar",
    "desadmoestadas": "desadmoestar",
    "desadmoestado": "desadmoestar",
    "desadmoestados": "desadmoestar",
    "desadmoestai": "desadmoestar",
    "desadmoestais": "desadmoestar",
    "desadmoestam": "desadmoestar",
    "desadmoestamo": "desadmoestar",
    "desadmoestamos": "desadmoestar",
    "desadmoestando": "desadmoestar",
    "desadmoestara": "desadmoestar",
    "desadmoestaram": "desadmoestar",
    "desadmoestaras": "desadmoestar",
    "desadmoestarde": "desadmoestar",
    "desadmoestardes": "desadmoestar",
    "desadmoestare": "desadmoestar",
    "desadmoestarei": "desadmoestar",
    "desadmoestareis": "desadmoestar",
    "desadmoestarem": "desadmoestar",
    "desadmoestaremos": "desadmoestar",
    "desadmoestares": "desadmoestar",
    "desadmoestaria": "desadmoestar",
    "desadmoestariam": "desadmoestar",
    "desadmoestarias": "desadmoestar",
    "desadmoestarmo": "desadmoestar",
    "desadmoestarmos": "desadmoestar",
    "desadmoestará": "desadmoestar",
    "desadmoestarás": "desadmoestar",
    "desadmoestarão": "desadmoestar",
    "desadmoestaríamos": "desadmoestar",
    "desadmoestaríeis": "desadmoestar",
    "desadmoestas": "desadmoestar",
    "desadmoestasse": "desadmoestar",
    "desadmoestassem": "desadmoestar",
    "desadmoestasses": "desadmoestar",
    "desadmoestaste": "desadmoestar",
    "desadmoestastes": "desadmoestar",
    "desadmoestava": "desadmoestar",
    "desadmoestavam": "desadmoestar",
    "desadmoestavas": "desadmoestar",
    "desadmoeste": "desadmoestar",
    "desadmoestei": "desadmoestar",
    "desadmoesteis": "desadmoestar",
    "desadmoestem": "desadmoestar",
    "desadmoestemo": "desadmoestar",
    "desadmoestemos": "desadmoestar",
    "desadmoestes": "desadmoestar",
    "desadmoesto": "desadmoestar",
    "desadmoestou": "desadmoestar",
    "desadmoestá": "desadmoestar",
    "desadmoestámo": "desadmoestar",
    "desadmoestámos": "desadmoestar",
    "desadmoestáramo": "desadmoestar",
    "desadmoestáramos": "desadmoestar",
    "desadmoestárei": "desadmoestar",
    "desadmoestáreis": "desadmoestar",
    "desadmoestásseis": "desadmoestar",
    "desadmoestássemos": "desadmoestar",
    "desadmoestávamo": "desadmoestar",
    "desadmoestávamos": "desadmoestar",
    "desadmoestávei": "desadmoestar",
    "desadmoestáveis": "desadmoestar",
    "desadora": "desadorar",
    "desadorada": "desadorar",
    "desadoradas": "desadorar",
    "desadorado": "desadorar",
    "desadorados": "desadorar",
    "desadorai": "desadorar",
    "desadorais": "desadorar",
    "desadoram": "desadorar",
    "desadoramo": "desadorar",
    "desadoramos": "desadorar",
    "desadorando": "desadorar",
    "desadorara": "desadorar",
    "desadoraram": "desadorar",
    "desadoraras": "desadorar",
    "desadorarde": "desadorar",
    "desadorardes": "desadorar",
    "desadorare": "desadorar",
    "desadorarei": "desadorar",
    "desadorareis": "desadorar",
    "desadorarem": "desadorar",
    "desadoraremos": "desadorar",
    "desadorares": "desadorar",
    "desadoraria": "desadorar",
    "desadorariam": "desadorar",
    "desadorarias": "desadorar",
    "desadorarmo": "desadorar",
    "desadorarmos": "desadorar",
    "desadorará": "desadorar",
    "desadorarás": "desadorar",
    "desadorarão": "desadorar",
    "desadoraríamos": "desadorar",
    "desadoraríeis": "desadorar",
    "desadoras": "desadorar",
    "desadorasse": "desadorar",
    "desadorassem": "desadorar",
    "desadorasses": "desadorar",
    "desadoraste": "desadorar",
    "desadorastes": "desadorar",
    "desadorava": "desadorar",
    "desadoravam": "desadorar",
    "desadoravas": "desadorar",
    "desadorações": "desadoração",
    "desadore": "desadorar",
    "desadorei": "desadorar",
    "desadoreis": "desadorar",
    "desadorem": "desadorar",
    "desadoremo": "desadorar",
    "desadoremos": "desadorar",
    "desadores": "desadorar",
    "desadormece": "desadormecer",
    "desadormecei": "desadormecer",
    "desadormeceis": "desadormecer",
    "desadormecem": "desadormecer",
    "desadormecemo": "desadormecer",
    "desadormecemos": "desadormecer",
    "desadormecendo": "desadormecer",
    "desadormecera": "desadormecer",
    "desadormeceram": "desadormecer",
    "desadormeceras": "desadormecer",
    "desadormecerde": "desadormecer",
    "desadormecerdes": "desadormecer",
    "desadormecere": "desadormecer",
    "desadormecerei": "desadormecer",
    "desadormecereis": "desadormecer",
    "desadormecerem": "desadormecer",
    "desadormeceremos": "desadormecer",
    "desadormeceres": "desadormecer",
    "desadormeceria": "desadormecer",
    "desadormeceriam": "desadormecer",
    "desadormecerias": "desadormecer",
    "desadormecermo": "desadormecer",
    "desadormecermos": "desadormecer",
    "desadormecerá": "desadormecer",
    "desadormecerás": "desadormecer",
    "desadormecerão": "desadormecer",
    "desadormeceríamos": "desadormecer",
    "desadormeceríeis": "desadormecer",
    "desadormeces": "desadormecer",
    "desadormecesse": "desadormecer",
    "desadormecessem": "desadormecer",
    "desadormecesses": "desadormecer",
    "desadormeceste": "desadormecer",
    "desadormecestes": "desadormecer",
    "desadormeceu": "desadormecer",
    "desadormeci": "desadormecer",
    "desadormecia": "desadormecer",
    "desadormeciam": "desadormecer",
    "desadormecias": "desadormecer",
    "desadormecida": "desadormecer",
    "desadormecidas": "desadormecer",
    "desadormecido": "desadormecer",
    "desadormecidos": "desadormecer",
    "desadormecê": "desadormecer",
    "desadormecêramo": "desadormecer",
    "desadormecêramos": "desadormecer",
    "desadormecêrei": "desadormecer",
    "desadormecêreis": "desadormecer",
    "desadormecêsseis": "desadormecer",
    "desadormecêssemos": "desadormecer",
    "desadormecíamo": "desadormecer",
    "desadormecíamos": "desadormecer",
    "desadormecíei": "desadormecer",
    "desadormecíeis": "desadormecer",
    "desadormenta": "desadormentar",
    "desadormentada": "desadormentar",
    "desadormentadas": "desadormentar",
    "desadormentado": "desadormentar",
    "desadormentados": "desadormentar",
    "desadormentai": "desadormentar",
    "desadormentais": "desadormentar",
    "desadormentam": "desadormentar",
    "desadormentamo": "desadormentar",
    "desadormentamos": "desadormentar",
    "desadormentando": "desadormentar",
    "desadormentara": "desadormentar",
    "desadormentaram": "desadormentar",
    "desadormentaras": "desadormentar",
    "desadormentarde": "desadormentar",
    "desadormentardes": "desadormentar",
    "desadormentare": "desadormentar",
    "desadormentarei": "desadormentar",
    "desadormentareis": "desadormentar",
    "desadormentarem": "desadormentar",
    "desadormentaremos": "desadormentar",
    "desadormentares": "desadormentar",
    "desadormentaria": "desadormentar",
    "desadormentariam": "desadormentar",
    "desadormentarias": "desadormentar",
    "desadormentarmo": "desadormentar",
    "desadormentarmos": "desadormentar",
    "desadormentará": "desadormentar",
    "desadormentarás": "desadormentar",
    "desadormentarão": "desadormentar",
    "desadormentaríamos": "desadormentar",
    "desadormentaríeis": "desadormentar",
    "desadormentas": "desadormentar",
    "desadormentasse": "desadormentar",
    "desadormentassem": "desadormentar",
    "desadormentasses": "desadormentar",
    "desadormentaste": "desadormentar",
    "desadormentastes": "desadormentar",
    "desadormentava": "desadormentar",
    "desadormentavam": "desadormentar",
    "desadormentavas": "desadormentar",
    "desadormente": "desadormentar",
    "desadormentei": "desadormentar",
    "desadormenteis": "desadormentar",
    "desadormentem": "desadormentar",
    "desadormentemo": "desadormentar",
    "desadormentemos": "desadormentar",
    "desadormentes": "desadormentar",
    "desadormento": "desadormentar",
    "desadormentou": "desadormentar",
    "desadormentá": "desadormentar",
    "desadormentámo": "desadormentar",
    "desadormentámos": "desadormentar",
    "desadormentáramo": "desadormentar",
    "desadormentáramos": "desadormentar",
    "desadormentárei": "desadormentar",
    "desadormentáreis": "desadormentar",
    "desadormentásseis": "desadormentar",
    "desadormentássemos": "desadormentar",
    "desadormentávamo": "desadormentar",
    "desadormentávamos": "desadormentar",
    "desadormentávei": "desadormentar",
    "desadormentáveis": "desadormentar",
    "desadormeça": "desadormecer",
    "desadormeçais": "desadormecer",
    "desadormeçam": "desadormecer",
    "desadormeçamo": "desadormecer",
    "desadormeçamos": "desadormecer",
    "desadormeças": "desadormecer",
    "desadormeço": "desadormecer",
    "desadorna": "desadornar",
    "desadornada": "desadornar",
    "desadornadas": "desadornar",
    "desadornado": "desadornar",
    "desadornados": "desadornar",
    "desadornai": "desadornar",
    "desadornais": "desadornar",
    "desadornam": "desadornar",
    "desadornamo": "desadornar",
    "desadornamos": "desadornar",
    "desadornando": "desadornar",
    "desadornara": "desadornar",
    "desadornaram": "desadornar",
    "desadornaras": "desadornar",
    "desadornarde": "desadornar",
    "desadornardes": "desadornar",
    "desadornare": "desadornar",
    "desadornarei": "desadornar",
    "desadornareis": "desadornar",
    "desadornarem": "desadornar",
    "desadornaremos": "desadornar",
    "desadornares": "desadornar",
    "desadornaria": "desadornar",
    "desadornariam": "desadornar",
    "desadornarias": "desadornar",
    "desadornarmo": "desadornar",
    "desadornarmos": "desadornar",
    "desadornará": "desadornar",
    "desadornarás": "desadornar",
    "desadornarão": "desadornar",
    "desadornaríamos": "desadornar",
    "desadornaríeis": "desadornar",
    "desadornas": "desadornar",
    "desadornasse": "desadornar",
    "desadornassem": "desadornar",
    "desadornasses": "desadornar",
    "desadornaste": "desadornar",
    "desadornastes": "desadornar",
    "desadornava": "desadornar",
    "desadornavam": "desadornar",
    "desadornavas": "desadornar",
    "desadorne": "desadornar",
    "desadornei": "desadornar",
    "desadorneis": "desadornar",
    "desadornem": "desadornar",
    "desadornemo": "desadornar",
    "desadornemos": "desadornar",
    "desadornes": "desadornar",
    "desadorno": "desadornar",
    "desadornos": "desadorno",
    "desadornou": "desadornar",
    "desadorná": "desadornar",
    "desadornámo": "desadornar",
    "desadornámos": "desadornar",
    "desadornáramo": "desadornar",
    "desadornáramos": "desadornar",
    "desadornárei": "desadornar",
    "desadornáreis": "desadornar",
    "desadornásseis": "desadornar",
    "desadornássemos": "desadornar",
    "desadornávamo": "desadornar",
    "desadornávamos": "desadornar",
    "desadornávei": "desadornar",
    "desadornáveis": "desadornar",
    "desadoro": "desadorar",
    "desadorou": "desadorar",
    "desadorá": "desadorar",
    "desadorámo": "desadorar",
    "desadorámos": "desadorar",
    "desadoráramo": "desadorar",
    "desadoráramos": "desadorar",
    "desadorárei": "desadorar",
    "desadoráreis": "desadorar",
    "desadorásseis": "desadorar",
    "desadorássemos": "desadorar",
    "desadorávamo": "desadorar",
    "desadorávamos": "desadorar",
    "desadorávei": "desadorar",
    "desadoráveis": "desadorar",
    "desaduna": "desadunar",
    "desadunada": "desadunar",
    "desadunadas": "desadunar",
    "desadunado": "desadunar",
    "desadunados": "desadunar",
    "desadunai": "desadunar",
    "desadunais": "desadunar",
    "desadunam": "desadunar",
    "desadunamo": "desadunar",
    "desadunamos": "desadunar",
    "desadunando": "desadunar",
    "desadunara": "desadunar",
    "desadunaram": "desadunar",
    "desadunaras": "desadunar",
    "desadunarde": "desadunar",
    "desadunardes": "desadunar",
    "desadunare": "desadunar",
    "desadunarei": "desadunar",
    "desadunareis": "desadunar",
    "desadunarem": "desadunar",
    "desadunaremos": "desadunar",
    "desadunares": "desadunar",
    "desadunaria": "desadunar",
    "desadunariam": "desadunar",
    "desadunarias": "desadunar",
    "desadunarmo": "desadunar",
    "desadunarmos": "desadunar",
    "desadunará": "desadunar",
    "desadunarás": "desadunar",
    "desadunarão": "desadunar",
    "desadunaríamos": "desadunar",
    "desadunaríeis": "desadunar",
    "desadunas": "desadunar",
    "desadunasse": "desadunar",
    "desadunassem": "desadunar",
    "desadunasses": "desadunar",
    "desadunaste": "desadunar",
    "desadunastes": "desadunar",
    "desadunava": "desadunar",
    "desadunavam": "desadunar",
    "desadunavas": "desadunar",
    "desadune": "desadunar",
    "desadunei": "desadunar",
    "desaduneis": "desadunar",
    "desadunem": "desadunar",
    "desadunemo": "desadunar",
    "desadunemos": "desadunar",
    "desadunes": "desadunar",
    "desaduno": "desadunar",
    "desadunou": "desadunar",
    "desaduná": "desadunar",
    "desadunámo": "desadunar",
    "desadunámos": "desadunar",
    "desadunáramo": "desadunar",
    "desadunáramos": "desadunar",
    "desadunárei": "desadunar",
    "desadunáreis": "desadunar",
    "desadunásseis": "desadunar",
    "desadunássemos": "desadunar",
    "desadunávamo": "desadunar",
    "desadunávamos": "desadunar",
    "desadunávei": "desadunar",
    "desadunáveis": "desadunar",
    "desadvertida": "desadvertido",
    "desadvertidas": "desadvertido",
    "desadvertidos": "desadvertido",
    "desafabilidades": "desafabilidade",
    "desafaima": "desafaimar",
    "desafaimada": "desafaimar",
    "desafaimadas": "desafaimar",
    "desafaimado": "desafaimar",
    "desafaimados": "desafaimar",
    "desafaimai": "desafaimar",
    "desafaimais": "desafaimar",
    "desafaimam": "desafaimar",
    "desafaimamo": "desafaimar",
    "desafaimamos": "desafaimar",
    "desafaimando": "desafaimar",
    "desafaimara": "desafaimar",
    "desafaimaram": "desafaimar",
    "desafaimaras": "desafaimar",
    "desafaimarde": "desafaimar",
    "desafaimardes": "desafaimar",
    "desafaimare": "desafaimar",
    "desafaimarei": "desafaimar",
    "desafaimareis": "desafaimar",
    "desafaimarem": "desafaimar",
    "desafaimaremos": "desafaimar",
    "desafaimares": "desafaimar",
    "desafaimaria": "desafaimar",
    "desafaimariam": "desafaimar",
    "desafaimarias": "desafaimar",
    "desafaimarmo": "desafaimar",
    "desafaimarmos": "desafaimar",
    "desafaimará": "desafaimar",
    "desafaimarás": "desafaimar",
    "desafaimarão": "desafaimar",
    "desafaimaríamos": "desafaimar",
    "desafaimaríeis": "desafaimar",
    "desafaimas": "desafaimar",
    "desafaimasse": "desafaimar",
    "desafaimassem": "desafaimar",
    "desafaimasses": "desafaimar",
    "desafaimaste": "desafaimar",
    "desafaimastes": "desafaimar",
    "desafaimava": "desafaimar",
    "desafaimavam": "desafaimar",
    "desafaimavas": "desafaimar",
    "desafaime": "desafaimar",
    "desafaimei": "desafaimar",
    "desafaimeis": "desafaimar",
    "desafaimem": "desafaimar",
    "desafaimemo": "desafaimar",
    "desafaimemos": "desafaimar",
    "desafaimes": "desafaimar",
    "desafaimo": "desafaimar",
    "desafaimou": "desafaimar",
    "desafaimá": "desafaimar",
    "desafaimámo": "desafaimar",
    "desafaimámos": "desafaimar",
    "desafaimáramo": "desafaimar",
    "desafaimáramos": "desafaimar",
    "desafaimárei": "desafaimar",
    "desafaimáreis": "desafaimar",
    "desafaimásseis": "desafaimar",
    "desafaimássemos": "desafaimar",
    "desafaimávamo": "desafaimar",
    "desafaimávamos": "desafaimar",
    "desafaimávei": "desafaimar",
    "desafaimáveis": "desafaimar",
    "desafama": "desafamar",
    "desafamada": "desafamar",
    "desafamadas": "desafamar",
    "desafamado": "desafamar",
    "desafamados": "desafamar",
    "desafamai": "desafamar",
    "desafamais": "desafamar",
    "desafamam": "desafamar",
    "desafamamo": "desafamar",
    "desafamamos": "desafamar",
    "desafamando": "desafamar",
    "desafamara": "desafamar",
    "desafamaram": "desafamar",
    "desafamaras": "desafamar",
    "desafamarde": "desafamar",
    "desafamardes": "desafamar",
    "desafamare": "desafamar",
    "desafamarei": "desafamar",
    "desafamareis": "desafamar",
    "desafamarem": "desafamar",
    "desafamaremos": "desafamar",
    "desafamares": "desafamar",
    "desafamaria": "desafamar",
    "desafamariam": "desafamar",
    "desafamarias": "desafamar",
    "desafamarmo": "desafamar",
    "desafamarmos": "desafamar",
    "desafamará": "desafamar",
    "desafamarás": "desafamar",
    "desafamarão": "desafamar",
    "desafamaríamos": "desafamar",
    "desafamaríeis": "desafamar",
    "desafamas": "desafamar",
    "desafamasse": "desafamar",
    "desafamassem": "desafamar",
    "desafamasses": "desafamar",
    "desafamaste": "desafamar",
    "desafamastes": "desafamar",
    "desafamava": "desafamar",
    "desafamavam": "desafamar",
    "desafamavas": "desafamar",
    "desafame": "desafamar",
    "desafamei": "desafamar",
    "desafameis": "desafamar",
    "desafamem": "desafamar",
    "desafamemo": "desafamar",
    "desafamemos": "desafamar",
    "desafames": "desafamar",
    "desafamo": "desafamar",
    "desafamou": "desafamar",
    "desafamá": "desafamar",
    "desafamámo": "desafamar",
    "desafamámos": "desafamar",
    "desafamáramo": "desafamar",
    "desafamáramos": "desafamar",
    "desafamárei": "desafamar",
    "desafamáreis": "desafamar",
    "desafamásseis": "desafamar",
    "desafamássemos": "desafamar",
    "desafamávamo": "desafamar",
    "desafamávamos": "desafamar",
    "desafamávei": "desafamar",
    "desafamáveis": "desafamar",
    "desafea": "desafear",
    "desafeada": "desafear",
    "desafeadas": "desafear",
    "desafeado": "desafear",
    "desafeados": "desafear",
    "desafeai": "desafear",
    "desafeais": "desafear",
    "desafeam": "desafear",
    "desafeamo": "desafear",
    "desafeamos": "desafear",
    "desafeando": "desafear",
    "desafeara": "desafear",
    "desafearam": "desafear",
    "desafearas": "desafear",
    "desafearde": "desafear",
    "desafeardes": "desafear",
    "desafeare": "desafear",
    "desafearei": "desafear",
    "desafeareis": "desafear",
    "desafearem": "desafear",
    "desafearemos": "desafear",
    "desafeares": "desafear",
    "desafearia": "desafear",
    "desafeariam": "desafear",
    "desafearias": "desafear",
    "desafearmo": "desafear",
    "desafearmos": "desafear",
    "desafeará": "desafear",
    "desafearás": "desafear",
    "desafearão": "desafear",
    "desafearíamos": "desafear",
    "desafearíeis": "desafear",
    "desafeas": "desafear",
    "desafeasse": "desafear",
    "desafeassem": "desafear",
    "desafeasses": "desafear",
    "desafeaste": "desafear",
    "desafeastes": "desafear",
    "desafeava": "desafear",
    "desafeavam": "desafear",
    "desafeavas": "desafear",
    "desafecta": "desafecto",
    "desafectada": "desafectar",
    "desafectadas": "desafectar",
    "desafectado": "desafectar",
    "desafectados": "desafectar",
    "desafectai": "desafectar",
    "desafectais": "desafectar",
    "desafectam": "desafectar",
    "desafectamo": "desafectar",
    "desafectamos": "desafectar",
    "desafectando": "desafectar",
    "desafectara": "desafectar",
    "desafectaram": "desafectar",
    "desafectaras": "desafectar",
    "desafectarde": "desafectar",
    "desafectardes": "desafectar",
    "desafectare": "desafectar",
    "desafectarei": "desafectar",
    "desafectareis": "desafectar",
    "desafectarem": "desafectar",
    "desafectaremos": "desafectar",
    "desafectares": "desafectar",
    "desafectaria": "desafectar",
    "desafectariam": "desafectar",
    "desafectarias": "desafectar",
    "desafectarmo": "desafectar",
    "desafectarmos": "desafectar",
    "desafectará": "desafectar",
    "desafectarás": "desafectar",
    "desafectarão": "desafectar",
    "desafectaríamos": "desafectar",
    "desafectaríeis": "desafectar",
    "desafectas": "desafecto",
    "desafectasse": "desafectar",
    "desafectassem": "desafectar",
    "desafectasses": "desafectar",
    "desafectaste": "desafectar",
    "desafectastes": "desafectar",
    "desafectava": "desafectar",
    "desafectavam": "desafectar",
    "desafectavas": "desafectar",
    "desafectações": "desafectação",
    "desafecte": "desafectar",
    "desafectei": "desafectar",
    "desafecteis": "desafectar",
    "desafectem": "desafectar",
    "desafectemo": "desafectar",
    "desafectemos": "desafectar",
    "desafectes": "desafectar",
    "desafecto": "desafectar",
    "desafectos": "desafecto",
    "desafectou": "desafectar",
    "desafectá": "desafectar",
    "desafectámo": "desafectar",
    "desafectámos": "desafectar",
    "desafectáramo": "desafectar",
    "desafectáramos": "desafectar",
    "desafectárei": "desafectar",
    "desafectáreis": "desafectar",
    "desafectásseis": "desafectar",
    "desafectássemos": "desafectar",
    "desafectávamo": "desafectar",
    "desafectávamos": "desafectar",
    "desafectávei": "desafectar",
    "desafectáveis": "desafectar",
    "desafee": "desafear",
    "desafeei": "desafear",
    "desafeeis": "desafear",
    "desafeem": "desafear",
    "desafeemo": "desafear",
    "desafeemos": "desafear",
    "desafees": "desafear",
    "desafeita": "desafeito",
    "desafeitada": "desafeitar",
    "desafeitadas": "desafeitar",
    "desafeitado": "desafeitar",
    "desafeitados": "desafeitar",
    "desafeitai": "desafeitar",
    "desafeitais": "desafeitar",
    "desafeitam": "desafeitar",
    "desafeitamo": "desafeitar",
    "desafeitamos": "desafeitar",
    "desafeitando": "desafeitar",
    "desafeitara": "desafeitar",
    "desafeitaram": "desafeitar",
    "desafeitaras": "desafeitar",
    "desafeitarde": "desafeitar",
    "desafeitardes": "desafeitar",
    "desafeitare": "desafeitar",
    "desafeitarei": "desafeitar",
    "desafeitareis": "desafeitar",
    "desafeitarem": "desafeitar",
    "desafeitaremos": "desafeitar",
    "desafeitares": "desafeitar",
    "desafeitaria": "desafeitar",
    "desafeitariam": "desafeitar",
    "desafeitarias": "desafeitar",
    "desafeitarmo": "desafeitar",
    "desafeitarmos": "desafeitar",
    "desafeitará": "desafeitar",
    "desafeitarás": "desafeitar",
    "desafeitarão": "desafeitar",
    "desafeitaríamos": "desafeitar",
    "desafeitaríeis": "desafeitar",
    "desafeitas": "desafeito",
    "desafeitasse": "desafeitar",
    "desafeitassem": "desafeitar",
    "desafeitasses": "desafeitar",
    "desafeitaste": "desafeitar",
    "desafeitastes": "desafeitar",
    "desafeitava": "desafeitar",
    "desafeitavam": "desafeitar",
    "desafeitavas": "desafeitar",
    "desafeite": "desafeitar",
    "desafeitei": "desafeitar",
    "desafeiteis": "desafeitar",
    "desafeitem": "desafeitar",
    "desafeitemo": "desafeitar",
    "desafeitemos": "desafeitar",
    "desafeites": "desafeitar",
    "desafeito": "desafeitar",
    "desafeitos": "desafeito",
    "desafeitou": "desafeitar",
    "desafeitá": "desafeitar",
    "desafeitámo": "desafeitar",
    "desafeitámos": "desafeitar",
    "desafeitáramo": "desafeitar",
    "desafeitáramos": "desafeitar",
    "desafeitárei": "desafeitar",
    "desafeitáreis": "desafeitar",
    "desafeitásseis": "desafeitar",
    "desafeitássemos": "desafeitar",
    "desafeitávamo": "desafeitar",
    "desafeitávamos": "desafeitar",
    "desafeitávei": "desafeitar",
    "desafeitáveis": "desafeitar",
    "desafeiçoa": "desafeiçoar",
    "desafeiçoada": "desafeiçoar",
    "desafeiçoadas": "desafeiçoar",
    "desafeiçoado": "desafeiçoar",
    "desafeiçoados": "desafeiçoar",
    "desafeiçoai": "desafeiçoar",
    "desafeiçoais": "desafeiçoar",
    "desafeiçoam": "desafeiçoar",
    "desafeiçoamentos": "desafeiçoamento",
    "desafeiçoamo": "desafeiçoar",
    "desafeiçoamos": "desafeiçoar",
    "desafeiçoando": "desafeiçoar",
    "desafeiçoara": "desafeiçoar",
    "desafeiçoaram": "desafeiçoar",
    "desafeiçoaras": "desafeiçoar",
    "desafeiçoarde": "desafeiçoar",
    "desafeiçoardes": "desafeiçoar",
    "desafeiçoare": "desafeiçoar",
    "desafeiçoarei": "desafeiçoar",
    "desafeiçoareis": "desafeiçoar",
    "desafeiçoarem": "desafeiçoar",
    "desafeiçoaremos": "desafeiçoar",
    "desafeiçoares": "desafeiçoar",
    "desafeiçoaria": "desafeiçoar",
    "desafeiçoariam": "desafeiçoar",
    "desafeiçoarias": "desafeiçoar",
    "desafeiçoarmo": "desafeiçoar",
    "desafeiçoarmos": "desafeiçoar",
    "desafeiçoará": "desafeiçoar",
    "desafeiçoarás": "desafeiçoar",
    "desafeiçoarão": "desafeiçoar",
    "desafeiçoaríamos": "desafeiçoar",
    "desafeiçoaríeis": "desafeiçoar",
    "desafeiçoas": "desafeiçoar",
    "desafeiçoasse": "desafeiçoar",
    "desafeiçoassem": "desafeiçoar",
    "desafeiçoasses": "desafeiçoar",
    "desafeiçoaste": "desafeiçoar",
    "desafeiçoastes": "desafeiçoar",
    "desafeiçoava": "desafeiçoar",
    "desafeiçoavam": "desafeiçoar",
    "desafeiçoavas": "desafeiçoar",
    "desafeiçoe": "desafeiçoar",
    "desafeiçoei": "desafeiçoar",
    "desafeiçoeis": "desafeiçoar",
    "desafeiçoem": "desafeiçoar",
    "desafeiçoemo": "desafeiçoar",
    "desafeiçoemos": "desafeiçoar",
    "desafeiçoes": "desafeiçoar",
    "desafeiçoo": "desafeiçoar",
    "desafeiçoou": "desafeiçoar",
    "desafeiçoá": "desafeiçoar",
    "desafeiçoámo": "desafeiçoar",
    "desafeiçoámos": "desafeiçoar",
    "desafeiçoáramo": "desafeiçoar",
    "desafeiçoáramos": "desafeiçoar",
    "desafeiçoárei": "desafeiçoar",
    "desafeiçoáreis": "desafeiçoar",
    "desafeiçoásseis": "desafeiçoar",
    "desafeiçoássemos": "desafeiçoar",
    "desafeiçoávamo": "desafeiçoar",
    "desafeiçoávamos": "desafeiçoar",
    "desafeiçoávei": "desafeiçoar",
    "desafeiçoáveis": "desafeiçoar",
    "desafeições": "desafeição",
    "desafeo": "desafear",
    "desafeou": "desafear",
    "desaferra": "desaferrar",
    "desaferrada": "desaferrar",
    "desaferradas": "desaferrar",
    "desaferrado": "desaferrar",
    "desaferrados": "desaferrar",
    "desaferrai": "desaferrar",
    "desaferrais": "desaferrar",
    "desaferram": "desaferrar",
    "desaferramo": "desaferrar",
    "desaferramos": "desaferrar",
    "desaferrando": "desaferrar",
    "desaferrara": "desaferrar",
    "desaferraram": "desaferrar",
    "desaferraras": "desaferrar",
    "desaferrarde": "desaferrar",
    "desaferrardes": "desaferrar",
    "desaferrare": "desaferrar",
    "desaferrarei": "desaferrar",
    "desaferrareis": "desaferrar",
    "desaferrarem": "desaferrar",
    "desaferraremos": "desaferrar",
    "desaferrares": "desaferrar",
    "desaferraria": "desaferrar",
    "desaferrariam": "desaferrar",
    "desaferrarias": "desaferrar",
    "desaferrarmo": "desaferrar",
    "desaferrarmos": "desaferrar",
    "desaferrará": "desaferrar",
    "desaferrarás": "desaferrar",
    "desaferrarão": "desaferrar",
    "desaferraríamos": "desaferrar",
    "desaferraríeis": "desaferrar",
    "desaferras": "desaferrar",
    "desaferrasse": "desaferrar",
    "desaferrassem": "desaferrar",
    "desaferrasses": "desaferrar",
    "desaferraste": "desaferrar",
    "desaferrastes": "desaferrar",
    "desaferrava": "desaferrar",
    "desaferravam": "desaferrar",
    "desaferravas": "desaferrar",
    "desaferre": "desaferrar",
    "desaferrei": "desaferrar",
    "desaferreis": "desaferrar",
    "desaferrem": "desaferrar",
    "desaferremo": "desaferrar",
    "desaferremos": "desaferrar",
    "desaferres": "desaferrar",
    "desaferro": "desaferrar",
    "desaferroa": "desaferroar",
    "desaferroada": "desaferroar",
    "desaferroadas": "desaferroar",
    "desaferroado": "desaferroar",
    "desaferroados": "desaferroar",
    "desaferroai": "desaferroar",
    "desaferroais": "desaferroar",
    "desaferroam": "desaferroar",
    "desaferroamo": "desaferroar",
    "desaferroamos": "desaferroar",
    "desaferroando": "desaferroar",
    "desaferroara": "desaferroar",
    "desaferroaram": "desaferroar",
    "desaferroaras": "desaferroar",
    "desaferroarde": "desaferroar",
    "desaferroardes": "desaferroar",
    "desaferroare": "desaferroar",
    "desaferroarei": "desaferroar",
    "desaferroareis": "desaferroar",
    "desaferroarem": "desaferroar",
    "desaferroaremos": "desaferroar",
    "desaferroares": "desaferroar",
    "desaferroaria": "desaferroar",
    "desaferroariam": "desaferroar",
    "desaferroarias": "desaferroar",
    "desaferroarmo": "desaferroar",
    "desaferroarmos": "desaferroar",
    "desaferroará": "desaferroar",
    "desaferroarás": "desaferroar",
    "desaferroarão": "desaferroar",
    "desaferroaríamos": "desaferroar",
    "desaferroaríeis": "desaferroar",
    "desaferroas": "desaferroar",
    "desaferroasse": "desaferroar",
    "desaferroassem": "desaferroar",
    "desaferroasses": "desaferroar",
    "desaferroaste": "desaferroar",
    "desaferroastes": "desaferroar",
    "desaferroava": "desaferroar",
    "desaferroavam": "desaferroar",
    "desaferroavas": "desaferroar",
    "desaferroe": "desaferroar",
    "desaferroei": "desaferroar",
    "desaferroeis": "desaferroar",
    "desaferroem": "desaferroar",
    "desaferroemo": "desaferroar",
    "desaferroemos": "desaferroar",
    "desaferroes": "desaferroar",
    "desaferrolha": "desaferrolhar",
    "desaferrolhada": "desaferrolhar",
    "desaferrolhadas": "desaferrolhar",
    "desaferrolhado": "desaferrolhar",
    "desaferrolhados": "desaferrolhar",
    "desaferrolhai": "desaferrolhar",
    "desaferrolhais": "desaferrolhar",
    "desaferrolham": "desaferrolhar",
    "desaferrolhamo": "desaferrolhar",
    "desaferrolhamos": "desaferrolhar",
    "desaferrolhando": "desaferrolhar",
    "desaferrolhara": "desaferrolhar",
    "desaferrolharam": "desaferrolhar",
    "desaferrolharas": "desaferrolhar",
    "desaferrolharde": "desaferrolhar",
    "desaferrolhardes": "desaferrolhar",
    "desaferrolhare": "desaferrolhar",
    "desaferrolharei": "desaferrolhar",
    "desaferrolhareis": "desaferrolhar",
    "desaferrolharem": "desaferrolhar",
    "desaferrolharemos": "desaferrolhar",
    "desaferrolhares": "desaferrolhar",
    "desaferrolharia": "desaferrolhar",
    "desaferrolhariam": "desaferrolhar",
    "desaferrolharias": "desaferrolhar",
    "desaferrolharmo": "desaferrolhar",
    "desaferrolharmos": "desaferrolhar",
    "desaferrolhará": "desaferrolhar",
    "desaferrolharás": "desaferrolhar",
    "desaferrolharão": "desaferrolhar",
    "desaferrolharíamos": "desaferrolhar",
    "desaferrolharíeis": "desaferrolhar",
    "desaferrolhas": "desaferrolhar",
    "desaferrolhasse": "desaferrolhar",
    "desaferrolhassem": "desaferrolhar",
    "desaferrolhasses": "desaferrolhar",
    "desaferrolhaste": "desaferrolhar",
    "desaferrolhastes": "desaferrolhar",
    "desaferrolhava": "desaferrolhar",
    "desaferrolhavam": "desaferrolhar",
    "desaferrolhavas": "desaferrolhar",
    "desaferrolhe": "desaferrolhar",
    "desaferrolhei": "desaferrolhar",
    "desaferrolheis": "desaferrolhar",
    "desaferrolhem": "desaferrolhar",
    "desaferrolhemo": "desaferrolhar",
    "desaferrolhemos": "desaferrolhar",
    "desaferrolhes": "desaferrolhar",
    "desaferrolho": "desaferrolhar",
    "desaferrolhou": "desaferrolhar",
    "desaferrolhá": "desaferrolhar",
    "desaferrolhámo": "desaferrolhar",
    "desaferrolhámos": "desaferrolhar",
    "desaferrolháramo": "desaferrolhar",
    "desaferrolháramos": "desaferrolhar",
    "desaferrolhárei": "desaferrolhar",
    "desaferrolháreis": "desaferrolhar",
    "desaferrolhásseis": "desaferrolhar",
    "desaferrolhássemos": "desaferrolhar",
    "desaferrolhávamo": "desaferrolhar",
    "desaferrolhávamos": "desaferrolhar",
    "desaferrolhávei": "desaferrolhar",
    "desaferrolháveis": "desaferrolhar",
    "desaferroo": "desaferroar",
    "desaferroou": "desaferroar",
    "desaferros": "desaferro",
    "desaferrou": "desaferrar",
    "desaferroá": "desaferroar",
    "desaferroámo": "desaferroar",
    "desaferroámos": "desaferroar",
    "desaferroáramo": "desaferroar",
    "desaferroáramos": "desaferroar",
    "desaferroárei": "desaferroar",
    "desaferroáreis": "desaferroar",
    "desaferroásseis": "desaferroar",
    "desaferroássemos": "desaferroar",
    "desaferroávamo": "desaferroar",
    "desaferroávamos": "desaferroar",
    "desaferroávei": "desaferroar",
    "desaferroáveis": "desaferroar",
    "desaferrá": "desaferrar",
    "desaferrámo": "desaferrar",
    "desaferrámos": "desaferrar",
    "desaferráramo": "desaferrar",
    "desaferráramos": "desaferrar",
    "desaferrárei": "desaferrar",
    "desaferráreis": "desaferrar",
    "desaferrásseis": "desaferrar",
    "desaferrássemos": "desaferrar",
    "desaferrávamo": "desaferrar",
    "desaferrávamos": "desaferrar",
    "desaferrávei": "desaferrar",
    "desaferráveis": "desaferrar",
    "desafervora": "desafervorar",
    "desafervorada": "desafervorar",
    "desafervoradas": "desafervorar",
    "desafervorado": "desafervorar",
    "desafervorados": "desafervorar",
    "desafervorai": "desafervorar",
    "desafervorais": "desafervorar",
    "desafervoram": "desafervorar",
    "desafervoramo": "desafervorar",
    "desafervoramos": "desafervorar",
    "desafervorando": "desafervorar",
    "desafervorara": "desafervorar",
    "desafervoraram": "desafervorar",
    "desafervoraras": "desafervorar",
    "desafervorarde": "desafervorar",
    "desafervorardes": "desafervorar",
    "desafervorare": "desafervorar",
    "desafervorarei": "desafervorar",
    "desafervorareis": "desafervorar",
    "desafervorarem": "desafervorar",
    "desafervoraremos": "desafervorar",
    "desafervorares": "desafervorar",
    "desafervoraria": "desafervorar",
    "desafervorariam": "desafervorar",
    "desafervorarias": "desafervorar",
    "desafervorarmo": "desafervorar",
    "desafervorarmos": "desafervorar",
    "desafervorará": "desafervorar",
    "desafervorarás": "desafervorar",
    "desafervorarão": "desafervorar",
    "desafervoraríamos": "desafervorar",
    "desafervoraríeis": "desafervorar",
    "desafervoras": "desafervorar",
    "desafervorasse": "desafervorar",
    "desafervorassem": "desafervorar",
    "desafervorasses": "desafervorar",
    "desafervoraste": "desafervorar",
    "desafervorastes": "desafervorar",
    "desafervorava": "desafervorar",
    "desafervoravam": "desafervorar",
    "desafervoravas": "desafervorar",
    "desafervore": "desafervorar",
    "desafervorei": "desafervorar",
    "desafervoreis": "desafervorar",
    "desafervorem": "desafervorar",
    "desafervoremo": "desafervorar",
    "desafervoremos": "desafervorar",
    "desafervores": "desafervorar",
    "desafervoro": "desafervorar",
    "desafervorou": "desafervorar",
    "desafervorá": "desafervorar",
    "desafervorámo": "desafervorar",
    "desafervorámos": "desafervorar",
    "desafervoráramo": "desafervorar",
    "desafervoráramos": "desafervorar",
    "desafervorárei": "desafervorar",
    "desafervoráreis": "desafervorar",
    "desafervorásseis": "desafervorar",
    "desafervorássemos": "desafervorar",
    "desafervorávamo": "desafervorar",
    "desafervorávamos": "desafervorar",
    "desafervorávei": "desafervorar",
    "desafervoráveis": "desafervorar",
    "desafeá": "desafear",
    "desafeámo": "desafear",
    "desafeámos": "desafear",
    "desafeáramo": "desafear",
    "desafeáramos": "desafear",
    "desafeárei": "desafear",
    "desafeáreis": "desafear",
    "desafeásseis": "desafear",
    "desafeássemos": "desafear",
    "desafeávamo": "desafear",
    "desafeávamos": "desafear",
    "desafeávei": "desafear",
    "desafeáveis": "desafear",
    "desafia": "desafiar",
    "desafiada": "desafiar",
    "desafiadas": "desafiar",
    "desafiado": "desafiar",
    "desafiadora": "desafiador",
    "desafiadoras": "desafiador",
    "desafiadores": "desafiador",
    "desafiados": "desafiar",
    "desafiai": "desafiar",
    "desafiais": "desafiar",
    "desafiam": "desafiar",
    "desafiamo": "desafiar",
    "desafiamos": "desafiar",
    "desafiando": "desafiar",
    "desafiantes": "desafiante",
    "desafiara": "desafiar",
    "desafiaram": "desafiar",
    "desafiaras": "desafiar",
    "desafiarde": "desafiar",
    "desafiardes": "desafiar",
    "desafiare": "desafiar",
    "desafiarei": "desafiar",
    "desafiareis": "desafiar",
    "desafiarem": "desafiar",
    "desafiaremos": "desafiar",
    "desafiares": "desafiar",
    "desafiaria": "desafiar",
    "desafiariam": "desafiar",
    "desafiarias": "desafiar",
    "desafiarmo": "desafiar",
    "desafiarmos": "desafiar",
    "desafiará": "desafiar",
    "desafiarás": "desafiar",
    "desafiarão": "desafiar",
    "desafiaríamos": "desafiar",
    "desafiaríeis": "desafiar",
    "desafias": "desafiar",
    "desafiasse": "desafiar",
    "desafiassem": "desafiar",
    "desafiasses": "desafiar",
    "desafiaste": "desafiar",
    "desafiastes": "desafiar",
    "desafiava": "desafiar",
    "desafiavam": "desafiar",
    "desafiavas": "desafiar",
    "desafie": "desafiar",
    "desafiei": "desafiar",
    "desafieis": "desafiar",
    "desafiem": "desafiar",
    "desafiemo": "desafiar",
    "desafiemos": "desafiar",
    "desafies": "desafiar",
    "desafilha": "desafilhar",
    "desafilhada": "desafilhar",
    "desafilhadas": "desafilhar",
    "desafilhado": "desafilhar",
    "desafilhados": "desafilhar",
    "desafilhai": "desafilhar",
    "desafilhais": "desafilhar",
    "desafilham": "desafilhar",
    "desafilhamo": "desafilhar",
    "desafilhamos": "desafilhar",
    "desafilhando": "desafilhar",
    "desafilhara": "desafilhar",
    "desafilharam": "desafilhar",
    "desafilharas": "desafilhar",
    "desafilharde": "desafilhar",
    "desafilhardes": "desafilhar",
    "desafilhare": "desafilhar",
    "desafilharei": "desafilhar",
    "desafilhareis": "desafilhar",
    "desafilharem": "desafilhar",
    "desafilharemos": "desafilhar",
    "desafilhares": "desafilhar",
    "desafilharia": "desafilhar",
    "desafilhariam": "desafilhar",
    "desafilharias": "desafilhar",
    "desafilharmo": "desafilhar",
    "desafilharmos": "desafilhar",
    "desafilhará": "desafilhar",
    "desafilharás": "desafilhar",
    "desafilharão": "desafilhar",
    "desafilharíamos": "desafilhar",
    "desafilharíeis": "desafilhar",
    "desafilhas": "desafilhar",
    "desafilhasse": "desafilhar",
    "desafilhassem": "desafilhar",
    "desafilhasses": "desafilhar",
    "desafilhaste": "desafilhar",
    "desafilhastes": "desafilhar",
    "desafilhava": "desafilhar",
    "desafilhavam": "desafilhar",
    "desafilhavas": "desafilhar",
    "desafilhe": "desafilhar",
    "desafilhei": "desafilhar",
    "desafilheis": "desafilhar",
    "desafilhem": "desafilhar",
    "desafilhemo": "desafilhar",
    "desafilhemos": "desafilhar",
    "desafilhes": "desafilhar",
    "desafilho": "desafilhar",
    "desafilhou": "desafilhar",
    "desafilhá": "desafilhar",
    "desafilhámo": "desafilhar",
    "desafilhámos": "desafilhar",
    "desafilháramo": "desafilhar",
    "desafilháramos": "desafilhar",
    "desafilhárei": "desafilhar",
    "desafilháreis": "desafilhar",
    "desafilhásseis": "desafilhar",
    "desafilhássemos": "desafilhar",
    "desafilhávamo": "desafilhar",
    "desafilhávamos": "desafilhar",
    "desafilhávei": "desafilhar",
    "desafilháveis": "desafilhar",
    "desafina": "desafinar",
    "desafinada": "desafinar",
    "desafinadas": "desafinar",
    "desafinado": "desafinar",
    "desafinados": "desafinar",
    "desafinadíssima": "desafinado",
    "desafinadíssimas": "desafinado",
    "desafinadíssimo": "desafinado",
    "desafinadíssimos": "desafinado",
    "desafinai": "desafinar",
    "desafinais": "desafinar",
    "desafinam": "desafinar",
    "desafinamentos": "desafinamento",
    "desafinamo": "desafinar",
    "desafinamos": "desafinar",
    "desafinando": "desafinar",
    "desafinara": "desafinar",
    "desafinaram": "desafinar",
    "desafinaras": "desafinar",
    "desafinarde": "desafinar",
    "desafinardes": "desafinar",
    "desafinare": "desafinar",
    "desafinarei": "desafinar",
    "desafinareis": "desafinar",
    "desafinarem": "desafinar",
    "desafinaremos": "desafinar",
    "desafinares": "desafinar",
    "desafinaria": "desafinar",
    "desafinariam": "desafinar",
    "desafinarias": "desafinar",
    "desafinarmo": "desafinar",
    "desafinarmos": "desafinar",
    "desafinará": "desafinar",
    "desafinarás": "desafinar",
    "desafinarão": "desafinar",
    "desafinaríamos": "desafinar",
    "desafinaríeis": "desafinar",
    "desafinas": "desafinar",
    "desafinasse": "desafinar",
    "desafinassem": "desafinar",
    "desafinasses": "desafinar",
    "desafinaste": "desafinar",
    "desafinastes": "desafinar",
    "desafinava": "desafinar",
    "desafinavam": "desafinar",
    "desafinavas": "desafinar",
    "desafinações": "desafinação",
    "desafine": "desafinar",
    "desafinei": "desafinar",
    "desafineis": "desafinar",
    "desafinem": "desafinar",
    "desafinemo": "desafinar",
    "desafinemos": "desafinar",
    "desafines": "desafinar",
    "desafino": "desafinar",
    "desafinou": "desafinar",
    "desafiná": "desafinar",
    "desafinámo": "desafinar",
    "desafinámos": "desafinar",
    "desafináramo": "desafinar",
    "desafináramos": "desafinar",
    "desafinárei": "desafinar",
    "desafináreis": "desafinar",
    "desafinásseis": "desafinar",
    "desafinássemos": "desafinar",
    "desafinávamo": "desafinar",
    "desafinávamos": "desafinar",
    "desafinávei": "desafinar",
    "desafináveis": "desafinar",
    "desafio": "desafiar",
    "desafios": "desafio",
    "desafiou": "desafiar",
    "desafivela": "desafivelar",
    "desafivelada": "desafivelar",
    "desafiveladas": "desafivelar",
    "desafivelado": "desafivelar",
    "desafivelados": "desafivelar",
    "desafivelai": "desafivelar",
    "desafivelais": "desafivelar",
    "desafivelam": "desafivelar",
    "desafivelamo": "desafivelar",
    "desafivelamos": "desafivelar",
    "desafivelando": "desafivelar",
    "desafivelara": "desafivelar",
    "desafivelaram": "desafivelar",
    "desafivelaras": "desafivelar",
    "desafivelarde": "desafivelar",
    "desafivelardes": "desafivelar",
    "desafivelare": "desafivelar",
    "desafivelarei": "desafivelar",
    "desafivelareis": "desafivelar",
    "desafivelarem": "desafivelar",
    "desafivelaremos": "desafivelar",
    "desafivelares": "desafivelar",
    "desafivelaria": "desafivelar",
    "desafivelariam": "desafivelar",
    "desafivelarias": "desafivelar",
    "desafivelarmo": "desafivelar",
    "desafivelarmos": "desafivelar",
    "desafivelará": "desafivelar",
    "desafivelarás": "desafivelar",
    "desafivelarão": "desafivelar",
    "desafivelaríamos": "desafivelar",
    "desafivelaríeis": "desafivelar",
    "desafivelas": "desafivelar",
    "desafivelasse": "desafivelar",
    "desafivelassem": "desafivelar",
    "desafivelasses": "desafivelar",
    "desafivelaste": "desafivelar",
    "desafivelastes": "desafivelar",
    "desafivelava": "desafivelar",
    "desafivelavam": "desafivelar",
    "desafivelavas": "desafivelar",
    "desafivele": "desafivelar",
    "desafivelei": "desafivelar",
    "desafiveleis": "desafivelar",
    "desafivelem": "desafivelar",
    "desafivelemo": "desafivelar",
    "desafivelemos": "desafivelar",
    "desafiveles": "desafivelar",
    "desafivelo": "desafivelar",
    "desafivelou": "desafivelar",
    "desafivelá": "desafivelar",
    "desafivelámo": "desafivelar",
    "desafivelámos": "desafivelar",
    "desafiveláramo": "desafivelar",
    "desafiveláramos": "desafivelar",
    "desafivelárei": "desafivelar",
    "desafiveláreis": "desafivelar",
    "desafivelásseis": "desafivelar",
    "desafivelássemos": "desafivelar",
    "desafivelávamo": "desafivelar",
    "desafivelávamos": "desafivelar",
    "desafivelávei": "desafivelar",
    "desafiveláveis": "desafivelar",
    "desafixa": "desafixar",
    "desafixada": "desafixar",
    "desafixadas": "desafixar",
    "desafixado": "desafixar",
    "desafixados": "desafixar",
    "desafixai": "desafixar",
    "desafixais": "desafixar",
    "desafixam": "desafixar",
    "desafixamo": "desafixar",
    "desafixamos": "desafixar",
    "desafixando": "desafixar",
    "desafixara": "desafixar",
    "desafixaram": "desafixar",
    "desafixaras": "desafixar",
    "desafixarde": "desafixar",
    "desafixardes": "desafixar",
    "desafixare": "desafixar",
    "desafixarei": "desafixar",
    "desafixareis": "desafixar",
    "desafixarem": "desafixar",
    "desafixaremos": "desafixar",
    "desafixares": "desafixar",
    "desafixaria": "desafixar",
    "desafixariam": "desafixar",
    "desafixarias": "desafixar",
    "desafixarmo": "desafixar",
    "desafixarmos": "desafixar",
    "desafixará": "desafixar",
    "desafixarás": "desafixar",
    "desafixarão": "desafixar",
    "desafixaríamos": "desafixar",
    "desafixaríeis": "desafixar",
    "desafixas": "desafixar",
    "desafixasse": "desafixar",
    "desafixassem": "desafixar",
    "desafixasses": "desafixar",
    "desafixaste": "desafixar",
    "desafixastes": "desafixar",
    "desafixava": "desafixar",
    "desafixavam": "desafixar",
    "desafixavas": "desafixar",
    "desafixe": "desafixar",
    "desafixei": "desafixar",
    "desafixeis": "desafixar",
    "desafixem": "desafixar",
    "desafixemo": "desafixar",
    "desafixemos": "desafixar",
    "desafixes": "desafixar",
    "desafixo": "desafixar",
    "desafixou": "desafixar",
    "desafixá": "desafixar",
    "desafixámo": "desafixar",
    "desafixámos": "desafixar",
    "desafixáramo": "desafixar",
    "desafixáramos": "desafixar",
    "desafixárei": "desafixar",
    "desafixáreis": "desafixar",
    "desafixásseis": "desafixar",
    "desafixássemos": "desafixar",
    "desafixávamo": "desafixar",
    "desafixávamos": "desafixar",
    "desafixávei": "desafixar",
    "desafixáveis": "desafixar",
    "desafiá": "desafiar",
    "desafiámo": "desafiar",
    "desafiámos": "desafiar",
    "desafiáramo": "desafiar",
    "desafiáramos": "desafiar",
    "desafiárei": "desafiar",
    "desafiáreis": "desafiar",
    "desafiásseis": "desafiar",
    "desafiássemos": "desafiar",
    "desafiávamo": "desafiar",
    "desafiávamos": "desafiar",
    "desafiávei": "desafiar",
    "desafiáveis": "desafiar",
    "desaflige": "desafligir",
    "desafligem": "desafligir",
    "desafliges": "desafligir",
    "desafligi": "desafligir",
    "desafligia": "desafligir",
    "desafligiam": "desafligir",
    "desafligias": "desafligir",
    "desafligida": "desafligir",
    "desafligidas": "desafligir",
    "desafligido": "desafligir",
    "desafligidos": "desafligir",
    "desafligimo": "desafligir",
    "desafligimos": "desafligir",
    "desafligindo": "desafligir",
    "desafligira": "desafligir",
    "desafligiram": "desafligir",
    "desafligiras": "desafligir",
    "desafligirde": "desafligir",
    "desafligirdes": "desafligir",
    "desafligire": "desafligir",
    "desafligirei": "desafligir",
    "desafligireis": "desafligir",
    "desafligirem": "desafligir",
    "desafligiremos": "desafligir",
    "desafligires": "desafligir",
    "desafligiria": "desafligir",
    "desafligiriam": "desafligir",
    "desafligirias": "desafligir",
    "desafligirmo": "desafligir",
    "desafligirmos": "desafligir",
    "desafligirá": "desafligir",
    "desafligirás": "desafligir",
    "desafligirão": "desafligir",
    "desafligiríamos": "desafligir",
    "desafligiríeis": "desafligir",
    "desafligis": "desafligir",
    "desafligisse": "desafligir",
    "desafligissem": "desafligir",
    "desafligisses": "desafligir",
    "desafligiste": "desafligir",
    "desafligistes": "desafligir",
    "desafligiu": "desafligir",
    "desafligíamo": "desafligir",
    "desafligíamos": "desafligir",
    "desafligíei": "desafligir",
    "desafligíeis": "desafligir",
    "desafligíramo": "desafligir",
    "desafligíramos": "desafligir",
    "desafligírei": "desafligir",
    "desafligíreis": "desafligir",
    "desafligísseis": "desafligir",
    "desafligíssemos": "desafligir",
    "desaflija": "desafligir",
    "desaflijais": "desafligir",
    "desaflijam": "desafligir",
    "desaflijamo": "desafligir",
    "desaflijamos": "desafligir",
    "desaflijas": "desafligir",
    "desaflijo": "desafligir",
    "desafoga": "desafogar",
    "desafogada": "desafogar",
    "desafogadas": "desafogar",
    "desafogado": "desafogar",
    "desafogados": "desafogar",
    "desafogai": "desafogar",
    "desafogais": "desafogar",
    "desafogam": "desafogar",
    "desafogamo": "desafogar",
    "desafogamos": "desafogar",
    "desafogando": "desafogar",
    "desafogara": "desafogar",
    "desafogaram": "desafogar",
    "desafogaras": "desafogar",
    "desafogarde": "desafogar",
    "desafogardes": "desafogar",
    "desafogare": "desafogar",
    "desafogarei": "desafogar",
    "desafogareis": "desafogar",
    "desafogarem": "desafogar",
    "desafogaremos": "desafogar",
    "desafogares": "desafogar",
    "desafogaria": "desafogar",
    "desafogariam": "desafogar",
    "desafogarias": "desafogar",
    "desafogarmo": "desafogar",
    "desafogarmos": "desafogar",
    "desafogará": "desafogar",
    "desafogarás": "desafogar",
    "desafogarão": "desafogar",
    "desafogaríamos": "desafogar",
    "desafogaríeis": "desafogar",
    "desafogas": "desafogar",
    "desafogasse": "desafogar",
    "desafogassem": "desafogar",
    "desafogasses": "desafogar",
    "desafogaste": "desafogar",
    "desafogastes": "desafogar",
    "desafogava": "desafogar",
    "desafogavam": "desafogar",
    "desafogavas": "desafogar",
    "desafoge": "desafogar",
    "desafogei": "desafogar",
    "desafogeis": "desafogar",
    "desafogem": "desafogar",
    "desafogemo": "desafogar",
    "desafogemos": "desafogar",
    "desafoges": "desafogar",
    "desafogo": "desafogar",
    "desafogos": "desafogo",
    "desafogou": "desafogar",
    "desafogueada": "desafogueado",
    "desafogueadas": "desafogueado",
    "desafogueados": "desafogueado",
    "desafogá": "desafogar",
    "desafogámo": "desafogar",
    "desafogámos": "desafogar",
    "desafogáramo": "desafogar",
    "desafogáramos": "desafogar",
    "desafogárei": "desafogar",
    "desafogáreis": "desafogar",
    "desafogásseis": "desafogar",
    "desafogássemos": "desafogar",
    "desafogávamo": "desafogar",
    "desafogávamos": "desafogar",
    "desafogávei": "desafogar",
    "desafogáveis": "desafogar",
    "desafora": "desaforar",
    "desaforada": "desaforar",
    "desaforadas": "desaforar",
    "desaforado": "desaforar",
    "desaforados": "desaforar",
    "desaforai": "desaforar",
    "desaforais": "desaforar",
    "desaforam": "desaforar",
    "desaforamentos": "desaforamento",
    "desaforamo": "desaforar",
    "desaforamos": "desaforar",
    "desaforando": "desaforar",
    "desaforara": "desaforar",
    "desaforaram": "desaforar",
    "desaforaras": "desaforar",
    "desaforarde": "desaforar",
    "desaforardes": "desaforar",
    "desaforare": "desaforar",
    "desaforarei": "desaforar",
    "desaforareis": "desaforar",
    "desaforarem": "desaforar",
    "desaforaremos": "desaforar",
    "desaforares": "desaforar",
    "desaforaria": "desaforar",
    "desaforariam": "desaforar",
    "desaforarias": "desaforar",
    "desaforarmo": "desaforar",
    "desaforarmos": "desaforar",
    "desaforará": "desaforar",
    "desaforarás": "desaforar",
    "desaforarão": "desaforar",
    "desaforaríamos": "desaforar",
    "desaforaríeis": "desaforar",
    "desaforas": "desaforar",
    "desaforasse": "desaforar",
    "desaforassem": "desaforar",
    "desaforasses": "desaforar",
    "desaforaste": "desaforar",
    "desaforastes": "desaforar",
    "desaforava": "desaforar",
    "desaforavam": "desaforar",
    "desaforavas": "desaforar",
    "desafore": "desaforar",
    "desaforei": "desaforar",
    "desaforeis": "desaforar",
    "desaforem": "desaforar",
    "desaforemo": "desaforar",
    "desaforemos": "desaforar",
    "desafores": "desaforar",
    "desaforida": "desaforido",
    "desaforidas": "desaforido",
    "desaforidos": "desaforido",
    "desaformecida": "desaformecido",
    "desaformecidas": "desaformecido",
    "desaformecidos": "desaformecido",
    "desaforo": "desaforar",
    "desaforos": "desaforo",
    "desaforou": "desaforar",
    "desafortunada": "desafortunado",
    "desafortunadas": "desafortunado",
    "desafortunados": "desafortunado",
    "desaforá": "desaforar",
    "desaforámo": "desaforar",
    "desaforámos": "desaforar",
    "desaforáramo": "desaforar",
    "desaforáramos": "desaforar",
    "desaforárei": "desaforar",
    "desaforáreis": "desaforar",
    "desaforásseis": "desaforar",
    "desaforássemos": "desaforar",
    "desaforávamo": "desaforar",
    "desaforávamos": "desaforar",
    "desaforávei": "desaforar",
    "desaforáveis": "desaforar",
    "desafrancesáveis": "desafrancesável",
    "desafreguesa": "desafreguesar",
    "desafreguesada": "desafreguesar",
    "desafreguesadas": "desafreguesar",
    "desafreguesado": "desafreguesar",
    "desafreguesados": "desafreguesar",
    "desafreguesai": "desafreguesar",
    "desafreguesais": "desafreguesar",
    "desafreguesam": "desafreguesar",
    "desafreguesamo": "desafreguesar",
    "desafreguesamos": "desafreguesar",
    "desafreguesando": "desafreguesar",
    "desafreguesara": "desafreguesar",
    "desafreguesaram": "desafreguesar",
    "desafreguesaras": "desafreguesar",
    "desafreguesarde": "desafreguesar",
    "desafreguesardes": "desafreguesar",
    "desafreguesare": "desafreguesar",
    "desafreguesarei": "desafreguesar",
    "desafreguesareis": "desafreguesar",
    "desafreguesarem": "desafreguesar",
    "desafreguesaremos": "desafreguesar",
    "desafreguesares": "desafreguesar",
    "desafreguesaria": "desafreguesar",
    "desafreguesariam": "desafreguesar",
    "desafreguesarias": "desafreguesar",
    "desafreguesarmo": "desafreguesar",
    "desafreguesarmos": "desafreguesar",
    "desafreguesará": "desafreguesar",
    "desafreguesarás": "desafreguesar",
    "desafreguesarão": "desafreguesar",
    "desafreguesaríamos": "desafreguesar",
    "desafreguesaríeis": "desafreguesar",
    "desafreguesas": "desafreguesar",
    "desafreguesasse": "desafreguesar",
    "desafreguesassem": "desafreguesar",
    "desafreguesasses": "desafreguesar",
    "desafreguesaste": "desafreguesar",
    "desafreguesastes": "desafreguesar",
    "desafreguesava": "desafreguesar",
    "desafreguesavam": "desafreguesar",
    "desafreguesavas": "desafreguesar",
    "desafreguese": "desafreguesar",
    "desafreguesei": "desafreguesar",
    "desafregueseis": "desafreguesar",
    "desafreguesem": "desafreguesar",
    "desafreguesemo": "desafreguesar",
    "desafreguesemos": "desafreguesar",
    "desafregueses": "desafreguesar",
    "desafregueso": "desafreguesar",
    "desafreguesou": "desafreguesar",
    "desafreguesá": "desafreguesar",
    "desafreguesámo": "desafreguesar",
    "desafreguesámos": "desafreguesar",
    "desafreguesáramo": "desafreguesar",
    "desafreguesáramos": "desafreguesar",
    "desafreguesárei": "desafreguesar",
    "desafreguesáreis": "desafreguesar",
    "desafreguesásseis": "desafreguesar",
    "desafreguesássemos": "desafreguesar",
    "desafreguesávamo": "desafreguesar",
    "desafreguesávamos": "desafreguesar",
    "desafreguesávei": "desafreguesar",
    "desafreguesáveis": "desafreguesar",
    "desafreimada": "desafreimado",
    "desafreimadas": "desafreimado",
    "desafreimados": "desafreimado",
    "desafricanizáveis": "desafricanizável",
    "desafronta": "desafrontar",
    "desafrontada": "desafrontar",
    "desafrontadas": "desafrontar",
    "desafrontado": "desafrontar",
    "desafrontadora": "desafrontador",
    "desafrontadoras": "desafrontador",
    "desafrontadores": "desafrontador",
    "desafrontados": "desafrontar",
    "desafrontai": "desafrontar",
    "desafrontais": "desafrontar",
    "desafrontam": "desafrontar",
    "desafrontamentos": "desafrontamento",
    "desafrontamo": "desafrontar",
    "desafrontamos": "desafrontar",
    "desafrontando": "desafrontar",
    "desafrontara": "desafrontar",
    "desafrontaram": "desafrontar",
    "desafrontaras": "desafrontar",
    "desafrontarde": "desafrontar",
    "desafrontardes": "desafrontar",
    "desafrontare": "desafrontar",
    "desafrontarei": "desafrontar",
    "desafrontareis": "desafrontar",
    "desafrontarem": "desafrontar",
    "desafrontaremos": "desafrontar",
    "desafrontares": "desafrontar",
    "desafrontaria": "desafrontar",
    "desafrontariam": "desafrontar",
    "desafrontarias": "desafrontar",
    "desafrontarmo": "desafrontar",
    "desafrontarmos": "desafrontar",
    "desafrontará": "desafrontar",
    "desafrontarás": "desafrontar",
    "desafrontarão": "desafrontar",
    "desafrontaríamos": "desafrontar",
    "desafrontaríeis": "desafrontar",
    "desafrontas": "desafrontar",
    "desafrontasse": "desafrontar",
    "desafrontassem": "desafrontar",
    "desafrontasses": "desafrontar",
    "desafrontaste": "desafrontar",
    "desafrontastes": "desafrontar",
    "desafrontava": "desafrontar",
    "desafrontavam": "desafrontar",
    "desafrontavas": "desafrontar",
    "desafronte": "desafrontar",
    "desafrontei": "desafrontar",
    "desafronteis": "desafrontar",
    "desafrontem": "desafrontar",
    "desafrontemo": "desafrontar",
    "desafrontemos": "desafrontar",
    "desafrontes": "desafrontar",
    "desafronto": "desafrontar",
    "desafrontou": "desafrontar",
    "desafrontá": "desafrontar",
    "desafrontámo": "desafrontar",
    "desafrontámos": "desafrontar",
    "desafrontáramo": "desafrontar",
    "desafrontáramos": "desafrontar",
    "desafrontárei": "desafrontar",
    "desafrontáreis": "desafrontar",
    "desafrontásseis": "desafrontar",
    "desafrontássemos": "desafrontar",
    "desafrontávamo": "desafrontar",
    "desafrontávamos": "desafrontar",
    "desafrontávei": "desafrontar",
    "desafrontáveis": "desafrontar",
    "desafuma": "desafumar",
    "desafumada": "desafumar",
    "desafumadas": "desafumar",
    "desafumado": "desafumar",
    "desafumados": "desafumar",
    "desafumai": "desafumar",
    "desafumais": "desafumar",
    "desafumam": "desafumar",
    "desafumamo": "desafumar",
    "desafumamos": "desafumar",
    "desafumando": "desafumar",
    "desafumara": "desafumar",
    "desafumaram": "desafumar",
    "desafumaras": "desafumar",
    "desafumarde": "desafumar",
    "desafumardes": "desafumar",
    "desafumare": "desafumar",
    "desafumarei": "desafumar",
    "desafumareis": "desafumar",
    "desafumarem": "desafumar",
    "desafumaremos": "desafumar",
    "desafumares": "desafumar",
    "desafumaria": "desafumar",
    "desafumariam": "desafumar",
    "desafumarias": "desafumar",
    "desafumarmo": "desafumar",
    "desafumarmos": "desafumar",
    "desafumará": "desafumar",
    "desafumarás": "desafumar",
    "desafumarão": "desafumar",
    "desafumaríamos": "desafumar",
    "desafumaríeis": "desafumar",
    "desafumas": "desafumar",
    "desafumasse": "desafumar",
    "desafumassem": "desafumar",
    "desafumasses": "desafumar",
    "desafumaste": "desafumar",
    "desafumastes": "desafumar",
    "desafumava": "desafumar",
    "desafumavam": "desafumar",
    "desafumavas": "desafumar",
    "desafume": "desafumar",
    "desafumei": "desafumar",
    "desafumeis": "desafumar",
    "desafumem": "desafumar",
    "desafumemo": "desafumar",
    "desafumemos": "desafumar",
    "desafumes": "desafumar",
    "desafumo": "desafumar",
    "desafumou": "desafumar",
    "desafumá": "desafumar",
    "desafumámo": "desafumar",
    "desafumámos": "desafumar",
    "desafumáramo": "desafumar",
    "desafumáramos": "desafumar",
    "desafumárei": "desafumar",
    "desafumáreis": "desafumar",
    "desafumásseis": "desafumar",
    "desafumássemos": "desafumar",
    "desafumávamo": "desafumar",
    "desafumávamos": "desafumar",
    "desafumávei": "desafumar",
    "desafumáveis": "desafumar",
    "desafunda": "desafundar",
    "desafundada": "desafundar",
    "desafundadas": "desafundar",
    "desafundado": "desafundar",
    "desafundados": "desafundar",
    "desafundai": "desafundar",
    "desafundais": "desafundar",
    "desafundam": "desafundar",
    "desafundamo": "desafundar",
    "desafundamos": "desafundar",
    "desafundando": "desafundar",
    "desafundara": "desafundar",
    "desafundaram": "desafundar",
    "desafundaras": "desafundar",
    "desafundarde": "desafundar",
    "desafundardes": "desafundar",
    "desafundare": "desafundar",
    "desafundarei": "desafundar",
    "desafundareis": "desafundar",
    "desafundarem": "desafundar",
    "desafundaremos": "desafundar",
    "desafundares": "desafundar",
    "desafundaria": "desafundar",
    "desafundariam": "desafundar",
    "desafundarias": "desafundar",
    "desafundarmo": "desafundar",
    "desafundarmos": "desafundar",
    "desafundará": "desafundar",
    "desafundarás": "desafundar",
    "desafundarão": "desafundar",
    "desafundaríamos": "desafundar",
    "desafundaríeis": "desafundar",
    "desafundas": "desafundar",
    "desafundasse": "desafundar",
    "desafundassem": "desafundar",
    "desafundasses": "desafundar",
    "desafundaste": "desafundar",
    "desafundastes": "desafundar",
    "desafundava": "desafundar",
    "desafundavam": "desafundar",
    "desafundavas": "desafundar",
    "desafunde": "desafundar",
    "desafundei": "desafundar",
    "desafundeis": "desafundar",
    "desafundem": "desafundar",
    "desafundemo": "desafundar",
    "desafundemos": "desafundar",
    "desafundes": "desafundar",
    "desafundo": "desafundar",
    "desafundou": "desafundar",
    "desafundá": "desafundar",
    "desafundámo": "desafundar",
    "desafundámos": "desafundar",
    "desafundáramo": "desafundar",
    "desafundáramos": "desafundar",
    "desafundárei": "desafundar",
    "desafundáreis": "desafundar",
    "desafundásseis": "desafundar",
    "desafundássemos": "desafundar",
    "desafundávamo": "desafundar",
    "desafundávamos": "desafundar",
    "desafundávei": "desafundar",
    "desafundáveis": "desafundar",
    "desafáveis": "desafável",
    "desagaloa": "desagaloar",
    "desagaloada": "desagaloar",
    "desagaloadas": "desagaloar",
    "desagaloado": "desagaloar",
    "desagaloados": "desagaloar",
    "desagaloai": "desagaloar",
    "desagaloais": "desagaloar",
    "desagaloam": "desagaloar",
    "desagaloamo": "desagaloar",
    "desagaloamos": "desagaloar",
    "desagaloando": "desagaloar",
    "desagaloara": "desagaloar",
    "desagaloaram": "desagaloar",
    "desagaloaras": "desagaloar",
    "desagaloarde": "desagaloar",
    "desagaloardes": "desagaloar",
    "desagaloare": "desagaloar",
    "desagaloarei": "desagaloar",
    "desagaloareis": "desagaloar",
    "desagaloarem": "desagaloar",
    "desagaloaremos": "desagaloar",
    "desagaloares": "desagaloar",
    "desagaloaria": "desagaloar",
    "desagaloariam": "desagaloar",
    "desagaloarias": "desagaloar",
    "desagaloarmo": "desagaloar",
    "desagaloarmos": "desagaloar",
    "desagaloará": "desagaloar",
    "desagaloarás": "desagaloar",
    "desagaloarão": "desagaloar",
    "desagaloaríamos": "desagaloar",
    "desagaloaríeis": "desagaloar",
    "desagaloas": "desagaloar",
    "desagaloasse": "desagaloar",
    "desagaloassem": "desagaloar",
    "desagaloasses": "desagaloar",
    "desagaloaste": "desagaloar",
    "desagaloastes": "desagaloar",
    "desagaloava": "desagaloar",
    "desagaloavam": "desagaloar",
    "desagaloavas": "desagaloar",
    "desagaloe": "desagaloar",
    "desagaloei": "desagaloar",
    "desagaloeis": "desagaloar",
    "desagaloem": "desagaloar",
    "desagaloemo": "desagaloar",
    "desagaloemos": "desagaloar",
    "desagaloes": "desagaloar",
    "desagaloo": "desagaloar",
    "desagaloou": "desagaloar",
    "desagaloá": "desagaloar",
    "desagaloámo": "desagaloar",
    "desagaloámos": "desagaloar",
    "desagaloáramo": "desagaloar",
    "desagaloáramos": "desagaloar",
    "desagaloárei": "desagaloar",
    "desagaloáreis": "desagaloar",
    "desagaloásseis": "desagaloar",
    "desagaloássemos": "desagaloar",
    "desagaloávamo": "desagaloar",
    "desagaloávamos": "desagaloar",
    "desagaloávei": "desagaloar",
    "desagaloáveis": "desagaloar",
    "desagarra": "desagarrar",
    "desagarrada": "desagarrar",
    "desagarradas": "desagarrar",
    "desagarrado": "desagarrar",
    "desagarrados": "desagarrar",
    "desagarrai": "desagarrar",
    "desagarrais": "desagarrar",
    "desagarram": "desagarrar",
    "desagarramo": "desagarrar",
    "desagarramos": "desagarrar",
    "desagarrando": "desagarrar",
    "desagarrara": "desagarrar",
    "desagarraram": "desagarrar",
    "desagarraras": "desagarrar",
    "desagarrarde": "desagarrar",
    "desagarrardes": "desagarrar",
    "desagarrare": "desagarrar",
    "desagarrarei": "desagarrar",
    "desagarrareis": "desagarrar",
    "desagarrarem": "desagarrar",
    "desagarraremos": "desagarrar",
    "desagarrares": "desagarrar",
    "desagarraria": "desagarrar",
    "desagarrariam": "desagarrar",
    "desagarrarias": "desagarrar",
    "desagarrarmo": "desagarrar",
    "desagarrarmos": "desagarrar",
    "desagarrará": "desagarrar",
    "desagarrarás": "desagarrar",
    "desagarrarão": "desagarrar",
    "desagarraríamos": "desagarrar",
    "desagarraríeis": "desagarrar",
    "desagarras": "desagarrar",
    "desagarrasse": "desagarrar",
    "desagarrassem": "desagarrar",
    "desagarrasses": "desagarrar",
    "desagarraste": "desagarrar",
    "desagarrastes": "desagarrar",
    "desagarrava": "desagarrar",
    "desagarravam": "desagarrar",
    "desagarravas": "desagarrar",
    "desagarre": "desagarrar",
    "desagarrei": "desagarrar",
    "desagarreis": "desagarrar",
    "desagarrem": "desagarrar",
    "desagarremo": "desagarrar",
    "desagarremos": "desagarrar",
    "desagarres": "desagarrar",
    "desagarro": "desagarrar",
    "desagarrou": "desagarrar",
    "desagarrá": "desagarrar",
    "desagarrámo": "desagarrar",
    "desagarrámos": "desagarrar",
    "desagarráramo": "desagarrar",
    "desagarráramos": "desagarrar",
    "desagarrárei": "desagarrar",
    "desagarráreis": "desagarrar",
    "desagarrásseis": "desagarrar",
    "desagarrássemos": "desagarrar",
    "desagarrávamo": "desagarrar",
    "desagarrávamos": "desagarrar",
    "desagarrávei": "desagarrar",
    "desagarráveis": "desagarrar",
    "desagasalha": "desagasalhar",
    "desagasalhada": "desagasalhar",
    "desagasalhadas": "desagasalhar",
    "desagasalhado": "desagasalhar",
    "desagasalhados": "desagasalhar",
    "desagasalhai": "desagasalhar",
    "desagasalhais": "desagasalhar",
    "desagasalham": "desagasalhar",
    "desagasalhamo": "desagasalhar",
    "desagasalhamos": "desagasalhar",
    "desagasalhando": "desagasalhar",
    "desagasalhara": "desagasalhar",
    "desagasalharam": "desagasalhar",
    "desagasalharas": "desagasalhar",
    "desagasalharde": "desagasalhar",
    "desagasalhardes": "desagasalhar",
    "desagasalhare": "desagasalhar",
    "desagasalharei": "desagasalhar",
    "desagasalhareis": "desagasalhar",
    "desagasalharem": "desagasalhar",
    "desagasalharemos": "desagasalhar",
    "desagasalhares": "desagasalhar",
    "desagasalharia": "desagasalhar",
    "desagasalhariam": "desagasalhar",
    "desagasalharias": "desagasalhar",
    "desagasalharmo": "desagasalhar",
    "desagasalharmos": "desagasalhar",
    "desagasalhará": "desagasalhar",
    "desagasalharás": "desagasalhar",
    "desagasalharão": "desagasalhar",
    "desagasalharíamos": "desagasalhar",
    "desagasalharíeis": "desagasalhar",
    "desagasalhas": "desagasalhar",
    "desagasalhasse": "desagasalhar",
    "desagasalhassem": "desagasalhar",
    "desagasalhasses": "desagasalhar",
    "desagasalhaste": "desagasalhar",
    "desagasalhastes": "desagasalhar",
    "desagasalhava": "desagasalhar",
    "desagasalhavam": "desagasalhar",
    "desagasalhavas": "desagasalhar",
    "desagasalhe": "desagasalhar",
    "desagasalhei": "desagasalhar",
    "desagasalheis": "desagasalhar",
    "desagasalhem": "desagasalhar",
    "desagasalhemo": "desagasalhar",
    "desagasalhemos": "desagasalhar",
    "desagasalhes": "desagasalhar",
    "desagasalho": "desagasalhar",
    "desagasalhos": "desagasalho",
    "desagasalhou": "desagasalhar",
    "desagasalhá": "desagasalhar",
    "desagasalhámo": "desagasalhar",
    "desagasalhámos": "desagasalhar",
    "desagasalháramo": "desagasalhar",
    "desagasalháramos": "desagasalhar",
    "desagasalhárei": "desagasalhar",
    "desagasalháreis": "desagasalhar",
    "desagasalhásseis": "desagasalhar",
    "desagasalhássemos": "desagasalhar",
    "desagasalhávamo": "desagasalhar",
    "desagasalhávamos": "desagasalhar",
    "desagasalhávei": "desagasalhar",
    "desagasalháveis": "desagasalhar",
    "desagasta": "desagastar",
    "desagastada": "desagastar",
    "desagastadas": "desagastar",
    "desagastado": "desagastar",
    "desagastados": "desagastar",
    "desagastai": "desagastar",
    "desagastais": "desagastar",
    "desagastam": "desagastar",
    "desagastamentos": "desagastamento",
    "desagastamo": "desagastar",
    "desagastamos": "desagastar",
    "desagastando": "desagastar",
    "desagastara": "desagastar",
    "desagastaram": "desagastar",
    "desagastaras": "desagastar",
    "desagastarde": "desagastar",
    "desagastardes": "desagastar",
    "desagastare": "desagastar",
    "desagastarei": "desagastar",
    "desagastareis": "desagastar",
    "desagastarem": "desagastar",
    "desagastaremos": "desagastar",
    "desagastares": "desagastar",
    "desagastaria": "desagastar",
    "desagastariam": "desagastar",
    "desagastarias": "desagastar",
    "desagastarmo": "desagastar",
    "desagastarmos": "desagastar",
    "desagastará": "desagastar",
    "desagastarás": "desagastar",
    "desagastarão": "desagastar",
    "desagastaríamos": "desagastar",
    "desagastaríeis": "desagastar",
    "desagastas": "desagastar",
    "desagastasse": "desagastar",
    "desagastassem": "desagastar",
    "desagastasses": "desagastar",
    "desagastaste": "desagastar",
    "desagastastes": "desagastar",
    "desagastava": "desagastar",
    "desagastavam": "desagastar",
    "desagastavas": "desagastar",
    "desagaste": "desagastar",
    "desagastei": "desagastar",
    "desagasteis": "desagastar",
    "desagastem": "desagastar",
    "desagastemo": "desagastar",
    "desagastemos": "desagastar",
    "desagastes": "desagastar",
    "desagasto": "desagastar",
    "desagastou": "desagastar",
    "desagastá": "desagastar",
    "desagastámo": "desagastar",
    "desagastámos": "desagastar",
    "desagastáramo": "desagastar",
    "desagastáramos": "desagastar",
    "desagastárei": "desagastar",
    "desagastáreis": "desagastar",
    "desagastásseis": "desagastar",
    "desagastássemos": "desagastar",
    "desagastávamo": "desagastar",
    "desagastávamos": "desagastar",
    "desagastávei": "desagastar",
    "desagastáveis": "desagastar",
    "desaglomera": "desaglomerar",
    "desaglomerada": "desaglomerar",
    "desaglomeradas": "desaglomerar",
    "desaglomerado": "desaglomerar",
    "desaglomerados": "desaglomerar",
    "desaglomerai": "desaglomerar",
    "desaglomerais": "desaglomerar",
    "desaglomeram": "desaglomerar",
    "desaglomeramo": "desaglomerar",
    "desaglomeramos": "desaglomerar",
    "desaglomerando": "desaglomerar",
    "desaglomerara": "desaglomerar",
    "desaglomeraram": "desaglomerar",
    "desaglomeraras": "desaglomerar",
    "desaglomerarde": "desaglomerar",
    "desaglomerardes": "desaglomerar",
    "desaglomerare": "desaglomerar",
    "desaglomerarei": "desaglomerar",
    "desaglomerareis": "desaglomerar",
    "desaglomerarem": "desaglomerar",
    "desaglomeraremos": "desaglomerar",
    "desaglomerares": "desaglomerar",
    "desaglomeraria": "desaglomerar",
    "desaglomerariam": "desaglomerar",
    "desaglomerarias": "desaglomerar",
    "desaglomerarmo": "desaglomerar",
    "desaglomerarmos": "desaglomerar",
    "desaglomerará": "desaglomerar",
    "desaglomerarás": "desaglomerar",
    "desaglomerarão": "desaglomerar",
    "desaglomeraríamos": "desaglomerar",
    "desaglomeraríeis": "desaglomerar",
    "desaglomeras": "desaglomerar",
    "desaglomerasse": "desaglomerar",
    "desaglomerassem": "desaglomerar",
    "desaglomerasses": "desaglomerar",
    "desaglomeraste": "desaglomerar",
    "desaglomerastes": "desaglomerar",
    "desaglomerava": "desaglomerar",
    "desaglomeravam": "desaglomerar",
    "desaglomeravas": "desaglomerar",
    "desaglomere": "desaglomerar",
    "desaglomerei": "desaglomerar",
    "desaglomereis": "desaglomerar",
    "desaglomerem": "desaglomerar",
    "desaglomeremo": "desaglomerar",
    "desaglomeremos": "desaglomerar",
    "desaglomeres": "desaglomerar",
    "desaglomero": "desaglomerar",
    "desaglomerou": "desaglomerar",
    "desaglomerá": "desaglomerar",
    "desaglomerámo": "desaglomerar",
    "desaglomerámos": "desaglomerar",
    "desaglomeráramo": "desaglomerar",
    "desaglomeráramos": "desaglomerar",
    "desaglomerárei": "desaglomerar",
    "desaglomeráreis": "desaglomerar",
    "desaglomerásseis": "desaglomerar",
    "desaglomerássemos": "desaglomerar",
    "desaglomerávamo": "desaglomerar",
    "desaglomerávamos": "desaglomerar",
    "desaglomerávei": "desaglomerar",
    "desaglomeráveis": "desaglomerar",
    "desaglutináveis": "desaglutinável",
    "desagonia": "desagoniar",
    "desagoniada": "desagoniar",
    "desagoniadas": "desagoniar",
    "desagoniado": "desagoniar",
    "desagoniados": "desagoniar",
    "desagoniai": "desagoniar",
    "desagoniais": "desagoniar",
    "desagoniam": "desagoniar",
    "desagoniamo": "desagoniar",
    "desagoniamos": "desagoniar",
    "desagoniando": "desagoniar",
    "desagoniara": "desagoniar",
    "desagoniaram": "desagoniar",
    "desagoniaras": "desagoniar",
    "desagoniarde": "desagoniar",
    "desagoniardes": "desagoniar",
    "desagoniare": "desagoniar",
    "desagoniarei": "desagoniar",
    "desagoniareis": "desagoniar",
    "desagoniarem": "desagoniar",
    "desagoniaremos": "desagoniar",
    "desagoniares": "desagoniar",
    "desagoniaria": "desagoniar",
    "desagoniariam": "desagoniar",
    "desagoniarias": "desagoniar",
    "desagoniarmo": "desagoniar",
    "desagoniarmos": "desagoniar",
    "desagoniará": "desagoniar",
    "desagoniarás": "desagoniar",
    "desagoniarão": "desagoniar",
    "desagoniaríamos": "desagoniar",
    "desagoniaríeis": "desagoniar",
    "desagonias": "desagoniar",
    "desagoniasse": "desagoniar",
    "desagoniassem": "desagoniar",
    "desagoniasses": "desagoniar",
    "desagoniaste": "desagoniar",
    "desagoniastes": "desagoniar",
    "desagoniava": "desagoniar",
    "desagoniavam": "desagoniar",
    "desagoniavas": "desagoniar",
    "desagonie": "desagoniar",
    "desagoniei": "desagoniar",
    "desagonieis": "desagoniar",
    "desagoniem": "desagoniar",
    "desagoniemo": "desagoniar",
    "desagoniemos": "desagoniar",
    "desagonies": "desagoniar",
    "desagonio": "desagoniar",
    "desagoniou": "desagoniar",
    "desagoniá": "desagoniar",
    "desagoniámo": "desagoniar",
    "desagoniámos": "desagoniar",
    "desagoniáramo": "desagoniar",
    "desagoniáramos": "desagoniar",
    "desagoniárei": "desagoniar",
    "desagoniáreis": "desagoniar",
    "desagoniásseis": "desagoniar",
    "desagoniássemos": "desagoniar",
    "desagoniávamo": "desagoniar",
    "desagoniávamos": "desagoniar",
    "desagoniávei": "desagoniar",
    "desagoniáveis": "desagoniar",
    "desagrada": "desagradar",
    "desagradada": "desagradar",
    "desagradadas": "desagradar",
    "desagradado": "desagradar",
    "desagradados": "desagradar",
    "desagradai": "desagradar",
    "desagradais": "desagradar",
    "desagradam": "desagradar",
    "desagradamo": "desagradar",
    "desagradamos": "desagradar",
    "desagradando": "desagradar",
    "desagradara": "desagradar",
    "desagradaram": "desagradar",
    "desagradaras": "desagradar",
    "desagradarde": "desagradar",
    "desagradardes": "desagradar",
    "desagradare": "desagradar",
    "desagradarei": "desagradar",
    "desagradareis": "desagradar",
    "desagradarem": "desagradar",
    "desagradaremos": "desagradar",
    "desagradares": "desagradar",
    "desagradaria": "desagradar",
    "desagradariam": "desagradar",
    "desagradarias": "desagradar",
    "desagradarmo": "desagradar",
    "desagradarmos": "desagradar",
    "desagradará": "desagradar",
    "desagradarás": "desagradar",
    "desagradarão": "desagradar",
    "desagradaríamos": "desagradar",
    "desagradaríeis": "desagradar",
    "desagradas": "desagradar",
    "desagradasse": "desagradar",
    "desagradassem": "desagradar",
    "desagradasses": "desagradar",
    "desagradaste": "desagradar",
    "desagradastes": "desagradar",
    "desagradava": "desagradar",
    "desagradavam": "desagradar",
    "desagradavas": "desagradar",
    "desagrade": "desagradar",
    "desagradece": "desagradecer",
    "desagradecei": "desagradecer",
    "desagradeceis": "desagradecer",
    "desagradecem": "desagradecer",
    "desagradecemo": "desagradecer",
    "desagradecemos": "desagradecer",
    "desagradecendo": "desagradecer",
    "desagradecera": "desagradecer",
    "desagradeceram": "desagradecer",
    "desagradeceras": "desagradecer",
    "desagradecerde": "desagradecer",
    "desagradecerdes": "desagradecer",
    "desagradecere": "desagradecer",
    "desagradecerei": "desagradecer",
    "desagradecereis": "desagradecer",
    "desagradecerem": "desagradecer",
    "desagradeceremos": "desagradecer",
    "desagradeceres": "desagradecer",
    "desagradeceria": "desagradecer",
    "desagradeceriam": "desagradecer",
    "desagradecerias": "desagradecer",
    "desagradecermo": "desagradecer",
    "desagradecermos": "desagradecer",
    "desagradecerá": "desagradecer",
    "desagradecerás": "desagradecer",
    "desagradecerão": "desagradecer",
    "desagradeceríamos": "desagradecer",
    "desagradeceríeis": "desagradecer",
    "desagradeces": "desagradecer",
    "desagradecesse": "desagradecer",
    "desagradecessem": "desagradecer",
    "desagradecesses": "desagradecer",
    "desagradeceste": "desagradecer",
    "desagradecestes": "desagradecer",
    "desagradeceu": "desagradecer",
    "desagradeci": "desagradecer",
    "desagradecia": "desagradecer",
    "desagradeciam": "desagradecer",
    "desagradecias": "desagradecer",
    "desagradecida": "desagradecido",
    "desagradecidas": "desagradecido",
    "desagradecido": "desagradecer",
    "desagradecidos": "desagradecido",
    "desagradecimentos": "desagradecimento",
    "desagradecê": "desagradecer",
    "desagradecêramo": "desagradecer",
    "desagradecêramos": "desagradecer",
    "desagradecêrei": "desagradecer",
    "desagradecêreis": "desagradecer",
    "desagradecêsseis": "desagradecer",
    "desagradecêssemos": "desagradecer",
    "desagradecíamo": "desagradecer",
    "desagradecíamos": "desagradecer",
    "desagradecíei": "desagradecer",
    "desagradecíeis": "desagradecer",
    "desagradei": "desagradar",
    "desagradeis": "desagradar",
    "desagradem": "desagradar",
    "desagrademo": "desagradar",
    "desagrademos": "desagradar",
    "desagrades": "desagradar",
    "desagradeça": "desagradecer",
    "desagradeçais": "desagradecer",
    "desagradeçam": "desagradecer",
    "desagradeçamo": "desagradecer",
    "desagradeçamos": "desagradecer",
    "desagradeças": "desagradecer",
    "desagradeço": "desagradecer",
    "desagrado": "desagradar",
    "desagrados": "desagrado",
    "desagradou": "desagradar",
    "desagradá": "desagradar",
    "desagradámo": "desagradar",
    "desagradámos": "desagradar",
    "desagradáramo": "desagradar",
    "desagradáramos": "desagradar",
    "desagradárei": "desagradar",
    "desagradáreis": "desagradar",
    "desagradásseis": "desagradar",
    "desagradássemos": "desagradar",
    "desagradávamo": "desagradar",
    "desagradávamos": "desagradar",
    "desagradávei": "desagradar",
    "desagradáveis": "desagradável",
    "desagrava": "desagravar",
    "desagravada": "desagravar",
    "desagravadas": "desagravar",
    "desagravado": "desagravar",
    "desagravadora": "desagravador",
    "desagravadoras": "desagravador",
    "desagravadores": "desagravador",
    "desagravados": "desagravar",
    "desagravai": "desagravar",
    "desagravais": "desagravar",
    "desagravam": "desagravar",
    "desagravamentos": "desagravamento",
    "desagravamo": "desagravar",
    "desagravamos": "desagravar",
    "desagravando": "desagravar",
    "desagravantes": "desagravante",
    "desagravara": "desagravar",
    "desagravaram": "desagravar",
    "desagravaras": "desagravar",
    "desagravarde": "desagravar",
    "desagravardes": "desagravar",
    "desagravare": "desagravar",
    "desagravarei": "desagravar",
    "desagravareis": "desagravar",
    "desagravarem": "desagravar",
    "desagravaremos": "desagravar",
    "desagravares": "desagravar",
    "desagravaria": "desagravar",
    "desagravariam": "desagravar",
    "desagravarias": "desagravar",
    "desagravarmo": "desagravar",
    "desagravarmos": "desagravar",
    "desagravará": "desagravar",
    "desagravarás": "desagravar",
    "desagravarão": "desagravar",
    "desagravaríamos": "desagravar",
    "desagravaríeis": "desagravar",
    "desagravas": "desagravar",
    "desagravasse": "desagravar",
    "desagravassem": "desagravar",
    "desagravasses": "desagravar",
    "desagravaste": "desagravar",
    "desagravastes": "desagravar",
    "desagravava": "desagravar",
    "desagravavam": "desagravar",
    "desagravavas": "desagravar",
    "desagrave": "desagravar",
    "desagravei": "desagravar",
    "desagraveis": "desagravar",
    "desagravem": "desagravar",
    "desagravemo": "desagravar",
    "desagravemos": "desagravar",
    "desagraves": "desagravar",
    "desagravo": "desagravar",
    "desagravos": "desagravo",
    "desagravou": "desagravar",
    "desagravá": "desagravar",
    "desagravámo": "desagravar",
    "desagravámos": "desagravar",
    "desagraváramo": "desagravar",
    "desagraváramos": "desagravar",
    "desagravárei": "desagravar",
    "desagraváreis": "desagravar",
    "desagravásseis": "desagravar",
    "desagravássemos": "desagravar",
    "desagravávamo": "desagravar",
    "desagravávamos": "desagravar",
    "desagravávei": "desagravar",
    "desagraváveis": "desagravar",
    "desagrega": "desagregar",
    "desagregada": "desagregar",
    "desagregadas": "desagregar",
    "desagregado": "desagregar",
    "desagregadora": "desagregador",
    "desagregadoras": "desagregador",
    "desagregadores": "desagregador",
    "desagregados": "desagregar",
    "desagregai": "desagregar",
    "desagregais": "desagregar",
    "desagregam": "desagregar",
    "desagregamo": "desagregar",
    "desagregamos": "desagregar",
    "desagregando": "desagregar",
    "desagregantes": "desagregante",
    "desagregara": "desagregar",
    "desagregaram": "desagregar",
    "desagregaras": "desagregar",
    "desagregarde": "desagregar",
    "desagregardes": "desagregar",
    "desagregare": "desagregar",
    "desagregarei": "desagregar",
    "desagregareis": "desagregar",
    "desagregarem": "desagregar",
    "desagregaremos": "desagregar",
    "desagregares": "desagregar",
    "desagregaria": "desagregar",
    "desagregariam": "desagregar",
    "desagregarias": "desagregar",
    "desagregarmo": "desagregar",
    "desagregarmos": "desagregar",
    "desagregará": "desagregar",
    "desagregarás": "desagregar",
    "desagregarão": "desagregar",
    "desagregaríamos": "desagregar",
    "desagregaríeis": "desagregar",
    "desagregas": "desagregar",
    "desagregasse": "desagregar",
    "desagregassem": "desagregar",
    "desagregasses": "desagregar",
    "desagregaste": "desagregar",
    "desagregastes": "desagregar",
    "desagregava": "desagregar",
    "desagregavam": "desagregar",
    "desagregavas": "desagregar",
    "desagregações": "desagregação",
    "desagrego": "desagregar",
    "desagregou": "desagregar",
    "desagregue": "desagregar",
    "desagreguei": "desagregar",
    "desagregueis": "desagregar",
    "desagreguem": "desagregar",
    "desagreguemo": "desagregar",
    "desagreguemos": "desagregar",
    "desagregues": "desagregar",
    "desagregá": "desagregar",
    "desagregámo": "desagregar",
    "desagregámos": "desagregar",
    "desagregáramo": "desagregar",
    "desagregáramos": "desagregar",
    "desagregárei": "desagregar",
    "desagregáreis": "desagregar",
    "desagregásseis": "desagregar",
    "desagregássemos": "desagregar",
    "desagregávamo": "desagregar",
    "desagregávamos": "desagregar",
    "desagregávei": "desagregar",
    "desagregáveis": "desagregável",
    "desagrilhoa": "desagrilhoar",
    "desagrilhoada": "desagrilhoar",
    "desagrilhoadas": "desagrilhoar",
    "desagrilhoado": "desagrilhoar",
    "desagrilhoados": "desagrilhoar",
    "desagrilhoai": "desagrilhoar",
    "desagrilhoais": "desagrilhoar",
    "desagrilhoam": "desagrilhoar",
    "desagrilhoamentos": "desagrilhoamento",
    "desagrilhoamo": "desagrilhoar",
    "desagrilhoamos": "desagrilhoar",
    "desagrilhoando": "desagrilhoar",
    "desagrilhoara": "desagrilhoar",
    "desagrilhoaram": "desagrilhoar",
    "desagrilhoaras": "desagrilhoar",
    "desagrilhoarde": "desagrilhoar",
    "desagrilhoardes": "desagrilhoar",
    "desagrilhoare": "desagrilhoar",
    "desagrilhoarei": "desagrilhoar",
    "desagrilhoareis": "desagrilhoar",
    "desagrilhoarem": "desagrilhoar",
    "desagrilhoaremos": "desagrilhoar",
    "desagrilhoares": "desagrilhoar",
    "desagrilhoaria": "desagrilhoar",
    "desagrilhoariam": "desagrilhoar",
    "desagrilhoarias": "desagrilhoar",
    "desagrilhoarmo": "desagrilhoar",
    "desagrilhoarmos": "desagrilhoar",
    "desagrilhoará": "desagrilhoar",
    "desagrilhoarás": "desagrilhoar",
    "desagrilhoarão": "desagrilhoar",
    "desagrilhoaríamos": "desagrilhoar",
    "desagrilhoaríeis": "desagrilhoar",
    "desagrilhoas": "desagrilhoar",
    "desagrilhoasse": "desagrilhoar",
    "desagrilhoassem": "desagrilhoar",
    "desagrilhoasses": "desagrilhoar",
    "desagrilhoaste": "desagrilhoar",
    "desagrilhoastes": "desagrilhoar",
    "desagrilhoava": "desagrilhoar",
    "desagrilhoavam": "desagrilhoar",
    "desagrilhoavas": "desagrilhoar",
    "desagrilhoe": "desagrilhoar",
    "desagrilhoei": "desagrilhoar",
    "desagrilhoeis": "desagrilhoar",
    "desagrilhoem": "desagrilhoar",
    "desagrilhoemo": "desagrilhoar",
    "desagrilhoemos": "desagrilhoar",
    "desagrilhoes": "desagrilhoar",
    "desagrilhoo": "desagrilhoar",
    "desagrilhoou": "desagrilhoar",
    "desagrilhoá": "desagrilhoar",
    "desagrilhoámo": "desagrilhoar",
    "desagrilhoámos": "desagrilhoar",
    "desagrilhoáramo": "desagrilhoar",
    "desagrilhoáramos": "desagrilhoar",
    "desagrilhoárei": "desagrilhoar",
    "desagrilhoáreis": "desagrilhoar",
    "desagrilhoásseis": "desagrilhoar",
    "desagrilhoássemos": "desagrilhoar",
    "desagrilhoávamo": "desagrilhoar",
    "desagrilhoávamos": "desagrilhoar",
    "desagrilhoávei": "desagrilhoar",
    "desagrilhoáveis": "desagrilhoar",
    "desagua": "desaguar",
    "desaguada": "desaguar",
    "desaguadas": "desaguar",
    "desaguado": "desaguar",
    "desaguadoiros": "desaguadoiro",
    "desaguadora": "desaguador",
    "desaguadoras": "desaguador",
    "desaguadores": "desaguador",
    "desaguados": "desaguar",
    "desaguadouros": "desaguadouro",
    "desaguai": "desaguar",
    "desaguais": "desaguar",
    "desaguam": "desaguar",
    "desaguamentos": "desaguamento",
    "desaguamo": "desaguar",
    "desaguamos": "desaguar",
    "desaguando": "desaguar",
    "desaguara": "desaguar",
    "desaguaram": "desaguar",
    "desaguaras": "desaguar",
    "desaguardes": "desaguar",
    "desaguarei": "desaguar",
    "desaguareis": "desaguar",
    "desaguarem": "desaguar",
    "desaguaremos": "desaguar",
    "desaguares": "desaguar",
    "desaguaria": "desaguar",
    "desaguariam": "desaguar",
    "desaguarias": "desaguar",
    "desaguarmo": "desaguar",
    "desaguarmos": "desaguar",
    "desaguará": "desaguar",
    "desaguarás": "desaguar",
    "desaguarão": "desaguar",
    "desaguaríamos": "desaguar",
    "desaguaríeis": "desaguar",
    "desaguas": "desaguar",
    "desaguasse": "desaguar",
    "desaguassem": "desaguar",
    "desaguasses": "desaguar",
    "desaguaste": "desaguar",
    "desaguastes": "desaguar",
    "desaguava": "desaguar",
    "desaguavam": "desaguar",
    "desaguavas": "desaguar",
    "desaguce": "desaguçar",
    "desagucei": "desaguçar",
    "desaguceis": "desaguçar",
    "desagucem": "desaguçar",
    "desagucemo": "desaguçar",
    "desagucemos": "desaguçar",
    "desaguces": "desaguçar",
    "desaguei": "desaguar",
    "desagueis": "desaguar",
    "desaguemo": "desaguar",
    "desaguemos": "desaguar",
    "desagues": "desaguar",
    "desaguilhoamentos": "desaguilhoamento",
    "desaguisa": "desaguisar",
    "desaguisada": "desaguisar",
    "desaguisadas": "desaguisar",
    "desaguisado": "desaguisar",
    "desaguisados": "desaguisar",
    "desaguisai": "desaguisar",
    "desaguisais": "desaguisar",
    "desaguisam": "desaguisar",
    "desaguisamo": "desaguisar",
    "desaguisamos": "desaguisar",
    "desaguisando": "desaguisar",
    "desaguisara": "desaguisar",
    "desaguisaram": "desaguisar",
    "desaguisaras": "desaguisar",
    "desaguisarde": "desaguisar",
    "desaguisardes": "desaguisar",
    "desaguisare": "desaguisar",
    "desaguisarei": "desaguisar",
    "desaguisareis": "desaguisar",
    "desaguisarem": "desaguisar",
    "desaguisaremos": "desaguisar",
    "desaguisares": "desaguisar",
    "desaguisaria": "desaguisar",
    "desaguisariam": "desaguisar",
    "desaguisarias": "desaguisar",
    "desaguisarmo": "desaguisar",
    "desaguisarmos": "desaguisar",
    "desaguisará": "desaguisar",
    "desaguisarás": "desaguisar",
    "desaguisarão": "desaguisar",
    "desaguisaríamos": "desaguisar",
    "desaguisaríeis": "desaguisar",
    "desaguisas": "desaguisar",
    "desaguisasse": "desaguisar",
    "desaguisassem": "desaguisar",
    "desaguisasses": "desaguisar",
    "desaguisaste": "desaguisar",
    "desaguisastes": "desaguisar",
    "desaguisava": "desaguisar",
    "desaguisavam": "desaguisar",
    "desaguisavas": "desaguisar",
    "desaguise": "desaguisar",
    "desaguisei": "desaguisar",
    "desaguiseis": "desaguisar",
    "desaguisem": "desaguisar",
    "desaguisemo": "desaguisar",
    "desaguisemos": "desaguisar",
    "desaguises": "desaguisar",
    "desaguiso": "desaguisar",
    "desaguisou": "desaguisar",
    "desaguisá": "desaguisar",
    "desaguisámo": "desaguisar",
    "desaguisámos": "desaguisar",
    "desaguisáramo": "desaguisar",
    "desaguisáramos": "desaguisar",
    "desaguisárei": "desaguisar",
    "desaguisáreis": "desaguisar",
    "desaguisásseis": "desaguisar",
    "desaguisássemos": "desaguisar",
    "desaguisávamo": "desaguisar",
    "desaguisávamos": "desaguisar",
    "desaguisávei": "desaguisar",
    "desaguisáveis": "desaguisar",
    "desaguo": "desaguar",
    "desaguou": "desaguar",
    "desaguámo": "desaguar",
    "desaguámos": "desaguar",
    "desaguáramo": "desaguar",
    "desaguáramos": "desaguar",
    "desaguáreis": "desaguar",
    "desaguásseis": "desaguar",
    "desaguássemos": "desaguar",
    "desaguávamo": "desaguar",
    "desaguávamos": "desaguar",
    "desaguáveis": "desaguar",
    "desaguça": "desaguçar",
    "desaguçada": "desaguçar",
    "desaguçadas": "desaguçar",
    "desaguçado": "desaguçar",
    "desaguçados": "desaguçar",
    "desaguçai": "desaguçar",
    "desaguçais": "desaguçar",
    "desaguçam": "desaguçar",
    "desaguçamo": "desaguçar",
    "desaguçamos": "desaguçar",
    "desaguçando": "desaguçar",
    "desaguçara": "desaguçar",
    "desaguçaram": "desaguçar",
    "desaguçaras": "desaguçar",
    "desaguçarde": "desaguçar",
    "desaguçardes": "desaguçar",
    "desaguçare": "desaguçar",
    "desaguçarei": "desaguçar",
    "desaguçareis": "desaguçar",
    "desaguçarem": "desaguçar",
    "desaguçaremos": "desaguçar",
    "desaguçares": "desaguçar",
    "desaguçaria": "desaguçar",
    "desaguçariam": "desaguçar",
    "desaguçarias": "desaguçar",
    "desaguçarmo": "desaguçar",
    "desaguçarmos": "desaguçar",
    "desaguçará": "desaguçar",
    "desaguçarás": "desaguçar",
    "desaguçarão": "desaguçar",
    "desaguçaríamos": "desaguçar",
    "desaguçaríeis": "desaguçar",
    "desaguças": "desaguçar",
    "desaguçasse": "desaguçar",
    "desaguçassem": "desaguçar",
    "desaguçasses": "desaguçar",
    "desaguçaste": "desaguçar",
    "desaguçastes": "desaguçar",
    "desaguçava": "desaguçar",
    "desaguçavam": "desaguçar",
    "desaguçavas": "desaguçar",
    "desaguço": "desaguçar",
    "desaguçou": "desaguçar",
    "desaguçá": "desaguçar",
    "desaguçámo": "desaguçar",
    "desaguçámos": "desaguçar",
    "desaguçáramo": "desaguçar",
    "desaguçáramos": "desaguçar",
    "desaguçárei": "desaguçar",
    "desaguçáreis": "desaguçar",
    "desaguçásseis": "desaguçar",
    "desaguçássemos": "desaguçar",
    "desaguçávamo": "desaguçar",
    "desaguçávamos": "desaguçar",
    "desaguçávei": "desaguçar",
    "desaguçáveis": "desaguçar",
    "desagúe": "desaguar",
    "desagúem": "desaguar",
    "desagúes": "desaguar",
    "desaina": "desainar",
    "desainada": "desainar",
    "desainadas": "desainar",
    "desainado": "desainar",
    "desainados": "desainar",
    "desainai": "desainar",
    "desainais": "desainar",
    "desainam": "desainar",
    "desainamo": "desainar",
    "desainamos": "desainar",
    "desainando": "desainar",
    "desainara": "desainar",
    "desainaram": "desainar",
    "desainaras": "desainar",
    "desainarde": "desainar",
    "desainardes": "desainar",
    "desainare": "desainar",
    "desainarei": "desainar",
    "desainareis": "desainar",
    "desainarem": "desainar",
    "desainaremos": "desainar",
    "desainares": "desainar",
    "desainaria": "desainar",
    "desainariam": "desainar",
    "desainarias": "desainar",
    "desainarmo": "desainar",
    "desainarmos": "desainar",
    "desainará": "desainar",
    "desainarás": "desainar",
    "desainarão": "desainar",
    "desainaríamos": "desainar",
    "desainaríeis": "desainar",
    "desainas": "desainar",
    "desainasse": "desainar",
    "desainassem": "desainar",
    "desainasses": "desainar",
    "desainaste": "desainar",
    "desainastes": "desainar",
    "desainava": "desainar",
    "desainavam": "desainar",
    "desainavas": "desainar",
    "desaine": "desainar",
    "desainei": "desainar",
    "desaineis": "desainar",
    "desainem": "desainar",
    "desainemo": "desainar",
    "desainemos": "desainar",
    "desaines": "desainar",
    "desaino": "desainar",
    "desainou": "desainar",
    "desainá": "desainar",
    "desainámo": "desainar",
    "desainámos": "desainar",
    "desaináramo": "desainar",
    "desaináramos": "desainar",
    "desainárei": "desainar",
    "desaináreis": "desainar",
    "desainásseis": "desainar",
    "desainássemos": "desainar",
    "desainávamo": "desainar",
    "desainávamos": "desainar",
    "desainávei": "desainar",
    "desaináveis": "desainar",
    "desaira": "desairar",
    "desairada": "desairar",
    "desairadas": "desairar",
    "desairado": "desairar",
    "desairados": "desairar",
    "desairai": "desairar",
    "desairais": "desairar",
    "desairam": "desairar",
    "desairamo": "desairar",
    "desairamos": "desairar",
    "desairando": "desairar",
    "desairara": "desairar",
    "desairaram": "desairar",
    "desairaras": "desairar",
    "desairarde": "desairar",
    "desairardes": "desairar",
    "desairare": "desairar",
    "desairarei": "desairar",
    "desairareis": "desairar",
    "desairarem": "desairar",
    "desairaremos": "desairar",
    "desairares": "desairar",
    "desairaria": "desairar",
    "desairariam": "desairar",
    "desairarias": "desairar",
    "desairarmo": "desairar",
    "desairarmos": "desairar",
    "desairará": "desairar",
    "desairarás": "desairar",
    "desairarão": "desairar",
    "desairaríamos": "desairar",
    "desairaríeis": "desairar",
    "desairas": "desairar",
    "desairasse": "desairar",
    "desairassem": "desairar",
    "desairasses": "desairar",
    "desairaste": "desairar",
    "desairastes": "desairar",
    "desairava": "desairar",
    "desairavam": "desairar",
    "desairavas": "desairar",
    "desaire": "desairar",
    "desairei": "desairar",
    "desaireis": "desairar",
    "desairem": "desairar",
    "desairemo": "desairar",
    "desairemos": "desairar",
    "desaires": "desaire",
    "desairo": "desairar",
    "desairosa": "desairoso",
    "desairosas": "desairoso",
    "desairosos": "desairoso",
    "desairou": "desairar",
    "desairá": "desairar",
    "desairámo": "desairar",
    "desairámos": "desairar",
    "desairáramo": "desairar",
    "desairáramos": "desairar",
    "desairárei": "desairar",
    "desairáreis": "desairar",
    "desairásseis": "desairar",
    "desairássemos": "desairar",
    "desairávamo": "desairar",
    "desairávamos": "desairar",
    "desairávei": "desairar",
    "desairáveis": "desairar",
    "desajeita": "desajeitar",
    "desajeitada": "desajeitar",
    "desajeitadas": "desajeitar",
    "desajeitado": "desajeitar",
    "desajeitados": "desajeitar",
    "desajeitai": "desajeitar",
    "desajeitais": "desajeitar",
    "desajeitam": "desajeitar",
    "desajeitamentos": "desajeitamento",
    "desajeitamo": "desajeitar",
    "desajeitamos": "desajeitar",
    "desajeitando": "desajeitar",
    "desajeitara": "desajeitar",
    "desajeitaram": "desajeitar",
    "desajeitaras": "desajeitar",
    "desajeitarde": "desajeitar",
    "desajeitardes": "desajeitar",
    "desajeitare": "desajeitar",
    "desajeitarei": "desajeitar",
    "desajeitareis": "desajeitar",
    "desajeitarem": "desajeitar",
    "desajeitaremos": "desajeitar",
    "desajeitares": "desajeitar",
    "desajeitaria": "desajeitar",
    "desajeitariam": "desajeitar",
    "desajeitarias": "desajeitar",
    "desajeitarmo": "desajeitar",
    "desajeitarmos": "desajeitar",
    "desajeitará": "desajeitar",
    "desajeitarás": "desajeitar",
    "desajeitarão": "desajeitar",
    "desajeitaríamos": "desajeitar",
    "desajeitaríeis": "desajeitar",
    "desajeitas": "desajeitar",
    "desajeitasse": "desajeitar",
    "desajeitassem": "desajeitar",
    "desajeitasses": "desajeitar",
    "desajeitaste": "desajeitar",
    "desajeitastes": "desajeitar",
    "desajeitava": "desajeitar",
    "desajeitavam": "desajeitar",
    "desajeitavas": "desajeitar",
    "desajeite": "desajeitar",
    "desajeitei": "desajeitar",
    "desajeiteis": "desajeitar",
    "desajeitem": "desajeitar",
    "desajeitemo": "desajeitar",
    "desajeitemos": "desajeitar",
    "desajeites": "desajeitar",
    "desajeito": "desajeitar",
    "desajeitou": "desajeitar",
    "desajeitá": "desajeitar",
    "desajeitámo": "desajeitar",
    "desajeitámos": "desajeitar",
    "desajeitáramo": "desajeitar",
    "desajeitáramos": "desajeitar",
    "desajeitárei": "desajeitar",
    "desajeitáreis": "desajeitar",
    "desajeitásseis": "desajeitar",
    "desajeitássemos": "desajeitar",
    "desajeitávamo": "desajeitar",
    "desajeitávamos": "desajeitar",
    "desajeitávei": "desajeitar",
    "desajeitáveis": "desajeitar",
    "desajuda": "desajudar",
    "desajudada": "desajudar",
    "desajudadas": "desajudar",
    "desajudado": "desajudar",
    "desajudados": "desajudar",
    "desajudai": "desajudar",
    "desajudais": "desajudar",
    "desajudam": "desajudar",
    "desajudamo": "desajudar",
    "desajudamos": "desajudar",
    "desajudando": "desajudar",
    "desajudara": "desajudar",
    "desajudaram": "desajudar",
    "desajudaras": "desajudar",
    "desajudarde": "desajudar",
    "desajudardes": "desajudar",
    "desajudare": "desajudar",
    "desajudarei": "desajudar",
    "desajudareis": "desajudar",
    "desajudarem": "desajudar",
    "desajudaremos": "desajudar",
    "desajudares": "desajudar",
    "desajudaria": "desajudar",
    "desajudariam": "desajudar",
    "desajudarias": "desajudar",
    "desajudarmo": "desajudar",
    "desajudarmos": "desajudar",
    "desajudará": "desajudar",
    "desajudarás": "desajudar",
    "desajudarão": "desajudar",
    "desajudaríamos": "desajudar",
    "desajudaríeis": "desajudar",
    "desajudas": "desajudar",
    "desajudasse": "desajudar",
    "desajudassem": "desajudar",
    "desajudasses": "desajudar",
    "desajudaste": "desajudar",
    "desajudastes": "desajudar",
    "desajudava": "desajudar",
    "desajudavam": "desajudar",
    "desajudavas": "desajudar",
    "desajude": "desajudar",
    "desajudei": "desajudar",
    "desajudeis": "desajudar",
    "desajudem": "desajudar",
    "desajudemo": "desajudar",
    "desajudemos": "desajudar",
    "desajudes": "desajudar",
    "desajudo": "desajudar",
    "desajudou": "desajudar",
    "desajudá": "desajudar",
    "desajudámo": "desajudar",
    "desajudámos": "desajudar",
    "desajudáramo": "desajudar",
    "desajudáramos": "desajudar",
    "desajudárei": "desajudar",
    "desajudáreis": "desajudar",
    "desajudásseis": "desajudar",
    "desajudássemos": "desajudar",
    "desajudávamo": "desajudar",
    "desajudávamos": "desajudar",
    "desajudávei": "desajudar",
    "desajudáveis": "desajudar",
    "desajuizada": "desajuizar",
    "desajuizadas": "desajuizar",
    "desajuizado": "desajuizar",
    "desajuizados": "desajuizar",
    "desajuizai": "desajuizar",
    "desajuizais": "desajuizar",
    "desajuizamo": "desajuizar",
    "desajuizamos": "desajuizar",
    "desajuizando": "desajuizar",
    "desajuizara": "desajuizar",
    "desajuizaram": "desajuizar",
    "desajuizaras": "desajuizar",
    "desajuizarde": "desajuizar",
    "desajuizardes": "desajuizar",
    "desajuizare": "desajuizar",
    "desajuizarei": "desajuizar",
    "desajuizareis": "desajuizar",
    "desajuizarem": "desajuizar",
    "desajuizaremos": "desajuizar",
    "desajuizares": "desajuizar",
    "desajuizaria": "desajuizar",
    "desajuizariam": "desajuizar",
    "desajuizarias": "desajuizar",
    "desajuizarmo": "desajuizar",
    "desajuizarmos": "desajuizar",
    "desajuizará": "desajuizar",
    "desajuizarás": "desajuizar",
    "desajuizarão": "desajuizar",
    "desajuizaríamos": "desajuizar",
    "desajuizaríeis": "desajuizar",
    "desajuizasse": "desajuizar",
    "desajuizassem": "desajuizar",
    "desajuizasses": "desajuizar",
    "desajuizaste": "desajuizar",
    "desajuizastes": "desajuizar",
    "desajuizava": "desajuizar",
    "desajuizavam": "desajuizar",
    "desajuizavas": "desajuizar",
    "desajuizei": "desajuizar",
    "desajuizeis": "desajuizar",
    "desajuizemo": "desajuizar",
    "desajuizemos": "desajuizar",
    "desajuizou": "desajuizar",
    "desajuizá": "desajuizar",
    "desajuizámo": "desajuizar",
    "desajuizámos": "desajuizar",
    "desajuizáramo": "desajuizar",
    "desajuizáramos": "desajuizar",
    "desajuizárei": "desajuizar",
    "desajuizáreis": "desajuizar",
    "desajuizásseis": "desajuizar",
    "desajuizássemos": "desajuizar",
    "desajuizávamo": "desajuizar",
    "desajuizávamos": "desajuizar",
    "desajuizávei": "desajuizar",
    "desajuizáveis": "desajuizar",
    "desajunta": "desajuntar",
    "desajuntada": "desajuntar",
    "desajuntadas": "desajuntar",
    "desajuntado": "desajuntar",
    "desajuntados": "desajuntar",
    "desajuntai": "desajuntar",
    "desajuntais": "desajuntar",
    "desajuntam": "desajuntar",
    "desajuntamo": "desajuntar",
    "desajuntamos": "desajuntar",
    "desajuntando": "desajuntar",
    "desajuntara": "desajuntar",
    "desajuntaram": "desajuntar",
    "desajuntaras": "desajuntar",
    "desajuntarde": "desajuntar",
    "desajuntardes": "desajuntar",
    "desajuntare": "desajuntar",
    "desajuntarei": "desajuntar",
    "desajuntareis": "desajuntar",
    "desajuntarem": "desajuntar",
    "desajuntaremos": "desajuntar",
    "desajuntares": "desajuntar",
    "desajuntaria": "desajuntar",
    "desajuntariam": "desajuntar",
    "desajuntarias": "desajuntar",
    "desajuntarmo": "desajuntar",
    "desajuntarmos": "desajuntar",
    "desajuntará": "desajuntar",
    "desajuntarás": "desajuntar",
    "desajuntarão": "desajuntar",
    "desajuntaríamos": "desajuntar",
    "desajuntaríeis": "desajuntar",
    "desajuntas": "desajuntar",
    "desajuntasse": "desajuntar",
    "desajuntassem": "desajuntar",
    "desajuntasses": "desajuntar",
    "desajuntaste": "desajuntar",
    "desajuntastes": "desajuntar",
    "desajuntava": "desajuntar",
    "desajuntavam": "desajuntar",
    "desajuntavas": "desajuntar",
    "desajunte": "desajuntar",
    "desajuntei": "desajuntar",
    "desajunteis": "desajuntar",
    "desajuntem": "desajuntar",
    "desajuntemo": "desajuntar",
    "desajuntemos": "desajuntar",
    "desajuntes": "desajuntar",
    "desajunto": "desajuntar",
    "desajuntou": "desajuntar",
    "desajuntá": "desajuntar",
    "desajuntámo": "desajuntar",
    "desajuntámos": "desajuntar",
    "desajuntáramo": "desajuntar",
    "desajuntáramos": "desajuntar",
    "desajuntárei": "desajuntar",
    "desajuntáreis": "desajuntar",
    "desajuntásseis": "desajuntar",
    "desajuntássemos": "desajuntar",
    "desajuntávamo": "desajuntar",
    "desajuntávamos": "desajuntar",
    "desajuntávei": "desajuntar",
    "desajuntáveis": "desajuntar",
    "desajusta": "desajustar",
    "desajustada": "desajustar",
    "desajustadas": "desajustar",
    "desajustado": "desajustar",
    "desajustados": "desajustar",
    "desajustai": "desajustar",
    "desajustais": "desajustar",
    "desajustam": "desajustar",
    "desajustamentos": "desajustamento",
    "desajustamo": "desajustar",
    "desajustamos": "desajustar",
    "desajustando": "desajustar",
    "desajustara": "desajustar",
    "desajustaram": "desajustar",
    "desajustaras": "desajustar",
    "desajustarde": "desajustar",
    "desajustardes": "desajustar",
    "desajustare": "desajustar",
    "desajustarei": "desajustar",
    "desajustareis": "desajustar",
    "desajustarem": "desajustar",
    "desajustaremos": "desajustar",
    "desajustares": "desajustar",
    "desajustaria": "desajustar",
    "desajustariam": "desajustar",
    "desajustarias": "desajustar",
    "desajustarmo": "desajustar",
    "desajustarmos": "desajustar",
    "desajustará": "desajustar",
    "desajustarás": "desajustar",
    "desajustarão": "desajustar",
    "desajustaríamos": "desajustar",
    "desajustaríeis": "desajustar",
    "desajustas": "desajustar",
    "desajustasse": "desajustar",
    "desajustassem": "desajustar",
    "desajustasses": "desajustar",
    "desajustaste": "desajustar",
    "desajustastes": "desajustar",
    "desajustava": "desajustar",
    "desajustavam": "desajustar",
    "desajustavas": "desajustar",
    "desajuste": "desajustar",
    "desajustei": "desajustar",
    "desajusteis": "desajustar",
    "desajustem": "desajustar",
    "desajustemo": "desajustar",
    "desajustemos": "desajustar",
    "desajustes": "desajuste",
    "desajusto": "desajustar",
    "desajustou": "desajustar",
    "desajustá": "desajustar",
    "desajustámo": "desajustar",
    "desajustámos": "desajustar",
    "desajustáramo": "desajustar",
    "desajustáramos": "desajustar",
    "desajustárei": "desajustar",
    "desajustáreis": "desajustar",
    "desajustásseis": "desajustar",
    "desajustássemos": "desajustar",
    "desajustávamo": "desajustar",
    "desajustávamos": "desajustar",
    "desajustávei": "desajustar",
    "desajustáveis": "desajustar",
    "desajuíza": "desajuizar",
    "desajuízam": "desajuizar",
    "desajuízas": "desajuizar",
    "desajuíze": "desajuizar",
    "desajuízem": "desajuizar",
    "desajuízes": "desajuizar",
    "desajuízo": "desajuizar",
    "desalaga": "desalagar",
    "desalagada": "desalagar",
    "desalagadas": "desalagar",
    "desalagado": "desalagar",
    "desalagados": "desalagar",
    "desalagai": "desalagar",
    "desalagais": "desalagar",
    "desalagam": "desalagar",
    "desalagamo": "desalagar",
    "desalagamos": "desalagar",
    "desalagando": "desalagar",
    "desalagara": "desalagar",
    "desalagaram": "desalagar",
    "desalagaras": "desalagar",
    "desalagarde": "desalagar",
    "desalagardes": "desalagar",
    "desalagare": "desalagar",
    "desalagarei": "desalagar",
    "desalagareis": "desalagar",
    "desalagarem": "desalagar",
    "desalagaremos": "desalagar",
    "desalagares": "desalagar",
    "desalagaria": "desalagar",
    "desalagariam": "desalagar",
    "desalagarias": "desalagar",
    "desalagarmo": "desalagar",
    "desalagarmos": "desalagar",
    "desalagará": "desalagar",
    "desalagarás": "desalagar",
    "desalagarão": "desalagar",
    "desalagaríamos": "desalagar",
    "desalagaríeis": "desalagar",
    "desalagas": "desalagar",
    "desalagasse": "desalagar",
    "desalagassem": "desalagar",
    "desalagasses": "desalagar",
    "desalagaste": "desalagar",
    "desalagastes": "desalagar",
    "desalagava": "desalagar",
    "desalagavam": "desalagar",
    "desalagavas": "desalagar",
    "desalago": "desalagar",
    "desalagou": "desalagar",
    "desalague": "desalagar",
    "desalaguei": "desalagar",
    "desalagueis": "desalagar",
    "desalaguem": "desalagar",
    "desalaguemo": "desalagar",
    "desalaguemos": "desalagar",
    "desalagues": "desalagar",
    "desalagá": "desalagar",
    "desalagámo": "desalagar",
    "desalagámos": "desalagar",
    "desalagáramo": "desalagar",
    "desalagáramos": "desalagar",
    "desalagárei": "desalagar",
    "desalagáreis": "desalagar",
    "desalagásseis": "desalagar",
    "desalagássemos": "desalagar",
    "desalagávamo": "desalagar",
    "desalagávamos": "desalagar",
    "desalagávei": "desalagar",
    "desalagáveis": "desalagar",
    "desalastra": "desalastrar",
    "desalastrada": "desalastrar",
    "desalastradas": "desalastrar",
    "desalastrado": "desalastrar",
    "desalastrados": "desalastrar",
    "desalastrai": "desalastrar",
    "desalastrais": "desalastrar",
    "desalastram": "desalastrar",
    "desalastramo": "desalastrar",
    "desalastramos": "desalastrar",
    "desalastrando": "desalastrar",
    "desalastrara": "desalastrar",
    "desalastraram": "desalastrar",
    "desalastraras": "desalastrar",
    "desalastrarde": "desalastrar",
    "desalastrardes": "desalastrar",
    "desalastrare": "desalastrar",
    "desalastrarei": "desalastrar",
    "desalastrareis": "desalastrar",
    "desalastrarem": "desalastrar",
    "desalastraremos": "desalastrar",
    "desalastrares": "desalastrar",
    "desalastraria": "desalastrar",
    "desalastrariam": "desalastrar",
    "desalastrarias": "desalastrar",
    "desalastrarmo": "desalastrar",
    "desalastrarmos": "desalastrar",
    "desalastrará": "desalastrar",
    "desalastrarás": "desalastrar",
    "desalastrarão": "desalastrar",
    "desalastraríamos": "desalastrar",
    "desalastraríeis": "desalastrar",
    "desalastras": "desalastrar",
    "desalastrasse": "desalastrar",
    "desalastrassem": "desalastrar",
    "desalastrasses": "desalastrar",
    "desalastraste": "desalastrar",
    "desalastrastes": "desalastrar",
    "desalastrava": "desalastrar",
    "desalastravam": "desalastrar",
    "desalastravas": "desalastrar",
    "desalastre": "desalastrar",
    "desalastrei": "desalastrar",
    "desalastreis": "desalastrar",
    "desalastrem": "desalastrar",
    "desalastremo": "desalastrar",
    "desalastremos": "desalastrar",
    "desalastres": "desalastrar",
    "desalastro": "desalastrar",
    "desalastrou": "desalastrar",
    "desalastrá": "desalastrar",
    "desalastrámo": "desalastrar",
    "desalastrámos": "desalastrar",
    "desalastráramo": "desalastrar",
    "desalastráramos": "desalastrar",
    "desalastrárei": "desalastrar",
    "desalastráreis": "desalastrar",
    "desalastrásseis": "desalastrar",
    "desalastrássemos": "desalastrar",
    "desalastrávamo": "desalastrar",
    "desalastrávamos": "desalastrar",
    "desalastrávei": "desalastrar",
    "desalastráveis": "desalastrar",
    "desalbarda": "desalbardar",
    "desalbardada": "desalbardar",
    "desalbardadas": "desalbardar",
    "desalbardado": "desalbardar",
    "desalbardados": "desalbardar",
    "desalbardai": "desalbardar",
    "desalbardais": "desalbardar",
    "desalbardam": "desalbardar",
    "desalbardamo": "desalbardar",
    "desalbardamos": "desalbardar",
    "desalbardando": "desalbardar",
    "desalbardara": "desalbardar",
    "desalbardaram": "desalbardar",
    "desalbardaras": "desalbardar",
    "desalbardarde": "desalbardar",
    "desalbardardes": "desalbardar",
    "desalbardare": "desalbardar",
    "desalbardarei": "desalbardar",
    "desalbardareis": "desalbardar",
    "desalbardarem": "desalbardar",
    "desalbardaremos": "desalbardar",
    "desalbardares": "desalbardar",
    "desalbardaria": "desalbardar",
    "desalbardariam": "desalbardar",
    "desalbardarias": "desalbardar",
    "desalbardarmo": "desalbardar",
    "desalbardarmos": "desalbardar",
    "desalbardará": "desalbardar",
    "desalbardarás": "desalbardar",
    "desalbardarão": "desalbardar",
    "desalbardaríamos": "desalbardar",
    "desalbardaríeis": "desalbardar",
    "desalbardas": "desalbardar",
    "desalbardasse": "desalbardar",
    "desalbardassem": "desalbardar",
    "desalbardasses": "desalbardar",
    "desalbardaste": "desalbardar",
    "desalbardastes": "desalbardar",
    "desalbardava": "desalbardar",
    "desalbardavam": "desalbardar",
    "desalbardavas": "desalbardar",
    "desalbarde": "desalbardar",
    "desalbardei": "desalbardar",
    "desalbardeis": "desalbardar",
    "desalbardem": "desalbardar",
    "desalbardemo": "desalbardar",
    "desalbardemos": "desalbardar",
    "desalbardes": "desalbardar",
    "desalbardo": "desalbardar",
    "desalbardou": "desalbardar",
    "desalbardá": "desalbardar",
    "desalbardámo": "desalbardar",
    "desalbardámos": "desalbardar",
    "desalbardáramo": "desalbardar",
    "desalbardáramos": "desalbardar",
    "desalbardárei": "desalbardar",
    "desalbardáreis": "desalbardar",
    "desalbardásseis": "desalbardar",
    "desalbardássemos": "desalbardar",
    "desalbardávamo": "desalbardar",
    "desalbardávamos": "desalbardar",
    "desalbardávei": "desalbardar",
    "desalbardáveis": "desalbardar",
    "desalegra": "desalegrar",
    "desalegrada": "desalegrar",
    "desalegradas": "desalegrar",
    "desalegrado": "desalegrar",
    "desalegrados": "desalegrar",
    "desalegrai": "desalegrar",
    "desalegrais": "desalegrar",
    "desalegram": "desalegrar",
    "desalegramo": "desalegrar",
    "desalegramos": "desalegrar",
    "desalegrando": "desalegrar",
    "desalegrara": "desalegrar",
    "desalegraram": "desalegrar",
    "desalegraras": "desalegrar",
    "desalegrarde": "desalegrar",
    "desalegrardes": "desalegrar",
    "desalegrare": "desalegrar",
    "desalegrarei": "desalegrar",
    "desalegrareis": "desalegrar",
    "desalegrarem": "desalegrar",
    "desalegraremos": "desalegrar",
    "desalegrares": "desalegrar",
    "desalegraria": "desalegrar",
    "desalegrariam": "desalegrar",
    "desalegrarias": "desalegrar",
    "desalegrarmo": "desalegrar",
    "desalegrarmos": "desalegrar",
    "desalegrará": "desalegrar",
    "desalegrarás": "desalegrar",
    "desalegrarão": "desalegrar",
    "desalegraríamos": "desalegrar",
    "desalegraríeis": "desalegrar",
    "desalegras": "desalegrar",
    "desalegrasse": "desalegrar",
    "desalegrassem": "desalegrar",
    "desalegrasses": "desalegrar",
    "desalegraste": "desalegrar",
    "desalegrastes": "desalegrar",
    "desalegrava": "desalegrar",
    "desalegravam": "desalegrar",
    "desalegravas": "desalegrar",
    "desalegre": "desalegrar",
    "desalegrei": "desalegrar",
    "desalegreis": "desalegrar",
    "desalegrem": "desalegrar",
    "desalegremo": "desalegrar",
    "desalegremos": "desalegrar",
    "desalegres": "desalegrar",
    "desalegro": "desalegrar",
    "desalegrou": "desalegrar",
    "desalegrá": "desalegrar",
    "desalegrámo": "desalegrar",
    "desalegrámos": "desalegrar",
    "desalegráramo": "desalegrar",
    "desalegráramos": "desalegrar",
    "desalegrárei": "desalegrar",
    "desalegráreis": "desalegrar",
    "desalegrásseis": "desalegrar",
    "desalegrássemos": "desalegrar",
    "desalegrávamo": "desalegrar",
    "desalegrávamos": "desalegrar",
    "desalegrávei": "desalegrar",
    "desalegráveis": "desalegrar",
    "desaleita": "desaleitar",
    "desaleitada": "desaleitar",
    "desaleitadas": "desaleitar",
    "desaleitado": "desaleitar",
    "desaleitados": "desaleitar",
    "desaleitai": "desaleitar",
    "desaleitais": "desaleitar",
    "desaleitam": "desaleitar",
    "desaleitamo": "desaleitar",
    "desaleitamos": "desaleitar",
    "desaleitando": "desaleitar",
    "desaleitara": "desaleitar",
    "desaleitaram": "desaleitar",
    "desaleitaras": "desaleitar",
    "desaleitarde": "desaleitar",
    "desaleitardes": "desaleitar",
    "desaleitare": "desaleitar",
    "desaleitarei": "desaleitar",
    "desaleitareis": "desaleitar",
    "desaleitarem": "desaleitar",
    "desaleitaremos": "desaleitar",
    "desaleitares": "desaleitar",
    "desaleitaria": "desaleitar",
    "desaleitariam": "desaleitar",
    "desaleitarias": "desaleitar",
    "desaleitarmo": "desaleitar",
    "desaleitarmos": "desaleitar",
    "desaleitará": "desaleitar",
    "desaleitarás": "desaleitar",
    "desaleitarão": "desaleitar",
    "desaleitaríamos": "desaleitar",
    "desaleitaríeis": "desaleitar",
    "desaleitas": "desaleitar",
    "desaleitasse": "desaleitar",
    "desaleitassem": "desaleitar",
    "desaleitasses": "desaleitar",
    "desaleitaste": "desaleitar",
    "desaleitastes": "desaleitar",
    "desaleitava": "desaleitar",
    "desaleitavam": "desaleitar",
    "desaleitavas": "desaleitar",
    "desaleite": "desaleitar",
    "desaleitei": "desaleitar",
    "desaleiteis": "desaleitar",
    "desaleitem": "desaleitar",
    "desaleitemo": "desaleitar",
    "desaleitemos": "desaleitar",
    "desaleites": "desaleitar",
    "desaleito": "desaleitar",
    "desaleitou": "desaleitar",
    "desaleitá": "desaleitar",
    "desaleitámo": "desaleitar",
    "desaleitámos": "desaleitar",
    "desaleitáramo": "desaleitar",
    "desaleitáramos": "desaleitar",
    "desaleitárei": "desaleitar",
    "desaleitáreis": "desaleitar",
    "desaleitásseis": "desaleitar",
    "desaleitássemos": "desaleitar",
    "desaleitávamo": "desaleitar",
    "desaleitávamos": "desaleitar",
    "desaleitávei": "desaleitar",
    "desaleitáveis": "desaleitar",
    "desalenta": "desalentar",
    "desalentada": "desalentar",
    "desalentadas": "desalentar",
    "desalentado": "desalentar",
    "desalentadora": "desalentador",
    "desalentadoras": "desalentador",
    "desalentadores": "desalentador",
    "desalentados": "desalentar",
    "desalentai": "desalentar",
    "desalentais": "desalentar",
    "desalentam": "desalentar",
    "desalentamo": "desalentar",
    "desalentamos": "desalentar",
    "desalentando": "desalentar",
    "desalentara": "desalentar",
    "desalentaram": "desalentar",
    "desalentaras": "desalentar",
    "desalentarde": "desalentar",
    "desalentardes": "desalentar",
    "desalentare": "desalentar",
    "desalentarei": "desalentar",
    "desalentareis": "desalentar",
    "desalentarem": "desalentar",
    "desalentaremos": "desalentar",
    "desalentares": "desalentar",
    "desalentaria": "desalentar",
    "desalentariam": "desalentar",
    "desalentarias": "desalentar",
    "desalentarmo": "desalentar",
    "desalentarmos": "desalentar",
    "desalentará": "desalentar",
    "desalentarás": "desalentar",
    "desalentarão": "desalentar",
    "desalentaríamos": "desalentar",
    "desalentaríeis": "desalentar",
    "desalentas": "desalentar",
    "desalentasse": "desalentar",
    "desalentassem": "desalentar",
    "desalentasses": "desalentar",
    "desalentaste": "desalentar",
    "desalentastes": "desalentar",
    "desalentava": "desalentar",
    "desalentavam": "desalentar",
    "desalentavas": "desalentar",
    "desalente": "desalentar",
    "desalentei": "desalentar",
    "desalenteis": "desalentar",
    "desalentem": "desalentar",
    "desalentemo": "desalentar",
    "desalentemos": "desalentar",
    "desalentes": "desalentar",
    "desalento": "desalentar",
    "desalentos": "desalento",
    "desalentou": "desalentar",
    "desalentá": "desalentar",
    "desalentámo": "desalentar",
    "desalentámos": "desalentar",
    "desalentáramo": "desalentar",
    "desalentáramos": "desalentar",
    "desalentárei": "desalentar",
    "desalentáreis": "desalentar",
    "desalentásseis": "desalentar",
    "desalentássemos": "desalentar",
    "desalentávamo": "desalentar",
    "desalentávamos": "desalentar",
    "desalentávei": "desalentar",
    "desalentáveis": "desalentar",
    "desalfandega": "desalfandegar",
    "desalfandegada": "desalfandegar",
    "desalfandegadas": "desalfandegar",
    "desalfandegado": "desalfandegar",
    "desalfandegados": "desalfandegar",
    "desalfandegai": "desalfandegar",
    "desalfandegais": "desalfandegar",
    "desalfandegam": "desalfandegar",
    "desalfandegamo": "desalfandegar",
    "desalfandegamos": "desalfandegar",
    "desalfandegando": "desalfandegar",
    "desalfandegara": "desalfandegar",
    "desalfandegaram": "desalfandegar",
    "desalfandegaras": "desalfandegar",
    "desalfandegarde": "desalfandegar",
    "desalfandegardes": "desalfandegar",
    "desalfandegare": "desalfandegar",
    "desalfandegarei": "desalfandegar",
    "desalfandegareis": "desalfandegar",
    "desalfandegarem": "desalfandegar",
    "desalfandegaremos": "desalfandegar",
    "desalfandegares": "desalfandegar",
    "desalfandegaria": "desalfandegar",
    "desalfandegariam": "desalfandegar",
    "desalfandegarias": "desalfandegar",
    "desalfandegarmo": "desalfandegar",
    "desalfandegarmos": "desalfandegar",
    "desalfandegará": "desalfandegar",
    "desalfandegarás": "desalfandegar",
    "desalfandegarão": "desalfandegar",
    "desalfandegaríamos": "desalfandegar",
    "desalfandegaríeis": "desalfandegar",
    "desalfandegas": "desalfandegar",
    "desalfandegasse": "desalfandegar",
    "desalfandegassem": "desalfandegar",
    "desalfandegasses": "desalfandegar",
    "desalfandegaste": "desalfandegar",
    "desalfandegastes": "desalfandegar",
    "desalfandegava": "desalfandegar",
    "desalfandegavam": "desalfandegar",
    "desalfandegavas": "desalfandegar",
    "desalfandego": "desalfandegar",
    "desalfandegou": "desalfandegar",
    "desalfandegue": "desalfandegar",
    "desalfandeguei": "desalfandegar",
    "desalfandegueis": "desalfandegar",
    "desalfandeguem": "desalfandegar",
    "desalfandeguemo": "desalfandegar",
    "desalfandeguemos": "desalfandegar",
    "desalfandegues": "desalfandegar",
    "desalfandegá": "desalfandegar",
    "desalfandegámo": "desalfandegar",
    "desalfandegámos": "desalfandegar",
    "desalfandegáramo": "desalfandegar",
    "desalfandegáramos": "desalfandegar",
    "desalfandegárei": "desalfandegar",
    "desalfandegáreis": "desalfandegar",
    "desalfandegásseis": "desalfandegar",
    "desalfandegássemos": "desalfandegar",
    "desalfandegávamo": "desalfandegar",
    "desalfandegávamos": "desalfandegar",
    "desalfandegávei": "desalfandegar",
    "desalfandegáveis": "desalfandegar",
    "desalgema": "desalgemar",
    "desalgemada": "desalgemar",
    "desalgemadas": "desalgemar",
    "desalgemado": "desalgemar",
    "desalgemados": "desalgemar",
    "desalgemai": "desalgemar",
    "desalgemais": "desalgemar",
    "desalgemam": "desalgemar",
    "desalgemamo": "desalgemar",
    "desalgemamos": "desalgemar",
    "desalgemando": "desalgemar",
    "desalgemara": "desalgemar",
    "desalgemaram": "desalgemar",
    "desalgemaras": "desalgemar",
    "desalgemarde": "desalgemar",
    "desalgemardes": "desalgemar",
    "desalgemare": "desalgemar",
    "desalgemarei": "desalgemar",
    "desalgemareis": "desalgemar",
    "desalgemarem": "desalgemar",
    "desalgemaremos": "desalgemar",
    "desalgemares": "desalgemar",
    "desalgemaria": "desalgemar",
    "desalgemariam": "desalgemar",
    "desalgemarias": "desalgemar",
    "desalgemarmo": "desalgemar",
    "desalgemarmos": "desalgemar",
    "desalgemará": "desalgemar",
    "desalgemarás": "desalgemar",
    "desalgemarão": "desalgemar",
    "desalgemaríamos": "desalgemar",
    "desalgemaríeis": "desalgemar",
    "desalgemas": "desalgemar",
    "desalgemasse": "desalgemar",
    "desalgemassem": "desalgemar",
    "desalgemasses": "desalgemar",
    "desalgemaste": "desalgemar",
    "desalgemastes": "desalgemar",
    "desalgemava": "desalgemar",
    "desalgemavam": "desalgemar",
    "desalgemavas": "desalgemar",
    "desalgeme": "desalgemar",
    "desalgemei": "desalgemar",
    "desalgemeis": "desalgemar",
    "desalgemem": "desalgemar",
    "desalgememo": "desalgemar",
    "desalgememos": "desalgemar",
    "desalgemes": "desalgemar",
    "desalgemo": "desalgemar",
    "desalgemou": "desalgemar",
    "desalgemá": "desalgemar",
    "desalgemámo": "desalgemar",
    "desalgemámos": "desalgemar",
    "desalgemáramo": "desalgemar",
    "desalgemáramos": "desalgemar",
    "desalgemárei": "desalgemar",
    "desalgemáreis": "desalgemar",
    "desalgemásseis": "desalgemar",
    "desalgemássemos": "desalgemar",
    "desalgemávamo": "desalgemar",
    "desalgemávamos": "desalgemar",
    "desalgemávei": "desalgemar",
    "desalgemáveis": "desalgemar",
    "desalia": "desaliar",
    "desaliada": "desaliar",
    "desaliadas": "desaliar",
    "desaliado": "desaliar",
    "desaliados": "desaliar",
    "desaliai": "desaliar",
    "desaliais": "desaliar",
    "desaliam": "desaliar",
    "desaliamo": "desaliar",
    "desaliamos": "desaliar",
    "desaliando": "desaliar",
    "desalianças": "desaliança",
    "desaliara": "desaliar",
    "desaliaram": "desaliar",
    "desaliaras": "desaliar",
    "desaliarde": "desaliar",
    "desaliardes": "desaliar",
    "desaliare": "desaliar",
    "desaliarei": "desaliar",
    "desaliareis": "desaliar",
    "desaliarem": "desaliar",
    "desaliaremos": "desaliar",
    "desaliares": "desaliar",
    "desaliaria": "desaliar",
    "desaliariam": "desaliar",
    "desaliarias": "desaliar",
    "desaliarmo": "desaliar",
    "desaliarmos": "desaliar",
    "desaliará": "desaliar",
    "desaliarás": "desaliar",
    "desaliarão": "desaliar",
    "desaliaríamos": "desaliar",
    "desaliaríeis": "desaliar",
    "desalias": "desaliar",
    "desaliasse": "desaliar",
    "desaliassem": "desaliar",
    "desaliasses": "desaliar",
    "desaliaste": "desaliar",
    "desaliastes": "desaliar",
    "desaliava": "desaliar",
    "desaliavam": "desaliar",
    "desaliavas": "desaliar",
    "desalie": "desaliar",
    "desaliei": "desaliar",
    "desalieis": "desaliar",
    "desaliem": "desaliar",
    "desaliemo": "desaliar",
    "desaliemos": "desaliar",
    "desalies": "desaliar",
    "desalinha": "desalinhar",
    "desalinhada": "desalinhar",
    "desalinhadas": "desalinhar",
    "desalinhado": "desalinhar",
    "desalinhados": "desalinhar",
    "desalinhai": "desalinhar",
    "desalinhais": "desalinhar",
    "desalinham": "desalinhar",
    "desalinhamo": "desalinhar",
    "desalinhamos": "desalinhar",
    "desalinhando": "desalinhar",
    "desalinhara": "desalinhar",
    "desalinharam": "desalinhar",
    "desalinharas": "desalinhar",
    "desalinharde": "desalinhar",
    "desalinhardes": "desalinhar",
    "desalinhare": "desalinhar",
    "desalinharei": "desalinhar",
    "desalinhareis": "desalinhar",
    "desalinharem": "desalinhar",
    "desalinharemos": "desalinhar",
    "desalinhares": "desalinhar",
    "desalinharia": "desalinhar",
    "desalinhariam": "desalinhar",
    "desalinharias": "desalinhar",
    "desalinharmo": "desalinhar",
    "desalinharmos": "desalinhar",
    "desalinhará": "desalinhar",
    "desalinharás": "desalinhar",
    "desalinharão": "desalinhar",
    "desalinharíamos": "desalinhar",
    "desalinharíeis": "desalinhar",
    "desalinhas": "desalinhar",
    "desalinhasse": "desalinhar",
    "desalinhassem": "desalinhar",
    "desalinhasses": "desalinhar",
    "desalinhaste": "desalinhar",
    "desalinhastes": "desalinhar",
    "desalinhava": "desalinhavar",
    "desalinhavada": "desalinhavar",
    "desalinhavadas": "desalinhavar",
    "desalinhavado": "desalinhavar",
    "desalinhavados": "desalinhavar",
    "desalinhavai": "desalinhavar",
    "desalinhavais": "desalinhavar",
    "desalinhavam": "desalinhavar",
    "desalinhavamo": "desalinhavar",
    "desalinhavamos": "desalinhavar",
    "desalinhavando": "desalinhavar",
    "desalinhavara": "desalinhavar",
    "desalinhavaram": "desalinhavar",
    "desalinhavaras": "desalinhavar",
    "desalinhavarde": "desalinhavar",
    "desalinhavardes": "desalinhavar",
    "desalinhavare": "desalinhavar",
    "desalinhavarei": "desalinhavar",
    "desalinhavareis": "desalinhavar",
    "desalinhavarem": "desalinhavar",
    "desalinhavaremos": "desalinhavar",
    "desalinhavares": "desalinhavar",
    "desalinhavaria": "desalinhavar",
    "desalinhavariam": "desalinhavar",
    "desalinhavarias": "desalinhavar",
    "desalinhavarmo": "desalinhavar",
    "desalinhavarmos": "desalinhavar",
    "desalinhavará": "desalinhavar",
    "desalinhavarás": "desalinhavar",
    "desalinhavarão": "desalinhavar",
    "desalinhavaríamos": "desalinhavar",
    "desalinhavaríeis": "desalinhavar",
    "desalinhavas": "desalinhavar",
    "desalinhavasse": "desalinhavar",
    "desalinhavassem": "desalinhavar",
    "desalinhavasses": "desalinhavar",
    "desalinhavaste": "desalinhavar",
    "desalinhavastes": "desalinhavar",
    "desalinhavava": "desalinhavar",
    "desalinhavavam": "desalinhavar",
    "desalinhavavas": "desalinhavar",
    "desalinhave": "desalinhavar",
    "desalinhavei": "desalinhavar",
    "desalinhaveis": "desalinhavar",
    "desalinhavem": "desalinhavar",
    "desalinhavemo": "desalinhavar",
    "desalinhavemos": "desalinhavar",
    "desalinhaves": "desalinhavar",
    "desalinhavo": "desalinhavar",
    "desalinhavou": "desalinhavar",
    "desalinhavá": "desalinhavar",
    "desalinhavámo": "desalinhavar",
    "desalinhavámos": "desalinhavar",
    "desalinhaváramo": "desalinhavar",
    "desalinhaváramos": "desalinhavar",
    "desalinhavárei": "desalinhavar",
    "desalinhaváreis": "desalinhavar",
    "desalinhavásseis": "desalinhavar",
    "desalinhavássemos": "desalinhavar",
    "desalinhavávamo": "desalinhavar",
    "desalinhavávamos": "desalinhavar",
    "desalinhavávei": "desalinhavar",
    "desalinhaváveis": "desalinhavar",
    "desalinhe": "desalinhar",
    "desalinhei": "desalinhar",
    "desalinheis": "desalinhar",
    "desalinhem": "desalinhar",
    "desalinhemo": "desalinhar",
    "desalinhemos": "desalinhar",
    "desalinhes": "desalinhar",
    "desalinho": "desalinhar",
    "desalinhos": "desalinho",
    "desalinhou": "desalinhar",
    "desalinhá": "desalinhar",
    "desalinhámo": "desalinhar",
    "desalinhámos": "desalinhar",
    "desalinháramo": "desalinhar",
    "desalinháramos": "desalinhar",
    "desalinhárei": "desalinhar",
    "desalinháreis": "desalinhar",
    "desalinhásseis": "desalinhar",
    "desalinhássemos": "desalinhar",
    "desalinhávamo": "desalinhar",
    "desalinhávamos": "desalinhar",
    "desalinhávei": "desalinhar",
    "desalinháveis": "desalinhar",
    "desalio": "desaliar",
    "desaliou": "desaliar",
    "desalista": "desalistar",
    "desalistada": "desalistar",
    "desalistadas": "desalistar",
    "desalistado": "desalistar",
    "desalistados": "desalistar",
    "desalistai": "desalistar",
    "desalistais": "desalistar",
    "desalistam": "desalistar",
    "desalistamo": "desalistar",
    "desalistamos": "desalistar",
    "desalistando": "desalistar",
    "desalistara": "desalistar",
    "desalistaram": "desalistar",
    "desalistaras": "desalistar",
    "desalistarde": "desalistar",
    "desalistardes": "desalistar",
    "desalistare": "desalistar",
    "desalistarei": "desalistar",
    "desalistareis": "desalistar",
    "desalistarem": "desalistar",
    "desalistaremos": "desalistar",
    "desalistares": "desalistar",
    "desalistaria": "desalistar",
    "desalistariam": "desalistar",
    "desalistarias": "desalistar",
    "desalistarmo": "desalistar",
    "desalistarmos": "desalistar",
    "desalistará": "desalistar",
    "desalistarás": "desalistar",
    "desalistarão": "desalistar",
    "desalistaríamos": "desalistar",
    "desalistaríeis": "desalistar",
    "desalistas": "desalistar",
    "desalistasse": "desalistar",
    "desalistassem": "desalistar",
    "desalistasses": "desalistar",
    "desalistaste": "desalistar",
    "desalistastes": "desalistar",
    "desalistava": "desalistar",
    "desalistavam": "desalistar",
    "desalistavas": "desalistar",
    "desaliste": "desalistar",
    "desalistei": "desalistar",
    "desalisteis": "desalistar",
    "desalistem": "desalistar",
    "desalistemo": "desalistar",
    "desalistemos": "desalistar",
    "desalistes": "desalistar",
    "desalisto": "desalistar",
    "desalistou": "desalistar",
    "desalistá": "desalistar",
    "desalistámo": "desalistar",
    "desalistámos": "desalistar",
    "desalistáramo": "desalistar",
    "desalistáramos": "desalistar",
    "desalistárei": "desalistar",
    "desalistáreis": "desalistar",
    "desalistásseis": "desalistar",
    "desalistássemos": "desalistar",
    "desalistávamo": "desalistar",
    "desalistávamos": "desalistar",
    "desalistávei": "desalistar",
    "desalistáveis": "desalistar",
    "desaliá": "desaliar",
    "desaliámo": "desaliar",
    "desaliámos": "desaliar",
    "desaliáramo": "desaliar",
    "desaliáramos": "desaliar",
    "desaliárei": "desaliar",
    "desaliáreis": "desaliar",
    "desaliásseis": "desaliar",
    "desaliássemos": "desaliar",
    "desaliávamo": "desaliar",
    "desaliávamos": "desaliar",
    "desaliávei": "desaliar",
    "desaliáveis": "desaliar",
    "desalma": "desalmar",
    "desalmada": "desalmar",
    "desalmadas": "desalmar",
    "desalmado": "desalmar",
    "desalmados": "desalmar",
    "desalmai": "desalmar",
    "desalmais": "desalmar",
    "desalmam": "desalmar",
    "desalmamentos": "desalmamento",
    "desalmamo": "desalmar",
    "desalmamos": "desalmar",
    "desalmando": "desalmar",
    "desalmara": "desalmar",
    "desalmaram": "desalmar",
    "desalmaras": "desalmar",
    "desalmarde": "desalmar",
    "desalmardes": "desalmar",
    "desalmare": "desalmar",
    "desalmarei": "desalmar",
    "desalmareis": "desalmar",
    "desalmarem": "desalmar",
    "desalmaremos": "desalmar",
    "desalmares": "desalmar",
    "desalmaria": "desalmar",
    "desalmariam": "desalmar",
    "desalmarias": "desalmar",
    "desalmarmo": "desalmar",
    "desalmarmos": "desalmar",
    "desalmará": "desalmar",
    "desalmarás": "desalmar",
    "desalmarão": "desalmar",
    "desalmaríamos": "desalmar",
    "desalmaríeis": "desalmar",
    "desalmas": "desalmar",
    "desalmasse": "desalmar",
    "desalmassem": "desalmar",
    "desalmasses": "desalmar",
    "desalmaste": "desalmar",
    "desalmastes": "desalmar",
    "desalmava": "desalmar",
    "desalmavam": "desalmar",
    "desalmavas": "desalmar",
    "desalme": "desalmar",
    "desalmei": "desalmar",
    "desalmeis": "desalmar",
    "desalmem": "desalmar",
    "desalmemo": "desalmar",
    "desalmemos": "desalmar",
    "desalmes": "desalmar",
    "desalmo": "desalmar",
    "desalmou": "desalmar",
    "desalmá": "desalmar",
    "desalmámo": "desalmar",
    "desalmámos": "desalmar",
    "desalmáramo": "desalmar",
    "desalmáramos": "desalmar",
    "desalmárei": "desalmar",
    "desalmáreis": "desalmar",
    "desalmásseis": "desalmar",
    "desalmássemos": "desalmar",
    "desalmávamo": "desalmar",
    "desalmávamos": "desalmar",
    "desalmávei": "desalmar",
    "desalmáveis": "desalmar",
    "desaloja": "desalojar",
    "desalojada": "desalojar",
    "desalojadas": "desalojar",
    "desalojado": "desalojar",
    "desalojados": "desalojar",
    "desalojai": "desalojar",
    "desalojais": "desalojar",
    "desalojam": "desalojar",
    "desalojamentos": "desalojamento",
    "desalojamo": "desalojar",
    "desalojamos": "desalojar",
    "desalojando": "desalojar",
    "desalojara": "desalojar",
    "desalojaram": "desalojar",
    "desalojaras": "desalojar",
    "desalojarde": "desalojar",
    "desalojardes": "desalojar",
    "desalojare": "desalojar",
    "desalojarei": "desalojar",
    "desalojareis": "desalojar",
    "desalojarem": "desalojar",
    "desalojaremos": "desalojar",
    "desalojares": "desalojar",
    "desalojaria": "desalojar",
    "desalojariam": "desalojar",
    "desalojarias": "desalojar",
    "desalojarmo": "desalojar",
    "desalojarmos": "desalojar",
    "desalojará": "desalojar",
    "desalojarás": "desalojar",
    "desalojarão": "desalojar",
    "desalojaríamos": "desalojar",
    "desalojaríeis": "desalojar",
    "desalojas": "desalojar",
    "desalojasse": "desalojar",
    "desalojassem": "desalojar",
    "desalojasses": "desalojar",
    "desalojaste": "desalojar",
    "desalojastes": "desalojar",
    "desalojava": "desalojar",
    "desalojavam": "desalojar",
    "desalojavas": "desalojar",
    "desaloje": "desalojar",
    "desalojei": "desalojar",
    "desalojeis": "desalojar",
    "desalojem": "desalojar",
    "desalojemo": "desalojar",
    "desalojemos": "desalojar",
    "desalojes": "desalojar",
    "desalojo": "desalojar",
    "desalojou": "desalojar",
    "desalojá": "desalojar",
    "desalojámo": "desalojar",
    "desalojámos": "desalojar",
    "desalojáramo": "desalojar",
    "desalojáramos": "desalojar",
    "desalojárei": "desalojar",
    "desalojáreis": "desalojar",
    "desalojásseis": "desalojar",
    "desalojássemos": "desalojar",
    "desalojávamo": "desalojar",
    "desalojávamos": "desalojar",
    "desalojávei": "desalojar",
    "desalojáveis": "desalojar",
    "desaltera": "desalterar",
    "desalterada": "desalterar",
    "desalteradas": "desalterar",
    "desalterado": "desalterar",
    "desalterados": "desalterar",
    "desalterai": "desalterar",
    "desalterais": "desalterar",
    "desalteram": "desalterar",
    "desalteramo": "desalterar",
    "desalteramos": "desalterar",
    "desalterando": "desalterar",
    "desalterara": "desalterar",
    "desalteraram": "desalterar",
    "desalteraras": "desalterar",
    "desalterarde": "desalterar",
    "desalterardes": "desalterar",
    "desalterare": "desalterar",
    "desalterarei": "desalterar",
    "desalterareis": "desalterar",
    "desalterarem": "desalterar",
    "desalteraremos": "desalterar",
    "desalterares": "desalterar",
    "desalteraria": "desalterar",
    "desalterariam": "desalterar",
    "desalterarias": "desalterar",
    "desalterarmo": "desalterar",
    "desalterarmos": "desalterar",
    "desalterará": "desalterar",
    "desalterarás": "desalterar",
    "desalterarão": "desalterar",
    "desalteraríamos": "desalterar",
    "desalteraríeis": "desalterar",
    "desalteras": "desalterar",
    "desalterasse": "desalterar",
    "desalterassem": "desalterar",
    "desalterasses": "desalterar",
    "desalteraste": "desalterar",
    "desalterastes": "desalterar",
    "desalterava": "desalterar",
    "desalteravam": "desalterar",
    "desalteravas": "desalterar",
    "desaltere": "desalterar",
    "desalterei": "desalterar",
    "desaltereis": "desalterar",
    "desalterem": "desalterar",
    "desalteremo": "desalterar",
    "desalteremos": "desalterar",
    "desalteres": "desalterar",
    "desaltero": "desalterar",
    "desalterou": "desalterar",
    "desalterá": "desalterar",
    "desalterámo": "desalterar",
    "desalterámos": "desalterar",
    "desalteráramo": "desalterar",
    "desalteráramos": "desalterar",
    "desalterárei": "desalterar",
    "desalteráreis": "desalterar",
    "desalterásseis": "desalterar",
    "desalterássemos": "desalterar",
    "desalterávamo": "desalterar",
    "desalterávamos": "desalterar",
    "desalterávei": "desalterar",
    "desalteráveis": "desalterar",
    "desaluga": "desalugar",
    "desalugada": "desalugar",
    "desalugadas": "desalugar",
    "desalugado": "desalugar",
    "desalugados": "desalugar",
    "desalugai": "desalugar",
    "desalugais": "desalugar",
    "desalugam": "desalugar",
    "desalugamo": "desalugar",
    "desalugamos": "desalugar",
    "desalugando": "desalugar",
    "desalugara": "desalugar",
    "desalugaram": "desalugar",
    "desalugaras": "desalugar",
    "desalugarde": "desalugar",
    "desalugardes": "desalugar",
    "desalugare": "desalugar",
    "desalugarei": "desalugar",
    "desalugareis": "desalugar",
    "desalugarem": "desalugar",
    "desalugaremos": "desalugar",
    "desalugares": "desalugar",
    "desalugaria": "desalugar",
    "desalugariam": "desalugar",
    "desalugarias": "desalugar",
    "desalugarmo": "desalugar",
    "desalugarmos": "desalugar",
    "desalugará": "desalugar",
    "desalugarás": "desalugar",
    "desalugarão": "desalugar",
    "desalugaríamos": "desalugar",
    "desalugaríeis": "desalugar",
    "desalugas": "desalugar",
    "desalugasse": "desalugar",
    "desalugassem": "desalugar",
    "desalugasses": "desalugar",
    "desalugaste": "desalugar",
    "desalugastes": "desalugar",
    "desalugava": "desalugar",
    "desalugavam": "desalugar",
    "desalugavas": "desalugar",
    "desalugo": "desalugar",
    "desalugou": "desalugar",
    "desalugue": "desalugar",
    "desaluguei": "desalugar",
    "desalugueis": "desalugar",
    "desaluguem": "desalugar",
    "desaluguemo": "desalugar",
    "desaluguemos": "desalugar",
    "desalugues": "desalugar",
    "desalugá": "desalugar",
    "desalugámo": "desalugar",
    "desalugámos": "desalugar",
    "desalugáramo": "desalugar",
    "desalugáramos": "desalugar",
    "desalugárei": "desalugar",
    "desalugáreis": "desalugar",
    "desalugásseis": "desalugar",
    "desalugássemos": "desalugar",
    "desalugávamo": "desalugar",
    "desalugávamos": "desalugar",
    "desalugávei": "desalugar",
    "desalugáveis": "desalugar",
    "desalumiada": "desalumiado",
    "desalumiadas": "desalumiado",
    "desalumiados": "desalumiado",
    "desalvora": "desalvorar",
    "desalvorada": "desalvorar",
    "desalvoradas": "desalvorar",
    "desalvorado": "desalvorar",
    "desalvorados": "desalvorar",
    "desalvorai": "desalvorar",
    "desalvorais": "desalvorar",
    "desalvoram": "desalvorar",
    "desalvoramo": "desalvorar",
    "desalvoramos": "desalvorar",
    "desalvorando": "desalvorar",
    "desalvorara": "desalvorar",
    "desalvoraram": "desalvorar",
    "desalvoraras": "desalvorar",
    "desalvorarde": "desalvorar",
    "desalvorardes": "desalvorar",
    "desalvorare": "desalvorar",
    "desalvorarei": "desalvorar",
    "desalvorareis": "desalvorar",
    "desalvorarem": "desalvorar",
    "desalvoraremos": "desalvorar",
    "desalvorares": "desalvorar",
    "desalvoraria": "desalvorar",
    "desalvorariam": "desalvorar",
    "desalvorarias": "desalvorar",
    "desalvorarmo": "desalvorar",
    "desalvorarmos": "desalvorar",
    "desalvorará": "desalvorar",
    "desalvorarás": "desalvorar",
    "desalvorarão": "desalvorar",
    "desalvoraríamos": "desalvorar",
    "desalvoraríeis": "desalvorar",
    "desalvoras": "desalvorar",
    "desalvorasse": "desalvorar",
    "desalvorassem": "desalvorar",
    "desalvorasses": "desalvorar",
    "desalvoraste": "desalvorar",
    "desalvorastes": "desalvorar",
    "desalvorava": "desalvorar",
    "desalvoravam": "desalvorar",
    "desalvoravas": "desalvorar",
    "desalvore": "desalvorar",
    "desalvorei": "desalvorar",
    "desalvoreis": "desalvorar",
    "desalvorem": "desalvorar",
    "desalvoremo": "desalvorar",
    "desalvoremos": "desalvorar",
    "desalvores": "desalvorar",
    "desalvoro": "desalvorar",
    "desalvorou": "desalvorar",
    "desalvorá": "desalvorar",
    "desalvorámo": "desalvorar",
    "desalvorámos": "desalvorar",
    "desalvoráramo": "desalvorar",
    "desalvoráramos": "desalvorar",
    "desalvorárei": "desalvorar",
    "desalvoráreis": "desalvorar",
    "desalvorásseis": "desalvorar",
    "desalvorássemos": "desalvorar",
    "desalvorávamo": "desalvorar",
    "desalvorávamos": "desalvorar",
    "desalvorávei": "desalvorar",
    "desalvoráveis": "desalvorar",
    "desama": "desamar",
    "desamabilidades": "desamabilidade",
    "desamada": "desamar",
    "desamadas": "desamar",
    "desamado": "desamar",
    "desamadora": "desamador",
    "desamadoras": "desamador",
    "desamadores": "desamador",
    "desamados": "desamar",
    "desamai": "desamar",
    "desamais": "desamar",
    "desamalgama": "desamalgamar",
    "desamalgamada": "desamalgamar",
    "desamalgamadas": "desamalgamar",
    "desamalgamado": "desamalgamar",
    "desamalgamados": "desamalgamar",
    "desamalgamai": "desamalgamar",
    "desamalgamais": "desamalgamar",
    "desamalgamam": "desamalgamar",
    "desamalgamamo": "desamalgamar",
    "desamalgamamos": "desamalgamar",
    "desamalgamando": "desamalgamar",
    "desamalgamara": "desamalgamar",
    "desamalgamaram": "desamalgamar",
    "desamalgamaras": "desamalgamar",
    "desamalgamarde": "desamalgamar",
    "desamalgamardes": "desamalgamar",
    "desamalgamare": "desamalgamar",
    "desamalgamarei": "desamalgamar",
    "desamalgamareis": "desamalgamar",
    "desamalgamarem": "desamalgamar",
    "desamalgamaremos": "desamalgamar",
    "desamalgamares": "desamalgamar",
    "desamalgamaria": "desamalgamar",
    "desamalgamariam": "desamalgamar",
    "desamalgamarias": "desamalgamar",
    "desamalgamarmo": "desamalgamar",
    "desamalgamarmos": "desamalgamar",
    "desamalgamará": "desamalgamar",
    "desamalgamarás": "desamalgamar",
    "desamalgamarão": "desamalgamar",
    "desamalgamaríamos": "desamalgamar",
    "desamalgamaríeis": "desamalgamar",
    "desamalgamas": "desamalgamar",
    "desamalgamasse": "desamalgamar",
    "desamalgamassem": "desamalgamar",
    "desamalgamasses": "desamalgamar",
    "desamalgamaste": "desamalgamar",
    "desamalgamastes": "desamalgamar",
    "desamalgamava": "desamalgamar",
    "desamalgamavam": "desamalgamar",
    "desamalgamavas": "desamalgamar",
    "desamalgame": "desamalgamar",
    "desamalgamei": "desamalgamar",
    "desamalgameis": "desamalgamar",
    "desamalgamem": "desamalgamar",
    "desamalgamemo": "desamalgamar",
    "desamalgamemos": "desamalgamar",
    "desamalgames": "desamalgamar",
    "desamalgamo": "desamalgamar",
    "desamalgamou": "desamalgamar",
    "desamalgamá": "desamalgamar",
    "desamalgamámo": "desamalgamar",
    "desamalgamámos": "desamalgamar",
    "desamalgamáramo": "desamalgamar",
    "desamalgamáramos": "desamalgamar",
    "desamalgamárei": "desamalgamar",
    "desamalgamáreis": "desamalgamar",
    "desamalgamásseis": "desamalgamar",
    "desamalgamássemos": "desamalgamar",
    "desamalgamávamo": "desamalgamar",
    "desamalgamávamos": "desamalgamar",
    "desamalgamávei": "desamalgamar",
    "desamalgamáveis": "desamalgamar",
    "desamam": "desamar",
    "desamamenta": "desamamentar",
    "desamamentada": "desamamentar",
    "desamamentadas": "desamamentar",
    "desamamentado": "desamamentar",
    "desamamentados": "desamamentar",
    "desamamentai": "desamamentar",
    "desamamentais": "desamamentar",
    "desamamentam": "desamamentar",
    "desamamentamo": "desamamentar",
    "desamamentamos": "desamamentar",
    "desamamentando": "desamamentar",
    "desamamentara": "desamamentar",
    "desamamentaram": "desamamentar",
    "desamamentaras": "desamamentar",
    "desamamentarde": "desamamentar",
    "desamamentardes": "desamamentar",
    "desamamentare": "desamamentar",
    "desamamentarei": "desamamentar",
    "desamamentareis": "desamamentar",
    "desamamentarem": "desamamentar",
    "desamamentaremos": "desamamentar",
    "desamamentares": "desamamentar",
    "desamamentaria": "desamamentar",
    "desamamentariam": "desamamentar",
    "desamamentarias": "desamamentar",
    "desamamentarmo": "desamamentar",
    "desamamentarmos": "desamamentar",
    "desamamentará": "desamamentar",
    "desamamentarás": "desamamentar",
    "desamamentarão": "desamamentar",
    "desamamentaríamos": "desamamentar",
    "desamamentaríeis": "desamamentar",
    "desamamentas": "desamamentar",
    "desamamentasse": "desamamentar",
    "desamamentassem": "desamamentar",
    "desamamentasses": "desamamentar",
    "desamamentaste": "desamamentar",
    "desamamentastes": "desamamentar",
    "desamamentava": "desamamentar",
    "desamamentavam": "desamamentar",
    "desamamentavas": "desamamentar",
    "desamamente": "desamamentar",
    "desamamentei": "desamamentar",
    "desamamenteis": "desamamentar",
    "desamamentem": "desamamentar",
    "desamamentemo": "desamamentar",
    "desamamentemos": "desamamentar",
    "desamamentes": "desamamentar",
    "desamamento": "desamamentar",
    "desamamentou": "desamamentar",
    "desamamentá": "desamamentar",
    "desamamentámo": "desamamentar",
    "desamamentámos": "desamamentar",
    "desamamentáramo": "desamamentar",
    "desamamentáramos": "desamamentar",
    "desamamentárei": "desamamentar",
    "desamamentáreis": "desamamentar",
    "desamamentásseis": "desamamentar",
    "desamamentássemos": "desamamentar",
    "desamamentávamo": "desamamentar",
    "desamamentávamos": "desamamentar",
    "desamamentávei": "desamamentar",
    "desamamentáveis": "desamamentar",
    "desamamo": "desamar",
    "desamamos": "desamar",
    "desamando": "desamar",
    "desamanha": "desamanhar",
    "desamanhada": "desamanhar",
    "desamanhadas": "desamanhar",
    "desamanhado": "desamanhar",
    "desamanhados": "desamanhar",
    "desamanhai": "desamanhar",
    "desamanhais": "desamanhar",
    "desamanham": "desamanhar",
    "desamanhamo": "desamanhar",
    "desamanhamos": "desamanhar",
    "desamanhando": "desamanhar",
    "desamanhara": "desamanhar",
    "desamanharam": "desamanhar",
    "desamanharas": "desamanhar",
    "desamanharde": "desamanhar",
    "desamanhardes": "desamanhar",
    "desamanhare": "desamanhar",
    "desamanharei": "desamanhar",
    "desamanhareis": "desamanhar",
    "desamanharem": "desamanhar",
    "desamanharemos": "desamanhar",
    "desamanhares": "desamanhar",
    "desamanharia": "desamanhar",
    "desamanhariam": "desamanhar",
    "desamanharias": "desamanhar",
    "desamanharmo": "desamanhar",
    "desamanharmos": "desamanhar",
    "desamanhará": "desamanhar",
    "desamanharás": "desamanhar",
    "desamanharão": "desamanhar",
    "desamanharíamos": "desamanhar",
    "desamanharíeis": "desamanhar",
    "desamanhas": "desamanhar",
    "desamanhasse": "desamanhar",
    "desamanhassem": "desamanhar",
    "desamanhasses": "desamanhar",
    "desamanhaste": "desamanhar",
    "desamanhastes": "desamanhar",
    "desamanhava": "desamanhar",
    "desamanhavam": "desamanhar",
    "desamanhavas": "desamanhar",
    "desamanhe": "desamanhar",
    "desamanhei": "desamanhar",
    "desamanheis": "desamanhar",
    "desamanhem": "desamanhar",
    "desamanhemo": "desamanhar",
    "desamanhemos": "desamanhar",
    "desamanhes": "desamanhar",
    "desamanho": "desamanhar",
    "desamanhos": "desamanho",
    "desamanhou": "desamanhar",
    "desamanhá": "desamanhar",
    "desamanhámo": "desamanhar",
    "desamanhámos": "desamanhar",
    "desamanháramo": "desamanhar",
    "desamanháramos": "desamanhar",
    "desamanhárei": "desamanhar",
    "desamanháreis": "desamanhar",
    "desamanhásseis": "desamanhar",
    "desamanhássemos": "desamanhar",
    "desamanhávamo": "desamanhar",
    "desamanhávamos": "desamanhar",
    "desamanhávei": "desamanhar",
    "desamanháveis": "desamanhar",
    "desamantilha": "desamantilhar",
    "desamantilhada": "desamantilhar",
    "desamantilhadas": "desamantilhar",
    "desamantilhado": "desamantilhar",
    "desamantilhados": "desamantilhar",
    "desamantilhai": "desamantilhar",
    "desamantilhais": "desamantilhar",
    "desamantilham": "desamantilhar",
    "desamantilhamo": "desamantilhar",
    "desamantilhamos": "desamantilhar",
    "desamantilhando": "desamantilhar",
    "desamantilhara": "desamantilhar",
    "desamantilharam": "desamantilhar",
    "desamantilharas": "desamantilhar",
    "desamantilharde": "desamantilhar",
    "desamantilhardes": "desamantilhar",
    "desamantilhare": "desamantilhar",
    "desamantilharei": "desamantilhar",
    "desamantilhareis": "desamantilhar",
    "desamantilharem": "desamantilhar",
    "desamantilharemos": "desamantilhar",
    "desamantilhares": "desamantilhar",
    "desamantilharia": "desamantilhar",
    "desamantilhariam": "desamantilhar",
    "desamantilharias": "desamantilhar",
    "desamantilharmo": "desamantilhar",
    "desamantilharmos": "desamantilhar",
    "desamantilhará": "desamantilhar",
    "desamantilharás": "desamantilhar",
    "desamantilharão": "desamantilhar",
    "desamantilharíamos": "desamantilhar",
    "desamantilharíeis": "desamantilhar",
    "desamantilhas": "desamantilhar",
    "desamantilhasse": "desamantilhar",
    "desamantilhassem": "desamantilhar",
    "desamantilhasses": "desamantilhar",
    "desamantilhaste": "desamantilhar",
    "desamantilhastes": "desamantilhar",
    "desamantilhava": "desamantilhar",
    "desamantilhavam": "desamantilhar",
    "desamantilhavas": "desamantilhar",
    "desamantilhe": "desamantilhar",
    "desamantilhei": "desamantilhar",
    "desamantilheis": "desamantilhar",
    "desamantilhem": "desamantilhar",
    "desamantilhemo": "desamantilhar",
    "desamantilhemos": "desamantilhar",
    "desamantilhes": "desamantilhar",
    "desamantilho": "desamantilhar",
    "desamantilhou": "desamantilhar",
    "desamantilhá": "desamantilhar",
    "desamantilhámo": "desamantilhar",
    "desamantilhámos": "desamantilhar",
    "desamantilháramo": "desamantilhar",
    "desamantilháramos": "desamantilhar",
    "desamantilhárei": "desamantilhar",
    "desamantilháreis": "desamantilhar",
    "desamantilhásseis": "desamantilhar",
    "desamantilhássemos": "desamantilhar",
    "desamantilhávamo": "desamantilhar",
    "desamantilhávamos": "desamantilhar",
    "desamantilhávei": "desamantilhar",
    "desamantilháveis": "desamantilhar",
    "desamara": "desamar",
    "desamaram": "desamar",
    "desamaras": "desamar",
    "desamarde": "desamar",
    "desamardes": "desamar",
    "desamare": "desamar",
    "desamarei": "desamar",
    "desamareis": "desamar",
    "desamarem": "desamar",
    "desamaremos": "desamar",
    "desamares": "desamar",
    "desamaria": "desamar",
    "desamariam": "desamar",
    "desamarias": "desamar",
    "desamarmo": "desamar",
    "desamarmos": "desamar",
    "desamarra": "desamarrar",
    "desamarrada": "desamarrar",
    "desamarradas": "desamarrar",
    "desamarrado": "desamarrar",
    "desamarrados": "desamarrar",
    "desamarrai": "desamarrar",
    "desamarrais": "desamarrar",
    "desamarram": "desamarrar",
    "desamarramo": "desamarrar",
    "desamarramos": "desamarrar",
    "desamarrando": "desamarrar",
    "desamarrara": "desamarrar",
    "desamarraram": "desamarrar",
    "desamarraras": "desamarrar",
    "desamarrarde": "desamarrar",
    "desamarrardes": "desamarrar",
    "desamarrare": "desamarrar",
    "desamarrarei": "desamarrar",
    "desamarrareis": "desamarrar",
    "desamarrarem": "desamarrar",
    "desamarraremos": "desamarrar",
    "desamarrares": "desamarrar",
    "desamarraria": "desamarrar",
    "desamarrariam": "desamarrar",
    "desamarrarias": "desamarrar",
    "desamarrarmo": "desamarrar",
    "desamarrarmos": "desamarrar",
    "desamarrará": "desamarrar",
    "desamarrarás": "desamarrar",
    "desamarrarão": "desamarrar",
    "desamarraríamos": "desamarrar",
    "desamarraríeis": "desamarrar",
    "desamarras": "desamarrar",
    "desamarrasse": "desamarrar",
    "desamarrassem": "desamarrar",
    "desamarrasses": "desamarrar",
    "desamarraste": "desamarrar",
    "desamarrastes": "desamarrar",
    "desamarrava": "desamarrar",
    "desamarravam": "desamarrar",
    "desamarravas": "desamarrar",
    "desamarre": "desamarrar",
    "desamarrei": "desamarrar",
    "desamarreis": "desamarrar",
    "desamarrem": "desamarrar",
    "desamarremo": "desamarrar",
    "desamarremos": "desamarrar",
    "desamarres": "desamarrar",
    "desamarro": "desamarrar",
    "desamarrota": "desamarrotar",
    "desamarrotada": "desamarrotar",
    "desamarrotadas": "desamarrotar",
    "desamarrotado": "desamarrotar",
    "desamarrotados": "desamarrotar",
    "desamarrotai": "desamarrotar",
    "desamarrotais": "desamarrotar",
    "desamarrotam": "desamarrotar",
    "desamarrotamo": "desamarrotar",
    "desamarrotamos": "desamarrotar",
    "desamarrotando": "desamarrotar",
    "desamarrotara": "desamarrotar",
    "desamarrotaram": "desamarrotar",
    "desamarrotaras": "desamarrotar",
    "desamarrotarde": "desamarrotar",
    "desamarrotardes": "desamarrotar",
    "desamarrotare": "desamarrotar",
    "desamarrotarei": "desamarrotar",
    "desamarrotareis": "desamarrotar",
    "desamarrotarem": "desamarrotar",
    "desamarrotaremos": "desamarrotar",
    "desamarrotares": "desamarrotar",
    "desamarrotaria": "desamarrotar",
    "desamarrotariam": "desamarrotar",
    "desamarrotarias": "desamarrotar",
    "desamarrotarmo": "desamarrotar",
    "desamarrotarmos": "desamarrotar",
    "desamarrotará": "desamarrotar",
    "desamarrotarás": "desamarrotar",
    "desamarrotarão": "desamarrotar",
    "desamarrotaríamos": "desamarrotar",
    "desamarrotaríeis": "desamarrotar",
    "desamarrotas": "desamarrotar",
    "desamarrotasse": "desamarrotar",
    "desamarrotassem": "desamarrotar",
    "desamarrotasses": "desamarrotar",
    "desamarrotaste": "desamarrotar",
    "desamarrotastes": "desamarrotar",
    "desamarrotava": "desamarrotar",
    "desamarrotavam": "desamarrotar",
    "desamarrotavas": "desamarrotar",
    "desamarrote": "desamarrotar",
    "desamarrotei": "desamarrotar",
    "desamarroteis": "desamarrotar",
    "desamarrotem": "desamarrotar",
    "desamarrotemo": "desamarrotar",
    "desamarrotemos": "desamarrotar",
    "desamarrotes": "desamarrotar",
    "desamarroto": "desamarrotar",
    "desamarrotou": "desamarrotar",
    "desamarrotá": "desamarrotar",
    "desamarrotámo": "desamarrotar",
    "desamarrotámos": "desamarrotar",
    "desamarrotáramo": "desamarrotar",
    "desamarrotáramos": "desamarrotar",
    "desamarrotárei": "desamarrotar",
    "desamarrotáreis": "desamarrotar",
    "desamarrotásseis": "desamarrotar",
    "desamarrotássemos": "desamarrotar",
    "desamarrotávamo": "desamarrotar",
    "desamarrotávamos": "desamarrotar",
    "desamarrotávei": "desamarrotar",
    "desamarrotáveis": "desamarrotar",
    "desamarrou": "desamarrar",
    "desamarrá": "desamarrar",
    "desamarrámo": "desamarrar",
    "desamarrámos": "desamarrar",
    "desamarráramo": "desamarrar",
    "desamarráramos": "desamarrar",
    "desamarrárei": "desamarrar",
    "desamarráreis": "desamarrar",
    "desamarrásseis": "desamarrar",
    "desamarrássemos": "desamarrar",
    "desamarrávamo": "desamarrar",
    "desamarrávamos": "desamarrar",
    "desamarrávei": "desamarrar",
    "desamarráveis": "desamarrar",
    "desamará": "desamar",
    "desamarás": "desamar",
    "desamarão": "desamar",
    "desamaríamos": "desamar",
    "desamaríeis": "desamar",
    "desamas": "desamar",
    "desamassa": "desamassar",
    "desamassada": "desamassar",
    "desamassadas": "desamassar",
    "desamassado": "desamassar",
    "desamassados": "desamassar",
    "desamassai": "desamassar",
    "desamassais": "desamassar",
    "desamassam": "desamassar",
    "desamassamo": "desamassar",
    "desamassamos": "desamassar",
    "desamassando": "desamassar",
    "desamassara": "desamassar",
    "desamassaram": "desamassar",
    "desamassaras": "desamassar",
    "desamassarde": "desamassar",
    "desamassardes": "desamassar",
    "desamassare": "desamassar",
    "desamassarei": "desamassar",
    "desamassareis": "desamassar",
    "desamassarem": "desamassar",
    "desamassaremos": "desamassar",
    "desamassares": "desamassar",
    "desamassaria": "desamassar",
    "desamassariam": "desamassar",
    "desamassarias": "desamassar",
    "desamassarmo": "desamassar",
    "desamassarmos": "desamassar",
    "desamassará": "desamassar",
    "desamassarás": "desamassar",
    "desamassarão": "desamassar",
    "desamassaríamos": "desamassar",
    "desamassaríeis": "desamassar",
    "desamassas": "desamassar",
    "desamassasse": "desamassar",
    "desamassassem": "desamassar",
    "desamassasses": "desamassar",
    "desamassaste": "desamassar",
    "desamassastes": "desamassar",
    "desamassava": "desamassar",
    "desamassavam": "desamassar",
    "desamassavas": "desamassar",
    "desamasse": "desamassar",
    "desamassei": "desamassar",
    "desamasseis": "desamassar",
    "desamassem": "desamassar",
    "desamassemo": "desamassar",
    "desamassemos": "desamassar",
    "desamasses": "desamassar",
    "desamasso": "desamassar",
    "desamassou": "desamassar",
    "desamassá": "desamassar",
    "desamassámo": "desamassar",
    "desamassámos": "desamassar",
    "desamassáramo": "desamassar",
    "desamassáramos": "desamassar",
    "desamassárei": "desamassar",
    "desamassáreis": "desamassar",
    "desamassásseis": "desamassar",
    "desamassássemos": "desamassar",
    "desamassávamo": "desamassar",
    "desamassávamos": "desamassar",
    "desamassávei": "desamassar",
    "desamassáveis": "desamassar",
    "desamaste": "desamar",
    "desamastes": "desamar",
    "desamava": "desamar",
    "desamavam": "desamar",
    "desamavas": "desamar",
    "desambiciosa": "desambicioso",
    "desambiciosas": "desambicioso",
    "desambiciosos": "desambicioso",
    "desambições": "desambição",
    "desame": "desamar",
    "desamei": "desamar",
    "desameis": "desamar",
    "desamem": "desamar",
    "desamemo": "desamar",
    "desamemos": "desamar",
    "desames": "desamar",
    "desamiga": "desamigar",
    "desamigada": "desamigar",
    "desamigadas": "desamigar",
    "desamigado": "desamigar",
    "desamigados": "desamigar",
    "desamigai": "desamigar",
    "desamigais": "desamigar",
    "desamigam": "desamigar",
    "desamigamo": "desamigar",
    "desamigamos": "desamigar",
    "desamigando": "desamigar",
    "desamigara": "desamigar",
    "desamigaram": "desamigar",
    "desamigaras": "desamigar",
    "desamigarde": "desamigar",
    "desamigardes": "desamigar",
    "desamigare": "desamigar",
    "desamigarei": "desamigar",
    "desamigareis": "desamigar",
    "desamigarem": "desamigar",
    "desamigaremos": "desamigar",
    "desamigares": "desamigar",
    "desamigaria": "desamigar",
    "desamigariam": "desamigar",
    "desamigarias": "desamigar",
    "desamigarmo": "desamigar",
    "desamigarmos": "desamigar",
    "desamigará": "desamigar",
    "desamigarás": "desamigar",
    "desamigarão": "desamigar",
    "desamigaríamos": "desamigar",
    "desamigaríeis": "desamigar",
    "desamigas": "desamigar",
    "desamigasse": "desamigar",
    "desamigassem": "desamigar",
    "desamigasses": "desamigar",
    "desamigaste": "desamigar",
    "desamigastes": "desamigar",
    "desamigava": "desamigar",
    "desamigavam": "desamigar",
    "desamigavas": "desamigar",
    "desamigo": "desamigar",
    "desamigou": "desamigar",
    "desamigue": "desamigar",
    "desamiguei": "desamigar",
    "desamigueis": "desamigar",
    "desamiguem": "desamigar",
    "desamiguemo": "desamigar",
    "desamiguemos": "desamigar",
    "desamigues": "desamigar",
    "desamigá": "desamigar",
    "desamigámo": "desamigar",
    "desamigámos": "desamigar",
    "desamigáramo": "desamigar",
    "desamigáramos": "desamigar",
    "desamigárei": "desamigar",
    "desamigáreis": "desamigar",
    "desamigásseis": "desamigar",
    "desamigássemos": "desamigar",
    "desamigávamo": "desamigar",
    "desamigávamos": "desamigar",
    "desamigávei": "desamigar",
    "desamigáveis": "desamigar",
    "desamima": "desamimar",
    "desamimada": "desamimar",
    "desamimadas": "desamimar",
    "desamimado": "desamimar",
    "desamimados": "desamimar",
    "desamimai": "desamimar",
    "desamimais": "desamimar",
    "desamimam": "desamimar",
    "desamimamo": "desamimar",
    "desamimamos": "desamimar",
    "desamimando": "desamimar",
    "desamimara": "desamimar",
    "desamimaram": "desamimar",
    "desamimaras": "desamimar",
    "desamimarde": "desamimar",
    "desamimardes": "desamimar",
    "desamimare": "desamimar",
    "desamimarei": "desamimar",
    "desamimareis": "desamimar",
    "desamimarem": "desamimar",
    "desamimaremos": "desamimar",
    "desamimares": "desamimar",
    "desamimaria": "desamimar",
    "desamimariam": "desamimar",
    "desamimarias": "desamimar",
    "desamimarmo": "desamimar",
    "desamimarmos": "desamimar",
    "desamimará": "desamimar",
    "desamimarás": "desamimar",
    "desamimarão": "desamimar",
    "desamimaríamos": "desamimar",
    "desamimaríeis": "desamimar",
    "desamimas": "desamimar",
    "desamimasse": "desamimar",
    "desamimassem": "desamimar",
    "desamimasses": "desamimar",
    "desamimaste": "desamimar",
    "desamimastes": "desamimar",
    "desamimava": "desamimar",
    "desamimavam": "desamimar",
    "desamimavas": "desamimar",
    "desamime": "desamimar",
    "desamimei": "desamimar",
    "desamimeis": "desamimar",
    "desamimem": "desamimar",
    "desamimemo": "desamimar",
    "desamimemos": "desamimar",
    "desamimes": "desamimar",
    "desamimo": "desamimar",
    "desamimou": "desamimar",
    "desamimá": "desamimar",
    "desamimámo": "desamimar",
    "desamimámos": "desamimar",
    "desamimáramo": "desamimar",
    "desamimáramos": "desamimar",
    "desamimárei": "desamimar",
    "desamimáreis": "desamimar",
    "desamimásseis": "desamimar",
    "desamimássemos": "desamimar",
    "desamimávamo": "desamimar",
    "desamimávamos": "desamimar",
    "desamimávei": "desamimar",
    "desamimáveis": "desamimar",
    "desamista": "desamistar",
    "desamistada": "desamistar",
    "desamistadas": "desamistar",
    "desamistado": "desamistar",
    "desamistados": "desamistar",
    "desamistai": "desamistar",
    "desamistais": "desamistar",
    "desamistam": "desamistar",
    "desamistamo": "desamistar",
    "desamistamos": "desamistar",
    "desamistando": "desamistar",
    "desamistara": "desamistar",
    "desamistaram": "desamistar",
    "desamistaras": "desamistar",
    "desamistarde": "desamistar",
    "desamistardes": "desamistar",
    "desamistare": "desamistar",
    "desamistarei": "desamistar",
    "desamistareis": "desamistar",
    "desamistarem": "desamistar",
    "desamistaremos": "desamistar",
    "desamistares": "desamistar",
    "desamistaria": "desamistar",
    "desamistariam": "desamistar",
    "desamistarias": "desamistar",
    "desamistarmo": "desamistar",
    "desamistarmos": "desamistar",
    "desamistará": "desamistar",
    "desamistarás": "desamistar",
    "desamistarão": "desamistar",
    "desamistaríamos": "desamistar",
    "desamistaríeis": "desamistar",
    "desamistas": "desamistar",
    "desamistasse": "desamistar",
    "desamistassem": "desamistar",
    "desamistasses": "desamistar",
    "desamistaste": "desamistar",
    "desamistastes": "desamistar",
    "desamistava": "desamistar",
    "desamistavam": "desamistar",
    "desamistavas": "desamistar",
    "desamiste": "desamistar",
    "desamistei": "desamistar",
    "desamisteis": "desamistar",
    "desamistem": "desamistar",
    "desamistemo": "desamistar",
    "desamistemos": "desamistar",
    "desamistes": "desamistar",
    "desamisto": "desamistar",
    "desamistou": "desamistar",
    "desamistá": "desamistar",
    "desamistámo": "desamistar",
    "desamistámos": "desamistar",
    "desamistáramo": "desamistar",
    "desamistáramos": "desamistar",
    "desamistárei": "desamistar",
    "desamistáreis": "desamistar",
    "desamistásseis": "desamistar",
    "desamistássemos": "desamistar",
    "desamistávamo": "desamistar",
    "desamistávamos": "desamistar",
    "desamistávei": "desamistar",
    "desamistáveis": "desamistar",
    "desamizades": "desamizade",
    "desamo": "desamar",
    "desamodorra": "desamodorrar",
    "desamodorrada": "desamodorrar",
    "desamodorradas": "desamodorrar",
    "desamodorrado": "desamodorrar",
    "desamodorrados": "desamodorrar",
    "desamodorrai": "desamodorrar",
    "desamodorrais": "desamodorrar",
    "desamodorram": "desamodorrar",
    "desamodorramo": "desamodorrar",
    "desamodorramos": "desamodorrar",
    "desamodorrando": "desamodorrar",
    "desamodorrara": "desamodorrar",
    "desamodorraram": "desamodorrar",
    "desamodorraras": "desamodorrar",
    "desamodorrarde": "desamodorrar",
    "desamodorrardes": "desamodorrar",
    "desamodorrare": "desamodorrar",
    "desamodorrarei": "desamodorrar",
    "desamodorrareis": "desamodorrar",
    "desamodorrarem": "desamodorrar",
    "desamodorraremos": "desamodorrar",
    "desamodorrares": "desamodorrar",
    "desamodorraria": "desamodorrar",
    "desamodorrariam": "desamodorrar",
    "desamodorrarias": "desamodorrar",
    "desamodorrarmo": "desamodorrar",
    "desamodorrarmos": "desamodorrar",
    "desamodorrará": "desamodorrar",
    "desamodorrarás": "desamodorrar",
    "desamodorrarão": "desamodorrar",
    "desamodorraríamos": "desamodorrar",
    "desamodorraríeis": "desamodorrar",
    "desamodorras": "desamodorrar",
    "desamodorrasse": "desamodorrar",
    "desamodorrassem": "desamodorrar",
    "desamodorrasses": "desamodorrar",
    "desamodorraste": "desamodorrar",
    "desamodorrastes": "desamodorrar",
    "desamodorrava": "desamodorrar",
    "desamodorravam": "desamodorrar",
    "desamodorravas": "desamodorrar",
    "desamodorre": "desamodorrar",
    "desamodorrei": "desamodorrar",
    "desamodorreis": "desamodorrar",
    "desamodorrem": "desamodorrar",
    "desamodorremo": "desamodorrar",
    "desamodorremos": "desamodorrar",
    "desamodorres": "desamodorrar",
    "desamodorro": "desamodorrar",
    "desamodorrou": "desamodorrar",
    "desamodorrá": "desamodorrar",
    "desamodorrámo": "desamodorrar",
    "desamodorrámos": "desamodorrar",
    "desamodorráramo": "desamodorrar",
    "desamodorráramos": "desamodorrar",
    "desamodorrárei": "desamodorrar",
    "desamodorráreis": "desamodorrar",
    "desamodorrásseis": "desamodorrar",
    "desamodorrássemos": "desamodorrar",
    "desamodorrávamo": "desamodorrar",
    "desamodorrávamos": "desamodorrar",
    "desamodorrávei": "desamodorrar",
    "desamodorráveis": "desamodorrar",
    "desamoeda": "desamoedar",
    "desamoedada": "desamoedar",
    "desamoedadas": "desamoedar",
    "desamoedado": "desamoedar",
    "desamoedados": "desamoedar",
    "desamoedai": "desamoedar",
    "desamoedais": "desamoedar",
    "desamoedam": "desamoedar",
    "desamoedamo": "desamoedar",
    "desamoedamos": "desamoedar",
    "desamoedando": "desamoedar",
    "desamoedara": "desamoedar",
    "desamoedaram": "desamoedar",
    "desamoedaras": "desamoedar",
    "desamoedarde": "desamoedar",
    "desamoedardes": "desamoedar",
    "desamoedare": "desamoedar",
    "desamoedarei": "desamoedar",
    "desamoedareis": "desamoedar",
    "desamoedarem": "desamoedar",
    "desamoedaremos": "desamoedar",
    "desamoedares": "desamoedar",
    "desamoedaria": "desamoedar",
    "desamoedariam": "desamoedar",
    "desamoedarias": "desamoedar",
    "desamoedarmo": "desamoedar",
    "desamoedarmos": "desamoedar",
    "desamoedará": "desamoedar",
    "desamoedarás": "desamoedar",
    "desamoedarão": "desamoedar",
    "desamoedaríamos": "desamoedar",
    "desamoedaríeis": "desamoedar",
    "desamoedas": "desamoedar",
    "desamoedasse": "desamoedar",
    "desamoedassem": "desamoedar",
    "desamoedasses": "desamoedar",
    "desamoedaste": "desamoedar",
    "desamoedastes": "desamoedar",
    "desamoedava": "desamoedar",
    "desamoedavam": "desamoedar",
    "desamoedavas": "desamoedar",
    "desamoedações": "desamoedação",
    "desamoede": "desamoedar",
    "desamoedei": "desamoedar",
    "desamoedeis": "desamoedar",
    "desamoedem": "desamoedar",
    "desamoedemo": "desamoedar",
    "desamoedemos": "desamoedar",
    "desamoedes": "desamoedar",
    "desamoedo": "desamoedar",
    "desamoedou": "desamoedar",
    "desamoedá": "desamoedar",
    "desamoedámo": "desamoedar",
    "desamoedámos": "desamoedar",
    "desamoedáramo": "desamoedar",
    "desamoedáramos": "desamoedar",
    "desamoedárei": "desamoedar",
    "desamoedáreis": "desamoedar",
    "desamoedásseis": "desamoedar",
    "desamoedássemos": "desamoedar",
    "desamoedávamo": "desamoedar",
    "desamoedávamos": "desamoedar",
    "desamoedávei": "desamoedar",
    "desamoedáveis": "desamoedar",
    "desamolga": "desamolgar",
    "desamolgada": "desamolgar",
    "desamolgadas": "desamolgar",
    "desamolgado": "desamolgar",
    "desamolgados": "desamolgar",
    "desamolgai": "desamolgar",
    "desamolgais": "desamolgar",
    "desamolgam": "desamolgar",
    "desamolgamo": "desamolgar",
    "desamolgamos": "desamolgar",
    "desamolgando": "desamolgar",
    "desamolgara": "desamolgar",
    "desamolgaram": "desamolgar",
    "desamolgaras": "desamolgar",
    "desamolgarde": "desamolgar",
    "desamolgardes": "desamolgar",
    "desamolgare": "desamolgar",
    "desamolgarei": "desamolgar",
    "desamolgareis": "desamolgar",
    "desamolgarem": "desamolgar",
    "desamolgaremos": "desamolgar",
    "desamolgares": "desamolgar",
    "desamolgaria": "desamolgar",
    "desamolgariam": "desamolgar",
    "desamolgarias": "desamolgar",
    "desamolgarmo": "desamolgar",
    "desamolgarmos": "desamolgar",
    "desamolgará": "desamolgar",
    "desamolgarás": "desamolgar",
    "desamolgarão": "desamolgar",
    "desamolgaríamos": "desamolgar",
    "desamolgaríeis": "desamolgar",
    "desamolgas": "desamolgar",
    "desamolgasse": "desamolgar",
    "desamolgassem": "desamolgar",
    "desamolgasses": "desamolgar",
    "desamolgaste": "desamolgar",
    "desamolgastes": "desamolgar",
    "desamolgava": "desamolgar",
    "desamolgavam": "desamolgar",
    "desamolgavas": "desamolgar",
    "desamolgo": "desamolgar",
    "desamolgou": "desamolgar",
    "desamolgue": "desamolgar",
    "desamolguei": "desamolgar",
    "desamolgueis": "desamolgar",
    "desamolguem": "desamolgar",
    "desamolguemo": "desamolgar",
    "desamolguemos": "desamolgar",
    "desamolgues": "desamolgar",
    "desamolgá": "desamolgar",
    "desamolgámo": "desamolgar",
    "desamolgámos": "desamolgar",
    "desamolgáramo": "desamolgar",
    "desamolgáramos": "desamolgar",
    "desamolgárei": "desamolgar",
    "desamolgáreis": "desamolgar",
    "desamolgásseis": "desamolgar",
    "desamolgássemos": "desamolgar",
    "desamolgávamo": "desamolgar",
    "desamolgávamos": "desamolgar",
    "desamolgávei": "desamolgar",
    "desamolgáveis": "desamolgável",
    "desamontoa": "desamontoar",
    "desamontoada": "desamontoar",
    "desamontoadas": "desamontoar",
    "desamontoado": "desamontoar",
    "desamontoados": "desamontoar",
    "desamontoai": "desamontoar",
    "desamontoais": "desamontoar",
    "desamontoam": "desamontoar",
    "desamontoamo": "desamontoar",
    "desamontoamos": "desamontoar",
    "desamontoando": "desamontoar",
    "desamontoara": "desamontoar",
    "desamontoaram": "desamontoar",
    "desamontoaras": "desamontoar",
    "desamontoarde": "desamontoar",
    "desamontoardes": "desamontoar",
    "desamontoare": "desamontoar",
    "desamontoarei": "desamontoar",
    "desamontoareis": "desamontoar",
    "desamontoarem": "desamontoar",
    "desamontoaremos": "desamontoar",
    "desamontoares": "desamontoar",
    "desamontoaria": "desamontoar",
    "desamontoariam": "desamontoar",
    "desamontoarias": "desamontoar",
    "desamontoarmo": "desamontoar",
    "desamontoarmos": "desamontoar",
    "desamontoará": "desamontoar",
    "desamontoarás": "desamontoar",
    "desamontoarão": "desamontoar",
    "desamontoaríamos": "desamontoar",
    "desamontoaríeis": "desamontoar",
    "desamontoas": "desamontoar",
    "desamontoasse": "desamontoar",
    "desamontoassem": "desamontoar",
    "desamontoasses": "desamontoar",
    "desamontoaste": "desamontoar",
    "desamontoastes": "desamontoar",
    "desamontoava": "desamontoar",
    "desamontoavam": "desamontoar",
    "desamontoavas": "desamontoar",
    "desamontoe": "desamontoar",
    "desamontoei": "desamontoar",
    "desamontoeis": "desamontoar",
    "desamontoem": "desamontoar",
    "desamontoemo": "desamontoar",
    "desamontoemos": "desamontoar",
    "desamontoes": "desamontoar",
    "desamontoo": "desamontoar",
    "desamontoou": "desamontoar",
    "desamontoá": "desamontoar",
    "desamontoámo": "desamontoar",
    "desamontoámos": "desamontoar",
    "desamontoáramo": "desamontoar",
    "desamontoáramos": "desamontoar",
    "desamontoárei": "desamontoar",
    "desamontoáreis": "desamontoar",
    "desamontoásseis": "desamontoar",
    "desamontoássemos": "desamontoar",
    "desamontoávamo": "desamontoar",
    "desamontoávamos": "desamontoar",
    "desamontoávei": "desamontoar",
    "desamontoáveis": "desamontoar",
    "desamores": "desamor",
    "desamorosa": "desamoroso",
    "desamorosas": "desamoroso",
    "desamorosos": "desamoroso",
    "desamortalha": "desamortalhar",
    "desamortalhada": "desamortalhar",
    "desamortalhadas": "desamortalhar",
    "desamortalhado": "desamortalhar",
    "desamortalhados": "desamortalhar",
    "desamortalhai": "desamortalhar",
    "desamortalhais": "desamortalhar",
    "desamortalham": "desamortalhar",
    "desamortalhamo": "desamortalhar",
    "desamortalhamos": "desamortalhar",
    "desamortalhando": "desamortalhar",
    "desamortalhara": "desamortalhar",
    "desamortalharam": "desamortalhar",
    "desamortalharas": "desamortalhar",
    "desamortalharde": "desamortalhar",
    "desamortalhardes": "desamortalhar",
    "desamortalhare": "desamortalhar",
    "desamortalharei": "desamortalhar",
    "desamortalhareis": "desamortalhar",
    "desamortalharem": "desamortalhar",
    "desamortalharemos": "desamortalhar",
    "desamortalhares": "desamortalhar",
    "desamortalharia": "desamortalhar",
    "desamortalhariam": "desamortalhar",
    "desamortalharias": "desamortalhar",
    "desamortalharmo": "desamortalhar",
    "desamortalharmos": "desamortalhar",
    "desamortalhará": "desamortalhar",
    "desamortalharás": "desamortalhar",
    "desamortalharão": "desamortalhar",
    "desamortalharíamos": "desamortalhar",
    "desamortalharíeis": "desamortalhar",
    "desamortalhas": "desamortalhar",
    "desamortalhasse": "desamortalhar",
    "desamortalhassem": "desamortalhar",
    "desamortalhasses": "desamortalhar",
    "desamortalhaste": "desamortalhar",
    "desamortalhastes": "desamortalhar",
    "desamortalhava": "desamortalhar",
    "desamortalhavam": "desamortalhar",
    "desamortalhavas": "desamortalhar",
    "desamortalhe": "desamortalhar",
    "desamortalhei": "desamortalhar",
    "desamortalheis": "desamortalhar",
    "desamortalhem": "desamortalhar",
    "desamortalhemo": "desamortalhar",
    "desamortalhemos": "desamortalhar",
    "desamortalhes": "desamortalhar",
    "desamortalho": "desamortalhar",
    "desamortalhou": "desamortalhar",
    "desamortalhá": "desamortalhar",
    "desamortalhámo": "desamortalhar",
    "desamortalhámos": "desamortalhar",
    "desamortalháramo": "desamortalhar",
    "desamortalháramos": "desamortalhar",
    "desamortalhárei": "desamortalhar",
    "desamortalháreis": "desamortalhar",
    "desamortalhásseis": "desamortalhar",
    "desamortalhássemos": "desamortalhar",
    "desamortalhávamo": "desamortalhar",
    "desamortalhávamos": "desamortalhar",
    "desamortalhávei": "desamortalhar",
    "desamortalháveis": "desamortalhar",
    "desamortiza": "desamortizar",
    "desamortizada": "desamortizar",
    "desamortizadas": "desamortizar",
    "desamortizado": "desamortizar",
    "desamortizados": "desamortizar",
    "desamortizai": "desamortizar",
    "desamortizais": "desamortizar",
    "desamortizam": "desamortizar",
    "desamortizamo": "desamortizar",
    "desamortizamos": "desamortizar",
    "desamortizando": "desamortizar",
    "desamortizara": "desamortizar",
    "desamortizaram": "desamortizar",
    "desamortizaras": "desamortizar",
    "desamortizarde": "desamortizar",
    "desamortizardes": "desamortizar",
    "desamortizare": "desamortizar",
    "desamortizarei": "desamortizar",
    "desamortizareis": "desamortizar",
    "desamortizarem": "desamortizar",
    "desamortizaremos": "desamortizar",
    "desamortizares": "desamortizar",
    "desamortizaria": "desamortizar",
    "desamortizariam": "desamortizar",
    "desamortizarias": "desamortizar",
    "desamortizarmo": "desamortizar",
    "desamortizarmos": "desamortizar",
    "desamortizará": "desamortizar",
    "desamortizarás": "desamortizar",
    "desamortizarão": "desamortizar",
    "desamortizaríamos": "desamortizar",
    "desamortizaríeis": "desamortizar",
    "desamortizas": "desamortizar",
    "desamortizasse": "desamortizar",
    "desamortizassem": "desamortizar",
    "desamortizasses": "desamortizar",
    "desamortizaste": "desamortizar",
    "desamortizastes": "desamortizar",
    "desamortizava": "desamortizar",
    "desamortizavam": "desamortizar",
    "desamortizavas": "desamortizar",
    "desamortizações": "desamortização",
    "desamortize": "desamortizar",
    "desamortizei": "desamortizar",
    "desamortizeis": "desamortizar",
    "desamortizem": "desamortizar",
    "desamortizemo": "desamortizar",
    "desamortizemos": "desamortizar",
    "desamortizes": "desamortizar",
    "desamortizo": "desamortizar",
    "desamortizou": "desamortizar",
    "desamortizá": "desamortizar",
    "desamortizámo": "desamortizar",
    "desamortizámos": "desamortizar",
    "desamortizáramo": "desamortizar",
    "desamortizáramos": "desamortizar",
    "desamortizárei": "desamortizar",
    "desamortizáreis": "desamortizar",
    "desamortizásseis": "desamortizar",
    "desamortizássemos": "desamortizar",
    "desamortizávamo": "desamortizar",
    "desamortizávamos": "desamortizar",
    "desamortizávei": "desamortizar",
    "desamortizáveis": "desamortizável",
    "desamoráveis": "desamorável",
    "desamotina": "desamotinar",
    "desamotinada": "desamotinar",
    "desamotinadas": "desamotinar",
    "desamotinado": "desamotinar",
    "desamotinados": "desamotinar",
    "desamotinai": "desamotinar",
    "desamotinais": "desamotinar",
    "desamotinam": "desamotinar",
    "desamotinamo": "desamotinar",
    "desamotinamos": "desamotinar",
    "desamotinando": "desamotinar",
    "desamotinara": "desamotinar",
    "desamotinaram": "desamotinar",
    "desamotinaras": "desamotinar",
    "desamotinarde": "desamotinar",
    "desamotinardes": "desamotinar",
    "desamotinare": "desamotinar",
    "desamotinarei": "desamotinar",
    "desamotinareis": "desamotinar",
    "desamotinarem": "desamotinar",
    "desamotinaremos": "desamotinar",
    "desamotinares": "desamotinar",
    "desamotinaria": "desamotinar",
    "desamotinariam": "desamotinar",
    "desamotinarias": "desamotinar",
    "desamotinarmo": "desamotinar",
    "desamotinarmos": "desamotinar",
    "desamotinará": "desamotinar",
    "desamotinarás": "desamotinar",
    "desamotinarão": "desamotinar",
    "desamotinaríamos": "desamotinar",
    "desamotinaríeis": "desamotinar",
    "desamotinas": "desamotinar",
    "desamotinasse": "desamotinar",
    "desamotinassem": "desamotinar",
    "desamotinasses": "desamotinar",
    "desamotinaste": "desamotinar",
    "desamotinastes": "desamotinar",
    "desamotinava": "desamotinar",
    "desamotinavam": "desamotinar",
    "desamotinavas": "desamotinar",
    "desamotine": "desamotinar",
    "desamotinei": "desamotinar",
    "desamotineis": "desamotinar",
    "desamotinem": "desamotinar",
    "desamotinemo": "desamotinar",
    "desamotinemos": "desamotinar",
    "desamotines": "desamotinar",
    "desamotino": "desamotinar",
    "desamotinou": "desamotinar",
    "desamotiná": "desamotinar",
    "desamotinámo": "desamotinar",
    "desamotinámos": "desamotinar",
    "desamotináramo": "desamotinar",
    "desamotináramos": "desamotinar",
    "desamotinárei": "desamotinar",
    "desamotináreis": "desamotinar",
    "desamotinásseis": "desamotinar",
    "desamotinássemos": "desamotinar",
    "desamotinávamo": "desamotinar",
    "desamotinávamos": "desamotinar",
    "desamotinávei": "desamotinar",
    "desamotináveis": "desamotinar",
    "desamou": "desamar",
    "desampara": "desamparar",
    "desamparada": "desamparar",
    "desamparadas": "desamparar",
    "desamparado": "desamparar",
    "desamparados": "desamparar",
    "desamparai": "desamparar",
    "desamparais": "desamparar",
    "desamparam": "desamparar",
    "desamparamo": "desamparar",
    "desamparamos": "desamparar",
    "desamparando": "desamparar",
    "desamparara": "desamparar",
    "desampararam": "desamparar",
    "desampararas": "desamparar",
    "desampararde": "desamparar",
    "desamparardes": "desamparar",
    "desamparare": "desamparar",
    "desampararei": "desamparar",
    "desamparareis": "desamparar",
    "desampararem": "desamparar",
    "desampararemos": "desamparar",
    "desamparares": "desamparar",
    "desampararia": "desamparar",
    "desamparariam": "desamparar",
    "desampararias": "desamparar",
    "desampararmo": "desamparar",
    "desampararmos": "desamparar",
    "desamparará": "desamparar",
    "desampararás": "desamparar",
    "desampararão": "desamparar",
    "desampararíamos": "desamparar",
    "desampararíeis": "desamparar",
    "desamparas": "desamparar",
    "desamparasse": "desamparar",
    "desamparassem": "desamparar",
    "desamparasses": "desamparar",
    "desamparaste": "desamparar",
    "desamparastes": "desamparar",
    "desamparava": "desamparar",
    "desamparavam": "desamparar",
    "desamparavas": "desamparar",
    "desampare": "desamparar",
    "desamparei": "desamparar",
    "desampareis": "desamparar",
    "desamparem": "desamparar",
    "desamparemo": "desamparar",
    "desamparemos": "desamparar",
    "desampares": "desamparar",
    "desamparo": "desamparar",
    "desamparos": "desamparo",
    "desamparou": "desamparar",
    "desampará": "desamparar",
    "desamparámo": "desamparar",
    "desamparámos": "desamparar",
    "desamparáramo": "desamparar",
    "desamparáramos": "desamparar",
    "desamparárei": "desamparar",
    "desamparáreis": "desamparar",
    "desamparásseis": "desamparar",
    "desamparássemos": "desamparar",
    "desamparávamo": "desamparar",
    "desamparávamos": "desamparar",
    "desamparávei": "desamparar",
    "desamparáveis": "desamparar",
    "desamua": "desamuar",
    "desamuada": "desamuar",
    "desamuadas": "desamuar",
    "desamuado": "desamuar",
    "desamuados": "desamuar",
    "desamuai": "desamuar",
    "desamuais": "desamuar",
    "desamuam": "desamuar",
    "desamuamo": "desamuar",
    "desamuamos": "desamuar",
    "desamuando": "desamuar",
    "desamuara": "desamuar",
    "desamuaram": "desamuar",
    "desamuaras": "desamuar",
    "desamuarde": "desamuar",
    "desamuardes": "desamuar",
    "desamuare": "desamuar",
    "desamuarei": "desamuar",
    "desamuareis": "desamuar",
    "desamuarem": "desamuar",
    "desamuaremos": "desamuar",
    "desamuares": "desamuar",
    "desamuaria": "desamuar",
    "desamuariam": "desamuar",
    "desamuarias": "desamuar",
    "desamuarmo": "desamuar",
    "desamuarmos": "desamuar",
    "desamuará": "desamuar",
    "desamuarás": "desamuar",
    "desamuarão": "desamuar",
    "desamuaríamos": "desamuar",
    "desamuaríeis": "desamuar",
    "desamuas": "desamuar",
    "desamuasse": "desamuar",
    "desamuassem": "desamuar",
    "desamuasses": "desamuar",
    "desamuaste": "desamuar",
    "desamuastes": "desamuar",
    "desamuava": "desamuar",
    "desamuavam": "desamuar",
    "desamuavas": "desamuar",
    "desamue": "desamuar",
    "desamuei": "desamuar",
    "desamueis": "desamuar",
    "desamuem": "desamuar",
    "desamuemo": "desamuar",
    "desamuemos": "desamuar",
    "desamues": "desamuar",
    "desamuo": "desamuar",
    "desamuou": "desamuar",
    "desamuá": "desamuar",
    "desamuámo": "desamuar",
    "desamuámos": "desamuar",
    "desamuáramo": "desamuar",
    "desamuáramos": "desamuar",
    "desamuárei": "desamuar",
    "desamuáreis": "desamuar",
    "desamuásseis": "desamuar",
    "desamuássemos": "desamuar",
    "desamuávamo": "desamuar",
    "desamuávamos": "desamuar",
    "desamuávei": "desamuar",
    "desamuáveis": "desamuar",
    "desamá": "desamar",
    "desamámo": "desamar",
    "desamámos": "desamar",
    "desamáramo": "desamar",
    "desamáramos": "desamar",
    "desamárei": "desamar",
    "desamáreis": "desamar",
    "desamásseis": "desamar",
    "desamássemos": "desamar",
    "desamávamo": "desamar",
    "desamávamos": "desamar",
    "desamávei": "desamar",
    "desamáveis": "desamável",
    "desanalfabetiza": "desanalfabetizar",
    "desanalfabetizada": "desanalfabetizar",
    "desanalfabetizadas": "desanalfabetizar",
    "desanalfabetizado": "desanalfabetizar",
    "desanalfabetizados": "desanalfabetizar",
    "desanalfabetizai": "desanalfabetizar",
    "desanalfabetizais": "desanalfabetizar",
    "desanalfabetizam": "desanalfabetizar",
    "desanalfabetizamo": "desanalfabetizar",
    "desanalfabetizamos": "desanalfabetizar",
    "desanalfabetizando": "desanalfabetizar",
    "desanalfabetizara": "desanalfabetizar",
    "desanalfabetizaram": "desanalfabetizar",
    "desanalfabetizaras": "desanalfabetizar",
    "desanalfabetizarde": "desanalfabetizar",
    "desanalfabetizardes": "desanalfabetizar",
    "desanalfabetizare": "desanalfabetizar",
    "desanalfabetizarei": "desanalfabetizar",
    "desanalfabetizareis": "desanalfabetizar",
    "desanalfabetizarem": "desanalfabetizar",
    "desanalfabetizaremos": "desanalfabetizar",
    "desanalfabetizares": "desanalfabetizar",
    "desanalfabetizaria": "desanalfabetizar",
    "desanalfabetizariam": "desanalfabetizar",
    "desanalfabetizarias": "desanalfabetizar",
    "desanalfabetizarmo": "desanalfabetizar",
    "desanalfabetizarmos": "desanalfabetizar",
    "desanalfabetizará": "desanalfabetizar",
    "desanalfabetizarás": "desanalfabetizar",
    "desanalfabetizarão": "desanalfabetizar",
    "desanalfabetizaríamos": "desanalfabetizar",
    "desanalfabetizaríeis": "desanalfabetizar",
    "desanalfabetizas": "desanalfabetizar",
    "desanalfabetizasse": "desanalfabetizar",
    "desanalfabetizassem": "desanalfabetizar",
    "desanalfabetizasses": "desanalfabetizar",
    "desanalfabetizaste": "desanalfabetizar",
    "desanalfabetizastes": "desanalfabetizar",
    "desanalfabetizava": "desanalfabetizar",
    "desanalfabetizavam": "desanalfabetizar",
    "desanalfabetizavas": "desanalfabetizar",
    "desanalfabetize": "desanalfabetizar",
    "desanalfabetizei": "desanalfabetizar",
    "desanalfabetizeis": "desanalfabetizar",
    "desanalfabetizem": "desanalfabetizar",
    "desanalfabetizemo": "desanalfabetizar",
    "desanalfabetizemos": "desanalfabetizar",
    "desanalfabetizes": "desanalfabetizar",
    "desanalfabetizo": "desanalfabetizar",
    "desanalfabetizou": "desanalfabetizar",
    "desanalfabetizá": "desanalfabetizar",
    "desanalfabetizámo": "desanalfabetizar",
    "desanalfabetizámos": "desanalfabetizar",
    "desanalfabetizáramo": "desanalfabetizar",
    "desanalfabetizáramos": "desanalfabetizar",
    "desanalfabetizárei": "desanalfabetizar",
    "desanalfabetizáreis": "desanalfabetizar",
    "desanalfabetizásseis": "desanalfabetizar",
    "desanalfabetizássemos": "desanalfabetizar",
    "desanalfabetizávamo": "desanalfabetizar",
    "desanalfabetizávamos": "desanalfabetizar",
    "desanalfabetizávei": "desanalfabetizar",
    "desanalfabetizáveis": "desanalfabetizar",
    "desanca": "desancar",
    "desancada": "desancar",
    "desancadas": "desancar",
    "desancado": "desancar",
    "desancadora": "desancador",
    "desancadoras": "desancador",
    "desancadores": "desancador",
    "desancados": "desancar",
    "desancai": "desancar",
    "desancais": "desancar",
    "desancam": "desancar",
    "desancamo": "desancar",
    "desancamos": "desancar",
    "desancando": "desancar",
    "desancara": "desancar",
    "desancaram": "desancar",
    "desancaras": "desancar",
    "desancarde": "desancar",
    "desancardes": "desancar",
    "desancare": "desancar",
    "desancarei": "desancar",
    "desancareis": "desancar",
    "desancarem": "desancar",
    "desancaremos": "desancar",
    "desancares": "desancar",
    "desancaria": "desancar",
    "desancariam": "desancar",
    "desancarias": "desancar",
    "desancarmo": "desancar",
    "desancarmos": "desancar",
    "desancará": "desancar",
    "desancarás": "desancar",
    "desancarão": "desancar",
    "desancaríamos": "desancar",
    "desancaríeis": "desancar",
    "desancas": "desancar",
    "desancasse": "desancar",
    "desancassem": "desancar",
    "desancasses": "desancar",
    "desancaste": "desancar",
    "desancastes": "desancar",
    "desancava": "desancar",
    "desancavam": "desancar",
    "desancavas": "desancar",
    "desanco": "desancar",
    "desancora": "desancorar",
    "desancorada": "desancorar",
    "desancoradas": "desancorar",
    "desancorado": "desancorar",
    "desancorados": "desancorar",
    "desancorai": "desancorar",
    "desancorais": "desancorar",
    "desancoram": "desancorar",
    "desancoramo": "desancorar",
    "desancoramos": "desancorar",
    "desancorando": "desancorar",
    "desancorara": "desancorar",
    "desancoraram": "desancorar",
    "desancoraras": "desancorar",
    "desancorarde": "desancorar",
    "desancorardes": "desancorar",
    "desancorare": "desancorar",
    "desancorarei": "desancorar",
    "desancorareis": "desancorar",
    "desancorarem": "desancorar",
    "desancoraremos": "desancorar",
    "desancorares": "desancorar",
    "desancoraria": "desancorar",
    "desancorariam": "desancorar",
    "desancorarias": "desancorar",
    "desancorarmo": "desancorar",
    "desancorarmos": "desancorar",
    "desancorará": "desancorar",
    "desancorarás": "desancorar",
    "desancorarão": "desancorar",
    "desancoraríamos": "desancorar",
    "desancoraríeis": "desancorar",
    "desancoras": "desancorar",
    "desancorasse": "desancorar",
    "desancorassem": "desancorar",
    "desancorasses": "desancorar",
    "desancoraste": "desancorar",
    "desancorastes": "desancorar",
    "desancorava": "desancorar",
    "desancoravam": "desancorar",
    "desancoravas": "desancorar",
    "desancore": "desancorar",
    "desancorei": "desancorar",
    "desancoreis": "desancorar",
    "desancorem": "desancorar",
    "desancoremo": "desancorar",
    "desancoremos": "desancorar",
    "desancores": "desancorar",
    "desancoro": "desancorar",
    "desancorou": "desancorar",
    "desancorá": "desancorar",
    "desancorámo": "desancorar",
    "desancorámos": "desancorar",
    "desancoráramo": "desancorar",
    "desancoráramos": "desancorar",
    "desancorárei": "desancorar",
    "desancoráreis": "desancorar",
    "desancorásseis": "desancorar",
    "desancorássemos": "desancorar",
    "desancorávamo": "desancorar",
    "desancorávamos": "desancorar",
    "desancorávei": "desancorar",
    "desancoráveis": "desancorar",
    "desancou": "desancar",
    "desancá": "desancar",
    "desancámo": "desancar",
    "desancámos": "desancar",
    "desancáramo": "desancar",
    "desancáramos": "desancar",
    "desancárei": "desancar",
    "desancáreis": "desancar",
    "desancásseis": "desancar",
    "desancássemos": "desancar",
    "desancávamo": "desancar",
    "desancávamos": "desancar",
    "desancávei": "desancar",
    "desancáveis": "desancar",
    "desanda": "desandar",
    "desandada": "desandar",
    "desandadas": "desandar",
    "desandadeiras": "desandadeira",
    "desandadelas": "desandadela",
    "desandado": "desandar",
    "desandadora": "desandador",
    "desandadoras": "desandador",
    "desandadores": "desandador",
    "desandados": "desandar",
    "desandai": "desandar",
    "desandais": "desandar",
    "desandam": "desandar",
    "desandamo": "desandar",
    "desandamos": "desandar",
    "desandando": "desandar",
    "desandara": "desandar",
    "desandaram": "desandar",
    "desandaras": "desandar",
    "desandarde": "desandar",
    "desandardes": "desandar",
    "desandare": "desandar",
    "desandarei": "desandar",
    "desandareis": "desandar",
    "desandarem": "desandar",
    "desandaremos": "desandar",
    "desandares": "desandar",
    "desandaria": "desandar",
    "desandariam": "desandar",
    "desandarias": "desandar",
    "desandarmo": "desandar",
    "desandarmos": "desandar",
    "desandará": "desandar",
    "desandarás": "desandar",
    "desandarão": "desandar",
    "desandaríamos": "desandar",
    "desandaríeis": "desandar",
    "desandas": "desandar",
    "desandasse": "desandar",
    "desandassem": "desandar",
    "desandasses": "desandar",
    "desandaste": "desandar",
    "desandastes": "desandar",
    "desandava": "desandar",
    "desandavam": "desandar",
    "desandavas": "desandar",
    "desande": "desandar",
    "desandei": "desandar",
    "desandeis": "desandar",
    "desandem": "desandar",
    "desandemo": "desandar",
    "desandemos": "desandar",
    "desandes": "desandar",
    "desando": "desandar",
    "desandos": "desando",
    "desandou": "desandar",
    "desandá": "desandar",
    "desandámo": "desandar",
    "desandámos": "desandar",
    "desandáramo": "desandar",
    "desandáramos": "desandar",
    "desandárei": "desandar",
    "desandáreis": "desandar",
    "desandásseis": "desandar",
    "desandássemos": "desandar",
    "desandávamo": "desandar",
    "desandávamos": "desandar",
    "desandávei": "desandar",
    "desandáveis": "desandar",
    "desanela": "desanelar",
    "desanelada": "desanelar",
    "desaneladas": "desanelar",
    "desanelado": "desanelar",
    "desanelados": "desanelar",
    "desanelai": "desanelar",
    "desanelais": "desanelar",
    "desanelam": "desanelar",
    "desanelamo": "desanelar",
    "desanelamos": "desanelar",
    "desanelando": "desanelar",
    "desanelara": "desanelar",
    "desanelaram": "desanelar",
    "desanelaras": "desanelar",
    "desanelarde": "desanelar",
    "desanelardes": "desanelar",
    "desanelare": "desanelar",
    "desanelarei": "desanelar",
    "desanelareis": "desanelar",
    "desanelarem": "desanelar",
    "desanelaremos": "desanelar",
    "desanelares": "desanelar",
    "desanelaria": "desanelar",
    "desanelariam": "desanelar",
    "desanelarias": "desanelar",
    "desanelarmo": "desanelar",
    "desanelarmos": "desanelar",
    "desanelará": "desanelar",
    "desanelarás": "desanelar",
    "desanelarão": "desanelar",
    "desanelaríamos": "desanelar",
    "desanelaríeis": "desanelar",
    "desanelas": "desanelar",
    "desanelasse": "desanelar",
    "desanelassem": "desanelar",
    "desanelasses": "desanelar",
    "desanelaste": "desanelar",
    "desanelastes": "desanelar",
    "desanelava": "desanelar",
    "desanelavam": "desanelar",
    "desanelavas": "desanelar",
    "desanele": "desanelar",
    "desanelei": "desanelar",
    "desaneleis": "desanelar",
    "desanelem": "desanelar",
    "desanelemo": "desanelar",
    "desanelemos": "desanelar",
    "desaneles": "desanelar",
    "desanelo": "desanelar",
    "desanelou": "desanelar",
    "desanelá": "desanelar",
    "desanelámo": "desanelar",
    "desanelámos": "desanelar",
    "desaneláramo": "desanelar",
    "desaneláramos": "desanelar",
    "desanelárei": "desanelar",
    "desaneláreis": "desanelar",
    "desanelásseis": "desanelar",
    "desanelássemos": "desanelar",
    "desanelávamo": "desanelar",
    "desanelávamos": "desanelar",
    "desanelávei": "desanelar",
    "desaneláveis": "desanelar",
    "desanexa": "desanexar",
    "desanexada": "desanexar",
    "desanexadas": "desanexar",
    "desanexado": "desanexar",
    "desanexados": "desanexar",
    "desanexai": "desanexar",
    "desanexais": "desanexar",
    "desanexam": "desanexar",
    "desanexamo": "desanexar",
    "desanexamos": "desanexar",
    "desanexando": "desanexar",
    "desanexara": "desanexar",
    "desanexaram": "desanexar",
    "desanexaras": "desanexar",
    "desanexarde": "desanexar",
    "desanexardes": "desanexar",
    "desanexare": "desanexar",
    "desanexarei": "desanexar",
    "desanexareis": "desanexar",
    "desanexarem": "desanexar",
    "desanexaremos": "desanexar",
    "desanexares": "desanexar",
    "desanexaria": "desanexar",
    "desanexariam": "desanexar",
    "desanexarias": "desanexar",
    "desanexarmo": "desanexar",
    "desanexarmos": "desanexar",
    "desanexará": "desanexar",
    "desanexarás": "desanexar",
    "desanexarão": "desanexar",
    "desanexaríamos": "desanexar",
    "desanexaríeis": "desanexar",
    "desanexas": "desanexar",
    "desanexasse": "desanexar",
    "desanexassem": "desanexar",
    "desanexasses": "desanexar",
    "desanexaste": "desanexar",
    "desanexastes": "desanexar",
    "desanexava": "desanexar",
    "desanexavam": "desanexar",
    "desanexavas": "desanexar",
    "desanexações": "desanexação",
    "desanexe": "desanexar",
    "desanexei": "desanexar",
    "desanexeis": "desanexar",
    "desanexem": "desanexar",
    "desanexemo": "desanexar",
    "desanexemos": "desanexar",
    "desanexes": "desanexar",
    "desanexo": "desanexar",
    "desanexou": "desanexar",
    "desanexá": "desanexar",
    "desanexámo": "desanexar",
    "desanexámos": "desanexar",
    "desanexáramo": "desanexar",
    "desanexáramos": "desanexar",
    "desanexárei": "desanexar",
    "desanexáreis": "desanexar",
    "desanexásseis": "desanexar",
    "desanexássemos": "desanexar",
    "desanexávamo": "desanexar",
    "desanexávamos": "desanexar",
    "desanexávei": "desanexar",
    "desanexáveis": "desanexar",
    "desanicha": "desanichar",
    "desanichada": "desanichar",
    "desanichadas": "desanichar",
    "desanichado": "desanichar",
    "desanichados": "desanichar",
    "desanichai": "desanichar",
    "desanichais": "desanichar",
    "desanicham": "desanichar",
    "desanichamo": "desanichar",
    "desanichamos": "desanichar",
    "desanichando": "desanichar",
    "desanichara": "desanichar",
    "desanicharam": "desanichar",
    "desanicharas": "desanichar",
    "desanicharde": "desanichar",
    "desanichardes": "desanichar",
    "desanichare": "desanichar",
    "desanicharei": "desanichar",
    "desanichareis": "desanichar",
    "desanicharem": "desanichar",
    "desanicharemos": "desanichar",
    "desanichares": "desanichar",
    "desanicharia": "desanichar",
    "desanichariam": "desanichar",
    "desanicharias": "desanichar",
    "desanicharmo": "desanichar",
    "desanicharmos": "desanichar",
    "desanichará": "desanichar",
    "desanicharás": "desanichar",
    "desanicharão": "desanichar",
    "desanicharíamos": "desanichar",
    "desanicharíeis": "desanichar",
    "desanichas": "desanichar",
    "desanichasse": "desanichar",
    "desanichassem": "desanichar",
    "desanichasses": "desanichar",
    "desanichaste": "desanichar",
    "desanichastes": "desanichar",
    "desanichava": "desanichar",
    "desanichavam": "desanichar",
    "desanichavas": "desanichar",
    "desaniche": "desanichar",
    "desanichei": "desanichar",
    "desanicheis": "desanichar",
    "desanichem": "desanichar",
    "desanichemo": "desanichar",
    "desanichemos": "desanichar",
    "desaniches": "desanichar",
    "desanicho": "desanichar",
    "desanichou": "desanichar",
    "desanichá": "desanichar",
    "desanichámo": "desanichar",
    "desanichámos": "desanichar",
    "desanicháramo": "desanichar",
    "desanicháramos": "desanichar",
    "desanichárei": "desanichar",
    "desanicháreis": "desanichar",
    "desanichásseis": "desanichar",
    "desanichássemos": "desanichar",
    "desanichávamo": "desanichar",
    "desanichávamos": "desanichar",
    "desanichávei": "desanichar",
    "desanicháveis": "desanichar",
    "desanima": "desanimar",
    "desanimada": "desanimar",
    "desanimadas": "desanimar",
    "desanimado": "desanimar",
    "desanimadora": "desanimador",
    "desanimadoras": "desanimador",
    "desanimadores": "desanimador",
    "desanimados": "desanimar",
    "desanimadíssima": "desanimado",
    "desanimadíssimas": "desanimado",
    "desanimadíssimo": "desanimado",
    "desanimadíssimos": "desanimado",
    "desanimai": "desanimar",
    "desanimais": "desanimar",
    "desanimam": "desanimar",
    "desanimamo": "desanimar",
    "desanimamos": "desanimar",
    "desanimando": "desanimar",
    "desanimara": "desanimar",
    "desanimaram": "desanimar",
    "desanimaras": "desanimar",
    "desanimarde": "desanimar",
    "desanimardes": "desanimar",
    "desanimare": "desanimar",
    "desanimarei": "desanimar",
    "desanimareis": "desanimar",
    "desanimarem": "desanimar",
    "desanimaremos": "desanimar",
    "desanimares": "desanimar",
    "desanimaria": "desanimar",
    "desanimariam": "desanimar",
    "desanimarias": "desanimar",
    "desanimarmo": "desanimar",
    "desanimarmos": "desanimar",
    "desanimará": "desanimar",
    "desanimarás": "desanimar",
    "desanimarão": "desanimar",
    "desanimaríamos": "desanimar",
    "desanimaríeis": "desanimar",
    "desanimas": "desanimar",
    "desanimasse": "desanimar",
    "desanimassem": "desanimar",
    "desanimasses": "desanimar",
    "desanimaste": "desanimar",
    "desanimastes": "desanimar",
    "desanimava": "desanimar",
    "desanimavam": "desanimar",
    "desanimavas": "desanimar",
    "desanimações": "desanimação",
    "desanime": "desanimar",
    "desanimei": "desanimar",
    "desanimeis": "desanimar",
    "desanimem": "desanimar",
    "desanimemo": "desanimar",
    "desanimemos": "desanimar",
    "desanimes": "desanimar",
    "desanimo": "desanimar",
    "desanimou": "desanimar",
    "desanimá": "desanimar",
    "desanimámo": "desanimar",
    "desanimámos": "desanimar",
    "desanimáramo": "desanimar",
    "desanimáramos": "desanimar",
    "desanimárei": "desanimar",
    "desanimáreis": "desanimar",
    "desanimásseis": "desanimar",
    "desanimássemos": "desanimar",
    "desanimávamo": "desanimar",
    "desanimávamos": "desanimar",
    "desanimávei": "desanimar",
    "desanimáveis": "desanimar",
    "desaninha": "desaninhar",
    "desaninhada": "desaninhar",
    "desaninhadas": "desaninhar",
    "desaninhado": "desaninhar",
    "desaninhados": "desaninhar",
    "desaninhai": "desaninhar",
    "desaninhais": "desaninhar",
    "desaninham": "desaninhar",
    "desaninhamo": "desaninhar",
    "desaninhamos": "desaninhar",
    "desaninhando": "desaninhar",
    "desaninhara": "desaninhar",
    "desaninharam": "desaninhar",
    "desaninharas": "desaninhar",
    "desaninharde": "desaninhar",
    "desaninhardes": "desaninhar",
    "desaninhare": "desaninhar",
    "desaninharei": "desaninhar",
    "desaninhareis": "desaninhar",
    "desaninharem": "desaninhar",
    "desaninharemos": "desaninhar",
    "desaninhares": "desaninhar",
    "desaninharia": "desaninhar",
    "desaninhariam": "desaninhar",
    "desaninharias": "desaninhar",
    "desaninharmo": "desaninhar",
    "desaninharmos": "desaninhar",
    "desaninhará": "desaninhar",
    "desaninharás": "desaninhar",
    "desaninharão": "desaninhar",
    "desaninharíamos": "desaninhar",
    "desaninharíeis": "desaninhar",
    "desaninhas": "desaninhar",
    "desaninhasse": "desaninhar",
    "desaninhassem": "desaninhar",
    "desaninhasses": "desaninhar",
    "desaninhaste": "desaninhar",
    "desaninhastes": "desaninhar",
    "desaninhava": "desaninhar",
    "desaninhavam": "desaninhar",
    "desaninhavas": "desaninhar",
    "desaninhe": "desaninhar",
    "desaninhei": "desaninhar",
    "desaninheis": "desaninhar",
    "desaninhem": "desaninhar",
    "desaninhemo": "desaninhar",
    "desaninhemos": "desaninhar",
    "desaninhes": "desaninhar",
    "desaninho": "desaninhar",
    "desaninhou": "desaninhar",
    "desaninhá": "desaninhar",
    "desaninhámo": "desaninhar",
    "desaninhámos": "desaninhar",
    "desaninháramo": "desaninhar",
    "desaninháramos": "desaninhar",
    "desaninhárei": "desaninhar",
    "desaninháreis": "desaninhar",
    "desaninhásseis": "desaninhar",
    "desaninhássemos": "desaninhar",
    "desaninhávamo": "desaninhar",
    "desaninhávamos": "desaninhar",
    "desaninhávei": "desaninhar",
    "desaninháveis": "desaninhar",
    "desanoja": "desanojar",
    "desanojada": "desanojar",
    "desanojadas": "desanojar",
    "desanojado": "desanojar",
    "desanojados": "desanojar",
    "desanojai": "desanojar",
    "desanojais": "desanojar",
    "desanojam": "desanojar",
    "desanojamentos": "desanojamento",
    "desanojamo": "desanojar",
    "desanojamos": "desanojar",
    "desanojando": "desanojar",
    "desanojara": "desanojar",
    "desanojaram": "desanojar",
    "desanojaras": "desanojar",
    "desanojarde": "desanojar",
    "desanojardes": "desanojar",
    "desanojare": "desanojar",
    "desanojarei": "desanojar",
    "desanojareis": "desanojar",
    "desanojarem": "desanojar",
    "desanojaremos": "desanojar",
    "desanojares": "desanojar",
    "desanojaria": "desanojar",
    "desanojariam": "desanojar",
    "desanojarias": "desanojar",
    "desanojarmo": "desanojar",
    "desanojarmos": "desanojar",
    "desanojará": "desanojar",
    "desanojarás": "desanojar",
    "desanojarão": "desanojar",
    "desanojaríamos": "desanojar",
    "desanojaríeis": "desanojar",
    "desanojas": "desanojar",
    "desanojasse": "desanojar",
    "desanojassem": "desanojar",
    "desanojasses": "desanojar",
    "desanojaste": "desanojar",
    "desanojastes": "desanojar",
    "desanojava": "desanojar",
    "desanojavam": "desanojar",
    "desanojavas": "desanojar",
    "desanoje": "desanojar",
    "desanojei": "desanojar",
    "desanojeis": "desanojar",
    "desanojem": "desanojar",
    "desanojemo": "desanojar",
    "desanojemos": "desanojar",
    "desanojes": "desanojar",
    "desanojo": "desanojar",
    "desanojos": "desanojo",
    "desanojou": "desanojar",
    "desanojá": "desanojar",
    "desanojámo": "desanojar",
    "desanojámos": "desanojar",
    "desanojáramo": "desanojar",
    "desanojáramos": "desanojar",
    "desanojárei": "desanojar",
    "desanojáreis": "desanojar",
    "desanojásseis": "desanojar",
    "desanojássemos": "desanojar",
    "desanojávamo": "desanojar",
    "desanojávamos": "desanojar",
    "desanojávei": "desanojar",
    "desanojáveis": "desanojar",
    "desanque": "desancar",
    "desanquei": "desancar",
    "desanqueis": "desancar",
    "desanquem": "desancar",
    "desanquemo": "desancar",
    "desanquemos": "desancar",
    "desanques": "desancar",
    "desanuvia": "desanuviar",
    "desanuviada": "desanuviar",
    "desanuviadas": "desanuviar",
    "desanuviado": "desanuviar",
    "desanuviados": "desanuviar",
    "desanuviai": "desanuviar",
    "desanuviais": "desanuviar",
    "desanuviam": "desanuviar",
    "desanuviamentos": "desanuviamento",
    "desanuviamo": "desanuviar",
    "desanuviamos": "desanuviar",
    "desanuviando": "desanuviar",
    "desanuviara": "desanuviar",
    "desanuviaram": "desanuviar",
    "desanuviaras": "desanuviar",
    "desanuviarde": "desanuviar",
    "desanuviardes": "desanuviar",
    "desanuviare": "desanuviar",
    "desanuviarei": "desanuviar",
    "desanuviareis": "desanuviar",
    "desanuviarem": "desanuviar",
    "desanuviaremos": "desanuviar",
    "desanuviares": "desanuviar",
    "desanuviaria": "desanuviar",
    "desanuviariam": "desanuviar",
    "desanuviarias": "desanuviar",
    "desanuviarmo": "desanuviar",
    "desanuviarmos": "desanuviar",
    "desanuviará": "desanuviar",
    "desanuviarás": "desanuviar",
    "desanuviarão": "desanuviar",
    "desanuviaríamos": "desanuviar",
    "desanuviaríeis": "desanuviar",
    "desanuvias": "desanuviar",
    "desanuviasse": "desanuviar",
    "desanuviassem": "desanuviar",
    "desanuviasses": "desanuviar",
    "desanuviaste": "desanuviar",
    "desanuviastes": "desanuviar",
    "desanuviava": "desanuviar",
    "desanuviavam": "desanuviar",
    "desanuviavas": "desanuviar",
    "desanuvie": "desanuviar",
    "desanuviei": "desanuviar",
    "desanuvieis": "desanuviar",
    "desanuviem": "desanuviar",
    "desanuviemo": "desanuviar",
    "desanuviemos": "desanuviar",
    "desanuvies": "desanuviar",
    "desanuvio": "desanuviar",
    "desanuviou": "desanuviar",
    "desanuviá": "desanuviar",
    "desanuviámo": "desanuviar",
    "desanuviámos": "desanuviar",
    "desanuviáramo": "desanuviar",
    "desanuviáramos": "desanuviar",
    "desanuviárei": "desanuviar",
    "desanuviáreis": "desanuviar",
    "desanuviásseis": "desanuviar",
    "desanuviássemos": "desanuviar",
    "desanuviávamo": "desanuviar",
    "desanuviávamos": "desanuviar",
    "desanuviávei": "desanuviar",
    "desanuviáveis": "desanuviar",
    "desapacienta": "desapacientar",
    "desapacientada": "desapacientar",
    "desapacientadas": "desapacientar",
    "desapacientado": "desapacientar",
    "desapacientados": "desapacientar",
    "desapacientai": "desapacientar",
    "desapacientais": "desapacientar",
    "desapacientam": "desapacientar",
    "desapacientamo": "desapacientar",
    "desapacientamos": "desapacientar",
    "desapacientando": "desapacientar",
    "desapacientara": "desapacientar",
    "desapacientaram": "desapacientar",
    "desapacientaras": "desapacientar",
    "desapacientarde": "desapacientar",
    "desapacientardes": "desapacientar",
    "desapacientare": "desapacientar",
    "desapacientarei": "desapacientar",
    "desapacientareis": "desapacientar",
    "desapacientarem": "desapacientar",
    "desapacientaremos": "desapacientar",
    "desapacientares": "desapacientar",
    "desapacientaria": "desapacientar",
    "desapacientariam": "desapacientar",
    "desapacientarias": "desapacientar",
    "desapacientarmo": "desapacientar",
    "desapacientarmos": "desapacientar",
    "desapacientará": "desapacientar",
    "desapacientarás": "desapacientar",
    "desapacientarão": "desapacientar",
    "desapacientaríamos": "desapacientar",
    "desapacientaríeis": "desapacientar",
    "desapacientas": "desapacientar",
    "desapacientasse": "desapacientar",
    "desapacientassem": "desapacientar",
    "desapacientasses": "desapacientar",
    "desapacientaste": "desapacientar",
    "desapacientastes": "desapacientar",
    "desapacientava": "desapacientar",
    "desapacientavam": "desapacientar",
    "desapacientavas": "desapacientar",
    "desapaciente": "desapacientar",
    "desapacientei": "desapacientar",
    "desapacienteis": "desapacientar",
    "desapacientem": "desapacientar",
    "desapacientemo": "desapacientar",
    "desapacientemos": "desapacientar",
    "desapacientes": "desapacientar",
    "desapaciento": "desapacientar",
    "desapacientou": "desapacientar",
    "desapacientá": "desapacientar",
    "desapacientámo": "desapacientar",
    "desapacientámos": "desapacientar",
    "desapacientáramo": "desapacientar",
    "desapacientáramos": "desapacientar",
    "desapacientárei": "desapacientar",
    "desapacientáreis": "desapacientar",
    "desapacientásseis": "desapacientar",
    "desapacientássemos": "desapacientar",
    "desapacientávamo": "desapacientar",
    "desapacientávamos": "desapacientar",
    "desapacientávei": "desapacientar",
    "desapacientáveis": "desapacientar",
    "desapadrinha": "desapadrinhar",
    "desapadrinhada": "desapadrinhar",
    "desapadrinhadas": "desapadrinhar",
    "desapadrinhado": "desapadrinhar",
    "desapadrinhados": "desapadrinhar",
    "desapadrinhai": "desapadrinhar",
    "desapadrinhais": "desapadrinhar",
    "desapadrinham": "desapadrinhar",
    "desapadrinhamo": "desapadrinhar",
    "desapadrinhamos": "desapadrinhar",
    "desapadrinhando": "desapadrinhar",
    "desapadrinhara": "desapadrinhar",
    "desapadrinharam": "desapadrinhar",
    "desapadrinharas": "desapadrinhar",
    "desapadrinharde": "desapadrinhar",
    "desapadrinhardes": "desapadrinhar",
    "desapadrinhare": "desapadrinhar",
    "desapadrinharei": "desapadrinhar",
    "desapadrinhareis": "desapadrinhar",
    "desapadrinharem": "desapadrinhar",
    "desapadrinharemos": "desapadrinhar",
    "desapadrinhares": "desapadrinhar",
    "desapadrinharia": "desapadrinhar",
    "desapadrinhariam": "desapadrinhar",
    "desapadrinharias": "desapadrinhar",
    "desapadrinharmo": "desapadrinhar",
    "desapadrinharmos": "desapadrinhar",
    "desapadrinhará": "desapadrinhar",
    "desapadrinharás": "desapadrinhar",
    "desapadrinharão": "desapadrinhar",
    "desapadrinharíamos": "desapadrinhar",
    "desapadrinharíeis": "desapadrinhar",
    "desapadrinhas": "desapadrinhar",
    "desapadrinhasse": "desapadrinhar",
    "desapadrinhassem": "desapadrinhar",
    "desapadrinhasses": "desapadrinhar",
    "desapadrinhaste": "desapadrinhar",
    "desapadrinhastes": "desapadrinhar",
    "desapadrinhava": "desapadrinhar",
    "desapadrinhavam": "desapadrinhar",
    "desapadrinhavas": "desapadrinhar",
    "desapadrinhe": "desapadrinhar",
    "desapadrinhei": "desapadrinhar",
    "desapadrinheis": "desapadrinhar",
    "desapadrinhem": "desapadrinhar",
    "desapadrinhemo": "desapadrinhar",
    "desapadrinhemos": "desapadrinhar",
    "desapadrinhes": "desapadrinhar",
    "desapadrinho": "desapadrinhar",
    "desapadrinhou": "desapadrinhar",
    "desapadrinhá": "desapadrinhar",
    "desapadrinhámo": "desapadrinhar",
    "desapadrinhámos": "desapadrinhar",
    "desapadrinháramo": "desapadrinhar",
    "desapadrinháramos": "desapadrinhar",
    "desapadrinhárei": "desapadrinhar",
    "desapadrinháreis": "desapadrinhar",
    "desapadrinhásseis": "desapadrinhar",
    "desapadrinhássemos": "desapadrinhar",
    "desapadrinhávamo": "desapadrinhar",
    "desapadrinhávamos": "desapadrinhar",
    "desapadrinhávei": "desapadrinhar",
    "desapadrinháveis": "desapadrinhar",
    "desapaixona": "desapaixonar",
    "desapaixonada": "desapaixonar",
    "desapaixonadas": "desapaixonar",
    "desapaixonado": "desapaixonar",
    "desapaixonados": "desapaixonar",
    "desapaixonai": "desapaixonar",
    "desapaixonais": "desapaixonar",
    "desapaixonam": "desapaixonar",
    "desapaixonamo": "desapaixonar",
    "desapaixonamos": "desapaixonar",
    "desapaixonando": "desapaixonar",
    "desapaixonara": "desapaixonar",
    "desapaixonaram": "desapaixonar",
    "desapaixonaras": "desapaixonar",
    "desapaixonarde": "desapaixonar",
    "desapaixonardes": "desapaixonar",
    "desapaixonare": "desapaixonar",
    "desapaixonarei": "desapaixonar",
    "desapaixonareis": "desapaixonar",
    "desapaixonarem": "desapaixonar",
    "desapaixonaremos": "desapaixonar",
    "desapaixonares": "desapaixonar",
    "desapaixonaria": "desapaixonar",
    "desapaixonariam": "desapaixonar",
    "desapaixonarias": "desapaixonar",
    "desapaixonarmo": "desapaixonar",
    "desapaixonarmos": "desapaixonar",
    "desapaixonará": "desapaixonar",
    "desapaixonarás": "desapaixonar",
    "desapaixonarão": "desapaixonar",
    "desapaixonaríamos": "desapaixonar",
    "desapaixonaríeis": "desapaixonar",
    "desapaixonas": "desapaixonar",
    "desapaixonasse": "desapaixonar",
    "desapaixonassem": "desapaixonar",
    "desapaixonasses": "desapaixonar",
    "desapaixonaste": "desapaixonar",
    "desapaixonastes": "desapaixonar",
    "desapaixonava": "desapaixonar",
    "desapaixonavam": "desapaixonar",
    "desapaixonavas": "desapaixonar",
    "desapaixone": "desapaixonar",
    "desapaixonei": "desapaixonar",
    "desapaixoneis": "desapaixonar",
    "desapaixonem": "desapaixonar",
    "desapaixonemo": "desapaixonar",
    "desapaixonemos": "desapaixonar",
    "desapaixones": "desapaixonar",
    "desapaixono": "desapaixonar",
    "desapaixonou": "desapaixonar",
    "desapaixoná": "desapaixonar",
    "desapaixonámo": "desapaixonar",
    "desapaixonámos": "desapaixonar",
    "desapaixonáramo": "desapaixonar",
    "desapaixonáramos": "desapaixonar",
    "desapaixonárei": "desapaixonar",
    "desapaixonáreis": "desapaixonar",
    "desapaixonásseis": "desapaixonar",
    "desapaixonássemos": "desapaixonar",
    "desapaixonávamo": "desapaixonar",
    "desapaixonávamos": "desapaixonar",
    "desapaixonávei": "desapaixonar",
    "desapaixonáveis": "desapaixonar",
    "desaparafusa": "desaparafusar",
    "desaparafusada": "desaparafusar",
    "desaparafusadas": "desaparafusar",
    "desaparafusado": "desaparafusar",
    "desaparafusados": "desaparafusar",
    "desaparafusagens": "desaparafusagem",
    "desaparafusai": "desaparafusar",
    "desaparafusais": "desaparafusar",
    "desaparafusam": "desaparafusar",
    "desaparafusamentos": "desaparafusamento",
    "desaparafusamo": "desaparafusar",
    "desaparafusamos": "desaparafusar",
    "desaparafusando": "desaparafusar",
    "desaparafusara": "desaparafusar",
    "desaparafusaram": "desaparafusar",
    "desaparafusaras": "desaparafusar",
    "desaparafusarde": "desaparafusar",
    "desaparafusardes": "desaparafusar",
    "desaparafusare": "desaparafusar",
    "desaparafusarei": "desaparafusar",
    "desaparafusareis": "desaparafusar",
    "desaparafusarem": "desaparafusar",
    "desaparafusaremos": "desaparafusar",
    "desaparafusares": "desaparafusar",
    "desaparafusaria": "desaparafusar",
    "desaparafusariam": "desaparafusar",
    "desaparafusarias": "desaparafusar",
    "desaparafusarmo": "desaparafusar",
    "desaparafusarmos": "desaparafusar",
    "desaparafusará": "desaparafusar",
    "desaparafusarás": "desaparafusar",
    "desaparafusarão": "desaparafusar",
    "desaparafusaríamos": "desaparafusar",
    "desaparafusaríeis": "desaparafusar",
    "desaparafusas": "desaparafusar",
    "desaparafusasse": "desaparafusar",
    "desaparafusassem": "desaparafusar",
    "desaparafusasses": "desaparafusar",
    "desaparafusaste": "desaparafusar",
    "desaparafusastes": "desaparafusar",
    "desaparafusava": "desaparafusar",
    "desaparafusavam": "desaparafusar",
    "desaparafusavas": "desaparafusar",
    "desaparafuse": "desaparafusar",
    "desaparafusei": "desaparafusar",
    "desaparafuseis": "desaparafusar",
    "desaparafusem": "desaparafusar",
    "desaparafusemo": "desaparafusar",
    "desaparafusemos": "desaparafusar",
    "desaparafuses": "desaparafusar",
    "desaparafuso": "desaparafusar",
    "desaparafusou": "desaparafusar",
    "desaparafusá": "desaparafusar",
    "desaparafusámo": "desaparafusar",
    "desaparafusámos": "desaparafusar",
    "desaparafusáramo": "desaparafusar",
    "desaparafusáramos": "desaparafusar",
    "desaparafusárei": "desaparafusar",
    "desaparafusáreis": "desaparafusar",
    "desaparafusásseis": "desaparafusar",
    "desaparafusássemos": "desaparafusar",
    "desaparafusávamo": "desaparafusar",
    "desaparafusávamos": "desaparafusar",
    "desaparafusávei": "desaparafusar",
    "desaparafusáveis": "desaparafusar",
    "desaparatosa": "desaparatoso",
    "desaparatosas": "desaparatoso",
    "desaparatosos": "desaparatoso",
    "desaparece": "desaparecer",
    "desaparecei": "desaparecer",
    "desapareceis": "desaparecer",
    "desaparecem": "desaparecer",
    "desaparecemo": "desaparecer",
    "desaparecemos": "desaparecer",
    "desaparecendo": "desaparecer",
    "desaparecera": "desaparecer",
    "desapareceram": "desaparecer",
    "desapareceras": "desaparecer",
    "desaparecerdes": "desaparecer",
    "desaparecerei": "desaparecer",
    "desaparecereis": "desaparecer",
    "desaparecerem": "desaparecer",
    "desapareceremos": "desaparecer",
    "desapareceres": "desaparecer",
    "desapareceria": "desaparecer",
    "desapareceriam": "desaparecer",
    "desaparecerias": "desaparecer",
    "desaparecermo": "desaparecer",
    "desaparecermos": "desaparecer",
    "desaparecerá": "desaparecer",
    "desaparecerás": "desaparecer",
    "desaparecerão": "desaparecer",
    "desapareceríamos": "desaparecer",
    "desapareceríeis": "desaparecer",
    "desapareces": "desaparecer",
    "desaparecesse": "desaparecer",
    "desaparecessem": "desaparecer",
    "desaparecesses": "desaparecer",
    "desapareceste": "desaparecer",
    "desaparecestes": "desaparecer",
    "desapareceu": "desaparecer",
    "desapareci": "desaparecer",
    "desaparecia": "desaparecer",
    "desapareciam": "desaparecer",
    "desaparecias": "desaparecer",
    "desaparecida": "desaparecido",
    "desaparecidas": "desaparecido",
    "desaparecido": "desaparecer",
    "desaparecidos": "desaparecido",
    "desaparecimentos": "desaparecimento",
    "desaparecêramo": "desaparecer",
    "desaparecêramos": "desaparecer",
    "desaparecêreis": "desaparecer",
    "desaparecêsseis": "desaparecer",
    "desaparecêssemos": "desaparecer",
    "desaparecíamo": "desaparecer",
    "desaparecíamos": "desaparecer",
    "desaparecíeis": "desaparecer",
    "desaparelha": "desaparelhar",
    "desaparelhada": "desaparelhar",
    "desaparelhadas": "desaparelhar",
    "desaparelhado": "desaparelhar",
    "desaparelhados": "desaparelhar",
    "desaparelhai": "desaparelhar",
    "desaparelhais": "desaparelhar",
    "desaparelham": "desaparelhar",
    "desaparelhamentos": "desaparelhamento",
    "desaparelhamo": "desaparelhar",
    "desaparelhamos": "desaparelhar",
    "desaparelhando": "desaparelhar",
    "desaparelhara": "desaparelhar",
    "desaparelharam": "desaparelhar",
    "desaparelharas": "desaparelhar",
    "desaparelharde": "desaparelhar",
    "desaparelhardes": "desaparelhar",
    "desaparelhare": "desaparelhar",
    "desaparelharei": "desaparelhar",
    "desaparelhareis": "desaparelhar",
    "desaparelharem": "desaparelhar",
    "desaparelharemos": "desaparelhar",
    "desaparelhares": "desaparelhar",
    "desaparelharia": "desaparelhar",
    "desaparelhariam": "desaparelhar",
    "desaparelharias": "desaparelhar",
    "desaparelharmo": "desaparelhar",
    "desaparelharmos": "desaparelhar",
    "desaparelhará": "desaparelhar",
    "desaparelharás": "desaparelhar",
    "desaparelharão": "desaparelhar",
    "desaparelharíamos": "desaparelhar",
    "desaparelharíeis": "desaparelhar",
    "desaparelhas": "desaparelhar",
    "desaparelhasse": "desaparelhar",
    "desaparelhassem": "desaparelhar",
    "desaparelhasses": "desaparelhar",
    "desaparelhaste": "desaparelhar",
    "desaparelhastes": "desaparelhar",
    "desaparelhava": "desaparelhar",
    "desaparelhavam": "desaparelhar",
    "desaparelhavas": "desaparelhar",
    "desaparelhe": "desaparelhar",
    "desaparelhei": "desaparelhar",
    "desaparelheis": "desaparelhar",
    "desaparelhem": "desaparelhar",
    "desaparelhemo": "desaparelhar",
    "desaparelhemos": "desaparelhar",
    "desaparelhes": "desaparelhar",
    "desaparelho": "desaparelhar",
    "desaparelhos": "desaparelho",
    "desaparelhou": "desaparelhar",
    "desaparelhá": "desaparelhar",
    "desaparelhámo": "desaparelhar",
    "desaparelhámos": "desaparelhar",
    "desaparelháramo": "desaparelhar",
    "desaparelháramos": "desaparelhar",
    "desaparelhárei": "desaparelhar",
    "desaparelháreis": "desaparelhar",
    "desaparelhásseis": "desaparelhar",
    "desaparelhássemos": "desaparelhar",
    "desaparelhávamo": "desaparelhar",
    "desaparelhávamos": "desaparelhar",
    "desaparelhávei": "desaparelhar",
    "desaparelháveis": "desaparelhável",
    "desaparentada": "desaparentado",
    "desaparentadas": "desaparentado",
    "desaparentados": "desaparentado",
    "desapareça": "desaparecer",
    "desapareçais": "desaparecer",
    "desapareçam": "desaparecer",
    "desapareçamo": "desaparecer",
    "desapareçamos": "desaparecer",
    "desapareças": "desaparecer",
    "desapareço": "desaparecer",
    "desaparições": "desaparição",
    "desaparta": "desapartar",
    "desapartada": "desapartar",
    "desapartadas": "desapartar",
    "desapartado": "desapartar",
    "desapartados": "desapartar",
    "desapartai": "desapartar",
    "desapartais": "desapartar",
    "desapartam": "desapartar",
    "desapartamo": "desapartar",
    "desapartamos": "desapartar",
    "desapartando": "desapartar",
    "desapartara": "desapartar",
    "desapartaram": "desapartar",
    "desapartaras": "desapartar",
    "desapartarde": "desapartar",
    "desapartardes": "desapartar",
    "desapartare": "desapartar",
    "desapartarei": "desapartar",
    "desapartareis": "desapartar",
    "desapartarem": "desapartar",
    "desapartaremos": "desapartar",
    "desapartares": "desapartar",
    "desapartaria": "desapartar",
    "desapartariam": "desapartar",
    "desapartarias": "desapartar",
    "desapartarmo": "desapartar",
    "desapartarmos": "desapartar",
    "desapartará": "desapartar",
    "desapartarás": "desapartar",
    "desapartarão": "desapartar",
    "desapartaríamos": "desapartar",
    "desapartaríeis": "desapartar",
    "desapartas": "desapartar",
    "desapartasse": "desapartar",
    "desapartassem": "desapartar",
    "desapartasses": "desapartar",
    "desapartaste": "desapartar",
    "desapartastes": "desapartar",
    "desapartava": "desapartar",
    "desapartavam": "desapartar",
    "desapartavas": "desapartar",
    "desaparte": "desapartar",
    "desapartei": "desapartar",
    "desaparteis": "desapartar",
    "desapartem": "desapartar",
    "desapartemo": "desapartar",
    "desapartemos": "desapartar",
    "desapartes": "desapartar",
    "desaparto": "desapartar",
    "desapartou": "desapartar",
    "desapartá": "desapartar",
    "desapartámo": "desapartar",
    "desapartámos": "desapartar",
    "desapartáramo": "desapartar",
    "desapartáramos": "desapartar",
    "desapartárei": "desapartar",
    "desapartáreis": "desapartar",
    "desapartásseis": "desapartar",
    "desapartássemos": "desapartar",
    "desapartávamo": "desapartar",
    "desapartávamos": "desapartar",
    "desapartávei": "desapartar",
    "desapartáveis": "desapartar",
    "desapavora": "desapavorar",
    "desapavorada": "desapavorar",
    "desapavoradas": "desapavorar",
    "desapavorado": "desapavorar",
    "desapavorados": "desapavorar",
    "desapavorai": "desapavorar",
    "desapavorais": "desapavorar",
    "desapavoram": "desapavorar",
    "desapavoramo": "desapavorar",
    "desapavoramos": "desapavorar",
    "desapavorando": "desapavorar",
    "desapavorara": "desapavorar",
    "desapavoraram": "desapavorar",
    "desapavoraras": "desapavorar",
    "desapavorarde": "desapavorar",
    "desapavorardes": "desapavorar",
    "desapavorare": "desapavorar",
    "desapavorarei": "desapavorar",
    "desapavorareis": "desapavorar",
    "desapavorarem": "desapavorar",
    "desapavoraremos": "desapavorar",
    "desapavorares": "desapavorar",
    "desapavoraria": "desapavorar",
    "desapavorariam": "desapavorar",
    "desapavorarias": "desapavorar",
    "desapavorarmo": "desapavorar",
    "desapavorarmos": "desapavorar",
    "desapavorará": "desapavorar",
    "desapavorarás": "desapavorar",
    "desapavorarão": "desapavorar",
    "desapavoraríamos": "desapavorar",
    "desapavoraríeis": "desapavorar",
    "desapavoras": "desapavorar",
    "desapavorasse": "desapavorar",
    "desapavorassem": "desapavorar",
    "desapavorasses": "desapavorar",
    "desapavoraste": "desapavorar",
    "desapavorastes": "desapavorar",
    "desapavorava": "desapavorar",
    "desapavoravam": "desapavorar",
    "desapavoravas": "desapavorar",
    "desapavore": "desapavorar",
    "desapavorei": "desapavorar",
    "desapavoreis": "desapavorar",
    "desapavorem": "desapavorar",
    "desapavoremo": "desapavorar",
    "desapavoremos": "desapavorar",
    "desapavores": "desapavorar",
    "desapavoro": "desapavorar",
    "desapavorou": "desapavorar",
    "desapavorá": "desapavorar",
    "desapavorámo": "desapavorar",
    "desapavorámos": "desapavorar",
    "desapavoráramo": "desapavorar",
    "desapavoráramos": "desapavorar",
    "desapavorárei": "desapavorar",
    "desapavoráreis": "desapavorar",
    "desapavorásseis": "desapavorar",
    "desapavorássemos": "desapavorar",
    "desapavorávamo": "desapavorar",
    "desapavorávamos": "desapavorar",
    "desapavorávei": "desapavorar",
    "desapavoráveis": "desapavorar",
    "desapazigua": "desapaziguar",
    "desapaziguada": "desapaziguar",
    "desapaziguadas": "desapaziguar",
    "desapaziguado": "desapaziguar",
    "desapaziguados": "desapaziguar",
    "desapaziguai": "desapaziguar",
    "desapaziguais": "desapaziguar",
    "desapaziguam": "desapaziguar",
    "desapaziguamo": "desapaziguar",
    "desapaziguamos": "desapaziguar",
    "desapaziguando": "desapaziguar",
    "desapaziguara": "desapaziguar",
    "desapaziguaram": "desapaziguar",
    "desapaziguaras": "desapaziguar",
    "desapaziguarde": "desapaziguar",
    "desapaziguardes": "desapaziguar",
    "desapaziguare": "desapaziguar",
    "desapaziguarei": "desapaziguar",
    "desapaziguareis": "desapaziguar",
    "desapaziguarem": "desapaziguar",
    "desapaziguaremos": "desapaziguar",
    "desapaziguares": "desapaziguar",
    "desapaziguaria": "desapaziguar",
    "desapaziguariam": "desapaziguar",
    "desapaziguarias": "desapaziguar",
    "desapaziguarmo": "desapaziguar",
    "desapaziguarmos": "desapaziguar",
    "desapaziguará": "desapaziguar",
    "desapaziguarás": "desapaziguar",
    "desapaziguarão": "desapaziguar",
    "desapaziguaríamos": "desapaziguar",
    "desapaziguaríeis": "desapaziguar",
    "desapaziguas": "desapaziguar",
    "desapaziguasse": "desapaziguar",
    "desapaziguassem": "desapaziguar",
    "desapaziguasses": "desapaziguar",
    "desapaziguaste": "desapaziguar",
    "desapaziguastes": "desapaziguar",
    "desapaziguava": "desapaziguar",
    "desapaziguavam": "desapaziguar",
    "desapaziguavas": "desapaziguar",
    "desapaziguei": "desapaziguar",
    "desapazigueis": "desapaziguar",
    "desapaziguemo": "desapaziguar",
    "desapaziguemos": "desapaziguar",
    "desapazigues": "desapaziguar",
    "desapaziguo": "desapaziguar",
    "desapaziguou": "desapaziguar",
    "desapaziguá": "desapaziguar",
    "desapaziguámo": "desapaziguar",
    "desapaziguámos": "desapaziguar",
    "desapaziguáramo": "desapaziguar",
    "desapaziguáramos": "desapaziguar",
    "desapaziguárei": "desapaziguar",
    "desapaziguáreis": "desapaziguar",
    "desapaziguásseis": "desapaziguar",
    "desapaziguássemos": "desapaziguar",
    "desapaziguávamo": "desapaziguar",
    "desapaziguávamos": "desapaziguar",
    "desapaziguávei": "desapaziguar",
    "desapaziguáveis": "desapaziguar",
    "desapazigúe": "desapaziguar",
    "desapazigúem": "desapaziguar",
    "desapazigúes": "desapaziguar",
    "desapeada": "desapear",
    "desapeadas": "desapear",
    "desapeado": "desapear",
    "desapeados": "desapear",
    "desapeai": "desapear",
    "desapeais": "desapear",
    "desapeamo": "desapear",
    "desapeamos": "desapear",
    "desapeando": "desapear",
    "desapeara": "desapear",
    "desapearam": "desapear",
    "desapearas": "desapear",
    "desapearde": "desapear",
    "desapeardes": "desapear",
    "desapeare": "desapear",
    "desapearei": "desapear",
    "desapeareis": "desapear",
    "desapearem": "desapear",
    "desapearemos": "desapear",
    "desapeares": "desapear",
    "desapearia": "desapear",
    "desapeariam": "desapear",
    "desapearias": "desapear",
    "desapearmo": "desapear",
    "desapearmos": "desapear",
    "desapeará": "desapear",
    "desapearás": "desapear",
    "desapearão": "desapear",
    "desapearíamos": "desapear",
    "desapearíeis": "desapear",
    "desapeasse": "desapear",
    "desapeassem": "desapear",
    "desapeasses": "desapear",
    "desapeaste": "desapear",
    "desapeastes": "desapear",
    "desapeava": "desapear",
    "desapeavam": "desapear",
    "desapeavas": "desapear",
    "desapeei": "desapear",
    "desapeeis": "desapear",
    "desapeemo": "desapear",
    "desapeemos": "desapear",
    "desapega": "desapegar",
    "desapegada": "desapegar",
    "desapegadas": "desapegar",
    "desapegado": "desapegar",
    "desapegados": "desapegar",
    "desapegai": "desapegar",
    "desapegais": "desapegar",
    "desapegam": "desapegar",
    "desapegamentos": "desapegamento",
    "desapegamo": "desapegar",
    "desapegamos": "desapegar",
    "desapegando": "desapegar",
    "desapegara": "desapegar",
    "desapegaram": "desapegar",
    "desapegaras": "desapegar",
    "desapegarde": "desapegar",
    "desapegardes": "desapegar",
    "desapegare": "desapegar",
    "desapegarei": "desapegar",
    "desapegareis": "desapegar",
    "desapegarem": "desapegar",
    "desapegaremos": "desapegar",
    "desapegares": "desapegar",
    "desapegaria": "desapegar",
    "desapegariam": "desapegar",
    "desapegarias": "desapegar",
    "desapegarmo": "desapegar",
    "desapegarmos": "desapegar",
    "desapegará": "desapegar",
    "desapegarás": "desapegar",
    "desapegarão": "desapegar",
    "desapegaríamos": "desapegar",
    "desapegaríeis": "desapegar",
    "desapegas": "desapegar",
    "desapegasse": "desapegar",
    "desapegassem": "desapegar",
    "desapegasses": "desapegar",
    "desapegaste": "desapegar",
    "desapegastes": "desapegar",
    "desapegava": "desapegar",
    "desapegavam": "desapegar",
    "desapegavas": "desapegar",
    "desapego": "desapegar",
    "desapegos": "desapego",
    "desapegou": "desapegar",
    "desapegue": "desapegar",
    "desapeguei": "desapegar",
    "desapegueis": "desapegar",
    "desapeguem": "desapegar",
    "desapeguemo": "desapegar",
    "desapeguemos": "desapegar",
    "desapegues": "desapegar",
    "desapegá": "desapegar",
    "desapegámo": "desapegar",
    "desapegámos": "desapegar",
    "desapegáramo": "desapegar",
    "desapegáramos": "desapegar",
    "desapegárei": "desapegar",
    "desapegáreis": "desapegar",
    "desapegásseis": "desapegar",
    "desapegássemos": "desapegar",
    "desapegávamo": "desapegar",
    "desapegávamos": "desapegar",
    "desapegávei": "desapegar",
    "desapegáveis": "desapegar",
    "desapeia": "desapear",
    "desapeiam": "desapear",
    "desapeias": "desapear",
    "desapeie": "desapear",
    "desapeiem": "desapear",
    "desapeies": "desapear",
    "desapeio": "desapear",
    "desapeira": "desapeirar",
    "desapeirada": "desapeirar",
    "desapeiradas": "desapeirar",
    "desapeirado": "desapeirar",
    "desapeirados": "desapeirar",
    "desapeirai": "desapeirar",
    "desapeirais": "desapeirar",
    "desapeiram": "desapeirar",
    "desapeiramo": "desapeirar",
    "desapeiramos": "desapeirar",
    "desapeirando": "desapeirar",
    "desapeirara": "desapeirar",
    "desapeiraram": "desapeirar",
    "desapeiraras": "desapeirar",
    "desapeirarde": "desapeirar",
    "desapeirardes": "desapeirar",
    "desapeirare": "desapeirar",
    "desapeirarei": "desapeirar",
    "desapeirareis": "desapeirar",
    "desapeirarem": "desapeirar",
    "desapeiraremos": "desapeirar",
    "desapeirares": "desapeirar",
    "desapeiraria": "desapeirar",
    "desapeirariam": "desapeirar",
    "desapeirarias": "desapeirar",
    "desapeirarmo": "desapeirar",
    "desapeirarmos": "desapeirar",
    "desapeirará": "desapeirar",
    "desapeirarás": "desapeirar",
    "desapeirarão": "desapeirar",
    "desapeiraríamos": "desapeirar",
    "desapeiraríeis": "desapeirar",
    "desapeiras": "desapeirar",
    "desapeirasse": "desapeirar",
    "desapeirassem": "desapeirar",
    "desapeirasses": "desapeirar",
    "desapeiraste": "desapeirar",
    "desapeirastes": "desapeirar",
    "desapeirava": "desapeirar",
    "desapeiravam": "desapeirar",
    "desapeiravas": "desapeirar",
    "desapeire": "desapeirar",
    "desapeirei": "desapeirar",
    "desapeireis": "desapeirar",
    "desapeirem": "desapeirar",
    "desapeiremo": "desapeirar",
    "desapeiremos": "desapeirar",
    "desapeires": "desapeirar",
    "desapeiro": "desapeirar",
    "desapeirou": "desapeirar",
    "desapeirá": "desapeirar",
    "desapeirámo": "desapeirar",
    "desapeirámos": "desapeirar",
    "desapeiráramo": "desapeirar",
    "desapeiráramos": "desapeirar",
    "desapeirárei": "desapeirar",
    "desapeiráreis": "desapeirar",
    "desapeirásseis": "desapeirar",
    "desapeirássemos": "desapeirar",
    "desapeirávamo": "desapeirar",
    "desapeirávamos": "desapeirar",
    "desapeirávei": "desapeirar",
    "desapeiráveis": "desapeirar",
    "desapeou": "desapear",
    "desaperceba": "desaperceber",
    "desapercebais": "desaperceber",
    "desapercebam": "desaperceber",
    "desapercebamo": "desaperceber",
    "desapercebamos": "desaperceber",
    "desapercebas": "desaperceber",
    "desapercebe": "desaperceber",
    "desapercebei": "desaperceber",
    "desapercebeis": "desaperceber",
    "desapercebem": "desaperceber",
    "desapercebemo": "desaperceber",
    "desapercebemos": "desaperceber",
    "desapercebendo": "desaperceber",
    "desapercebera": "desaperceber",
    "desaperceberam": "desaperceber",
    "desaperceberas": "desaperceber",
    "desaperceberde": "desaperceber",
    "desaperceberdes": "desaperceber",
    "desapercebere": "desaperceber",
    "desaperceberei": "desaperceber",
    "desapercebereis": "desaperceber",
    "desaperceberem": "desaperceber",
    "desaperceberemos": "desaperceber",
    "desaperceberes": "desaperceber",
    "desaperceberia": "desaperceber",
    "desaperceberiam": "desaperceber",
    "desaperceberias": "desaperceber",
    "desapercebermo": "desaperceber",
    "desapercebermos": "desaperceber",
    "desaperceberá": "desaperceber",
    "desaperceberás": "desaperceber",
    "desaperceberão": "desaperceber",
    "desaperceberíamos": "desaperceber",
    "desaperceberíeis": "desaperceber",
    "desapercebes": "desaperceber",
    "desapercebesse": "desaperceber",
    "desapercebessem": "desaperceber",
    "desapercebesses": "desaperceber",
    "desapercebeste": "desaperceber",
    "desapercebestes": "desaperceber",
    "desapercebeu": "desaperceber",
    "desapercebi": "desaperceber",
    "desapercebia": "desaperceber",
    "desapercebiam": "desaperceber",
    "desapercebias": "desaperceber",
    "desapercebida": "desapercebido",
    "desapercebidas": "desapercebido",
    "desapercebido": "desaperceber",
    "desapercebidos": "desapercebido",
    "desapercebimentos": "desapercebimento",
    "desapercebo": "desaperceber",
    "desapercebê": "desaperceber",
    "desapercebêramo": "desaperceber",
    "desapercebêramos": "desaperceber",
    "desapercebêrei": "desaperceber",
    "desapercebêreis": "desaperceber",
    "desapercebêsseis": "desaperceber",
    "desapercebêssemos": "desaperceber",
    "desapercebíamo": "desaperceber",
    "desapercebíamos": "desaperceber",
    "desapercebíei": "desaperceber",
    "desapercebíeis": "desaperceber",
    "desaperra": "desaperrar",
    "desaperrada": "desaperrar",
    "desaperradas": "desaperrar",
    "desaperrado": "desaperrar",
    "desaperrados": "desaperrar",
    "desaperrai": "desaperrar",
    "desaperrais": "desaperrar",
    "desaperram": "desaperrar",
    "desaperramo": "desaperrar",
    "desaperramos": "desaperrar",
    "desaperrando": "desaperrar",
    "desaperrara": "desaperrar",
    "desaperraram": "desaperrar",
    "desaperraras": "desaperrar",
    "desaperrarde": "desaperrar",
    "desaperrardes": "desaperrar",
    "desaperrare": "desaperrar",
    "desaperrarei": "desaperrar",
    "desaperrareis": "desaperrar",
    "desaperrarem": "desaperrar",
    "desaperraremos": "desaperrar",
    "desaperrares": "desaperrar",
    "desaperraria": "desaperrar",
    "desaperrariam": "desaperrar",
    "desaperrarias": "desaperrar",
    "desaperrarmo": "desaperrar",
    "desaperrarmos": "desaperrar",
    "desaperrará": "desaperrar",
    "desaperrarás": "desaperrar",
    "desaperrarão": "desaperrar",
    "desaperraríamos": "desaperrar",
    "desaperraríeis": "desaperrar",
    "desaperras": "desaperrar",
    "desaperrasse": "desaperrar",
    "desaperrassem": "desaperrar",
    "desaperrasses": "desaperrar",
    "desaperraste": "desaperrar",
    "desaperrastes": "desaperrar",
    "desaperrava": "desaperrar",
    "desaperravam": "desaperrar",
    "desaperravas": "desaperrar",
    "desaperre": "desaperrar",
    "desaperrei": "desaperrar",
    "desaperreis": "desaperrar",
    "desaperrem": "desaperrar",
    "desaperremo": "desaperrar",
    "desaperremos": "desaperrar",
    "desaperres": "desaperrar",
    "desaperro": "desaperrar",
    "desaperrou": "desaperrar",
    "desaperrá": "desaperrar",
    "desaperrámo": "desaperrar",
    "desaperrámos": "desaperrar",
    "desaperráramo": "desaperrar",
    "desaperráramos": "desaperrar",
    "desaperrárei": "desaperrar",
    "desaperráreis": "desaperrar",
    "desaperrásseis": "desaperrar",
    "desaperrássemos": "desaperrar",
    "desaperrávamo": "desaperrar",
    "desaperrávamos": "desaperrar",
    "desaperrávei": "desaperrar",
    "desaperráveis": "desaperrar",
    "desaperta": "desapertar",
    "desapertada": "desapertar",
    "desapertadas": "desapertar",
    "desapertado": "desapertar",
    "desapertados": "desapertar",
    "desapertai": "desapertar",
    "desapertais": "desapertar",
    "desapertam": "desapertar",
    "desapertamo": "desapertar",
    "desapertamos": "desapertar",
    "desapertando": "desapertar",
    "desapertara": "desapertar",
    "desapertaram": "desapertar",
    "desapertaras": "desapertar",
    "desapertarde": "desapertar",
    "desapertardes": "desapertar",
    "desapertare": "desapertar",
    "desapertarei": "desapertar",
    "desapertareis": "desapertar",
    "desapertarem": "desapertar",
    "desapertaremos": "desapertar",
    "desapertares": "desapertar",
    "desapertaria": "desapertar",
    "desapertariam": "desapertar",
    "desapertarias": "desapertar",
    "desapertarmo": "desapertar",
    "desapertarmos": "desapertar",
    "desapertará": "desapertar",
    "desapertarás": "desapertar",
    "desapertarão": "desapertar",
    "desapertaríamos": "desapertar",
    "desapertaríeis": "desapertar",
    "desapertas": "desapertar",
    "desapertasse": "desapertar",
    "desapertassem": "desapertar",
    "desapertasses": "desapertar",
    "desapertaste": "desapertar",
    "desapertastes": "desapertar",
    "desapertava": "desapertar",
    "desapertavam": "desapertar",
    "desapertavas": "desapertar",
    "desaperte": "desapertar",
    "desapertei": "desapertar",
    "desaperteis": "desapertar",
    "desapertem": "desapertar",
    "desapertemo": "desapertar",
    "desapertemos": "desapertar",
    "desapertes": "desapertar",
    "desaperto": "desapertar",
    "desapertos": "desaperto",
    "desapertou": "desapertar",
    "desapertá": "desapertar",
    "desapertámo": "desapertar",
    "desapertámos": "desapertar",
    "desapertáramo": "desapertar",
    "desapertáramos": "desapertar",
    "desapertárei": "desapertar",
    "desapertáreis": "desapertar",
    "desapertásseis": "desapertar",
    "desapertássemos": "desapertar",
    "desapertávamo": "desapertar",
    "desapertávamos": "desapertar",
    "desapertávei": "desapertar",
    "desapertáveis": "desapertável",
    "desapeá": "desapear",
    "desapeámo": "desapear",
    "desapeámos": "desapear",
    "desapeáramo": "desapear",
    "desapeáramos": "desapear",
    "desapeárei": "desapear",
    "desapeáreis": "desapear",
    "desapeásseis": "desapear",
    "desapeássemos": "desapear",
    "desapeávamo": "desapear",
    "desapeávamos": "desapear",
    "desapeávei": "desapear",
    "desapeáveis": "desapear",
    "desapeçonhenta": "onhentar",
    "desapeçonhentada": "desapeçonhentar",
    "desapeçonhentadas": "desapeçonhentar",
    "desapeçonhentado": "desapeçonhentar",
    "desapeçonhentados": "desapeçonhentar",
    "desapeçonhentai": "desapeçonhentar",
    "desapeçonhentais": "desapeçonhentar",
    "desapeçonhentam": "desapeçonhentar",
    "desapeçonhentamo": "desapeçonhentar",
    "desapeçonhentamos": "desapeçonhentar",
    "desapeçonhentando": "desapeçonhentar",
    "desapeçonhentar": "onhentar",
    "desapeçonhentara": "onhentar",
    "desapeçonhentaram": "onhentar",
    "desapeçonhentaras": "desapeçonhentar",
    "desapeçonhentarde": "desapeçonhentar",
    "desapeçonhentardes": "desapeçonhentar",
    "desapeçonhentare": "desapeçonhentar",
    "desapeçonhentarei": "desapeçonhentar",
    "desapeçonhentareis": "desapeçonhentar",
    "desapeçonhentarem": "onhentar",
    "desapeçonhentaremos": "desapeçonhentar",
    "desapeçonhentares": "desapeçonhentar",
    "desapeçonhentaria": "onhentar",
    "desapeçonhentariam": "desapeçonhentar",
    "desapeçonhentarias": "desapeçonhentar",
    "desapeçonhentarmo": "desapeçonhentar",
    "desapeçonhentarmos": "desapeçonhentar",
    "desapeçonhentará": "desapeçonhentar",
    "desapeçonhentarás": "desapeçonhentar",
    "desapeçonhentarão": "desapeçonhentar",
    "desapeçonhentaríamos": "desapeçonhentar",
    "desapeçonhentaríeis": "desapeçonhentar",
    "desapeçonhentas": "desapeçonhentar",
    "desapeçonhentasse": "onhentar",
    "desapeçonhentassem": "desapeçonhentar",
    "desapeçonhentasses": "desapeçonhentar",
    "desapeçonhentaste": "desapeçonhentar",
    "desapeçonhentastes": "desapeçonhentar",
    "desapeçonhentava": "onhentar",
    "desapeçonhentavam": "desapeçonhentar",
    "desapeçonhentavas": "desapeçonhentar",
    "desapeçonhente": "onhentar",
    "desapeçonhentei": "desapeçonhentar",
    "desapeçonhenteis": "desapeçonhentar",
    "desapeçonhentem": "onhentar",
    "desapeçonhentemo": "desapeçonhentar",
    "desapeçonhentemos": "desapeçonhentar",
    "desapeçonhentes": "desapeçonhentar",
    "desapeçonhento": "desapeçonhentar",
    "desapeçonhentou": "desapeçonhentar",
    "desapeçonhentá": "onhentar",
    "desapeçonhentámo": "desapeçonhentar",
    "desapeçonhentámos": "desapeçonhentar",
    "desapeçonhentáramo": "desapeçonhentar",
    "desapeçonhentáramos": "desapeçonhentar",
    "desapeçonhentárei": "desapeçonhentar",
    "desapeçonhentáreis": "desapeçonhentar",
    "desapeçonhentásseis": "desapeçonhentar",
    "desapeçonhentássemos": "desapeçonhentar",
    "desapeçonhentávamo": "desapeçonhentar",
    "desapeçonhentávamos": "desapeçonhentar",
    "desapeçonhentávei": "desapeçonhentar",
    "desapeçonhentáveis": "desapeçonhentar",
    "desapieda": "desapiedar",
    "desapiedada": "desapiedar",
    "desapiedadas": "desapiedar",
    "desapiedado": "desapiedar",
    "desapiedados": "desapiedar",
    "desapiedai": "desapiedar",
    "desapiedais": "desapiedar",
    "desapiedam": "desapiedar",
    "desapiedamo": "desapiedar",
    "desapiedamos": "desapiedar",
    "desapiedando": "desapiedar",
    "desapiedara": "desapiedar",
    "desapiedaram": "desapiedar",
    "desapiedaras": "desapiedar",
    "desapiedarde": "desapiedar",
    "desapiedardes": "desapiedar",
    "desapiedare": "desapiedar",
    "desapiedarei": "desapiedar",
    "desapiedareis": "desapiedar",
    "desapiedarem": "desapiedar",
    "desapiedaremos": "desapiedar",
    "desapiedares": "desapiedar",
    "desapiedaria": "desapiedar",
    "desapiedariam": "desapiedar",
    "desapiedarias": "desapiedar",
    "desapiedarmo": "desapiedar",
    "desapiedarmos": "desapiedar",
    "desapiedará": "desapiedar",
    "desapiedarás": "desapiedar",
    "desapiedarão": "desapiedar",
    "desapiedaríamos": "desapiedar",
    "desapiedaríeis": "desapiedar",
    "desapiedas": "desapiedar",
    "desapiedasse": "desapiedar",
    "desapiedassem": "desapiedar",
    "desapiedasses": "desapiedar",
    "desapiedaste": "desapiedar",
    "desapiedastes": "desapiedar",
    "desapiedava": "desapiedar",
    "desapiedavam": "desapiedar",
    "desapiedavas": "desapiedar",
    "desapiede": "desapiedar",
    "desapiedei": "desapiedar",
    "desapiedeis": "desapiedar",
    "desapiedem": "desapiedar",
    "desapiedemo": "desapiedar",
    "desapiedemos": "desapiedar",
    "desapiedes": "desapiedar",
    "desapiedo": "desapiedar",
    "desapiedou": "desapiedar",
    "desapiedá": "desapiedar",
    "desapiedámo": "desapiedar",
    "desapiedámos": "desapiedar",
    "desapiedáramo": "desapiedar",
    "desapiedáramos": "desapiedar",
    "desapiedárei": "desapiedar",
    "desapiedáreis": "desapiedar",
    "desapiedásseis": "desapiedar",
    "desapiedássemos": "desapiedar",
    "desapiedávamo": "desapiedar",
    "desapiedávamos": "desapiedar",
    "desapiedávei": "desapiedar",
    "desapiedáveis": "desapiedar",
    "desaplauda": "desaplaudir",
    "desaplaudais": "desaplaudir",
    "desaplaudam": "desaplaudir",
    "desaplaudamo": "desaplaudir",
    "desaplaudamos": "desaplaudir",
    "desaplaudas": "desaplaudir",
    "desaplaude": "desaplaudir",
    "desaplaudem": "desaplaudir",
    "desaplaudes": "desaplaudir",
    "desaplaudi": "desaplaudir",
    "desaplaudia": "desaplaudir",
    "desaplaudiam": "desaplaudir",
    "desaplaudias": "desaplaudir",
    "desaplaudida": "desaplaudir",
    "desaplaudidas": "desaplaudir",
    "desaplaudido": "desaplaudir",
    "desaplaudidos": "desaplaudir",
    "desaplaudimo": "desaplaudir",
    "desaplaudimos": "desaplaudir",
    "desaplaudindo": "desaplaudir",
    "desaplaudira": "desaplaudir",
    "desaplaudiram": "desaplaudir",
    "desaplaudiras": "desaplaudir",
    "desaplaudirde": "desaplaudir",
    "desaplaudirdes": "desaplaudir",
    "desaplaudire": "desaplaudir",
    "desaplaudirei": "desaplaudir",
    "desaplaudireis": "desaplaudir",
    "desaplaudirem": "desaplaudir",
    "desaplaudiremos": "desaplaudir",
    "desaplaudires": "desaplaudir",
    "desaplaudiria": "desaplaudir",
    "desaplaudiriam": "desaplaudir",
    "desaplaudirias": "desaplaudir",
    "desaplaudirmo": "desaplaudir",
    "desaplaudirmos": "desaplaudir",
    "desaplaudirá": "desaplaudir",
    "desaplaudirás": "desaplaudir",
    "desaplaudirão": "desaplaudir",
    "desaplaudiríamos": "desaplaudir",
    "desaplaudiríeis": "desaplaudir",
    "desaplaudis": "desaplaudir",
    "desaplaudisse": "desaplaudir",
    "desaplaudissem": "desaplaudir",
    "desaplaudisses": "desaplaudir",
    "desaplaudiste": "desaplaudir",
    "desaplaudistes": "desaplaudir",
    "desaplaudiu": "desaplaudir",
    "desaplaudo": "desaplaudir",
    "desaplaudíamo": "desaplaudir",
    "desaplaudíamos": "desaplaudir",
    "desaplaudíei": "desaplaudir",
    "desaplaudíeis": "desaplaudir",
    "desaplaudíramo": "desaplaudir",
    "desaplaudíramos": "desaplaudir",
    "desaplaudírei": "desaplaudir",
    "desaplaudíreis": "desaplaudir",
    "desaplaudísseis": "desaplaudir",
    "desaplaudíssemos": "desaplaudir",
    "desaplausos": "desaplauso",
    "desaplica": "desaplicar",
    "desaplicada": "desaplicar",
    "desaplicadas": "desaplicar",
    "desaplicado": "desaplicar",
    "desaplicados": "desaplicar",
    "desaplicai": "desaplicar",
    "desaplicais": "desaplicar",
    "desaplicam": "desaplicar",
    "desaplicamo": "desaplicar",
    "desaplicamos": "desaplicar",
    "desaplicando": "desaplicar",
    "desaplicara": "desaplicar",
    "desaplicaram": "desaplicar",
    "desaplicaras": "desaplicar",
    "desaplicarde": "desaplicar",
    "desaplicardes": "desaplicar",
    "desaplicare": "desaplicar",
    "desaplicarei": "desaplicar",
    "desaplicareis": "desaplicar",
    "desaplicarem": "desaplicar",
    "desaplicaremos": "desaplicar",
    "desaplicares": "desaplicar",
    "desaplicaria": "desaplicar",
    "desaplicariam": "desaplicar",
    "desaplicarias": "desaplicar",
    "desaplicarmo": "desaplicar",
    "desaplicarmos": "desaplicar",
    "desaplicará": "desaplicar",
    "desaplicarás": "desaplicar",
    "desaplicarão": "desaplicar",
    "desaplicaríamos": "desaplicar",
    "desaplicaríeis": "desaplicar",
    "desaplicas": "desaplicar",
    "desaplicasse": "desaplicar",
    "desaplicassem": "desaplicar",
    "desaplicasses": "desaplicar",
    "desaplicaste": "desaplicar",
    "desaplicastes": "desaplicar",
    "desaplicava": "desaplicar",
    "desaplicavam": "desaplicar",
    "desaplicavas": "desaplicar",
    "desaplicações": "desaplicação",
    "desaplico": "desaplicar",
    "desaplicou": "desaplicar",
    "desaplicá": "desaplicar",
    "desaplicámo": "desaplicar",
    "desaplicámos": "desaplicar",
    "desaplicáramo": "desaplicar",
    "desaplicáramos": "desaplicar",
    "desaplicárei": "desaplicar",
    "desaplicáreis": "desaplicar",
    "desaplicásseis": "desaplicar",
    "desaplicássemos": "desaplicar",
    "desaplicávamo": "desaplicar",
    "desaplicávamos": "desaplicar",
    "desaplicávei": "desaplicar",
    "desaplicáveis": "desaplicar",
    "desaplique": "desaplicar",
    "desapliquei": "desaplicar",
    "desapliqueis": "desaplicar",
    "desapliquem": "desaplicar",
    "desapliquemo": "desaplicar",
    "desapliquemos": "desaplicar",
    "desapliques": "desaplicar",
    "desapodera": "desapoderar",
    "desapoderada": "desapoderar",
    "desapoderadas": "desapoderar",
    "desapoderado": "desapoderar",
    "desapoderados": "desapoderar",
    "desapoderai": "desapoderar",
    "desapoderais": "desapoderar",
    "desapoderam": "desapoderar",
    "desapoderamo": "desapoderar",
    "desapoderamos": "desapoderar",
    "desapoderando": "desapoderar",
    "desapoderara": "desapoderar",
    "desapoderaram": "desapoderar",
    "desapoderaras": "desapoderar",
    "desapoderarde": "desapoderar",
    "desapoderardes": "desapoderar",
    "desapoderare": "desapoderar",
    "desapoderarei": "desapoderar",
    "desapoderareis": "desapoderar",
    "desapoderarem": "desapoderar",
    "desapoderaremos": "desapoderar",
    "desapoderares": "desapoderar",
    "desapoderaria": "desapoderar",
    "desapoderariam": "desapoderar",
    "desapoderarias": "desapoderar",
    "desapoderarmo": "desapoderar",
    "desapoderarmos": "desapoderar",
    "desapoderará": "desapoderar",
    "desapoderarás": "desapoderar",
    "desapoderarão": "desapoderar",
    "desapoderaríamos": "desapoderar",
    "desapoderaríeis": "desapoderar",
    "desapoderas": "desapoderar",
    "desapoderasse": "desapoderar",
    "desapoderassem": "desapoderar",
    "desapoderasses": "desapoderar",
    "desapoderaste": "desapoderar",
    "desapoderastes": "desapoderar",
    "desapoderava": "desapoderar",
    "desapoderavam": "desapoderar",
    "desapoderavas": "desapoderar",
    "desapodere": "desapoderar",
    "desapoderei": "desapoderar",
    "desapodereis": "desapoderar",
    "desapoderem": "desapoderar",
    "desapoderemo": "desapoderar",
    "desapoderemos": "desapoderar",
    "desapoderes": "desapoderar",
    "desapodero": "desapoderar",
    "desapoderou": "desapoderar",
    "desapoderá": "desapoderar",
    "desapoderámo": "desapoderar",
    "desapoderámos": "desapoderar",
    "desapoderáramo": "desapoderar",
    "desapoderáramos": "desapoderar",
    "desapoderárei": "desapoderar",
    "desapoderáreis": "desapoderar",
    "desapoderásseis": "desapoderar",
    "desapoderássemos": "desapoderar",
    "desapoderávamo": "desapoderar",
    "desapoderávamos": "desapoderar",
    "desapoderávei": "desapoderar",
    "desapoderáveis": "desapoderar",
    "desapoia": "desapoiar",
    "desapoiada": "desapoiar",
    "desapoiadas": "desapoiar",
    "desapoiado": "desapoiar",
    "desapoiados": "desapoiar",
    "desapoiai": "desapoiar",
    "desapoiais": "desapoiar",
    "desapoiam": "desapoiar",
    "desapoiamo": "desapoiar",
    "desapoiamos": "desapoiar",
    "desapoiando": "desapoiar",
    "desapoiara": "desapoiar",
    "desapoiaram": "desapoiar",
    "desapoiaras": "desapoiar",
    "desapoiarde": "desapoiar",
    "desapoiardes": "desapoiar",
    "desapoiare": "desapoiar",
    "desapoiarei": "desapoiar",
    "desapoiareis": "desapoiar",
    "desapoiarem": "desapoiar",
    "desapoiaremos": "desapoiar",
    "desapoiares": "desapoiar",
    "desapoiaria": "desapoiar",
    "desapoiariam": "desapoiar",
    "desapoiarias": "desapoiar",
    "desapoiarmo": "desapoiar",
    "desapoiarmos": "desapoiar",
    "desapoiará": "desapoiar",
    "desapoiarás": "desapoiar",
    "desapoiarão": "desapoiar",
    "desapoiaríamos": "desapoiar",
    "desapoiaríeis": "desapoiar",
    "desapoias": "desapoiar",
    "desapoiasse": "desapoiar",
    "desapoiassem": "desapoiar",
    "desapoiasses": "desapoiar",
    "desapoiaste": "desapoiar",
    "desapoiastes": "desapoiar",
    "desapoiava": "desapoiar",
    "desapoiavam": "desapoiar",
    "desapoiavas": "desapoiar",
    "desapoie": "desapoiar",
    "desapoiei": "desapoiar",
    "desapoieis": "desapoiar",
    "desapoiem": "desapoiar",
    "desapoiemo": "desapoiar",
    "desapoiemos": "desapoiar",
    "desapoies": "desapoiar",
    "desapoio": "desapoiar",
    "desapoios": "desapoio",
    "desapoiou": "desapoiar",
    "desapoiá": "desapoiar",
    "desapoiámo": "desapoiar",
    "desapoiámos": "desapoiar",
    "desapoiáramo": "desapoiar",
    "desapoiáramos": "desapoiar",
    "desapoiárei": "desapoiar",
    "desapoiáreis": "desapoiar",
    "desapoiásseis": "desapoiar",
    "desapoiássemos": "desapoiar",
    "desapoiávamo": "desapoiar",
    "desapoiávamos": "desapoiar",
    "desapoiávei": "desapoiar",
    "desapoiáveis": "desapoiar",
    "desaponta": "desapontar",
    "desapontada": "desapontar",
    "desapontadas": "desapontar",
    "desapontado": "desapontar",
    "desapontadora": "desapontador",
    "desapontadoras": "desapontador",
    "desapontadores": "desapontador",
    "desapontados": "desapontar",
    "desapontadíssima": "desapontado",
    "desapontadíssimas": "desapontado",
    "desapontadíssimo": "desapontado",
    "desapontadíssimos": "desapontado",
    "desapontai": "desapontar",
    "desapontais": "desapontar",
    "desapontam": "desapontar",
    "desapontamentos": "desapontamento",
    "desapontamo": "desapontar",
    "desapontamos": "desapontar",
    "desapontando": "desapontar",
    "desapontara": "desapontar",
    "desapontaram": "desapontar",
    "desapontaras": "desapontar",
    "desapontarde": "desapontar",
    "desapontardes": "desapontar",
    "desapontare": "desapontar",
    "desapontarei": "desapontar",
    "desapontareis": "desapontar",
    "desapontarem": "desapontar",
    "desapontaremos": "desapontar",
    "desapontares": "desapontar",
    "desapontaria": "desapontar",
    "desapontariam": "desapontar",
    "desapontarias": "desapontar",
    "desapontarmo": "desapontar",
    "desapontarmos": "desapontar",
    "desapontará": "desapontar",
    "desapontarás": "desapontar",
    "desapontarão": "desapontar",
    "desapontaríamos": "desapontar",
    "desapontaríeis": "desapontar",
    "desapontas": "desapontar",
    "desapontasse": "desapontar",
    "desapontassem": "desapontar",
    "desapontasses": "desapontar",
    "desapontaste": "desapontar",
    "desapontastes": "desapontar",
    "desapontava": "desapontar",
    "desapontavam": "desapontar",
    "desapontavas": "desapontar",
    "desaponte": "desapontar",
    "desapontei": "desapontar",
    "desaponteis": "desapontar",
    "desapontem": "desapontar",
    "desapontemo": "desapontar",
    "desapontemos": "desapontar",
    "desapontes": "desapontar",
    "desaponto": "desapontar",
    "desapontou": "desapontar",
    "desapontá": "desapontar",
    "desapontámo": "desapontar",
    "desapontámos": "desapontar",
    "desapontáramo": "desapontar",
    "desapontáramos": "desapontar",
    "desapontárei": "desapontar",
    "desapontáreis": "desapontar",
    "desapontásseis": "desapontar",
    "desapontássemos": "desapontar",
    "desapontávamo": "desapontar",
    "desapontávamos": "desapontar",
    "desapontávei": "desapontar",
    "desapontáveis": "desapontar",
    "desapoquenta": "desapoquentar",
    "desapoquentada": "desapoquentar",
    "desapoquentadas": "desapoquentar",
    "desapoquentado": "desapoquentar",
    "desapoquentados": "desapoquentar",
    "desapoquentai": "desapoquentar",
    "desapoquentais": "desapoquentar",
    "desapoquentam": "desapoquentar",
    "desapoquentamo": "desapoquentar",
    "desapoquentamos": "desapoquentar",
    "desapoquentando": "desapoquentar",
    "desapoquentara": "desapoquentar",
    "desapoquentaram": "desapoquentar",
    "desapoquentaras": "desapoquentar",
    "desapoquentarde": "desapoquentar",
    "desapoquentardes": "desapoquentar",
    "desapoquentare": "desapoquentar",
    "desapoquentarei": "desapoquentar",
    "desapoquentareis": "desapoquentar",
    "desapoquentarem": "desapoquentar",
    "desapoquentaremos": "desapoquentar",
    "desapoquentares": "desapoquentar",
    "desapoquentaria": "desapoquentar",
    "desapoquentariam": "desapoquentar",
    "desapoquentarias": "desapoquentar",
    "desapoquentarmo": "desapoquentar",
    "desapoquentarmos": "desapoquentar",
    "desapoquentará": "desapoquentar",
    "desapoquentarás": "desapoquentar",
    "desapoquentarão": "desapoquentar",
    "desapoquentaríamos": "desapoquentar",
    "desapoquentaríeis": "desapoquentar",
    "desapoquentas": "desapoquentar",
    "desapoquentasse": "desapoquentar",
    "desapoquentassem": "desapoquentar",
    "desapoquentasses": "desapoquentar",
    "desapoquentaste": "desapoquentar",
    "desapoquentastes": "desapoquentar",
    "desapoquentava": "desapoquentar",
    "desapoquentavam": "desapoquentar",
    "desapoquentavas": "desapoquentar",
    "desapoquente": "desapoquentar",
    "desapoquentei": "desapoquentar",
    "desapoquenteis": "desapoquentar",
    "desapoquentem": "desapoquentar",
    "desapoquentemo": "desapoquentar",
    "desapoquentemos": "desapoquentar",
    "desapoquentes": "desapoquentar",
    "desapoquento": "desapoquentar",
    "desapoquentou": "desapoquentar",
    "desapoquentá": "desapoquentar",
    "desapoquentámo": "desapoquentar",
    "desapoquentámos": "desapoquentar",
    "desapoquentáramo": "desapoquentar",
    "desapoquentáramos": "desapoquentar",
    "desapoquentárei": "desapoquentar",
    "desapoquentáreis": "desapoquentar",
    "desapoquentásseis": "desapoquentar",
    "desapoquentássemos": "desapoquentar",
    "desapoquentávamo": "desapoquentar",
    "desapoquentávamos": "desapoquentar",
    "desapoquentávei": "desapoquentar",
    "desapoquentáveis": "desapoquentar",
    "desaportuguesa": "desaportuguesar",
    "desaportuguesada": "desaportuguesar",
    "desaportuguesadas": "desaportuguesar",
    "desaportuguesado": "desaportuguesar",
    "desaportuguesados": "desaportuguesar",
    "desaportuguesai": "desaportuguesar",
    "desaportuguesais": "desaportuguesar",
    "desaportuguesam": "desaportuguesar",
    "desaportuguesamo": "desaportuguesar",
    "desaportuguesamos": "desaportuguesar",
    "desaportuguesando": "desaportuguesar",
    "desaportuguesara": "desaportuguesar",
    "desaportuguesaram": "desaportuguesar",
    "desaportuguesaras": "desaportuguesar",
    "desaportuguesarde": "desaportuguesar",
    "desaportuguesardes": "desaportuguesar",
    "desaportuguesare": "desaportuguesar",
    "desaportuguesarei": "desaportuguesar",
    "desaportuguesareis": "desaportuguesar",
    "desaportuguesarem": "desaportuguesar",
    "desaportuguesaremos": "desaportuguesar",
    "desaportuguesares": "desaportuguesar",
    "desaportuguesaria": "desaportuguesar",
    "desaportuguesariam": "desaportuguesar",
    "desaportuguesarias": "desaportuguesar",
    "desaportuguesarmo": "desaportuguesar",
    "desaportuguesarmos": "desaportuguesar",
    "desaportuguesará": "desaportuguesar",
    "desaportuguesarás": "desaportuguesar",
    "desaportuguesarão": "desaportuguesar",
    "desaportuguesaríamos": "desaportuguesar",
    "desaportuguesaríeis": "desaportuguesar",
    "desaportuguesas": "desaportuguesar",
    "desaportuguesasse": "desaportuguesar",
    "desaportuguesassem": "desaportuguesar",
    "desaportuguesasses": "desaportuguesar",
    "desaportuguesaste": "desaportuguesar",
    "desaportuguesastes": "desaportuguesar",
    "desaportuguesava": "desaportuguesar",
    "desaportuguesavam": "desaportuguesar",
    "desaportuguesavas": "desaportuguesar",
    "desaportuguese": "desaportuguesar",
    "desaportuguesei": "desaportuguesar",
    "desaportugueseis": "desaportuguesar",
    "desaportuguesem": "desaportuguesar",
    "desaportuguesemo": "desaportuguesar",
    "desaportuguesemos": "desaportuguesar",
    "desaportugueses": "desaportuguesar",
    "desaportugueso": "desaportuguesar",
    "desaportuguesou": "desaportuguesar",
    "desaportuguesá": "desaportuguesar",
    "desaportuguesámo": "desaportuguesar",
    "desaportuguesámos": "desaportuguesar",
    "desaportuguesáramo": "desaportuguesar",
    "desaportuguesáramos": "desaportuguesar",
    "desaportuguesárei": "desaportuguesar",
    "desaportuguesáreis": "desaportuguesar",
    "desaportuguesásseis": "desaportuguesar",
    "desaportuguesássemos": "desaportuguesar",
    "desaportuguesávamo": "desaportuguesar",
    "desaportuguesávamos": "desaportuguesar",
    "desaportuguesávei": "desaportuguesar",
    "desaportuguesáveis": "desaportuguesável",
    "desaposenta": "desaposentar",
    "desaposentada": "desaposentar",
    "desaposentadas": "desaposentar",
    "desaposentado": "desaposentar",
    "desaposentados": "desaposentar",
    "desaposentai": "desaposentar",
    "desaposentais": "desaposentar",
    "desaposentam": "desaposentar",
    "desaposentamo": "desaposentar",
    "desaposentamos": "desaposentar",
    "desaposentando": "desaposentar",
    "desaposentara": "desaposentar",
    "desaposentaram": "desaposentar",
    "desaposentaras": "desaposentar",
    "desaposentarde": "desaposentar",
    "desaposentardes": "desaposentar",
    "desaposentare": "desaposentar",
    "desaposentarei": "desaposentar",
    "desaposentareis": "desaposentar",
    "desaposentarem": "desaposentar",
    "desaposentaremos": "desaposentar",
    "desaposentares": "desaposentar",
    "desaposentaria": "desaposentar",
    "desaposentariam": "desaposentar",
    "desaposentarias": "desaposentar",
    "desaposentarmo": "desaposentar",
    "desaposentarmos": "desaposentar",
    "desaposentará": "desaposentar",
    "desaposentarás": "desaposentar",
    "desaposentarão": "desaposentar",
    "desaposentaríamos": "desaposentar",
    "desaposentaríeis": "desaposentar",
    "desaposentas": "desaposentar",
    "desaposentasse": "desaposentar",
    "desaposentassem": "desaposentar",
    "desaposentasses": "desaposentar",
    "desaposentaste": "desaposentar",
    "desaposentastes": "desaposentar",
    "desaposentava": "desaposentar",
    "desaposentavam": "desaposentar",
    "desaposentavas": "desaposentar",
    "desaposente": "desaposentar",
    "desaposentei": "desaposentar",
    "desaposenteis": "desaposentar",
    "desaposentem": "desaposentar",
    "desaposentemo": "desaposentar",
    "desaposentemos": "desaposentar",
    "desaposentes": "desaposentar",
    "desaposento": "desaposentar",
    "desaposentou": "desaposentar",
    "desaposentá": "desaposentar",
    "desaposentámo": "desaposentar",
    "desaposentámos": "desaposentar",
    "desaposentáramo": "desaposentar",
    "desaposentáramos": "desaposentar",
    "desaposentárei": "desaposentar",
    "desaposentáreis": "desaposentar",
    "desaposentásseis": "desaposentar",
    "desaposentássemos": "desaposentar",
    "desaposentávamo": "desaposentar",
    "desaposentávamos": "desaposentar",
    "desaposentávei": "desaposentar",
    "desaposentáveis": "desaposentar",
    "desapossa": "desapossar",
    "desapossada": "desapossar",
    "desapossadas": "desapossar",
    "desapossado": "desapossar",
    "desapossados": "desapossar",
    "desapossai": "desapossar",
    "desapossais": "desapossar",
    "desapossam": "desapossar",
    "desapossamo": "desapossar",
    "desapossamos": "desapossar",
    "desapossando": "desapossar",
    "desapossara": "desapossar",
    "desapossaram": "desapossar",
    "desapossaras": "desapossar",
    "desapossarde": "desapossar",
    "desapossardes": "desapossar",
    "desapossare": "desapossar",
    "desapossarei": "desapossar",
    "desapossareis": "desapossar",
    "desapossarem": "desapossar",
    "desapossaremos": "desapossar",
    "desapossares": "desapossar",
    "desapossaria": "desapossar",
    "desapossariam": "desapossar",
    "desapossarias": "desapossar",
    "desapossarmo": "desapossar",
    "desapossarmos": "desapossar",
    "desapossará": "desapossar",
    "desapossarás": "desapossar",
    "desapossarão": "desapossar",
    "desapossaríamos": "desapossar",
    "desapossaríeis": "desapossar",
    "desapossas": "desapossar",
    "desapossasse": "desapossar",
    "desapossassem": "desapossar",
    "desapossasses": "desapossar",
    "desapossaste": "desapossar",
    "desapossastes": "desapossar",
    "desapossava": "desapossar",
    "desapossavam": "desapossar",
    "desapossavas": "desapossar",
    "desaposse": "desapossar",
    "desapossei": "desapossar",
    "desaposseis": "desapossar",
    "desapossem": "desapossar",
    "desapossemo": "desapossar",
    "desapossemos": "desapossar",
    "desaposses": "desapossar",
    "desaposso": "desapossar",
    "desapossou": "desapossar",
    "desapossá": "desapossar",
    "desapossámo": "desapossar",
    "desapossámos": "desapossar",
    "desapossáramo": "desapossar",
    "desapossáramos": "desapossar",
    "desapossárei": "desapossar",
    "desapossáreis": "desapossar",
    "desapossásseis": "desapossar",
    "desapossássemos": "desapossar",
    "desapossávamo": "desapossar",
    "desapossávamos": "desapossar",
    "desapossávei": "desapossar",
    "desapossáveis": "desapossar",
    "desapraz": "desaprazer",
    "desapraza": "desaprazer",
    "desaprazam": "desaprazer",
    "desaprazem": "desaprazer",
    "desaprazendo": "desaprazer",
    "desaprazerem": "desaprazer",
    "desaprazeria": "desaprazer",
    "desaprazeriam": "desaprazer",
    "desaprazerá": "desaprazer",
    "desaprazerão": "desaprazer",
    "desaprazia": "desaprazer",
    "desapraziam": "desaprazer",
    "desaprazida": "desaprazer",
    "desaprazidas": "desaprazer",
    "desaprazido": "desaprazer",
    "desaprazidos": "desaprazer",
    "desaprazíveis": "desaprazível",
    "desaprecia": "desapreciar",
    "desapreciada": "desapreciar",
    "desapreciadas": "desapreciar",
    "desapreciado": "desapreciar",
    "desapreciados": "desapreciar",
    "desapreciai": "desapreciar",
    "desapreciais": "desapreciar",
    "desapreciam": "desapreciar",
    "desapreciamo": "desapreciar",
    "desapreciamos": "desapreciar",
    "desapreciando": "desapreciar",
    "desapreciara": "desapreciar",
    "desapreciaram": "desapreciar",
    "desapreciaras": "desapreciar",
    "desapreciarde": "desapreciar",
    "desapreciardes": "desapreciar",
    "desapreciare": "desapreciar",
    "desapreciarei": "desapreciar",
    "desapreciareis": "desapreciar",
    "desapreciarem": "desapreciar",
    "desapreciaremos": "desapreciar",
    "desapreciares": "desapreciar",
    "desapreciaria": "desapreciar",
    "desapreciariam": "desapreciar",
    "desapreciarias": "desapreciar",
    "desapreciarmo": "desapreciar",
    "desapreciarmos": "desapreciar",
    "desapreciará": "desapreciar",
    "desapreciarás": "desapreciar",
    "desapreciarão": "desapreciar",
    "desapreciaríamos": "desapreciar",
    "desapreciaríeis": "desapreciar",
    "desaprecias": "desapreciar",
    "desapreciasse": "desapreciar",
    "desapreciassem": "desapreciar",
    "desapreciasses": "desapreciar",
    "desapreciaste": "desapreciar",
    "desapreciastes": "desapreciar",
    "desapreciava": "desapreciar",
    "desapreciavam": "desapreciar",
    "desapreciavas": "desapreciar",
    "desaprecie": "desapreciar",
    "desapreciei": "desapreciar",
    "desaprecieis": "desapreciar",
    "desapreciem": "desapreciar",
    "desapreciemo": "desapreciar",
    "desapreciemos": "desapreciar",
    "desaprecies": "desapreciar",
    "desaprecio": "desapreciar",
    "desapreciou": "desapreciar",
    "desapreciá": "desapreciar",
    "desapreciámo": "desapreciar",
    "desapreciámos": "desapreciar",
    "desapreciáramo": "desapreciar",
    "desapreciáramos": "desapreciar",
    "desapreciárei": "desapreciar",
    "desapreciáreis": "desapreciar",
    "desapreciásseis": "desapreciar",
    "desapreciássemos": "desapreciar",
    "desapreciávamo": "desapreciar",
    "desapreciávamos": "desapreciar",
    "desapreciávei": "desapreciar",
    "desapreciáveis": "desapreciar",
    "desaprenda": "desaprender",
    "desaprendais": "desaprender",
    "desaprendam": "desaprender",
    "desaprendamo": "desaprender",
    "desaprendamos": "desaprender",
    "desaprendas": "desaprender",
    "desaprende": "desaprender",
    "desaprendei": "desaprender",
    "desaprendeis": "desaprender",
    "desaprendem": "desaprender",
    "desaprendemo": "desaprender",
    "desaprendemos": "desaprender",
    "desaprendendo": "desaprender",
    "desaprendera": "desaprender",
    "desaprenderam": "desaprender",
    "desaprenderas": "desaprender",
    "desaprenderde": "desaprender",
    "desaprenderdes": "desaprender",
    "desaprendere": "desaprender",
    "desaprenderei": "desaprender",
    "desaprendereis": "desaprender",
    "desaprenderem": "desaprender",
    "desaprenderemos": "desaprender",
    "desaprenderes": "desaprender",
    "desaprenderia": "desaprender",
    "desaprenderiam": "desaprender",
    "desaprenderias": "desaprender",
    "desaprendermo": "desaprender",
    "desaprendermos": "desaprender",
    "desaprenderá": "desaprender",
    "desaprenderás": "desaprender",
    "desaprenderão": "desaprender",
    "desaprenderíamos": "desaprender",
    "desaprenderíeis": "desaprender",
    "desaprendes": "desaprender",
    "desaprendesse": "desaprender",
    "desaprendessem": "desaprender",
    "desaprendesses": "desaprender",
    "desaprendeste": "desaprender",
    "desaprendestes": "desaprender",
    "desaprendeu": "desaprender",
    "desaprendi": "desaprender",
    "desaprendia": "desaprender",
    "desaprendiam": "desaprender",
    "desaprendias": "desaprender",
    "desaprendida": "desaprendido",
    "desaprendidas": "desaprendido",
    "desaprendido": "desaprender",
    "desaprendidos": "desaprendido",
    "desaprendo": "desaprender",
    "desaprendê": "desaprender",
    "desaprendêramo": "desaprender",
    "desaprendêramos": "desaprender",
    "desaprendêrei": "desaprender",
    "desaprendêreis": "desaprender",
    "desaprendêsseis": "desaprender",
    "desaprendêssemos": "desaprender",
    "desaprendíamo": "desaprender",
    "desaprendíamos": "desaprender",
    "desaprendíei": "desaprender",
    "desaprendíeis": "desaprender",
    "desapresentáveis": "desapresentável",
    "desapressa": "desapressar",
    "desapressada": "desapressar",
    "desapressadas": "desapressar",
    "desapressado": "desapressar",
    "desapressados": "desapressar",
    "desapressai": "desapressar",
    "desapressais": "desapressar",
    "desapressam": "desapressar",
    "desapressamo": "desapressar",
    "desapressamos": "desapressar",
    "desapressando": "desapressar",
    "desapressara": "desapressar",
    "desapressaram": "desapressar",
    "desapressaras": "desapressar",
    "desapressarde": "desapressar",
    "desapressardes": "desapressar",
    "desapressare": "desapressar",
    "desapressarei": "desapressar",
    "desapressareis": "desapressar",
    "desapressarem": "desapressar",
    "desapressaremos": "desapressar",
    "desapressares": "desapressar",
    "desapressaria": "desapressar",
    "desapressariam": "desapressar",
    "desapressarias": "desapressar",
    "desapressarmo": "desapressar",
    "desapressarmos": "desapressar",
    "desapressará": "desapressar",
    "desapressarás": "desapressar",
    "desapressarão": "desapressar",
    "desapressaríamos": "desapressar",
    "desapressaríeis": "desapressar",
    "desapressas": "desapressar",
    "desapressasse": "desapressar",
    "desapressassem": "desapressar",
    "desapressasses": "desapressar",
    "desapressaste": "desapressar",
    "desapressastes": "desapressar",
    "desapressava": "desapressar",
    "desapressavam": "desapressar",
    "desapressavas": "desapressar",
    "desapresse": "desapressar",
    "desapressei": "desapressar",
    "desapresseis": "desapressar",
    "desapressem": "desapressar",
    "desapressemo": "desapressar",
    "desapressemos": "desapressar",
    "desapresses": "desapressar",
    "desapresso": "desapressar",
    "desapressou": "desapressar",
    "desapressá": "desapressar",
    "desapressámo": "desapressar",
    "desapressámos": "desapressar",
    "desapressáramo": "desapressar",
    "desapressáramos": "desapressar",
    "desapressárei": "desapressar",
    "desapressáreis": "desapressar",
    "desapressásseis": "desapressar",
    "desapressássemos": "desapressar",
    "desapressávamo": "desapressar",
    "desapressávamos": "desapressar",
    "desapressávei": "desapressar",
    "desapressáveis": "desapressar",
    "desapreços": "desapreço",
    "desaprimora": "desaprimorar",
    "desaprimorada": "desaprimorar",
    "desaprimoradas": "desaprimorar",
    "desaprimorado": "desaprimorar",
    "desaprimorados": "desaprimorar",
    "desaprimorai": "desaprimorar",
    "desaprimorais": "desaprimorar",
    "desaprimoram": "desaprimorar",
    "desaprimoramo": "desaprimorar",
    "desaprimoramos": "desaprimorar",
    "desaprimorando": "desaprimorar",
    "desaprimorara": "desaprimorar",
    "desaprimoraram": "desaprimorar",
    "desaprimoraras": "desaprimorar",
    "desaprimorarde": "desaprimorar",
    "desaprimorardes": "desaprimorar",
    "desaprimorare": "desaprimorar",
    "desaprimorarei": "desaprimorar",
    "desaprimorareis": "desaprimorar",
    "desaprimorarem": "desaprimorar",
    "desaprimoraremos": "desaprimorar",
    "desaprimorares": "desaprimorar",
    "desaprimoraria": "desaprimorar",
    "desaprimorariam": "desaprimorar",
    "desaprimorarias": "desaprimorar",
    "desaprimorarmo": "desaprimorar",
    "desaprimorarmos": "desaprimorar",
    "desaprimorará": "desaprimorar",
    "desaprimorarás": "desaprimorar",
    "desaprimorarão": "desaprimorar",
    "desaprimoraríamos": "desaprimorar",
    "desaprimoraríeis": "desaprimorar",
    "desaprimoras": "desaprimorar",
    "desaprimorasse": "desaprimorar",
    "desaprimorassem": "desaprimorar",
    "desaprimorasses": "desaprimorar",
    "desaprimoraste": "desaprimorar",
    "desaprimorastes": "desaprimorar",
    "desaprimorava": "desaprimorar",
    "desaprimoravam": "desaprimorar",
    "desaprimoravas": "desaprimorar",
    "desaprimore": "desaprimorar",
    "desaprimorei": "desaprimorar",
    "desaprimoreis": "desaprimorar",
    "desaprimorem": "desaprimorar",
    "desaprimoremo": "desaprimorar",
    "desaprimoremos": "desaprimorar",
    "desaprimores": "desaprimorar",
    "desaprimoro": "desaprimorar",
    "desaprimorou": "desaprimorar",
    "desaprimorá": "desaprimorar",
    "desaprimorámo": "desaprimorar",
    "desaprimorámos": "desaprimorar",
    "desaprimoráramo": "desaprimorar",
    "desaprimoráramos": "desaprimorar",
    "desaprimorárei": "desaprimorar",
    "desaprimoráreis": "desaprimorar",
    "desaprimorásseis": "desaprimorar",
    "desaprimorássemos": "desaprimorar",
    "desaprimorávamo": "desaprimorar",
    "desaprimorávamos": "desaprimorar",
    "desaprimorávei": "desaprimorar",
    "desaprimoráveis": "desaprimorar",
    "desapromada": "desapromado",
    "desapromadas": "desapromado",
    "desapromados": "desapromado",
    "desapropria": "desapropriar",
    "desapropriada": "desapropriar",
    "desapropriadas": "desapropriar",
    "desapropriado": "desapropriar",
    "desapropriadora": "desapropriador",
    "desapropriadoras": "desapropriador",
    "desapropriadores": "desapropriador",
    "desapropriados": "desapropriar",
    "desapropriai": "desapropriar",
    "desapropriais": "desapropriar",
    "desapropriam": "desapropriar",
    "desapropriamentos": "desapropriamento",
    "desapropriamo": "desapropriar",
    "desapropriamos": "desapropriar",
    "desapropriando": "desapropriar",
    "desapropriara": "desapropriar",
    "desapropriaram": "desapropriar",
    "desapropriaras": "desapropriar",
    "desapropriarde": "desapropriar",
    "desapropriardes": "desapropriar",
    "desapropriare": "desapropriar",
    "desapropriarei": "desapropriar",
    "desapropriareis": "desapropriar",
    "desapropriarem": "desapropriar",
    "desapropriaremos": "desapropriar",
    "desapropriares": "desapropriar",
    "desapropriaria": "desapropriar",
    "desapropriariam": "desapropriar",
    "desapropriarias": "desapropriar",
    "desapropriarmo": "desapropriar",
    "desapropriarmos": "desapropriar",
    "desapropriará": "desapropriar",
    "desapropriarás": "desapropriar",
    "desapropriarão": "desapropriar",
    "desapropriaríamos": "desapropriar",
    "desapropriaríeis": "desapropriar",
    "desaproprias": "desapropriar",
    "desapropriasse": "desapropriar",
    "desapropriassem": "desapropriar",
    "desapropriasses": "desapropriar",
    "desapropriaste": "desapropriar",
    "desapropriastes": "desapropriar",
    "desapropriava": "desapropriar",
    "desapropriavam": "desapropriar",
    "desapropriavas": "desapropriar",
    "desapropriações": "desapropriação",
    "desaproprie": "desapropriar",
    "desapropriei": "desapropriar",
    "desaproprieis": "desapropriar",
    "desapropriem": "desapropriar",
    "desapropriemo": "desapropriar",
    "desapropriemos": "desapropriar",
    "desapropries": "desapropriar",
    "desaproprio": "desapropriar",
    "desapropriou": "desapropriar",
    "desapropriá": "desapropriar",
    "desapropriámo": "desapropriar",
    "desapropriámos": "desapropriar",
    "desapropriáramo": "desapropriar",
    "desapropriáramos": "desapropriar",
    "desapropriárei": "desapropriar",
    "desapropriáreis": "desapropriar",
    "desapropriásseis": "desapropriar",
    "desapropriássemos": "desapropriar",
    "desapropriávamo": "desapropriar",
    "desapropriávamos": "desapropriar",
    "desapropriávei": "desapropriar",
    "desapropriáveis": "desapropriar",
    "desaprouve": "desaprazer",
    "desaprouver": "desaprazer",
    "desaprouvera": "desaprazer",
    "desaprouveram": "desaprazer",
    "desaprouverem": "desaprazer",
    "desaprouvesse": "desaprazer",
    "desaprouvessem": "desaprazer",
    "desaprova": "desaprovar",
    "desaprovada": "desaprovar",
    "desaprovadas": "desaprovar",
    "desaprovado": "desaprovar",
    "desaprovadora": "desaprovador",
    "desaprovadoras": "desaprovador",
    "desaprovadores": "desaprovador",
    "desaprovados": "desaprovar",
    "desaprovai": "desaprovar",
    "desaprovais": "desaprovar",
    "desaprovam": "desaprovar",
    "desaprovamo": "desaprovar",
    "desaprovamos": "desaprovar",
    "desaprovando": "desaprovar",
    "desaprovara": "desaprovar",
    "desaprovaram": "desaprovar",
    "desaprovaras": "desaprovar",
    "desaprovarde": "desaprovar",
    "desaprovardes": "desaprovar",
    "desaprovare": "desaprovar",
    "desaprovarei": "desaprovar",
    "desaprovareis": "desaprovar",
    "desaprovarem": "desaprovar",
    "desaprovaremos": "desaprovar",
    "desaprovares": "desaprovar",
    "desaprovaria": "desaprovar",
    "desaprovariam": "desaprovar",
    "desaprovarias": "desaprovar",
    "desaprovarmo": "desaprovar",
    "desaprovarmos": "desaprovar",
    "desaprovará": "desaprovar",
    "desaprovarás": "desaprovar",
    "desaprovarão": "desaprovar",
    "desaprovaríamos": "desaprovar",
    "desaprovaríeis": "desaprovar",
    "desaprovas": "desaprovar",
    "desaprovasse": "desaprovar",
    "desaprovassem": "desaprovar",
    "desaprovasses": "desaprovar",
    "desaprovaste": "desaprovar",
    "desaprovastes": "desaprovar",
    "desaprovava": "desaprovar",
    "desaprovavam": "desaprovar",
    "desaprovavas": "desaprovar",
    "desaprovações": "desaprovação",
    "desaprove": "desaprovar",
    "desaprovei": "desaprovar",
    "desaproveis": "desaprovar",
    "desaproveita": "desaproveitar",
    "desaproveitada": "desaproveitar",
    "desaproveitadas": "desaproveitar",
    "desaproveitado": "desaproveitar",
    "desaproveitados": "desaproveitar",
    "desaproveitai": "desaproveitar",
    "desaproveitais": "desaproveitar",
    "desaproveitam": "desaproveitar",
    "desaproveitamentos": "desaproveitamento",
    "desaproveitamo": "desaproveitar",
    "desaproveitamos": "desaproveitar",
    "desaproveitando": "desaproveitar",
    "desaproveitara": "desaproveitar",
    "desaproveitaram": "desaproveitar",
    "desaproveitaras": "desaproveitar",
    "desaproveitarde": "desaproveitar",
    "desaproveitardes": "desaproveitar",
    "desaproveitare": "desaproveitar",
    "desaproveitarei": "desaproveitar",
    "desaproveitareis": "desaproveitar",
    "desaproveitarem": "desaproveitar",
    "desaproveitaremos": "desaproveitar",
    "desaproveitares": "desaproveitar",
    "desaproveitaria": "desaproveitar",
    "desaproveitariam": "desaproveitar",
    "desaproveitarias": "desaproveitar",
    "desaproveitarmo": "desaproveitar",
    "desaproveitarmos": "desaproveitar",
    "desaproveitará": "desaproveitar",
    "desaproveitarás": "desaproveitar",
    "desaproveitarão": "desaproveitar",
    "desaproveitaríamos": "desaproveitar",
    "desaproveitaríeis": "desaproveitar",
    "desaproveitas": "desaproveitar",
    "desaproveitasse": "desaproveitar",
    "desaproveitassem": "desaproveitar",
    "desaproveitasses": "desaproveitar",
    "desaproveitaste": "desaproveitar",
    "desaproveitastes": "desaproveitar",
    "desaproveitava": "desaproveitar",
    "desaproveitavam": "desaproveitar",
    "desaproveitavas": "desaproveitar",
    "desaproveite": "desaproveitar",
    "desaproveitei": "desaproveitar",
    "desaproveiteis": "desaproveitar",
    "desaproveitem": "desaproveitar",
    "desaproveitemo": "desaproveitar",
    "desaproveitemos": "desaproveitar",
    "desaproveites": "desaproveitar",
    "desaproveito": "desaproveitar",
    "desaproveitou": "desaproveitar",
    "desaproveitá": "desaproveitar",
    "desaproveitámo": "desaproveitar",
    "desaproveitámos": "desaproveitar",
    "desaproveitáramo": "desaproveitar",
    "desaproveitáramos": "desaproveitar",
    "desaproveitárei": "desaproveitar",
    "desaproveitáreis": "desaproveitar",
    "desaproveitásseis": "desaproveitar",
    "desaproveitássemos": "desaproveitar",
    "desaproveitávamo": "desaproveitar",
    "desaproveitávamos": "desaproveitar",
    "desaproveitávei": "desaproveitar",
    "desaproveitáveis": "desaproveitar",
    "desaprovem": "desaprovar",
    "desaprovemo": "desaprovar",
    "desaprovemos": "desaprovar",
    "desaproves": "desaprovar",
    "desaprovo": "desaprovar",
    "desaprovou": "desaprovar",
    "desaprová": "desaprovar",
    "desaprovámo": "desaprovar",
    "desaprovámos": "desaprovar",
    "desaprováramo": "desaprovar",
    "desaprováramos": "desaprovar",
    "desaprovárei": "desaprovar",
    "desaprováreis": "desaprovar",
    "desaprovásseis": "desaprovar",
    "desaprovássemos": "desaprovar",
    "desaprovávamo": "desaprovar",
    "desaprovávamos": "desaprovar",
    "desaprovávei": "desaprovar",
    "desaprováveis": "desaprovável",
    "desaproxima": "desaproximar",
    "desaproximada": "desaproximar",
    "desaproximadas": "desaproximar",
    "desaproximado": "desaproximar",
    "desaproximados": "desaproximar",
    "desaproximai": "desaproximar",
    "desaproximais": "desaproximar",
    "desaproximam": "desaproximar",
    "desaproximamo": "desaproximar",
    "desaproximamos": "desaproximar",
    "desaproximando": "desaproximar",
    "desaproximara": "desaproximar",
    "desaproximaram": "desaproximar",
    "desaproximaras": "desaproximar",
    "desaproximarde": "desaproximar",
    "desaproximardes": "desaproximar",
    "desaproximare": "desaproximar",
    "desaproximarei": "desaproximar",
    "desaproximareis": "desaproximar",
    "desaproximarem": "desaproximar",
    "desaproximaremos": "desaproximar",
    "desaproximares": "desaproximar",
    "desaproximaria": "desaproximar",
    "desaproximariam": "desaproximar",
    "desaproximarias": "desaproximar",
    "desaproximarmo": "desaproximar",
    "desaproximarmos": "desaproximar",
    "desaproximará": "desaproximar",
    "desaproximarás": "desaproximar",
    "desaproximarão": "desaproximar",
    "desaproximaríamos": "desaproximar",
    "desaproximaríeis": "desaproximar",
    "desaproximas": "desaproximar",
    "desaproximasse": "desaproximar",
    "desaproximassem": "desaproximar",
    "desaproximasses": "desaproximar",
    "desaproximaste": "desaproximar",
    "desaproximastes": "desaproximar",
    "desaproximava": "desaproximar",
    "desaproximavam": "desaproximar",
    "desaproximavas": "desaproximar",
    "desaproxime": "desaproximar",
    "desaproximei": "desaproximar",
    "desaproximeis": "desaproximar",
    "desaproximem": "desaproximar",
    "desaproximemo": "desaproximar",
    "desaproximemos": "desaproximar",
    "desaproximes": "desaproximar",
    "desaproximo": "desaproximar",
    "desaproximou": "desaproximar",
    "desaproximá": "desaproximar",
    "desaproximámo": "desaproximar",
    "desaproximámos": "desaproximar",
    "desaproximáramo": "desaproximar",
    "desaproximáramos": "desaproximar",
    "desaproximárei": "desaproximar",
    "desaproximáreis": "desaproximar",
    "desaproximásseis": "desaproximar",
    "desaproximássemos": "desaproximar",
    "desaproximávamo": "desaproximar",
    "desaproximávamos": "desaproximar",
    "desaproximávei": "desaproximar",
    "desaproximáveis": "desaproximar",
    "desapruma": "desaprumar",
    "desaprumada": "desaprumar",
    "desaprumadas": "desaprumar",
    "desaprumado": "desaprumar",
    "desaprumados": "desaprumar",
    "desaprumai": "desaprumar",
    "desaprumais": "desaprumar",
    "desaprumam": "desaprumar",
    "desaprumamo": "desaprumar",
    "desaprumamos": "desaprumar",
    "desaprumando": "desaprumar",
    "desaprumara": "desaprumar",
    "desaprumaram": "desaprumar",
    "desaprumaras": "desaprumar",
    "desaprumarde": "desaprumar",
    "desaprumardes": "desaprumar",
    "desaprumare": "desaprumar",
    "desaprumarei": "desaprumar",
    "desaprumareis": "desaprumar",
    "desaprumarem": "desaprumar",
    "desaprumaremos": "desaprumar",
    "desaprumares": "desaprumar",
    "desaprumaria": "desaprumar",
    "desaprumariam": "desaprumar",
    "desaprumarias": "desaprumar",
    "desaprumarmo": "desaprumar",
    "desaprumarmos": "desaprumar",
    "desaprumará": "desaprumar",
    "desaprumarás": "desaprumar",
    "desaprumarão": "desaprumar",
    "desaprumaríamos": "desaprumar",
    "desaprumaríeis": "desaprumar",
    "desaprumas": "desaprumar",
    "desaprumasse": "desaprumar",
    "desaprumassem": "desaprumar",
    "desaprumasses": "desaprumar",
    "desaprumaste": "desaprumar",
    "desaprumastes": "desaprumar",
    "desaprumava": "desaprumar",
    "desaprumavam": "desaprumar",
    "desaprumavas": "desaprumar",
    "desaprume": "desaprumar",
    "desaprumei": "desaprumar",
    "desaprumeis": "desaprumar",
    "desaprumem": "desaprumar",
    "desaprumemo": "desaprumar",
    "desaprumemos": "desaprumar",
    "desaprumes": "desaprumar",
    "desaprumo": "desaprumar",
    "desaprumos": "desaprumo",
    "desaprumou": "desaprumar",
    "desaprumá": "desaprumar",
    "desaprumámo": "desaprumar",
    "desaprumámos": "desaprumar",
    "desaprumáramo": "desaprumar",
    "desaprumáramos": "desaprumar",
    "desaprumárei": "desaprumar",
    "desaprumáreis": "desaprumar",
    "desaprumásseis": "desaprumar",
    "desaprumássemos": "desaprumar",
    "desaprumávamo": "desaprumar",
    "desaprumávamos": "desaprumar",
    "desaprumávei": "desaprumar",
    "desaprumáveis": "desaprumar",
    "desapura": "desapurar",
    "desapurada": "desapurar",
    "desapuradas": "desapurar",
    "desapurado": "desapurar",
    "desapurados": "desapurar",
    "desapurai": "desapurar",
    "desapurais": "desapurar",
    "desapuram": "desapurar",
    "desapuramo": "desapurar",
    "desapuramos": "desapurar",
    "desapurando": "desapurar",
    "desapurara": "desapurar",
    "desapuraram": "desapurar",
    "desapuraras": "desapurar",
    "desapurarde": "desapurar",
    "desapurardes": "desapurar",
    "desapurare": "desapurar",
    "desapurarei": "desapurar",
    "desapurareis": "desapurar",
    "desapurarem": "desapurar",
    "desapuraremos": "desapurar",
    "desapurares": "desapurar",
    "desapuraria": "desapurar",
    "desapurariam": "desapurar",
    "desapurarias": "desapurar",
    "desapurarmo": "desapurar",
    "desapurarmos": "desapurar",
    "desapurará": "desapurar",
    "desapurarás": "desapurar",
    "desapurarão": "desapurar",
    "desapuraríamos": "desapurar",
    "desapuraríeis": "desapurar",
    "desapuras": "desapurar",
    "desapurasse": "desapurar",
    "desapurassem": "desapurar",
    "desapurasses": "desapurar",
    "desapuraste": "desapurar",
    "desapurastes": "desapurar",
    "desapurava": "desapurar",
    "desapuravam": "desapurar",
    "desapuravas": "desapurar",
    "desapure": "desapurar",
    "desapurei": "desapurar",
    "desapureis": "desapurar",
    "desapurem": "desapurar",
    "desapuremo": "desapurar",
    "desapuremos": "desapurar",
    "desapures": "desapurar",
    "desapuro": "desapurar",
    "desapuros": "desapuro",
    "desapurou": "desapurar",
    "desapurá": "desapurar",
    "desapurámo": "desapurar",
    "desapurámos": "desapurar",
    "desapuráramo": "desapurar",
    "desapuráramos": "desapurar",
    "desapurárei": "desapurar",
    "desapuráreis": "desapurar",
    "desapurásseis": "desapurar",
    "desapurássemos": "desapurar",
    "desapurávamo": "desapurar",
    "desapurávamos": "desapurar",
    "desapurávei": "desapurar",
    "desapuráveis": "desapurar",
    "desaquartela": "desaquartelar",
    "desaquartelada": "desaquartelar",
    "desaquarteladas": "desaquartelar",
    "desaquartelado": "desaquartelar",
    "desaquartelados": "desaquartelar",
    "desaquartelai": "desaquartelar",
    "desaquartelais": "desaquartelar",
    "desaquartelam": "desaquartelar",
    "desaquartelamo": "desaquartelar",
    "desaquartelamos": "desaquartelar",
    "desaquartelando": "desaquartelar",
    "desaquartelara": "desaquartelar",
    "desaquartelaram": "desaquartelar",
    "desaquartelaras": "desaquartelar",
    "desaquartelarde": "desaquartelar",
    "desaquartelardes": "desaquartelar",
    "desaquartelare": "desaquartelar",
    "desaquartelarei": "desaquartelar",
    "desaquartelareis": "desaquartelar",
    "desaquartelarem": "desaquartelar",
    "desaquartelaremos": "desaquartelar",
    "desaquartelares": "desaquartelar",
    "desaquartelaria": "desaquartelar",
    "desaquartelariam": "desaquartelar",
    "desaquartelarias": "desaquartelar",
    "desaquartelarmo": "desaquartelar",
    "desaquartelarmos": "desaquartelar",
    "desaquartelará": "desaquartelar",
    "desaquartelarás": "desaquartelar",
    "desaquartelarão": "desaquartelar",
    "desaquartelaríamos": "desaquartelar",
    "desaquartelaríeis": "desaquartelar",
    "desaquartelas": "desaquartelar",
    "desaquartelasse": "desaquartelar",
    "desaquartelassem": "desaquartelar",
    "desaquartelasses": "desaquartelar",
    "desaquartelaste": "desaquartelar",
    "desaquartelastes": "desaquartelar",
    "desaquartelava": "desaquartelar",
    "desaquartelavam": "desaquartelar",
    "desaquartelavas": "desaquartelar",
    "desaquartele": "desaquartelar",
    "desaquartelei": "desaquartelar",
    "desaquarteleis": "desaquartelar",
    "desaquartelem": "desaquartelar",
    "desaquartelemo": "desaquartelar",
    "desaquartelemos": "desaquartelar",
    "desaquarteles": "desaquartelar",
    "desaquartelo": "desaquartelar",
    "desaquartelou": "desaquartelar",
    "desaquartelá": "desaquartelar",
    "desaquartelámo": "desaquartelar",
    "desaquartelámos": "desaquartelar",
    "desaquarteláramo": "desaquartelar",
    "desaquarteláramos": "desaquartelar",
    "desaquartelárei": "desaquartelar",
    "desaquarteláreis": "desaquartelar",
    "desaquartelásseis": "desaquartelar",
    "desaquartelássemos": "desaquartelar",
    "desaquartelávamo": "desaquartelar",
    "desaquartelávamos": "desaquartelar",
    "desaquartelávei": "desaquartelar",
    "desaquarteláveis": "desaquartelar",
    "desaquece": "desaquecer",
    "desaquecei": "desaquecer",
    "desaqueceis": "desaquecer",
    "desaquecem": "desaquecer",
    "desaquecemo": "desaquecer",
    "desaquecemos": "desaquecer",
    "desaquecendo": "desaquecer",
    "desaquecera": "desaquecer",
    "desaqueceram": "desaquecer",
    "desaqueceras": "desaquecer",
    "desaquecerde": "desaquecer",
    "desaquecerdes": "desaquecer",
    "desaquecere": "desaquecer",
    "desaquecerei": "desaquecer",
    "desaquecereis": "desaquecer",
    "desaquecerem": "desaquecer",
    "desaqueceremos": "desaquecer",
    "desaqueceres": "desaquecer",
    "desaqueceria": "desaquecer",
    "desaqueceriam": "desaquecer",
    "desaquecerias": "desaquecer",
    "desaquecermo": "desaquecer",
    "desaquecermos": "desaquecer",
    "desaquecerá": "desaquecer",
    "desaquecerás": "desaquecer",
    "desaquecerão": "desaquecer",
    "desaqueceríamos": "desaquecer",
    "desaqueceríeis": "desaquecer",
    "desaqueces": "desaquecer",
    "desaquecesse": "desaquecer",
    "desaquecessem": "desaquecer",
    "desaquecesses": "desaquecer",
    "desaqueceste": "desaquecer",
    "desaquecestes": "desaquecer",
    "desaqueceu": "desaquecer",
    "desaqueci": "desaquecer",
    "desaquecia": "desaquecer",
    "desaqueciam": "desaquecer",
    "desaquecias": "desaquecer",
    "desaquecida": "desaquecer",
    "desaquecidas": "desaquecer",
    "desaquecido": "desaquecer",
    "desaquecidos": "desaquecer",
    "desaquecê": "desaquecer",
    "desaquecêramo": "desaquecer",
    "desaquecêramos": "desaquecer",
    "desaquecêrei": "desaquecer",
    "desaquecêreis": "desaquecer",
    "desaquecêsseis": "desaquecer",
    "desaquecêssemos": "desaquecer",
    "desaquecíamo": "desaquecer",
    "desaquecíamos": "desaquecer",
    "desaquecíei": "desaquecer",
    "desaquecíeis": "desaquecer",
    "desaqueça": "desaquecer",
    "desaqueçais": "desaquecer",
    "desaqueçam": "desaquecer",
    "desaqueçamo": "desaquecer",
    "desaqueçamos": "desaquecer",
    "desaqueças": "desaquecer",
    "desaqueço": "desaquecer",
    "desarboriza": "desarborizar",
    "desarborizada": "desarborizar",
    "desarborizadas": "desarborizar",
    "desarborizado": "desarborizar",
    "desarborizados": "desarborizar",
    "desarborizai": "desarborizar",
    "desarborizais": "desarborizar",
    "desarborizam": "desarborizar",
    "desarborizamo": "desarborizar",
    "desarborizamos": "desarborizar",
    "desarborizando": "desarborizar",
    "desarborizara": "desarborizar",
    "desarborizaram": "desarborizar",
    "desarborizaras": "desarborizar",
    "desarborizarde": "desarborizar",
    "desarborizardes": "desarborizar",
    "desarborizare": "desarborizar",
    "desarborizarei": "desarborizar",
    "desarborizareis": "desarborizar",
    "desarborizarem": "desarborizar",
    "desarborizaremos": "desarborizar",
    "desarborizares": "desarborizar",
    "desarborizaria": "desarborizar",
    "desarborizariam": "desarborizar",
    "desarborizarias": "desarborizar",
    "desarborizarmo": "desarborizar",
    "desarborizarmos": "desarborizar",
    "desarborizará": "desarborizar",
    "desarborizarás": "desarborizar",
    "desarborizarão": "desarborizar",
    "desarborizaríamos": "desarborizar",
    "desarborizaríeis": "desarborizar",
    "desarborizas": "desarborizar",
    "desarborizasse": "desarborizar",
    "desarborizassem": "desarborizar",
    "desarborizasses": "desarborizar",
    "desarborizaste": "desarborizar",
    "desarborizastes": "desarborizar",
    "desarborizava": "desarborizar",
    "desarborizavam": "desarborizar",
    "desarborizavas": "desarborizar",
    "desarborizações": "desarborização",
    "desarborize": "desarborizar",
    "desarborizei": "desarborizar",
    "desarborizeis": "desarborizar",
    "desarborizem": "desarborizar",
    "desarborizemo": "desarborizar",
    "desarborizemos": "desarborizar",
    "desarborizes": "desarborizar",
    "desarborizo": "desarborizar",
    "desarborizou": "desarborizar",
    "desarborizá": "desarborizar",
    "desarborizámo": "desarborizar",
    "desarborizámos": "desarborizar",
    "desarborizáramo": "desarborizar",
    "desarborizáramos": "desarborizar",
    "desarborizárei": "desarborizar",
    "desarborizáreis": "desarborizar",
    "desarborizásseis": "desarborizar",
    "desarborizássemos": "desarborizar",
    "desarborizávamo": "desarborizar",
    "desarborizávamos": "desarborizar",
    "desarborizávei": "desarborizar",
    "desarborizáveis": "desarborizar",
    "desarca": "desarcar",
    "desarcada": "desarcar",
    "desarcadas": "desarcar",
    "desarcado": "desarcar",
    "desarcados": "desarcar",
    "desarcai": "desarcar",
    "desarcais": "desarcar",
    "desarcam": "desarcar",
    "desarcamo": "desarcar",
    "desarcamos": "desarcar",
    "desarcando": "desarcar",
    "desarcara": "desarcar",
    "desarcaram": "desarcar",
    "desarcaras": "desarcar",
    "desarcarde": "desarcar",
    "desarcardes": "desarcar",
    "desarcare": "desarcar",
    "desarcarei": "desarcar",
    "desarcareis": "desarcar",
    "desarcarem": "desarcar",
    "desarcaremos": "desarcar",
    "desarcares": "desarcar",
    "desarcaria": "desarcar",
    "desarcariam": "desarcar",
    "desarcarias": "desarcar",
    "desarcarmo": "desarcar",
    "desarcarmos": "desarcar",
    "desarcará": "desarcar",
    "desarcarás": "desarcar",
    "desarcarão": "desarcar",
    "desarcaríamos": "desarcar",
    "desarcaríeis": "desarcar",
    "desarcas": "desarcar",
    "desarcasse": "desarcar",
    "desarcassem": "desarcar",
    "desarcasses": "desarcar",
    "desarcaste": "desarcar",
    "desarcastes": "desarcar",
    "desarcava": "desarcar",
    "desarcavam": "desarcar",
    "desarcavas": "desarcar",
    "desarco": "desarcar",
    "desarcou": "desarcar",
    "desarcá": "desarcar",
    "desarcámo": "desarcar",
    "desarcámos": "desarcar",
    "desarcáramo": "desarcar",
    "desarcáramos": "desarcar",
    "desarcárei": "desarcar",
    "desarcáreis": "desarcar",
    "desarcásseis": "desarcar",
    "desarcássemos": "desarcar",
    "desarcávamo": "desarcar",
    "desarcávamos": "desarcar",
    "desarcávei": "desarcar",
    "desarcáveis": "desarcar",
    "desares": "desar",
    "desaresta": "desarestar",
    "desarestada": "desarestar",
    "desarestadas": "desarestar",
    "desarestado": "desarestar",
    "desarestados": "desarestar",
    "desarestai": "desarestar",
    "desarestais": "desarestar",
    "desarestam": "desarestar",
    "desarestamo": "desarestar",
    "desarestamos": "desarestar",
    "desarestando": "desarestar",
    "desarestara": "desarestar",
    "desarestaram": "desarestar",
    "desarestaras": "desarestar",
    "desarestarde": "desarestar",
    "desarestardes": "desarestar",
    "desarestare": "desarestar",
    "desarestarei": "desarestar",
    "desarestareis": "desarestar",
    "desarestarem": "desarestar",
    "desarestaremos": "desarestar",
    "desarestares": "desarestar",
    "desarestaria": "desarestar",
    "desarestariam": "desarestar",
    "desarestarias": "desarestar",
    "desarestarmo": "desarestar",
    "desarestarmos": "desarestar",
    "desarestará": "desarestar",
    "desarestarás": "desarestar",
    "desarestarão": "desarestar",
    "desarestaríamos": "desarestar",
    "desarestaríeis": "desarestar",
    "desarestas": "desarestar",
    "desarestasse": "desarestar",
    "desarestassem": "desarestar",
    "desarestasses": "desarestar",
    "desarestaste": "desarestar",
    "desarestastes": "desarestar",
    "desarestava": "desarestar",
    "desarestavam": "desarestar",
    "desarestavas": "desarestar",
    "desareste": "desarestar",
    "desarestei": "desarestar",
    "desaresteis": "desarestar",
    "desarestem": "desarestar",
    "desarestemo": "desarestar",
    "desarestemos": "desarestar",
    "desarestes": "desarestar",
    "desaresto": "desarestar",
    "desarestou": "desarestar",
    "desarestá": "desarestar",
    "desarestámo": "desarestar",
    "desarestámos": "desarestar",
    "desarestáramo": "desarestar",
    "desarestáramos": "desarestar",
    "desarestárei": "desarestar",
    "desarestáreis": "desarestar",
    "desarestásseis": "desarestar",
    "desarestássemos": "desarestar",
    "desarestávamo": "desarestar",
    "desarestávamos": "desarestar",
    "desarestávei": "desarestar",
    "desarestáveis": "desarestar",
    "desarista": "desaristar",
    "desaristada": "desaristar",
    "desaristadas": "desaristar",
    "desaristado": "desaristar",
    "desaristados": "desaristar",
    "desaristai": "desaristar",
    "desaristais": "desaristar",
    "desaristam": "desaristar",
    "desaristamo": "desaristar",
    "desaristamos": "desaristar",
    "desaristando": "desaristar",
    "desaristara": "desaristar",
    "desaristaram": "desaristar",
    "desaristaras": "desaristar",
    "desaristarde": "desaristar",
    "desaristardes": "desaristar",
    "desaristare": "desaristar",
    "desaristarei": "desaristar",
    "desaristareis": "desaristar",
    "desaristarem": "desaristar",
    "desaristaremos": "desaristar",
    "desaristares": "desaristar",
    "desaristaria": "desaristar",
    "desaristariam": "desaristar",
    "desaristarias": "desaristar",
    "desaristarmo": "desaristar",
    "desaristarmos": "desaristar",
    "desaristará": "desaristar",
    "desaristarás": "desaristar",
    "desaristarão": "desaristar",
    "desaristaríamos": "desaristar",
    "desaristaríeis": "desaristar",
    "desaristas": "desaristar",
    "desaristasse": "desaristar",
    "desaristassem": "desaristar",
    "desaristasses": "desaristar",
    "desaristaste": "desaristar",
    "desaristastes": "desaristar",
    "desaristava": "desaristar",
    "desaristavam": "desaristar",
    "desaristavas": "desaristar",
    "desariste": "desaristar",
    "desaristei": "desaristar",
    "desaristeis": "desaristar",
    "desaristem": "desaristar",
    "desaristemo": "desaristar",
    "desaristemos": "desaristar",
    "desaristes": "desaristar",
    "desaristo": "desaristar",
    "desaristou": "desaristar",
    "desaristá": "desaristar",
    "desaristámo": "desaristar",
    "desaristámos": "desaristar",
    "desaristáramo": "desaristar",
    "desaristáramos": "desaristar",
    "desaristárei": "desaristar",
    "desaristáreis": "desaristar",
    "desaristásseis": "desaristar",
    "desaristássemos": "desaristar",
    "desaristávamo": "desaristar",
    "desaristávamos": "desaristar",
    "desaristávei": "desaristar",
    "desaristáveis": "desaristar",
    "desarma": "desarmar",
    "desarmada": "desarmar",
    "desarmadas": "desarmar",
    "desarmadilha": "desarmadilhar",
    "desarmadilhada": "desarmadilhar",
    "desarmadilhadas": "desarmadilhar",
    "desarmadilhado": "desarmadilhar",
    "desarmadilhados": "desarmadilhar",
    "desarmadilhai": "desarmadilhar",
    "desarmadilhais": "desarmadilhar",
    "desarmadilham": "desarmadilhar",
    "desarmadilhamo": "desarmadilhar",
    "desarmadilhamos": "desarmadilhar",
    "desarmadilhando": "desarmadilhar",
    "desarmadilhara": "desarmadilhar",
    "desarmadilharam": "desarmadilhar",
    "desarmadilharas": "desarmadilhar",
    "desarmadilharde": "desarmadilhar",
    "desarmadilhardes": "desarmadilhar",
    "desarmadilhare": "desarmadilhar",
    "desarmadilharei": "desarmadilhar",
    "desarmadilhareis": "desarmadilhar",
    "desarmadilharem": "desarmadilhar",
    "desarmadilharemos": "desarmadilhar",
    "desarmadilhares": "desarmadilhar",
    "desarmadilharia": "desarmadilhar",
    "desarmadilhariam": "desarmadilhar",
    "desarmadilharias": "desarmadilhar",
    "desarmadilharmo": "desarmadilhar",
    "desarmadilharmos": "desarmadilhar",
    "desarmadilhará": "desarmadilhar",
    "desarmadilharás": "desarmadilhar",
    "desarmadilharão": "desarmadilhar",
    "desarmadilharíamos": "desarmadilhar",
    "desarmadilharíeis": "desarmadilhar",
    "desarmadilhas": "desarmadilhar",
    "desarmadilhasse": "desarmadilhar",
    "desarmadilhassem": "desarmadilhar",
    "desarmadilhasses": "desarmadilhar",
    "desarmadilhaste": "desarmadilhar",
    "desarmadilhastes": "desarmadilhar",
    "desarmadilhava": "desarmadilhar",
    "desarmadilhavam": "desarmadilhar",
    "desarmadilhavas": "desarmadilhar",
    "desarmadilhe": "desarmadilhar",
    "desarmadilhei": "desarmadilhar",
    "desarmadilheis": "desarmadilhar",
    "desarmadilhem": "desarmadilhar",
    "desarmadilhemo": "desarmadilhar",
    "desarmadilhemos": "desarmadilhar",
    "desarmadilhes": "desarmadilhar",
    "desarmadilho": "desarmadilhar",
    "desarmadilhou": "desarmadilhar",
    "desarmadilhá": "desarmadilhar",
    "desarmadilhámo": "desarmadilhar",
    "desarmadilhámos": "desarmadilhar",
    "desarmadilháramo": "desarmadilhar",
    "desarmadilháramos": "desarmadilhar",
    "desarmadilhárei": "desarmadilhar",
    "desarmadilháreis": "desarmadilhar",
    "desarmadilhásseis": "desarmadilhar",
    "desarmadilhássemos": "desarmadilhar",
    "desarmadilhávamo": "desarmadilhar",
    "desarmadilhávamos": "desarmadilhar",
    "desarmadilhávei": "desarmadilhar",
    "desarmadilháveis": "desarmadilhar",
    "desarmado": "desarmar",
    "desarmadora": "desarmador",
    "desarmadoras": "desarmador",
    "desarmadores": "desarmador",
    "desarmados": "desarmar",
    "desarmai": "desarmar",
    "desarmais": "desarmar",
    "desarmam": "desarmar",
    "desarmamentismoos": "desarmamentismoo",
    "desarmamentos": "desarmamento",
    "desarmamo": "desarmar",
    "desarmamos": "desarmar",
    "desarmando": "desarmar",
    "desarmantes": "desarmante",
    "desarmara": "desarmar",
    "desarmaram": "desarmar",
    "desarmaras": "desarmar",
    "desarmarde": "desarmar",
    "desarmardes": "desarmar",
    "desarmare": "desarmar",
    "desarmarei": "desarmar",
    "desarmareis": "desarmar",
    "desarmarem": "desarmar",
    "desarmaremos": "desarmar",
    "desarmares": "desarmar",
    "desarmaria": "desarmar",
    "desarmariam": "desarmar",
    "desarmarias": "desarmar",
    "desarmarmo": "desarmar",
    "desarmarmos": "desarmar",
    "desarmará": "desarmar",
    "desarmarás": "desarmar",
    "desarmarão": "desarmar",
    "desarmaríamos": "desarmar",
    "desarmaríeis": "desarmar",
    "desarmas": "desarmar",
    "desarmasse": "desarmar",
    "desarmassem": "desarmar",
    "desarmasses": "desarmar",
    "desarmaste": "desarmar",
    "desarmastes": "desarmar",
    "desarmava": "desarmar",
    "desarmavam": "desarmar",
    "desarmavas": "desarmar",
    "desarmações": "desarmação",
    "desarme": "desarmar",
    "desarmei": "desarmar",
    "desarmeis": "desarmar",
    "desarmem": "desarmar",
    "desarmemo": "desarmar",
    "desarmemos": "desarmar",
    "desarmes": "desarme",
    "desarmo": "desarmar",
    "desarmonias": "desarmonia",
    "desarmoniosa": "desarmonioso",
    "desarmoniosas": "desarmonioso",
    "desarmoniosos": "desarmonioso",
    "desarmoniza": "desarmonizar",
    "desarmonizada": "desarmonizar",
    "desarmonizadas": "desarmonizar",
    "desarmonizado": "desarmonizar",
    "desarmonizadora": "desarmonizador",
    "desarmonizadoras": "desarmonizador",
    "desarmonizadores": "desarmonizador",
    "desarmonizados": "desarmonizar",
    "desarmonizai": "desarmonizar",
    "desarmonizais": "desarmonizar",
    "desarmonizam": "desarmonizar",
    "desarmonizamo": "desarmonizar",
    "desarmonizamos": "desarmonizar",
    "desarmonizando": "desarmonizar",
    "desarmonizara": "desarmonizar",
    "desarmonizaram": "desarmonizar",
    "desarmonizaras": "desarmonizar",
    "desarmonizarde": "desarmonizar",
    "desarmonizardes": "desarmonizar",
    "desarmonizare": "desarmonizar",
    "desarmonizarei": "desarmonizar",
    "desarmonizareis": "desarmonizar",
    "desarmonizarem": "desarmonizar",
    "desarmonizaremos": "desarmonizar",
    "desarmonizares": "desarmonizar",
    "desarmonizaria": "desarmonizar",
    "desarmonizariam": "desarmonizar",
    "desarmonizarias": "desarmonizar",
    "desarmonizarmo": "desarmonizar",
    "desarmonizarmos": "desarmonizar",
    "desarmonizará": "desarmonizar",
    "desarmonizarás": "desarmonizar",
    "desarmonizarão": "desarmonizar",
    "desarmonizaríamos": "desarmonizar",
    "desarmonizaríeis": "desarmonizar",
    "desarmonizas": "desarmonizar",
    "desarmonizasse": "desarmonizar",
    "desarmonizassem": "desarmonizar",
    "desarmonizasses": "desarmonizar",
    "desarmonizaste": "desarmonizar",
    "desarmonizastes": "desarmonizar",
    "desarmonizava": "desarmonizar",
    "desarmonizavam": "desarmonizar",
    "desarmonizavas": "desarmonizar",
    "desarmonizações": "desarmonização",
    "desarmonize": "desarmonizar",
    "desarmonizei": "desarmonizar",
    "desarmonizeis": "desarmonizar",
    "desarmonizem": "desarmonizar",
    "desarmonizemo": "desarmonizar",
    "desarmonizemos": "desarmonizar",
    "desarmonizes": "desarmonizar",
    "desarmonizo": "desarmonizar",
    "desarmonizou": "desarmonizar",
    "desarmonizá": "desarmonizar",
    "desarmonizámo": "desarmonizar",
    "desarmonizámos": "desarmonizar",
    "desarmonizáramo": "desarmonizar",
    "desarmonizáramos": "desarmonizar",
    "desarmonizárei": "desarmonizar",
    "desarmonizáreis": "desarmonizar",
    "desarmonizásseis": "desarmonizar",
    "desarmonizássemos": "desarmonizar",
    "desarmonizávamo": "desarmonizar",
    "desarmonizávamos": "desarmonizar",
    "desarmonizávei": "desarmonizar",
    "desarmonizáveis": "desarmonizar",
    "desarmou": "desarmar",
    "desarmá": "desarmar",
    "desarmámo": "desarmar",
    "desarmámos": "desarmar",
    "desarmáramo": "desarmar",
    "desarmáramos": "desarmar",
    "desarmárei": "desarmar",
    "desarmáreis": "desarmar",
    "desarmásseis": "desarmar",
    "desarmássemos": "desarmar",
    "desarmávamo": "desarmar",
    "desarmávamos": "desarmar",
    "desarmávei": "desarmar",
    "desarmáveis": "desarmar",
    "desarmónica": "desarmónico",
    "desarmónicas": "desarmónico",
    "desarmónicos": "desarmónico",
    "desaromatiza": "desaromatizar",
    "desaromatizada": "desaromatizar",
    "desaromatizadas": "desaromatizar",
    "desaromatizado": "desaromatizar",
    "desaromatizados": "desaromatizar",
    "desaromatizai": "desaromatizar",
    "desaromatizais": "desaromatizar",
    "desaromatizam": "desaromatizar",
    "desaromatizamo": "desaromatizar",
    "desaromatizamos": "desaromatizar",
    "desaromatizando": "desaromatizar",
    "desaromatizara": "desaromatizar",
    "desaromatizaram": "desaromatizar",
    "desaromatizaras": "desaromatizar",
    "desaromatizarde": "desaromatizar",
    "desaromatizardes": "desaromatizar",
    "desaromatizare": "desaromatizar",
    "desaromatizarei": "desaromatizar",
    "desaromatizareis": "desaromatizar",
    "desaromatizarem": "desaromatizar",
    "desaromatizaremos": "desaromatizar",
    "desaromatizares": "desaromatizar",
    "desaromatizaria": "desaromatizar",
    "desaromatizariam": "desaromatizar",
    "desaromatizarias": "desaromatizar",
    "desaromatizarmo": "desaromatizar",
    "desaromatizarmos": "desaromatizar",
    "desaromatizará": "desaromatizar",
    "desaromatizarás": "desaromatizar",
    "desaromatizarão": "desaromatizar",
    "desaromatizaríamos": "desaromatizar",
    "desaromatizaríeis": "desaromatizar",
    "desaromatizas": "desaromatizar",
    "desaromatizasse": "desaromatizar",
    "desaromatizassem": "desaromatizar",
    "desaromatizasses": "desaromatizar",
    "desaromatizaste": "desaromatizar",
    "desaromatizastes": "desaromatizar",
    "desaromatizava": "desaromatizar",
    "desaromatizavam": "desaromatizar",
    "desaromatizavas": "desaromatizar",
    "desaromatize": "desaromatizar",
    "desaromatizei": "desaromatizar",
    "desaromatizeis": "desaromatizar",
    "desaromatizem": "desaromatizar",
    "desaromatizemo": "desaromatizar",
    "desaromatizemos": "desaromatizar",
    "desaromatizes": "desaromatizar",
    "desaromatizo": "desaromatizar",
    "desaromatizou": "desaromatizar",
    "desaromatizá": "desaromatizar",
    "desaromatizámo": "desaromatizar",
    "desaromatizámos": "desaromatizar",
    "desaromatizáramo": "desaromatizar",
    "desaromatizáramos": "desaromatizar",
    "desaromatizárei": "desaromatizar",
    "desaromatizáreis": "desaromatizar",
    "desaromatizásseis": "desaromatizar",
    "desaromatizássemos": "desaromatizar",
    "desaromatizávamo": "desaromatizar",
    "desaromatizávamos": "desaromatizar",
    "desaromatizávei": "desaromatizar",
    "desaromatizáveis": "desaromatizar",
    "desarque": "desarcar",
    "desarqueada": "desarquear",
    "desarqueadas": "desarquear",
    "desarqueado": "desarquear",
    "desarqueados": "desarquear",
    "desarqueai": "desarquear",
    "desarqueais": "desarquear",
    "desarqueamo": "desarquear",
    "desarqueamos": "desarquear",
    "desarqueando": "desarquear",
    "desarqueara": "desarquear",
    "desarquearam": "desarquear",
    "desarquearas": "desarquear",
    "desarquearde": "desarquear",
    "desarqueardes": "desarquear",
    "desarqueare": "desarquear",
    "desarquearei": "desarquear",
    "desarqueareis": "desarquear",
    "desarquearem": "desarquear",
    "desarquearemos": "desarquear",
    "desarqueares": "desarquear",
    "desarquearia": "desarquear",
    "desarqueariam": "desarquear",
    "desarquearias": "desarquear",
    "desarquearmo": "desarquear",
    "desarquearmos": "desarquear",
    "desarqueará": "desarquear",
    "desarquearás": "desarquear",
    "desarquearão": "desarquear",
    "desarquearíamos": "desarquear",
    "desarquearíeis": "desarquear",
    "desarqueasse": "desarquear",
    "desarqueassem": "desarquear",
    "desarqueasses": "desarquear",
    "desarqueaste": "desarquear",
    "desarqueastes": "desarquear",
    "desarqueava": "desarquear",
    "desarqueavam": "desarquear",
    "desarqueavas": "desarquear",
    "desarqueei": "desarquear",
    "desarqueeis": "desarquear",
    "desarqueemo": "desarquear",
    "desarqueemos": "desarquear",
    "desarquei": "desarcar",
    "desarqueia": "desarquear",
    "desarqueiam": "desarquear",
    "desarqueias": "desarquear",
    "desarqueie": "desarquear",
    "desarqueiem": "desarquear",
    "desarqueies": "desarquear",
    "desarqueio": "desarquear",
    "desarqueis": "desarcar",
    "desarquem": "desarcar",
    "desarquemo": "desarcar",
    "desarquemos": "desarcar",
    "desarqueou": "desarquear",
    "desarques": "desarcar",
    "desarqueá": "desarquear",
    "desarqueámo": "desarquear",
    "desarqueámos": "desarquear",
    "desarqueáramo": "desarquear",
    "desarqueáramos": "desarquear",
    "desarqueárei": "desarquear",
    "desarqueáreis": "desarquear",
    "desarqueásseis": "desarquear",
    "desarqueássemos": "desarquear",
    "desarqueávamo": "desarquear",
    "desarqueávamos": "desarquear",
    "desarqueávei": "desarquear",
    "desarqueáveis": "desarquear",
    "desarquitecta": "desarquitectar",
    "desarquitectada": "desarquitectar",
    "desarquitectadas": "desarquitectar",
    "desarquitectado": "desarquitectar",
    "desarquitectados": "desarquitectar",
    "desarquitectai": "desarquitectar",
    "desarquitectais": "desarquitectar",
    "desarquitectam": "desarquitectar",
    "desarquitectamo": "desarquitectar",
    "desarquitectamos": "desarquitectar",
    "desarquitectando": "desarquitectar",
    "desarquitectara": "desarquitectar",
    "desarquitectaram": "desarquitectar",
    "desarquitectaras": "desarquitectar",
    "desarquitectarde": "desarquitectar",
    "desarquitectardes": "desarquitectar",
    "desarquitectare": "desarquitectar",
    "desarquitectarei": "desarquitectar",
    "desarquitectareis": "desarquitectar",
    "desarquitectarem": "desarquitectar",
    "desarquitectaremos": "desarquitectar",
    "desarquitectares": "desarquitectar",
    "desarquitectaria": "desarquitectar",
    "desarquitectariam": "desarquitectar",
    "desarquitectarias": "desarquitectar",
    "desarquitectarmo": "desarquitectar",
    "desarquitectarmos": "desarquitectar",
    "desarquitectará": "desarquitectar",
    "desarquitectarás": "desarquitectar",
    "desarquitectarão": "desarquitectar",
    "desarquitectaríamos": "desarquitectar",
    "desarquitectaríeis": "desarquitectar",
    "desarquitectas": "desarquitectar",
    "desarquitectasse": "desarquitectar",
    "desarquitectassem": "desarquitectar",
    "desarquitectasses": "desarquitectar",
    "desarquitectaste": "desarquitectar",
    "desarquitectastes": "desarquitectar",
    "desarquitectava": "desarquitectar",
    "desarquitectavam": "desarquitectar",
    "desarquitectavas": "desarquitectar",
    "desarquitecte": "desarquitectar",
    "desarquitectei": "desarquitectar",
    "desarquitecteis": "desarquitectar",
    "desarquitectem": "desarquitectar",
    "desarquitectemo": "desarquitectar",
    "desarquitectemos": "desarquitectar",
    "desarquitectes": "desarquitectar",
    "desarquitecto": "desarquitectar",
    "desarquitectou": "desarquitectar",
    "desarquitectá": "desarquitectar",
    "desarquitectámo": "desarquitectar",
    "desarquitectámos": "desarquitectar",
    "desarquitectáramo": "desarquitectar",
    "desarquitectáramos": "desarquitectar",
    "desarquitectárei": "desarquitectar",
    "desarquitectáreis": "desarquitectar",
    "desarquitectásseis": "desarquitectar",
    "desarquitectássemos": "desarquitectar",
    "desarquitectávamo": "desarquitectar",
    "desarquitectávamos": "desarquitectar",
    "desarquitectávei": "desarquitectar",
    "desarquitectáveis": "desarquitectar",
    "desarraiga": "desarraigar",
    "desarraigada": "desarraigar",
    "desarraigadas": "desarraigar",
    "desarraigado": "desarraigar",
    "desarraigados": "desarraigar",
    "desarraigai": "desarraigar",
    "desarraigais": "desarraigar",
    "desarraigam": "desarraigar",
    "desarraigamentos": "desarraigamento",
    "desarraigamo": "desarraigar",
    "desarraigamos": "desarraigar",
    "desarraigando": "desarraigar",
    "desarraigara": "desarraigar",
    "desarraigaram": "desarraigar",
    "desarraigaras": "desarraigar",
    "desarraigarde": "desarraigar",
    "desarraigardes": "desarraigar",
    "desarraigare": "desarraigar",
    "desarraigarei": "desarraigar",
    "desarraigareis": "desarraigar",
    "desarraigarem": "desarraigar",
    "desarraigaremos": "desarraigar",
    "desarraigares": "desarraigar",
    "desarraigaria": "desarraigar",
    "desarraigariam": "desarraigar",
    "desarraigarias": "desarraigar",
    "desarraigarmo": "desarraigar",
    "desarraigarmos": "desarraigar",
    "desarraigará": "desarraigar",
    "desarraigarás": "desarraigar",
    "desarraigarão": "desarraigar",
    "desarraigaríamos": "desarraigar",
    "desarraigaríeis": "desarraigar",
    "desarraigas": "desarraigar",
    "desarraigasse": "desarraigar",
    "desarraigassem": "desarraigar",
    "desarraigasses": "desarraigar",
    "desarraigaste": "desarraigar",
    "desarraigastes": "desarraigar",
    "desarraigava": "desarraigar",
    "desarraigavam": "desarraigar",
    "desarraigavas": "desarraigar",
    "desarraigo": "desarraigar",
    "desarraigou": "desarraigar",
    "desarraigue": "desarraigar",
    "desarraiguei": "desarraigar",
    "desarraigueis": "desarraigar",
    "desarraiguem": "desarraigar",
    "desarraiguemo": "desarraigar",
    "desarraiguemos": "desarraigar",
    "desarraigues": "desarraigar",
    "desarraigá": "desarraigar",
    "desarraigámo": "desarraigar",
    "desarraigámos": "desarraigar",
    "desarraigáramo": "desarraigar",
    "desarraigáramos": "desarraigar",
    "desarraigárei": "desarraigar",
    "desarraigáreis": "desarraigar",
    "desarraigásseis": "desarraigar",
    "desarraigássemos": "desarraigar",
    "desarraigávamo": "desarraigar",
    "desarraigávamos": "desarraigar",
    "desarraigávei": "desarraigar",
    "desarraigáveis": "desarraigar",
    "desarranchada": "desarranchado",
    "desarranchadas": "desarranchado",
    "desarranchados": "desarranchado",
    "desarranja": "desarranjar",
    "desarranjada": "desarranjar",
    "desarranjadas": "desarranjar",
    "desarranjado": "desarranjar",
    "desarranjadora": "desarranjador",
    "desarranjadoras": "desarranjador",
    "desarranjadores": "desarranjador",
    "desarranjados": "desarranjar",
    "desarranjai": "desarranjar",
    "desarranjais": "desarranjar",
    "desarranjam": "desarranjar",
    "desarranjamentos": "desarranjamento",
    "desarranjamo": "desarranjar",
    "desarranjamos": "desarranjar",
    "desarranjando": "desarranjar",
    "desarranjara": "desarranjar",
    "desarranjaram": "desarranjar",
    "desarranjaras": "desarranjar",
    "desarranjarde": "desarranjar",
    "desarranjardes": "desarranjar",
    "desarranjare": "desarranjar",
    "desarranjarei": "desarranjar",
    "desarranjareis": "desarranjar",
    "desarranjarem": "desarranjar",
    "desarranjaremos": "desarranjar",
    "desarranjares": "desarranjar",
    "desarranjaria": "desarranjar",
    "desarranjariam": "desarranjar",
    "desarranjarias": "desarranjar",
    "desarranjarmo": "desarranjar",
    "desarranjarmos": "desarranjar",
    "desarranjará": "desarranjar",
    "desarranjarás": "desarranjar",
    "desarranjarão": "desarranjar",
    "desarranjaríamos": "desarranjar",
    "desarranjaríeis": "desarranjar",
    "desarranjas": "desarranjar",
    "desarranjasse": "desarranjar",
    "desarranjassem": "desarranjar",
    "desarranjasses": "desarranjar",
    "desarranjaste": "desarranjar",
    "desarranjastes": "desarranjar",
    "desarranjava": "desarranjar",
    "desarranjavam": "desarranjar",
    "desarranjavas": "desarranjar",
    "desarranje": "desarranjar",
    "desarranjei": "desarranjar",
    "desarranjeis": "desarranjar",
    "desarranjem": "desarranjar",
    "desarranjemo": "desarranjar",
    "desarranjemos": "desarranjar",
    "desarranjes": "desarranjar",
    "desarranjo": "desarranjar",
    "desarranjos": "desarranjo",
    "desarranjou": "desarranjar",
    "desarranjá": "desarranjar",
    "desarranjámo": "desarranjar",
    "desarranjámos": "desarranjar",
    "desarranjáramo": "desarranjar",
    "desarranjáramos": "desarranjar",
    "desarranjárei": "desarranjar",
    "desarranjáreis": "desarranjar",
    "desarranjásseis": "desarranjar",
    "desarranjássemos": "desarranjar",
    "desarranjávamo": "desarranjar",
    "desarranjávamos": "desarranjar",
    "desarranjávei": "desarranjar",
    "desarranjáveis": "desarranjar",
    "desarrazoa": "desarrazoar",
    "desarrazoada": "desarrazoar",
    "desarrazoadas": "desarrazoar",
    "desarrazoado": "desarrazoar",
    "desarrazoados": "desarrazoar",
    "desarrazoai": "desarrazoar",
    "desarrazoais": "desarrazoar",
    "desarrazoam": "desarrazoar",
    "desarrazoamentos": "desarrazoamento",
    "desarrazoamo": "desarrazoar",
    "desarrazoamos": "desarrazoar",
    "desarrazoando": "desarrazoar",
    "desarrazoara": "desarrazoar",
    "desarrazoaram": "desarrazoar",
    "desarrazoaras": "desarrazoar",
    "desarrazoardes": "desarrazoar",
    "desarrazoarei": "desarrazoar",
    "desarrazoareis": "desarrazoar",
    "desarrazoarem": "desarrazoar",
    "desarrazoaremos": "desarrazoar",
    "desarrazoares": "desarrazoar",
    "desarrazoaria": "desarrazoar",
    "desarrazoariam": "desarrazoar",
    "desarrazoarias": "desarrazoar",
    "desarrazoarmo": "desarrazoar",
    "desarrazoarmos": "desarrazoar",
    "desarrazoará": "desarrazoar",
    "desarrazoarás": "desarrazoar",
    "desarrazoarão": "desarrazoar",
    "desarrazoaríamos": "desarrazoar",
    "desarrazoaríeis": "desarrazoar",
    "desarrazoas": "desarrazoar",
    "desarrazoasse": "desarrazoar",
    "desarrazoassem": "desarrazoar",
    "desarrazoasses": "desarrazoar",
    "desarrazoaste": "desarrazoar",
    "desarrazoastes": "desarrazoar",
    "desarrazoava": "desarrazoar",
    "desarrazoavam": "desarrazoar",
    "desarrazoavas": "desarrazoar",
    "desarrazoe": "desarrazoar",
    "desarrazoei": "desarrazoar",
    "desarrazoeis": "desarrazoar",
    "desarrazoem": "desarrazoar",
    "desarrazoemo": "desarrazoar",
    "desarrazoemos": "desarrazoar",
    "desarrazoes": "desarrazoar",
    "desarrazoo": "desarrazoar",
    "desarrazoou": "desarrazoar",
    "desarrazoámo": "desarrazoar",
    "desarrazoámos": "desarrazoar",
    "desarrazoáramo": "desarrazoar",
    "desarrazoáramos": "desarrazoar",
    "desarrazoáreis": "desarrazoar",
    "desarrazoásseis": "desarrazoar",
    "desarrazoássemos": "desarrazoar",
    "desarrazoávamo": "desarrazoar",
    "desarrazoávamos": "desarrazoar",
    "desarrazoáveis": "desarrazoar",
    "desarreada": "desarrear",
    "desarreadas": "desarrear",
    "desarreado": "desarrear",
    "desarreados": "desarrear",
    "desarreai": "desarrear",
    "desarreais": "desarrear",
    "desarreamo": "desarrear",
    "desarreamos": "desarrear",
    "desarreando": "desarrear",
    "desarreara": "desarrear",
    "desarrearam": "desarrear",
    "desarrearas": "desarrear",
    "desarrearde": "desarrear",
    "desarreardes": "desarrear",
    "desarreare": "desarrear",
    "desarrearei": "desarrear",
    "desarreareis": "desarrear",
    "desarrearem": "desarrear",
    "desarrearemos": "desarrear",
    "desarreares": "desarrear",
    "desarrearia": "desarrear",
    "desarreariam": "desarrear",
    "desarrearias": "desarrear",
    "desarrearmo": "desarrear",
    "desarrearmos": "desarrear",
    "desarreará": "desarrear",
    "desarrearás": "desarrear",
    "desarrearão": "desarrear",
    "desarrearíamos": "desarrear",
    "desarrearíeis": "desarrear",
    "desarreasse": "desarrear",
    "desarreassem": "desarrear",
    "desarreasses": "desarrear",
    "desarreaste": "desarrear",
    "desarreastes": "desarrear",
    "desarreata": "desarreatar",
    "desarreatada": "desarreatar",
    "desarreatadas": "desarreatar",
    "desarreatado": "desarreatar",
    "desarreatados": "desarreatar",
    "desarreatai": "desarreatar",
    "desarreatais": "desarreatar",
    "desarreatam": "desarreatar",
    "desarreatamo": "desarreatar",
    "desarreatamos": "desarreatar",
    "desarreatando": "desarreatar",
    "desarreatara": "desarreatar",
    "desarreataram": "desarreatar",
    "desarreataras": "desarreatar",
    "desarreatarde": "desarreatar",
    "desarreatardes": "desarreatar",
    "desarreatare": "desarreatar",
    "desarreatarei": "desarreatar",
    "desarreatareis": "desarreatar",
    "desarreatarem": "desarreatar",
    "desarreataremos": "desarreatar",
    "desarreatares": "desarreatar",
    "desarreataria": "desarreatar",
    "desarreatariam": "desarreatar",
    "desarreatarias": "desarreatar",
    "desarreatarmo": "desarreatar",
    "desarreatarmos": "desarreatar",
    "desarreatará": "desarreatar",
    "desarreatarás": "desarreatar",
    "desarreatarão": "desarreatar",
    "desarreataríamos": "desarreatar",
    "desarreataríeis": "desarreatar",
    "desarreatas": "desarreatar",
    "desarreatasse": "desarreatar",
    "desarreatassem": "desarreatar",
    "desarreatasses": "desarreatar",
    "desarreataste": "desarreatar",
    "desarreatastes": "desarreatar",
    "desarreatava": "desarreatar",
    "desarreatavam": "desarreatar",
    "desarreatavas": "desarreatar",
    "desarreate": "desarreatar",
    "desarreatei": "desarreatar",
    "desarreateis": "desarreatar",
    "desarreatem": "desarreatar",
    "desarreatemo": "desarreatar",
    "desarreatemos": "desarreatar",
    "desarreates": "desarreatar",
    "desarreato": "desarreatar",
    "desarreatou": "desarreatar",
    "desarreatá": "desarreatar",
    "desarreatámo": "desarreatar",
    "desarreatámos": "desarreatar",
    "desarreatáramo": "desarreatar",
    "desarreatáramos": "desarreatar",
    "desarreatárei": "desarreatar",
    "desarreatáreis": "desarreatar",
    "desarreatásseis": "desarreatar",
    "desarreatássemos": "desarreatar",
    "desarreatávamo": "desarreatar",
    "desarreatávamos": "desarreatar",
    "desarreatávei": "desarreatar",
    "desarreatáveis": "desarreatar",
    "desarreava": "desarrear",
    "desarreavam": "desarrear",
    "desarreavas": "desarrear",
    "desarrebita": "desarrebitar",
    "desarrebitada": "desarrebitar",
    "desarrebitadas": "desarrebitar",
    "desarrebitado": "desarrebitar",
    "desarrebitados": "desarrebitar",
    "desarrebitai": "desarrebitar",
    "desarrebitais": "desarrebitar",
    "desarrebitam": "desarrebitar",
    "desarrebitamo": "desarrebitar",
    "desarrebitamos": "desarrebitar",
    "desarrebitando": "desarrebitar",
    "desarrebitara": "desarrebitar",
    "desarrebitaram": "desarrebitar",
    "desarrebitaras": "desarrebitar",
    "desarrebitarde": "desarrebitar",
    "desarrebitardes": "desarrebitar",
    "desarrebitare": "desarrebitar",
    "desarrebitarei": "desarrebitar",
    "desarrebitareis": "desarrebitar",
    "desarrebitarem": "desarrebitar",
    "desarrebitaremos": "desarrebitar",
    "desarrebitares": "desarrebitar",
    "desarrebitaria": "desarrebitar",
    "desarrebitariam": "desarrebitar",
    "desarrebitarias": "desarrebitar",
    "desarrebitarmo": "desarrebitar",
    "desarrebitarmos": "desarrebitar",
    "desarrebitará": "desarrebitar",
    "desarrebitarás": "desarrebitar",
    "desarrebitarão": "desarrebitar",
    "desarrebitaríamos": "desarrebitar",
    "desarrebitaríeis": "desarrebitar",
    "desarrebitas": "desarrebitar",
    "desarrebitasse": "desarrebitar",
    "desarrebitassem": "desarrebitar",
    "desarrebitasses": "desarrebitar",
    "desarrebitaste": "desarrebitar",
    "desarrebitastes": "desarrebitar",
    "desarrebitava": "desarrebitar",
    "desarrebitavam": "desarrebitar",
    "desarrebitavas": "desarrebitar",
    "desarrebite": "desarrebitar",
    "desarrebitei": "desarrebitar",
    "desarrebiteis": "desarrebitar",
    "desarrebitem": "desarrebitar",
    "desarrebitemo": "desarrebitar",
    "desarrebitemos": "desarrebitar",
    "desarrebites": "desarrebitar",
    "desarrebito": "desarrebitar",
    "desarrebitou": "desarrebitar",
    "desarrebitá": "desarrebitar",
    "desarrebitámo": "desarrebitar",
    "desarrebitámos": "desarrebitar",
    "desarrebitáramo": "desarrebitar",
    "desarrebitáramos": "desarrebitar",
    "desarrebitárei": "desarrebitar",
    "desarrebitáreis": "desarrebitar",
    "desarrebitásseis": "desarrebitar",
    "desarrebitássemos": "desarrebitar",
    "desarrebitávamo": "desarrebitar",
    "desarrebitávamos": "desarrebitar",
    "desarrebitávei": "desarrebitar",
    "desarrebitáveis": "desarrebitar",
    "desarredada": "desarredado",
    "desarredadas": "desarredado",
    "desarredados": "desarredado",
    "desarredonda": "desarredondar",
    "desarredondada": "desarredondar",
    "desarredondadas": "desarredondar",
    "desarredondado": "desarredondar",
    "desarredondados": "desarredondar",
    "desarredondai": "desarredondar",
    "desarredondais": "desarredondar",
    "desarredondam": "desarredondar",
    "desarredondamo": "desarredondar",
    "desarredondamos": "desarredondar",
    "desarredondando": "desarredondar",
    "desarredondara": "desarredondar",
    "desarredondaram": "desarredondar",
    "desarredondaras": "desarredondar",
    "desarredondarde": "desarredondar",
    "desarredondardes": "desarredondar",
    "desarredondare": "desarredondar",
    "desarredondarei": "desarredondar",
    "desarredondareis": "desarredondar",
    "desarredondarem": "desarredondar",
    "desarredondaremos": "desarredondar",
    "desarredondares": "desarredondar",
    "desarredondaria": "desarredondar",
    "desarredondariam": "desarredondar",
    "desarredondarias": "desarredondar",
    "desarredondarmo": "desarredondar",
    "desarredondarmos": "desarredondar",
    "desarredondará": "desarredondar",
    "desarredondarás": "desarredondar",
    "desarredondarão": "desarredondar",
    "desarredondaríamos": "desarredondar",
    "desarredondaríeis": "desarredondar",
    "desarredondas": "desarredondar",
    "desarredondasse": "desarredondar",
    "desarredondassem": "desarredondar",
    "desarredondasses": "desarredondar",
    "desarredondaste": "desarredondar",
    "desarredondastes": "desarredondar",
    "desarredondava": "desarredondar",
    "desarredondavam": "desarredondar",
    "desarredondavas": "desarredondar",
    "desarredonde": "desarredondar",
    "desarredondei": "desarredondar",
    "desarredondeis": "desarredondar",
    "desarredondem": "desarredondar",
    "desarredondemo": "desarredondar",
    "desarredondemos": "desarredondar",
    "desarredondes": "desarredondar",
    "desarredondo": "desarredondar",
    "desarredondou": "desarredondar",
    "desarredondá": "desarredondar",
    "desarredondámo": "desarredondar",
    "desarredondámos": "desarredondar",
    "desarredondáramo": "desarredondar",
    "desarredondáramos": "desarredondar",
    "desarredondárei": "desarredondar",
    "desarredondáreis": "desarredondar",
    "desarredondásseis": "desarredondar",
    "desarredondássemos": "desarredondar",
    "desarredondávamo": "desarredondar",
    "desarredondávamos": "desarredondar",
    "desarredondávei": "desarredondar",
    "desarredondáveis": "desarredondar",
    "desarreei": "desarrear",
    "desarreeis": "desarrear",
    "desarreemo": "desarrear",
    "desarreemos": "desarrear",
    "desarregace": "desarregaçar",
    "desarregacei": "desarregaçar",
    "desarregaceis": "desarregaçar",
    "desarregacem": "desarregaçar",
    "desarregacemo": "desarregaçar",
    "desarregacemos": "desarregaçar",
    "desarregaces": "desarregaçar",
    "desarregaça": "desarregaçar",
    "desarregaçada": "desarregaçar",
    "desarregaçadas": "desarregaçar",
    "desarregaçado": "desarregaçar",
    "desarregaçados": "desarregaçar",
    "desarregaçai": "desarregaçar",
    "desarregaçais": "desarregaçar",
    "desarregaçam": "desarregaçar",
    "desarregaçamo": "desarregaçar",
    "desarregaçamos": "desarregaçar",
    "desarregaçando": "desarregaçar",
    "desarregaçara": "desarregaçar",
    "desarregaçaram": "desarregaçar",
    "desarregaçaras": "desarregaçar",
    "desarregaçarde": "desarregaçar",
    "desarregaçardes": "desarregaçar",
    "desarregaçare": "desarregaçar",
    "desarregaçarei": "desarregaçar",
    "desarregaçareis": "desarregaçar",
    "desarregaçarem": "desarregaçar",
    "desarregaçaremos": "desarregaçar",
    "desarregaçares": "desarregaçar",
    "desarregaçaria": "desarregaçar",
    "desarregaçariam": "desarregaçar",
    "desarregaçarias": "desarregaçar",
    "desarregaçarmo": "desarregaçar",
    "desarregaçarmos": "desarregaçar",
    "desarregaçará": "desarregaçar",
    "desarregaçarás": "desarregaçar",
    "desarregaçarão": "desarregaçar",
    "desarregaçaríamos": "desarregaçar",
    "desarregaçaríeis": "desarregaçar",
    "desarregaças": "desarregaçar",
    "desarregaçasse": "desarregaçar",
    "desarregaçassem": "desarregaçar",
    "desarregaçasses": "desarregaçar",
    "desarregaçaste": "desarregaçar",
    "desarregaçastes": "desarregaçar",
    "desarregaçava": "desarregaçar",
    "desarregaçavam": "desarregaçar",
    "desarregaçavas": "desarregaçar",
    "desarregaço": "desarregaçar",
    "desarregaçou": "desarregaçar",
    "desarregaçá": "desarregaçar",
    "desarregaçámo": "desarregaçar",
    "desarregaçámos": "desarregaçar",
    "desarregaçáramo": "desarregaçar",
    "desarregaçáramos": "desarregaçar",
    "desarregaçárei": "desarregaçar",
    "desarregaçáreis": "desarregaçar",
    "desarregaçásseis": "desarregaçar",
    "desarregaçássemos": "desarregaçar",
    "desarregaçávamo": "desarregaçar",
    "desarregaçávamos": "desarregaçar",
    "desarregaçávei": "desarregaçar",
    "desarregaçáveis": "desarregaçar",
    "desarreia": "desarrear",
    "desarreiam": "desarrear",
    "desarreias": "desarrear",
    "desarreie": "desarrear",
    "desarreiem": "desarrear",
    "desarreies": "desarrear",
    "desarreiga": "desarreigar",
    "desarreigada": "desarreigar",
    "desarreigadas": "desarreigar",
    "desarreigado": "desarreigar",
    "desarreigados": "desarreigar",
    "desarreigai": "desarreigar",
    "desarreigais": "desarreigar",
    "desarreigam": "desarreigar",
    "desarreigamentos": "desarreigamento",
    "desarreigamo": "desarreigar",
    "desarreigamos": "desarreigar",
    "desarreigando": "desarreigar",
    "desarreigara": "desarreigar",
    "desarreigaram": "desarreigar",
    "desarreigaras": "desarreigar",
    "desarreigarde": "desarreigar",
    "desarreigardes": "desarreigar",
    "desarreigare": "desarreigar",
    "desarreigarei": "desarreigar",
    "desarreigareis": "desarreigar",
    "desarreigarem": "desarreigar",
    "desarreigaremos": "desarreigar",
    "desarreigares": "desarreigar",
    "desarreigaria": "desarreigar",
    "desarreigariam": "desarreigar",
    "desarreigarias": "desarreigar",
    "desarreigarmo": "desarreigar",
    "desarreigarmos": "desarreigar",
    "desarreigará": "desarreigar",
    "desarreigarás": "desarreigar",
    "desarreigarão": "desarreigar",
    "desarreigaríamos": "desarreigar",
    "desarreigaríeis": "desarreigar",
    "desarreigas": "desarreigar",
    "desarreigasse": "desarreigar",
    "desarreigassem": "desarreigar",
    "desarreigasses": "desarreigar",
    "desarreigaste": "desarreigar",
    "desarreigastes": "desarreigar",
    "desarreigava": "desarreigar",
    "desarreigavam": "desarreigar",
    "desarreigavas": "desarreigar",
    "desarreigo": "desarreigar",
    "desarreigou": "desarreigar",
    "desarreigue": "desarreigar",
    "desarreiguei": "desarreigar",
    "desarreigueis": "desarreigar",
    "desarreiguem": "desarreigar",
    "desarreiguemo": "desarreigar",
    "desarreiguemos": "desarreigar",
    "desarreigues": "desarreigar",
    "desarreigá": "desarreigar",
    "desarreigámo": "desarreigar",
    "desarreigámos": "desarreigar",
    "desarreigáramo": "desarreigar",
    "desarreigáramos": "desarreigar",
    "desarreigárei": "desarreigar",
    "desarreigáreis": "desarreigar",
    "desarreigásseis": "desarreigar",
    "desarreigássemos": "desarreigar",
    "desarreigávamo": "desarreigar",
    "desarreigávamos": "desarreigar",
    "desarreigávei": "desarreigar",
    "desarreigáveis": "desarreigar",
    "desarreio": "desarrear",
    "desarreou": "desarrear",
    "desarreá": "desarrear",
    "desarreámo": "desarrear",
    "desarreámos": "desarrear",
    "desarreáramo": "desarrear",
    "desarreáramos": "desarrear",
    "desarreárei": "desarrear",
    "desarreáreis": "desarrear",
    "desarreásseis": "desarrear",
    "desarreássemos": "desarrear",
    "desarreávamo": "desarrear",
    "desarreávamos": "desarrear",
    "desarreávei": "desarrear",
    "desarreáveis": "desarrear",
    "desarrima": "desarrimar",
    "desarrimada": "desarrimar",
    "desarrimadas": "desarrimar",
    "desarrimado": "desarrimar",
    "desarrimados": "desarrimar",
    "desarrimai": "desarrimar",
    "desarrimais": "desarrimar",
    "desarrimam": "desarrimar",
    "desarrimamo": "desarrimar",
    "desarrimamos": "desarrimar",
    "desarrimando": "desarrimar",
    "desarrimara": "desarrimar",
    "desarrimaram": "desarrimar",
    "desarrimaras": "desarrimar",
    "desarrimarde": "desarrimar",
    "desarrimardes": "desarrimar",
    "desarrimare": "desarrimar",
    "desarrimarei": "desarrimar",
    "desarrimareis": "desarrimar",
    "desarrimarem": "desarrimar",
    "desarrimaremos": "desarrimar",
    "desarrimares": "desarrimar",
    "desarrimaria": "desarrimar",
    "desarrimariam": "desarrimar",
    "desarrimarias": "desarrimar",
    "desarrimarmo": "desarrimar",
    "desarrimarmos": "desarrimar",
    "desarrimará": "desarrimar",
    "desarrimarás": "desarrimar",
    "desarrimarão": "desarrimar",
    "desarrimaríamos": "desarrimar",
    "desarrimaríeis": "desarrimar",
    "desarrimas": "desarrimar",
    "desarrimasse": "desarrimar",
    "desarrimassem": "desarrimar",
    "desarrimasses": "desarrimar",
    "desarrimaste": "desarrimar",
    "desarrimastes": "desarrimar",
    "desarrimava": "desarrimar",
    "desarrimavam": "desarrimar",
    "desarrimavas": "desarrimar",
    "desarrime": "desarrimar",
    "desarrimei": "desarrimar",
    "desarrimeis": "desarrimar",
    "desarrimem": "desarrimar",
    "desarrimemo": "desarrimar",
    "desarrimemos": "desarrimar",
    "desarrimes": "desarrimar",
    "desarrimo": "desarrimar",
    "desarrimos": "desarrimo",
    "desarrimou": "desarrimar",
    "desarrimá": "desarrimar",
    "desarrimámo": "desarrimar",
    "desarrimámos": "desarrimar",
    "desarrimáramo": "desarrimar",
    "desarrimáramos": "desarrimar",
    "desarrimárei": "desarrimar",
    "desarrimáreis": "desarrimar",
    "desarrimásseis": "desarrimar",
    "desarrimássemos": "desarrimar",
    "desarrimávamo": "desarrimar",
    "desarrimávamos": "desarrimar",
    "desarrimávei": "desarrimar",
    "desarrimáveis": "desarrimar",
    "desarrisca": "desarriscar",
    "desarriscada": "desarriscar",
    "desarriscadas": "desarriscar",
    "desarriscado": "desarriscar",
    "desarriscados": "desarriscar",
    "desarriscai": "desarriscar",
    "desarriscais": "desarriscar",
    "desarriscam": "desarriscar",
    "desarriscamo": "desarriscar",
    "desarriscamos": "desarriscar",
    "desarriscando": "desarriscar",
    "desarriscara": "desarriscar",
    "desarriscaram": "desarriscar",
    "desarriscaras": "desarriscar",
    "desarriscarde": "desarriscar",
    "desarriscardes": "desarriscar",
    "desarriscare": "desarriscar",
    "desarriscarei": "desarriscar",
    "desarriscareis": "desarriscar",
    "desarriscarem": "desarriscar",
    "desarriscaremos": "desarriscar",
    "desarriscares": "desarriscar",
    "desarriscaria": "desarriscar",
    "desarriscariam": "desarriscar",
    "desarriscarias": "desarriscar",
    "desarriscarmo": "desarriscar",
    "desarriscarmos": "desarriscar",
    "desarriscará": "desarriscar",
    "desarriscarás": "desarriscar",
    "desarriscarão": "desarriscar",
    "desarriscaríamos": "desarriscar",
    "desarriscaríeis": "desarriscar",
    "desarriscas": "desarriscar",
    "desarriscasse": "desarriscar",
    "desarriscassem": "desarriscar",
    "desarriscasses": "desarriscar",
    "desarriscaste": "desarriscar",
    "desarriscastes": "desarriscar",
    "desarriscava": "desarriscar",
    "desarriscavam": "desarriscar",
    "desarriscavas": "desarriscar",
    "desarrisco": "desarriscar",
    "desarriscou": "desarriscar",
    "desarriscá": "desarriscar",
    "desarriscámo": "desarriscar",
    "desarriscámos": "desarriscar",
    "desarriscáramo": "desarriscar",
    "desarriscáramos": "desarriscar",
    "desarriscárei": "desarriscar",
    "desarriscáreis": "desarriscar",
    "desarriscásseis": "desarriscar",
    "desarriscássemos": "desarriscar",
    "desarriscávamo": "desarriscar",
    "desarriscávamos": "desarriscar",
    "desarriscávei": "desarriscar",
    "desarriscáveis": "desarriscar",
    "desarrisque": "desarriscar",
    "desarrisquei": "desarriscar",
    "desarrisqueis": "desarriscar",
    "desarrisquem": "desarriscar",
    "desarrisquemo": "desarriscar",
    "desarrisquemos": "desarriscar",
    "desarrisques": "desarriscar",
    "desarrocha": "desarrochar",
    "desarrochada": "desarrochar",
    "desarrochadas": "desarrochar",
    "desarrochado": "desarrochar",
    "desarrochados": "desarrochar",
    "desarrochai": "desarrochar",
    "desarrochais": "desarrochar",
    "desarrocham": "desarrochar",
    "desarrochamo": "desarrochar",
    "desarrochamos": "desarrochar",
    "desarrochando": "desarrochar",
    "desarrochara": "desarrochar",
    "desarrocharam": "desarrochar",
    "desarrocharas": "desarrochar",
    "desarrocharde": "desarrochar",
    "desarrochardes": "desarrochar",
    "desarrochare": "desarrochar",
    "desarrocharei": "desarrochar",
    "desarrochareis": "desarrochar",
    "desarrocharem": "desarrochar",
    "desarrocharemos": "desarrochar",
    "desarrochares": "desarrochar",
    "desarrocharia": "desarrochar",
    "desarrochariam": "desarrochar",
    "desarrocharias": "desarrochar",
    "desarrocharmo": "desarrochar",
    "desarrocharmos": "desarrochar",
    "desarrochará": "desarrochar",
    "desarrocharás": "desarrochar",
    "desarrocharão": "desarrochar",
    "desarrocharíamos": "desarrochar",
    "desarrocharíeis": "desarrochar",
    "desarrochas": "desarrochar",
    "desarrochasse": "desarrochar",
    "desarrochassem": "desarrochar",
    "desarrochasses": "desarrochar",
    "desarrochaste": "desarrochar",
    "desarrochastes": "desarrochar",
    "desarrochava": "desarrochar",
    "desarrochavam": "desarrochar",
    "desarrochavas": "desarrochar",
    "desarroche": "desarrochar",
    "desarrochei": "desarrochar",
    "desarrocheis": "desarrochar",
    "desarrochem": "desarrochar",
    "desarrochemo": "desarrochar",
    "desarrochemos": "desarrochar",
    "desarroches": "desarrochar",
    "desarrocho": "desarrochar",
    "desarrochou": "desarrochar",
    "desarrochá": "desarrochar",
    "desarrochámo": "desarrochar",
    "desarrochámos": "desarrochar",
    "desarrocháramo": "desarrochar",
    "desarrocháramos": "desarrochar",
    "desarrochárei": "desarrochar",
    "desarrocháreis": "desarrochar",
    "desarrochásseis": "desarrochar",
    "desarrochássemos": "desarrochar",
    "desarrochávamo": "desarrochar",
    "desarrochávamos": "desarrochar",
    "desarrochávei": "desarrochar",
    "desarrocháveis": "desarrochar",
    "desarrolha": "desarrolhar",
    "desarrolhada": "desarrolhar",
    "desarrolhadas": "desarrolhar",
    "desarrolhado": "desarrolhar",
    "desarrolhados": "desarrolhar",
    "desarrolhai": "desarrolhar",
    "desarrolhais": "desarrolhar",
    "desarrolham": "desarrolhar",
    "desarrolhamentos": "desarrolhamento",
    "desarrolhamo": "desarrolhar",
    "desarrolhamos": "desarrolhar",
    "desarrolhando": "desarrolhar",
    "desarrolhara": "desarrolhar",
    "desarrolharam": "desarrolhar",
    "desarrolharas": "desarrolhar",
    "desarrolharde": "desarrolhar",
    "desarrolhardes": "desarrolhar",
    "desarrolhare": "desarrolhar",
    "desarrolharei": "desarrolhar",
    "desarrolhareis": "desarrolhar",
    "desarrolharem": "desarrolhar",
    "desarrolharemos": "desarrolhar",
    "desarrolhares": "desarrolhar",
    "desarrolharia": "desarrolhar",
    "desarrolhariam": "desarrolhar",
    "desarrolharias": "desarrolhar",
    "desarrolharmo": "desarrolhar",
    "desarrolharmos": "desarrolhar",
    "desarrolhará": "desarrolhar",
    "desarrolharás": "desarrolhar",
    "desarrolharão": "desarrolhar",
    "desarrolharíamos": "desarrolhar",
    "desarrolharíeis": "desarrolhar",
    "desarrolhas": "desarrolhar",
    "desarrolhasse": "desarrolhar",
    "desarrolhassem": "desarrolhar",
    "desarrolhasses": "desarrolhar",
    "desarrolhaste": "desarrolhar",
    "desarrolhastes": "desarrolhar",
    "desarrolhava": "desarrolhar",
    "desarrolhavam": "desarrolhar",
    "desarrolhavas": "desarrolhar",
    "desarrolhe": "desarrolhar",
    "desarrolhei": "desarrolhar",
    "desarrolheis": "desarrolhar",
    "desarrolhem": "desarrolhar",
    "desarrolhemo": "desarrolhar",
    "desarrolhemos": "desarrolhar",
    "desarrolhes": "desarrolhar",
    "desarrolho": "desarrolhar",
    "desarrolhou": "desarrolhar",
    "desarrolhá": "desarrolhar",
    "desarrolhámo": "desarrolhar",
    "desarrolhámos": "desarrolhar",
    "desarrolháramo": "desarrolhar",
    "desarrolháramos": "desarrolhar",
    "desarrolhárei": "desarrolhar",
    "desarrolháreis": "desarrolhar",
    "desarrolhásseis": "desarrolhar",
    "desarrolhássemos": "desarrolhar",
    "desarrolhávamo": "desarrolhar",
    "desarrolhávamos": "desarrolhar",
    "desarrolhávei": "desarrolhar",
    "desarrolháveis": "desarrolhar",
    "desarrufos": "desarrufo",
    "desarruma": "desarrumar",
    "desarrumada": "desarrumar",
    "desarrumadas": "desarrumar",
    "desarrumado": "desarrumar",
    "desarrumados": "desarrumar",
    "desarrumai": "desarrumar",
    "desarrumais": "desarrumar",
    "desarrumam": "desarrumar",
    "desarrumamo": "desarrumar",
    "desarrumamos": "desarrumar",
    "desarrumando": "desarrumar",
    "desarrumara": "desarrumar",
    "desarrumaram": "desarrumar",
    "desarrumaras": "desarrumar",
    "desarrumarde": "desarrumar",
    "desarrumardes": "desarrumar",
    "desarrumare": "desarrumar",
    "desarrumarei": "desarrumar",
    "desarrumareis": "desarrumar",
    "desarrumarem": "desarrumar",
    "desarrumaremos": "desarrumar",
    "desarrumares": "desarrumar",
    "desarrumaria": "desarrumar",
    "desarrumariam": "desarrumar",
    "desarrumarias": "desarrumar",
    "desarrumarmo": "desarrumar",
    "desarrumarmos": "desarrumar",
    "desarrumará": "desarrumar",
    "desarrumarás": "desarrumar",
    "desarrumarão": "desarrumar",
    "desarrumaríamos": "desarrumar",
    "desarrumaríeis": "desarrumar",
    "desarrumas": "desarrumar",
    "desarrumasse": "desarrumar",
    "desarrumassem": "desarrumar",
    "desarrumasses": "desarrumar",
    "desarrumaste": "desarrumar",
    "desarrumastes": "desarrumar",
    "desarrumava": "desarrumar",
    "desarrumavam": "desarrumar",
    "desarrumavas": "desarrumar",
    "desarrumações": "desarrumação",
    "desarrume": "desarrumar",
    "desarrumei": "desarrumar",
    "desarrumeis": "desarrumar",
    "desarrumem": "desarrumar",
    "desarrumemo": "desarrumar",
    "desarrumemos": "desarrumar",
    "desarrumes": "desarrumar",
    "desarrumo": "desarrumar",
    "desarrumos": "desarrumo",
    "desarrumou": "desarrumar",
    "desarrumá": "desarrumar",
    "desarrumámo": "desarrumar",
    "desarrumámos": "desarrumar",
    "desarrumáramo": "desarrumar",
    "desarrumáramos": "desarrumar",
    "desarrumárei": "desarrumar",
    "desarrumáreis": "desarrumar",
    "desarrumásseis": "desarrumar",
    "desarrumássemos": "desarrumar",
    "desarrumávamo": "desarrumar",
    "desarrumávamos": "desarrumar",
    "desarrumávei": "desarrumar",
    "desarrumáveis": "desarrumável",
    "desarterializações": "desarterialização",
    "desarticula": "desarticular",
    "desarticulada": "desarticular",
    "desarticuladas": "desarticular",
    "desarticulado": "desarticular",
    "desarticulados": "desarticular",
    "desarticulai": "desarticular",
    "desarticulais": "desarticular",
    "desarticulam": "desarticular",
    "desarticulamo": "desarticular",
    "desarticulamos": "desarticular",
    "desarticulando": "desarticular",
    "desarticulara": "desarticular",
    "desarticularam": "desarticular",
    "desarticularas": "desarticular",
    "desarticularde": "desarticular",
    "desarticulardes": "desarticular",
    "desarticulare": "desarticular",
    "desarticularei": "desarticular",
    "desarticulareis": "desarticular",
    "desarticularem": "desarticular",
    "desarticularemos": "desarticular",
    "desarticulares": "desarticular",
    "desarticularia": "desarticular",
    "desarticulariam": "desarticular",
    "desarticularias": "desarticular",
    "desarticularmo": "desarticular",
    "desarticularmos": "desarticular",
    "desarticulará": "desarticular",
    "desarticularás": "desarticular",
    "desarticularão": "desarticular",
    "desarticularíamos": "desarticular",
    "desarticularíeis": "desarticular",
    "desarticulas": "desarticular",
    "desarticulasse": "desarticular",
    "desarticulassem": "desarticular",
    "desarticulasses": "desarticular",
    "desarticulaste": "desarticular",
    "desarticulastes": "desarticular",
    "desarticulava": "desarticular",
    "desarticulavam": "desarticular",
    "desarticulavas": "desarticular",
    "desarticulações": "desarticulação",
    "desarticule": "desarticular",
    "desarticulei": "desarticular",
    "desarticuleis": "desarticular",
    "desarticulem": "desarticular",
    "desarticulemo": "desarticular",
    "desarticulemos": "desarticular",
    "desarticules": "desarticular",
    "desarticulo": "desarticular",
    "desarticulou": "desarticular",
    "desarticulá": "desarticular",
    "desarticulámo": "desarticular",
    "desarticulámos": "desarticular",
    "desarticuláramo": "desarticular",
    "desarticuláramos": "desarticular",
    "desarticulárei": "desarticular",
    "desarticuláreis": "desarticular",
    "desarticulásseis": "desarticular",
    "desarticulássemos": "desarticular",
    "desarticulávamo": "desarticular",
    "desarticulávamos": "desarticular",
    "desarticulávei": "desarticular",
    "desarticuláveis": "desarticular",
    "desartificiosa": "desartificioso",
    "desartificiosas": "desartificioso",
    "desartificiosos": "desartificioso",
    "desartilha": "desartilhar",
    "desartilhada": "desartilhar",
    "desartilhadas": "desartilhar",
    "desartilhado": "desartilhar",
    "desartilhados": "desartilhar",
    "desartilhai": "desartilhar",
    "desartilhais": "desartilhar",
    "desartilham": "desartilhar",
    "desartilhamo": "desartilhar",
    "desartilhamos": "desartilhar",
    "desartilhando": "desartilhar",
    "desartilhara": "desartilhar",
    "desartilharam": "desartilhar",
    "desartilharas": "desartilhar",
    "desartilharde": "desartilhar",
    "desartilhardes": "desartilhar",
    "desartilhare": "desartilhar",
    "desartilharei": "desartilhar",
    "desartilhareis": "desartilhar",
    "desartilharem": "desartilhar",
    "desartilharemos": "desartilhar",
    "desartilhares": "desartilhar",
    "desartilharia": "desartilhar",
    "desartilhariam": "desartilhar",
    "desartilharias": "desartilhar",
    "desartilharmo": "desartilhar",
    "desartilharmos": "desartilhar",
    "desartilhará": "desartilhar",
    "desartilharás": "desartilhar",
    "desartilharão": "desartilhar",
    "desartilharíamos": "desartilhar",
    "desartilharíeis": "desartilhar",
    "desartilhas": "desartilhar",
    "desartilhasse": "desartilhar",
    "desartilhassem": "desartilhar",
    "desartilhasses": "desartilhar",
    "desartilhaste": "desartilhar",
    "desartilhastes": "desartilhar",
    "desartilhava": "desartilhar",
    "desartilhavam": "desartilhar",
    "desartilhavas": "desartilhar",
    "desartilhe": "desartilhar",
    "desartilhei": "desartilhar",
    "desartilheis": "desartilhar",
    "desartilhem": "desartilhar",
    "desartilhemo": "desartilhar",
    "desartilhemos": "desartilhar",
    "desartilhes": "desartilhar",
    "desartilho": "desartilhar",
    "desartilhou": "desartilhar",
    "desartilhá": "desartilhar",
    "desartilhámo": "desartilhar",
    "desartilhámos": "desartilhar",
    "desartilháramo": "desartilhar",
    "desartilháramos": "desartilhar",
    "desartilhárei": "desartilhar",
    "desartilháreis": "desartilhar",
    "desartilhásseis": "desartilhar",
    "desartilhássemos": "desartilhar",
    "desartilhávamo": "desartilhar",
    "desartilhávamos": "desartilhar",
    "desartilhávei": "desartilhar",
    "desartilháveis": "desartilhar",
    "desarvora": "desarvorar",
    "desarvorada": "desarvorar",
    "desarvoradas": "desarvorar",
    "desarvorado": "desarvorar",
    "desarvorados": "desarvorar",
    "desarvorai": "desarvorar",
    "desarvorais": "desarvorar",
    "desarvoram": "desarvorar",
    "desarvoramentos": "desarvoramento",
    "desarvoramo": "desarvorar",
    "desarvoramos": "desarvorar",
    "desarvorando": "desarvorar",
    "desarvorara": "desarvorar",
    "desarvoraram": "desarvorar",
    "desarvoraras": "desarvorar",
    "desarvorarde": "desarvorar",
    "desarvorardes": "desarvorar",
    "desarvorare": "desarvorar",
    "desarvorarei": "desarvorar",
    "desarvorareis": "desarvorar",
    "desarvorarem": "desarvorar",
    "desarvoraremos": "desarvorar",
    "desarvorares": "desarvorar",
    "desarvoraria": "desarvorar",
    "desarvorariam": "desarvorar",
    "desarvorarias": "desarvorar",
    "desarvorarmo": "desarvorar",
    "desarvorarmos": "desarvorar",
    "desarvorará": "desarvorar",
    "desarvorarás": "desarvorar",
    "desarvorarão": "desarvorar",
    "desarvoraríamos": "desarvorar",
    "desarvoraríeis": "desarvorar",
    "desarvoras": "desarvorar",
    "desarvorasse": "desarvorar",
    "desarvorassem": "desarvorar",
    "desarvorasses": "desarvorar",
    "desarvoraste": "desarvorar",
    "desarvorastes": "desarvorar",
    "desarvorava": "desarvorar",
    "desarvoravam": "desarvorar",
    "desarvoravas": "desarvorar",
    "desarvore": "desarvorar",
    "desarvorei": "desarvorar",
    "desarvoreis": "desarvorar",
    "desarvorem": "desarvorar",
    "desarvoremo": "desarvorar",
    "desarvoremos": "desarvorar",
    "desarvores": "desarvorar",
    "desarvoro": "desarvorar",
    "desarvorou": "desarvorar",
    "desarvorá": "desarvorar",
    "desarvorámo": "desarvorar",
    "desarvorámos": "desarvorar",
    "desarvoráramo": "desarvorar",
    "desarvoráramos": "desarvorar",
    "desarvorárei": "desarvorar",
    "desarvoráreis": "desarvorar",
    "desarvorásseis": "desarvorar",
    "desarvorássemos": "desarvorar",
    "desarvorávamo": "desarvorar",
    "desarvorávamos": "desarvorar",
    "desarvorávei": "desarvorar",
    "desarvoráveis": "desarvorar",
    "desasa": "desasar",
    "desasada": "desasar",
    "desasadas": "desasar",
    "desasado": "desasar",
    "desasados": "desasar",
    "desasadíssima": "desasado",
    "desasadíssimas": "desasado",
    "desasadíssimo": "desasado",
    "desasadíssimos": "desasado",
    "desasai": "desasar",
    "desasais": "desasar",
    "desasam": "desasar",
    "desasamo": "desasar",
    "desasamos": "desasar",
    "desasando": "desasar",
    "desasara": "desasar",
    "desasaram": "desasar",
    "desasaras": "desasar",
    "desasarde": "desasar",
    "desasardes": "desasar",
    "desasare": "desasar",
    "desasarei": "desasar",
    "desasareis": "desasar",
    "desasarem": "desasar",
    "desasaremos": "desasar",
    "desasares": "desasar",
    "desasaria": "desasar",
    "desasariam": "desasar",
    "desasarias": "desasar",
    "desasarmo": "desasar",
    "desasarmos": "desasar",
    "desasará": "desasar",
    "desasarás": "desasar",
    "desasarão": "desasar",
    "desasaríamos": "desasar",
    "desasaríeis": "desasar",
    "desasas": "desasar",
    "desasasse": "desasar",
    "desasassem": "desasar",
    "desasasses": "desasar",
    "desasaste": "desasar",
    "desasastes": "desasar",
    "desasava": "desasar",
    "desasavam": "desasar",
    "desasavas": "desasar",
    "desase": "desasar",
    "desasei": "desasar",
    "desaseis": "desasar",
    "desasem": "desasar",
    "desasemo": "desasar",
    "desasemos": "desasar",
    "desases": "desasar",
    "desasna": "desasnar",
    "desasnada": "desasnar",
    "desasnadas": "desasnar",
    "desasnado": "desasnar",
    "desasnados": "desasnar",
    "desasnai": "desasnar",
    "desasnais": "desasnar",
    "desasnam": "desasnar",
    "desasnamentos": "desasnamento",
    "desasnamo": "desasnar",
    "desasnamos": "desasnar",
    "desasnando": "desasnar",
    "desasnara": "desasnar",
    "desasnaram": "desasnar",
    "desasnaras": "desasnar",
    "desasnarde": "desasnar",
    "desasnardes": "desasnar",
    "desasnare": "desasnar",
    "desasnarei": "desasnar",
    "desasnareis": "desasnar",
    "desasnarem": "desasnar",
    "desasnaremos": "desasnar",
    "desasnares": "desasnar",
    "desasnaria": "desasnar",
    "desasnariam": "desasnar",
    "desasnarias": "desasnar",
    "desasnarmo": "desasnar",
    "desasnarmos": "desasnar",
    "desasnará": "desasnar",
    "desasnarás": "desasnar",
    "desasnarão": "desasnar",
    "desasnaríamos": "desasnar",
    "desasnaríeis": "desasnar",
    "desasnas": "desasnar",
    "desasnasse": "desasnar",
    "desasnassem": "desasnar",
    "desasnasses": "desasnar",
    "desasnaste": "desasnar",
    "desasnastes": "desasnar",
    "desasnava": "desasnar",
    "desasnavam": "desasnar",
    "desasnavas": "desasnar",
    "desasne": "desasnar",
    "desasnei": "desasnar",
    "desasneis": "desasnar",
    "desasnem": "desasnar",
    "desasnemo": "desasnar",
    "desasnemos": "desasnar",
    "desasnes": "desasnar",
    "desasno": "desasnar",
    "desasnou": "desasnar",
    "desasná": "desasnar",
    "desasnámo": "desasnar",
    "desasnámos": "desasnar",
    "desasnáramo": "desasnar",
    "desasnáramos": "desasnar",
    "desasnárei": "desasnar",
    "desasnáreis": "desasnar",
    "desasnásseis": "desasnar",
    "desasnássemos": "desasnar",
    "desasnávamo": "desasnar",
    "desasnávamos": "desasnar",
    "desasnávei": "desasnar",
    "desasnáveis": "desasnar",
    "desaso": "desasar",
    "desasou": "desasar",
    "desassanha": "desassanhar",
    "desassanhada": "desassanhar",
    "desassanhadas": "desassanhar",
    "desassanhado": "desassanhar",
    "desassanhados": "desassanhar",
    "desassanhai": "desassanhar",
    "desassanhais": "desassanhar",
    "desassanham": "desassanhar",
    "desassanhamo": "desassanhar",
    "desassanhamos": "desassanhar",
    "desassanhando": "desassanhar",
    "desassanhara": "desassanhar",
    "desassanharam": "desassanhar",
    "desassanharas": "desassanhar",
    "desassanharde": "desassanhar",
    "desassanhardes": "desassanhar",
    "desassanhare": "desassanhar",
    "desassanharei": "desassanhar",
    "desassanhareis": "desassanhar",
    "desassanharem": "desassanhar",
    "desassanharemos": "desassanhar",
    "desassanhares": "desassanhar",
    "desassanharia": "desassanhar",
    "desassanhariam": "desassanhar",
    "desassanharias": "desassanhar",
    "desassanharmo": "desassanhar",
    "desassanharmos": "desassanhar",
    "desassanhará": "desassanhar",
    "desassanharás": "desassanhar",
    "desassanharão": "desassanhar",
    "desassanharíamos": "desassanhar",
    "desassanharíeis": "desassanhar",
    "desassanhas": "desassanhar",
    "desassanhasse": "desassanhar",
    "desassanhassem": "desassanhar",
    "desassanhasses": "desassanhar",
    "desassanhaste": "desassanhar",
    "desassanhastes": "desassanhar",
    "desassanhava": "desassanhar",
    "desassanhavam": "desassanhar",
    "desassanhavas": "desassanhar",
    "desassanhe": "desassanhar",
    "desassanhei": "desassanhar",
    "desassanheis": "desassanhar",
    "desassanhem": "desassanhar",
    "desassanhemo": "desassanhar",
    "desassanhemos": "desassanhar",
    "desassanhes": "desassanhar",
    "desassanho": "desassanhar",
    "desassanhou": "desassanhar",
    "desassanhá": "desassanhar",
    "desassanhámo": "desassanhar",
    "desassanhámos": "desassanhar",
    "desassanháramo": "desassanhar",
    "desassanháramos": "desassanhar",
    "desassanhárei": "desassanhar",
    "desassanháreis": "desassanhar",
    "desassanhásseis": "desassanhar",
    "desassanhássemos": "desassanhar",
    "desassanhávamo": "desassanhar",
    "desassanhávamos": "desassanhar",
    "desassanhávei": "desassanhar",
    "desassanháveis": "desassanhar",
    "desassazonada": "desassazonado",
    "desassazonadas": "desassazonado",
    "desassazonados": "desassazonado",
    "desasseada": "desassear",
    "desasseadas": "desassear",
    "desasseado": "desassear",
    "desasseados": "desassear",
    "desasseai": "desassear",
    "desasseais": "desassear",
    "desasseamo": "desassear",
    "desasseamos": "desassear",
    "desasseando": "desassear",
    "desasseara": "desassear",
    "desassearam": "desassear",
    "desassearas": "desassear",
    "desassearde": "desassear",
    "desasseardes": "desassear",
    "desasseare": "desassear",
    "desassearei": "desassear",
    "desasseareis": "desassear",
    "desassearem": "desassear",
    "desassearemos": "desassear",
    "desasseares": "desassear",
    "desassearia": "desassear",
    "desasseariam": "desassear",
    "desassearias": "desassear",
    "desassearmo": "desassear",
    "desassearmos": "desassear",
    "desasseará": "desassear",
    "desassearás": "desassear",
    "desassearão": "desassear",
    "desassearíamos": "desassear",
    "desassearíeis": "desassear",
    "desasseasse": "desassear",
    "desasseassem": "desassear",
    "desasseasses": "desassear",
    "desasseaste": "desassear",
    "desasseastes": "desassear",
    "desasseava": "desassear",
    "desasseavam": "desassear",
    "desasseavas": "desassear",
    "desasseei": "desassear",
    "desasseeis": "desassear",
    "desasseemo": "desassear",
    "desasseemos": "desassear",
    "desasseia": "desassear",
    "desasseiam": "desassear",
    "desasseias": "desassear",
    "desasseie": "desassear",
    "desasseiem": "desassear",
    "desasseies": "desassear",
    "desasseio": "desassear",
    "desasseios": "desasseio",
    "desasselvaja": "desasselvajar",
    "desasselvajada": "desasselvajar",
    "desasselvajadas": "desasselvajar",
    "desasselvajado": "desasselvajar",
    "desasselvajados": "desasselvajar",
    "desasselvajai": "desasselvajar",
    "desasselvajais": "desasselvajar",
    "desasselvajam": "desasselvajar",
    "desasselvajamo": "desasselvajar",
    "desasselvajamos": "desasselvajar",
    "desasselvajando": "desasselvajar",
    "desasselvajara": "desasselvajar",
    "desasselvajaram": "desasselvajar",
    "desasselvajaras": "desasselvajar",
    "desasselvajarde": "desasselvajar",
    "desasselvajardes": "desasselvajar",
    "desasselvajare": "desasselvajar",
    "desasselvajarei": "desasselvajar",
    "desasselvajareis": "desasselvajar",
    "desasselvajarem": "desasselvajar",
    "desasselvajaremos": "desasselvajar",
    "desasselvajares": "desasselvajar",
    "desasselvajaria": "desasselvajar",
    "desasselvajariam": "desasselvajar",
    "desasselvajarias": "desasselvajar",
    "desasselvajarmo": "desasselvajar",
    "desasselvajarmos": "desasselvajar",
    "desasselvajará": "desasselvajar",
    "desasselvajarás": "desasselvajar",
    "desasselvajarão": "desasselvajar",
    "desasselvajaríamos": "desasselvajar",
    "desasselvajaríeis": "desasselvajar",
    "desasselvajas": "desasselvajar",
    "desasselvajasse": "desasselvajar",
    "desasselvajassem": "desasselvajar",
    "desasselvajasses": "desasselvajar",
    "desasselvajaste": "desasselvajar",
    "desasselvajastes": "desasselvajar",
    "desasselvajava": "desasselvajar",
    "desasselvajavam": "desasselvajar",
    "desasselvajavas": "desasselvajar",
    "desasselvaje": "desasselvajar",
    "desasselvajei": "desasselvajar",
    "desasselvajeis": "desasselvajar",
    "desasselvajem": "desasselvajar",
    "desasselvajemo": "desasselvajar",
    "desasselvajemos": "desasselvajar",
    "desasselvajes": "desasselvajar",
    "desasselvajo": "desasselvajar",
    "desasselvajou": "desasselvajar",
    "desasselvajá": "desasselvajar",
    "desasselvajámo": "desasselvajar",
    "desasselvajámos": "desasselvajar",
    "desasselvajáramo": "desasselvajar",
    "desasselvajáramos": "desasselvajar",
    "desasselvajárei": "desasselvajar",
    "desasselvajáreis": "desasselvajar",
    "desasselvajásseis": "desasselvajar",
    "desasselvajássemos": "desasselvajar",
    "desasselvajávamo": "desasselvajar",
    "desasselvajávamos": "desasselvajar",
    "desasselvajávei": "desasselvajar",
    "desasselvajáveis": "desasselvajar",
    "desassemelha": "desassemelhar",
    "desassemelhada": "desassemelhar",
    "desassemelhadas": "desassemelhar",
    "desassemelhado": "desassemelhar",
    "desassemelhados": "desassemelhar",
    "desassemelhai": "desassemelhar",
    "desassemelhais": "desassemelhar",
    "desassemelham": "desassemelhar",
    "desassemelhamo": "desassemelhar",
    "desassemelhamos": "desassemelhar",
    "desassemelhando": "desassemelhar",
    "desassemelhara": "desassemelhar",
    "desassemelharam": "desassemelhar",
    "desassemelharas": "desassemelhar",
    "desassemelharde": "desassemelhar",
    "desassemelhardes": "desassemelhar",
    "desassemelhare": "desassemelhar",
    "desassemelharei": "desassemelhar",
    "desassemelhareis": "desassemelhar",
    "desassemelharem": "desassemelhar",
    "desassemelharemos": "desassemelhar",
    "desassemelhares": "desassemelhar",
    "desassemelharia": "desassemelhar",
    "desassemelhariam": "desassemelhar",
    "desassemelharias": "desassemelhar",
    "desassemelharmo": "desassemelhar",
    "desassemelharmos": "desassemelhar",
    "desassemelhará": "desassemelhar",
    "desassemelharás": "desassemelhar",
    "desassemelharão": "desassemelhar",
    "desassemelharíamos": "desassemelhar",
    "desassemelharíeis": "desassemelhar",
    "desassemelhas": "desassemelhar",
    "desassemelhasse": "desassemelhar",
    "desassemelhassem": "desassemelhar",
    "desassemelhasses": "desassemelhar",
    "desassemelhaste": "desassemelhar",
    "desassemelhastes": "desassemelhar",
    "desassemelhava": "desassemelhar",
    "desassemelhavam": "desassemelhar",
    "desassemelhavas": "desassemelhar",
    "desassemelhe": "desassemelhar",
    "desassemelhei": "desassemelhar",
    "desassemelheis": "desassemelhar",
    "desassemelhem": "desassemelhar",
    "desassemelhemo": "desassemelhar",
    "desassemelhemos": "desassemelhar",
    "desassemelhes": "desassemelhar",
    "desassemelho": "desassemelhar",
    "desassemelhou": "desassemelhar",
    "desassemelhá": "desassemelhar",
    "desassemelhámo": "desassemelhar",
    "desassemelhámos": "desassemelhar",
    "desassemelháramo": "desassemelhar",
    "desassemelháramos": "desassemelhar",
    "desassemelhárei": "desassemelhar",
    "desassemelháreis": "desassemelhar",
    "desassemelhásseis": "desassemelhar",
    "desassemelhássemos": "desassemelhar",
    "desassemelhávamo": "desassemelhar",
    "desassemelhávamos": "desassemelhar",
    "desassemelhávei": "desassemelhar",
    "desassemelháveis": "desassemelhar",
    "desassenhoreada": "desassenhorear",
    "desassenhoreadas": "desassenhorear",
    "desassenhoreado": "desassenhorear",
    "desassenhoreados": "desassenhorear",
    "desassenhoreai": "desassenhorear",
    "desassenhoreais": "desassenhorear",
    "desassenhoreamo": "desassenhorear",
    "desassenhoreamos": "desassenhorear",
    "desassenhoreando": "desassenhorear",
    "desassenhoreara": "desassenhorear",
    "desassenhorearam": "desassenhorear",
    "desassenhorearas": "desassenhorear",
    "desassenhorearde": "desassenhorear",
    "desassenhoreardes": "desassenhorear",
    "desassenhoreare": "desassenhorear",
    "desassenhorearei": "desassenhorear",
    "desassenhoreareis": "desassenhorear",
    "desassenhorearem": "desassenhorear",
    "desassenhorearemos": "desassenhorear",
    "desassenhoreares": "desassenhorear",
    "desassenhorearia": "desassenhorear",
    "desassenhoreariam": "desassenhorear",
    "desassenhorearias": "desassenhorear",
    "desassenhorearmo": "desassenhorear",
    "desassenhorearmos": "desassenhorear",
    "desassenhoreará": "desassenhorear",
    "desassenhorearás": "desassenhorear",
    "desassenhorearão": "desassenhorear",
    "desassenhorearíamos": "desassenhorear",
    "desassenhorearíeis": "desassenhorear",
    "desassenhoreasse": "desassenhorear",
    "desassenhoreassem": "desassenhorear",
    "desassenhoreasses": "desassenhorear",
    "desassenhoreaste": "desassenhorear",
    "desassenhoreastes": "desassenhorear",
    "desassenhoreava": "desassenhorear",
    "desassenhoreavam": "desassenhorear",
    "desassenhoreavas": "desassenhorear",
    "desassenhoreei": "desassenhorear",
    "desassenhoreeis": "desassenhorear",
    "desassenhoreemo": "desassenhorear",
    "desassenhoreemos": "desassenhorear",
    "desassenhoreia": "desassenhorear",
    "desassenhoreiam": "desassenhorear",
    "desassenhoreias": "desassenhorear",
    "desassenhoreie": "desassenhorear",
    "desassenhoreiem": "desassenhorear",
    "desassenhoreies": "desassenhorear",
    "desassenhoreio": "desassenhorear",
    "desassenhoreou": "desassenhorear",
    "desassenhoreá": "desassenhorear",
    "desassenhoreámo": "desassenhorear",
    "desassenhoreámos": "desassenhorear",
    "desassenhoreáramo": "desassenhorear",
    "desassenhoreáramos": "desassenhorear",
    "desassenhoreárei": "desassenhorear",
    "desassenhoreáreis": "desassenhorear",
    "desassenhoreásseis": "desassenhorear",
    "desassenhoreássemos": "desassenhorear",
    "desassenhoreávamo": "desassenhorear",
    "desassenhoreávamos": "desassenhorear",
    "desassenhoreávei": "desassenhorear",
    "desassenhoreáveis": "desassenhorear",
    "desassenhoriada": "desassenhoriado",
    "desassenhoriadas": "desassenhoriado",
    "desassenhoriados": "desassenhoriado",
    "desasseou": "desassear",
    "desassesta": "desassestar",
    "desassestada": "desassestar",
    "desassestadas": "desassestar",
    "desassestado": "desassestar",
    "desassestados": "desassestar",
    "desassestai": "desassestar",
    "desassestais": "desassestar",
    "desassestam": "desassestar",
    "desassestamo": "desassestar",
    "desassestamos": "desassestar",
    "desassestando": "desassestar",
    "desassestara": "desassestar",
    "desassestaram": "desassestar",
    "desassestaras": "desassestar",
    "desassestarde": "desassestar",
    "desassestardes": "desassestar",
    "desassestare": "desassestar",
    "desassestarei": "desassestar",
    "desassestareis": "desassestar",
    "desassestarem": "desassestar",
    "desassestaremos": "desassestar",
    "desassestares": "desassestar",
    "desassestaria": "desassestar",
    "desassestariam": "desassestar",
    "desassestarias": "desassestar",
    "desassestarmo": "desassestar",
    "desassestarmos": "desassestar",
    "desassestará": "desassestar",
    "desassestarás": "desassestar",
    "desassestarão": "desassestar",
    "desassestaríamos": "desassestar",
    "desassestaríeis": "desassestar",
    "desassestas": "desassestar",
    "desassestasse": "desassestar",
    "desassestassem": "desassestar",
    "desassestasses": "desassestar",
    "desassestaste": "desassestar",
    "desassestastes": "desassestar",
    "desassestava": "desassestar",
    "desassestavam": "desassestar",
    "desassestavas": "desassestar",
    "desasseste": "desassestar",
    "desassestei": "desassestar",
    "desassesteis": "desassestar",
    "desassestem": "desassestar",
    "desassestemo": "desassestar",
    "desassestemos": "desassestar",
    "desassestes": "desassestar",
    "desassesto": "desassestar",
    "desassestou": "desassestar",
    "desassestá": "desassestar",
    "desassestámo": "desassestar",
    "desassestámos": "desassestar",
    "desassestáramo": "desassestar",
    "desassestáramos": "desassestar",
    "desassestárei": "desassestar",
    "desassestáreis": "desassestar",
    "desassestásseis": "desassestar",
    "desassestássemos": "desassestar",
    "desassestávamo": "desassestar",
    "desassestávamos": "desassestar",
    "desassestávei": "desassestar",
    "desassestáveis": "desassestar",
    "desasseá": "desassear",
    "desasseámo": "desassear",
    "desasseámos": "desassear",
    "desasseáramo": "desassear",
    "desasseáramos": "desassear",
    "desasseárei": "desassear",
    "desasseáreis": "desassear",
    "desasseásseis": "desassear",
    "desasseássemos": "desassear",
    "desasseávamo": "desassear",
    "desasseávamos": "desassear",
    "desasseávei": "desassear",
    "desasseáveis": "desassear",
    "desassimila": "desassimilar",
    "desassimilada": "desassimilar",
    "desassimiladas": "desassimilar",
    "desassimilado": "desassimilar",
    "desassimiladora": "desassimilador",
    "desassimiladoras": "desassimilador",
    "desassimiladores": "desassimilador",
    "desassimilados": "desassimilar",
    "desassimilai": "desassimilar",
    "desassimilais": "desassimilar",
    "desassimilam": "desassimilar",
    "desassimilamo": "desassimilar",
    "desassimilamos": "desassimilar",
    "desassimilando": "desassimilar",
    "desassimilara": "desassimilar",
    "desassimilaram": "desassimilar",
    "desassimilaras": "desassimilar",
    "desassimilarde": "desassimilar",
    "desassimilardes": "desassimilar",
    "desassimilare": "desassimilar",
    "desassimilarei": "desassimilar",
    "desassimilareis": "desassimilar",
    "desassimilarem": "desassimilar",
    "desassimilaremos": "desassimilar",
    "desassimilares": "desassimilar",
    "desassimilaria": "desassimilar",
    "desassimilariam": "desassimilar",
    "desassimilarias": "desassimilar",
    "desassimilarmo": "desassimilar",
    "desassimilarmos": "desassimilar",
    "desassimilará": "desassimilar",
    "desassimilarás": "desassimilar",
    "desassimilarão": "desassimilar",
    "desassimilaríamos": "desassimilar",
    "desassimilaríeis": "desassimilar",
    "desassimilas": "desassimilar",
    "desassimilasse": "desassimilar",
    "desassimilassem": "desassimilar",
    "desassimilasses": "desassimilar",
    "desassimilaste": "desassimilar",
    "desassimilastes": "desassimilar",
    "desassimilava": "desassimilar",
    "desassimilavam": "desassimilar",
    "desassimilavas": "desassimilar",
    "desassimilações": "desassimilação",
    "desassimile": "desassimilar",
    "desassimilei": "desassimilar",
    "desassimileis": "desassimilar",
    "desassimilem": "desassimilar",
    "desassimilemo": "desassimilar",
    "desassimilemos": "desassimilar",
    "desassimiles": "desassimilar",
    "desassimilo": "desassimilar",
    "desassimilou": "desassimilar",
    "desassimilá": "desassimilar",
    "desassimilámo": "desassimilar",
    "desassimilámos": "desassimilar",
    "desassimiláramo": "desassimilar",
    "desassimiláramos": "desassimilar",
    "desassimilárei": "desassimilar",
    "desassimiláreis": "desassimilar",
    "desassimilásseis": "desassimilar",
    "desassimilássemos": "desassimilar",
    "desassimilávamo": "desassimilar",
    "desassimilávamos": "desassimilar",
    "desassimilávei": "desassimilar",
    "desassimiláveis": "desassimilar",
    "desassisa": "desassisar",
    "desassisada": "desassisar",
    "desassisadas": "desassisar",
    "desassisado": "desassisar",
    "desassisados": "desassisar",
    "desassisai": "desassisar",
    "desassisais": "desassisar",
    "desassisam": "desassisar",
    "desassisamo": "desassisar",
    "desassisamos": "desassisar",
    "desassisando": "desassisar",
    "desassisara": "desassisar",
    "desassisaram": "desassisar",
    "desassisaras": "desassisar",
    "desassisarde": "desassisar",
    "desassisardes": "desassisar",
    "desassisare": "desassisar",
    "desassisarei": "desassisar",
    "desassisareis": "desassisar",
    "desassisarem": "desassisar",
    "desassisaremos": "desassisar",
    "desassisares": "desassisar",
    "desassisaria": "desassisar",
    "desassisariam": "desassisar",
    "desassisarias": "desassisar",
    "desassisarmo": "desassisar",
    "desassisarmos": "desassisar",
    "desassisará": "desassisar",
    "desassisarás": "desassisar",
    "desassisarão": "desassisar",
    "desassisaríamos": "desassisar",
    "desassisaríeis": "desassisar",
    "desassisas": "desassisar",
    "desassisasse": "desassisar",
    "desassisassem": "desassisar",
    "desassisasses": "desassisar",
    "desassisaste": "desassisar",
    "desassisastes": "desassisar",
    "desassisava": "desassisar",
    "desassisavam": "desassisar",
    "desassisavas": "desassisar",
    "desassise": "desassisar",
    "desassisei": "desassisar",
    "desassiseis": "desassisar",
    "desassisem": "desassisar",
    "desassisemo": "desassisar",
    "desassisemos": "desassisar",
    "desassises": "desassisar",
    "desassiso": "desassisar",
    "desassisos": "desassiso",
    "desassisou": "desassisar",
    "desassista": "desassistir",
    "desassistais": "desassistir",
    "desassistam": "desassistir",
    "desassistamo": "desassistir",
    "desassistamos": "desassistir",
    "desassistas": "desassistir",
    "desassiste": "desassistir",
    "desassistem": "desassistir",
    "desassistes": "desassistir",
    "desassisti": "desassistir",
    "desassistia": "desassistir",
    "desassistiam": "desassistir",
    "desassistias": "desassistir",
    "desassistida": "desassistir",
    "desassistidas": "desassistir",
    "desassistido": "desassistir",
    "desassistidos": "desassistir",
    "desassistimo": "desassistir",
    "desassistimos": "desassistir",
    "desassistindo": "desassistir",
    "desassistira": "desassistir",
    "desassistiram": "desassistir",
    "desassistiras": "desassistir",
    "desassistirde": "desassistir",
    "desassistirdes": "desassistir",
    "desassistire": "desassistir",
    "desassistirei": "desassistir",
    "desassistireis": "desassistir",
    "desassistirem": "desassistir",
    "desassistiremos": "desassistir",
    "desassistires": "desassistir",
    "desassistiria": "desassistir",
    "desassistiriam": "desassistir",
    "desassistirias": "desassistir",
    "desassistirmo": "desassistir",
    "desassistirmos": "desassistir",
    "desassistirá": "desassistir",
    "desassistirás": "desassistir",
    "desassistirão": "desassistir",
    "desassistiríamos": "desassistir",
    "desassistiríeis": "desassistir",
    "desassistis": "desassistir",
    "desassistisse": "desassistir",
    "desassistissem": "desassistir",
    "desassistisses": "desassistir",
    "desassististe": "desassistir",
    "desassististes": "desassistir",
    "desassistiu": "desassistir",
    "desassisto": "desassistir",
    "desassistências": "desassistência",
    "desassistíamo": "desassistir",
    "desassistíamos": "desassistir",
    "desassistíei": "desassistir",
    "desassistíeis": "desassistir",
    "desassistíramo": "desassistir",
    "desassistíramos": "desassistir",
    "desassistírei": "desassistir",
    "desassistíreis": "desassistir",
    "desassistísseis": "desassistir",
    "desassistíssemos": "desassistir",
    "desassisá": "desassisar",
    "desassisámo": "desassisar",
    "desassisámos": "desassisar",
    "desassisáramo": "desassisar",
    "desassisáramos": "desassisar",
    "desassisárei": "desassisar",
    "desassisáreis": "desassisar",
    "desassisásseis": "desassisar",
    "desassisássemos": "desassisar",
    "desassisávamo": "desassisar",
    "desassisávamos": "desassisar",
    "desassisávei": "desassisar",
    "desassisáveis": "desassisar",
    "desassocia": "desassociar",
    "desassociada": "desassociar",
    "desassociadas": "desassociar",
    "desassociado": "desassociar",
    "desassociados": "desassociar",
    "desassociai": "desassociar",
    "desassociais": "desassociar",
    "desassociam": "desassociar",
    "desassociamo": "desassociar",
    "desassociamos": "desassociar",
    "desassociando": "desassociar",
    "desassociara": "desassociar",
    "desassociaram": "desassociar",
    "desassociaras": "desassociar",
    "desassociarde": "desassociar",
    "desassociardes": "desassociar",
    "desassociare": "desassociar",
    "desassociarei": "desassociar",
    "desassociareis": "desassociar",
    "desassociarem": "desassociar",
    "desassociaremos": "desassociar",
    "desassociares": "desassociar",
    "desassociaria": "desassociar",
    "desassociariam": "desassociar",
    "desassociarias": "desassociar",
    "desassociarmo": "desassociar",
    "desassociarmos": "desassociar",
    "desassociará": "desassociar",
    "desassociarás": "desassociar",
    "desassociarão": "desassociar",
    "desassociaríamos": "desassociar",
    "desassociaríeis": "desassociar",
    "desassocias": "desassociar",
    "desassociasse": "desassociar",
    "desassociassem": "desassociar",
    "desassociasses": "desassociar",
    "desassociaste": "desassociar",
    "desassociastes": "desassociar",
    "desassociava": "desassociar",
    "desassociavam": "desassociar",
    "desassociavas": "desassociar",
    "desassociações": "desassociação",
    "desassocie": "desassociar",
    "desassociei": "desassociar",
    "desassocieis": "desassociar",
    "desassociem": "desassociar",
    "desassociemo": "desassociar",
    "desassociemos": "desassociar",
    "desassocies": "desassociar",
    "desassocio": "desassociar",
    "desassociou": "desassociar",
    "desassociá": "desassociar",
    "desassociámo": "desassociar",
    "desassociámos": "desassociar",
    "desassociáramo": "desassociar",
    "desassociáramos": "desassociar",
    "desassociárei": "desassociar",
    "desassociáreis": "desassociar",
    "desassociásseis": "desassociar",
    "desassociássemos": "desassociar",
    "desassociávamo": "desassociar",
    "desassociávamos": "desassociar",
    "desassociávei": "desassociar",
    "desassociáveis": "desassociar",
    "desassombra": "desassombrar",
    "desassombrada": "desassombrar",
    "desassombradas": "desassombrar",
    "desassombrado": "desassombrar",
    "desassombrados": "desassombrar",
    "desassombrai": "desassombrar",
    "desassombrais": "desassombrar",
    "desassombram": "desassombrar",
    "desassombramentos": "desassombramento",
    "desassombramo": "desassombrar",
    "desassombramos": "desassombrar",
    "desassombrando": "desassombrar",
    "desassombrara": "desassombrar",
    "desassombraram": "desassombrar",
    "desassombraras": "desassombrar",
    "desassombrarde": "desassombrar",
    "desassombrardes": "desassombrar",
    "desassombrare": "desassombrar",
    "desassombrarei": "desassombrar",
    "desassombrareis": "desassombrar",
    "desassombrarem": "desassombrar",
    "desassombraremos": "desassombrar",
    "desassombrares": "desassombrar",
    "desassombraria": "desassombrar",
    "desassombrariam": "desassombrar",
    "desassombrarias": "desassombrar",
    "desassombrarmo": "desassombrar",
    "desassombrarmos": "desassombrar",
    "desassombrará": "desassombrar",
    "desassombrarás": "desassombrar",
    "desassombrarão": "desassombrar",
    "desassombraríamos": "desassombrar",
    "desassombraríeis": "desassombrar",
    "desassombras": "desassombrar",
    "desassombrasse": "desassombrar",
    "desassombrassem": "desassombrar",
    "desassombrasses": "desassombrar",
    "desassombraste": "desassombrar",
    "desassombrastes": "desassombrar",
    "desassombrava": "desassombrar",
    "desassombravam": "desassombrar",
    "desassombravas": "desassombrar",
    "desassombre": "desassombrar",
    "desassombrei": "desassombrar",
    "desassombreis": "desassombrar",
    "desassombrem": "desassombrar",
    "desassombremo": "desassombrar",
    "desassombremos": "desassombrar",
    "desassombres": "desassombrar",
    "desassombro": "desassombrar",
    "desassombros": "desassombro",
    "desassombrou": "desassombrar",
    "desassombrá": "desassombrar",
    "desassombrámo": "desassombrar",
    "desassombrámos": "desassombrar",
    "desassombráramo": "desassombrar",
    "desassombráramos": "desassombrar",
    "desassombrárei": "desassombrar",
    "desassombráreis": "desassombrar",
    "desassombrásseis": "desassombrar",
    "desassombrássemos": "desassombrar",
    "desassombrávamo": "desassombrar",
    "desassombrávamos": "desassombrar",
    "desassombrávei": "desassombrar",
    "desassombráveis": "desassombrar",
    "desassoreada": "desassorear",
    "desassoreadas": "desassorear",
    "desassoreado": "desassorear",
    "desassoreados": "desassorear",
    "desassoreai": "desassorear",
    "desassoreais": "desassorear",
    "desassoreamentos": "desassoreamento",
    "desassoreamo": "desassorear",
    "desassoreamos": "desassorear",
    "desassoreando": "desassorear",
    "desassoreara": "desassorear",
    "desassorearam": "desassorear",
    "desassorearas": "desassorear",
    "desassorearde": "desassorear",
    "desassoreardes": "desassorear",
    "desassoreare": "desassorear",
    "desassorearei": "desassorear",
    "desassoreareis": "desassorear",
    "desassorearem": "desassorear",
    "desassorearemos": "desassorear",
    "desassoreares": "desassorear",
    "desassorearia": "desassorear",
    "desassoreariam": "desassorear",
    "desassorearias": "desassorear",
    "desassorearmo": "desassorear",
    "desassorearmos": "desassorear",
    "desassoreará": "desassorear",
    "desassorearás": "desassorear",
    "desassorearão": "desassorear",
    "desassorearíamos": "desassorear",
    "desassorearíeis": "desassorear",
    "desassoreasse": "desassorear",
    "desassoreassem": "desassorear",
    "desassoreasses": "desassorear",
    "desassoreaste": "desassorear",
    "desassoreastes": "desassorear",
    "desassoreava": "desassorear",
    "desassoreavam": "desassorear",
    "desassoreavas": "desassorear",
    "desassoreei": "desassorear",
    "desassoreeis": "desassorear",
    "desassoreemo": "desassorear",
    "desassoreemos": "desassorear",
    "desassoreia": "desassorear",
    "desassoreiam": "desassorear",
    "desassoreias": "desassorear",
    "desassoreie": "desassorear",
    "desassoreiem": "desassorear",
    "desassoreies": "desassorear",
    "desassoreio": "desassorear",
    "desassoreou": "desassorear",
    "desassoreá": "desassorear",
    "desassoreámo": "desassorear",
    "desassoreámos": "desassorear",
    "desassoreáramo": "desassorear",
    "desassoreáramos": "desassorear",
    "desassoreárei": "desassorear",
    "desassoreáreis": "desassorear",
    "desassoreásseis": "desassorear",
    "desassoreássemos": "desassorear",
    "desassoreávamo": "desassorear",
    "desassoreávamos": "desassorear",
    "desassoreávei": "desassorear",
    "desassoreáveis": "desassorear",
    "desassossega": "desassossegar",
    "desassossegada": "desassossegar",
    "desassossegadas": "desassossegar",
    "desassossegado": "desassossegar",
    "desassossegadora": "desassossegador",
    "desassossegadoras": "desassossegador",
    "desassossegadores": "desassossegador",
    "desassossegados": "desassossegar",
    "desassossegai": "desassossegar",
    "desassossegais": "desassossegar",
    "desassossegam": "desassossegar",
    "desassossegamo": "desassossegar",
    "desassossegamos": "desassossegar",
    "desassossegando": "desassossegar",
    "desassossegara": "desassossegar",
    "desassossegaram": "desassossegar",
    "desassossegaras": "desassossegar",
    "desassossegarde": "desassossegar",
    "desassossegardes": "desassossegar",
    "desassossegare": "desassossegar",
    "desassossegarei": "desassossegar",
    "desassossegareis": "desassossegar",
    "desassossegarem": "desassossegar",
    "desassossegaremos": "desassossegar",
    "desassossegares": "desassossegar",
    "desassossegaria": "desassossegar",
    "desassossegariam": "desassossegar",
    "desassossegarias": "desassossegar",
    "desassossegarmo": "desassossegar",
    "desassossegarmos": "desassossegar",
    "desassossegará": "desassossegar",
    "desassossegarás": "desassossegar",
    "desassossegarão": "desassossegar",
    "desassossegaríamos": "desassossegar",
    "desassossegaríeis": "desassossegar",
    "desassossegas": "desassossegar",
    "desassossegasse": "desassossegar",
    "desassossegassem": "desassossegar",
    "desassossegasses": "desassossegar",
    "desassossegaste": "desassossegar",
    "desassossegastes": "desassossegar",
    "desassossegava": "desassossegar",
    "desassossegavam": "desassossegar",
    "desassossegavas": "desassossegar",
    "desassossego": "desassossegar",
    "desassossegos": "desassossego",
    "desassossegou": "desassossegar",
    "desassossegue": "desassossegar",
    "desassosseguei": "desassossegar",
    "desassossegueis": "desassossegar",
    "desassosseguem": "desassossegar",
    "desassosseguemo": "desassossegar",
    "desassosseguemos": "desassossegar",
    "desassossegues": "desassossegar",
    "desassossegá": "desassossegar",
    "desassossegámo": "desassossegar",
    "desassossegámos": "desassossegar",
    "desassossegáramo": "desassossegar",
    "desassossegáramos": "desassossegar",
    "desassossegárei": "desassossegar",
    "desassossegáreis": "desassossegar",
    "desassossegásseis": "desassossegar",
    "desassossegássemos": "desassossegar",
    "desassossegávamo": "desassossegar",
    "desassossegávamos": "desassossegar",
    "desassossegávei": "desassossegar",
    "desassossegáveis": "desassossegar",
    "desassusta": "desassustar",
    "desassustada": "desassustar",
    "desassustadas": "desassustar",
    "desassustado": "desassustar",
    "desassustados": "desassustar",
    "desassustai": "desassustar",
    "desassustais": "desassustar",
    "desassustam": "desassustar",
    "desassustamo": "desassustar",
    "desassustamos": "desassustar",
    "desassustando": "desassustar",
    "desassustara": "desassustar",
    "desassustaram": "desassustar",
    "desassustaras": "desassustar",
    "desassustarde": "desassustar",
    "desassustardes": "desassustar",
    "desassustare": "desassustar",
    "desassustarei": "desassustar",
    "desassustareis": "desassustar",
    "desassustarem": "desassustar",
    "desassustaremos": "desassustar",
    "desassustares": "desassustar",
    "desassustaria": "desassustar",
    "desassustariam": "desassustar",
    "desassustarias": "desassustar",
    "desassustarmo": "desassustar",
    "desassustarmos": "desassustar",
    "desassustará": "desassustar",
    "desassustarás": "desassustar",
    "desassustarão": "desassustar",
    "desassustaríamos": "desassustar",
    "desassustaríeis": "desassustar",
    "desassustas": "desassustar",
    "desassustasse": "desassustar",
    "desassustassem": "desassustar",
    "desassustasses": "desassustar",
    "desassustaste": "desassustar",
    "desassustastes": "desassustar",
    "desassustava": "desassustar",
    "desassustavam": "desassustar",
    "desassustavas": "desassustar",
    "desassuste": "desassustar",
    "desassustei": "desassustar",
    "desassusteis": "desassustar",
    "desassustem": "desassustar",
    "desassustemo": "desassustar",
    "desassustemos": "desassustar",
    "desassustes": "desassustar",
    "desassusto": "desassustar",
    "desassustou": "desassustar",
    "desassustá": "desassustar",
    "desassustámo": "desassustar",
    "desassustámos": "desassustar",
    "desassustáramo": "desassustar",
    "desassustáramos": "desassustar",
    "desassustárei": "desassustar",
    "desassustáreis": "desassustar",
    "desassustásseis": "desassustar",
    "desassustássemos": "desassustar",
    "desassustávamo": "desassustar",
    "desassustávamos": "desassustar",
    "desassustávei": "desassustar",
    "desassustáveis": "desassustar",
    "desastrada": "desastrado",
    "desastradas": "desastrado",
    "desastrados": "desastrado",
    "desastres": "desastre",
    "desastrosa": "desastroso",
    "desastrosas": "desastroso",
    "desastrosos": "desastroso",
    "desasá": "desasar",
    "desasámo": "desasar",
    "desasámos": "desasar",
    "desasáramo": "desasar",
    "desasáramos": "desasar",
    "desasárei": "desasar",
    "desasáreis": "desasar",
    "desasásseis": "desasar",
    "desasássemos": "desasar",
    "desasávamo": "desasar",
    "desasávamos": "desasar",
    "desasávei": "desasar",
    "desasáveis": "desasar",
    "desata": "desatar",
    "desatabafa": "desatabafar",
    "desatabafada": "desatabafar",
    "desatabafadas": "desatabafar",
    "desatabafado": "desatabafar",
    "desatabafados": "desatabafar",
    "desatabafai": "desatabafar",
    "desatabafais": "desatabafar",
    "desatabafam": "desatabafar",
    "desatabafamo": "desatabafar",
    "desatabafamos": "desatabafar",
    "desatabafando": "desatabafar",
    "desatabafara": "desatabafar",
    "desatabafaram": "desatabafar",
    "desatabafaras": "desatabafar",
    "desatabafarde": "desatabafar",
    "desatabafardes": "desatabafar",
    "desatabafare": "desatabafar",
    "desatabafarei": "desatabafar",
    "desatabafareis": "desatabafar",
    "desatabafarem": "desatabafar",
    "desatabafaremos": "desatabafar",
    "desatabafares": "desatabafar",
    "desatabafaria": "desatabafar",
    "desatabafariam": "desatabafar",
    "desatabafarias": "desatabafar",
    "desatabafarmo": "desatabafar",
    "desatabafarmos": "desatabafar",
    "desatabafará": "desatabafar",
    "desatabafarás": "desatabafar",
    "desatabafarão": "desatabafar",
    "desatabafaríamos": "desatabafar",
    "desatabafaríeis": "desatabafar",
    "desatabafas": "desatabafar",
    "desatabafasse": "desatabafar",
    "desatabafassem": "desatabafar",
    "desatabafasses": "desatabafar",
    "desatabafaste": "desatabafar",
    "desatabafastes": "desatabafar",
    "desatabafava": "desatabafar",
    "desatabafavam": "desatabafar",
    "desatabafavas": "desatabafar",
    "desatabafe": "desatabafar",
    "desatabafei": "desatabafar",
    "desatabafeis": "desatabafar",
    "desatabafem": "desatabafar",
    "desatabafemo": "desatabafar",
    "desatabafemos": "desatabafar",
    "desatabafes": "desatabafar",
    "desatabafo": "desatabafar",
    "desatabafou": "desatabafar",
    "desatabafá": "desatabafar",
    "desatabafámo": "desatabafar",
    "desatabafámos": "desatabafar",
    "desatabafáramo": "desatabafar",
    "desatabafáramos": "desatabafar",
    "desatabafárei": "desatabafar",
    "desatabafáreis": "desatabafar",
    "desatabafásseis": "desatabafar",
    "desatabafássemos": "desatabafar",
    "desatabafávamo": "desatabafar",
    "desatabafávamos": "desatabafar",
    "desatabafávei": "desatabafar",
    "desatabafáveis": "desatabafar",
    "desataca": "desatacar",
    "desatacada": "desatacar",
    "desatacadas": "desatacar",
    "desatacado": "desatacar",
    "desatacados": "desatacar",
    "desatacai": "desatacar",
    "desatacais": "desatacar",
    "desatacam": "desatacar",
    "desatacamo": "desatacar",
    "desatacamos": "desatacar",
    "desatacando": "desatacar",
    "desatacara": "desatacar",
    "desatacaram": "desatacar",
    "desatacaras": "desatacar",
    "desatacarde": "desatacar",
    "desatacardes": "desatacar",
    "desatacare": "desatacar",
    "desatacarei": "desatacar",
    "desatacareis": "desatacar",
    "desatacarem": "desatacar",
    "desatacaremos": "desatacar",
    "desatacares": "desatacar",
    "desatacaria": "desatacar",
    "desatacariam": "desatacar",
    "desatacarias": "desatacar",
    "desatacarmo": "desatacar",
    "desatacarmos": "desatacar",
    "desatacará": "desatacar",
    "desatacarás": "desatacar",
    "desatacarão": "desatacar",
    "desatacaríamos": "desatacar",
    "desatacaríeis": "desatacar",
    "desatacas": "desatacar",
    "desatacasse": "desatacar",
    "desatacassem": "desatacar",
    "desatacasses": "desatacar",
    "desatacaste": "desatacar",
    "desatacastes": "desatacar",
    "desatacava": "desatacar",
    "desatacavam": "desatacar",
    "desatacavas": "desatacar",
    "desataco": "desatacar",
    "desatacou": "desatacar",
    "desatacá": "desatacar",
    "desatacámo": "desatacar",
    "desatacámos": "desatacar",
    "desatacáramo": "desatacar",
    "desatacáramos": "desatacar",
    "desatacárei": "desatacar",
    "desatacáreis": "desatacar",
    "desatacásseis": "desatacar",
    "desatacássemos": "desatacar",
    "desatacávamo": "desatacar",
    "desatacávamos": "desatacar",
    "desatacávei": "desatacar",
    "desatacáveis": "desatacar",
    "desatada": "desatar",
    "desatadas": "desatar",
    "desatado": "desatar",
    "desatadora": "desatador",
    "desatadoras": "desatador",
    "desatadores": "desatador",
    "desatados": "desatar",
    "desataduras": "desatadura",
    "desatafulha": "desatafulhar",
    "desatafulhada": "desatafulhar",
    "desatafulhadas": "desatafulhar",
    "desatafulhado": "desatafulhar",
    "desatafulhados": "desatafulhar",
    "desatafulhai": "desatafulhar",
    "desatafulhais": "desatafulhar",
    "desatafulham": "desatafulhar",
    "desatafulhamo": "desatafulhar",
    "desatafulhamos": "desatafulhar",
    "desatafulhando": "desatafulhar",
    "desatafulhara": "desatafulhar",
    "desatafulharam": "desatafulhar",
    "desatafulharas": "desatafulhar",
    "desatafulharde": "desatafulhar",
    "desatafulhardes": "desatafulhar",
    "desatafulhare": "desatafulhar",
    "desatafulharei": "desatafulhar",
    "desatafulhareis": "desatafulhar",
    "desatafulharem": "desatafulhar",
    "desatafulharemos": "desatafulhar",
    "desatafulhares": "desatafulhar",
    "desatafulharia": "desatafulhar",
    "desatafulhariam": "desatafulhar",
    "desatafulharias": "desatafulhar",
    "desatafulharmo": "desatafulhar",
    "desatafulharmos": "desatafulhar",
    "desatafulhará": "desatafulhar",
    "desatafulharás": "desatafulhar",
    "desatafulharão": "desatafulhar",
    "desatafulharíamos": "desatafulhar",
    "desatafulharíeis": "desatafulhar",
    "desatafulhas": "desatafulhar",
    "desatafulhasse": "desatafulhar",
    "desatafulhassem": "desatafulhar",
    "desatafulhasses": "desatafulhar",
    "desatafulhaste": "desatafulhar",
    "desatafulhastes": "desatafulhar",
    "desatafulhava": "desatafulhar",
    "desatafulhavam": "desatafulhar",
    "desatafulhavas": "desatafulhar",
    "desatafulhe": "desatafulhar",
    "desatafulhei": "desatafulhar",
    "desatafulheis": "desatafulhar",
    "desatafulhem": "desatafulhar",
    "desatafulhemo": "desatafulhar",
    "desatafulhemos": "desatafulhar",
    "desatafulhes": "desatafulhar",
    "desatafulho": "desatafulhar",
    "desatafulhou": "desatafulhar",
    "desatafulhá": "desatafulhar",
    "desatafulhámo": "desatafulhar",
    "desatafulhámos": "desatafulhar",
    "desatafulháramo": "desatafulhar",
    "desatafulháramos": "desatafulhar",
    "desatafulhárei": "desatafulhar",
    "desatafulháreis": "desatafulhar",
    "desatafulhásseis": "desatafulhar",
    "desatafulhássemos": "desatafulhar",
    "desatafulhávamo": "desatafulhar",
    "desatafulhávamos": "desatafulhar",
    "desatafulhávei": "desatafulhar",
    "desatafulháveis": "desatafulhar",
    "desatai": "desatar",
    "desatais": "desatar",
    "desatam": "desatar",
    "desatamentos": "desatamento",
    "desatamo": "desatar",
    "desatamos": "desatar",
    "desatando": "desatar",
    "desatapeta": "desatapetar",
    "desatapetada": "desatapetar",
    "desatapetadas": "desatapetar",
    "desatapetado": "desatapetar",
    "desatapetados": "desatapetar",
    "desatapetai": "desatapetar",
    "desatapetais": "desatapetar",
    "desatapetam": "desatapetar",
    "desatapetamo": "desatapetar",
    "desatapetamos": "desatapetar",
    "desatapetando": "desatapetar",
    "desatapetara": "desatapetar",
    "desatapetaram": "desatapetar",
    "desatapetaras": "desatapetar",
    "desatapetarde": "desatapetar",
    "desatapetardes": "desatapetar",
    "desatapetare": "desatapetar",
    "desatapetarei": "desatapetar",
    "desatapetareis": "desatapetar",
    "desatapetarem": "desatapetar",
    "desatapetaremos": "desatapetar",
    "desatapetares": "desatapetar",
    "desatapetaria": "desatapetar",
    "desatapetariam": "desatapetar",
    "desatapetarias": "desatapetar",
    "desatapetarmo": "desatapetar",
    "desatapetarmos": "desatapetar",
    "desatapetará": "desatapetar",
    "desatapetarás": "desatapetar",
    "desatapetarão": "desatapetar",
    "desatapetaríamos": "desatapetar",
    "desatapetaríeis": "desatapetar",
    "desatapetas": "desatapetar",
    "desatapetasse": "desatapetar",
    "desatapetassem": "desatapetar",
    "desatapetasses": "desatapetar",
    "desatapetaste": "desatapetar",
    "desatapetastes": "desatapetar",
    "desatapetava": "desatapetar",
    "desatapetavam": "desatapetar",
    "desatapetavas": "desatapetar",
    "desatapete": "desatapetar",
    "desatapetei": "desatapetar",
    "desatapeteis": "desatapetar",
    "desatapetem": "desatapetar",
    "desatapetemo": "desatapetar",
    "desatapetemos": "desatapetar",
    "desatapetes": "desatapetar",
    "desatapeto": "desatapetar",
    "desatapetou": "desatapetar",
    "desatapetá": "desatapetar",
    "desatapetámo": "desatapetar",
    "desatapetámos": "desatapetar",
    "desatapetáramo": "desatapetar",
    "desatapetáramos": "desatapetar",
    "desatapetárei": "desatapetar",
    "desatapetáreis": "desatapetar",
    "desatapetásseis": "desatapetar",
    "desatapetássemos": "desatapetar",
    "desatapetávamo": "desatapetar",
    "desatapetávamos": "desatapetar",
    "desatapetávei": "desatapetar",
    "desatapetáveis": "desatapetar",
    "desatapulha": "desatapulhar",
    "desatapulhada": "desatapulhar",
    "desatapulhadas": "desatapulhar",
    "desatapulhado": "desatapulhar",
    "desatapulhados": "desatapulhar",
    "desatapulhai": "desatapulhar",
    "desatapulhais": "desatapulhar",
    "desatapulham": "desatapulhar",
    "desatapulhamo": "desatapulhar",
    "desatapulhamos": "desatapulhar",
    "desatapulhando": "desatapulhar",
    "desatapulhara": "desatapulhar",
    "desatapulharam": "desatapulhar",
    "desatapulharas": "desatapulhar",
    "desatapulharde": "desatapulhar",
    "desatapulhardes": "desatapulhar",
    "desatapulhare": "desatapulhar",
    "desatapulharei": "desatapulhar",
    "desatapulhareis": "desatapulhar",
    "desatapulharem": "desatapulhar",
    "desatapulharemos": "desatapulhar",
    "desatapulhares": "desatapulhar",
    "desatapulharia": "desatapulhar",
    "desatapulhariam": "desatapulhar",
    "desatapulharias": "desatapulhar",
    "desatapulharmo": "desatapulhar",
    "desatapulharmos": "desatapulhar",
    "desatapulhará": "desatapulhar",
    "desatapulharás": "desatapulhar",
    "desatapulharão": "desatapulhar",
    "desatapulharíamos": "desatapulhar",
    "desatapulharíeis": "desatapulhar",
    "desatapulhas": "desatapulhar",
    "desatapulhasse": "desatapulhar",
    "desatapulhassem": "desatapulhar",
    "desatapulhasses": "desatapulhar",
    "desatapulhaste": "desatapulhar",
    "desatapulhastes": "desatapulhar",
    "desatapulhava": "desatapulhar",
    "desatapulhavam": "desatapulhar",
    "desatapulhavas": "desatapulhar",
    "desatapulhe": "desatapulhar",
    "desatapulhei": "desatapulhar",
    "desatapulheis": "desatapulhar",
    "desatapulhem": "desatapulhar",
    "desatapulhemo": "desatapulhar",
    "desatapulhemos": "desatapulhar",
    "desatapulhes": "desatapulhar",
    "desatapulho": "desatapulhar",
    "desatapulhou": "desatapulhar",
    "desatapulhá": "desatapulhar",
    "desatapulhámo": "desatapulhar",
    "desatapulhámos": "desatapulhar",
    "desatapulháramo": "desatapulhar",
    "desatapulháramos": "desatapulhar",
    "desatapulhárei": "desatapulhar",
    "desatapulháreis": "desatapulhar",
    "desatapulhásseis": "desatapulhar",
    "desatapulhássemos": "desatapulhar",
    "desatapulhávamo": "desatapulhar",
    "desatapulhávamos": "desatapulhar",
    "desatapulhávei": "desatapulhar",
    "desatapulháveis": "desatapulhar",
    "desataque": "desatacar",
    "desataquei": "desatacar",
    "desataqueis": "desatacar",
    "desataquem": "desatacar",
    "desataquemo": "desatacar",
    "desataquemos": "desatacar",
    "desataques": "desatacar",
    "desatara": "desatar",
    "desataram": "desatar",
    "desataras": "desatar",
    "desatarde": "desatar",
    "desatardes": "desatar",
    "desatare": "desatar",
    "desatarei": "desatar",
    "desatareis": "desatar",
    "desatarem": "desatar",
    "desataremos": "desatar",
    "desatares": "desatar",
    "desataria": "desatar",
    "desatariam": "desatar",
    "desatarias": "desatar",
    "desatarmo": "desatar",
    "desatarmos": "desatar",
    "desatarraxa": "desatarraxar",
    "desatarraxada": "desatarraxar",
    "desatarraxadas": "desatarraxar",
    "desatarraxado": "desatarraxar",
    "desatarraxados": "desatarraxar",
    "desatarraxai": "desatarraxar",
    "desatarraxais": "desatarraxar",
    "desatarraxam": "desatarraxar",
    "desatarraxamo": "desatarraxar",
    "desatarraxamos": "desatarraxar",
    "desatarraxando": "desatarraxar",
    "desatarraxara": "desatarraxar",
    "desatarraxaram": "desatarraxar",
    "desatarraxaras": "desatarraxar",
    "desatarraxarde": "desatarraxar",
    "desatarraxardes": "desatarraxar",
    "desatarraxare": "desatarraxar",
    "desatarraxarei": "desatarraxar",
    "desatarraxareis": "desatarraxar",
    "desatarraxarem": "desatarraxar",
    "desatarraxaremos": "desatarraxar",
    "desatarraxares": "desatarraxar",
    "desatarraxaria": "desatarraxar",
    "desatarraxariam": "desatarraxar",
    "desatarraxarias": "desatarraxar",
    "desatarraxarmo": "desatarraxar",
    "desatarraxarmos": "desatarraxar",
    "desatarraxará": "desatarraxar",
    "desatarraxarás": "desatarraxar",
    "desatarraxarão": "desatarraxar",
    "desatarraxaríamos": "desatarraxar",
    "desatarraxaríeis": "desatarraxar",
    "desatarraxas": "desatarraxar",
    "desatarraxasse": "desatarraxar",
    "desatarraxassem": "desatarraxar",
    "desatarraxasses": "desatarraxar",
    "desatarraxaste": "desatarraxar",
    "desatarraxastes": "desatarraxar",
    "desatarraxava": "desatarraxar",
    "desatarraxavam": "desatarraxar",
    "desatarraxavas": "desatarraxar",
    "desatarraxe": "desatarraxar",
    "desatarraxei": "desatarraxar",
    "desatarraxeis": "desatarraxar",
    "desatarraxem": "desatarraxar",
    "desatarraxemo": "desatarraxar",
    "desatarraxemos": "desatarraxar",
    "desatarraxes": "desatarraxar",
    "desatarraxo": "desatarraxar",
    "desatarraxou": "desatarraxar",
    "desatarraxá": "desatarraxar",
    "desatarraxámo": "desatarraxar",
    "desatarraxámos": "desatarraxar",
    "desatarraxáramo": "desatarraxar",
    "desatarraxáramos": "desatarraxar",
    "desatarraxárei": "desatarraxar",
    "desatarraxáreis": "desatarraxar",
    "desatarraxásseis": "desatarraxar",
    "desatarraxássemos": "desatarraxar",
    "desatarraxávamo": "desatarraxar",
    "desatarraxávamos": "desatarraxar",
    "desatarraxávei": "desatarraxar",
    "desatarraxáveis": "desatarraxar",
    "desatará": "desatar",
    "desatarás": "desatar",
    "desatarão": "desatar",
    "desataríamos": "desatar",
    "desataríeis": "desatar",
    "desatas": "desatar",
    "desatasca": "desatascar",
    "desatascada": "desatascar",
    "desatascadas": "desatascar",
    "desatascado": "desatascar",
    "desatascados": "desatascar",
    "desatascai": "desatascar",
    "desatascais": "desatascar",
    "desatascam": "desatascar",
    "desatascamo": "desatascar",
    "desatascamos": "desatascar",
    "desatascando": "desatascar",
    "desatascara": "desatascar",
    "desatascaram": "desatascar",
    "desatascaras": "desatascar",
    "desatascarde": "desatascar",
    "desatascardes": "desatascar",
    "desatascare": "desatascar",
    "desatascarei": "desatascar",
    "desatascareis": "desatascar",
    "desatascarem": "desatascar",
    "desatascaremos": "desatascar",
    "desatascares": "desatascar",
    "desatascaria": "desatascar",
    "desatascariam": "desatascar",
    "desatascarias": "desatascar",
    "desatascarmo": "desatascar",
    "desatascarmos": "desatascar",
    "desatascará": "desatascar",
    "desatascarás": "desatascar",
    "desatascarão": "desatascar",
    "desatascaríamos": "desatascar",
    "desatascaríeis": "desatascar",
    "desatascas": "desatascar",
    "desatascasse": "desatascar",
    "desatascassem": "desatascar",
    "desatascasses": "desatascar",
    "desatascaste": "desatascar",
    "desatascastes": "desatascar",
    "desatascava": "desatascar",
    "desatascavam": "desatascar",
    "desatascavas": "desatascar",
    "desatasco": "desatascar",
    "desatascou": "desatascar",
    "desatascá": "desatascar",
    "desatascámo": "desatascar",
    "desatascámos": "desatascar",
    "desatascáramo": "desatascar",
    "desatascáramos": "desatascar",
    "desatascárei": "desatascar",
    "desatascáreis": "desatascar",
    "desatascásseis": "desatascar",
    "desatascássemos": "desatascar",
    "desatascávamo": "desatascar",
    "desatascávamos": "desatascar",
    "desatascávei": "desatascar",
    "desatascáveis": "desatascar",
    "desatasque": "desatascar",
    "desatasquei": "desatascar",
    "desatasqueis": "desatascar",
    "desatasquem": "desatascar",
    "desatasquemo": "desatascar",
    "desatasquemos": "desatascar",
    "desatasques": "desatascar",
    "desatasse": "desatar",
    "desatassem": "desatar",
    "desatasses": "desatar",
    "desataste": "desatar",
    "desatastes": "desatar",
    "desatava": "desatar",
    "desatavam": "desatar",
    "desatavas": "desatar",
    "desatavia": "desataviar",
    "desataviada": "desataviar",
    "desataviadas": "desataviar",
    "desataviado": "desataviar",
    "desataviados": "desataviar",
    "desataviai": "desataviar",
    "desataviais": "desataviar",
    "desataviam": "desataviar",
    "desataviamo": "desataviar",
    "desataviamos": "desataviar",
    "desataviando": "desataviar",
    "desataviara": "desataviar",
    "desataviaram": "desataviar",
    "desataviaras": "desataviar",
    "desataviarde": "desataviar",
    "desataviardes": "desataviar",
    "desataviare": "desataviar",
    "desataviarei": "desataviar",
    "desataviareis": "desataviar",
    "desataviarem": "desataviar",
    "desataviaremos": "desataviar",
    "desataviares": "desataviar",
    "desataviaria": "desataviar",
    "desataviariam": "desataviar",
    "desataviarias": "desataviar",
    "desataviarmo": "desataviar",
    "desataviarmos": "desataviar",
    "desataviará": "desataviar",
    "desataviarás": "desataviar",
    "desataviarão": "desataviar",
    "desataviaríamos": "desataviar",
    "desataviaríeis": "desataviar",
    "desatavias": "desataviar",
    "desataviasse": "desataviar",
    "desataviassem": "desataviar",
    "desataviasses": "desataviar",
    "desataviaste": "desataviar",
    "desataviastes": "desataviar",
    "desataviava": "desataviar",
    "desataviavam": "desataviar",
    "desataviavas": "desataviar",
    "desatavie": "desataviar",
    "desataviei": "desataviar",
    "desatavieis": "desataviar",
    "desataviem": "desataviar",
    "desataviemo": "desataviar",
    "desataviemos": "desataviar",
    "desatavies": "desataviar",
    "desatavio": "desataviar",
    "desatavios": "desatavio",
    "desataviou": "desataviar",
    "desataviá": "desataviar",
    "desataviámo": "desataviar",
    "desataviámos": "desataviar",
    "desataviáramo": "desataviar",
    "desataviáramos": "desataviar",
    "desataviárei": "desataviar",
    "desataviáreis": "desataviar",
    "desataviásseis": "desataviar",
    "desataviássemos": "desataviar",
    "desataviávamo": "desataviar",
    "desataviávamos": "desataviar",
    "desataviávei": "desataviar",
    "desataviáveis": "desataviar",
    "desate": "desatar",
    "desatei": "desatar",
    "desateis": "desatar",
    "desatem": "desatar",
    "desatemo": "desatar",
    "desatemoriza": "desatemorizar",
    "desatemorizada": "desatemorizar",
    "desatemorizadas": "desatemorizar",
    "desatemorizado": "desatemorizar",
    "desatemorizados": "desatemorizar",
    "desatemorizai": "desatemorizar",
    "desatemorizais": "desatemorizar",
    "desatemorizam": "desatemorizar",
    "desatemorizamo": "desatemorizar",
    "desatemorizamos": "desatemorizar",
    "desatemorizando": "desatemorizar",
    "desatemorizara": "desatemorizar",
    "desatemorizaram": "desatemorizar",
    "desatemorizaras": "desatemorizar",
    "desatemorizarde": "desatemorizar",
    "desatemorizardes": "desatemorizar",
    "desatemorizare": "desatemorizar",
    "desatemorizarei": "desatemorizar",
    "desatemorizareis": "desatemorizar",
    "desatemorizarem": "desatemorizar",
    "desatemorizaremos": "desatemorizar",
    "desatemorizares": "desatemorizar",
    "desatemorizaria": "desatemorizar",
    "desatemorizariam": "desatemorizar",
    "desatemorizarias": "desatemorizar",
    "desatemorizarmo": "desatemorizar",
    "desatemorizarmos": "desatemorizar",
    "desatemorizará": "desatemorizar",
    "desatemorizarás": "desatemorizar",
    "desatemorizarão": "desatemorizar",
    "desatemorizaríamos": "desatemorizar",
    "desatemorizaríeis": "desatemorizar",
    "desatemorizas": "desatemorizar",
    "desatemorizasse": "desatemorizar",
    "desatemorizassem": "desatemorizar",
    "desatemorizasses": "desatemorizar",
    "desatemorizaste": "desatemorizar",
    "desatemorizastes": "desatemorizar",
    "desatemorizava": "desatemorizar",
    "desatemorizavam": "desatemorizar",
    "desatemorizavas": "desatemorizar",
    "desatemorize": "desatemorizar",
    "desatemorizei": "desatemorizar",
    "desatemorizeis": "desatemorizar",
    "desatemorizem": "desatemorizar",
    "desatemorizemo": "desatemorizar",
    "desatemorizemos": "desatemorizar",
    "desatemorizes": "desatemorizar",
    "desatemorizo": "desatemorizar",
    "desatemorizou": "desatemorizar",
    "desatemorizá": "desatemorizar",
    "desatemorizámo": "desatemorizar",
    "desatemorizámos": "desatemorizar",
    "desatemorizáramo": "desatemorizar",
    "desatemorizáramos": "desatemorizar",
    "desatemorizárei": "desatemorizar",
    "desatemorizáreis": "desatemorizar",
    "desatemorizásseis": "desatemorizar",
    "desatemorizássemos": "desatemorizar",
    "desatemorizávamo": "desatemorizar",
    "desatemorizávamos": "desatemorizar",
    "desatemorizávei": "desatemorizar",
    "desatemorizáveis": "desatemorizar",
    "desatemos": "desatar",
    "desatenciosa": "desatencioso",
    "desatenciosas": "desatencioso",
    "desatenciosos": "desatencioso",
    "desatenda": "desatender",
    "desatendais": "desatender",
    "desatendam": "desatender",
    "desatendamo": "desatender",
    "desatendamos": "desatender",
    "desatendas": "desatender",
    "desatende": "desatender",
    "desatendei": "desatender",
    "desatendeis": "desatender",
    "desatendem": "desatender",
    "desatendemo": "desatender",
    "desatendemos": "desatender",
    "desatendendo": "desatender",
    "desatendera": "desatender",
    "desatenderam": "desatender",
    "desatenderas": "desatender",
    "desatenderde": "desatender",
    "desatenderdes": "desatender",
    "desatendere": "desatender",
    "desatenderei": "desatender",
    "desatendereis": "desatender",
    "desatenderem": "desatender",
    "desatenderemos": "desatender",
    "desatenderes": "desatender",
    "desatenderia": "desatender",
    "desatenderiam": "desatender",
    "desatenderias": "desatender",
    "desatendermo": "desatender",
    "desatendermos": "desatender",
    "desatenderá": "desatender",
    "desatenderás": "desatender",
    "desatenderão": "desatender",
    "desatenderíamos": "desatender",
    "desatenderíeis": "desatender",
    "desatendes": "desatender",
    "desatendesse": "desatender",
    "desatendessem": "desatender",
    "desatendesses": "desatender",
    "desatendeste": "desatender",
    "desatendestes": "desatender",
    "desatendeu": "desatender",
    "desatendi": "desatender",
    "desatendia": "desatender",
    "desatendiam": "desatender",
    "desatendias": "desatender",
    "desatendida": "desatender",
    "desatendidas": "desatender",
    "desatendido": "desatender",
    "desatendidos": "desatender",
    "desatendo": "desatender",
    "desatendê": "desatender",
    "desatendêramo": "desatender",
    "desatendêramos": "desatender",
    "desatendêrei": "desatender",
    "desatendêreis": "desatender",
    "desatendêsseis": "desatender",
    "desatendêssemos": "desatender",
    "desatendíamo": "desatender",
    "desatendíamos": "desatender",
    "desatendíei": "desatender",
    "desatendíeis": "desatender",
    "desatendíveis": "desatendível",
    "desatenta": "desatento",
    "desatentada": "desatentar",
    "desatentadas": "desatentar",
    "desatentado": "desatentar",
    "desatentados": "desatentar",
    "desatentai": "desatentar",
    "desatentais": "desatentar",
    "desatentam": "desatentar",
    "desatentamo": "desatentar",
    "desatentamos": "desatentar",
    "desatentando": "desatentar",
    "desatentara": "desatentar",
    "desatentaram": "desatentar",
    "desatentaras": "desatentar",
    "desatentardes": "desatentar",
    "desatentarei": "desatentar",
    "desatentareis": "desatentar",
    "desatentarem": "desatentar",
    "desatentaremos": "desatentar",
    "desatentares": "desatentar",
    "desatentaria": "desatentar",
    "desatentariam": "desatentar",
    "desatentarias": "desatentar",
    "desatentarmo": "desatentar",
    "desatentarmos": "desatentar",
    "desatentará": "desatentar",
    "desatentarás": "desatentar",
    "desatentarão": "desatentar",
    "desatentaríamos": "desatentar",
    "desatentaríeis": "desatentar",
    "desatentas": "desatento",
    "desatentasse": "desatentar",
    "desatentassem": "desatentar",
    "desatentasses": "desatentar",
    "desatentaste": "desatentar",
    "desatentastes": "desatentar",
    "desatentava": "desatentar",
    "desatentavam": "desatentar",
    "desatentavas": "desatentar",
    "desatente": "desatentar",
    "desatentei": "desatentar",
    "desatenteis": "desatentar",
    "desatentem": "desatentar",
    "desatentemo": "desatentar",
    "desatentemos": "desatentar",
    "desatentes": "desatentar",
    "desatento": "desatentar",
    "desatentos": "desatento",
    "desatentou": "desatentar",
    "desatentámo": "desatentar",
    "desatentámos": "desatentar",
    "desatentáramo": "desatentar",
    "desatentáramos": "desatentar",
    "desatentáreis": "desatentar",
    "desatentásseis": "desatentar",
    "desatentássemos": "desatentar",
    "desatentávamo": "desatentar",
    "desatentávamos": "desatentar",
    "desatentáveis": "desatentar",
    "desatenções": "desatenção",
    "desaterializada": "desaterializado",
    "desaterializadas": "desaterializado",
    "desaterializados": "desaterializado",
    "desaterra": "desaterrar",
    "desaterrada": "desaterrar",
    "desaterradas": "desaterrar",
    "desaterrado": "desaterrar",
    "desaterrados": "desaterrar",
    "desaterrai": "desaterrar",
    "desaterrais": "desaterrar",
    "desaterram": "desaterrar",
    "desaterramentos": "desaterramento",
    "desaterramo": "desaterrar",
    "desaterramos": "desaterrar",
    "desaterrando": "desaterrar",
    "desaterrara": "desaterrar",
    "desaterraram": "desaterrar",
    "desaterraras": "desaterrar",
    "desaterrarde": "desaterrar",
    "desaterrardes": "desaterrar",
    "desaterrare": "desaterrar",
    "desaterrarei": "desaterrar",
    "desaterrareis": "desaterrar",
    "desaterrarem": "desaterrar",
    "desaterraremos": "desaterrar",
    "desaterrares": "desaterrar",
    "desaterraria": "desaterrar",
    "desaterrariam": "desaterrar",
    "desaterrarias": "desaterrar",
    "desaterrarmo": "desaterrar",
    "desaterrarmos": "desaterrar",
    "desaterrará": "desaterrar",
    "desaterrarás": "desaterrar",
    "desaterrarão": "desaterrar",
    "desaterraríamos": "desaterrar",
    "desaterraríeis": "desaterrar",
    "desaterras": "desaterrar",
    "desaterrasse": "desaterrar",
    "desaterrassem": "desaterrar",
    "desaterrasses": "desaterrar",
    "desaterraste": "desaterrar",
    "desaterrastes": "desaterrar",
    "desaterrava": "desaterrar",
    "desaterravam": "desaterrar",
    "desaterravas": "desaterrar",
    "desaterre": "desaterrar",
    "desaterrei": "desaterrar",
    "desaterreis": "desaterrar",
    "desaterrem": "desaterrar",
    "desaterremo": "desaterrar",
    "desaterremos": "desaterrar",
    "desaterres": "desaterrar",
    "desaterro": "desaterrar",
    "desaterros": "desaterro",
    "desaterrou": "desaterrar",
    "desaterrá": "desaterrar",
    "desaterrámo": "desaterrar",
    "desaterrámos": "desaterrar",
    "desaterráramo": "desaterrar",
    "desaterráramos": "desaterrar",
    "desaterrárei": "desaterrar",
    "desaterráreis": "desaterrar",
    "desaterrásseis": "desaterrar",
    "desaterrássemos": "desaterrar",
    "desaterrávamo": "desaterrar",
    "desaterrávamos": "desaterrar",
    "desaterrávei": "desaterrar",
    "desaterráveis": "desaterrar",
    "desates": "desate",
    "desatesta": "desatestar",
    "desatestada": "desatestar",
    "desatestadas": "desatestar",
    "desatestado": "desatestar",
    "desatestados": "desatestar",
    "desatestai": "desatestar",
    "desatestais": "desatestar",
    "desatestam": "desatestar",
    "desatestamo": "desatestar",
    "desatestamos": "desatestar",
    "desatestando": "desatestar",
    "desatestara": "desatestar",
    "desatestaram": "desatestar",
    "desatestaras": "desatestar",
    "desatestarde": "desatestar",
    "desatestardes": "desatestar",
    "desatestare": "desatestar",
    "desatestarei": "desatestar",
    "desatestareis": "desatestar",
    "desatestarem": "desatestar",
    "desatestaremos": "desatestar",
    "desatestares": "desatestar",
    "desatestaria": "desatestar",
    "desatestariam": "desatestar",
    "desatestarias": "desatestar",
    "desatestarmo": "desatestar",
    "desatestarmos": "desatestar",
    "desatestará": "desatestar",
    "desatestarás": "desatestar",
    "desatestarão": "desatestar",
    "desatestaríamos": "desatestar",
    "desatestaríeis": "desatestar",
    "desatestas": "desatestar",
    "desatestasse": "desatestar",
    "desatestassem": "desatestar",
    "desatestasses": "desatestar",
    "desatestaste": "desatestar",
    "desatestastes": "desatestar",
    "desatestava": "desatestar",
    "desatestavam": "desatestar",
    "desatestavas": "desatestar",
    "desateste": "desatestar",
    "desatestei": "desatestar",
    "desatesteis": "desatestar",
    "desatestem": "desatestar",
    "desatestemo": "desatestar",
    "desatestemos": "desatestar",
    "desatestes": "desatestar",
    "desatesto": "desatestar",
    "desatestou": "desatestar",
    "desatestá": "desatestar",
    "desatestámo": "desatestar",
    "desatestámos": "desatestar",
    "desatestáramo": "desatestar",
    "desatestáramos": "desatestar",
    "desatestárei": "desatestar",
    "desatestáreis": "desatestar",
    "desatestásseis": "desatestar",
    "desatestássemos": "desatestar",
    "desatestávamo": "desatestar",
    "desatestávamos": "desatestar",
    "desatestávei": "desatestar",
    "desatestáveis": "desatestar",
    "desatilada": "desatilado",
    "desatiladas": "desatilado",
    "desatilados": "desatilado",
    "desatilha": "desatilhar",
    "desatilhada": "desatilhar",
    "desatilhadas": "desatilhar",
    "desatilhado": "desatilhar",
    "desatilhados": "desatilhar",
    "desatilhai": "desatilhar",
    "desatilhais": "desatilhar",
    "desatilham": "desatilhar",
    "desatilhamo": "desatilhar",
    "desatilhamos": "desatilhar",
    "desatilhando": "desatilhar",
    "desatilhara": "desatilhar",
    "desatilharam": "desatilhar",
    "desatilharas": "desatilhar",
    "desatilharde": "desatilhar",
    "desatilhardes": "desatilhar",
    "desatilhare": "desatilhar",
    "desatilharei": "desatilhar",
    "desatilhareis": "desatilhar",
    "desatilharem": "desatilhar",
    "desatilharemos": "desatilhar",
    "desatilhares": "desatilhar",
    "desatilharia": "desatilhar",
    "desatilhariam": "desatilhar",
    "desatilharias": "desatilhar",
    "desatilharmo": "desatilhar",
    "desatilharmos": "desatilhar",
    "desatilhará": "desatilhar",
    "desatilharás": "desatilhar",
    "desatilharão": "desatilhar",
    "desatilharíamos": "desatilhar",
    "desatilharíeis": "desatilhar",
    "desatilhas": "desatilhar",
    "desatilhasse": "desatilhar",
    "desatilhassem": "desatilhar",
    "desatilhasses": "desatilhar",
    "desatilhaste": "desatilhar",
    "desatilhastes": "desatilhar",
    "desatilhava": "desatilhar",
    "desatilhavam": "desatilhar",
    "desatilhavas": "desatilhar",
    "desatilhe": "desatilhar",
    "desatilhei": "desatilhar",
    "desatilheis": "desatilhar",
    "desatilhem": "desatilhar",
    "desatilhemo": "desatilhar",
    "desatilhemos": "desatilhar",
    "desatilhes": "desatilhar",
    "desatilho": "desatilhar",
    "desatilhou": "desatilhar",
    "desatilhá": "desatilhar",
    "desatilhámo": "desatilhar",
    "desatilhámos": "desatilhar",
    "desatilháramo": "desatilhar",
    "desatilháramos": "desatilhar",
    "desatilhárei": "desatilhar",
    "desatilháreis": "desatilhar",
    "desatilhásseis": "desatilhar",
    "desatilhássemos": "desatilhar",
    "desatilhávamo": "desatilhar",
    "desatilhávamos": "desatilhar",
    "desatilhávei": "desatilhar",
    "desatilháveis": "desatilhar",
    "desatina": "desatinar",
    "desatinada": "desatinar",
    "desatinadas": "desatinar",
    "desatinado": "desatinar",
    "desatinados": "desatinar",
    "desatinai": "desatinar",
    "desatinais": "desatinar",
    "desatinam": "desatinar",
    "desatinamo": "desatinar",
    "desatinamos": "desatinar",
    "desatinando": "desatinar",
    "desatinara": "desatinar",
    "desatinaram": "desatinar",
    "desatinaras": "desatinar",
    "desatinardes": "desatinar",
    "desatinarei": "desatinar",
    "desatinareis": "desatinar",
    "desatinarem": "desatinar",
    "desatinaremos": "desatinar",
    "desatinares": "desatinar",
    "desatinaria": "desatinar",
    "desatinariam": "desatinar",
    "desatinarias": "desatinar",
    "desatinarmo": "desatinar",
    "desatinarmos": "desatinar",
    "desatinará": "desatinar",
    "desatinarás": "desatinar",
    "desatinarão": "desatinar",
    "desatinaríamos": "desatinar",
    "desatinaríeis": "desatinar",
    "desatinas": "desatinar",
    "desatinasse": "desatinar",
    "desatinassem": "desatinar",
    "desatinasses": "desatinar",
    "desatinaste": "desatinar",
    "desatinastes": "desatinar",
    "desatinava": "desatinar",
    "desatinavam": "desatinar",
    "desatinavas": "desatinar",
    "desatinações": "desatinação",
    "desatine": "desatinar",
    "desatinei": "desatinar",
    "desatineis": "desatinar",
    "desatinem": "desatinar",
    "desatinemo": "desatinar",
    "desatinemos": "desatinar",
    "desatines": "desatinar",
    "desatino": "desatinar",
    "desatinos": "desatino",
    "desatinou": "desatinar",
    "desatinámo": "desatinar",
    "desatinámos": "desatinar",
    "desatináramo": "desatinar",
    "desatináramos": "desatinar",
    "desatináreis": "desatinar",
    "desatinásseis": "desatinar",
    "desatinássemos": "desatinar",
    "desatinávamo": "desatinar",
    "desatinávamos": "desatinar",
    "desatináveis": "desatinar",
    "desativacçãos": "desativacção",
    "desato": "desatar",
    "desatola": "desatolar",
    "desatolada": "desatolar",
    "desatoladas": "desatolar",
    "desatolado": "desatolar",
    "desatolados": "desatolar",
    "desatolai": "desatolar",
    "desatolais": "desatolar",
    "desatolam": "desatolar",
    "desatolamo": "desatolar",
    "desatolamos": "desatolar",
    "desatolando": "desatolar",
    "desatolara": "desatolar",
    "desatolaram": "desatolar",
    "desatolaras": "desatolar",
    "desatolarde": "desatolar",
    "desatolardes": "desatolar",
    "desatolare": "desatolar",
    "desatolarei": "desatolar",
    "desatolareis": "desatolar",
    "desatolarem": "desatolar",
    "desatolaremos": "desatolar",
    "desatolares": "desatolar",
    "desatolaria": "desatolar",
    "desatolariam": "desatolar",
    "desatolarias": "desatolar",
    "desatolarmo": "desatolar",
    "desatolarmos": "desatolar",
    "desatolará": "desatolar",
    "desatolarás": "desatolar",
    "desatolarão": "desatolar",
    "desatolaríamos": "desatolar",
    "desatolaríeis": "desatolar",
    "desatolas": "desatolar",
    "desatolasse": "desatolar",
    "desatolassem": "desatolar",
    "desatolasses": "desatolar",
    "desatolaste": "desatolar",
    "desatolastes": "desatolar",
    "desatolava": "desatolar",
    "desatolavam": "desatolar",
    "desatolavas": "desatolar",
    "desatole": "desatolar",
    "desatolei": "desatolar",
    "desatoleis": "desatolar",
    "desatolem": "desatolar",
    "desatolemo": "desatolar",
    "desatolemos": "desatolar",
    "desatoles": "desatolar",
    "desatolo": "desatolar",
    "desatolou": "desatolar",
    "desatolá": "desatolar",
    "desatolámo": "desatolar",
    "desatolámos": "desatolar",
    "desatoláramo": "desatolar",
    "desatoláramos": "desatolar",
    "desatolárei": "desatolar",
    "desatoláreis": "desatolar",
    "desatolásseis": "desatolar",
    "desatolássemos": "desatolar",
    "desatolávamo": "desatolar",
    "desatolávamos": "desatolar",
    "desatolávei": "desatolar",
    "desatoláveis": "desatolar",
    "desatordoa": "desatordoar",
    "desatordoada": "desatordoar",
    "desatordoadas": "desatordoar",
    "desatordoado": "desatordoar",
    "desatordoados": "desatordoar",
    "desatordoai": "desatordoar",
    "desatordoais": "desatordoar",
    "desatordoam": "desatordoar",
    "desatordoamo": "desatordoar",
    "desatordoamos": "desatordoar",
    "desatordoando": "desatordoar",
    "desatordoara": "desatordoar",
    "desatordoaram": "desatordoar",
    "desatordoaras": "desatordoar",
    "desatordoarde": "desatordoar",
    "desatordoardes": "desatordoar",
    "desatordoare": "desatordoar",
    "desatordoarei": "desatordoar",
    "desatordoareis": "desatordoar",
    "desatordoarem": "desatordoar",
    "desatordoaremos": "desatordoar",
    "desatordoares": "desatordoar",
    "desatordoaria": "desatordoar",
    "desatordoariam": "desatordoar",
    "desatordoarias": "desatordoar",
    "desatordoarmo": "desatordoar",
    "desatordoarmos": "desatordoar",
    "desatordoará": "desatordoar",
    "desatordoarás": "desatordoar",
    "desatordoarão": "desatordoar",
    "desatordoaríamos": "desatordoar",
    "desatordoaríeis": "desatordoar",
    "desatordoas": "desatordoar",
    "desatordoasse": "desatordoar",
    "desatordoassem": "desatordoar",
    "desatordoasses": "desatordoar",
    "desatordoaste": "desatordoar",
    "desatordoastes": "desatordoar",
    "desatordoava": "desatordoar",
    "desatordoavam": "desatordoar",
    "desatordoavas": "desatordoar",
    "desatordoe": "desatordoar",
    "desatordoei": "desatordoar",
    "desatordoeis": "desatordoar",
    "desatordoem": "desatordoar",
    "desatordoemo": "desatordoar",
    "desatordoemos": "desatordoar",
    "desatordoes": "desatordoar",
    "desatordoo": "desatordoar",
    "desatordoou": "desatordoar",
    "desatordoá": "desatordoar",
    "desatordoámo": "desatordoar",
    "desatordoámos": "desatordoar",
    "desatordoáramo": "desatordoar",
    "desatordoáramos": "desatordoar",
    "desatordoárei": "desatordoar",
    "desatordoáreis": "desatordoar",
    "desatordoásseis": "desatordoar",
    "desatordoássemos": "desatordoar",
    "desatordoávamo": "desatordoar",
    "desatordoávamos": "desatordoar",
    "desatordoávei": "desatordoar",
    "desatordoáveis": "desatordoar",
    "desatou": "desatar",
    "desatraca": "desatracar",
    "desatracada": "desatracar",
    "desatracadas": "desatracar",
    "desatracado": "desatracar",
    "desatracados": "desatracar",
    "desatracai": "desatracar",
    "desatracais": "desatracar",
    "desatracam": "desatracar",
    "desatracamo": "desatracar",
    "desatracamos": "desatracar",
    "desatracando": "desatracar",
    "desatracara": "desatracar",
    "desatracaram": "desatracar",
    "desatracaras": "desatracar",
    "desatracarde": "desatracar",
    "desatracardes": "desatracar",
    "desatracare": "desatracar",
    "desatracarei": "desatracar",
    "desatracareis": "desatracar",
    "desatracarem": "desatracar",
    "desatracaremos": "desatracar",
    "desatracares": "desatracar",
    "desatracaria": "desatracar",
    "desatracariam": "desatracar",
    "desatracarias": "desatracar",
    "desatracarmo": "desatracar",
    "desatracarmos": "desatracar",
    "desatracará": "desatracar",
    "desatracarás": "desatracar",
    "desatracarão": "desatracar",
    "desatracaríamos": "desatracar",
    "desatracaríeis": "desatracar",
    "desatracas": "desatracar",
    "desatracasse": "desatracar",
    "desatracassem": "desatracar",
    "desatracasses": "desatracar",
    "desatracaste": "desatracar",
    "desatracastes": "desatracar",
    "desatracava": "desatracar",
    "desatracavam": "desatracar",
    "desatracavas": "desatracar",
    "desatracações": "desatracação",
    "desatraco": "desatracar",
    "desatracou": "desatracar",
    "desatracá": "desatracar",
    "desatracámo": "desatracar",
    "desatracámos": "desatracar",
    "desatracáramo": "desatracar",
    "desatracáramos": "desatracar",
    "desatracárei": "desatracar",
    "desatracáreis": "desatracar",
    "desatracásseis": "desatracar",
    "desatracássemos": "desatracar",
    "desatracávamo": "desatracar",
    "desatracávamos": "desatracar",
    "desatracávei": "desatracar",
    "desatracáveis": "desatracar",
    "desatranca": "desatrancar",
    "desatrancada": "desatrancar",
    "desatrancadas": "desatrancar",
    "desatrancado": "desatrancar",
    "desatrancados": "desatrancar",
    "desatrancai": "desatrancar",
    "desatrancais": "desatrancar",
    "desatrancam": "desatrancar",
    "desatrancamo": "desatrancar",
    "desatrancamos": "desatrancar",
    "desatrancando": "desatrancar",
    "desatrancara": "desatrancar",
    "desatrancaram": "desatrancar",
    "desatrancaras": "desatrancar",
    "desatrancarde": "desatrancar",
    "desatrancardes": "desatrancar",
    "desatrancare": "desatrancar",
    "desatrancarei": "desatrancar",
    "desatrancareis": "desatrancar",
    "desatrancarem": "desatrancar",
    "desatrancaremos": "desatrancar",
    "desatrancares": "desatrancar",
    "desatrancaria": "desatrancar",
    "desatrancariam": "desatrancar",
    "desatrancarias": "desatrancar",
    "desatrancarmo": "desatrancar",
    "desatrancarmos": "desatrancar",
    "desatrancará": "desatrancar",
    "desatrancarás": "desatrancar",
    "desatrancarão": "desatrancar",
    "desatrancaríamos": "desatrancar",
    "desatrancaríeis": "desatrancar",
    "desatrancas": "desatrancar",
    "desatrancasse": "desatrancar",
    "desatrancassem": "desatrancar",
    "desatrancasses": "desatrancar",
    "desatrancaste": "desatrancar",
    "desatrancastes": "desatrancar",
    "desatrancava": "desatrancar",
    "desatrancavam": "desatrancar",
    "desatrancavas": "desatrancar",
    "desatranco": "desatrancar",
    "desatrancou": "desatrancar",
    "desatrancá": "desatrancar",
    "desatrancámo": "desatrancar",
    "desatrancámos": "desatrancar",
    "desatrancáramo": "desatrancar",
    "desatrancáramos": "desatrancar",
    "desatrancárei": "desatrancar",
    "desatrancáreis": "desatrancar",
    "desatrancásseis": "desatrancar",
    "desatrancássemos": "desatrancar",
    "desatrancávamo": "desatrancar",
    "desatrancávamos": "desatrancar",
    "desatrancávei": "desatrancar",
    "desatrancáveis": "desatrancar",
    "desatranque": "desatrancar",
    "desatranquei": "desatrancar",
    "desatranqueis": "desatrancar",
    "desatranquem": "desatrancar",
    "desatranquemo": "desatrancar",
    "desatranquemos": "desatrancar",
    "desatranques": "desatrancar",
    "desatraque": "desatracar",
    "desatraquei": "desatracar",
    "desatraqueis": "desatracar",
    "desatraquem": "desatracar",
    "desatraquemo": "desatracar",
    "desatraquemos": "desatracar",
    "desatraques": "desatracar",
    "desatravanca": "desatravancar",
    "desatravancada": "desatravancar",
    "desatravancadas": "desatravancar",
    "desatravancado": "desatravancar",
    "desatravancados": "desatravancar",
    "desatravancai": "desatravancar",
    "desatravancais": "desatravancar",
    "desatravancam": "desatravancar",
    "desatravancamentos": "desatravancamento",
    "desatravancamo": "desatravancar",
    "desatravancamos": "desatravancar",
    "desatravancando": "desatravancar",
    "desatravancara": "desatravancar",
    "desatravancaram": "desatravancar",
    "desatravancaras": "desatravancar",
    "desatravancarde": "desatravancar",
    "desatravancardes": "desatravancar",
    "desatravancare": "desatravancar",
    "desatravancarei": "desatravancar",
    "desatravancareis": "desatravancar",
    "desatravancarem": "desatravancar",
    "desatravancaremos": "desatravancar",
    "desatravancares": "desatravancar",
    "desatravancaria": "desatravancar",
    "desatravancariam": "desatravancar",
    "desatravancarias": "desatravancar",
    "desatravancarmo": "desatravancar",
    "desatravancarmos": "desatravancar",
    "desatravancará": "desatravancar",
    "desatravancarás": "desatravancar",
    "desatravancarão": "desatravancar",
    "desatravancaríamos": "desatravancar",
    "desatravancaríeis": "desatravancar",
    "desatravancas": "desatravancar",
    "desatravancasse": "desatravancar",
    "desatravancassem": "desatravancar",
    "desatravancasses": "desatravancar",
    "desatravancaste": "desatravancar",
    "desatravancastes": "desatravancar",
    "desatravancava": "desatravancar",
    "desatravancavam": "desatravancar",
    "desatravancavas": "desatravancar",
    "desatravanco": "desatravancar",
    "desatravancou": "desatravancar",
    "desatravancá": "desatravancar",
    "desatravancámo": "desatravancar",
    "desatravancámos": "desatravancar",
    "desatravancáramo": "desatravancar",
    "desatravancáramos": "desatravancar",
    "desatravancárei": "desatravancar",
    "desatravancáreis": "desatravancar",
    "desatravancásseis": "desatravancar",
    "desatravancássemos": "desatravancar",
    "desatravancávamo": "desatravancar",
    "desatravancávamos": "desatravancar",
    "desatravancávei": "desatravancar",
    "desatravancáveis": "desatravancar",
    "desatravanque": "desatravancar",
    "desatravanquei": "desatravancar",
    "desatravanqueis": "desatravancar",
    "desatravanquem": "desatravancar",
    "desatravanquemo": "desatravancar",
    "desatravanquemos": "desatravancar",
    "desatravanques": "desatravancar",
    "desatravessa": "desatravessar",
    "desatravessada": "desatravessar",
    "desatravessadas": "desatravessar",
    "desatravessado": "desatravessar",
    "desatravessados": "desatravessar",
    "desatravessai": "desatravessar",
    "desatravessais": "desatravessar",
    "desatravessam": "desatravessar",
    "desatravessamo": "desatravessar",
    "desatravessamos": "desatravessar",
    "desatravessando": "desatravessar",
    "desatravessara": "desatravessar",
    "desatravessaram": "desatravessar",
    "desatravessaras": "desatravessar",
    "desatravessarde": "desatravessar",
    "desatravessardes": "desatravessar",
    "desatravessare": "desatravessar",
    "desatravessarei": "desatravessar",
    "desatravessareis": "desatravessar",
    "desatravessarem": "desatravessar",
    "desatravessaremos": "desatravessar",
    "desatravessares": "desatravessar",
    "desatravessaria": "desatravessar",
    "desatravessariam": "desatravessar",
    "desatravessarias": "desatravessar",
    "desatravessarmo": "desatravessar",
    "desatravessarmos": "desatravessar",
    "desatravessará": "desatravessar",
    "desatravessarás": "desatravessar",
    "desatravessarão": "desatravessar",
    "desatravessaríamos": "desatravessar",
    "desatravessaríeis": "desatravessar",
    "desatravessas": "desatravessar",
    "desatravessasse": "desatravessar",
    "desatravessassem": "desatravessar",
    "desatravessasses": "desatravessar",
    "desatravessaste": "desatravessar",
    "desatravessastes": "desatravessar",
    "desatravessava": "desatravessar",
    "desatravessavam": "desatravessar",
    "desatravessavas": "desatravessar",
    "desatravesse": "desatravessar",
    "desatravessei": "desatravessar",
    "desatravesseis": "desatravessar",
    "desatravessem": "desatravessar",
    "desatravessemo": "desatravessar",
    "desatravessemos": "desatravessar",
    "desatravesses": "desatravessar",
    "desatravesso": "desatravessar",
    "desatravessou": "desatravessar",
    "desatravessá": "desatravessar",
    "desatravessámo": "desatravessar",
    "desatravessámos": "desatravessar",
    "desatravessáramo": "desatravessar",
    "desatravessáramos": "desatravessar",
    "desatravessárei": "desatravessar",
    "desatravessáreis": "desatravessar",
    "desatravessásseis": "desatravessar",
    "desatravessássemos": "desatravessar",
    "desatravessávamo": "desatravessar",
    "desatravessávamos": "desatravessar",
    "desatravessávei": "desatravessar",
    "desatravessáveis": "desatravessar",
    "desatrela": "desatrelar",
    "desatrelada": "desatrelar",
    "desatreladas": "desatrelar",
    "desatrelado": "desatrelar",
    "desatrelados": "desatrelar",
    "desatrelai": "desatrelar",
    "desatrelais": "desatrelar",
    "desatrelam": "desatrelar",
    "desatrelamo": "desatrelar",
    "desatrelamos": "desatrelar",
    "desatrelando": "desatrelar",
    "desatrelara": "desatrelar",
    "desatrelaram": "desatrelar",
    "desatrelaras": "desatrelar",
    "desatrelarde": "desatrelar",
    "desatrelardes": "desatrelar",
    "desatrelare": "desatrelar",
    "desatrelarei": "desatrelar",
    "desatrelareis": "desatrelar",
    "desatrelarem": "desatrelar",
    "desatrelaremos": "desatrelar",
    "desatrelares": "desatrelar",
    "desatrelaria": "desatrelar",
    "desatrelariam": "desatrelar",
    "desatrelarias": "desatrelar",
    "desatrelarmo": "desatrelar",
    "desatrelarmos": "desatrelar",
    "desatrelará": "desatrelar",
    "desatrelarás": "desatrelar",
    "desatrelarão": "desatrelar",
    "desatrelaríamos": "desatrelar",
    "desatrelaríeis": "desatrelar",
    "desatrelas": "desatrelar",
    "desatrelasse": "desatrelar",
    "desatrelassem": "desatrelar",
    "desatrelasses": "desatrelar",
    "desatrelaste": "desatrelar",
    "desatrelastes": "desatrelar",
    "desatrelava": "desatrelar",
    "desatrelavam": "desatrelar",
    "desatrelavas": "desatrelar",
    "desatrele": "desatrelar",
    "desatrelei": "desatrelar",
    "desatreleis": "desatrelar",
    "desatrelem": "desatrelar",
    "desatrelemo": "desatrelar",
    "desatrelemos": "desatrelar",
    "desatreles": "desatrelar",
    "desatrelo": "desatrelar",
    "desatrelou": "desatrelar",
    "desatrelá": "desatrelar",
    "desatrelámo": "desatrelar",
    "desatrelámos": "desatrelar",
    "desatreláramo": "desatrelar",
    "desatreláramos": "desatrelar",
    "desatrelárei": "desatrelar",
    "desatreláreis": "desatrelar",
    "desatrelásseis": "desatrelar",
    "desatrelássemos": "desatrelar",
    "desatrelávamo": "desatrelar",
    "desatrelávamos": "desatrelar",
    "desatrelávei": "desatrelar",
    "desatreláveis": "desatrelável",
    "desatrema": "desatremar",
    "desatremada": "desatremar",
    "desatremadas": "desatremar",
    "desatremado": "desatremar",
    "desatremados": "desatremar",
    "desatremai": "desatremar",
    "desatremais": "desatremar",
    "desatremam": "desatremar",
    "desatremamo": "desatremar",
    "desatremamos": "desatremar",
    "desatremando": "desatremar",
    "desatremara": "desatremar",
    "desatremaram": "desatremar",
    "desatremaras": "desatremar",
    "desatremardes": "desatremar",
    "desatremarei": "desatremar",
    "desatremareis": "desatremar",
    "desatremarem": "desatremar",
    "desatremaremos": "desatremar",
    "desatremares": "desatremar",
    "desatremaria": "desatremar",
    "desatremariam": "desatremar",
    "desatremarias": "desatremar",
    "desatremarmo": "desatremar",
    "desatremarmos": "desatremar",
    "desatremará": "desatremar",
    "desatremarás": "desatremar",
    "desatremarão": "desatremar",
    "desatremaríamos": "desatremar",
    "desatremaríeis": "desatremar",
    "desatremas": "desatremar",
    "desatremasse": "desatremar",
    "desatremassem": "desatremar",
    "desatremasses": "desatremar",
    "desatremaste": "desatremar",
    "desatremastes": "desatremar",
    "desatremava": "desatremar",
    "desatremavam": "desatremar",
    "desatremavas": "desatremar",
    "desatreme": "desatremar",
    "desatremei": "desatremar",
    "desatremeis": "desatremar",
    "desatremem": "desatremar",
    "desatrememo": "desatremar",
    "desatrememos": "desatremar",
    "desatremes": "desatremar",
    "desatremo": "desatremar",
    "desatremou": "desatremar",
    "desatremámo": "desatremar",
    "desatremámos": "desatremar",
    "desatremáramo": "desatremar",
    "desatremáramos": "desatremar",
    "desatremáreis": "desatremar",
    "desatremásseis": "desatremar",
    "desatremássemos": "desatremar",
    "desatremávamo": "desatremar",
    "desatremávamos": "desatremar",
    "desatremáveis": "desatremar",
    "desatribula": "desatribular",
    "desatribulada": "desatribular",
    "desatribuladas": "desatribular",
    "desatribulado": "desatribular",
    "desatribulados": "desatribular",
    "desatribulai": "desatribular",
    "desatribulais": "desatribular",
    "desatribulam": "desatribular",
    "desatribulamo": "desatribular",
    "desatribulamos": "desatribular",
    "desatribulando": "desatribular",
    "desatribulara": "desatribular",
    "desatribularam": "desatribular",
    "desatribularas": "desatribular",
    "desatribularde": "desatribular",
    "desatribulardes": "desatribular",
    "desatribulare": "desatribular",
    "desatribularei": "desatribular",
    "desatribulareis": "desatribular",
    "desatribularem": "desatribular",
    "desatribularemos": "desatribular",
    "desatribulares": "desatribular",
    "desatribularia": "desatribular",
    "desatribulariam": "desatribular",
    "desatribularias": "desatribular",
    "desatribularmo": "desatribular",
    "desatribularmos": "desatribular",
    "desatribulará": "desatribular",
    "desatribularás": "desatribular",
    "desatribularão": "desatribular",
    "desatribularíamos": "desatribular",
    "desatribularíeis": "desatribular",
    "desatribulas": "desatribular",
    "desatribulasse": "desatribular",
    "desatribulassem": "desatribular",
    "desatribulasses": "desatribular",
    "desatribulaste": "desatribular",
    "desatribulastes": "desatribular",
    "desatribulava": "desatribular",
    "desatribulavam": "desatribular",
    "desatribulavas": "desatribular",
    "desatribule": "desatribular",
    "desatribulei": "desatribular",
    "desatribuleis": "desatribular",
    "desatribulem": "desatribular",
    "desatribulemo": "desatribular",
    "desatribulemos": "desatribular",
    "desatribules": "desatribular",
    "desatribulo": "desatribular",
    "desatribulou": "desatribular",
    "desatribulá": "desatribular",
    "desatribulámo": "desatribular",
    "desatribulámos": "desatribular",
    "desatribuláramo": "desatribular",
    "desatribuláramos": "desatribular",
    "desatribulárei": "desatribular",
    "desatribuláreis": "desatribular",
    "desatribulásseis": "desatribular",
    "desatribulássemos": "desatribular",
    "desatribulávamo": "desatribular",
    "desatribulávamos": "desatribular",
    "desatribulávei": "desatribular",
    "desatribuláveis": "desatribular",
    "desaturda": "desaturdir",
    "desaturdais": "desaturdir",
    "desaturdam": "desaturdir",
    "desaturdamo": "desaturdir",
    "desaturdamos": "desaturdir",
    "desaturdas": "desaturdir",
    "desaturde": "desaturdir",
    "desaturdem": "desaturdir",
    "desaturdes": "desaturdir",
    "desaturdi": "desaturdir",
    "desaturdia": "desaturdir",
    "desaturdiam": "desaturdir",
    "desaturdias": "desaturdir",
    "desaturdida": "desaturdir",
    "desaturdidas": "desaturdir",
    "desaturdido": "desaturdir",
    "desaturdidos": "desaturdir",
    "desaturdimo": "desaturdir",
    "desaturdimos": "desaturdir",
    "desaturdindo": "desaturdir",
    "desaturdira": "desaturdir",
    "desaturdiram": "desaturdir",
    "desaturdiras": "desaturdir",
    "desaturdirde": "desaturdir",
    "desaturdirdes": "desaturdir",
    "desaturdire": "desaturdir",
    "desaturdirei": "desaturdir",
    "desaturdireis": "desaturdir",
    "desaturdirem": "desaturdir",
    "desaturdiremos": "desaturdir",
    "desaturdires": "desaturdir",
    "desaturdiria": "desaturdir",
    "desaturdiriam": "desaturdir",
    "desaturdirias": "desaturdir",
    "desaturdirmo": "desaturdir",
    "desaturdirmos": "desaturdir",
    "desaturdirá": "desaturdir",
    "desaturdirás": "desaturdir",
    "desaturdirão": "desaturdir",
    "desaturdiríamos": "desaturdir",
    "desaturdiríeis": "desaturdir",
    "desaturdis": "desaturdir",
    "desaturdisse": "desaturdir",
    "desaturdissem": "desaturdir",
    "desaturdisses": "desaturdir",
    "desaturdiste": "desaturdir",
    "desaturdistes": "desaturdir",
    "desaturdiu": "desaturdir",
    "desaturdo": "desaturdir",
    "desaturdíamo": "desaturdir",
    "desaturdíamos": "desaturdir",
    "desaturdíei": "desaturdir",
    "desaturdíeis": "desaturdir",
    "desaturdíramo": "desaturdir",
    "desaturdíramos": "desaturdir",
    "desaturdírei": "desaturdir",
    "desaturdíreis": "desaturdir",
    "desaturdísseis": "desaturdir",
    "desaturdíssemos": "desaturdir",
    "desatá": "desatar",
    "desatámo": "desatar",
    "desatámos": "desatar",
    "desatáramo": "desatar",
    "desatáramos": "desatar",
    "desatárei": "desatar",
    "desatáreis": "desatar",
    "desatásseis": "desatar",
    "desatássemos": "desatar",
    "desatávamo": "desatar",
    "desatávamos": "desatar",
    "desatávei": "desatar",
    "desatáveis": "desatável",
    "desaugada": "desaugado",
    "desaugadas": "desaugado",
    "desaugados": "desaugado",
    "desaurida": "desaurido",
    "desauridas": "desaurido",
    "desauridos": "desaurido",
    "desaustinada": "desaustinado",
    "desaustinadas": "desaustinado",
    "desaustinados": "desaustinado",
    "desaustinadíssima": "desaustinado",
    "desaustinadíssimas": "desaustinado",
    "desaustinadíssimo": "desaustinado",
    "desaustinadíssimos": "desaustinado",
    "desautora": "desautorar",
    "desautorada": "desautorar",
    "desautoradas": "desautorar",
    "desautorado": "desautorar",
    "desautorados": "desautorar",
    "desautorai": "desautorar",
    "desautorais": "desautorar",
    "desautoram": "desautorar",
    "desautoramo": "desautorar",
    "desautoramos": "desautorar",
    "desautorando": "desautorar",
    "desautorara": "desautorar",
    "desautoraram": "desautorar",
    "desautoraras": "desautorar",
    "desautorarde": "desautorar",
    "desautorardes": "desautorar",
    "desautorare": "desautorar",
    "desautorarei": "desautorar",
    "desautorareis": "desautorar",
    "desautorarem": "desautorar",
    "desautoraremos": "desautorar",
    "desautorares": "desautorar",
    "desautoraria": "desautorar",
    "desautorariam": "desautorar",
    "desautorarias": "desautorar",
    "desautorarmo": "desautorar",
    "desautorarmos": "desautorar",
    "desautorará": "desautorar",
    "desautorarás": "desautorar",
    "desautorarão": "desautorar",
    "desautoraríamos": "desautorar",
    "desautoraríeis": "desautorar",
    "desautoras": "desautorar",
    "desautorasse": "desautorar",
    "desautorassem": "desautorar",
    "desautorasses": "desautorar",
    "desautoraste": "desautorar",
    "desautorastes": "desautorar",
    "desautorava": "desautorar",
    "desautoravam": "desautorar",
    "desautoravas": "desautorar",
    "desautorações": "desautoração",
    "desautore": "desautorar",
    "desautorei": "desautorar",
    "desautoreis": "desautorar",
    "desautorem": "desautorar",
    "desautoremo": "desautorar",
    "desautoremos": "desautorar",
    "desautores": "desautorar",
    "desautoriza": "desautorizar",
    "desautorizada": "desautorizar",
    "desautorizadas": "desautorizar",
    "desautorizado": "desautorizar",
    "desautorizados": "desautorizar",
    "desautorizai": "desautorizar",
    "desautorizais": "desautorizar",
    "desautorizam": "desautorizar",
    "desautorizamo": "desautorizar",
    "desautorizamos": "desautorizar",
    "desautorizando": "desautorizar",
    "desautorizara": "desautorizar",
    "desautorizaram": "desautorizar",
    "desautorizaras": "desautorizar",
    "desautorizarde": "desautorizar",
    "desautorizardes": "desautorizar",
    "desautorizare": "desautorizar",
    "desautorizarei": "desautorizar",
    "desautorizareis": "desautorizar",
    "desautorizarem": "desautorizar",
    "desautorizaremos": "desautorizar",
    "desautorizares": "desautorizar",
    "desautorizaria": "desautorizar",
    "desautorizariam": "desautorizar",
    "desautorizarias": "desautorizar",
    "desautorizarmo": "desautorizar",
    "desautorizarmos": "desautorizar",
    "desautorizará": "desautorizar",
    "desautorizarás": "desautorizar",
    "desautorizarão": "desautorizar",
    "desautorizaríamos": "desautorizar",
    "desautorizaríeis": "desautorizar",
    "desautorizas": "desautorizar",
    "desautorizasse": "desautorizar",
    "desautorizassem": "desautorizar",
    "desautorizasses": "desautorizar",
    "desautorizaste": "desautorizar",
    "desautorizastes": "desautorizar",
    "desautorizava": "desautorizar",
    "desautorizavam": "desautorizar",
    "desautorizavas": "desautorizar",
    "desautorizações": "desautorização",
    "desautorize": "desautorizar",
    "desautorizei": "desautorizar",
    "desautorizeis": "desautorizar",
    "desautorizem": "desautorizar",
    "desautorizemo": "desautorizar",
    "desautorizemos": "desautorizar",
    "desautorizes": "desautorizar",
    "desautorizo": "desautorizar",
    "desautorizou": "desautorizar",
    "desautorizá": "desautorizar",
    "desautorizámo": "desautorizar",
    "desautorizámos": "desautorizar",
    "desautorizáramo": "desautorizar",
    "desautorizáramos": "desautorizar",
    "desautorizárei": "desautorizar",
    "desautorizáreis": "desautorizar",
    "desautorizásseis": "desautorizar",
    "desautorizássemos": "desautorizar",
    "desautorizávamo": "desautorizar",
    "desautorizávamos": "desautorizar",
    "desautorizávei": "desautorizar",
    "desautorizáveis": "desautorizável",
    "desautoro": "desautorar",
    "desautorou": "desautorar",
    "desautorá": "desautorar",
    "desautorámo": "desautorar",
    "desautorámos": "desautorar",
    "desautoráramo": "desautorar",
    "desautoráramos": "desautorar",
    "desautorárei": "desautorar",
    "desautoráreis": "desautorar",
    "desautorásseis": "desautorar",
    "desautorássemos": "desautorar",
    "desautorávamo": "desautorar",
    "desautorávamos": "desautorar",
    "desautorávei": "desautorar",
    "desautoráveis": "desautorar",
    "desauxilia": "desauxiliar",
    "desauxiliada": "desauxiliar",
    "desauxiliadas": "desauxiliar",
    "desauxiliado": "desauxiliar",
    "desauxiliados": "desauxiliar",
    "desauxiliai": "desauxiliar",
    "desauxiliais": "desauxiliar",
    "desauxiliam": "desauxiliar",
    "desauxiliamo": "desauxiliar",
    "desauxiliamos": "desauxiliar",
    "desauxiliando": "desauxiliar",
    "desauxiliara": "desauxiliar",
    "desauxiliaram": "desauxiliar",
    "desauxiliaras": "desauxiliar",
    "desauxiliarde": "desauxiliar",
    "desauxiliardes": "desauxiliar",
    "desauxiliare": "desauxiliar",
    "desauxiliarei": "desauxiliar",
    "desauxiliareis": "desauxiliar",
    "desauxiliarem": "desauxiliar",
    "desauxiliaremos": "desauxiliar",
    "desauxiliares": "desauxiliar",
    "desauxiliaria": "desauxiliar",
    "desauxiliariam": "desauxiliar",
    "desauxiliarias": "desauxiliar",
    "desauxiliarmo": "desauxiliar",
    "desauxiliarmos": "desauxiliar",
    "desauxiliará": "desauxiliar",
    "desauxiliarás": "desauxiliar",
    "desauxiliarão": "desauxiliar",
    "desauxiliaríamos": "desauxiliar",
    "desauxiliaríeis": "desauxiliar",
    "desauxilias": "desauxiliar",
    "desauxiliasse": "desauxiliar",
    "desauxiliassem": "desauxiliar",
    "desauxiliasses": "desauxiliar",
    "desauxiliaste": "desauxiliar",
    "desauxiliastes": "desauxiliar",
    "desauxiliava": "desauxiliar",
    "desauxiliavam": "desauxiliar",
    "desauxiliavas": "desauxiliar",
    "desauxilie": "desauxiliar",
    "desauxiliei": "desauxiliar",
    "desauxilieis": "desauxiliar",
    "desauxiliem": "desauxiliar",
    "desauxiliemo": "desauxiliar",
    "desauxiliemos": "desauxiliar",
    "desauxilies": "desauxiliar",
    "desauxilio": "desauxiliar",
    "desauxiliou": "desauxiliar",
    "desauxiliá": "desauxiliar",
    "desauxiliámo": "desauxiliar",
    "desauxiliámos": "desauxiliar",
    "desauxiliáramo": "desauxiliar",
    "desauxiliáramos": "desauxiliar",
    "desauxiliárei": "desauxiliar",
    "desauxiliáreis": "desauxiliar",
    "desauxiliásseis": "desauxiliar",
    "desauxiliássemos": "desauxiliar",
    "desauxiliávamo": "desauxiliar",
    "desauxiliávamos": "desauxiliar",
    "desauxiliávei": "desauxiliar",
    "desauxiliáveis": "desauxiliar",
    "desauxílios": "desauxílio",
    "desavenças": "desavença",
    "desaverba": "desaverbar",
    "desaverbada": "desaverbar",
    "desaverbadas": "desaverbar",
    "desaverbado": "desaverbar",
    "desaverbados": "desaverbar",
    "desaverbai": "desaverbar",
    "desaverbais": "desaverbar",
    "desaverbam": "desaverbar",
    "desaverbamo": "desaverbar",
    "desaverbamos": "desaverbar",
    "desaverbando": "desaverbar",
    "desaverbara": "desaverbar",
    "desaverbaram": "desaverbar",
    "desaverbaras": "desaverbar",
    "desaverbarde": "desaverbar",
    "desaverbardes": "desaverbar",
    "desaverbare": "desaverbar",
    "desaverbarei": "desaverbar",
    "desaverbareis": "desaverbar",
    "desaverbarem": "desaverbar",
    "desaverbaremos": "desaverbar",
    "desaverbares": "desaverbar",
    "desaverbaria": "desaverbar",
    "desaverbariam": "desaverbar",
    "desaverbarias": "desaverbar",
    "desaverbarmo": "desaverbar",
    "desaverbarmos": "desaverbar",
    "desaverbará": "desaverbar",
    "desaverbarás": "desaverbar",
    "desaverbarão": "desaverbar",
    "desaverbaríamos": "desaverbar",
    "desaverbaríeis": "desaverbar",
    "desaverbas": "desaverbar",
    "desaverbasse": "desaverbar",
    "desaverbassem": "desaverbar",
    "desaverbasses": "desaverbar",
    "desaverbaste": "desaverbar",
    "desaverbastes": "desaverbar",
    "desaverbava": "desaverbar",
    "desaverbavam": "desaverbar",
    "desaverbavas": "desaverbar",
    "desaverbe": "desaverbar",
    "desaverbei": "desaverbar",
    "desaverbeis": "desaverbar",
    "desaverbem": "desaverbar",
    "desaverbemo": "desaverbar",
    "desaverbemos": "desaverbar",
    "desaverbes": "desaverbar",
    "desaverbo": "desaverbar",
    "desaverbou": "desaverbar",
    "desaverbá": "desaverbar",
    "desaverbámo": "desaverbar",
    "desaverbámos": "desaverbar",
    "desaverbáramo": "desaverbar",
    "desaverbáramos": "desaverbar",
    "desaverbárei": "desaverbar",
    "desaverbáreis": "desaverbar",
    "desaverbásseis": "desaverbar",
    "desaverbássemos": "desaverbar",
    "desaverbávamo": "desaverbar",
    "desaverbávamos": "desaverbar",
    "desaverbávei": "desaverbar",
    "desaverbáveis": "desaverbar",
    "desavergonha": "desavergonhar",
    "desavergonhada": "desavergonhar",
    "desavergonhadas": "desavergonhar",
    "desavergonhado": "desavergonhar",
    "desavergonhados": "desavergonhar",
    "desavergonhai": "desavergonhar",
    "desavergonhais": "desavergonhar",
    "desavergonham": "desavergonhar",
    "desavergonhamentos": "desavergonhamento",
    "desavergonhamo": "desavergonhar",
    "desavergonhamos": "desavergonhar",
    "desavergonhando": "desavergonhar",
    "desavergonhara": "desavergonhar",
    "desavergonharam": "desavergonhar",
    "desavergonharas": "desavergonhar",
    "desavergonharde": "desavergonhar",
    "desavergonhardes": "desavergonhar",
    "desavergonhare": "desavergonhar",
    "desavergonharei": "desavergonhar",
    "desavergonhareis": "desavergonhar",
    "desavergonharem": "desavergonhar",
    "desavergonharemos": "desavergonhar",
    "desavergonhares": "desavergonhar",
    "desavergonharia": "desavergonhar",
    "desavergonhariam": "desavergonhar",
    "desavergonharias": "desavergonhar",
    "desavergonharmo": "desavergonhar",
    "desavergonharmos": "desavergonhar",
    "desavergonhará": "desavergonhar",
    "desavergonharás": "desavergonhar",
    "desavergonharão": "desavergonhar",
    "desavergonharíamos": "desavergonhar",
    "desavergonharíeis": "desavergonhar",
    "desavergonhas": "desavergonhar",
    "desavergonhasse": "desavergonhar",
    "desavergonhassem": "desavergonhar",
    "desavergonhasses": "desavergonhar",
    "desavergonhaste": "desavergonhar",
    "desavergonhastes": "desavergonhar",
    "desavergonhava": "desavergonhar",
    "desavergonhavam": "desavergonhar",
    "desavergonhavas": "desavergonhar",
    "desavergonhe": "desavergonhar",
    "desavergonhei": "desavergonhar",
    "desavergonheis": "desavergonhar",
    "desavergonhem": "desavergonhar",
    "desavergonhemo": "desavergonhar",
    "desavergonhemos": "desavergonhar",
    "desavergonhes": "desavergonhar",
    "desavergonho": "desavergonhar",
    "desavergonhou": "desavergonhar",
    "desavergonhá": "desavergonhar",
    "desavergonhámo": "desavergonhar",
    "desavergonhámos": "desavergonhar",
    "desavergonháramo": "desavergonhar",
    "desavergonháramos": "desavergonhar",
    "desavergonhárei": "desavergonhar",
    "desavergonháreis": "desavergonhar",
    "desavergonhásseis": "desavergonhar",
    "desavergonhássemos": "desavergonhar",
    "desavergonhávamo": "desavergonhar",
    "desavergonhávamos": "desavergonhar",
    "desavergonhávei": "desavergonhar",
    "desavergonháveis": "desavergonhar",
    "desaveriguada": "desaveriguado",
    "desaveriguadas": "desaveriguado",
    "desaveriguados": "desaveriguado",
    "desavessa": "desavesso",
    "desavessas": "desavesso",
    "desavessos": "desavesso",
    "desaveza": "desavezar",
    "desavezada": "desavezar",
    "desavezadas": "desavezar",
    "desavezado": "desavezar",
    "desavezados": "desavezar",
    "desavezai": "desavezar",
    "desavezais": "desavezar",
    "desavezam": "desavezar",
    "desavezamo": "desavezar",
    "desavezamos": "desavezar",
    "desavezando": "desavezar",
    "desavezara": "desavezar",
    "desavezaram": "desavezar",
    "desavezaras": "desavezar",
    "desavezarde": "desavezar",
    "desavezardes": "desavezar",
    "desavezare": "desavezar",
    "desavezarei": "desavezar",
    "desavezareis": "desavezar",
    "desavezarem": "desavezar",
    "desavezaremos": "desavezar",
    "desavezares": "desavezar",
    "desavezaria": "desavezar",
    "desavezariam": "desavezar",
    "desavezarias": "desavezar",
    "desavezarmo": "desavezar",
    "desavezarmos": "desavezar",
    "desavezará": "desavezar",
    "desavezarás": "desavezar",
    "desavezarão": "desavezar",
    "desavezaríamos": "desavezar",
    "desavezaríeis": "desavezar",
    "desavezas": "desavezar",
    "desavezasse": "desavezar",
    "desavezassem": "desavezar",
    "desavezasses": "desavezar",
    "desavezaste": "desavezar",
    "desavezastes": "desavezar",
    "desavezava": "desavezar",
    "desavezavam": "desavezar",
    "desavezavas": "desavezar",
    "desaveze": "desavezar",
    "desavezei": "desavezar",
    "desavezeis": "desavezar",
    "desavezem": "desavezar",
    "desavezemo": "desavezar",
    "desavezemos": "desavezar",
    "desavezes": "desavezar",
    "desavezo": "desavezar",
    "desavezos": "desavezo",
    "desavezou": "desavezar",
    "desavezá": "desavezar",
    "desavezámo": "desavezar",
    "desavezámos": "desavezar",
    "desavezáramo": "desavezar",
    "desavezáramos": "desavezar",
    "desavezárei": "desavezar",
    "desavezáreis": "desavezar",
    "desavezásseis": "desavezar",
    "desavezássemos": "desavezar",
    "desavezávamo": "desavezar",
    "desavezávamos": "desavezar",
    "desavezávei": "desavezar",
    "desavezáveis": "desavezar",
    "desavia": "desaviar",
    "desaviada": "desaviar",
    "desaviadas": "desaviar",
    "desaviado": "desaviar",
    "desaviados": "desaviar",
    "desaviai": "desaviar",
    "desaviais": "desaviar",
    "desaviam": "desaviar",
    "desaviamo": "desaviar",
    "desaviamos": "desaviar",
    "desaviando": "desaviar",
    "desaviara": "desaviar",
    "desaviaram": "desaviar",
    "desaviaras": "desaviar",
    "desaviarde": "desaviar",
    "desaviardes": "desaviar",
    "desaviare": "desaviar",
    "desaviarei": "desaviar",
    "desaviareis": "desaviar",
    "desaviarem": "desaviar",
    "desaviaremos": "desaviar",
    "desaviares": "desaviar",
    "desaviaria": "desaviar",
    "desaviariam": "desaviar",
    "desaviarias": "desaviar",
    "desaviarmo": "desaviar",
    "desaviarmos": "desaviar",
    "desaviará": "desaviar",
    "desaviarás": "desaviar",
    "desaviarão": "desaviar",
    "desaviaríamos": "desaviar",
    "desaviaríeis": "desaviar",
    "desavias": "desaviar",
    "desaviasse": "desaviar",
    "desaviassem": "desaviar",
    "desaviasses": "desaviar",
    "desaviaste": "desaviar",
    "desaviastes": "desaviar",
    "desaviava": "desaviar",
    "desaviavam": "desaviar",
    "desaviavas": "desaviar",
    "desavida": "desavido",
    "desavidas": "desavido",
    "desavidos": "desavido",
    "desavie": "desaviar",
    "desaviei": "desaviar",
    "desavieis": "desaviar",
    "desaviem": "desaviar",
    "desaviemo": "desaviar",
    "desaviemos": "desaviar",
    "desavies": "desaviar",
    "desavinda": "desavindo",
    "desavindas": "desavindo",
    "desavindos": "desavindo",
    "desavinha": "desavinhar",
    "desavinhada": "desavinhar",
    "desavinhadas": "desavinhar",
    "desavinhado": "desavinhar",
    "desavinhados": "desavinhar",
    "desavinhai": "desavinhar",
    "desavinhais": "desavinhar",
    "desavinham": "desavinhar",
    "desavinhamo": "desavinhar",
    "desavinhamos": "desavinhar",
    "desavinhando": "desavinhar",
    "desavinhara": "desavinhar",
    "desavinharam": "desavinhar",
    "desavinharas": "desavinhar",
    "desavinhardes": "desavinhar",
    "desavinharei": "desavinhar",
    "desavinhareis": "desavinhar",
    "desavinharem": "desavinhar",
    "desavinharemos": "desavinhar",
    "desavinhares": "desavinhar",
    "desavinharia": "desavinhar",
    "desavinhariam": "desavinhar",
    "desavinharias": "desavinhar",
    "desavinharmo": "desavinhar",
    "desavinharmos": "desavinhar",
    "desavinhará": "desavinhar",
    "desavinharás": "desavinhar",
    "desavinharão": "desavinhar",
    "desavinharíamos": "desavinhar",
    "desavinharíeis": "desavinhar",
    "desavinhas": "desavinhar",
    "desavinhasse": "desavinhar",
    "desavinhassem": "desavinhar",
    "desavinhasses": "desavinhar",
    "desavinhaste": "desavinhar",
    "desavinhastes": "desavinhar",
    "desavinhava": "desavinhar",
    "desavinhavam": "desavinhar",
    "desavinhavas": "desavinhar",
    "desavinhe": "desavinhar",
    "desavinhei": "desavinhar",
    "desavinheis": "desavinhar",
    "desavinhem": "desavinhar",
    "desavinhemo": "desavinhar",
    "desavinhemos": "desavinhar",
    "desavinhes": "desavinhar",
    "desavinho": "desavinhar",
    "desavinhos": "desavinho",
    "desavinhou": "desavinhar",
    "desavinhámo": "desavinhar",
    "desavinhámos": "desavinhar",
    "desavinháramo": "desavinhar",
    "desavinháramos": "desavinhar",
    "desavinháreis": "desavinhar",
    "desavinhásseis": "desavinhar",
    "desavinhássemos": "desavinhar",
    "desavinhávamo": "desavinhar",
    "desavinhávamos": "desavinhar",
    "desavinháveis": "desavinhar",
    "desavio": "desaviar",
    "desaviou": "desaviar",
    "desavisa": "desavisar",
    "desavisada": "desavisar",
    "desavisadas": "desavisar",
    "desavisado": "desavisar",
    "desavisados": "desavisar",
    "desavisai": "desavisar",
    "desavisais": "desavisar",
    "desavisam": "desavisar",
    "desavisamentos": "desavisamento",
    "desavisamo": "desavisar",
    "desavisamos": "desavisar",
    "desavisando": "desavisar",
    "desavisara": "desavisar",
    "desavisaram": "desavisar",
    "desavisaras": "desavisar",
    "desavisarde": "desavisar",
    "desavisardes": "desavisar",
    "desavisare": "desavisar",
    "desavisarei": "desavisar",
    "desavisareis": "desavisar",
    "desavisarem": "desavisar",
    "desavisaremos": "desavisar",
    "desavisares": "desavisar",
    "desavisaria": "desavisar",
    "desavisariam": "desavisar",
    "desavisarias": "desavisar",
    "desavisarmo": "desavisar",
    "desavisarmos": "desavisar",
    "desavisará": "desavisar",
    "desavisarás": "desavisar",
    "desavisarão": "desavisar",
    "desavisaríamos": "desavisar",
    "desavisaríeis": "desavisar",
    "desavisas": "desavisar",
    "desavisasse": "desavisar",
    "desavisassem": "desavisar",
    "desavisasses": "desavisar",
    "desavisaste": "desavisar",
    "desavisastes": "desavisar",
    "desavisava": "desavisar",
    "desavisavam": "desavisar",
    "desavisavas": "desavisar",
    "desavise": "desavisar",
    "desavisei": "desavisar",
    "desaviseis": "desavisar",
    "desavisem": "desavisar",
    "desavisemo": "desavisar",
    "desavisemos": "desavisar",
    "desavises": "desavisar",
    "desaviso": "desavisar",
    "desavisos": "desaviso",
    "desavisou": "desavisar",
    "desavista": "desavistar",
    "desavistada": "desavistar",
    "desavistadas": "desavistar",
    "desavistado": "desavistar",
    "desavistados": "desavistar",
    "desavistai": "desavistar",
    "desavistais": "desavistar",
    "desavistam": "desavistar",
    "desavistamo": "desavistar",
    "desavistamos": "desavistar",
    "desavistando": "desavistar",
    "desavistara": "desavistar",
    "desavistaram": "desavistar",
    "desavistaras": "desavistar",
    "desavistarde": "desavistar",
    "desavistardes": "desavistar",
    "desavistare": "desavistar",
    "desavistarei": "desavistar",
    "desavistareis": "desavistar",
    "desavistarem": "desavistar",
    "desavistaremos": "desavistar",
    "desavistares": "desavistar",
    "desavistaria": "desavistar",
    "desavistariam": "desavistar",
    "desavistarias": "desavistar",
    "desavistarmo": "desavistar",
    "desavistarmos": "desavistar",
    "desavistará": "desavistar",
    "desavistarás": "desavistar",
    "desavistarão": "desavistar",
    "desavistaríamos": "desavistar",
    "desavistaríeis": "desavistar",
    "desavistas": "desavistar",
    "desavistasse": "desavistar",
    "desavistassem": "desavistar",
    "desavistasses": "desavistar",
    "desavistaste": "desavistar",
    "desavistastes": "desavistar",
    "desavistava": "desavistar",
    "desavistavam": "desavistar",
    "desavistavas": "desavistar",
    "desaviste": "desavistar",
    "desavistei": "desavistar",
    "desavisteis": "desavistar",
    "desavistem": "desavistar",
    "desavistemo": "desavistar",
    "desavistemos": "desavistar",
    "desavistes": "desavistar",
    "desavisto": "desavistar",
    "desavistou": "desavistar",
    "desavistá": "desavistar",
    "desavistámo": "desavistar",
    "desavistámos": "desavistar",
    "desavistáramo": "desavistar",
    "desavistáramos": "desavistar",
    "desavistárei": "desavistar",
    "desavistáreis": "desavistar",
    "desavistásseis": "desavistar",
    "desavistássemos": "desavistar",
    "desavistávamo": "desavistar",
    "desavistávamos": "desavistar",
    "desavistávei": "desavistar",
    "desavistáveis": "desavistar",
    "desavisá": "desavisar",
    "desavisámo": "desavisar",
    "desavisámos": "desavisar",
    "desavisáramo": "desavisar",
    "desavisáramos": "desavisar",
    "desavisárei": "desavisar",
    "desavisáreis": "desavisar",
    "desavisásseis": "desavisar",
    "desavisássemos": "desavisar",
    "desavisávamo": "desavisar",
    "desavisávamos": "desavisar",
    "desavisávei": "desavisar",
    "desavisáveis": "desavisar",
    "desaviá": "desaviar",
    "desaviámo": "desaviar",
    "desaviámos": "desaviar",
    "desaviáramo": "desaviar",
    "desaviáramos": "desaviar",
    "desaviárei": "desaviar",
    "desaviáreis": "desaviar",
    "desaviásseis": "desaviar",
    "desaviássemos": "desaviar",
    "desaviávamo": "desaviar",
    "desaviávamos": "desaviar",
    "desaviávei": "desaviar",
    "desaviáveis": "desaviar",
    "desavoluma": "desavolumar",
    "desavolumada": "desavolumar",
    "desavolumadas": "desavolumar",
    "desavolumado": "desavolumar",
    "desavolumados": "desavolumar",
    "desavolumai": "desavolumar",
    "desavolumais": "desavolumar",
    "desavolumam": "desavolumar",
    "desavolumamo": "desavolumar",
    "desavolumamos": "desavolumar",
    "desavolumando": "desavolumar",
    "desavolumara": "desavolumar",
    "desavolumaram": "desavolumar",
    "desavolumaras": "desavolumar",
    "desavolumarde": "desavolumar",
    "desavolumardes": "desavolumar",
    "desavolumare": "desavolumar",
    "desavolumarei": "desavolumar",
    "desavolumareis": "desavolumar",
    "desavolumarem": "desavolumar",
    "desavolumaremos": "desavolumar",
    "desavolumares": "desavolumar",
    "desavolumaria": "desavolumar",
    "desavolumariam": "desavolumar",
    "desavolumarias": "desavolumar",
    "desavolumarmo": "desavolumar",
    "desavolumarmos": "desavolumar",
    "desavolumará": "desavolumar",
    "desavolumarás": "desavolumar",
    "desavolumarão": "desavolumar",
    "desavolumaríamos": "desavolumar",
    "desavolumaríeis": "desavolumar",
    "desavolumas": "desavolumar",
    "desavolumasse": "desavolumar",
    "desavolumassem": "desavolumar",
    "desavolumasses": "desavolumar",
    "desavolumaste": "desavolumar",
    "desavolumastes": "desavolumar",
    "desavolumava": "desavolumar",
    "desavolumavam": "desavolumar",
    "desavolumavas": "desavolumar",
    "desavolume": "desavolumar",
    "desavolumei": "desavolumar",
    "desavolumeis": "desavolumar",
    "desavolumem": "desavolumar",
    "desavolumemo": "desavolumar",
    "desavolumemos": "desavolumar",
    "desavolumes": "desavolumar",
    "desavolumo": "desavolumar",
    "desavolumou": "desavolumar",
    "desavolumá": "desavolumar",
    "desavolumámo": "desavolumar",
    "desavolumámos": "desavolumar",
    "desavolumáramo": "desavolumar",
    "desavolumáramos": "desavolumar",
    "desavolumárei": "desavolumar",
    "desavolumáreis": "desavolumar",
    "desavolumásseis": "desavolumar",
    "desavolumássemos": "desavolumar",
    "desavolumávamo": "desavolumar",
    "desavolumávamos": "desavolumar",
    "desavolumávei": "desavolumar",
    "desavolumáveis": "desavolumar",
    "desazada": "desazado",
    "desazadas": "desazado",
    "desazados": "desazado",
    "desazos": "desazo",
    "desazota": "desazotar",
    "desazotada": "desazotar",
    "desazotadas": "desazotar",
    "desazotado": "desazotar",
    "desazotados": "desazotar",
    "desazotai": "desazotar",
    "desazotais": "desazotar",
    "desazotam": "desazotar",
    "desazotamo": "desazotar",
    "desazotamos": "desazotar",
    "desazotando": "desazotar",
    "desazotara": "desazotar",
    "desazotaram": "desazotar",
    "desazotaras": "desazotar",
    "desazotarde": "desazotar",
    "desazotardes": "desazotar",
    "desazotare": "desazotar",
    "desazotarei": "desazotar",
    "desazotareis": "desazotar",
    "desazotarem": "desazotar",
    "desazotaremos": "desazotar",
    "desazotares": "desazotar",
    "desazotaria": "desazotar",
    "desazotariam": "desazotar",
    "desazotarias": "desazotar",
    "desazotarmo": "desazotar",
    "desazotarmos": "desazotar",
    "desazotará": "desazotar",
    "desazotarás": "desazotar",
    "desazotarão": "desazotar",
    "desazotaríamos": "desazotar",
    "desazotaríeis": "desazotar",
    "desazotas": "desazotar",
    "desazotasse": "desazotar",
    "desazotassem": "desazotar",
    "desazotasses": "desazotar",
    "desazotaste": "desazotar",
    "desazotastes": "desazotar",
    "desazotava": "desazotar",
    "desazotavam": "desazotar",
    "desazotavas": "desazotar",
    "desazote": "desazotar",
    "desazotei": "desazotar",
    "desazoteis": "desazotar",
    "desazotem": "desazotar",
    "desazotemo": "desazotar",
    "desazotemos": "desazotar",
    "desazotes": "desazotar",
    "desazoto": "desazotar",
    "desazotou": "desazotar",
    "desazotá": "desazotar",
    "desazotámo": "desazotar",
    "desazotámos": "desazotar",
    "desazotáramo": "desazotar",
    "desazotáramos": "desazotar",
    "desazotárei": "desazotar",
    "desazotáreis": "desazotar",
    "desazotásseis": "desazotar",
    "desazotássemos": "desazotar",
    "desazotávamo": "desazotar",
    "desazotávamos": "desazotar",
    "desazotávei": "desazotar",
    "desazotáveis": "desazotar",
    "desaçaima": "desaçaimar",
    "desaçaimada": "desaçaimar",
    "desaçaimadas": "desaçaimar",
    "desaçaimado": "desaçaimar",
    "desaçaimados": "desaçaimar",
    "desaçaimai": "desaçaimar",
    "desaçaimais": "desaçaimar",
    "desaçaimam": "desaçaimar",
    "desaçaimamo": "desaçaimar",
    "desaçaimamos": "desaçaimar",
    "desaçaimando": "desaçaimar",
    "desaçaimar": "aimar",
    "desaçaimara": "desaçaimar",
    "desaçaimaram": "desaçaimar",
    "desaçaimaras": "desaçaimar",
    "desaçaimarde": "desaçaimar",
    "desaçaimardes": "desaçaimar",
    "desaçaimare": "desaçaimar",
    "desaçaimarei": "desaçaimar",
    "desaçaimareis": "desaçaimar",
    "desaçaimarem": "desaçaimar",
    "desaçaimaremos": "desaçaimar",
    "desaçaimares": "desaçaimar",
    "desaçaimaria": "desaçaimar",
    "desaçaimariam": "desaçaimar",
    "desaçaimarias": "desaçaimar",
    "desaçaimarmo": "desaçaimar",
    "desaçaimarmos": "desaçaimar",
    "desaçaimará": "desaçaimar",
    "desaçaimarás": "desaçaimar",
    "desaçaimarão": "desaçaimar",
    "desaçaimaríamos": "desaçaimar",
    "desaçaimaríeis": "desaçaimar",
    "desaçaimas": "desaçaimar",
    "desaçaimasse": "desaçaimar",
    "desaçaimassem": "desaçaimar",
    "desaçaimasses": "desaçaimar",
    "desaçaimaste": "desaçaimar",
    "desaçaimastes": "desaçaimar",
    "desaçaimava": "desaçaimar",
    "desaçaimavam": "desaçaimar",
    "desaçaimavas": "desaçaimar",
    "desaçaime": "desaçaimar",
    "desaçaimei": "desaçaimar",
    "desaçaimeis": "desaçaimar",
    "desaçaimem": "desaçaimar",
    "desaçaimemo": "desaçaimar",
    "desaçaimemos": "desaçaimar",
    "desaçaimes": "desaçaimar",
    "desaçaimo": "desaçaimar",
    "desaçaimou": "desaçaimar",
    "desaçaimá": "desaçaimar",
    "desaçaimámo": "desaçaimar",
    "desaçaimámos": "desaçaimar",
    "desaçaimáramo": "desaçaimar",
    "desaçaimáramos": "desaçaimar",
    "desaçaimárei": "desaçaimar",
    "desaçaimáreis": "desaçaimar",
    "desaçaimásseis": "desaçaimar",
    "desaçaimássemos": "desaçaimar",
    "desaçaimávamo": "desaçaimar",
    "desaçaimávamos": "desaçaimar",
    "desaçaimávei": "desaçaimar",
    "desaçaimáveis": "desaçaimar",
    "desaçama": "desaçamar",
    "desaçamada": "desaçamar",
    "desaçamadas": "desaçamar",
    "desaçamado": "desaçamar",
    "desaçamados": "desaçamar",
    "desaçamai": "desaçamar",
    "desaçamais": "desaçamar",
    "desaçamam": "desaçamar",
    "desaçamamo": "desaçamar",
    "desaçamamos": "desaçamar",
    "desaçamando": "desaçamar",
    "desaçamar": "amar",
    "desaçamara": "desaçamar",
    "desaçamaram": "desaçamar",
    "desaçamaras": "desaçamar",
    "desaçamarde": "desaçamar",
    "desaçamardes": "desaçamar",
    "desaçamare": "desaçamar",
    "desaçamarei": "desaçamar",
    "desaçamareis": "desaçamar",
    "desaçamarem": "desaçamar",
    "desaçamaremos": "desaçamar",
    "desaçamares": "desaçamar",
    "desaçamaria": "desaçamar",
    "desaçamariam": "desaçamar",
    "desaçamarias": "desaçamar",
    "desaçamarmo": "desaçamar",
    "desaçamarmos": "desaçamar",
    "desaçamará": "desaçamar",
    "desaçamarás": "desaçamar",
    "desaçamarão": "desaçamar",
    "desaçamaríamos": "desaçamar",
    "desaçamaríeis": "desaçamar",
    "desaçamas": "desaçamar",
    "desaçamasse": "desaçamar",
    "desaçamassem": "desaçamar",
    "desaçamasses": "desaçamar",
    "desaçamaste": "desaçamar",
    "desaçamastes": "desaçamar",
    "desaçamava": "desaçamar",
    "desaçamavam": "desaçamar",
    "desaçamavas": "desaçamar",
    "desaçame": "desaçamar",
    "desaçamei": "desaçamar",
    "desaçameis": "desaçamar",
    "desaçamem": "desaçamar",
    "desaçamemo": "desaçamar",
    "desaçamemos": "desaçamar",
    "desaçames": "desaçamar",
    "desaçamo": "desaçamar",
    "desaçamou": "desaçamar",
    "desaçamá": "desaçamar",
    "desaçamámo": "desaçamar",
    "desaçamámos": "desaçamar",
    "desaçamáramo": "desaçamar",
    "desaçamáramos": "desaçamar",
    "desaçamárei": "desaçamar",
    "desaçamáreis": "desaçamar",
    "desaçamásseis": "desaçamar",
    "desaçamássemos": "desaçamar",
    "desaçamávamo": "desaçamar",
    "desaçamávamos": "desaçamar",
    "desaçamávei": "desaçamar",
    "desaçamáveis": "desaçamar",
    "desbaba": "desbabar",
    "desbabada": "desbabar",
    "desbabadas": "desbabar",
    "desbabado": "desbabar",
    "desbabados": "desbabar",
    "desbabai": "desbabar",
    "desbabais": "desbabar",
    "desbabam": "desbabar",
    "desbabamo": "desbabar",
    "desbabamos": "desbabar",
    "desbabando": "desbabar",
    "desbabara": "desbabar",
    "desbabaram": "desbabar",
    "desbabaras": "desbabar",
    "desbabarde": "desbabar",
    "desbabardes": "desbabar",
    "desbabare": "desbabar",
    "desbabarei": "desbabar",
    "desbabareis": "desbabar",
    "desbabarem": "desbabar",
    "desbabaremos": "desbabar",
    "desbabares": "desbabar",
    "desbabaria": "desbabar",
    "desbabariam": "desbabar",
    "desbabarias": "desbabar",
    "desbabarmo": "desbabar",
    "desbabarmos": "desbabar",
    "desbabará": "desbabar",
    "desbabarás": "desbabar",
    "desbabarão": "desbabar",
    "desbabaríamos": "desbabar",
    "desbabaríeis": "desbabar",
    "desbabas": "desbabar",
    "desbabasse": "desbabar",
    "desbabassem": "desbabar",
    "desbabasses": "desbabar",
    "desbabaste": "desbabar",
    "desbabastes": "desbabar",
    "desbabava": "desbabar",
    "desbabavam": "desbabar",
    "desbabavas": "desbabar",
    "desbabe": "desbabar",
    "desbabei": "desbabar",
    "desbabeis": "desbabar",
    "desbabem": "desbabar",
    "desbabemo": "desbabar",
    "desbabemos": "desbabar",
    "desbabes": "desbabar",
    "desbabo": "desbabar",
    "desbabou": "desbabar",
    "desbabá": "desbabar",
    "desbabámo": "desbabar",
    "desbabámos": "desbabar",
    "desbabáramo": "desbabar",
    "desbabáramos": "desbabar",
    "desbabárei": "desbabar",
    "desbabáreis": "desbabar",
    "desbabásseis": "desbabar",
    "desbabássemos": "desbabar",
    "desbabávamo": "desbabar",
    "desbabávamos": "desbabar",
    "desbabávei": "desbabar",
    "desbabáveis": "desbabar",
    "desbaga": "desbagar",
    "desbagada": "desbagar",
    "desbagadas": "desbagar",
    "desbagado": "desbagar",
    "desbagados": "desbagar",
    "desbagai": "desbagar",
    "desbagais": "desbagar",
    "desbagam": "desbagar",
    "desbagamentos": "desbagamento",
    "desbagamo": "desbagar",
    "desbagamos": "desbagar",
    "desbagando": "desbagar",
    "desbagara": "desbagar",
    "desbagaram": "desbagar",
    "desbagaras": "desbagar",
    "desbagarde": "desbagar",
    "desbagardes": "desbagar",
    "desbagare": "desbagar",
    "desbagarei": "desbagar",
    "desbagareis": "desbagar",
    "desbagarem": "desbagar",
    "desbagaremos": "desbagar",
    "desbagares": "desbagar",
    "desbagaria": "desbagar",
    "desbagariam": "desbagar",
    "desbagarias": "desbagar",
    "desbagarmo": "desbagar",
    "desbagarmos": "desbagar",
    "desbagará": "desbagar",
    "desbagarás": "desbagar",
    "desbagarão": "desbagar",
    "desbagaríamos": "desbagar",
    "desbagaríeis": "desbagar",
    "desbagas": "desbagar",
    "desbagasse": "desbagar",
    "desbagassem": "desbagar",
    "desbagasses": "desbagar",
    "desbagaste": "desbagar",
    "desbagastes": "desbagar",
    "desbagava": "desbagar",
    "desbagavam": "desbagar",
    "desbagavas": "desbagar",
    "desbago": "desbagar",
    "desbagoa": "desbagoar",
    "desbagoada": "desbagoar",
    "desbagoadas": "desbagoar",
    "desbagoado": "desbagoar",
    "desbagoados": "desbagoar",
    "desbagoai": "desbagoar",
    "desbagoais": "desbagoar",
    "desbagoam": "desbagoar",
    "desbagoamo": "desbagoar",
    "desbagoamos": "desbagoar",
    "desbagoando": "desbagoar",
    "desbagoara": "desbagoar",
    "desbagoaram": "desbagoar",
    "desbagoaras": "desbagoar",
    "desbagoarde": "desbagoar",
    "desbagoardes": "desbagoar",
    "desbagoare": "desbagoar",
    "desbagoarei": "desbagoar",
    "desbagoareis": "desbagoar",
    "desbagoarem": "desbagoar",
    "desbagoaremos": "desbagoar",
    "desbagoares": "desbagoar",
    "desbagoaria": "desbagoar",
    "desbagoariam": "desbagoar",
    "desbagoarias": "desbagoar",
    "desbagoarmo": "desbagoar",
    "desbagoarmos": "desbagoar",
    "desbagoará": "desbagoar",
    "desbagoarás": "desbagoar",
    "desbagoarão": "desbagoar",
    "desbagoaríamos": "desbagoar",
    "desbagoaríeis": "desbagoar",
    "desbagoas": "desbagoar",
    "desbagoasse": "desbagoar",
    "desbagoassem": "desbagoar",
    "desbagoasses": "desbagoar",
    "desbagoaste": "desbagoar",
    "desbagoastes": "desbagoar",
    "desbagoava": "desbagoar",
    "desbagoavam": "desbagoar",
    "desbagoavas": "desbagoar",
    "desbagoe": "desbagoar",
    "desbagoei": "desbagoar",
    "desbagoeis": "desbagoar",
    "desbagoem": "desbagoar",
    "desbagoemo": "desbagoar",
    "desbagoemos": "desbagoar",
    "desbagoes": "desbagoar",
    "desbagoo": "desbagoar",
    "desbagoou": "desbagoar",
    "desbagou": "desbagar",
    "desbagoá": "desbagoar",
    "desbagoámo": "desbagoar",
    "desbagoámos": "desbagoar",
    "desbagoáramo": "desbagoar",
    "desbagoáramos": "desbagoar",
    "desbagoárei": "desbagoar",
    "desbagoáreis": "desbagoar",
    "desbagoásseis": "desbagoar",
    "desbagoássemos": "desbagoar",
    "desbagoávamo": "desbagoar",
    "desbagoávamos": "desbagoar",
    "desbagoávei": "desbagoar",
    "desbagoáveis": "desbagoar",
    "desbague": "desbagar",
    "desbaguei": "desbagar",
    "desbagueis": "desbagar",
    "desbaguem": "desbagar",
    "desbaguemo": "desbagar",
    "desbaguemos": "desbagar",
    "desbagues": "desbagar",
    "desbagulha": "desbagulhar",
    "desbagulhada": "desbagulhar",
    "desbagulhadas": "desbagulhar",
    "desbagulhado": "desbagulhar",
    "desbagulhados": "desbagulhar",
    "desbagulhai": "desbagulhar",
    "desbagulhais": "desbagulhar",
    "desbagulham": "desbagulhar",
    "desbagulhamo": "desbagulhar",
    "desbagulhamos": "desbagulhar",
    "desbagulhando": "desbagulhar",
    "desbagulhara": "desbagulhar",
    "desbagulharam": "desbagulhar",
    "desbagulharas": "desbagulhar",
    "desbagulharde": "desbagulhar",
    "desbagulhardes": "desbagulhar",
    "desbagulhare": "desbagulhar",
    "desbagulharei": "desbagulhar",
    "desbagulhareis": "desbagulhar",
    "desbagulharem": "desbagulhar",
    "desbagulharemos": "desbagulhar",
    "desbagulhares": "desbagulhar",
    "desbagulharia": "desbagulhar",
    "desbagulhariam": "desbagulhar",
    "desbagulharias": "desbagulhar",
    "desbagulharmo": "desbagulhar",
    "desbagulharmos": "desbagulhar",
    "desbagulhará": "desbagulhar",
    "desbagulharás": "desbagulhar",
    "desbagulharão": "desbagulhar",
    "desbagulharíamos": "desbagulhar",
    "desbagulharíeis": "desbagulhar",
    "desbagulhas": "desbagulhar",
    "desbagulhasse": "desbagulhar",
    "desbagulhassem": "desbagulhar",
    "desbagulhasses": "desbagulhar",
    "desbagulhaste": "desbagulhar",
    "desbagulhastes": "desbagulhar",
    "desbagulhava": "desbagulhar",
    "desbagulhavam": "desbagulhar",
    "desbagulhavas": "desbagulhar",
    "desbagulhe": "desbagulhar",
    "desbagulhei": "desbagulhar",
    "desbagulheis": "desbagulhar",
    "desbagulhem": "desbagulhar",
    "desbagulhemo": "desbagulhar",
    "desbagulhemos": "desbagulhar",
    "desbagulhes": "desbagulhar",
    "desbagulho": "desbagulhar",
    "desbagulhou": "desbagulhar",
    "desbagulhá": "desbagulhar",
    "desbagulhámo": "desbagulhar",
    "desbagulhámos": "desbagulhar",
    "desbagulháramo": "desbagulhar",
    "desbagulháramos": "desbagulhar",
    "desbagulhárei": "desbagulhar",
    "desbagulháreis": "desbagulhar",
    "desbagulhásseis": "desbagulhar",
    "desbagulhássemos": "desbagulhar",
    "desbagulhávamo": "desbagulhar",
    "desbagulhávamos": "desbagulhar",
    "desbagulhávei": "desbagulhar",
    "desbagulháveis": "desbagulhar",
    "desbagá": "desbagar",
    "desbagámo": "desbagar",
    "desbagámos": "desbagar",
    "desbagáramo": "desbagar",
    "desbagáramos": "desbagar",
    "desbagárei": "desbagar",
    "desbagáreis": "desbagar",
    "desbagásseis": "desbagar",
    "desbagássemos": "desbagar",
    "desbagávamo": "desbagar",
    "desbagávamos": "desbagar",
    "desbagávei": "desbagar",
    "desbagáveis": "desbagar",
    "desbaliza": "desbalizar",
    "desbalizada": "desbalizar",
    "desbalizadas": "desbalizar",
    "desbalizado": "desbalizar",
    "desbalizados": "desbalizar",
    "desbalizai": "desbalizar",
    "desbalizais": "desbalizar",
    "desbalizam": "desbalizar",
    "desbalizamo": "desbalizar",
    "desbalizamos": "desbalizar",
    "desbalizando": "desbalizar",
    "desbalizara": "desbalizar",
    "desbalizaram": "desbalizar",
    "desbalizaras": "desbalizar",
    "desbalizarde": "desbalizar",
    "desbalizardes": "desbalizar",
    "desbalizare": "desbalizar",
    "desbalizarei": "desbalizar",
    "desbalizareis": "desbalizar",
    "desbalizarem": "desbalizar",
    "desbalizaremos": "desbalizar",
    "desbalizares": "desbalizar",
    "desbalizaria": "desbalizar",
    "desbalizariam": "desbalizar",
    "desbalizarias": "desbalizar",
    "desbalizarmo": "desbalizar",
    "desbalizarmos": "desbalizar",
    "desbalizará": "desbalizar",
    "desbalizarás": "desbalizar",
    "desbalizarão": "desbalizar",
    "desbalizaríamos": "desbalizar",
    "desbalizaríeis": "desbalizar",
    "desbalizas": "desbalizar",
    "desbalizasse": "desbalizar",
    "desbalizassem": "desbalizar",
    "desbalizasses": "desbalizar",
    "desbalizaste": "desbalizar",
    "desbalizastes": "desbalizar",
    "desbalizava": "desbalizar",
    "desbalizavam": "desbalizar",
    "desbalizavas": "desbalizar",
    "desbalize": "desbalizar",
    "desbalizei": "desbalizar",
    "desbalizeis": "desbalizar",
    "desbalizem": "desbalizar",
    "desbalizemo": "desbalizar",
    "desbalizemos": "desbalizar",
    "desbalizes": "desbalizar",
    "desbalizo": "desbalizar",
    "desbalizou": "desbalizar",
    "desbalizá": "desbalizar",
    "desbalizámo": "desbalizar",
    "desbalizámos": "desbalizar",
    "desbalizáramo": "desbalizar",
    "desbalizáramos": "desbalizar",
    "desbalizárei": "desbalizar",
    "desbalizáreis": "desbalizar",
    "desbalizásseis": "desbalizar",
    "desbalizássemos": "desbalizar",
    "desbalizávamo": "desbalizar",
    "desbalizávamos": "desbalizar",
    "desbalizávei": "desbalizar",
    "desbalizáveis": "desbalizar",
    "desbamba": "desbambar",
    "desbambada": "desbambar",
    "desbambadas": "desbambar",
    "desbambado": "desbambar",
    "desbambados": "desbambar",
    "desbambai": "desbambar",
    "desbambais": "desbambar",
    "desbambam": "desbambar",
    "desbambamo": "desbambar",
    "desbambamos": "desbambar",
    "desbambando": "desbambar",
    "desbambara": "desbambar",
    "desbambaram": "desbambar",
    "desbambaras": "desbambar",
    "desbambarde": "desbambar",
    "desbambardes": "desbambar",
    "desbambare": "desbambar",
    "desbambarei": "desbambar",
    "desbambareis": "desbambar",
    "desbambarem": "desbambar",
    "desbambaremos": "desbambar",
    "desbambares": "desbambar",
    "desbambaria": "desbambar",
    "desbambariam": "desbambar",
    "desbambarias": "desbambar",
    "desbambarmo": "desbambar",
    "desbambarmos": "desbambar",
    "desbambará": "desbambar",
    "desbambarás": "desbambar",
    "desbambarão": "desbambar",
    "desbambaríamos": "desbambar",
    "desbambaríeis": "desbambar",
    "desbambas": "desbambar",
    "desbambasse": "desbambar",
    "desbambassem": "desbambar",
    "desbambasses": "desbambar",
    "desbambaste": "desbambar",
    "desbambastes": "desbambar",
    "desbambava": "desbambar",
    "desbambavam": "desbambar",
    "desbambavas": "desbambar",
    "desbambe": "desbambar",
    "desbambei": "desbambar",
    "desbambeis": "desbambar",
    "desbambem": "desbambar",
    "desbambemo": "desbambar",
    "desbambemos": "desbambar",
    "desbambes": "desbambar",
    "desbambo": "desbambar",
    "desbambou": "desbambar",
    "desbambá": "desbambar",
    "desbambámo": "desbambar",
    "desbambámos": "desbambar",
    "desbambáramo": "desbambar",
    "desbambáramos": "desbambar",
    "desbambárei": "desbambar",
    "desbambáreis": "desbambar",
    "desbambásseis": "desbambar",
    "desbambássemos": "desbambar",
    "desbambávamo": "desbambar",
    "desbambávamos": "desbambar",
    "desbambávei": "desbambar",
    "desbambáveis": "desbambar",
    "desbanaliza": "desbanalizar",
    "desbanalizada": "desbanalizar",
    "desbanalizadas": "desbanalizar",
    "desbanalizado": "desbanalizar",
    "desbanalizados": "desbanalizar",
    "desbanalizai": "desbanalizar",
    "desbanalizais": "desbanalizar",
    "desbanalizam": "desbanalizar",
    "desbanalizamo": "desbanalizar",
    "desbanalizamos": "desbanalizar",
    "desbanalizando": "desbanalizar",
    "desbanalizara": "desbanalizar",
    "desbanalizaram": "desbanalizar",
    "desbanalizaras": "desbanalizar",
    "desbanalizarde": "desbanalizar",
    "desbanalizardes": "desbanalizar",
    "desbanalizare": "desbanalizar",
    "desbanalizarei": "desbanalizar",
    "desbanalizareis": "desbanalizar",
    "desbanalizarem": "desbanalizar",
    "desbanalizaremos": "desbanalizar",
    "desbanalizares": "desbanalizar",
    "desbanalizaria": "desbanalizar",
    "desbanalizariam": "desbanalizar",
    "desbanalizarias": "desbanalizar",
    "desbanalizarmo": "desbanalizar",
    "desbanalizarmos": "desbanalizar",
    "desbanalizará": "desbanalizar",
    "desbanalizarás": "desbanalizar",
    "desbanalizarão": "desbanalizar",
    "desbanalizaríamos": "desbanalizar",
    "desbanalizaríeis": "desbanalizar",
    "desbanalizas": "desbanalizar",
    "desbanalizasse": "desbanalizar",
    "desbanalizassem": "desbanalizar",
    "desbanalizasses": "desbanalizar",
    "desbanalizaste": "desbanalizar",
    "desbanalizastes": "desbanalizar",
    "desbanalizava": "desbanalizar",
    "desbanalizavam": "desbanalizar",
    "desbanalizavas": "desbanalizar",
    "desbanalize": "desbanalizar",
    "desbanalizei": "desbanalizar",
    "desbanalizeis": "desbanalizar",
    "desbanalizem": "desbanalizar",
    "desbanalizemo": "desbanalizar",
    "desbanalizemos": "desbanalizar",
    "desbanalizes": "desbanalizar",
    "desbanalizo": "desbanalizar",
    "desbanalizou": "desbanalizar",
    "desbanalizá": "desbanalizar",
    "desbanalizámo": "desbanalizar",
    "desbanalizámos": "desbanalizar",
    "desbanalizáramo": "desbanalizar",
    "desbanalizáramos": "desbanalizar",
    "desbanalizárei": "desbanalizar",
    "desbanalizáreis": "desbanalizar",
    "desbanalizásseis": "desbanalizar",
    "desbanalizássemos": "desbanalizar",
    "desbanalizávamo": "desbanalizar",
    "desbanalizávamos": "desbanalizar",
    "desbanalizávei": "desbanalizar",
    "desbanalizáveis": "desbanalizar",
    "desbanca": "desbancar",
    "desbancada": "desbancar",
    "desbancadas": "desbancar",
    "desbancado": "desbancar",
    "desbancados": "desbancar",
    "desbancai": "desbancar",
    "desbancais": "desbancar",
    "desbancam": "desbancar",
    "desbancamo": "desbancar",
    "desbancamos": "desbancar",
    "desbancando": "desbancar",
    "desbancara": "desbancar",
    "desbancaram": "desbancar",
    "desbancaras": "desbancar",
    "desbancarde": "desbancar",
    "desbancardes": "desbancar",
    "desbancare": "desbancar",
    "desbancarei": "desbancar",
    "desbancareis": "desbancar",
    "desbancarem": "desbancar",
    "desbancaremos": "desbancar",
    "desbancares": "desbancar",
    "desbancaria": "desbancar",
    "desbancariam": "desbancar",
    "desbancarias": "desbancar",
    "desbancarmo": "desbancar",
    "desbancarmos": "desbancar",
    "desbancará": "desbancar",
    "desbancarás": "desbancar",
    "desbancarão": "desbancar",
    "desbancaríamos": "desbancar",
    "desbancaríeis": "desbancar",
    "desbancas": "desbancar",
    "desbancasse": "desbancar",
    "desbancassem": "desbancar",
    "desbancasses": "desbancar",
    "desbancaste": "desbancar",
    "desbancastes": "desbancar",
    "desbancava": "desbancar",
    "desbancavam": "desbancar",
    "desbancavas": "desbancar",
    "desbanco": "desbancar",
    "desbancou": "desbancar",
    "desbancá": "desbancar",
    "desbancámo": "desbancar",
    "desbancámos": "desbancar",
    "desbancáramo": "desbancar",
    "desbancáramos": "desbancar",
    "desbancárei": "desbancar",
    "desbancáreis": "desbancar",
    "desbancásseis": "desbancar",
    "desbancássemos": "desbancar",
    "desbancávamo": "desbancar",
    "desbancávamos": "desbancar",
    "desbancávei": "desbancar",
    "desbancáveis": "desbancar",
    "desbanda": "desbandar",
    "desbandada": "desbandar",
    "desbandadas": "desbandar",
    "desbandado": "desbandar",
    "desbandados": "desbandar",
    "desbandai": "desbandar",
    "desbandais": "desbandar",
    "desbandam": "desbandar",
    "desbandamo": "desbandar",
    "desbandamos": "desbandar",
    "desbandando": "desbandar",
    "desbandara": "desbandar",
    "desbandaram": "desbandar",
    "desbandaras": "desbandar",
    "desbandarde": "desbandar",
    "desbandardes": "desbandar",
    "desbandare": "desbandar",
    "desbandarei": "desbandar",
    "desbandareis": "desbandar",
    "desbandarem": "desbandar",
    "desbandaremos": "desbandar",
    "desbandares": "desbandar",
    "desbandaria": "desbandar",
    "desbandariam": "desbandar",
    "desbandarias": "desbandar",
    "desbandarmo": "desbandar",
    "desbandarmos": "desbandar",
    "desbandará": "desbandar",
    "desbandarás": "desbandar",
    "desbandarão": "desbandar",
    "desbandaríamos": "desbandar",
    "desbandaríeis": "desbandar",
    "desbandas": "desbandar",
    "desbandasse": "desbandar",
    "desbandassem": "desbandar",
    "desbandasses": "desbandar",
    "desbandaste": "desbandar",
    "desbandastes": "desbandar",
    "desbandava": "desbandar",
    "desbandavam": "desbandar",
    "desbandavas": "desbandar",
    "desbande": "desbandar",
    "desbandei": "desbandar",
    "desbandeiras": "desbandeira",
    "desbandeis": "desbandar",
    "desbandem": "desbandar",
    "desbandemo": "desbandar",
    "desbandemos": "desbandar",
    "desbandes": "desbandar",
    "desbando": "desbandar",
    "desbandou": "desbandar",
    "desbandá": "desbandar",
    "desbandámo": "desbandar",
    "desbandámos": "desbandar",
    "desbandáramo": "desbandar",
    "desbandáramos": "desbandar",
    "desbandárei": "desbandar",
    "desbandáreis": "desbandar",
    "desbandásseis": "desbandar",
    "desbandássemos": "desbandar",
    "desbandávamo": "desbandar",
    "desbandávamos": "desbandar",
    "desbandávei": "desbandar",
    "desbandáveis": "desbandar",
    "desbanque": "desbancar",
    "desbanquei": "desbancar",
    "desbanqueis": "desbancar",
    "desbanquem": "desbancar",
    "desbanquemo": "desbancar",
    "desbanquemos": "desbancar",
    "desbanques": "desbanque",
    "desbarata": "desbaratar",
    "desbaratada": "desbaratar",
    "desbaratadas": "desbaratar",
    "desbaratado": "desbaratar",
    "desbaratadora": "desbaratador",
    "desbaratadoras": "desbaratador",
    "desbaratadores": "desbaratador",
    "desbaratados": "desbaratar",
    "desbaratai": "desbaratar",
    "desbaratais": "desbaratar",
    "desbaratam": "desbaratar",
    "desbaratamentos": "desbaratamento",
    "desbaratamo": "desbaratar",
    "desbaratamos": "desbaratar",
    "desbaratando": "desbaratar",
    "desbaratara": "desbaratar",
    "desbarataram": "desbaratar",
    "desbarataras": "desbaratar",
    "desbaratarde": "desbaratar",
    "desbaratardes": "desbaratar",
    "desbaratare": "desbaratar",
    "desbaratarei": "desbaratar",
    "desbaratareis": "desbaratar",
    "desbaratarem": "desbaratar",
    "desbarataremos": "desbaratar",
    "desbaratares": "desbaratar",
    "desbarataria": "desbaratar",
    "desbaratariam": "desbaratar",
    "desbaratarias": "desbaratar",
    "desbaratarmo": "desbaratar",
    "desbaratarmos": "desbaratar",
    "desbaratará": "desbaratar",
    "desbaratarás": "desbaratar",
    "desbaratarão": "desbaratar",
    "desbarataríamos": "desbaratar",
    "desbarataríeis": "desbaratar",
    "desbaratas": "desbaratar",
    "desbaratasse": "desbaratar",
    "desbaratassem": "desbaratar",
    "desbaratasses": "desbaratar",
    "desbarataste": "desbaratar",
    "desbaratastes": "desbaratar",
    "desbaratava": "desbaratar",
    "desbaratavam": "desbaratar",
    "desbaratavas": "desbaratar",
    "desbarate": "desbaratar",
    "desbaratei": "desbaratar",
    "desbarateis": "desbaratar",
    "desbaratem": "desbaratar",
    "desbaratemo": "desbaratar",
    "desbaratemos": "desbaratar",
    "desbarates": "desbarate",
    "desbarato": "desbaratar",
    "desbaratos": "desbarato",
    "desbaratou": "desbaratar",
    "desbaratá": "desbaratar",
    "desbaratámo": "desbaratar",
    "desbaratámos": "desbaratar",
    "desbaratáramo": "desbaratar",
    "desbaratáramos": "desbaratar",
    "desbaratárei": "desbaratar",
    "desbaratáreis": "desbaratar",
    "desbaratásseis": "desbaratar",
    "desbaratássemos": "desbaratar",
    "desbaratávamo": "desbaratar",
    "desbaratávamos": "desbaratar",
    "desbaratávei": "desbaratar",
    "desbaratáveis": "desbaratar",
    "desbarba": "desbarbar",
    "desbarbada": "desbarbar",
    "desbarbadas": "desbarbar",
    "desbarbado": "desbarbar",
    "desbarbados": "desbarbar",
    "desbarbai": "desbarbar",
    "desbarbais": "desbarbar",
    "desbarbam": "desbarbar",
    "desbarbamentos": "desbarbamento",
    "desbarbamo": "desbarbar",
    "desbarbamos": "desbarbar",
    "desbarbando": "desbarbar",
    "desbarbara": "desbarbar",
    "desbarbaram": "desbarbar",
    "desbarbaras": "desbarbar",
    "desbarbarde": "desbarbar",
    "desbarbardes": "desbarbar",
    "desbarbare": "desbarbar",
    "desbarbarei": "desbarbar",
    "desbarbareis": "desbarbar",
    "desbarbarem": "desbarbar",
    "desbarbaremos": "desbarbar",
    "desbarbares": "desbarbar",
    "desbarbaria": "desbarbar",
    "desbarbariam": "desbarbar",
    "desbarbarias": "desbarbar",
    "desbarbariza": "desbarbarizar",
    "desbarbarizada": "desbarbarizar",
    "desbarbarizadas": "desbarbarizar",
    "desbarbarizado": "desbarbarizar",
    "desbarbarizados": "desbarbarizar",
    "desbarbarizai": "desbarbarizar",
    "desbarbarizais": "desbarbarizar",
    "desbarbarizam": "desbarbarizar",
    "desbarbarizamo": "desbarbarizar",
    "desbarbarizamos": "desbarbarizar",
    "desbarbarizando": "desbarbarizar",
    "desbarbarizara": "desbarbarizar",
    "desbarbarizaram": "desbarbarizar",
    "desbarbarizaras": "desbarbarizar",
    "desbarbarizarde": "desbarbarizar",
    "desbarbarizardes": "desbarbarizar",
    "desbarbarizare": "desbarbarizar",
    "desbarbarizarei": "desbarbarizar",
    "desbarbarizareis": "desbarbarizar",
    "desbarbarizarem": "desbarbarizar",
    "desbarbarizaremos": "desbarbarizar",
    "desbarbarizares": "desbarbarizar",
    "desbarbarizaria": "desbarbarizar",
    "desbarbarizariam": "desbarbarizar",
    "desbarbarizarias": "desbarbarizar",
    "desbarbarizarmo": "desbarbarizar",
    "desbarbarizarmos": "desbarbarizar",
    "desbarbarizará": "desbarbarizar",
    "desbarbarizarás": "desbarbarizar",
    "desbarbarizarão": "desbarbarizar",
    "desbarbarizaríamos": "desbarbarizar",
    "desbarbarizaríeis": "desbarbarizar",
    "desbarbarizas": "desbarbarizar",
    "desbarbarizasse": "desbarbarizar",
    "desbarbarizassem": "desbarbarizar",
    "desbarbarizasses": "desbarbarizar",
    "desbarbarizaste": "desbarbarizar",
    "desbarbarizastes": "desbarbarizar",
    "desbarbarizava": "desbarbarizar",
    "desbarbarizavam": "desbarbarizar",
    "desbarbarizavas": "desbarbarizar",
    "desbarbarize": "desbarbarizar",
    "desbarbarizei": "desbarbarizar",
    "desbarbarizeis": "desbarbarizar",
    "desbarbarizem": "desbarbarizar",
    "desbarbarizemo": "desbarbarizar",
    "desbarbarizemos": "desbarbarizar",
    "desbarbarizes": "desbarbarizar",
    "desbarbarizo": "desbarbarizar",
    "desbarbarizou": "desbarbarizar",
    "desbarbarizá": "desbarbarizar",
    "desbarbarizámo": "desbarbarizar",
    "desbarbarizámos": "desbarbarizar",
    "desbarbarizáramo": "desbarbarizar",
    "desbarbarizáramos": "desbarbarizar",
    "desbarbarizárei": "desbarbarizar",
    "desbarbarizáreis": "desbarbarizar",
    "desbarbarizásseis": "desbarbarizar",
    "desbarbarizássemos": "desbarbarizar",
    "desbarbarizávamo": "desbarbarizar",
    "desbarbarizávamos": "desbarbarizar",
    "desbarbarizávei": "desbarbarizar",
    "desbarbarizáveis": "desbarbarizar",
    "desbarbarmo": "desbarbar",
    "desbarbarmos": "desbarbar",
    "desbarbará": "desbarbar",
    "desbarbarás": "desbarbar",
    "desbarbarão": "desbarbar",
    "desbarbaríamos": "desbarbar",
    "desbarbaríeis": "desbarbar",
    "desbarbas": "desbarbar",
    "desbarbasse": "desbarbar",
    "desbarbassem": "desbarbar",
    "desbarbasses": "desbarbar",
    "desbarbaste": "desbarbar",
    "desbarbastes": "desbarbar",
    "desbarbava": "desbarbar",
    "desbarbavam": "desbarbar",
    "desbarbavas": "desbarbar",
    "desbarbe": "desbarbar",
    "desbarbedos": "desbarbedo",
    "desbarbei": "desbarbar",
    "desbarbeis": "desbarbar",
    "desbarbem": "desbarbar",
    "desbarbemo": "desbarbar",
    "desbarbemos": "desbarbar",
    "desbarbes": "desbarbar",
    "desbarbo": "desbarbar",
    "desbarbou": "desbarbar",
    "desbarbá": "desbarbar",
    "desbarbámo": "desbarbar",
    "desbarbámos": "desbarbar",
    "desbarbáramo": "desbarbar",
    "desbarbáramos": "desbarbar",
    "desbarbárei": "desbarbar",
    "desbarbáreis": "desbarbar",
    "desbarbásseis": "desbarbar",
    "desbarbássemos": "desbarbar",
    "desbarbávamo": "desbarbar",
    "desbarbávamos": "desbarbar",
    "desbarbávei": "desbarbar",
    "desbarbáveis": "desbarbar",
    "desbarrada": "desbarrado",
    "desbarradas": "desbarrado",
    "desbarrados": "desbarrado",
    "desbarranca": "desbarrancar",
    "desbarrancada": "desbarrancar",
    "desbarrancadas": "desbarrancar",
    "desbarrancado": "desbarrancar",
    "desbarrancados": "desbarrancar",
    "desbarrancai": "desbarrancar",
    "desbarrancais": "desbarrancar",
    "desbarrancam": "desbarrancar",
    "desbarrancamentos": "desbarrancamento",
    "desbarrancamo": "desbarrancar",
    "desbarrancamos": "desbarrancar",
    "desbarrancando": "desbarrancar",
    "desbarrancara": "desbarrancar",
    "desbarrancaram": "desbarrancar",
    "desbarrancaras": "desbarrancar",
    "desbarrancarde": "desbarrancar",
    "desbarrancardes": "desbarrancar",
    "desbarrancare": "desbarrancar",
    "desbarrancarei": "desbarrancar",
    "desbarrancareis": "desbarrancar",
    "desbarrancarem": "desbarrancar",
    "desbarrancaremos": "desbarrancar",
    "desbarrancares": "desbarrancar",
    "desbarrancaria": "desbarrancar",
    "desbarrancariam": "desbarrancar",
    "desbarrancarias": "desbarrancar",
    "desbarrancarmo": "desbarrancar",
    "desbarrancarmos": "desbarrancar",
    "desbarrancará": "desbarrancar",
    "desbarrancarás": "desbarrancar",
    "desbarrancarão": "desbarrancar",
    "desbarrancaríamos": "desbarrancar",
    "desbarrancaríeis": "desbarrancar",
    "desbarrancas": "desbarrancar",
    "desbarrancasse": "desbarrancar",
    "desbarrancassem": "desbarrancar",
    "desbarrancasses": "desbarrancar",
    "desbarrancaste": "desbarrancar",
    "desbarrancastes": "desbarrancar",
    "desbarrancava": "desbarrancar",
    "desbarrancavam": "desbarrancar",
    "desbarrancavas": "desbarrancar",
    "desbarranco": "desbarrancar",
    "desbarrancos": "desbarranco",
    "desbarrancou": "desbarrancar",
    "desbarrancá": "desbarrancar",
    "desbarrancámo": "desbarrancar",
    "desbarrancámos": "desbarrancar",
    "desbarrancáramo": "desbarrancar",
    "desbarrancáramos": "desbarrancar",
    "desbarrancárei": "desbarrancar",
    "desbarrancáreis": "desbarrancar",
    "desbarrancásseis": "desbarrancar",
    "desbarrancássemos": "desbarrancar",
    "desbarrancávamo": "desbarrancar",
    "desbarrancávamos": "desbarrancar",
    "desbarrancávei": "desbarrancar",
    "desbarrancáveis": "desbarrancar",
    "desbarranque": "desbarrancar",
    "desbarranquei": "desbarrancar",
    "desbarranqueis": "desbarrancar",
    "desbarranquem": "desbarrancar",
    "desbarranquemo": "desbarrancar",
    "desbarranquemos": "desbarrancar",
    "desbarranques": "desbarrancar",
    "desbarreta": "desbarretar",
    "desbarretada": "desbarretar",
    "desbarretadas": "desbarretar",
    "desbarretado": "desbarretar",
    "desbarretados": "desbarretar",
    "desbarretai": "desbarretar",
    "desbarretais": "desbarretar",
    "desbarretam": "desbarretar",
    "desbarretamo": "desbarretar",
    "desbarretamos": "desbarretar",
    "desbarretando": "desbarretar",
    "desbarretara": "desbarretar",
    "desbarretaram": "desbarretar",
    "desbarretaras": "desbarretar",
    "desbarretarde": "desbarretar",
    "desbarretardes": "desbarretar",
    "desbarretare": "desbarretar",
    "desbarretarei": "desbarretar",
    "desbarretareis": "desbarretar",
    "desbarretarem": "desbarretar",
    "desbarretaremos": "desbarretar",
    "desbarretares": "desbarretar",
    "desbarretaria": "desbarretar",
    "desbarretariam": "desbarretar",
    "desbarretarias": "desbarretar",
    "desbarretarmo": "desbarretar",
    "desbarretarmos": "desbarretar",
    "desbarretará": "desbarretar",
    "desbarretarás": "desbarretar",
    "desbarretarão": "desbarretar",
    "desbarretaríamos": "desbarretar",
    "desbarretaríeis": "desbarretar",
    "desbarretas": "desbarretar",
    "desbarretasse": "desbarretar",
    "desbarretassem": "desbarretar",
    "desbarretasses": "desbarretar",
    "desbarretaste": "desbarretar",
    "desbarretastes": "desbarretar",
    "desbarretava": "desbarretar",
    "desbarretavam": "desbarretar",
    "desbarretavas": "desbarretar",
    "desbarrete": "desbarretar",
    "desbarretei": "desbarretar",
    "desbarreteis": "desbarretar",
    "desbarretem": "desbarretar",
    "desbarretemo": "desbarretar",
    "desbarretemos": "desbarretar",
    "desbarretes": "desbarretar",
    "desbarreto": "desbarretar",
    "desbarretou": "desbarretar",
    "desbarretá": "desbarretar",
    "desbarretámo": "desbarretar",
    "desbarretámos": "desbarretar",
    "desbarretáramo": "desbarretar",
    "desbarretáramos": "desbarretar",
    "desbarretárei": "desbarretar",
    "desbarretáreis": "desbarretar",
    "desbarretásseis": "desbarretar",
    "desbarretássemos": "desbarretar",
    "desbarretávamo": "desbarretar",
    "desbarretávamos": "desbarretar",
    "desbarretávei": "desbarretar",
    "desbarretáveis": "desbarretar",
    "desbarriga": "desbarrigar",
    "desbarrigada": "desbarrigar",
    "desbarrigadas": "desbarrigar",
    "desbarrigado": "desbarrigar",
    "desbarrigados": "desbarrigar",
    "desbarrigai": "desbarrigar",
    "desbarrigais": "desbarrigar",
    "desbarrigam": "desbarrigar",
    "desbarrigamo": "desbarrigar",
    "desbarrigamos": "desbarrigar",
    "desbarrigando": "desbarrigar",
    "desbarrigara": "desbarrigar",
    "desbarrigaram": "desbarrigar",
    "desbarrigaras": "desbarrigar",
    "desbarrigarde": "desbarrigar",
    "desbarrigardes": "desbarrigar",
    "desbarrigare": "desbarrigar",
    "desbarrigarei": "desbarrigar",
    "desbarrigareis": "desbarrigar",
    "desbarrigarem": "desbarrigar",
    "desbarrigaremos": "desbarrigar",
    "desbarrigares": "desbarrigar",
    "desbarrigaria": "desbarrigar",
    "desbarrigariam": "desbarrigar",
    "desbarrigarias": "desbarrigar",
    "desbarrigarmo": "desbarrigar",
    "desbarrigarmos": "desbarrigar",
    "desbarrigará": "desbarrigar",
    "desbarrigarás": "desbarrigar",
    "desbarrigarão": "desbarrigar",
    "desbarrigaríamos": "desbarrigar",
    "desbarrigaríeis": "desbarrigar",
    "desbarrigas": "desbarrigar",
    "desbarrigasse": "desbarrigar",
    "desbarrigassem": "desbarrigar",
    "desbarrigasses": "desbarrigar",
    "desbarrigaste": "desbarrigar",
    "desbarrigastes": "desbarrigar",
    "desbarrigava": "desbarrigar",
    "desbarrigavam": "desbarrigar",
    "desbarrigavas": "desbarrigar",
    "desbarrigo": "desbarrigar",
    "desbarrigou": "desbarrigar",
    "desbarrigue": "desbarrigar",
    "desbarriguei": "desbarrigar",
    "desbarrigueis": "desbarrigar",
    "desbarriguem": "desbarrigar",
    "desbarriguemo": "desbarrigar",
    "desbarriguemos": "desbarrigar",
    "desbarrigues": "desbarrigar",
    "desbarrigá": "desbarrigar",
    "desbarrigámo": "desbarrigar",
    "desbarrigámos": "desbarrigar",
    "desbarrigáramo": "desbarrigar",
    "desbarrigáramos": "desbarrigar",
    "desbarrigárei": "desbarrigar",
    "desbarrigáreis": "desbarrigar",
    "desbarrigásseis": "desbarrigar",
    "desbarrigássemos": "desbarrigar",
    "desbarrigávamo": "desbarrigar",
    "desbarrigávamos": "desbarrigar",
    "desbarrigávei": "desbarrigar",
    "desbarrigáveis": "desbarrigar",
    "desbasta": "desbastar",
    "desbastada": "desbastar",
    "desbastadas": "desbastar",
    "desbastado": "desbastar",
    "desbastadora": "desbastador",
    "desbastadoras": "desbastador",
    "desbastadores": "desbastador",
    "desbastados": "desbastar",
    "desbastai": "desbastar",
    "desbastais": "desbastar",
    "desbastam": "desbastar",
    "desbastamentos": "desbastamento",
    "desbastamo": "desbastar",
    "desbastamos": "desbastar",
    "desbastando": "desbastar",
    "desbastara": "desbastar",
    "desbastaram": "desbastar",
    "desbastaras": "desbastar",
    "desbastarda": "desbastardar",
    "desbastardada": "desbastardar",
    "desbastardadas": "desbastardar",
    "desbastardado": "desbastardar",
    "desbastardados": "desbastardar",
    "desbastardai": "desbastardar",
    "desbastardais": "desbastardar",
    "desbastardam": "desbastardar",
    "desbastardamo": "desbastardar",
    "desbastardamos": "desbastardar",
    "desbastardando": "desbastardar",
    "desbastardara": "desbastardar",
    "desbastardaram": "desbastardar",
    "desbastardaras": "desbastardar",
    "desbastardarde": "desbastardar",
    "desbastardardes": "desbastardar",
    "desbastardare": "desbastardar",
    "desbastardarei": "desbastardar",
    "desbastardareis": "desbastardar",
    "desbastardarem": "desbastardar",
    "desbastardaremos": "desbastardar",
    "desbastardares": "desbastardar",
    "desbastardaria": "desbastardar",
    "desbastardariam": "desbastardar",
    "desbastardarias": "desbastardar",
    "desbastardarmo": "desbastardar",
    "desbastardarmos": "desbastardar",
    "desbastardará": "desbastardar",
    "desbastardarás": "desbastardar",
    "desbastardarão": "desbastardar",
    "desbastardaríamos": "desbastardar",
    "desbastardaríeis": "desbastardar",
    "desbastardas": "desbastardar",
    "desbastardasse": "desbastardar",
    "desbastardassem": "desbastardar",
    "desbastardasses": "desbastardar",
    "desbastardaste": "desbastardar",
    "desbastardastes": "desbastardar",
    "desbastardava": "desbastardar",
    "desbastardavam": "desbastardar",
    "desbastardavas": "desbastardar",
    "desbastarde": "desbastardar",
    "desbastardei": "desbastardar",
    "desbastardeis": "desbastardar",
    "desbastardem": "desbastardar",
    "desbastardemo": "desbastardar",
    "desbastardemos": "desbastardar",
    "desbastardes": "desbastardar",
    "desbastardo": "desbastardar",
    "desbastardou": "desbastardar",
    "desbastardá": "desbastardar",
    "desbastardámo": "desbastardar",
    "desbastardámos": "desbastardar",
    "desbastardáramo": "desbastardar",
    "desbastardáramos": "desbastardar",
    "desbastardárei": "desbastardar",
    "desbastardáreis": "desbastardar",
    "desbastardásseis": "desbastardar",
    "desbastardássemos": "desbastardar",
    "desbastardávamo": "desbastardar",
    "desbastardávamos": "desbastardar",
    "desbastardávei": "desbastardar",
    "desbastardáveis": "desbastardar",
    "desbastare": "desbastar",
    "desbastarei": "desbastar",
    "desbastareis": "desbastar",
    "desbastarem": "desbastar",
    "desbastaremos": "desbastar",
    "desbastares": "desbastar",
    "desbastaria": "desbastar",
    "desbastariam": "desbastar",
    "desbastarias": "desbastar",
    "desbastarmo": "desbastar",
    "desbastarmos": "desbastar",
    "desbastará": "desbastar",
    "desbastarás": "desbastar",
    "desbastarão": "desbastar",
    "desbastaríamos": "desbastar",
    "desbastaríeis": "desbastar",
    "desbastas": "desbastar",
    "desbastasse": "desbastar",
    "desbastassem": "desbastar",
    "desbastasses": "desbastar",
    "desbastaste": "desbastar",
    "desbastastes": "desbastar",
    "desbastava": "desbastar",
    "desbastavam": "desbastar",
    "desbastavas": "desbastar",
    "desbastações": "desbastação",
    "desbaste": "desbastar",
    "desbastece": "desbastecer",
    "desbastecei": "desbastecer",
    "desbasteceis": "desbastecer",
    "desbastecem": "desbastecer",
    "desbastecemo": "desbastecer",
    "desbastecemos": "desbastecer",
    "desbastecendo": "desbastecer",
    "desbastecera": "desbastecer",
    "desbasteceram": "desbastecer",
    "desbasteceras": "desbastecer",
    "desbastecerde": "desbastecer",
    "desbastecerdes": "desbastecer",
    "desbastecere": "desbastecer",
    "desbastecerei": "desbastecer",
    "desbastecereis": "desbastecer",
    "desbastecerem": "desbastecer",
    "desbasteceremos": "desbastecer",
    "desbasteceres": "desbastecer",
    "desbasteceria": "desbastecer",
    "desbasteceriam": "desbastecer",
    "desbastecerias": "desbastecer",
    "desbastecermo": "desbastecer",
    "desbastecermos": "desbastecer",
    "desbastecerá": "desbastecer",
    "desbastecerás": "desbastecer",
    "desbastecerão": "desbastecer",
    "desbasteceríamos": "desbastecer",
    "desbasteceríeis": "desbastecer",
    "desbasteces": "desbastecer",
    "desbastecesse": "desbastecer",
    "desbastecessem": "desbastecer",
    "desbastecesses": "desbastecer",
    "desbasteceste": "desbastecer",
    "desbastecestes": "desbastecer",
    "desbasteceu": "desbastecer",
    "desbasteci": "desbastecer",
    "desbastecia": "desbastecer",
    "desbasteciam": "desbastecer",
    "desbastecias": "desbastecer",
    "desbastecida": "desbastecido",
    "desbastecidas": "desbastecido",
    "desbastecido": "desbastecer",
    "desbastecidos": "desbastecido",
    "desbastecê": "desbastecer",
    "desbastecêramo": "desbastecer",
    "desbastecêramos": "desbastecer",
    "desbastecêrei": "desbastecer",
    "desbastecêreis": "desbastecer",
    "desbastecêsseis": "desbastecer",
    "desbastecêssemos": "desbastecer",
    "desbastecíamo": "desbastecer",
    "desbastecíamos": "desbastecer",
    "desbastecíei": "desbastecer",
    "desbastecíeis": "desbastecer",
    "desbastei": "desbastar",
    "desbasteis": "desbastar",
    "desbastem": "desbastar",
    "desbastemo": "desbastar",
    "desbastemos": "desbastar",
    "desbastes": "desbaste",
    "desbasteça": "desbastecer",
    "desbasteçais": "desbastecer",
    "desbasteçam": "desbastecer",
    "desbasteçamo": "desbastecer",
    "desbasteçamos": "desbastecer",
    "desbasteças": "desbastecer",
    "desbasteço": "desbastecer",
    "desbasto": "desbastar",
    "desbastou": "desbastar",
    "desbastá": "desbastar",
    "desbastámo": "desbastar",
    "desbastámos": "desbastar",
    "desbastáramo": "desbastar",
    "desbastáramos": "desbastar",
    "desbastárei": "desbastar",
    "desbastáreis": "desbastar",
    "desbastásseis": "desbastar",
    "desbastássemos": "desbastar",
    "desbastávamo": "desbastar",
    "desbastávamos": "desbastar",
    "desbastávei": "desbastar",
    "desbastáveis": "desbastar",
    "desbatoca": "desbatocar",
    "desbatocada": "desbatocar",
    "desbatocadas": "desbatocar",
    "desbatocado": "desbatocar",
    "desbatocados": "desbatocar",
    "desbatocai": "desbatocar",
    "desbatocais": "desbatocar",
    "desbatocam": "desbatocar",
    "desbatocamo": "desbatocar",
    "desbatocamos": "desbatocar",
    "desbatocando": "desbatocar",
    "desbatocara": "desbatocar",
    "desbatocaram": "desbatocar",
    "desbatocaras": "desbatocar",
    "desbatocarde": "desbatocar",
    "desbatocardes": "desbatocar",
    "desbatocare": "desbatocar",
    "desbatocarei": "desbatocar",
    "desbatocareis": "desbatocar",
    "desbatocarem": "desbatocar",
    "desbatocaremos": "desbatocar",
    "desbatocares": "desbatocar",
    "desbatocaria": "desbatocar",
    "desbatocariam": "desbatocar",
    "desbatocarias": "desbatocar",
    "desbatocarmo": "desbatocar",
    "desbatocarmos": "desbatocar",
    "desbatocará": "desbatocar",
    "desbatocarás": "desbatocar",
    "desbatocarão": "desbatocar",
    "desbatocaríamos": "desbatocar",
    "desbatocaríeis": "desbatocar",
    "desbatocas": "desbatocar",
    "desbatocasse": "desbatocar",
    "desbatocassem": "desbatocar",
    "desbatocasses": "desbatocar",
    "desbatocaste": "desbatocar",
    "desbatocastes": "desbatocar",
    "desbatocava": "desbatocar",
    "desbatocavam": "desbatocar",
    "desbatocavas": "desbatocar",
    "desbatoco": "desbatocar",
    "desbatocou": "desbatocar",
    "desbatocá": "desbatocar",
    "desbatocámo": "desbatocar",
    "desbatocámos": "desbatocar",
    "desbatocáramo": "desbatocar",
    "desbatocáramos": "desbatocar",
    "desbatocárei": "desbatocar",
    "desbatocáreis": "desbatocar",
    "desbatocásseis": "desbatocar",
    "desbatocássemos": "desbatocar",
    "desbatocávamo": "desbatocar",
    "desbatocávamos": "desbatocar",
    "desbatocávei": "desbatocar",
    "desbatocáveis": "desbatocar",
    "desbatoque": "desbatocar",
    "desbatoquei": "desbatocar",
    "desbatoqueis": "desbatocar",
    "desbatoquem": "desbatocar",
    "desbatoquemo": "desbatocar",
    "desbatoquemos": "desbatocar",
    "desbatoques": "desbatocar",
    "desbeiçada": "desbeiçado",
    "desbeiçadas": "desbeiçado",
    "desbeiçados": "desbeiçado",
    "desbica": "desbicar",
    "desbicada": "desbicar",
    "desbicadas": "desbicar",
    "desbicado": "desbicar",
    "desbicados": "desbicar",
    "desbicai": "desbicar",
    "desbicais": "desbicar",
    "desbicam": "desbicar",
    "desbicamo": "desbicar",
    "desbicamos": "desbicar",
    "desbicando": "desbicar",
    "desbicara": "desbicar",
    "desbicaram": "desbicar",
    "desbicaras": "desbicar",
    "desbicarde": "desbicar",
    "desbicardes": "desbicar",
    "desbicare": "desbicar",
    "desbicarei": "desbicar",
    "desbicareis": "desbicar",
    "desbicarem": "desbicar",
    "desbicaremos": "desbicar",
    "desbicares": "desbicar",
    "desbicaria": "desbicar",
    "desbicariam": "desbicar",
    "desbicarias": "desbicar",
    "desbicarmo": "desbicar",
    "desbicarmos": "desbicar",
    "desbicará": "desbicar",
    "desbicarás": "desbicar",
    "desbicarão": "desbicar",
    "desbicaríamos": "desbicar",
    "desbicaríeis": "desbicar",
    "desbicas": "desbicar",
    "desbicasse": "desbicar",
    "desbicassem": "desbicar",
    "desbicasses": "desbicar",
    "desbicaste": "desbicar",
    "desbicastes": "desbicar",
    "desbicava": "desbicar",
    "desbicavam": "desbicar",
    "desbicavas": "desbicar",
    "desbico": "desbicar",
    "desbicou": "desbicar",
    "desbicá": "desbicar",
    "desbicámo": "desbicar",
    "desbicámos": "desbicar",
    "desbicáramo": "desbicar",
    "desbicáramos": "desbicar",
    "desbicárei": "desbicar",
    "desbicáreis": "desbicar",
    "desbicásseis": "desbicar",
    "desbicássemos": "desbicar",
    "desbicávamo": "desbicar",
    "desbicávamos": "desbicar",
    "desbicávei": "desbicar",
    "desbicáveis": "desbicar",
    "desbique": "desbicar",
    "desbiquei": "desbicar",
    "desbiqueis": "desbicar",
    "desbiquem": "desbicar",
    "desbiquemo": "desbicar",
    "desbiquemos": "desbicar",
    "desbiques": "desbicar",
    "desbloqueada": "desbloquear",
    "desbloqueadas": "desbloquear",
    "desbloqueado": "desbloquear",
    "desbloqueados": "desbloquear",
    "desbloqueai": "desbloquear",
    "desbloqueais": "desbloquear",
    "desbloqueamentos": "desbloqueamento",
    "desbloqueamo": "desbloquear",
    "desbloqueamos": "desbloquear",
    "desbloqueando": "desbloquear",
    "desbloqueara": "desbloquear",
    "desbloquearam": "desbloquear",
    "desbloquearas": "desbloquear",
    "desbloquearde": "desbloquear",
    "desbloqueardes": "desbloquear",
    "desbloqueare": "desbloquear",
    "desbloquearei": "desbloquear",
    "desbloqueareis": "desbloquear",
    "desbloquearem": "desbloquear",
    "desbloquearemos": "desbloquear",
    "desbloqueares": "desbloquear",
    "desbloquearia": "desbloquear",
    "desbloqueariam": "desbloquear",
    "desbloquearias": "desbloquear",
    "desbloquearmo": "desbloquear",
    "desbloquearmos": "desbloquear",
    "desbloqueará": "desbloquear",
    "desbloquearás": "desbloquear",
    "desbloquearão": "desbloquear",
    "desbloquearíamos": "desbloquear",
    "desbloquearíeis": "desbloquear",
    "desbloqueasse": "desbloquear",
    "desbloqueassem": "desbloquear",
    "desbloqueasses": "desbloquear",
    "desbloqueaste": "desbloquear",
    "desbloqueastes": "desbloquear",
    "desbloqueava": "desbloquear",
    "desbloqueavam": "desbloquear",
    "desbloqueavas": "desbloquear",
    "desbloqueei": "desbloquear",
    "desbloqueeis": "desbloquear",
    "desbloqueemo": "desbloquear",
    "desbloqueemos": "desbloquear",
    "desbloqueia": "desbloquear",
    "desbloqueiam": "desbloquear",
    "desbloqueias": "desbloquear",
    "desbloqueie": "desbloquear",
    "desbloqueiem": "desbloquear",
    "desbloqueies": "desbloquear",
    "desbloqueio": "desbloquear",
    "desbloqueios": "desbloqueio",
    "desbloqueou": "desbloquear",
    "desbloqueá": "desbloquear",
    "desbloqueámo": "desbloquear",
    "desbloqueámos": "desbloquear",
    "desbloqueáramo": "desbloquear",
    "desbloqueáramos": "desbloquear",
    "desbloqueárei": "desbloquear",
    "desbloqueáreis": "desbloquear",
    "desbloqueásseis": "desbloquear",
    "desbloqueássemos": "desbloquear",
    "desbloqueávamo": "desbloquear",
    "desbloqueávamos": "desbloquear",
    "desbloqueávei": "desbloquear",
    "desbloqueáveis": "desbloqueável",
    "desbocada": "desbocado",
    "desbocadas": "desbocado",
    "desbocados": "desbocado",
    "desbocamentos": "desbocamento",
    "desbolada": "desbolado",
    "desboladas": "desbolado",
    "desbolados": "desbolado",
    "desbolina": "desbolinar",
    "desbolinada": "desbolinar",
    "desbolinadas": "desbolinar",
    "desbolinado": "desbolinar",
    "desbolinados": "desbolinar",
    "desbolinai": "desbolinar",
    "desbolinais": "desbolinar",
    "desbolinam": "desbolinar",
    "desbolinamo": "desbolinar",
    "desbolinamos": "desbolinar",
    "desbolinando": "desbolinar",
    "desbolinara": "desbolinar",
    "desbolinaram": "desbolinar",
    "desbolinaras": "desbolinar",
    "desbolinarde": "desbolinar",
    "desbolinardes": "desbolinar",
    "desbolinare": "desbolinar",
    "desbolinarei": "desbolinar",
    "desbolinareis": "desbolinar",
    "desbolinarem": "desbolinar",
    "desbolinaremos": "desbolinar",
    "desbolinares": "desbolinar",
    "desbolinaria": "desbolinar",
    "desbolinariam": "desbolinar",
    "desbolinarias": "desbolinar",
    "desbolinarmo": "desbolinar",
    "desbolinarmos": "desbolinar",
    "desbolinará": "desbolinar",
    "desbolinarás": "desbolinar",
    "desbolinarão": "desbolinar",
    "desbolinaríamos": "desbolinar",
    "desbolinaríeis": "desbolinar",
    "desbolinas": "desbolinar",
    "desbolinasse": "desbolinar",
    "desbolinassem": "desbolinar",
    "desbolinasses": "desbolinar",
    "desbolinaste": "desbolinar",
    "desbolinastes": "desbolinar",
    "desbolinava": "desbolinar",
    "desbolinavam": "desbolinar",
    "desbolinavas": "desbolinar",
    "desboline": "desbolinar",
    "desbolinei": "desbolinar",
    "desbolineis": "desbolinar",
    "desbolinem": "desbolinar",
    "desbolinemo": "desbolinar",
    "desbolinemos": "desbolinar",
    "desbolines": "desbolinar",
    "desbolino": "desbolinar",
    "desbolinou": "desbolinar",
    "desboliná": "desbolinar",
    "desbolinámo": "desbolinar",
    "desbolinámos": "desbolinar",
    "desbolináramo": "desbolinar",
    "desbolináramos": "desbolinar",
    "desbolinárei": "desbolinar",
    "desbolináreis": "desbolinar",
    "desbolinásseis": "desbolinar",
    "desbolinássemos": "desbolinar",
    "desbolinávamo": "desbolinar",
    "desbolinávamos": "desbolinar",
    "desbolinávei": "desbolinar",
    "desbolináveis": "desbolinar",
    "desborca": "desborcar",
    "desborcada": "desborcar",
    "desborcadas": "desborcar",
    "desborcado": "desborcar",
    "desborcados": "desborcar",
    "desborcai": "desborcar",
    "desborcais": "desborcar",
    "desborcam": "desborcar",
    "desborcamo": "desborcar",
    "desborcamos": "desborcar",
    "desborcando": "desborcar",
    "desborcara": "desborcar",
    "desborcaram": "desborcar",
    "desborcaras": "desborcar",
    "desborcarde": "desborcar",
    "desborcardes": "desborcar",
    "desborcare": "desborcar",
    "desborcarei": "desborcar",
    "desborcareis": "desborcar",
    "desborcarem": "desborcar",
    "desborcaremos": "desborcar",
    "desborcares": "desborcar",
    "desborcaria": "desborcar",
    "desborcariam": "desborcar",
    "desborcarias": "desborcar",
    "desborcarmo": "desborcar",
    "desborcarmos": "desborcar",
    "desborcará": "desborcar",
    "desborcarás": "desborcar",
    "desborcarão": "desborcar",
    "desborcaríamos": "desborcar",
    "desborcaríeis": "desborcar",
    "desborcas": "desborcar",
    "desborcasse": "desborcar",
    "desborcassem": "desborcar",
    "desborcasses": "desborcar",
    "desborcaste": "desborcar",
    "desborcastes": "desborcar",
    "desborcava": "desborcar",
    "desborcavam": "desborcar",
    "desborcavas": "desborcar",
    "desborco": "desborcar",
    "desborcou": "desborcar",
    "desborcá": "desborcar",
    "desborcámo": "desborcar",
    "desborcámos": "desborcar",
    "desborcáramo": "desborcar",
    "desborcáramos": "desborcar",
    "desborcárei": "desborcar",
    "desborcáreis": "desborcar",
    "desborcásseis": "desborcar",
    "desborcássemos": "desborcar",
    "desborcávamo": "desborcar",
    "desborcávamos": "desborcar",
    "desborcávei": "desborcar",
    "desborcáveis": "desborcar",
    "desborda": "desbordar",
    "desbordada": "desbordar",
    "desbordadas": "desbordar",
    "desbordado": "desbordar",
    "desbordados": "desbordar",
    "desbordai": "desbordar",
    "desbordais": "desbordar",
    "desbordam": "desbordar",
    "desbordamentos": "desbordamento",
    "desbordamo": "desbordar",
    "desbordamos": "desbordar",
    "desbordando": "desbordar",
    "desbordantes": "desbordante",
    "desbordara": "desbordar",
    "desbordaram": "desbordar",
    "desbordaras": "desbordar",
    "desbordardes": "desbordar",
    "desbordarei": "desbordar",
    "desbordareis": "desbordar",
    "desbordarem": "desbordar",
    "desbordaremos": "desbordar",
    "desbordares": "desbordar",
    "desbordaria": "desbordar",
    "desbordariam": "desbordar",
    "desbordarias": "desbordar",
    "desbordarmo": "desbordar",
    "desbordarmos": "desbordar",
    "desbordará": "desbordar",
    "desbordarás": "desbordar",
    "desbordarão": "desbordar",
    "desbordaríamos": "desbordar",
    "desbordaríeis": "desbordar",
    "desbordas": "desbordar",
    "desbordasse": "desbordar",
    "desbordassem": "desbordar",
    "desbordasses": "desbordar",
    "desbordaste": "desbordar",
    "desbordastes": "desbordar",
    "desbordava": "desbordar",
    "desbordavam": "desbordar",
    "desbordavas": "desbordar",
    "desborde": "desbordar",
    "desbordei": "desbordar",
    "desbordeis": "desbordar",
    "desbordem": "desbordar",
    "desbordemo": "desbordar",
    "desbordemos": "desbordar",
    "desbordes": "desbordar",
    "desbordo": "desbordar",
    "desbordos": "desbordo",
    "desbordou": "desbordar",
    "desbordámo": "desbordar",
    "desbordámos": "desbordar",
    "desbordáramo": "desbordar",
    "desbordáramos": "desbordar",
    "desbordáreis": "desbordar",
    "desbordásseis": "desbordar",
    "desbordássemos": "desbordar",
    "desbordávamo": "desbordar",
    "desbordávamos": "desbordar",
    "desbordáveis": "desbordar",
    "desboroa": "desboroar",
    "desboroada": "desboroar",
    "desboroadas": "desboroar",
    "desboroado": "desboroar",
    "desboroados": "desboroar",
    "desboroai": "desboroar",
    "desboroais": "desboroar",
    "desboroam": "desboroar",
    "desboroamo": "desboroar",
    "desboroamos": "desboroar",
    "desboroando": "desboroar",
    "desboroara": "desboroar",
    "desboroaram": "desboroar",
    "desboroaras": "desboroar",
    "desboroarde": "desboroar",
    "desboroardes": "desboroar",
    "desboroare": "desboroar",
    "desboroarei": "desboroar",
    "desboroareis": "desboroar",
    "desboroarem": "desboroar",
    "desboroaremos": "desboroar",
    "desboroares": "desboroar",
    "desboroaria": "desboroar",
    "desboroariam": "desboroar",
    "desboroarias": "desboroar",
    "desboroarmo": "desboroar",
    "desboroarmos": "desboroar",
    "desboroará": "desboroar",
    "desboroarás": "desboroar",
    "desboroarão": "desboroar",
    "desboroaríamos": "desboroar",
    "desboroaríeis": "desboroar",
    "desboroas": "desboroar",
    "desboroasse": "desboroar",
    "desboroassem": "desboroar",
    "desboroasses": "desboroar",
    "desboroaste": "desboroar",
    "desboroastes": "desboroar",
    "desboroava": "desboroar",
    "desboroavam": "desboroar",
    "desboroavas": "desboroar",
    "desboroe": "desboroar",
    "desboroei": "desboroar",
    "desboroeis": "desboroar",
    "desboroem": "desboroar",
    "desboroemo": "desboroar",
    "desboroemos": "desboroar",
    "desboroes": "desboroar",
    "desboroo": "desboroar",
    "desboroou": "desboroar",
    "desboroá": "desboroar",
    "desboroámo": "desboroar",
    "desboroámos": "desboroar",
    "desboroáramo": "desboroar",
    "desboroáramos": "desboroar",
    "desboroárei": "desboroar",
    "desboroáreis": "desboroar",
    "desboroásseis": "desboroar",
    "desboroássemos": "desboroar",
    "desboroávamo": "desboroar",
    "desboroávamos": "desboroar",
    "desboroávei": "desboroar",
    "desboroáveis": "desboroar",
    "desborque": "desborcar",
    "desborquei": "desborcar",
    "desborqueis": "desborcar",
    "desborquem": "desborcar",
    "desborquemo": "desborcar",
    "desborquemos": "desborcar",
    "desborques": "desborcar",
    "desbota": "desbotar",
    "desbotada": "desbotar",
    "desbotadas": "desbotar",
    "desbotado": "desbotar",
    "desbotados": "desbotar",
    "desbotaduras": "desbotadura",
    "desbotai": "desbotar",
    "desbotais": "desbotar",
    "desbotam": "desbotar",
    "desbotamentos": "desbotamento",
    "desbotamo": "desbotar",
    "desbotamos": "desbotar",
    "desbotando": "desbotar",
    "desbotara": "desbotar",
    "desbotaram": "desbotar",
    "desbotaras": "desbotar",
    "desbotarde": "desbotar",
    "desbotardes": "desbotar",
    "desbotare": "desbotar",
    "desbotarei": "desbotar",
    "desbotareis": "desbotar",
    "desbotarem": "desbotar",
    "desbotaremos": "desbotar",
    "desbotares": "desbotar",
    "desbotaria": "desbotar",
    "desbotariam": "desbotar",
    "desbotarias": "desbotar",
    "desbotarmo": "desbotar",
    "desbotarmos": "desbotar",
    "desbotará": "desbotar",
    "desbotarás": "desbotar",
    "desbotarão": "desbotar",
    "desbotaríamos": "desbotar",
    "desbotaríeis": "desbotar",
    "desbotas": "desbotar",
    "desbotasse": "desbotar",
    "desbotassem": "desbotar",
    "desbotasses": "desbotar",
    "desbotaste": "desbotar",
    "desbotastes": "desbotar",
    "desbotava": "desbotar",
    "desbotavam": "desbotar",
    "desbotavas": "desbotar",
    "desbote": "desbotar",
    "desbotei": "desbotar",
    "desboteis": "desbotar",
    "desbotem": "desbotar",
    "desbotemo": "desbotar",
    "desbotemos": "desbotar",
    "desbotes": "desbote",
    "desboto": "desbotar",
    "desbotoa": "desbotoar",
    "desbotoada": "desbotoar",
    "desbotoadas": "desbotoar",
    "desbotoado": "desbotoar",
    "desbotoados": "desbotoar",
    "desbotoai": "desbotoar",
    "desbotoais": "desbotoar",
    "desbotoam": "desbotoar",
    "desbotoamo": "desbotoar",
    "desbotoamos": "desbotoar",
    "desbotoando": "desbotoar",
    "desbotoara": "desbotoar",
    "desbotoaram": "desbotoar",
    "desbotoaras": "desbotoar",
    "desbotoarde": "desbotoar",
    "desbotoardes": "desbotoar",
    "desbotoare": "desbotoar",
    "desbotoarei": "desbotoar",
    "desbotoareis": "desbotoar",
    "desbotoarem": "desbotoar",
    "desbotoaremos": "desbotoar",
    "desbotoares": "desbotoar",
    "desbotoaria": "desbotoar",
    "desbotoariam": "desbotoar",
    "desbotoarias": "desbotoar",
    "desbotoarmo": "desbotoar",
    "desbotoarmos": "desbotoar",
    "desbotoará": "desbotoar",
    "desbotoarás": "desbotoar",
    "desbotoarão": "desbotoar",
    "desbotoaríamos": "desbotoar",
    "desbotoaríeis": "desbotoar",
    "desbotoas": "desbotoar",
    "desbotoasse": "desbotoar",
    "desbotoassem": "desbotoar",
    "desbotoasses": "desbotoar",
    "desbotoaste": "desbotoar",
    "desbotoastes": "desbotoar",
    "desbotoava": "desbotoar",
    "desbotoavam": "desbotoar",
    "desbotoavas": "desbotoar",
    "desbotoe": "desbotoar",
    "desbotoei": "desbotoar",
    "desbotoeis": "desbotoar",
    "desbotoem": "desbotoar",
    "desbotoemo": "desbotoar",
    "desbotoemos": "desbotoar",
    "desbotoes": "desbotoar",
    "desbotoo": "desbotoar",
    "desbotoou": "desbotoar",
    "desbotou": "desbotar",
    "desbotoá": "desbotoar",
    "desbotoámo": "desbotoar",
    "desbotoámos": "desbotoar",
    "desbotoáramo": "desbotoar",
    "desbotoáramos": "desbotoar",
    "desbotoárei": "desbotoar",
    "desbotoáreis": "desbotoar",
    "desbotoásseis": "desbotoar",
    "desbotoássemos": "desbotoar",
    "desbotoávamo": "desbotoar",
    "desbotoávamos": "desbotoar",
    "desbotoávei": "desbotoar",
    "desbotoáveis": "desbotoar",
    "desbotá": "desbotar",
    "desbotámo": "desbotar",
    "desbotámos": "desbotar",
    "desbotáramo": "desbotar",
    "desbotáramos": "desbotar",
    "desbotárei": "desbotar",
    "desbotáreis": "desbotar",
    "desbotásseis": "desbotar",
    "desbotássemos": "desbotar",
    "desbotávamo": "desbotar",
    "desbotávamos": "desbotar",
    "desbotávei": "desbotar",
    "desbotáveis": "desbotar",
    "desbraga": "desbragar",
    "desbragada": "desbragar",
    "desbragadas": "desbragar",
    "desbragado": "desbragar",
    "desbragados": "desbragar",
    "desbragadíssima": "desbragado",
    "desbragadíssimas": "desbragado",
    "desbragadíssimo": "desbragado",
    "desbragadíssimos": "desbragado",
    "desbragai": "desbragar",
    "desbragais": "desbragar",
    "desbragam": "desbragar",
    "desbragamentos": "desbragamento",
    "desbragamo": "desbragar",
    "desbragamos": "desbragar",
    "desbragando": "desbragar",
    "desbragara": "desbragar",
    "desbragaram": "desbragar",
    "desbragaras": "desbragar",
    "desbragarde": "desbragar",
    "desbragardes": "desbragar",
    "desbragare": "desbragar",
    "desbragarei": "desbragar",
    "desbragareis": "desbragar",
    "desbragarem": "desbragar",
    "desbragaremos": "desbragar",
    "desbragares": "desbragar",
    "desbragaria": "desbragar",
    "desbragariam": "desbragar",
    "desbragarias": "desbragar",
    "desbragarmo": "desbragar",
    "desbragarmos": "desbragar",
    "desbragará": "desbragar",
    "desbragarás": "desbragar",
    "desbragarão": "desbragar",
    "desbragaríamos": "desbragar",
    "desbragaríeis": "desbragar",
    "desbragas": "desbragar",
    "desbragasse": "desbragar",
    "desbragassem": "desbragar",
    "desbragasses": "desbragar",
    "desbragaste": "desbragar",
    "desbragastes": "desbragar",
    "desbragava": "desbragar",
    "desbragavam": "desbragar",
    "desbragavas": "desbragar",
    "desbrago": "desbragar",
    "desbragou": "desbragar",
    "desbrague": "desbragar",
    "desbraguei": "desbragar",
    "desbragueis": "desbragar",
    "desbraguem": "desbragar",
    "desbraguemo": "desbragar",
    "desbraguemos": "desbragar",
    "desbragues": "desbragar",
    "desbragá": "desbragar",
    "desbragámo": "desbragar",
    "desbragámos": "desbragar",
    "desbragáramo": "desbragar",
    "desbragáramos": "desbragar",
    "desbragárei": "desbragar",
    "desbragáreis": "desbragar",
    "desbragásseis": "desbragar",
    "desbragássemos": "desbragar",
    "desbragávamo": "desbragar",
    "desbragávamos": "desbragar",
    "desbragávei": "desbragar",
    "desbragáveis": "desbragar",
    "desbrasileira": "desbrasileirar",
    "desbrasileirada": "desbrasileirar",
    "desbrasileiradas": "desbrasileirar",
    "desbrasileirado": "desbrasileirar",
    "desbrasileirados": "desbrasileirar",
    "desbrasileirai": "desbrasileirar",
    "desbrasileirais": "desbrasileirar",
    "desbrasileiram": "desbrasileirar",
    "desbrasileiramo": "desbrasileirar",
    "desbrasileiramos": "desbrasileirar",
    "desbrasileirando": "desbrasileirar",
    "desbrasileirara": "desbrasileirar",
    "desbrasileiraram": "desbrasileirar",
    "desbrasileiraras": "desbrasileirar",
    "desbrasileirarde": "desbrasileirar",
    "desbrasileirardes": "desbrasileirar",
    "desbrasileirare": "desbrasileirar",
    "desbrasileirarei": "desbrasileirar",
    "desbrasileirareis": "desbrasileirar",
    "desbrasileirarem": "desbrasileirar",
    "desbrasileiraremos": "desbrasileirar",
    "desbrasileirares": "desbrasileirar",
    "desbrasileiraria": "desbrasileirar",
    "desbrasileirariam": "desbrasileirar",
    "desbrasileirarias": "desbrasileirar",
    "desbrasileirarmo": "desbrasileirar",
    "desbrasileirarmos": "desbrasileirar",
    "desbrasileirará": "desbrasileirar",
    "desbrasileirarás": "desbrasileirar",
    "desbrasileirarão": "desbrasileirar",
    "desbrasileiraríamos": "desbrasileirar",
    "desbrasileiraríeis": "desbrasileirar",
    "desbrasileiras": "desbrasileirar",
    "desbrasileirasse": "desbrasileirar",
    "desbrasileirassem": "desbrasileirar",
    "desbrasileirasses": "desbrasileirar",
    "desbrasileiraste": "desbrasileirar",
    "desbrasileirastes": "desbrasileirar",
    "desbrasileirava": "desbrasileirar",
    "desbrasileiravam": "desbrasileirar",
    "desbrasileiravas": "desbrasileirar",
    "desbrasileire": "desbrasileirar",
    "desbrasileirei": "desbrasileirar",
    "desbrasileireis": "desbrasileirar",
    "desbrasileirem": "desbrasileirar",
    "desbrasileiremo": "desbrasileirar",
    "desbrasileiremos": "desbrasileirar",
    "desbrasileires": "desbrasileirar",
    "desbrasileiro": "desbrasileirar",
    "desbrasileirou": "desbrasileirar",
    "desbrasileirá": "desbrasileirar",
    "desbrasileirámo": "desbrasileirar",
    "desbrasileirámos": "desbrasileirar",
    "desbrasileiráramo": "desbrasileirar",
    "desbrasileiráramos": "desbrasileirar",
    "desbrasileirárei": "desbrasileirar",
    "desbrasileiráreis": "desbrasileirar",
    "desbrasileirásseis": "desbrasileirar",
    "desbrasileirássemos": "desbrasileirar",
    "desbrasileirávamo": "desbrasileirar",
    "desbrasileirávamos": "desbrasileirar",
    "desbrasileirávei": "desbrasileirar",
    "desbrasileiráveis": "desbrasileirar",
    "desbrava": "desbravar",
    "desbravada": "desbravar",
    "desbravadas": "desbravar",
    "desbravado": "desbravar",
    "desbravadora": "desbravador",
    "desbravadoras": "desbravador",
    "desbravadores": "desbravador",
    "desbravados": "desbravar",
    "desbravai": "desbravar",
    "desbravais": "desbravar",
    "desbravam": "desbravar",
    "desbravamentos": "desbravamento",
    "desbravamo": "desbravar",
    "desbravamos": "desbravar",
    "desbravando": "desbravar",
    "desbravara": "desbravar",
    "desbravaram": "desbravar",
    "desbravaras": "desbravar",
    "desbravarde": "desbravar",
    "desbravardes": "desbravar",
    "desbravare": "desbravar",
    "desbravarei": "desbravar",
    "desbravareis": "desbravar",
    "desbravarem": "desbravar",
    "desbravaremos": "desbravar",
    "desbravares": "desbravar",
    "desbravaria": "desbravar",
    "desbravariam": "desbravar",
    "desbravarias": "desbravar",
    "desbravarmo": "desbravar",
    "desbravarmos": "desbravar",
    "desbravará": "desbravar",
    "desbravarás": "desbravar",
    "desbravarão": "desbravar",
    "desbravaríamos": "desbravar",
    "desbravaríeis": "desbravar",
    "desbravas": "desbravar",
    "desbravasse": "desbravar",
    "desbravassem": "desbravar",
    "desbravasses": "desbravar",
    "desbravaste": "desbravar",
    "desbravastes": "desbravar",
    "desbravava": "desbravar",
    "desbravavam": "desbravar",
    "desbravavas": "desbravar",
    "desbrave": "desbravar",
    "desbravei": "desbravar",
    "desbraveis": "desbravar",
    "desbravem": "desbravar",
    "desbravemo": "desbravar",
    "desbravemos": "desbravar",
    "desbraves": "desbravar",
    "desbravo": "desbravar",
    "desbravou": "desbravar",
    "desbravá": "desbravar",
    "desbravámo": "desbravar",
    "desbravámos": "desbravar",
    "desbraváramo": "desbravar",
    "desbraváramos": "desbravar",
    "desbravárei": "desbravar",
    "desbraváreis": "desbravar",
    "desbravásseis": "desbravar",
    "desbravássemos": "desbravar",
    "desbravávamo": "desbravar",
    "desbravávamos": "desbravar",
    "desbravávei": "desbravar",
    "desbraváveis": "desbravar",
    "desbria": "desbriar",
    "desbriada": "desbriar",
    "desbriadas": "desbriar",
    "desbriado": "desbriar",
    "desbriados": "desbriar",
    "desbriai": "desbriar",
    "desbriais": "desbriar",
    "desbriam": "desbriar",
    "desbriamentos": "desbriamento",
    "desbriamo": "desbriar",
    "desbriamos": "desbriar",
    "desbriando": "desbriar",
    "desbriara": "desbriar",
    "desbriaram": "desbriar",
    "desbriaras": "desbriar",
    "desbriarde": "desbriar",
    "desbriardes": "desbriar",
    "desbriare": "desbriar",
    "desbriarei": "desbriar",
    "desbriareis": "desbriar",
    "desbriarem": "desbriar",
    "desbriaremos": "desbriar",
    "desbriares": "desbriar",
    "desbriaria": "desbriar",
    "desbriariam": "desbriar",
    "desbriarias": "desbriar",
    "desbriarmo": "desbriar",
    "desbriarmos": "desbriar",
    "desbriará": "desbriar",
    "desbriarás": "desbriar",
    "desbriarão": "desbriar",
    "desbriaríamos": "desbriar",
    "desbriaríeis": "desbriar",
    "desbrias": "desbriar",
    "desbriasse": "desbriar",
    "desbriassem": "desbriar",
    "desbriasses": "desbriar",
    "desbriaste": "desbriar",
    "desbriastes": "desbriar",
    "desbriava": "desbriar",
    "desbriavam": "desbriar",
    "desbriavas": "desbriar",
    "desbrida": "desbridar",
    "desbridada": "desbridar",
    "desbridadas": "desbridar",
    "desbridado": "desbridar",
    "desbridados": "desbridar",
    "desbridai": "desbridar",
    "desbridais": "desbridar",
    "desbridam": "desbridar",
    "desbridamentos": "desbridamento",
    "desbridamo": "desbridar",
    "desbridamos": "desbridar",
    "desbridando": "desbridar",
    "desbridara": "desbridar",
    "desbridaram": "desbridar",
    "desbridaras": "desbridar",
    "desbridarde": "desbridar",
    "desbridardes": "desbridar",
    "desbridare": "desbridar",
    "desbridarei": "desbridar",
    "desbridareis": "desbridar",
    "desbridarem": "desbridar",
    "desbridaremos": "desbridar",
    "desbridares": "desbridar",
    "desbridaria": "desbridar",
    "desbridariam": "desbridar",
    "desbridarias": "desbridar",
    "desbridarmo": "desbridar",
    "desbridarmos": "desbridar",
    "desbridará": "desbridar",
    "desbridarás": "desbridar",
    "desbridarão": "desbridar",
    "desbridaríamos": "desbridar",
    "desbridaríeis": "desbridar",
    "desbridas": "desbridar",
    "desbridasse": "desbridar",
    "desbridassem": "desbridar",
    "desbridasses": "desbridar",
    "desbridaste": "desbridar",
    "desbridastes": "desbridar",
    "desbridava": "desbridar",
    "desbridavam": "desbridar",
    "desbridavas": "desbridar",
    "desbridações": "desbridação",
    "desbride": "desbridar",
    "desbridei": "desbridar",
    "desbrideis": "desbridar",
    "desbridem": "desbridar",
    "desbridemo": "desbridar",
    "desbridemos": "desbridar",
    "desbrides": "desbridar",
    "desbrido": "desbridar",
    "desbridou": "desbridar",
    "desbridá": "desbridar",
    "desbridámo": "desbridar",
    "desbridámos": "desbridar",
    "desbridáramo": "desbridar",
    "desbridáramos": "desbridar",
    "desbridárei": "desbridar",
    "desbridáreis": "desbridar",
    "desbridásseis": "desbridar",
    "desbridássemos": "desbridar",
    "desbridávamo": "desbridar",
    "desbridávamos": "desbridar",
    "desbridávei": "desbridar",
    "desbridáveis": "desbridar",
    "desbrie": "desbriar",
    "desbriei": "desbriar",
    "desbrieis": "desbriar",
    "desbriem": "desbriar",
    "desbriemo": "desbriar",
    "desbriemos": "desbriar",
    "desbries": "desbriar",
    "desbrilhos": "desbrilho",
    "desbrio": "desbriar",
    "desbrios": "desbrio",
    "desbriosa": "desbrioso",
    "desbriosas": "desbrioso",
    "desbriosos": "desbrioso",
    "desbriou": "desbriar",
    "desbriá": "desbriar",
    "desbriámo": "desbriar",
    "desbriámos": "desbriar",
    "desbriáramo": "desbriar",
    "desbriáramos": "desbriar",
    "desbriárei": "desbriar",
    "desbriáreis": "desbriar",
    "desbriásseis": "desbriar",
    "desbriássemos": "desbriar",
    "desbriávamo": "desbriar",
    "desbriávamos": "desbriar",
    "desbriávei": "desbriar",
    "desbriáveis": "desbriar",
    "desbulha": "desbulhar",
    "desbulhada": "desbulhar",
    "desbulhadas": "desbulhar",
    "desbulhado": "desbulhar",
    "desbulhados": "desbulhar",
    "desbulhai": "desbulhar",
    "desbulhais": "desbulhar",
    "desbulham": "desbulhar",
    "desbulhamo": "desbulhar",
    "desbulhamos": "desbulhar",
    "desbulhando": "desbulhar",
    "desbulhara": "desbulhar",
    "desbulharam": "desbulhar",
    "desbulharas": "desbulhar",
    "desbulharde": "desbulhar",
    "desbulhardes": "desbulhar",
    "desbulhare": "desbulhar",
    "desbulharei": "desbulhar",
    "desbulhareis": "desbulhar",
    "desbulharem": "desbulhar",
    "desbulharemos": "desbulhar",
    "desbulhares": "desbulhar",
    "desbulharia": "desbulhar",
    "desbulhariam": "desbulhar",
    "desbulharias": "desbulhar",
    "desbulharmo": "desbulhar",
    "desbulharmos": "desbulhar",
    "desbulhará": "desbulhar",
    "desbulharás": "desbulhar",
    "desbulharão": "desbulhar",
    "desbulharíamos": "desbulhar",
    "desbulharíeis": "desbulhar",
    "desbulhas": "desbulhar",
    "desbulhasse": "desbulhar",
    "desbulhassem": "desbulhar",
    "desbulhasses": "desbulhar",
    "desbulhaste": "desbulhar",
    "desbulhastes": "desbulhar",
    "desbulhava": "desbulhar",
    "desbulhavam": "desbulhar",
    "desbulhavas": "desbulhar",
    "desbulhe": "desbulhar",
    "desbulhei": "desbulhar",
    "desbulheis": "desbulhar",
    "desbulhem": "desbulhar",
    "desbulhemo": "desbulhar",
    "desbulhemos": "desbulhar",
    "desbulhes": "desbulhar",
    "desbulho": "desbulhar",
    "desbulhou": "desbulhar",
    "desbulhá": "desbulhar",
    "desbulhámo": "desbulhar",
    "desbulhámos": "desbulhar",
    "desbulháramo": "desbulhar",
    "desbulháramos": "desbulhar",
    "desbulhárei": "desbulhar",
    "desbulháreis": "desbulhar",
    "desbulhásseis": "desbulhar",
    "desbulhássemos": "desbulhar",
    "desbulhávamo": "desbulhar",
    "desbulhávamos": "desbulhar",
    "desbulhávei": "desbulhar",
    "desbulháveis": "desbulhar",
    "desburocratiza": "desburocratizar",
    "desburocratizada": "desburocratizar",
    "desburocratizadas": "desburocratizar",
    "desburocratizado": "desburocratizar",
    "desburocratizados": "desburocratizar",
    "desburocratizai": "desburocratizar",
    "desburocratizais": "desburocratizar",
    "desburocratizam": "desburocratizar",
    "desburocratizamo": "desburocratizar",
    "desburocratizamos": "desburocratizar",
    "desburocratizando": "desburocratizar",
    "desburocratizara": "desburocratizar",
    "desburocratizaram": "desburocratizar",
    "desburocratizaras": "desburocratizar",
    "desburocratizarde": "desburocratizar",
    "desburocratizardes": "desburocratizar",
    "desburocratizare": "desburocratizar",
    "desburocratizarei": "desburocratizar",
    "desburocratizareis": "desburocratizar",
    "desburocratizarem": "desburocratizar",
    "desburocratizaremos": "desburocratizar",
    "desburocratizares": "desburocratizar",
    "desburocratizaria": "desburocratizar",
    "desburocratizariam": "desburocratizar",
    "desburocratizarias": "desburocratizar",
    "desburocratizarmo": "desburocratizar",
    "desburocratizarmos": "desburocratizar",
    "desburocratizará": "desburocratizar",
    "desburocratizarás": "desburocratizar",
    "desburocratizarão": "desburocratizar",
    "desburocratizaríamos": "desburocratizar",
    "desburocratizaríeis": "desburocratizar",
    "desburocratizas": "desburocratizar",
    "desburocratizasse": "desburocratizar",
    "desburocratizassem": "desburocratizar",
    "desburocratizasses": "desburocratizar",
    "desburocratizaste": "desburocratizar",
    "desburocratizastes": "desburocratizar",
    "desburocratizava": "desburocratizar",
    "desburocratizavam": "desburocratizar",
    "desburocratizavas": "desburocratizar",
    "desburocratizações": "desburocratização",
    "desburocratize": "desburocratizar",
    "desburocratizei": "desburocratizar",
    "desburocratizeis": "desburocratizar",
    "desburocratizem": "desburocratizar",
    "desburocratizemo": "desburocratizar",
    "desburocratizemos": "desburocratizar",
    "desburocratizes": "desburocratizar",
    "desburocratizo": "desburocratizar",
    "desburocratizou": "desburocratizar",
    "desburocratizá": "desburocratizar",
    "desburocratizámo": "desburocratizar",
    "desburocratizámos": "desburocratizar",
    "desburocratizáramo": "desburocratizar",
    "desburocratizáramos": "desburocratizar",
    "desburocratizárei": "desburocratizar",
    "desburocratizáreis": "desburocratizar",
    "desburocratizásseis": "desburocratizar",
    "desburocratizássemos": "desburocratizar",
    "desburocratizávamo": "desburocratizar",
    "desburocratizávamos": "desburocratizar",
    "desburocratizávei": "desburocratizar",
    "desburocratizáveis": "desburocratizar",
    "descabe": "descaber",
    "descabece": "descabeçar",
    "descabecei": "descabeçar",
    "descabeceis": "descabeçar",
    "descabecem": "descabeçar",
    "descabecemo": "descabeçar",
    "descabecemos": "descabeçar",
    "descabeces": "descabeçar",
    "descabei": "descaber",
    "descabeis": "descaber",
    "descabela": "descabelar",
    "descabelada": "descabelar",
    "descabeladas": "descabelar",
    "descabelado": "descabelar",
    "descabelados": "descabelar",
    "descabelai": "descabelar",
    "descabelais": "descabelar",
    "descabelam": "descabelar",
    "descabelamo": "descabelar",
    "descabelamos": "descabelar",
    "descabelando": "descabelar",
    "descabelara": "descabelar",
    "descabelaram": "descabelar",
    "descabelaras": "descabelar",
    "descabelarde": "descabelar",
    "descabelardes": "descabelar",
    "descabelare": "descabelar",
    "descabelarei": "descabelar",
    "descabelareis": "descabelar",
    "descabelarem": "descabelar",
    "descabelaremos": "descabelar",
    "descabelares": "descabelar",
    "descabelaria": "descabelar",
    "descabelariam": "descabelar",
    "descabelarias": "descabelar",
    "descabelarmo": "descabelar",
    "descabelarmos": "descabelar",
    "descabelará": "descabelar",
    "descabelarás": "descabelar",
    "descabelarão": "descabelar",
    "descabelaríamos": "descabelar",
    "descabelaríeis": "descabelar",
    "descabelas": "descabelar",
    "descabelasse": "descabelar",
    "descabelassem": "descabelar",
    "descabelasses": "descabelar",
    "descabelaste": "descabelar",
    "descabelastes": "descabelar",
    "descabelava": "descabelar",
    "descabelavam": "descabelar",
    "descabelavas": "descabelar",
    "descabele": "descabelar",
    "descabelei": "descabelar",
    "descabeleis": "descabelar",
    "descabelem": "descabelar",
    "descabelemo": "descabelar",
    "descabelemos": "descabelar",
    "descabeles": "descabelar",
    "descabelo": "descabelar",
    "descabelos": "descabelo",
    "descabelou": "descabelar",
    "descabelá": "descabelar",
    "descabelámo": "descabelar",
    "descabelámos": "descabelar",
    "descabeláramo": "descabelar",
    "descabeláramos": "descabelar",
    "descabelárei": "descabelar",
    "descabeláreis": "descabelar",
    "descabelásseis": "descabelar",
    "descabelássemos": "descabelar",
    "descabelávamo": "descabelar",
    "descabelávamos": "descabelar",
    "descabelávei": "descabelar",
    "descabeláveis": "descabelar",
    "descabem": "descaber",
    "descabemo": "descaber",
    "descabemos": "descaber",
    "descabendo": "descaber",
    "descaberdes": "descaber",
    "descaberei": "descaber",
    "descabereis": "descaber",
    "descaberem": "descaber",
    "descaberemos": "descaber",
    "descaberes": "descaber",
    "descaberia": "descaber",
    "descaberiam": "descaber",
    "descaberias": "descaber",
    "descabermo": "descaber",
    "descabermos": "descaber",
    "descaberá": "descaber",
    "descaberás": "descaber",
    "descaberão": "descaber",
    "descaberíamos": "descaber",
    "descaberíeis": "descaber",
    "descabes": "descaber",
    "descabeça": "descabeçar",
    "descabeçada": "descabeçar",
    "descabeçadas": "descabeçar",
    "descabeçado": "descabeçar",
    "descabeçadora": "descabeçador",
    "descabeçadoras": "descabeçador",
    "descabeçadores": "descabeçador",
    "descabeçados": "descabeçar",
    "descabeçai": "descabeçar",
    "descabeçais": "descabeçar",
    "descabeçam": "descabeçar",
    "descabeçamentos": "descabeçamento",
    "descabeçamo": "descabeçar",
    "descabeçamos": "descabeçar",
    "descabeçando": "descabeçar",
    "descabeçara": "descabeçar",
    "descabeçaram": "descabeçar",
    "descabeçaras": "descabeçar",
    "descabeçarde": "descabeçar",
    "descabeçardes": "descabeçar",
    "descabeçare": "descabeçar",
    "descabeçarei": "descabeçar",
    "descabeçareis": "descabeçar",
    "descabeçarem": "descabeçar",
    "descabeçaremos": "descabeçar",
    "descabeçares": "descabeçar",
    "descabeçaria": "descabeçar",
    "descabeçariam": "descabeçar",
    "descabeçarias": "descabeçar",
    "descabeçarmo": "descabeçar",
    "descabeçarmos": "descabeçar",
    "descabeçará": "descabeçar",
    "descabeçarás": "descabeçar",
    "descabeçarão": "descabeçar",
    "descabeçaríamos": "descabeçar",
    "descabeçaríeis": "descabeçar",
    "descabeças": "descabeçar",
    "descabeçasse": "descabeçar",
    "descabeçassem": "descabeçar",
    "descabeçasses": "descabeçar",
    "descabeçaste": "descabeçar",
    "descabeçastes": "descabeçar",
    "descabeçava": "descabeçar",
    "descabeçavam": "descabeçar",
    "descabeçavas": "descabeçar",
    "descabeço": "descabeçar",
    "descabeçou": "descabeçar",
    "descabeçá": "descabeçar",
    "descabeçámo": "descabeçar",
    "descabeçámos": "descabeçar",
    "descabeçáramo": "descabeçar",
    "descabeçáramos": "descabeçar",
    "descabeçárei": "descabeçar",
    "descabeçáreis": "descabeçar",
    "descabeçásseis": "descabeçar",
    "descabeçássemos": "descabeçar",
    "descabeçávamo": "descabeçar",
    "descabeçávamos": "descabeçar",
    "descabeçávei": "descabeçar",
    "descabeçáveis": "descabeçar",
    "descabia": "descaber",
    "descabiam": "descaber",
    "descabias": "descaber",
    "descabida": "descabido",
    "descabidas": "descabido",
    "descabido": "descaber",
    "descabidos": "descabido",
    "descabíamo": "descaber",
    "descabíamos": "descaber",
    "descabíeis": "descaber",
    "descadeira": "descadeirar",
    "descadeirada": "descadeirar",
    "descadeiradas": "descadeirar",
    "descadeirado": "descadeirar",
    "descadeirados": "descadeirar",
    "descadeirai": "descadeirar",
    "descadeirais": "descadeirar",
    "descadeiram": "descadeirar",
    "descadeiramo": "descadeirar",
    "descadeiramos": "descadeirar",
    "descadeirando": "descadeirar",
    "descadeirara": "descadeirar",
    "descadeiraram": "descadeirar",
    "descadeiraras": "descadeirar",
    "descadeirarde": "descadeirar",
    "descadeirardes": "descadeirar",
    "descadeirare": "descadeirar",
    "descadeirarei": "descadeirar",
    "descadeirareis": "descadeirar",
    "descadeirarem": "descadeirar",
    "descadeiraremos": "descadeirar",
    "descadeirares": "descadeirar",
    "descadeiraria": "descadeirar",
    "descadeirariam": "descadeirar",
    "descadeirarias": "descadeirar",
    "descadeirarmo": "descadeirar",
    "descadeirarmos": "descadeirar",
    "descadeirará": "descadeirar",
    "descadeirarás": "descadeirar",
    "descadeirarão": "descadeirar",
    "descadeiraríamos": "descadeirar",
    "descadeiraríeis": "descadeirar",
    "descadeiras": "descadeirar",
    "descadeirasse": "descadeirar",
    "descadeirassem": "descadeirar",
    "descadeirasses": "descadeirar",
    "descadeiraste": "descadeirar",
    "descadeirastes": "descadeirar",
    "descadeirava": "descadeirar",
    "descadeiravam": "descadeirar",
    "descadeiravas": "descadeirar",
    "descadeire": "descadeirar",
    "descadeirei": "descadeirar",
    "descadeireis": "descadeirar",
    "descadeirem": "descadeirar",
    "descadeiremo": "descadeirar",
    "descadeiremos": "descadeirar",
    "descadeires": "descadeirar",
    "descadeiro": "descadeirar",
    "descadeirou": "descadeirar",
    "descadeirá": "descadeirar",
    "descadeirámo": "descadeirar",
    "descadeirámos": "descadeirar",
    "descadeiráramo": "descadeirar",
    "descadeiráramos": "descadeirar",
    "descadeirárei": "descadeirar",
    "descadeiráreis": "descadeirar",
    "descadeirásseis": "descadeirar",
    "descadeirássemos": "descadeirar",
    "descadeirávamo": "descadeirar",
    "descadeirávamos": "descadeirar",
    "descadeirávei": "descadeirar",
    "descadeiráveis": "descadeirar",
    "descaem": "descair",
    "descafeinada": "descafeinado",
    "descafeinadas": "descafeinado",
    "descafeinados": "descafeinado",
    "descafeinações": "descafeinação",
    "descai": "descair",
    "descaia": "descair",
    "descaiais": "descair",
    "descaiam": "descair",
    "descaiamo": "descair",
    "descaiamos": "descair",
    "descaias": "descair",
    "descaiba": "descaber",
    "descaibais": "descaber",
    "descaibam": "descaber",
    "descaibamo": "descaber",
    "descaibamos": "descaber",
    "descaibas": "descaber",
    "descaibo": "descaber",
    "descaida": "descaido",
    "descaidas": "descaido",
    "descaidelas": "descaidela",
    "descaidos": "descaido",
    "descaimentos": "descaimento",
    "descaindo": "descair",
    "descaio": "descair",
    "descairde": "descair",
    "descairdes": "descair",
    "descairei": "descair",
    "descaireis": "descair",
    "descairemos": "descair",
    "descairia": "descair",
    "descairiam": "descair",
    "descairias": "descair",
    "descairmo": "descair",
    "descairmos": "descair",
    "descairá": "descair",
    "descairás": "descair",
    "descairão": "descair",
    "descairíamos": "descair",
    "descairíeis": "descair",
    "descais": "descair",
    "descaiu": "descair",
    "descalabrada": "descalabrado",
    "descalabradas": "descalabrado",
    "descalabrados": "descalabrado",
    "descalabros": "descalabro",
    "descalce": "descalçar",
    "descalcei": "descalçar",
    "descalceis": "descalçar",
    "descalcem": "descalçar",
    "descalcemo": "descalçar",
    "descalcemos": "descalçar",
    "descalces": "descalçar",
    "descalcifica": "descalcificar",
    "descalcificada": "descalcificar",
    "descalcificadas": "descalcificar",
    "descalcificado": "descalcificar",
    "descalcificadora": "descalcificador",
    "descalcificadoras": "descalcificador",
    "descalcificadores": "descalcificador",
    "descalcificados": "descalcificar",
    "descalcificai": "descalcificar",
    "descalcificais": "descalcificar",
    "descalcificam": "descalcificar",
    "descalcificamo": "descalcificar",
    "descalcificamos": "descalcificar",
    "descalcificando": "descalcificar",
    "descalcificantes": "descalcificante",
    "descalcificara": "descalcificar",
    "descalcificaram": "descalcificar",
    "descalcificaras": "descalcificar",
    "descalcificarde": "descalcificar",
    "descalcificardes": "descalcificar",
    "descalcificare": "descalcificar",
    "descalcificarei": "descalcificar",
    "descalcificareis": "descalcificar",
    "descalcificarem": "descalcificar",
    "descalcificaremos": "descalcificar",
    "descalcificares": "descalcificar",
    "descalcificaria": "descalcificar",
    "descalcificariam": "descalcificar",
    "descalcificarias": "descalcificar",
    "descalcificarmo": "descalcificar",
    "descalcificarmos": "descalcificar",
    "descalcificará": "descalcificar",
    "descalcificarás": "descalcificar",
    "descalcificarão": "descalcificar",
    "descalcificaríamos": "descalcificar",
    "descalcificaríeis": "descalcificar",
    "descalcificas": "descalcificar",
    "descalcificasse": "descalcificar",
    "descalcificassem": "descalcificar",
    "descalcificasses": "descalcificar",
    "descalcificaste": "descalcificar",
    "descalcificastes": "descalcificar",
    "descalcificava": "descalcificar",
    "descalcificavam": "descalcificar",
    "descalcificavas": "descalcificar",
    "descalcificações": "descalcificação",
    "descalcifico": "descalcificar",
    "descalcificou": "descalcificar",
    "descalcificá": "descalcificar",
    "descalcificámo": "descalcificar",
    "descalcificámos": "descalcificar",
    "descalcificáramo": "descalcificar",
    "descalcificáramos": "descalcificar",
    "descalcificárei": "descalcificar",
    "descalcificáreis": "descalcificar",
    "descalcificásseis": "descalcificar",
    "descalcificássemos": "descalcificar",
    "descalcificávamo": "descalcificar",
    "descalcificávamos": "descalcificar",
    "descalcificávei": "descalcificar",
    "descalcificáveis": "descalcificar",
    "descalcifique": "descalcificar",
    "descalcifiquei": "descalcificar",
    "descalcifiqueis": "descalcificar",
    "descalcifiquem": "descalcificar",
    "descalcifiquemo": "descalcificar",
    "descalcifiquemos": "descalcificar",
    "descalcifiques": "descalcificar",
    "descalice": "descaliçar",
    "descalicei": "descaliçar",
    "descaliceis": "descaliçar",
    "descalicem": "descaliçar",
    "descalicemo": "descaliçar",
    "descalicemos": "descaliçar",
    "descalices": "descaliçar",
    "descaliça": "descaliçar",
    "descaliçada": "descaliçar",
    "descaliçadas": "descaliçar",
    "descaliçado": "descaliçar",
    "descaliçados": "descaliçar",
    "descaliçai": "descaliçar",
    "descaliçais": "descaliçar",
    "descaliçam": "descaliçar",
    "descaliçamo": "descaliçar",
    "descaliçamos": "descaliçar",
    "descaliçando": "descaliçar",
    "descaliçara": "descaliçar",
    "descaliçaram": "descaliçar",
    "descaliçaras": "descaliçar",
    "descaliçarde": "descaliçar",
    "descaliçardes": "descaliçar",
    "descaliçare": "descaliçar",
    "descaliçarei": "descaliçar",
    "descaliçareis": "descaliçar",
    "descaliçarem": "descaliçar",
    "descaliçaremos": "descaliçar",
    "descaliçares": "descaliçar",
    "descaliçaria": "descaliçar",
    "descaliçariam": "descaliçar",
    "descaliçarias": "descaliçar",
    "descaliçarmo": "descaliçar",
    "descaliçarmos": "descaliçar",
    "descaliçará": "descaliçar",
    "descaliçarás": "descaliçar",
    "descaliçarão": "descaliçar",
    "descaliçaríamos": "descaliçar",
    "descaliçaríeis": "descaliçar",
    "descaliças": "descaliçar",
    "descaliçasse": "descaliçar",
    "descaliçassem": "descaliçar",
    "descaliçasses": "descaliçar",
    "descaliçaste": "descaliçar",
    "descaliçastes": "descaliçar",
    "descaliçava": "descaliçar",
    "descaliçavam": "descaliçar",
    "descaliçavas": "descaliçar",
    "descaliço": "descaliçar",
    "descaliçou": "descaliçar",
    "descaliçá": "descaliçar",
    "descaliçámo": "descaliçar",
    "descaliçámos": "descaliçar",
    "descaliçáramo": "descaliçar",
    "descaliçáramos": "descaliçar",
    "descaliçárei": "descaliçar",
    "descaliçáreis": "descaliçar",
    "descaliçásseis": "descaliçar",
    "descaliçássemos": "descaliçar",
    "descaliçávamo": "descaliçar",
    "descaliçávamos": "descaliçar",
    "descaliçávei": "descaliçar",
    "descaliçáveis": "descaliçar",
    "descalça": "descalço",
    "descalçada": "descalçar",
    "descalçadas": "descalçar",
    "descalçadeiras": "descalçadeira",
    "descalçadelas": "descalçadela",
    "descalçado": "descalçar",
    "descalçadora": "descalçador",
    "descalçadoras": "descalçador",
    "descalçadores": "descalçador",
    "descalçados": "descalçar",
    "descalçaduras": "descalçadura",
    "descalçai": "descalçar",
    "descalçais": "descalçar",
    "descalçam": "descalçar",
    "descalçamo": "descalçar",
    "descalçamos": "descalçar",
    "descalçando": "descalçar",
    "descalçara": "descalçar",
    "descalçaram": "descalçar",
    "descalçaras": "descalçar",
    "descalçarde": "descalçar",
    "descalçardes": "descalçar",
    "descalçare": "descalçar",
    "descalçarei": "descalçar",
    "descalçareis": "descalçar",
    "descalçarem": "descalçar",
    "descalçaremos": "descalçar",
    "descalçares": "descalçar",
    "descalçaria": "descalçar",
    "descalçariam": "descalçar",
    "descalçarias": "descalçar",
    "descalçarmo": "descalçar",
    "descalçarmos": "descalçar",
    "descalçará": "descalçar",
    "descalçarás": "descalçar",
    "descalçarão": "descalçar",
    "descalçaríamos": "descalçar",
    "descalçaríeis": "descalçar",
    "descalças": "descalço",
    "descalçasse": "descalçar",
    "descalçassem": "descalçar",
    "descalçasses": "descalçar",
    "descalçaste": "descalçar",
    "descalçastes": "descalçar",
    "descalçava": "descalçar",
    "descalçavam": "descalçar",
    "descalçavas": "descalçar",
    "descalço": "descalçar",
    "descalços": "descalço",
    "descalçou": "descalçar",
    "descalçá": "descalçar",
    "descalçámo": "descalçar",
    "descalçámos": "descalçar",
    "descalçáramo": "descalçar",
    "descalçáramos": "descalçar",
    "descalçárei": "descalçar",
    "descalçáreis": "descalçar",
    "descalçásseis": "descalçar",
    "descalçássemos": "descalçar",
    "descalçávamo": "descalçar",
    "descalçávamos": "descalçar",
    "descalçávei": "descalçar",
    "descalçáveis": "descalçar",
    "descama": "descamar",
    "descamada": "descamar",
    "descamadas": "descamar",
    "descamado": "descamar",
    "descamados": "descamar",
    "descamai": "descamar",
    "descamais": "descamar",
    "descamam": "descamar",
    "descamamo": "descamar",
    "descamamos": "descamar",
    "descamando": "descamar",
    "descamara": "descamar",
    "descamaram": "descamar",
    "descamaras": "descamar",
    "descamarde": "descamar",
    "descamardes": "descamar",
    "descamare": "descamar",
    "descamarei": "descamar",
    "descamareis": "descamar",
    "descamarem": "descamar",
    "descamaremos": "descamar",
    "descamares": "descamar",
    "descamaria": "descamar",
    "descamariam": "descamar",
    "descamarias": "descamar",
    "descamarmo": "descamar",
    "descamarmos": "descamar",
    "descamará": "descamar",
    "descamarás": "descamar",
    "descamarão": "descamar",
    "descamaríamos": "descamar",
    "descamaríeis": "descamar",
    "descamas": "descamar",
    "descamasse": "descamar",
    "descamassem": "descamar",
    "descamasses": "descamar",
    "descamaste": "descamar",
    "descamastes": "descamar",
    "descamava": "descamar",
    "descamavam": "descamar",
    "descamavas": "descamar",
    "descamações": "descamação",
    "descamba": "descambar",
    "descambada": "descambar",
    "descambadas": "descambar",
    "descambadelas": "descambadela",
    "descambado": "descambar",
    "descambados": "descambar",
    "descambai": "descambar",
    "descambais": "descambar",
    "descambam": "descambar",
    "descambamo": "descambar",
    "descambamos": "descambar",
    "descambando": "descambar",
    "descambara": "descambar",
    "descambaram": "descambar",
    "descambaras": "descambar",
    "descambardes": "descambar",
    "descambarei": "descambar",
    "descambareis": "descambar",
    "descambarem": "descambar",
    "descambaremos": "descambar",
    "descambares": "descambar",
    "descambaria": "descambar",
    "descambariam": "descambar",
    "descambarias": "descambar",
    "descambarmo": "descambar",
    "descambarmos": "descambar",
    "descambará": "descambar",
    "descambarás": "descambar",
    "descambarão": "descambar",
    "descambaríamos": "descambar",
    "descambaríeis": "descambar",
    "descambas": "descambar",
    "descambasse": "descambar",
    "descambassem": "descambar",
    "descambasses": "descambar",
    "descambaste": "descambar",
    "descambastes": "descambar",
    "descambava": "descambar",
    "descambavam": "descambar",
    "descambavas": "descambar",
    "descambações": "descambação",
    "descambe": "descambar",
    "descambei": "descambar",
    "descambeis": "descambar",
    "descambem": "descambar",
    "descambemo": "descambar",
    "descambemos": "descambar",
    "descambes": "descambar",
    "descambo": "descambar",
    "descambou": "descambar",
    "descambámo": "descambar",
    "descambámos": "descambar",
    "descambáramo": "descambar",
    "descambáramos": "descambar",
    "descambáreis": "descambar",
    "descambásseis": "descambar",
    "descambássemos": "descambar",
    "descambávamo": "descambar",
    "descambávamos": "descambar",
    "descambáveis": "descambar",
    "descame": "descamar",
    "descamei": "descamar",
    "descameis": "descamar",
    "descamem": "descamar",
    "descamemo": "descamar",
    "descamemos": "descamar",
    "descames": "descamar",
    "descaminha": "descaminhar",
    "descaminhada": "descaminhar",
    "descaminhadas": "descaminhar",
    "descaminhado": "descaminhar",
    "descaminhados": "descaminhar",
    "descaminhai": "descaminhar",
    "descaminhais": "descaminhar",
    "descaminham": "descaminhar",
    "descaminhamo": "descaminhar",
    "descaminhamos": "descaminhar",
    "descaminhando": "descaminhar",
    "descaminhara": "descaminhar",
    "descaminharam": "descaminhar",
    "descaminharas": "descaminhar",
    "descaminharde": "descaminhar",
    "descaminhardes": "descaminhar",
    "descaminhare": "descaminhar",
    "descaminharei": "descaminhar",
    "descaminhareis": "descaminhar",
    "descaminharem": "descaminhar",
    "descaminharemos": "descaminhar",
    "descaminhares": "descaminhar",
    "descaminharia": "descaminhar",
    "descaminhariam": "descaminhar",
    "descaminharias": "descaminhar",
    "descaminharmo": "descaminhar",
    "descaminharmos": "descaminhar",
    "descaminhará": "descaminhar",
    "descaminharás": "descaminhar",
    "descaminharão": "descaminhar",
    "descaminharíamos": "descaminhar",
    "descaminharíeis": "descaminhar",
    "descaminhas": "descaminhar",
    "descaminhasse": "descaminhar",
    "descaminhassem": "descaminhar",
    "descaminhasses": "descaminhar",
    "descaminhaste": "descaminhar",
    "descaminhastes": "descaminhar",
    "descaminhava": "descaminhar",
    "descaminhavam": "descaminhar",
    "descaminhavas": "descaminhar",
    "descaminhe": "descaminhar",
    "descaminhei": "descaminhar",
    "descaminheis": "descaminhar",
    "descaminhem": "descaminhar",
    "descaminhemo": "descaminhar",
    "descaminhemos": "descaminhar",
    "descaminhes": "descaminhar",
    "descaminho": "descaminhar",
    "descaminhos": "descaminho",
    "descaminhou": "descaminhar",
    "descaminhá": "descaminhar",
    "descaminhámo": "descaminhar",
    "descaminhámos": "descaminhar",
    "descaminháramo": "descaminhar",
    "descaminháramos": "descaminhar",
    "descaminhárei": "descaminhar",
    "descaminháreis": "descaminhar",
    "descaminhásseis": "descaminhar",
    "descaminhássemos": "descaminhar",
    "descaminhávamo": "descaminhar",
    "descaminhávamos": "descaminhar",
    "descaminhávei": "descaminhar",
    "descaminháveis": "descaminhar",
    "descamisa": "descamisar",
    "descamisada": "descamisar",
    "descamisadas": "descamisar",
    "descamisado": "descamisar",
    "descamisadora": "descamisador",
    "descamisadoras": "descamisador",
    "descamisadores": "descamisador",
    "descamisados": "descamisar",
    "descamisai": "descamisar",
    "descamisais": "descamisar",
    "descamisam": "descamisar",
    "descamisamo": "descamisar",
    "descamisamos": "descamisar",
    "descamisando": "descamisar",
    "descamisara": "descamisar",
    "descamisaram": "descamisar",
    "descamisaras": "descamisar",
    "descamisarde": "descamisar",
    "descamisardes": "descamisar",
    "descamisare": "descamisar",
    "descamisarei": "descamisar",
    "descamisareis": "descamisar",
    "descamisarem": "descamisar",
    "descamisaremos": "descamisar",
    "descamisares": "descamisar",
    "descamisaria": "descamisar",
    "descamisariam": "descamisar",
    "descamisarias": "descamisar",
    "descamisarmo": "descamisar",
    "descamisarmos": "descamisar",
    "descamisará": "descamisar",
    "descamisarás": "descamisar",
    "descamisarão": "descamisar",
    "descamisaríamos": "descamisar",
    "descamisaríeis": "descamisar",
    "descamisas": "descamisar",
    "descamisasse": "descamisar",
    "descamisassem": "descamisar",
    "descamisasses": "descamisar",
    "descamisaste": "descamisar",
    "descamisastes": "descamisar",
    "descamisava": "descamisar",
    "descamisavam": "descamisar",
    "descamisavas": "descamisar",
    "descamise": "descamisar",
    "descamisei": "descamisar",
    "descamiseis": "descamisar",
    "descamisem": "descamisar",
    "descamisemo": "descamisar",
    "descamisemos": "descamisar",
    "descamises": "descamisar",
    "descamiso": "descamisar",
    "descamisou": "descamisar",
    "descamisá": "descamisar",
    "descamisámo": "descamisar",
    "descamisámos": "descamisar",
    "descamisáramo": "descamisar",
    "descamisáramos": "descamisar",
    "descamisárei": "descamisar",
    "descamisáreis": "descamisar",
    "descamisásseis": "descamisar",
    "descamisássemos": "descamisar",
    "descamisávamo": "descamisar",
    "descamisávamos": "descamisar",
    "descamisávei": "descamisar",
    "descamisáveis": "descamisar",
    "descamo": "descamar",
    "descamou": "descamar",
    "descampada": "descampado",
    "descampadas": "descampado",
    "descampados": "descampado",
    "descamá": "descamar",
    "descamámo": "descamar",
    "descamámos": "descamar",
    "descamáramo": "descamar",
    "descamáramos": "descamar",
    "descamárei": "descamar",
    "descamáreis": "descamar",
    "descamásseis": "descamar",
    "descamássemos": "descamar",
    "descamávamo": "descamar",
    "descamávamos": "descamar",
    "descamávei": "descamar",
    "descamáveis": "descamar",
    "descancela": "descancelar",
    "descancelada": "descancelar",
    "descanceladas": "descancelar",
    "descancelado": "descancelar",
    "descancelados": "descancelar",
    "descancelai": "descancelar",
    "descancelais": "descancelar",
    "descancelam": "descancelar",
    "descancelamo": "descancelar",
    "descancelamos": "descancelar",
    "descancelando": "descancelar",
    "descancelara": "descancelar",
    "descancelaram": "descancelar",
    "descancelaras": "descancelar",
    "descancelarde": "descancelar",
    "descancelardes": "descancelar",
    "descancelare": "descancelar",
    "descancelarei": "descancelar",
    "descancelareis": "descancelar",
    "descancelarem": "descancelar",
    "descancelaremos": "descancelar",
    "descancelares": "descancelar",
    "descancelaria": "descancelar",
    "descancelariam": "descancelar",
    "descancelarias": "descancelar",
    "descancelarmo": "descancelar",
    "descancelarmos": "descancelar",
    "descancelará": "descancelar",
    "descancelarás": "descancelar",
    "descancelarão": "descancelar",
    "descancelaríamos": "descancelar",
    "descancelaríeis": "descancelar",
    "descancelas": "descancelar",
    "descancelasse": "descancelar",
    "descancelassem": "descancelar",
    "descancelasses": "descancelar",
    "descancelaste": "descancelar",
    "descancelastes": "descancelar",
    "descancelava": "descancelar",
    "descancelavam": "descancelar",
    "descancelavas": "descancelar",
    "descancele": "descancelar",
    "descancelei": "descancelar",
    "descanceleis": "descancelar",
    "descancelem": "descancelar",
    "descancelemo": "descancelar",
    "descancelemos": "descancelar",
    "descanceles": "descancelar",
    "descancelo": "descancelar",
    "descancelou": "descancelar",
    "descancelá": "descancelar",
    "descancelámo": "descancelar",
    "descancelámos": "descancelar",
    "descanceláramo": "descancelar",
    "descanceláramos": "descancelar",
    "descancelárei": "descancelar",
    "descanceláreis": "descancelar",
    "descancelásseis": "descancelar",
    "descancelássemos": "descancelar",
    "descancelávamo": "descancelar",
    "descancelávamos": "descancelar",
    "descancelávei": "descancelar",
    "descanceláveis": "descancelar",
    "descanga": "descangar",
    "descangada": "descangar",
    "descangadas": "descangar",
    "descangado": "descangar",
    "descangados": "descangar",
    "descangai": "descangar",
    "descangais": "descangar",
    "descangam": "descangar",
    "descangamo": "descangar",
    "descangamos": "descangar",
    "descangando": "descangar",
    "descangara": "descangar",
    "descangaram": "descangar",
    "descangaras": "descangar",
    "descangarde": "descangar",
    "descangardes": "descangar",
    "descangare": "descangar",
    "descangarei": "descangar",
    "descangareis": "descangar",
    "descangarem": "descangar",
    "descangaremos": "descangar",
    "descangares": "descangar",
    "descangaria": "descangar",
    "descangariam": "descangar",
    "descangarias": "descangar",
    "descangarmo": "descangar",
    "descangarmos": "descangar",
    "descangará": "descangar",
    "descangarás": "descangar",
    "descangarão": "descangar",
    "descangaríamos": "descangar",
    "descangaríeis": "descangar",
    "descangas": "descangar",
    "descangasse": "descangar",
    "descangassem": "descangar",
    "descangasses": "descangar",
    "descangaste": "descangar",
    "descangastes": "descangar",
    "descangava": "descangar",
    "descangavam": "descangar",
    "descangavas": "descangar",
    "descango": "descangar",
    "descangou": "descangar",
    "descangue": "descangar",
    "descanguei": "descangar",
    "descangueis": "descangar",
    "descanguem": "descangar",
    "descanguemo": "descangar",
    "descanguemos": "descangar",
    "descangues": "descangar",
    "descangá": "descangar",
    "descangámo": "descangar",
    "descangámos": "descangar",
    "descangáramo": "descangar",
    "descangáramos": "descangar",
    "descangárei": "descangar",
    "descangáreis": "descangar",
    "descangásseis": "descangar",
    "descangássemos": "descangar",
    "descangávamo": "descangar",
    "descangávamos": "descangar",
    "descangávei": "descangar",
    "descangáveis": "descangar",
    "descansa": "descansar",
    "descansada": "descansar",
    "descansadas": "descansar",
    "descansadeiros": "descansadeiro",
    "descansadinha": "descansado",
    "descansadinhas": "descansado",
    "descansadinho": "descansado",
    "descansadinhos": "descansado",
    "descansadita": "descansado",
    "descansaditas": "descansado",
    "descansadito": "descansado",
    "descansaditos": "descansado",
    "descansado": "descansar",
    "descansados": "descansar",
    "descansadíssima": "descansado",
    "descansadíssimas": "descansado",
    "descansadíssimo": "descansado",
    "descansadíssimos": "descansado",
    "descansadões": "descansadão",
    "descansai": "descansar",
    "descansais": "descansar",
    "descansam": "descansar",
    "descansamo": "descansar",
    "descansamos": "descansar",
    "descansando": "descansar",
    "descansara": "descansar",
    "descansaram": "descansar",
    "descansaras": "descansar",
    "descansarde": "descansar",
    "descansardes": "descansar",
    "descansare": "descansar",
    "descansarei": "descansar",
    "descansareis": "descansar",
    "descansarem": "descansar",
    "descansaremos": "descansar",
    "descansares": "descansar",
    "descansaria": "descansar",
    "descansariam": "descansar",
    "descansarias": "descansar",
    "descansarmo": "descansar",
    "descansarmos": "descansar",
    "descansará": "descansar",
    "descansarás": "descansar",
    "descansarão": "descansar",
    "descansaríamos": "descansar",
    "descansaríeis": "descansar",
    "descansas": "descansar",
    "descansasse": "descansar",
    "descansassem": "descansar",
    "descansasses": "descansar",
    "descansaste": "descansar",
    "descansastes": "descansar",
    "descansava": "descansar",
    "descansavam": "descansar",
    "descansavas": "descansar",
    "descanse": "descansar",
    "descansei": "descansar",
    "descanseis": "descansar",
    "descansem": "descansar",
    "descansemo": "descansar",
    "descansemos": "descansar",
    "descanses": "descansar",
    "descanso": "descansar",
    "descansos": "descanso",
    "descansou": "descansar",
    "descansá": "descansar",
    "descansámo": "descansar",
    "descansámos": "descansar",
    "descansáramo": "descansar",
    "descansáramos": "descansar",
    "descansárei": "descansar",
    "descansáreis": "descansar",
    "descansásseis": "descansar",
    "descansássemos": "descansar",
    "descansávamo": "descansar",
    "descansávamos": "descansar",
    "descansávei": "descansar",
    "descansáveis": "descansar",
    "descanta": "descantar",
    "descantada": "descantar",
    "descantadas": "descantar",
    "descantado": "descantar",
    "descantados": "descantar",
    "descantai": "descantar",
    "descantais": "descantar",
    "descantam": "descantar",
    "descantamo": "descantar",
    "descantamos": "descantar",
    "descantando": "descantar",
    "descantara": "descantar",
    "descantaram": "descantar",
    "descantaras": "descantar",
    "descantarde": "descantar",
    "descantardes": "descantar",
    "descantare": "descantar",
    "descantarei": "descantar",
    "descantareis": "descantar",
    "descantarem": "descantar",
    "descantaremos": "descantar",
    "descantares": "descantar",
    "descantaria": "descantar",
    "descantariam": "descantar",
    "descantarias": "descantar",
    "descantarmo": "descantar",
    "descantarmos": "descantar",
    "descantará": "descantar",
    "descantarás": "descantar",
    "descantarão": "descantar",
    "descantaríamos": "descantar",
    "descantaríeis": "descantar",
    "descantas": "descantar",
    "descantasse": "descantar",
    "descantassem": "descantar",
    "descantasses": "descantar",
    "descantaste": "descantar",
    "descantastes": "descantar",
    "descantava": "descantar",
    "descantavam": "descantar",
    "descantavas": "descantar",
    "descante": "descantar",
    "descantei": "descantar",
    "descanteis": "descantar",
    "descantem": "descantar",
    "descantemo": "descantar",
    "descantemos": "descantar",
    "descantes": "descante",
    "descanto": "descantar",
    "descantos": "descanto",
    "descantou": "descantar",
    "descantá": "descantar",
    "descantámo": "descantar",
    "descantámos": "descantar",
    "descantáramo": "descantar",
    "descantáramos": "descantar",
    "descantárei": "descantar",
    "descantáreis": "descantar",
    "descantásseis": "descantar",
    "descantássemos": "descantar",
    "descantávamo": "descantar",
    "descantávamos": "descantar",
    "descantávei": "descantar",
    "descantáveis": "descantar",
    "descapacita": "descapacitar",
    "descapacitada": "descapacitar",
    "descapacitadas": "descapacitar",
    "descapacitado": "descapacitar",
    "descapacitados": "descapacitar",
    "descapacitai": "descapacitar",
    "descapacitais": "descapacitar",
    "descapacitam": "descapacitar",
    "descapacitamo": "descapacitar",
    "descapacitamos": "descapacitar",
    "descapacitando": "descapacitar",
    "descapacitara": "descapacitar",
    "descapacitaram": "descapacitar",
    "descapacitaras": "descapacitar",
    "descapacitarde": "descapacitar",
    "descapacitardes": "descapacitar",
    "descapacitare": "descapacitar",
    "descapacitarei": "descapacitar",
    "descapacitareis": "descapacitar",
    "descapacitarem": "descapacitar",
    "descapacitaremos": "descapacitar",
    "descapacitares": "descapacitar",
    "descapacitaria": "descapacitar",
    "descapacitariam": "descapacitar",
    "descapacitarias": "descapacitar",
    "descapacitarmo": "descapacitar",
    "descapacitarmos": "descapacitar",
    "descapacitará": "descapacitar",
    "descapacitarás": "descapacitar",
    "descapacitarão": "descapacitar",
    "descapacitaríamos": "descapacitar",
    "descapacitaríeis": "descapacitar",
    "descapacitas": "descapacitar",
    "descapacitasse": "descapacitar",
    "descapacitassem": "descapacitar",
    "descapacitasses": "descapacitar",
    "descapacitaste": "descapacitar",
    "descapacitastes": "descapacitar",
    "descapacitava": "descapacitar",
    "descapacitavam": "descapacitar",
    "descapacitavas": "descapacitar",
    "descapacite": "descapacitar",
    "descapacitei": "descapacitar",
    "descapaciteis": "descapacitar",
    "descapacitem": "descapacitar",
    "descapacitemo": "descapacitar",
    "descapacitemos": "descapacitar",
    "descapacites": "descapacitar",
    "descapacito": "descapacitar",
    "descapacitou": "descapacitar",
    "descapacitá": "descapacitar",
    "descapacitámo": "descapacitar",
    "descapacitámos": "descapacitar",
    "descapacitáramo": "descapacitar",
    "descapacitáramos": "descapacitar",
    "descapacitárei": "descapacitar",
    "descapacitáreis": "descapacitar",
    "descapacitásseis": "descapacitar",
    "descapacitássemos": "descapacitar",
    "descapacitávamo": "descapacitar",
    "descapacitávamos": "descapacitar",
    "descapacitávei": "descapacitar",
    "descapacitáveis": "descapacitar",
    "descapela": "descapelar",
    "descapelada": "descapelar",
    "descapeladas": "descapelar",
    "descapelado": "descapelar",
    "descapelados": "descapelar",
    "descapelai": "descapelar",
    "descapelais": "descapelar",
    "descapelam": "descapelar",
    "descapelamo": "descapelar",
    "descapelamos": "descapelar",
    "descapelando": "descapelar",
    "descapelara": "descapelar",
    "descapelaram": "descapelar",
    "descapelaras": "descapelar",
    "descapelarde": "descapelar",
    "descapelardes": "descapelar",
    "descapelare": "descapelar",
    "descapelarei": "descapelar",
    "descapelareis": "descapelar",
    "descapelarem": "descapelar",
    "descapelaremos": "descapelar",
    "descapelares": "descapelar",
    "descapelaria": "descapelar",
    "descapelariam": "descapelar",
    "descapelarias": "descapelar",
    "descapelarmo": "descapelar",
    "descapelarmos": "descapelar",
    "descapelará": "descapelar",
    "descapelarás": "descapelar",
    "descapelarão": "descapelar",
    "descapelaríamos": "descapelar",
    "descapelaríeis": "descapelar",
    "descapelas": "descapelar",
    "descapelasse": "descapelar",
    "descapelassem": "descapelar",
    "descapelasses": "descapelar",
    "descapelaste": "descapelar",
    "descapelastes": "descapelar",
    "descapelava": "descapelar",
    "descapelavam": "descapelar",
    "descapelavas": "descapelar",
    "descapele": "descapelar",
    "descapelei": "descapelar",
    "descapeleis": "descapelar",
    "descapelem": "descapelar",
    "descapelemo": "descapelar",
    "descapelemos": "descapelar",
    "descapeles": "descapelar",
    "descapelo": "descapelar",
    "descapelou": "descapelar",
    "descapelá": "descapelar",
    "descapelámo": "descapelar",
    "descapelámos": "descapelar",
    "descapeláramo": "descapelar",
    "descapeláramos": "descapelar",
    "descapelárei": "descapelar",
    "descapeláreis": "descapelar",
    "descapelásseis": "descapelar",
    "descapelássemos": "descapelar",
    "descapelávamo": "descapelar",
    "descapelávamos": "descapelar",
    "descapelávei": "descapelar",
    "descapeláveis": "descapelar",
    "descapitaliza": "descapitalizar",
    "descapitalizada": "descapitalizar",
    "descapitalizadas": "descapitalizar",
    "descapitalizado": "descapitalizar",
    "descapitalizados": "descapitalizar",
    "descapitalizai": "descapitalizar",
    "descapitalizais": "descapitalizar",
    "descapitalizam": "descapitalizar",
    "descapitalizamo": "descapitalizar",
    "descapitalizamos": "descapitalizar",
    "descapitalizando": "descapitalizar",
    "descapitalizara": "descapitalizar",
    "descapitalizaram": "descapitalizar",
    "descapitalizaras": "descapitalizar",
    "descapitalizarde": "descapitalizar",
    "descapitalizardes": "descapitalizar",
    "descapitalizare": "descapitalizar",
    "descapitalizarei": "descapitalizar",
    "descapitalizareis": "descapitalizar",
    "descapitalizarem": "descapitalizar",
    "descapitalizaremos": "descapitalizar",
    "descapitalizares": "descapitalizar",
    "descapitalizaria": "descapitalizar",
    "descapitalizariam": "descapitalizar",
    "descapitalizarias": "descapitalizar",
    "descapitalizarmo": "descapitalizar",
    "descapitalizarmos": "descapitalizar",
    "descapitalizará": "descapitalizar",
    "descapitalizarás": "descapitalizar",
    "descapitalizarão": "descapitalizar",
    "descapitalizaríamos": "descapitalizar",
    "descapitalizaríeis": "descapitalizar",
    "descapitalizas": "descapitalizar",
    "descapitalizasse": "descapitalizar",
    "descapitalizassem": "descapitalizar",
    "descapitalizasses": "descapitalizar",
    "descapitalizaste": "descapitalizar",
    "descapitalizastes": "descapitalizar",
    "descapitalizava": "descapitalizar",
    "descapitalizavam": "descapitalizar",
    "descapitalizavas": "descapitalizar",
    "descapitalizações": "descapitalização",
    "descapitalize": "descapitalizar",
    "descapitalizei": "descapitalizar",
    "descapitalizeis": "descapitalizar",
    "descapitalizem": "descapitalizar",
    "descapitalizemo": "descapitalizar",
    "descapitalizemos": "descapitalizar",
    "descapitalizes": "descapitalizar",
    "descapitalizo": "descapitalizar",
    "descapitalizou": "descapitalizar",
    "descapitalizá": "descapitalizar",
    "descapitalizámo": "descapitalizar",
    "descapitalizámos": "descapitalizar",
    "descapitalizáramo": "descapitalizar",
    "descapitalizáramos": "descapitalizar",
    "descapitalizárei": "descapitalizar",
    "descapitalizáreis": "descapitalizar",
    "descapitalizásseis": "descapitalizar",
    "descapitalizássemos": "descapitalizar",
    "descapitalizávamo": "descapitalizar",
    "descapitalizávamos": "descapitalizar",
    "descapitalizávei": "descapitalizar",
    "descapitalizáveis": "descapitalizável",
    "descapotáveis": "descapotável",
    "descapsula": "descapsular",
    "descapsulada": "descapsular",
    "descapsuladas": "descapsular",
    "descapsulado": "descapsular",
    "descapsulados": "descapsular",
    "descapsulai": "descapsular",
    "descapsulais": "descapsular",
    "descapsulam": "descapsular",
    "descapsulamo": "descapsular",
    "descapsulamos": "descapsular",
    "descapsulando": "descapsular",
    "descapsulara": "descapsular",
    "descapsularam": "descapsular",
    "descapsularas": "descapsular",
    "descapsularde": "descapsular",
    "descapsulardes": "descapsular",
    "descapsulare": "descapsular",
    "descapsularei": "descapsular",
    "descapsulareis": "descapsular",
    "descapsularem": "descapsular",
    "descapsularemos": "descapsular",
    "descapsulares": "descapsular",
    "descapsularia": "descapsular",
    "descapsulariam": "descapsular",
    "descapsularias": "descapsular",
    "descapsularmo": "descapsular",
    "descapsularmos": "descapsular",
    "descapsulará": "descapsular",
    "descapsularás": "descapsular",
    "descapsularão": "descapsular",
    "descapsularíamos": "descapsular",
    "descapsularíeis": "descapsular",
    "descapsulas": "descapsular",
    "descapsulasse": "descapsular",
    "descapsulassem": "descapsular",
    "descapsulasses": "descapsular",
    "descapsulaste": "descapsular",
    "descapsulastes": "descapsular",
    "descapsulava": "descapsular",
    "descapsulavam": "descapsular",
    "descapsulavas": "descapsular",
    "descapsulações": "descapsulação",
    "descapsule": "descapsular",
    "descapsulei": "descapsular",
    "descapsuleis": "descapsular",
    "descapsulem": "descapsular",
    "descapsulemo": "descapsular",
    "descapsulemos": "descapsular",
    "descapsules": "descapsular",
    "descapsulo": "descapsular",
    "descapsulou": "descapsular",
    "descapsulá": "descapsular",
    "descapsulámo": "descapsular",
    "descapsulámos": "descapsular",
    "descapsuláramo": "descapsular",
    "descapsuláramos": "descapsular",
    "descapsulárei": "descapsular",
    "descapsuláreis": "descapsular",
    "descapsulásseis": "descapsular",
    "descapsulássemos": "descapsular",
    "descapsulávamo": "descapsular",
    "descapsulávamos": "descapsular",
    "descapsulávei": "descapsular",
    "descapsuláveis": "descapsular",
    "descara": "descarar",
    "descaracteriza": "descaracterizar",
    "descaracterizada": "descaracterizar",
    "descaracterizadas": "descaracterizar",
    "descaracterizado": "descaracterizar",
    "descaracterizados": "descaracterizar",
    "descaracterizai": "descaracterizar",
    "descaracterizais": "descaracterizar",
    "descaracterizam": "descaracterizar",
    "descaracterizamo": "descaracterizar",
    "descaracterizamos": "descaracterizar",
    "descaracterizando": "descaracterizar",
    "descaracterizara": "descaracterizar",
    "descaracterizaram": "descaracterizar",
    "descaracterizaras": "descaracterizar",
    "descaracterizarde": "descaracterizar",
    "descaracterizardes": "descaracterizar",
    "descaracterizare": "descaracterizar",
    "descaracterizarei": "descaracterizar",
    "descaracterizareis": "descaracterizar",
    "descaracterizarem": "descaracterizar",
    "descaracterizaremos": "descaracterizar",
    "descaracterizares": "descaracterizar",
    "descaracterizaria": "descaracterizar",
    "descaracterizariam": "descaracterizar",
    "descaracterizarias": "descaracterizar",
    "descaracterizarmo": "descaracterizar",
    "descaracterizarmos": "descaracterizar",
    "descaracterizará": "descaracterizar",
    "descaracterizarás": "descaracterizar",
    "descaracterizarão": "descaracterizar",
    "descaracterizaríamos": "descaracterizar",
    "descaracterizaríeis": "descaracterizar",
    "descaracterizas": "descaracterizar",
    "descaracterizasse": "descaracterizar",
    "descaracterizassem": "descaracterizar",
    "descaracterizasses": "descaracterizar",
    "descaracterizaste": "descaracterizar",
    "descaracterizastes": "descaracterizar",
    "descaracterizava": "descaracterizar",
    "descaracterizavam": "descaracterizar",
    "descaracterizavas": "descaracterizar",
    "descaracterizações": "descaracterização",
    "descaracterize": "descaracterizar",
    "descaracterizei": "descaracterizar",
    "descaracterizeis": "descaracterizar",
    "descaracterizem": "descaracterizar",
    "descaracterizemo": "descaracterizar",
    "descaracterizemos": "descaracterizar",
    "descaracterizes": "descaracterizar",
    "descaracterizo": "descaracterizar",
    "descaracterizou": "descaracterizar",
    "descaracterizá": "descaracterizar",
    "descaracterizámo": "descaracterizar",
    "descaracterizámos": "descaracterizar",
    "descaracterizáramo": "descaracterizar",
    "descaracterizáramos": "descaracterizar",
    "descaracterizárei": "descaracterizar",
    "descaracterizáreis": "descaracterizar",
    "descaracterizásseis": "descaracterizar",
    "descaracterizássemos": "descaracterizar",
    "descaracterizávamo": "descaracterizar",
    "descaracterizávamos": "descaracterizar",
    "descaracterizávei": "descaracterizar",
    "descaracterizáveis": "descaracterizável",
    "descarada": "descarar",
    "descaradas": "descarar",
    "descarado": "descarar",
    "descarados": "descarar",
    "descaradíssima": "descarado",
    "descaradíssimas": "descarado",
    "descaradíssimo": "descarado",
    "descaradíssimos": "descarado",
    "descarai": "descarar",
    "descarais": "descarar",
    "descaram": "descarar",
    "descaramentos": "descaramento",
    "descaramo": "descarar",
    "descaramos": "descarar",
    "descarando": "descarar",
    "descarapuce": "descarapuçar",
    "descarapucei": "descarapuçar",
    "descarapuceis": "descarapuçar",
    "descarapucem": "descarapuçar",
    "descarapucemo": "descarapuçar",
    "descarapucemos": "descarapuçar",
    "descarapuces": "descarapuçar",
    "descarapuça": "descarapuçar",
    "descarapuçada": "descarapuçar",
    "descarapuçadas": "descarapuçar",
    "descarapuçado": "descarapuçar",
    "descarapuçados": "descarapuçar",
    "descarapuçai": "descarapuçar",
    "descarapuçais": "descarapuçar",
    "descarapuçam": "descarapuçar",
    "descarapuçamo": "descarapuçar",
    "descarapuçamos": "descarapuçar",
    "descarapuçando": "descarapuçar",
    "descarapuçara": "descarapuçar",
    "descarapuçaram": "descarapuçar",
    "descarapuçaras": "descarapuçar",
    "descarapuçarde": "descarapuçar",
    "descarapuçardes": "descarapuçar",
    "descarapuçare": "descarapuçar",
    "descarapuçarei": "descarapuçar",
    "descarapuçareis": "descarapuçar",
    "descarapuçarem": "descarapuçar",
    "descarapuçaremos": "descarapuçar",
    "descarapuçares": "descarapuçar",
    "descarapuçaria": "descarapuçar",
    "descarapuçariam": "descarapuçar",
    "descarapuçarias": "descarapuçar",
    "descarapuçarmo": "descarapuçar",
    "descarapuçarmos": "descarapuçar",
    "descarapuçará": "descarapuçar",
    "descarapuçarás": "descarapuçar",
    "descarapuçarão": "descarapuçar",
    "descarapuçaríamos": "descarapuçar",
    "descarapuçaríeis": "descarapuçar",
    "descarapuças": "descarapuçar",
    "descarapuçasse": "descarapuçar",
    "descarapuçassem": "descarapuçar",
    "descarapuçasses": "descarapuçar",
    "descarapuçaste": "descarapuçar",
    "descarapuçastes": "descarapuçar",
    "descarapuçava": "descarapuçar",
    "descarapuçavam": "descarapuçar",
    "descarapuçavas": "descarapuçar",
    "descarapuço": "descarapuçar",
    "descarapuçou": "descarapuçar",
    "descarapuçá": "descarapuçar",
    "descarapuçámo": "descarapuçar",
    "descarapuçámos": "descarapuçar",
    "descarapuçáramo": "descarapuçar",
    "descarapuçáramos": "descarapuçar",
    "descarapuçárei": "descarapuçar",
    "descarapuçáreis": "descarapuçar",
    "descarapuçásseis": "descarapuçar",
    "descarapuçássemos": "descarapuçar",
    "descarapuçávamo": "descarapuçar",
    "descarapuçávamos": "descarapuçar",
    "descarapuçávei": "descarapuçar",
    "descarapuçáveis": "descarapuçar",
    "descarara": "descarar",
    "descararam": "descarar",
    "descararas": "descarar",
    "descararde": "descarar",
    "descarardes": "descarar",
    "descarare": "descarar",
    "descararei": "descarar",
    "descarareis": "descarar",
    "descararem": "descarar",
    "descararemos": "descarar",
    "descarares": "descarar",
    "descararia": "descarar",
    "descarariam": "descarar",
    "descararias": "descarar",
    "descararmo": "descarar",
    "descararmos": "descarar",
    "descarará": "descarar",
    "descararás": "descarar",
    "descararão": "descarar",
    "descararíamos": "descarar",
    "descararíeis": "descarar",
    "descaras": "descarar",
    "descarasse": "descarar",
    "descarassem": "descarar",
    "descarasses": "descarar",
    "descaraste": "descarar",
    "descarastes": "descarar",
    "descarava": "descarar",
    "descaravam": "descarar",
    "descaravas": "descarar",
    "descarbona": "descarbonar",
    "descarbonada": "descarbonar",
    "descarbonadas": "descarbonar",
    "descarbonado": "descarbonar",
    "descarbonados": "descarbonar",
    "descarbonai": "descarbonar",
    "descarbonais": "descarbonar",
    "descarbonam": "descarbonar",
    "descarbonamo": "descarbonar",
    "descarbonamos": "descarbonar",
    "descarbonando": "descarbonar",
    "descarbonara": "descarbonar",
    "descarbonaram": "descarbonar",
    "descarbonaras": "descarbonar",
    "descarbonarde": "descarbonar",
    "descarbonardes": "descarbonar",
    "descarbonare": "descarbonar",
    "descarbonarei": "descarbonar",
    "descarbonareis": "descarbonar",
    "descarbonarem": "descarbonar",
    "descarbonaremos": "descarbonar",
    "descarbonares": "descarbonar",
    "descarbonaria": "descarbonar",
    "descarbonariam": "descarbonar",
    "descarbonarias": "descarbonar",
    "descarbonarmo": "descarbonar",
    "descarbonarmos": "descarbonar",
    "descarbonará": "descarbonar",
    "descarbonarás": "descarbonar",
    "descarbonarão": "descarbonar",
    "descarbonaríamos": "descarbonar",
    "descarbonaríeis": "descarbonar",
    "descarbonas": "descarbonar",
    "descarbonasse": "descarbonar",
    "descarbonassem": "descarbonar",
    "descarbonasses": "descarbonar",
    "descarbonaste": "descarbonar",
    "descarbonastes": "descarbonar",
    "descarbonata": "descarbonatar",
    "descarbonatada": "descarbonatar",
    "descarbonatadas": "descarbonatar",
    "descarbonatado": "descarbonatar",
    "descarbonatados": "descarbonatar",
    "descarbonatai": "descarbonatar",
    "descarbonatais": "descarbonatar",
    "descarbonatam": "descarbonatar",
    "descarbonatamo": "descarbonatar",
    "descarbonatamos": "descarbonatar",
    "descarbonatando": "descarbonatar",
    "descarbonatara": "descarbonatar",
    "descarbonataram": "descarbonatar",
    "descarbonataras": "descarbonatar",
    "descarbonatarde": "descarbonatar",
    "descarbonatardes": "descarbonatar",
    "descarbonatare": "descarbonatar",
    "descarbonatarei": "descarbonatar",
    "descarbonatareis": "descarbonatar",
    "descarbonatarem": "descarbonatar",
    "descarbonataremos": "descarbonatar",
    "descarbonatares": "descarbonatar",
    "descarbonataria": "descarbonatar",
    "descarbonatariam": "descarbonatar",
    "descarbonatarias": "descarbonatar",
    "descarbonatarmo": "descarbonatar",
    "descarbonatarmos": "descarbonatar",
    "descarbonatará": "descarbonatar",
    "descarbonatarás": "descarbonatar",
    "descarbonatarão": "descarbonatar",
    "descarbonataríamos": "descarbonatar",
    "descarbonataríeis": "descarbonatar",
    "descarbonatas": "descarbonatar",
    "descarbonatasse": "descarbonatar",
    "descarbonatassem": "descarbonatar",
    "descarbonatasses": "descarbonatar",
    "descarbonataste": "descarbonatar",
    "descarbonatastes": "descarbonatar",
    "descarbonatava": "descarbonatar",
    "descarbonatavam": "descarbonatar",
    "descarbonatavas": "descarbonatar",
    "descarbonate": "descarbonatar",
    "descarbonatei": "descarbonatar",
    "descarbonateis": "descarbonatar",
    "descarbonatem": "descarbonatar",
    "descarbonatemo": "descarbonatar",
    "descarbonatemos": "descarbonatar",
    "descarbonates": "descarbonatar",
    "descarbonato": "descarbonatar",
    "descarbonatou": "descarbonatar",
    "descarbonatá": "descarbonatar",
    "descarbonatámo": "descarbonatar",
    "descarbonatámos": "descarbonatar",
    "descarbonatáramo": "descarbonatar",
    "descarbonatáramos": "descarbonatar",
    "descarbonatárei": "descarbonatar",
    "descarbonatáreis": "descarbonatar",
    "descarbonatásseis": "descarbonatar",
    "descarbonatássemos": "descarbonatar",
    "descarbonatávamo": "descarbonatar",
    "descarbonatávamos": "descarbonatar",
    "descarbonatávei": "descarbonatar",
    "descarbonatáveis": "descarbonatar",
    "descarbonava": "descarbonar",
    "descarbonavam": "descarbonar",
    "descarbonavas": "descarbonar",
    "descarbone": "descarbonar",
    "descarbonei": "descarbonar",
    "descarboneis": "descarbonar",
    "descarbonem": "descarbonar",
    "descarbonemo": "descarbonar",
    "descarbonemos": "descarbonar",
    "descarbones": "descarbonar",
    "descarboniza": "descarbonizar",
    "descarbonizada": "descarbonizar",
    "descarbonizadas": "descarbonizar",
    "descarbonizado": "descarbonizar",
    "descarbonizados": "descarbonizar",
    "descarbonizai": "descarbonizar",
    "descarbonizais": "descarbonizar",
    "descarbonizam": "descarbonizar",
    "descarbonizamo": "descarbonizar",
    "descarbonizamos": "descarbonizar",
    "descarbonizando": "descarbonizar",
    "descarbonizara": "descarbonizar",
    "descarbonizaram": "descarbonizar",
    "descarbonizaras": "descarbonizar",
    "descarbonizarde": "descarbonizar",
    "descarbonizardes": "descarbonizar",
    "descarbonizare": "descarbonizar",
    "descarbonizarei": "descarbonizar",
    "descarbonizareis": "descarbonizar",
    "descarbonizarem": "descarbonizar",
    "descarbonizaremos": "descarbonizar",
    "descarbonizares": "descarbonizar",
    "descarbonizaria": "descarbonizar",
    "descarbonizariam": "descarbonizar",
    "descarbonizarias": "descarbonizar",
    "descarbonizarmo": "descarbonizar",
    "descarbonizarmos": "descarbonizar",
    "descarbonizará": "descarbonizar",
    "descarbonizarás": "descarbonizar",
    "descarbonizarão": "descarbonizar",
    "descarbonizaríamos": "descarbonizar",
    "descarbonizaríeis": "descarbonizar",
    "descarbonizas": "descarbonizar",
    "descarbonizasse": "descarbonizar",
    "descarbonizassem": "descarbonizar",
    "descarbonizasses": "descarbonizar",
    "descarbonizaste": "descarbonizar",
    "descarbonizastes": "descarbonizar",
    "descarbonizava": "descarbonizar",
    "descarbonizavam": "descarbonizar",
    "descarbonizavas": "descarbonizar",
    "descarbonize": "descarbonizar",
    "descarbonizei": "descarbonizar",
    "descarbonizeis": "descarbonizar",
    "descarbonizem": "descarbonizar",
    "descarbonizemo": "descarbonizar",
    "descarbonizemos": "descarbonizar",
    "descarbonizes": "descarbonizar",
    "descarbonizo": "descarbonizar",
    "descarbonizou": "descarbonizar",
    "descarbonizá": "descarbonizar",
    "descarbonizámo": "descarbonizar",
    "descarbonizámos": "descarbonizar",
    "descarbonizáramo": "descarbonizar",
    "descarbonizáramos": "descarbonizar",
    "descarbonizárei": "descarbonizar",
    "descarbonizáreis": "descarbonizar",
    "descarbonizásseis": "descarbonizar",
    "descarbonizássemos": "descarbonizar",
    "descarbonizávamo": "descarbonizar",
    "descarbonizávamos": "descarbonizar",
    "descarbonizávei": "descarbonizar",
    "descarbonizáveis": "descarbonizar",
    "descarbono": "descarbonar",
    "descarbonou": "descarbonar",
    "descarboná": "descarbonar",
    "descarbonámo": "descarbonar",
    "descarbonámos": "descarbonar",
    "descarbonáramo": "descarbonar",
    "descarbonáramos": "descarbonar",
    "descarbonárei": "descarbonar",
    "descarbonáreis": "descarbonar",
    "descarbonásseis": "descarbonar",
    "descarbonássemos": "descarbonar",
    "descarbonávamo": "descarbonar",
    "descarbonávamos": "descarbonar",
    "descarbonávei": "descarbonar",
    "descarbonáveis": "descarbonar",
    "descarboxilações": "descarboxilação",
    "descarburizações": "descarburização",
    "descare": "descarar",
    "descarece": "descarecer",
    "descarecei": "descarecer",
    "descareceis": "descarecer",
    "descarecem": "descarecer",
    "descarecemo": "descarecer",
    "descarecemos": "descarecer",
    "descarecendo": "descarecer",
    "descarecera": "descarecer",
    "descareceram": "descarecer",
    "descareceras": "descarecer",
    "descarecerdes": "descarecer",
    "descarecerei": "descarecer",
    "descarecereis": "descarecer",
    "descarecerem": "descarecer",
    "descareceremos": "descarecer",
    "descareceres": "descarecer",
    "descareceria": "descarecer",
    "descareceriam": "descarecer",
    "descarecerias": "descarecer",
    "descarecermo": "descarecer",
    "descarecermos": "descarecer",
    "descarecerá": "descarecer",
    "descarecerás": "descarecer",
    "descarecerão": "descarecer",
    "descareceríamos": "descarecer",
    "descareceríeis": "descarecer",
    "descareces": "descarecer",
    "descarecesse": "descarecer",
    "descarecessem": "descarecer",
    "descarecesses": "descarecer",
    "descareceste": "descarecer",
    "descarecestes": "descarecer",
    "descareceu": "descarecer",
    "descareci": "descarecer",
    "descarecia": "descarecer",
    "descareciam": "descarecer",
    "descarecias": "descarecer",
    "descarecida": "descarecer",
    "descarecidas": "descarecer",
    "descarecido": "descarecer",
    "descarecidos": "descarecer",
    "descarecêramo": "descarecer",
    "descarecêramos": "descarecer",
    "descarecêreis": "descarecer",
    "descarecêsseis": "descarecer",
    "descarecêssemos": "descarecer",
    "descarecíamo": "descarecer",
    "descarecíamos": "descarecer",
    "descarecíeis": "descarecer",
    "descarei": "descarar",
    "descareis": "descarar",
    "descarem": "descarar",
    "descaremo": "descarar",
    "descaremos": "descarar",
    "descares": "descarar",
    "descareça": "descarecer",
    "descareçais": "descarecer",
    "descareçam": "descarecer",
    "descareçamo": "descarecer",
    "descareçamos": "descarecer",
    "descareças": "descarecer",
    "descareço": "descarecer",
    "descargas": "descarga",
    "descargos": "descargo",
    "descaridades": "descaridade",
    "descaridosa": "descaridoso",
    "descaridosas": "descaridoso",
    "descaridosos": "descaridoso",
    "descarinhos": "descarinho",
    "descarinhosa": "descarinhoso",
    "descarinhosas": "descarinhoso",
    "descarinhosos": "descarinhoso",
    "descaritativa": "descaritativo",
    "descaritativas": "descaritativo",
    "descaritativos": "descaritativo",
    "descarna": "descarnar",
    "descarnada": "descarnar",
    "descarnadas": "descarnar",
    "descarnado": "descarnar",
    "descarnadora": "descarnador",
    "descarnadoras": "descarnador",
    "descarnadores": "descarnador",
    "descarnados": "descarnar",
    "descarnaduras": "descarnadura",
    "descarnai": "descarnar",
    "descarnais": "descarnar",
    "descarnam": "descarnar",
    "descarnamentos": "descarnamento",
    "descarnamo": "descarnar",
    "descarnamos": "descarnar",
    "descarnando": "descarnar",
    "descarnara": "descarnar",
    "descarnaram": "descarnar",
    "descarnaras": "descarnar",
    "descarnarde": "descarnar",
    "descarnardes": "descarnar",
    "descarnare": "descarnar",
    "descarnarei": "descarnar",
    "descarnareis": "descarnar",
    "descarnarem": "descarnar",
    "descarnaremos": "descarnar",
    "descarnares": "descarnar",
    "descarnaria": "descarnar",
    "descarnariam": "descarnar",
    "descarnarias": "descarnar",
    "descarnarmo": "descarnar",
    "descarnarmos": "descarnar",
    "descarnará": "descarnar",
    "descarnarás": "descarnar",
    "descarnarão": "descarnar",
    "descarnaríamos": "descarnar",
    "descarnaríeis": "descarnar",
    "descarnas": "descarnar",
    "descarnasse": "descarnar",
    "descarnassem": "descarnar",
    "descarnasses": "descarnar",
    "descarnaste": "descarnar",
    "descarnastes": "descarnar",
    "descarnava": "descarnar",
    "descarnavam": "descarnar",
    "descarnavas": "descarnar",
    "descarne": "descarnar",
    "descarnei": "descarnar",
    "descarneis": "descarnar",
    "descarnem": "descarnar",
    "descarnemo": "descarnar",
    "descarnemos": "descarnar",
    "descarnes": "descarnar",
    "descarno": "descarnar",
    "descarnou": "descarnar",
    "descarná": "descarnar",
    "descarnámo": "descarnar",
    "descarnámos": "descarnar",
    "descarnáramo": "descarnar",
    "descarnáramos": "descarnar",
    "descarnárei": "descarnar",
    "descarnáreis": "descarnar",
    "descarnásseis": "descarnar",
    "descarnássemos": "descarnar",
    "descarnávamo": "descarnar",
    "descarnávamos": "descarnar",
    "descarnávei": "descarnar",
    "descarnáveis": "descarnar",
    "descaro": "descarar",
    "descaroce": "descaroçar",
    "descarocei": "descaroçar",
    "descaroceis": "descaroçar",
    "descarocem": "descaroçar",
    "descarocemo": "descaroçar",
    "descarocemos": "descaroçar",
    "descaroces": "descaroçar",
    "descarolada": "descarolado",
    "descaroladas": "descarolado",
    "descaroladora": "descarolador",
    "descaroladoras": "descarolador",
    "descaroladores": "descarolador",
    "descarolados": "descarolado",
    "descaros": "descaro",
    "descarou": "descarar",
    "descaroáveis": "descaroável",
    "descaroça": "descaroçar",
    "descaroçada": "descaroçar",
    "descaroçadas": "descaroçar",
    "descaroçado": "descaroçar",
    "descaroçadora": "descaroçador",
    "descaroçadoras": "descaroçador",
    "descaroçadores": "descaroçador",
    "descaroçados": "descaroçar",
    "descaroçai": "descaroçar",
    "descaroçais": "descaroçar",
    "descaroçam": "descaroçar",
    "descaroçamentos": "descaroçamento",
    "descaroçamo": "descaroçar",
    "descaroçamos": "descaroçar",
    "descaroçando": "descaroçar",
    "descaroçara": "descaroçar",
    "descaroçaram": "descaroçar",
    "descaroçaras": "descaroçar",
    "descaroçarde": "descaroçar",
    "descaroçardes": "descaroçar",
    "descaroçare": "descaroçar",
    "descaroçarei": "descaroçar",
    "descaroçareis": "descaroçar",
    "descaroçarem": "descaroçar",
    "descaroçaremos": "descaroçar",
    "descaroçares": "descaroçar",
    "descaroçaria": "descaroçar",
    "descaroçariam": "descaroçar",
    "descaroçarias": "descaroçar",
    "descaroçarmo": "descaroçar",
    "descaroçarmos": "descaroçar",
    "descaroçará": "descaroçar",
    "descaroçarás": "descaroçar",
    "descaroçarão": "descaroçar",
    "descaroçaríamos": "descaroçar",
    "descaroçaríeis": "descaroçar",
    "descaroças": "descaroçar",
    "descaroçasse": "descaroçar",
    "descaroçassem": "descaroçar",
    "descaroçasses": "descaroçar",
    "descaroçaste": "descaroçar",
    "descaroçastes": "descaroçar",
    "descaroçava": "descaroçar",
    "descaroçavam": "descaroçar",
    "descaroçavas": "descaroçar",
    "descaroço": "descaroçar",
    "descaroçou": "descaroçar",
    "descaroçá": "descaroçar",
    "descaroçámo": "descaroçar",
    "descaroçámos": "descaroçar",
    "descaroçáramo": "descaroçar",
    "descaroçáramos": "descaroçar",
    "descaroçárei": "descaroçar",
    "descaroçáreis": "descaroçar",
    "descaroçásseis": "descaroçar",
    "descaroçássemos": "descaroçar",
    "descaroçávamo": "descaroçar",
    "descaroçávamos": "descaroçar",
    "descaroçávei": "descaroçar",
    "descaroçáveis": "descaroçar",
    "descarrega": "descarregar",
    "descarregada": "descarregar",
    "descarregadas": "descarregar",
    "descarregado": "descarregar",
    "descarregadora": "descarregador",
    "descarregadoras": "descarregador",
    "descarregadores": "descarregador",
    "descarregados": "descarregar",
    "descarregadouros": "descarregadouro",
    "descarregai": "descarregar",
    "descarregais": "descarregar",
    "descarregam": "descarregar",
    "descarregamentos": "descarregamento",
    "descarregamo": "descarregar",
    "descarregamos": "descarregar",
    "descarregando": "descarregar",
    "descarregara": "descarregar",
    "descarregaram": "descarregar",
    "descarregaras": "descarregar",
    "descarregarde": "descarregar",
    "descarregardes": "descarregar",
    "descarregare": "descarregar",
    "descarregarei": "descarregar",
    "descarregareis": "descarregar",
    "descarregarem": "descarregar",
    "descarregaremos": "descarregar",
    "descarregares": "descarregar",
    "descarregaria": "descarregar",
    "descarregariam": "descarregar",
    "descarregarias": "descarregar",
    "descarregarmo": "descarregar",
    "descarregarmos": "descarregar",
    "descarregará": "descarregar",
    "descarregarás": "descarregar",
    "descarregarão": "descarregar",
    "descarregaríamos": "descarregar",
    "descarregaríeis": "descarregar",
    "descarregas": "descarregar",
    "descarregasse": "descarregar",
    "descarregassem": "descarregar",
    "descarregasses": "descarregar",
    "descarregaste": "descarregar",
    "descarregastes": "descarregar",
    "descarregava": "descarregar",
    "descarregavam": "descarregar",
    "descarregavas": "descarregar",
    "descarrego": "descarregar",
    "descarregos": "descarrego",
    "descarregou": "descarregar",
    "descarregue": "descarregar",
    "descarreguei": "descarregar",
    "descarregueis": "descarregar",
    "descarreguem": "descarregar",
    "descarreguemo": "descarregar",
    "descarreguemos": "descarregar",
    "descarregues": "descarregar",
    "descarregá": "descarregar",
    "descarregámo": "descarregar",
    "descarregámos": "descarregar",
    "descarregáramo": "descarregar",
    "descarregáramos": "descarregar",
    "descarregárei": "descarregar",
    "descarregáreis": "descarregar",
    "descarregásseis": "descarregar",
    "descarregássemos": "descarregar",
    "descarregávamo": "descarregar",
    "descarregávamos": "descarregar",
    "descarregávei": "descarregar",
    "descarregáveis": "descarregável",
    "descarreira": "descarreirar",
    "descarreirada": "descarreirar",
    "descarreiradas": "descarreirar",
    "descarreirado": "descarreirar",
    "descarreirados": "descarreirar",
    "descarreirai": "descarreirar",
    "descarreirais": "descarreirar",
    "descarreiram": "descarreirar",
    "descarreiramo": "descarreirar",
    "descarreiramos": "descarreirar",
    "descarreirando": "descarreirar",
    "descarreirara": "descarreirar",
    "descarreiraram": "descarreirar",
    "descarreiraras": "descarreirar",
    "descarreirarde": "descarreirar",
    "descarreirardes": "descarreirar",
    "descarreirare": "descarreirar",
    "descarreirarei": "descarreirar",
    "descarreirareis": "descarreirar",
    "descarreirarem": "descarreirar",
    "descarreiraremos": "descarreirar",
    "descarreirares": "descarreirar",
    "descarreiraria": "descarreirar",
    "descarreirariam": "descarreirar",
    "descarreirarias": "descarreirar",
    "descarreirarmo": "descarreirar",
    "descarreirarmos": "descarreirar",
    "descarreirará": "descarreirar",
    "descarreirarás": "descarreirar",
    "descarreirarão": "descarreirar",
    "descarreiraríamos": "descarreirar",
    "descarreiraríeis": "descarreirar",
    "descarreiras": "descarreirar",
    "descarreirasse": "descarreirar",
    "descarreirassem": "descarreirar",
    "descarreirasses": "descarreirar",
    "descarreiraste": "descarreirar",
    "descarreirastes": "descarreirar",
    "descarreirava": "descarreirar",
    "descarreiravam": "descarreirar",
    "descarreiravas": "descarreirar",
    "descarreire": "descarreirar",
    "descarreirei": "descarreirar",
    "descarreireis": "descarreirar",
    "descarreirem": "descarreirar",
    "descarreiremo": "descarreirar",
    "descarreiremos": "descarreirar",
    "descarreires": "descarreirar",
    "descarreiro": "descarreirar",
    "descarreirou": "descarreirar",
    "descarreirá": "descarreirar",
    "descarreirámo": "descarreirar",
    "descarreirámos": "descarreirar",
    "descarreiráramo": "descarreirar",
    "descarreiráramos": "descarreirar",
    "descarreirárei": "descarreirar",
    "descarreiráreis": "descarreirar",
    "descarreirásseis": "descarreirar",
    "descarreirássemos": "descarreirar",
    "descarreirávamo": "descarreirar",
    "descarreirávamos": "descarreirar",
    "descarreirávei": "descarreirar",
    "descarreiráveis": "descarreirar",
    "descarreta": "descarretar",
    "descarretada": "descarretar",
    "descarretadas": "descarretar",
    "descarretado": "descarretar",
    "descarretados": "descarretar",
    "descarretai": "descarretar",
    "descarretais": "descarretar",
    "descarretam": "descarretar",
    "descarretamo": "descarretar",
    "descarretamos": "descarretar",
    "descarretando": "descarretar",
    "descarretara": "descarretar",
    "descarretaram": "descarretar",
    "descarretaras": "descarretar",
    "descarretarde": "descarretar",
    "descarretardes": "descarretar",
    "descarretare": "descarretar",
    "descarretarei": "descarretar",
    "descarretareis": "descarretar",
    "descarretarem": "descarretar",
    "descarretaremos": "descarretar",
    "descarretares": "descarretar",
    "descarretaria": "descarretar",
    "descarretariam": "descarretar",
    "descarretarias": "descarretar",
    "descarretarmo": "descarretar",
    "descarretarmos": "descarretar",
    "descarretará": "descarretar",
    "descarretarás": "descarretar",
    "descarretarão": "descarretar",
    "descarretaríamos": "descarretar",
    "descarretaríeis": "descarretar",
    "descarretas": "descarretar",
    "descarretasse": "descarretar",
    "descarretassem": "descarretar",
    "descarretasses": "descarretar",
    "descarretaste": "descarretar",
    "descarretastes": "descarretar",
    "descarretava": "descarretar",
    "descarretavam": "descarretar",
    "descarretavas": "descarretar",
    "descarrete": "descarretar",
    "descarretei": "descarretar",
    "descarreteis": "descarretar",
    "descarretem": "descarretar",
    "descarretemo": "descarretar",
    "descarretemos": "descarretar",
    "descarretes": "descarretar",
    "descarreto": "descarretar",
    "descarretou": "descarretar",
    "descarretá": "descarretar",
    "descarretámo": "descarretar",
    "descarretámos": "descarretar",
    "descarretáramo": "descarretar",
    "descarretáramos": "descarretar",
    "descarretárei": "descarretar",
    "descarretáreis": "descarretar",
    "descarretásseis": "descarretar",
    "descarretássemos": "descarretar",
    "descarretávamo": "descarretar",
    "descarretávamos": "descarretar",
    "descarretávei": "descarretar",
    "descarretáveis": "descarretar",
    "descarrila": "descarrilar",
    "descarrilada": "descarrilar",
    "descarriladas": "descarrilar",
    "descarrilado": "descarrilar",
    "descarrilados": "descarrilar",
    "descarrilai": "descarrilar",
    "descarrilais": "descarrilar",
    "descarrilam": "descarrilar",
    "descarrilamentos": "descarrilamento",
    "descarrilamo": "descarrilar",
    "descarrilamos": "descarrilar",
    "descarrilando": "descarrilar",
    "descarrilara": "descarrilar",
    "descarrilaram": "descarrilar",
    "descarrilaras": "descarrilar",
    "descarrilarde": "descarrilar",
    "descarrilardes": "descarrilar",
    "descarrilare": "descarrilar",
    "descarrilarei": "descarrilar",
    "descarrilareis": "descarrilar",
    "descarrilarem": "descarrilar",
    "descarrilaremos": "descarrilar",
    "descarrilares": "descarrilar",
    "descarrilaria": "descarrilar",
    "descarrilariam": "descarrilar",
    "descarrilarias": "descarrilar",
    "descarrilarmo": "descarrilar",
    "descarrilarmos": "descarrilar",
    "descarrilará": "descarrilar",
    "descarrilarás": "descarrilar",
    "descarrilarão": "descarrilar",
    "descarrilaríamos": "descarrilar",
    "descarrilaríeis": "descarrilar",
    "descarrilas": "descarrilar",
    "descarrilasse": "descarrilar",
    "descarrilassem": "descarrilar",
    "descarrilasses": "descarrilar",
    "descarrilaste": "descarrilar",
    "descarrilastes": "descarrilar",
    "descarrilava": "descarrilar",
    "descarrilavam": "descarrilar",
    "descarrilavas": "descarrilar",
    "descarrile": "descarrilar",
    "descarrilei": "descarrilar",
    "descarrileis": "descarrilar",
    "descarrilem": "descarrilar",
    "descarrilemo": "descarrilar",
    "descarrilemos": "descarrilar",
    "descarriles": "descarrilar",
    "descarrilo": "descarrilar",
    "descarrilou": "descarrilar",
    "descarrilá": "descarrilar",
    "descarrilámo": "descarrilar",
    "descarrilámos": "descarrilar",
    "descarriláramo": "descarrilar",
    "descarriláramos": "descarrilar",
    "descarrilárei": "descarrilar",
    "descarriláreis": "descarrilar",
    "descarrilásseis": "descarrilar",
    "descarrilássemos": "descarrilar",
    "descarrilávamo": "descarrilar",
    "descarrilávamos": "descarrilar",
    "descarrilávei": "descarrilar",
    "descarriláveis": "descarrilar",
    "descarta": "descartar",
    "descartada": "descartar",
    "descartadas": "descartar",
    "descartado": "descartar",
    "descartados": "descartar",
    "descartai": "descartar",
    "descartais": "descartar",
    "descartam": "descartar",
    "descartamo": "descartar",
    "descartamos": "descartar",
    "descartando": "descartar",
    "descartara": "descartar",
    "descartaram": "descartar",
    "descartaras": "descartar",
    "descartarde": "descartar",
    "descartardes": "descartar",
    "descartare": "descartar",
    "descartarei": "descartar",
    "descartareis": "descartar",
    "descartarem": "descartar",
    "descartaremos": "descartar",
    "descartares": "descartar",
    "descartaria": "descartar",
    "descartariam": "descartar",
    "descartarias": "descartar",
    "descartarmo": "descartar",
    "descartarmos": "descartar",
    "descartará": "descartar",
    "descartarás": "descartar",
    "descartarão": "descartar",
    "descartaríamos": "descartar",
    "descartaríeis": "descartar",
    "descartas": "descartar",
    "descartasse": "descartar",
    "descartassem": "descartar",
    "descartasses": "descartar",
    "descartaste": "descartar",
    "descartastes": "descartar",
    "descartava": "descartar",
    "descartavam": "descartar",
    "descartavas": "descartar",
    "descarte": "descartar",
    "descartei": "descartar",
    "descarteis": "descartar",
    "descartem": "descartar",
    "descartemo": "descartar",
    "descartemos": "descartar",
    "descartes": "descarte",
    "descarto": "descartar",
    "descartou": "descartar",
    "descartá": "descartar",
    "descartámo": "descartar",
    "descartámos": "descartar",
    "descartáramo": "descartar",
    "descartáramos": "descartar",
    "descartárei": "descartar",
    "descartáreis": "descartar",
    "descartásseis": "descartar",
    "descartássemos": "descartar",
    "descartávamo": "descartar",
    "descartávamos": "descartar",
    "descartávei": "descartar",
    "descartáveis": "descartável",
    "descará": "descarar",
    "descarámo": "descarar",
    "descarámos": "descarar",
    "descaráramo": "descarar",
    "descaráramos": "descarar",
    "descarárei": "descarar",
    "descaráreis": "descarar",
    "descarásseis": "descarar",
    "descarássemos": "descarar",
    "descarávamo": "descarar",
    "descarávamos": "descarar",
    "descarávei": "descarar",
    "descaráveis": "descarar",
    "descasa": "descasar",
    "descasada": "descasar",
    "descasadas": "descasar",
    "descasado": "descasar",
    "descasados": "descasar",
    "descasai": "descasar",
    "descasais": "descasar",
    "descasalada": "descasalado",
    "descasaladas": "descasalado",
    "descasalados": "descasalado",
    "descasam": "descasar",
    "descasamentos": "descasamento",
    "descasamo": "descasar",
    "descasamos": "descasar",
    "descasando": "descasar",
    "descasara": "descasar",
    "descasaram": "descasar",
    "descasaras": "descasar",
    "descasarde": "descasar",
    "descasardes": "descasar",
    "descasare": "descasar",
    "descasarei": "descasar",
    "descasareis": "descasar",
    "descasarem": "descasar",
    "descasaremos": "descasar",
    "descasares": "descasar",
    "descasaria": "descasar",
    "descasariam": "descasar",
    "descasarias": "descasar",
    "descasarmo": "descasar",
    "descasarmos": "descasar",
    "descasará": "descasar",
    "descasarás": "descasar",
    "descasarão": "descasar",
    "descasaríamos": "descasar",
    "descasaríeis": "descasar",
    "descasas": "descasar",
    "descasasse": "descasar",
    "descasassem": "descasar",
    "descasasses": "descasar",
    "descasaste": "descasar",
    "descasastes": "descasar",
    "descasava": "descasar",
    "descasavam": "descasar",
    "descasavas": "descasar",
    "descasca": "descascar",
    "descascada": "descascar",
    "descascadas": "descascar",
    "descascadeiras": "descascadeira",
    "descascadelas": "descascadela",
    "descascado": "descascar",
    "descascadora": "descascador",
    "descascadoras": "descascador",
    "descascadores": "descascador",
    "descascados": "descascar",
    "descascaduras": "descascadura",
    "descascai": "descascar",
    "descascais": "descascar",
    "descascam": "descascar",
    "descascamentos": "descascamento",
    "descascamo": "descascar",
    "descascamos": "descascar",
    "descascando": "descascar",
    "descascara": "descascar",
    "descascaram": "descascar",
    "descascaras": "descascar",
    "descascarde": "descascar",
    "descascardes": "descascar",
    "descascare": "descascar",
    "descascarei": "descascar",
    "descascareis": "descascar",
    "descascarem": "descascar",
    "descascaremos": "descascar",
    "descascares": "descascar",
    "descascaria": "descascar",
    "descascariam": "descascar",
    "descascarias": "descascar",
    "descascarmo": "descascar",
    "descascarmos": "descascar",
    "descascará": "descascar",
    "descascarás": "descascar",
    "descascarão": "descascar",
    "descascaríamos": "descascar",
    "descascaríeis": "descascar",
    "descascas": "descascar",
    "descascasse": "descascar",
    "descascassem": "descascar",
    "descascasses": "descascar",
    "descascaste": "descascar",
    "descascastes": "descascar",
    "descascava": "descascar",
    "descascavam": "descascar",
    "descascavas": "descascar",
    "descascações": "descascação",
    "descasco": "descascar",
    "descascou": "descascar",
    "descascá": "descascar",
    "descascámo": "descascar",
    "descascámos": "descascar",
    "descascáramo": "descascar",
    "descascáramos": "descascar",
    "descascárei": "descascar",
    "descascáreis": "descascar",
    "descascásseis": "descascar",
    "descascássemos": "descascar",
    "descascávamo": "descascar",
    "descascávamos": "descascar",
    "descascávei": "descascar",
    "descascáveis": "descascável",
    "descase": "descasar",
    "descasei": "descasar",
    "descaseis": "descasar",
    "descasem": "descasar",
    "descasemo": "descasar",
    "descasemos": "descasar",
    "descases": "descasar",
    "descaso": "descasar",
    "descasou": "descasar",
    "descaspa": "descaspar",
    "descaspada": "descaspar",
    "descaspadas": "descaspar",
    "descaspado": "descaspar",
    "descaspados": "descaspar",
    "descaspai": "descaspar",
    "descaspais": "descaspar",
    "descaspam": "descaspar",
    "descaspamo": "descaspar",
    "descaspamos": "descaspar",
    "descaspando": "descaspar",
    "descaspara": "descaspar",
    "descasparam": "descaspar",
    "descasparas": "descaspar",
    "descasparde": "descaspar",
    "descaspardes": "descaspar",
    "descaspare": "descaspar",
    "descasparei": "descaspar",
    "descaspareis": "descaspar",
    "descasparem": "descaspar",
    "descasparemos": "descaspar",
    "descaspares": "descaspar",
    "descasparia": "descaspar",
    "descaspariam": "descaspar",
    "descasparias": "descaspar",
    "descasparmo": "descaspar",
    "descasparmos": "descaspar",
    "descaspará": "descaspar",
    "descasparás": "descaspar",
    "descasparão": "descaspar",
    "descasparíamos": "descaspar",
    "descasparíeis": "descaspar",
    "descaspas": "descaspar",
    "descaspasse": "descaspar",
    "descaspassem": "descaspar",
    "descaspasses": "descaspar",
    "descaspaste": "descaspar",
    "descaspastes": "descaspar",
    "descaspava": "descaspar",
    "descaspavam": "descaspar",
    "descaspavas": "descaspar",
    "descaspe": "descaspar",
    "descaspei": "descaspar",
    "descaspeis": "descaspar",
    "descaspem": "descaspar",
    "descaspemo": "descaspar",
    "descaspemos": "descaspar",
    "descaspes": "descaspar",
    "descaspo": "descaspar",
    "descaspou": "descaspar",
    "descaspá": "descaspar",
    "descaspámo": "descaspar",
    "descaspámos": "descaspar",
    "descaspáramo": "descaspar",
    "descaspáramos": "descaspar",
    "descaspárei": "descaspar",
    "descaspáreis": "descaspar",
    "descaspásseis": "descaspar",
    "descaspássemos": "descaspar",
    "descaspávamo": "descaspar",
    "descaspávamos": "descaspar",
    "descaspávei": "descaspar",
    "descaspáveis": "descaspar",
    "descasque": "descascar",
    "descasquea": "descasquear",
    "descasqueada": "descasquear",
    "descasqueadas": "descasquear",
    "descasqueado": "descasquear",
    "descasqueados": "descasquear",
    "descasqueai": "descasquear",
    "descasqueais": "descasquear",
    "descasqueam": "descasquear",
    "descasqueamo": "descasquear",
    "descasqueamos": "descasquear",
    "descasqueando": "descasquear",
    "descasqueara": "descasquear",
    "descasquearam": "descasquear",
    "descasquearas": "descasquear",
    "descasquearde": "descasquear",
    "descasqueardes": "descasquear",
    "descasqueare": "descasquear",
    "descasquearei": "descasquear",
    "descasqueareis": "descasquear",
    "descasquearem": "descasquear",
    "descasquearemos": "descasquear",
    "descasqueares": "descasquear",
    "descasquearia": "descasquear",
    "descasqueariam": "descasquear",
    "descasquearias": "descasquear",
    "descasquearmo": "descasquear",
    "descasquearmos": "descasquear",
    "descasqueará": "descasquear",
    "descasquearás": "descasquear",
    "descasquearão": "descasquear",
    "descasquearíamos": "descasquear",
    "descasquearíeis": "descasquear",
    "descasqueas": "descasquear",
    "descasqueasse": "descasquear",
    "descasqueassem": "descasquear",
    "descasqueasses": "descasquear",
    "descasqueaste": "descasquear",
    "descasqueastes": "descasquear",
    "descasqueava": "descasquear",
    "descasqueavam": "descasquear",
    "descasqueavas": "descasquear",
    "descasquee": "descasquear",
    "descasqueei": "descasquear",
    "descasqueeis": "descasquear",
    "descasqueem": "descasquear",
    "descasqueemo": "descasquear",
    "descasqueemos": "descasquear",
    "descasquees": "descasquear",
    "descasquei": "descascar",
    "descasqueis": "descascar",
    "descasquem": "descascar",
    "descasquemo": "descascar",
    "descasquemos": "descascar",
    "descasqueo": "descasquear",
    "descasqueou": "descasquear",
    "descasques": "descasque",
    "descasqueá": "descasquear",
    "descasqueámo": "descasquear",
    "descasqueámos": "descasquear",
    "descasqueáramo": "descasquear",
    "descasqueáramos": "descasquear",
    "descasqueárei": "descasquear",
    "descasqueáreis": "descasquear",
    "descasqueásseis": "descasquear",
    "descasqueássemos": "descasquear",
    "descasqueávamo": "descasquear",
    "descasqueávamos": "descasquear",
    "descasqueávei": "descasquear",
    "descasqueáveis": "descasquear",
    "descasá": "descasar",
    "descasámo": "descasar",
    "descasámos": "descasar",
    "descasáramo": "descasar",
    "descasáramos": "descasar",
    "descasárei": "descasar",
    "descasáreis": "descasar",
    "descasásseis": "descasar",
    "descasássemos": "descasar",
    "descasávamo": "descasar",
    "descasávamos": "descasar",
    "descasávei": "descasar",
    "descasáveis": "descasar",
    "descativa": "descativar",
    "descativada": "descativar",
    "descativadas": "descativar",
    "descativado": "descativar",
    "descativados": "descativar",
    "descativai": "descativar",
    "descativais": "descativar",
    "descativam": "descativar",
    "descativamo": "descativar",
    "descativamos": "descativar",
    "descativando": "descativar",
    "descativara": "descativar",
    "descativaram": "descativar",
    "descativaras": "descativar",
    "descativarde": "descativar",
    "descativardes": "descativar",
    "descativare": "descativar",
    "descativarei": "descativar",
    "descativareis": "descativar",
    "descativarem": "descativar",
    "descativaremos": "descativar",
    "descativares": "descativar",
    "descativaria": "descativar",
    "descativariam": "descativar",
    "descativarias": "descativar",
    "descativarmo": "descativar",
    "descativarmos": "descativar",
    "descativará": "descativar",
    "descativarás": "descativar",
    "descativarão": "descativar",
    "descativaríamos": "descativar",
    "descativaríeis": "descativar",
    "descativas": "descativar",
    "descativasse": "descativar",
    "descativassem": "descativar",
    "descativasses": "descativar",
    "descativaste": "descativar",
    "descativastes": "descativar",
    "descativava": "descativar",
    "descativavam": "descativar",
    "descativavas": "descativar",
    "descative": "descativar",
    "descativei": "descativar",
    "descativeis": "descativar",
    "descativem": "descativar",
    "descativemo": "descativar",
    "descativemos": "descativar",
    "descatives": "descativar",
    "descativo": "descativar",
    "descativou": "descativar",
    "descativá": "descativar",
    "descativámo": "descativar",
    "descativámos": "descativar",
    "descativáramo": "descativar",
    "descativáramos": "descativar",
    "descativárei": "descativar",
    "descativáreis": "descativar",
    "descativásseis": "descativar",
    "descativássemos": "descativar",
    "descativávamo": "descativar",
    "descativávamos": "descativar",
    "descativávei": "descativar",
    "descativáveis": "descativar",
    "descatoliza": "descatolizar",
    "descatolizada": "descatolizar",
    "descatolizadas": "descatolizar",
    "descatolizado": "descatolizar",
    "descatolizados": "descatolizar",
    "descatolizai": "descatolizar",
    "descatolizais": "descatolizar",
    "descatolizam": "descatolizar",
    "descatolizamo": "descatolizar",
    "descatolizamos": "descatolizar",
    "descatolizando": "descatolizar",
    "descatolizara": "descatolizar",
    "descatolizaram": "descatolizar",
    "descatolizaras": "descatolizar",
    "descatolizarde": "descatolizar",
    "descatolizardes": "descatolizar",
    "descatolizare": "descatolizar",
    "descatolizarei": "descatolizar",
    "descatolizareis": "descatolizar",
    "descatolizarem": "descatolizar",
    "descatolizaremos": "descatolizar",
    "descatolizares": "descatolizar",
    "descatolizaria": "descatolizar",
    "descatolizariam": "descatolizar",
    "descatolizarias": "descatolizar",
    "descatolizarmo": "descatolizar",
    "descatolizarmos": "descatolizar",
    "descatolizará": "descatolizar",
    "descatolizarás": "descatolizar",
    "descatolizarão": "descatolizar",
    "descatolizaríamos": "descatolizar",
    "descatolizaríeis": "descatolizar",
    "descatolizas": "descatolizar",
    "descatolizasse": "descatolizar",
    "descatolizassem": "descatolizar",
    "descatolizasses": "descatolizar",
    "descatolizaste": "descatolizar",
    "descatolizastes": "descatolizar",
    "descatolizava": "descatolizar",
    "descatolizavam": "descatolizar",
    "descatolizavas": "descatolizar",
    "descatolizações": "descatolização",
    "descatolize": "descatolizar",
    "descatolizei": "descatolizar",
    "descatolizeis": "descatolizar",
    "descatolizem": "descatolizar",
    "descatolizemo": "descatolizar",
    "descatolizemos": "descatolizar",
    "descatolizes": "descatolizar",
    "descatolizo": "descatolizar",
    "descatolizou": "descatolizar",
    "descatolizá": "descatolizar",
    "descatolizámo": "descatolizar",
    "descatolizámos": "descatolizar",
    "descatolizáramo": "descatolizar",
    "descatolizáramos": "descatolizar",
    "descatolizárei": "descatolizar",
    "descatolizáreis": "descatolizar",
    "descatolizásseis": "descatolizar",
    "descatolizássemos": "descatolizar",
    "descatolizávamo": "descatolizar",
    "descatolizávamos": "descatolizar",
    "descatolizávei": "descatolizar",
    "descatolizáveis": "descatolizar",
    "descauda": "descaudar",
    "descaudada": "descaudar",
    "descaudadas": "descaudar",
    "descaudado": "descaudar",
    "descaudados": "descaudar",
    "descaudai": "descaudar",
    "descaudais": "descaudar",
    "descaudam": "descaudar",
    "descaudamo": "descaudar",
    "descaudamos": "descaudar",
    "descaudando": "descaudar",
    "descaudara": "descaudar",
    "descaudaram": "descaudar",
    "descaudaras": "descaudar",
    "descaudarde": "descaudar",
    "descaudardes": "descaudar",
    "descaudare": "descaudar",
    "descaudarei": "descaudar",
    "descaudareis": "descaudar",
    "descaudarem": "descaudar",
    "descaudaremos": "descaudar",
    "descaudares": "descaudar",
    "descaudaria": "descaudar",
    "descaudariam": "descaudar",
    "descaudarias": "descaudar",
    "descaudarmo": "descaudar",
    "descaudarmos": "descaudar",
    "descaudará": "descaudar",
    "descaudarás": "descaudar",
    "descaudarão": "descaudar",
    "descaudaríamos": "descaudar",
    "descaudaríeis": "descaudar",
    "descaudas": "descaudar",
    "descaudasse": "descaudar",
    "descaudassem": "descaudar",
    "descaudasses": "descaudar",
    "descaudaste": "descaudar",
    "descaudastes": "descaudar",
    "descaudava": "descaudar",
    "descaudavam": "descaudar",
    "descaudavas": "descaudar",
    "descaude": "descaudar",
    "descaudei": "descaudar",
    "descaudeis": "descaudar",
    "descaudem": "descaudar",
    "descaudemo": "descaudar",
    "descaudemos": "descaudar",
    "descaudes": "descaudar",
    "descaudo": "descaudar",
    "descaudou": "descaudar",
    "descaudá": "descaudar",
    "descaudámo": "descaudar",
    "descaudámos": "descaudar",
    "descaudáramo": "descaudar",
    "descaudáramos": "descaudar",
    "descaudárei": "descaudar",
    "descaudáreis": "descaudar",
    "descaudásseis": "descaudar",
    "descaudássemos": "descaudar",
    "descaudávamo": "descaudar",
    "descaudávamos": "descaudar",
    "descaudávei": "descaudar",
    "descaudáveis": "descaudar",
    "descautelada": "descautelado",
    "descauteladas": "descautelado",
    "descautelados": "descautelado",
    "descautelas": "descautela",
    "descautelosa": "descauteloso",
    "descautelosas": "descauteloso",
    "descautelosos": "descauteloso",
    "descavalga": "descavalgar",
    "descavalgada": "descavalgar",
    "descavalgadas": "descavalgar",
    "descavalgado": "descavalgar",
    "descavalgados": "descavalgar",
    "descavalgai": "descavalgar",
    "descavalgais": "descavalgar",
    "descavalgam": "descavalgar",
    "descavalgamentos": "descavalgamento",
    "descavalgamo": "descavalgar",
    "descavalgamos": "descavalgar",
    "descavalgando": "descavalgar",
    "descavalgara": "descavalgar",
    "descavalgaram": "descavalgar",
    "descavalgaras": "descavalgar",
    "descavalgarde": "descavalgar",
    "descavalgardes": "descavalgar",
    "descavalgare": "descavalgar",
    "descavalgarei": "descavalgar",
    "descavalgareis": "descavalgar",
    "descavalgarem": "descavalgar",
    "descavalgaremos": "descavalgar",
    "descavalgares": "descavalgar",
    "descavalgaria": "descavalgar",
    "descavalgariam": "descavalgar",
    "descavalgarias": "descavalgar",
    "descavalgarmo": "descavalgar",
    "descavalgarmos": "descavalgar",
    "descavalgará": "descavalgar",
    "descavalgarás": "descavalgar",
    "descavalgarão": "descavalgar",
    "descavalgaríamos": "descavalgar",
    "descavalgaríeis": "descavalgar",
    "descavalgas": "descavalgar",
    "descavalgasse": "descavalgar",
    "descavalgassem": "descavalgar",
    "descavalgasses": "descavalgar",
    "descavalgaste": "descavalgar",
    "descavalgastes": "descavalgar",
    "descavalgava": "descavalgar",
    "descavalgavam": "descavalgar",
    "descavalgavas": "descavalgar",
    "descavalgo": "descavalgar",
    "descavalgou": "descavalgar",
    "descavalgue": "descavalgar",
    "descavalguei": "descavalgar",
    "descavalgueis": "descavalgar",
    "descavalguem": "descavalgar",
    "descavalguemo": "descavalgar",
    "descavalguemos": "descavalgar",
    "descavalgues": "descavalgar",
    "descavalgá": "descavalgar",
    "descavalgámo": "descavalgar",
    "descavalgámos": "descavalgar",
    "descavalgáramo": "descavalgar",
    "descavalgáramos": "descavalgar",
    "descavalgárei": "descavalgar",
    "descavalgáreis": "descavalgar",
    "descavalgásseis": "descavalgar",
    "descavalgássemos": "descavalgar",
    "descavalgávamo": "descavalgar",
    "descavalgávamos": "descavalgar",
    "descavalgávei": "descavalgar",
    "descavalgáveis": "descavalgar",
    "descaí": "descair",
    "descaía": "descair",
    "descaíam": "descair",
    "descaíamo": "descair",
    "descaíamos": "descair",
    "descaías": "descair",
    "descaída": "descair",
    "descaídas": "descair",
    "descaído": "descair",
    "descaídos": "descair",
    "descaíei": "descair",
    "descaíeis": "descair",
    "descaímo": "descair",
    "descaímos": "descair",
    "descaíra": "descair",
    "descaíram": "descair",
    "descaíramo": "descair",
    "descaíramos": "descair",
    "descaíras": "descair",
    "descaíre": "descair",
    "descaírei": "descair",
    "descaíreis": "descair",
    "descaírem": "descair",
    "descaíres": "descair",
    "descaís": "descair",
    "descaísse": "descair",
    "descaísseis": "descair",
    "descaíssem": "descair",
    "descaíssemos": "descair",
    "descaísses": "descair",
    "descaíste": "descair",
    "descaístes": "descair",
    "desce": "descer",
    "descedeiras": "descedeira",
    "descega": "descegar",
    "descegada": "descegar",
    "descegadas": "descegar",
    "descegado": "descegar",
    "descegados": "descegar",
    "descegai": "descegar",
    "descegais": "descegar",
    "descegam": "descegar",
    "descegamo": "descegar",
    "descegamos": "descegar",
    "descegando": "descegar",
    "descegara": "descegar",
    "descegaram": "descegar",
    "descegaras": "descegar",
    "descegarde": "descegar",
    "descegardes": "descegar",
    "descegare": "descegar",
    "descegarei": "descegar",
    "descegareis": "descegar",
    "descegarem": "descegar",
    "descegaremos": "descegar",
    "descegares": "descegar",
    "descegaria": "descegar",
    "descegariam": "descegar",
    "descegarias": "descegar",
    "descegarmo": "descegar",
    "descegarmos": "descegar",
    "descegará": "descegar",
    "descegarás": "descegar",
    "descegarão": "descegar",
    "descegaríamos": "descegar",
    "descegaríeis": "descegar",
    "descegas": "descegar",
    "descegasse": "descegar",
    "descegassem": "descegar",
    "descegasses": "descegar",
    "descegaste": "descegar",
    "descegastes": "descegar",
    "descegava": "descegar",
    "descegavam": "descegar",
    "descegavas": "descegar",
    "descego": "descegar",
    "descegou": "descegar",
    "descegue": "descegar",
    "desceguei": "descegar",
    "descegueis": "descegar",
    "desceguem": "descegar",
    "desceguemo": "descegar",
    "desceguemos": "descegar",
    "descegues": "descegar",
    "descegá": "descegar",
    "descegámo": "descegar",
    "descegámos": "descegar",
    "descegáramo": "descegar",
    "descegáramos": "descegar",
    "descegárei": "descegar",
    "descegáreis": "descegar",
    "descegásseis": "descegar",
    "descegássemos": "descegar",
    "descegávamo": "descegar",
    "descegávamos": "descegar",
    "descegávei": "descegar",
    "descegáveis": "descegar",
    "descei": "descer",
    "desceis": "descer",
    "descelula": "descelular",
    "descelulada": "descelular",
    "desceluladas": "descelular",
    "descelulado": "descelular",
    "descelulados": "descelular",
    "descelulai": "descelular",
    "descelulais": "descelular",
    "descelulam": "descelular",
    "descelulamo": "descelular",
    "descelulamos": "descelular",
    "descelulando": "descelular",
    "descelulara": "descelular",
    "descelularam": "descelular",
    "descelularas": "descelular",
    "descelularde": "descelular",
    "descelulardes": "descelular",
    "descelulare": "descelular",
    "descelularei": "descelular",
    "descelulareis": "descelular",
    "descelularem": "descelular",
    "descelularemos": "descelular",
    "descelulares": "descelular",
    "descelularia": "descelular",
    "descelulariam": "descelular",
    "descelularias": "descelular",
    "descelularmo": "descelular",
    "descelularmos": "descelular",
    "descelulará": "descelular",
    "descelularás": "descelular",
    "descelularão": "descelular",
    "descelularíamos": "descelular",
    "descelularíeis": "descelular",
    "descelulas": "descelular",
    "descelulasse": "descelular",
    "descelulassem": "descelular",
    "descelulasses": "descelular",
    "descelulaste": "descelular",
    "descelulastes": "descelular",
    "descelulava": "descelular",
    "descelulavam": "descelular",
    "descelulavas": "descelular",
    "descelule": "descelular",
    "descelulei": "descelular",
    "desceluleis": "descelular",
    "descelulem": "descelular",
    "descelulemo": "descelular",
    "descelulemos": "descelular",
    "descelules": "descelular",
    "descelulo": "descelular",
    "descelulou": "descelular",
    "descelulá": "descelular",
    "descelulámo": "descelular",
    "descelulámos": "descelular",
    "desceluláramo": "descelular",
    "desceluláramos": "descelular",
    "descelulárei": "descelular",
    "desceluláreis": "descelular",
    "descelulásseis": "descelular",
    "descelulássemos": "descelular",
    "descelulávamo": "descelular",
    "descelulávamos": "descelular",
    "descelulávei": "descelular",
    "desceluláveis": "descelular",
    "descem": "descer",
    "descemo": "descer",
    "descemos": "descer",
    "descenda": "descender",
    "descendais": "descender",
    "descendam": "descender",
    "descendamo": "descender",
    "descendamos": "descender",
    "descendas": "descender",
    "descende": "descender",
    "descendei": "descender",
    "descendeis": "descender",
    "descendem": "descender",
    "descendemo": "descender",
    "descendemos": "descender",
    "descendendo": "descender",
    "descendentes": "descendente",
    "descendera": "descender",
    "descenderam": "descender",
    "descenderas": "descender",
    "descenderdes": "descender",
    "descenderei": "descender",
    "descendereis": "descender",
    "descenderem": "descender",
    "descenderemos": "descender",
    "descenderes": "descender",
    "descenderia": "descender",
    "descenderiam": "descender",
    "descenderias": "descender",
    "descendermo": "descender",
    "descendermos": "descender",
    "descenderá": "descender",
    "descenderás": "descender",
    "descenderão": "descender",
    "descenderíamos": "descender",
    "descenderíeis": "descender",
    "descendes": "descender",
    "descendesse": "descender",
    "descendessem": "descender",
    "descendesses": "descender",
    "descendeste": "descender",
    "descendestes": "descender",
    "descendeu": "descender",
    "descendi": "descender",
    "descendia": "descender",
    "descendiam": "descender",
    "descendias": "descender",
    "descendida": "descender",
    "descendidas": "descender",
    "descendido": "descender",
    "descendidos": "descender",
    "descendimentos": "descendimento",
    "descendo": "descer",
    "descendências": "descendência",
    "descendêramo": "descender",
    "descendêramos": "descender",
    "descendêreis": "descender",
    "descendêsseis": "descender",
    "descendêssemos": "descender",
    "descendíamo": "descender",
    "descendíamos": "descender",
    "descendíeis": "descender",
    "descensionais": "descensional",
    "descensos": "descenso",
    "descensões": "descensão",
    "descentes": "descente",
    "descentra": "descentrar",
    "descentrada": "descentrar",
    "descentradas": "descentrar",
    "descentrado": "descentrar",
    "descentrados": "descentrar",
    "descentrai": "descentrar",
    "descentrais": "descentrar",
    "descentralismos": "descentralismo",
    "descentralistas": "descentralista",
    "descentraliza": "descentralizar",
    "descentralizada": "descentralizar",
    "descentralizadas": "descentralizar",
    "descentralizado": "descentralizar",
    "descentralizadora": "descentralizador",
    "descentralizadoras": "descentralizador",
    "descentralizadores": "descentralizador",
    "descentralizados": "descentralizar",
    "descentralizai": "descentralizar",
    "descentralizais": "descentralizar",
    "descentralizam": "descentralizar",
    "descentralizamo": "descentralizar",
    "descentralizamos": "descentralizar",
    "descentralizando": "descentralizar",
    "descentralizara": "descentralizar",
    "descentralizaram": "descentralizar",
    "descentralizaras": "descentralizar",
    "descentralizarde": "descentralizar",
    "descentralizardes": "descentralizar",
    "descentralizare": "descentralizar",
    "descentralizarei": "descentralizar",
    "descentralizareis": "descentralizar",
    "descentralizarem": "descentralizar",
    "descentralizaremos": "descentralizar",
    "descentralizares": "descentralizar",
    "descentralizaria": "descentralizar",
    "descentralizariam": "descentralizar",
    "descentralizarias": "descentralizar",
    "descentralizarmo": "descentralizar",
    "descentralizarmos": "descentralizar",
    "descentralizará": "descentralizar",
    "descentralizarás": "descentralizar",
    "descentralizarão": "descentralizar",
    "descentralizaríamos": "descentralizar",
    "descentralizaríeis": "descentralizar",
    "descentralizas": "descentralizar",
    "descentralizasse": "descentralizar",
    "descentralizassem": "descentralizar",
    "descentralizasses": "descentralizar",
    "descentralizaste": "descentralizar",
    "descentralizastes": "descentralizar",
    "descentralizava": "descentralizar",
    "descentralizavam": "descentralizar",
    "descentralizavas": "descentralizar",
    "descentralizações": "descentralização",
    "descentralize": "descentralizar",
    "descentralizei": "descentralizar",
    "descentralizeis": "descentralizar",
    "descentralizem": "descentralizar",
    "descentralizemo": "descentralizar",
    "descentralizemos": "descentralizar",
    "descentralizes": "descentralizar",
    "descentralizo": "descentralizar",
    "descentralizou": "descentralizar",
    "descentralizá": "descentralizar",
    "descentralizámo": "descentralizar",
    "descentralizámos": "descentralizar",
    "descentralizáramo": "descentralizar",
    "descentralizáramos": "descentralizar",
    "descentralizárei": "descentralizar",
    "descentralizáreis": "descentralizar",
    "descentralizásseis": "descentralizar",
    "descentralizássemos": "descentralizar",
    "descentralizávamo": "descentralizar",
    "descentralizávamos": "descentralizar",
    "descentralizávei": "descentralizar",
    "descentralizáveis": "descentralizável",
    "descentram": "descentrar",
    "descentramo": "descentrar",
    "descentramos": "descentrar",
    "descentrando": "descentrar",
    "descentrara": "descentrar",
    "descentraram": "descentrar",
    "descentraras": "descentrar",
    "descentrarde": "descentrar",
    "descentrardes": "descentrar",
    "descentrare": "descentrar",
    "descentrarei": "descentrar",
    "descentrareis": "descentrar",
    "descentrarem": "descentrar",
    "descentraremos": "descentrar",
    "descentrares": "descentrar",
    "descentraria": "descentrar",
    "descentrariam": "descentrar",
    "descentrarias": "descentrar",
    "descentrarmo": "descentrar",
    "descentrarmos": "descentrar",
    "descentrará": "descentrar",
    "descentrarás": "descentrar",
    "descentrarão": "descentrar",
    "descentraríamos": "descentrar",
    "descentraríeis": "descentrar",
    "descentras": "descentrar",
    "descentrasse": "descentrar",
    "descentrassem": "descentrar",
    "descentrasses": "descentrar",
    "descentraste": "descentrar",
    "descentrastes": "descentrar",
    "descentrava": "descentrar",
    "descentravam": "descentrar",
    "descentravas": "descentrar",
    "descentre": "descentrar",
    "descentrei": "descentrar",
    "descentreis": "descentrar",
    "descentrem": "descentrar",
    "descentremo": "descentrar",
    "descentremos": "descentrar",
    "descentres": "descentrar",
    "descentro": "descentrar",
    "descentrou": "descentrar",
    "descentrá": "descentrar",
    "descentrámo": "descentrar",
    "descentrámos": "descentrar",
    "descentráramo": "descentrar",
    "descentráramos": "descentrar",
    "descentrárei": "descentrar",
    "descentráreis": "descentrar",
    "descentrásseis": "descentrar",
    "descentrássemos": "descentrar",
    "descentrávamo": "descentrar",
    "descentrávamos": "descentrar",
    "descentrávei": "descentrar",
    "descentráveis": "descentrar",
    "descera": "descer",
    "desceram": "descer",
    "desceras": "descer",
    "descerca": "descercar",
    "descercada": "descercar",
    "descercadas": "descercar",
    "descercado": "descercar",
    "descercadora": "descercador",
    "descercadoras": "descercador",
    "descercadores": "descercador",
    "descercados": "descercar",
    "descercai": "descercar",
    "descercais": "descercar",
    "descercam": "descercar",
    "descercamo": "descercar",
    "descercamos": "descercar",
    "descercando": "descercar",
    "descercara": "descercar",
    "descercaram": "descercar",
    "descercaras": "descercar",
    "descercarde": "descercar",
    "descercardes": "descercar",
    "descercare": "descercar",
    "descercarei": "descercar",
    "descercareis": "descercar",
    "descercarem": "descercar",
    "descercaremos": "descercar",
    "descercares": "descercar",
    "descercaria": "descercar",
    "descercariam": "descercar",
    "descercarias": "descercar",
    "descercarmo": "descercar",
    "descercarmos": "descercar",
    "descercará": "descercar",
    "descercarás": "descercar",
    "descercarão": "descercar",
    "descercaríamos": "descercar",
    "descercaríeis": "descercar",
    "descercas": "descercar",
    "descercasse": "descercar",
    "descercassem": "descercar",
    "descercasses": "descercar",
    "descercaste": "descercar",
    "descercastes": "descercar",
    "descercava": "descercar",
    "descercavam": "descercar",
    "descercavas": "descercar",
    "descerco": "descercar",
    "descercos": "descerco",
    "descercou": "descercar",
    "descercá": "descercar",
    "descercámo": "descercar",
    "descercámos": "descercar",
    "descercáramo": "descercar",
    "descercáramos": "descercar",
    "descercárei": "descercar",
    "descercáreis": "descercar",
    "descercásseis": "descercar",
    "descercássemos": "descercar",
    "descercávamo": "descercar",
    "descercávamos": "descercar",
    "descercávei": "descercar",
    "descercáveis": "descercar",
    "descerde": "descer",
    "descerdes": "descer",
    "descere": "descer",
    "descerebra": "descerebrar",
    "descerebrada": "descerebrar",
    "descerebradas": "descerebrar",
    "descerebrado": "descerebrar",
    "descerebrados": "descerebrar",
    "descerebrai": "descerebrar",
    "descerebrais": "descerebrar",
    "descerebram": "descerebrar",
    "descerebramo": "descerebrar",
    "descerebramos": "descerebrar",
    "descerebrando": "descerebrar",
    "descerebrara": "descerebrar",
    "descerebraram": "descerebrar",
    "descerebraras": "descerebrar",
    "descerebrarde": "descerebrar",
    "descerebrardes": "descerebrar",
    "descerebrare": "descerebrar",
    "descerebrarei": "descerebrar",
    "descerebrareis": "descerebrar",
    "descerebrarem": "descerebrar",
    "descerebraremos": "descerebrar",
    "descerebrares": "descerebrar",
    "descerebraria": "descerebrar",
    "descerebrariam": "descerebrar",
    "descerebrarias": "descerebrar",
    "descerebrarmo": "descerebrar",
    "descerebrarmos": "descerebrar",
    "descerebrará": "descerebrar",
    "descerebrarás": "descerebrar",
    "descerebrarão": "descerebrar",
    "descerebraríamos": "descerebrar",
    "descerebraríeis": "descerebrar",
    "descerebras": "descerebrar",
    "descerebrasse": "descerebrar",
    "descerebrassem": "descerebrar",
    "descerebrasses": "descerebrar",
    "descerebraste": "descerebrar",
    "descerebrastes": "descerebrar",
    "descerebrava": "descerebrar",
    "descerebravam": "descerebrar",
    "descerebravas": "descerebrar",
    "descerebrações": "descerebração",
    "descerebre": "descerebrar",
    "descerebrei": "descerebrar",
    "descerebreis": "descerebrar",
    "descerebrem": "descerebrar",
    "descerebremo": "descerebrar",
    "descerebremos": "descerebrar",
    "descerebres": "descerebrar",
    "descerebro": "descerebrar",
    "descerebrou": "descerebrar",
    "descerebrá": "descerebrar",
    "descerebrámo": "descerebrar",
    "descerebrámos": "descerebrar",
    "descerebráramo": "descerebrar",
    "descerebráramos": "descerebrar",
    "descerebrárei": "descerebrar",
    "descerebráreis": "descerebrar",
    "descerebrásseis": "descerebrar",
    "descerebrássemos": "descerebrar",
    "descerebrávamo": "descerebrar",
    "descerebrávamos": "descerebrar",
    "descerebrávei": "descerebrar",
    "descerebráveis": "descerebrar",
    "descerei": "descer",
    "descereis": "descer",
    "descerem": "descer",
    "desceremos": "descer",
    "desceres": "descer",
    "desceria": "descer",
    "desceriam": "descer",
    "descerias": "descer",
    "descerimoniosa": "descerimonioso",
    "descerimoniosas": "descerimonioso",
    "descerimoniosos": "descerimonioso",
    "descerinónias": "descerinónia",
    "descermo": "descer",
    "descermos": "descer",
    "descerque": "descercar",
    "descerquei": "descercar",
    "descerqueis": "descercar",
    "descerquem": "descercar",
    "descerquemo": "descercar",
    "descerquemos": "descercar",
    "descerques": "descercar",
    "descerra": "descerrar",
    "descerrada": "descerrar",
    "descerradas": "descerrar",
    "descerrado": "descerrar",
    "descerrados": "descerrar",
    "descerrai": "descerrar",
    "descerrais": "descerrar",
    "descerram": "descerrar",
    "descerramentos": "descerramento",
    "descerramo": "descerrar",
    "descerramos": "descerrar",
    "descerrando": "descerrar",
    "descerrara": "descerrar",
    "descerraram": "descerrar",
    "descerraras": "descerrar",
    "descerrarde": "descerrar",
    "descerrardes": "descerrar",
    "descerrare": "descerrar",
    "descerrarei": "descerrar",
    "descerrareis": "descerrar",
    "descerrarem": "descerrar",
    "descerraremos": "descerrar",
    "descerrares": "descerrar",
    "descerraria": "descerrar",
    "descerrariam": "descerrar",
    "descerrarias": "descerrar",
    "descerrarmo": "descerrar",
    "descerrarmos": "descerrar",
    "descerrará": "descerrar",
    "descerrarás": "descerrar",
    "descerrarão": "descerrar",
    "descerraríamos": "descerrar",
    "descerraríeis": "descerrar",
    "descerras": "descerrar",
    "descerrasse": "descerrar",
    "descerrassem": "descerrar",
    "descerrasses": "descerrar",
    "descerraste": "descerrar",
    "descerrastes": "descerrar",
    "descerrava": "descerrar",
    "descerravam": "descerrar",
    "descerravas": "descerrar",
    "descerre": "descerrar",
    "descerrei": "descerrar",
    "descerreis": "descerrar",
    "descerrem": "descerrar",
    "descerremo": "descerrar",
    "descerremos": "descerrar",
    "descerres": "descerrar",
    "descerro": "descerrar",
    "descerrou": "descerrar",
    "descerrá": "descerrar",
    "descerrámo": "descerrar",
    "descerrámos": "descerrar",
    "descerráramo": "descerrar",
    "descerráramos": "descerrar",
    "descerrárei": "descerrar",
    "descerráreis": "descerrar",
    "descerrásseis": "descerrar",
    "descerrássemos": "descerrar",
    "descerrávamo": "descerrar",
    "descerrávamos": "descerrar",
    "descerrávei": "descerrar",
    "descerráveis": "descerrar",
    "descerá": "descer",
    "descerás": "descer",
    "descerão": "descer",
    "desceríamos": "descer",
    "desceríeis": "descer",
    "desces": "descer",
    "descesse": "descer",
    "descessem": "descer",
    "descesses": "descer",
    "desceste": "descer",
    "descestes": "descer",
    "desceu": "descer",
    "deschancela": "deschancelar",
    "deschancelada": "deschancelar",
    "deschanceladas": "deschancelar",
    "deschancelado": "deschancelar",
    "deschancelados": "deschancelar",
    "deschancelai": "deschancelar",
    "deschancelais": "deschancelar",
    "deschancelam": "deschancelar",
    "deschancelamo": "deschancelar",
    "deschancelamos": "deschancelar",
    "deschancelando": "deschancelar",
    "deschancelara": "deschancelar",
    "deschancelaram": "deschancelar",
    "deschancelaras": "deschancelar",
    "deschancelarde": "deschancelar",
    "deschancelardes": "deschancelar",
    "deschancelare": "deschancelar",
    "deschancelarei": "deschancelar",
    "deschancelareis": "deschancelar",
    "deschancelarem": "deschancelar",
    "deschancelaremos": "deschancelar",
    "deschancelares": "deschancelar",
    "deschancelaria": "deschancelar",
    "deschancelariam": "deschancelar",
    "deschancelarias": "deschancelar",
    "deschancelarmo": "deschancelar",
    "deschancelarmos": "deschancelar",
    "deschancelará": "deschancelar",
    "deschancelarás": "deschancelar",
    "deschancelarão": "deschancelar",
    "deschancelaríamos": "deschancelar",
    "deschancelaríeis": "deschancelar",
    "deschancelas": "deschancelar",
    "deschancelasse": "deschancelar",
    "deschancelassem": "deschancelar",
    "deschancelasses": "deschancelar",
    "deschancelaste": "deschancelar",
    "deschancelastes": "deschancelar",
    "deschancelava": "deschancelar",
    "deschancelavam": "deschancelar",
    "deschancelavas": "deschancelar",
    "deschancele": "deschancelar",
    "deschancelei": "deschancelar",
    "deschanceleis": "deschancelar",
    "deschancelem": "deschancelar",
    "deschancelemo": "deschancelar",
    "deschancelemos": "deschancelar",
    "deschanceles": "deschancelar",
    "deschancelo": "deschancelar",
    "deschancelou": "deschancelar",
    "deschancelá": "deschancelar",
    "deschancelámo": "deschancelar",
    "deschancelámos": "deschancelar",
    "deschanceláramo": "deschancelar",
    "deschanceláramos": "deschancelar",
    "deschancelárei": "deschancelar",
    "deschanceláreis": "deschancelar",
    "deschancelásseis": "deschancelar",
    "deschancelássemos": "deschancelar",
    "deschancelávamo": "deschancelar",
    "deschancelávamos": "deschancelar",
    "deschancelávei": "deschancelar",
    "deschanceláveis": "deschancelar",
    "deschumba": "deschumbar",
    "deschumbada": "deschumbar",
    "deschumbadas": "deschumbar",
    "deschumbado": "deschumbar",
    "deschumbados": "deschumbar",
    "deschumbai": "deschumbar",
    "deschumbais": "deschumbar",
    "deschumbam": "deschumbar",
    "deschumbamo": "deschumbar",
    "deschumbamos": "deschumbar",
    "deschumbando": "deschumbar",
    "deschumbara": "deschumbar",
    "deschumbaram": "deschumbar",
    "deschumbaras": "deschumbar",
    "deschumbarde": "deschumbar",
    "deschumbardes": "deschumbar",
    "deschumbare": "deschumbar",
    "deschumbarei": "deschumbar",
    "deschumbareis": "deschumbar",
    "deschumbarem": "deschumbar",
    "deschumbaremos": "deschumbar",
    "deschumbares": "deschumbar",
    "deschumbaria": "deschumbar",
    "deschumbariam": "deschumbar",
    "deschumbarias": "deschumbar",
    "deschumbarmo": "deschumbar",
    "deschumbarmos": "deschumbar",
    "deschumbará": "deschumbar",
    "deschumbarás": "deschumbar",
    "deschumbarão": "deschumbar",
    "deschumbaríamos": "deschumbar",
    "deschumbaríeis": "deschumbar",
    "deschumbas": "deschumbar",
    "deschumbasse": "deschumbar",
    "deschumbassem": "deschumbar",
    "deschumbasses": "deschumbar",
    "deschumbaste": "deschumbar",
    "deschumbastes": "deschumbar",
    "deschumbava": "deschumbar",
    "deschumbavam": "deschumbar",
    "deschumbavas": "deschumbar",
    "deschumbe": "deschumbar",
    "deschumbei": "deschumbar",
    "deschumbeis": "deschumbar",
    "deschumbem": "deschumbar",
    "deschumbemo": "deschumbar",
    "deschumbemos": "deschumbar",
    "deschumbes": "deschumbar",
    "deschumbo": "deschumbar",
    "deschumbou": "deschumbar",
    "deschumbá": "deschumbar",
    "deschumbámo": "deschumbar",
    "deschumbámos": "deschumbar",
    "deschumbáramo": "deschumbar",
    "deschumbáramos": "deschumbar",
    "deschumbárei": "deschumbar",
    "deschumbáreis": "deschumbar",
    "deschumbásseis": "deschumbar",
    "deschumbássemos": "deschumbar",
    "deschumbávamo": "deschumbar",
    "deschumbávamos": "deschumbar",
    "deschumbávei": "deschumbar",
    "deschumbáveis": "deschumbar",
    "desci": "descer",
    "descia": "descer",
    "desciam": "descer",
    "descias": "descer",
    "descida": "descido",
    "descidas": "descido",
    "descido": "descer",
    "descidos": "descido",
    "descimbra": "descimbrar",
    "descimbrada": "descimbrar",
    "descimbradas": "descimbrar",
    "descimbrado": "descimbrar",
    "descimbrados": "descimbrar",
    "descimbrai": "descimbrar",
    "descimbrais": "descimbrar",
    "descimbram": "descimbrar",
    "descimbramentos": "descimbramento",
    "descimbramo": "descimbrar",
    "descimbramos": "descimbrar",
    "descimbrando": "descimbrar",
    "descimbrara": "descimbrar",
    "descimbraram": "descimbrar",
    "descimbraras": "descimbrar",
    "descimbrarde": "descimbrar",
    "descimbrardes": "descimbrar",
    "descimbrare": "descimbrar",
    "descimbrarei": "descimbrar",
    "descimbrareis": "descimbrar",
    "descimbrarem": "descimbrar",
    "descimbraremos": "descimbrar",
    "descimbrares": "descimbrar",
    "descimbraria": "descimbrar",
    "descimbrariam": "descimbrar",
    "descimbrarias": "descimbrar",
    "descimbrarmo": "descimbrar",
    "descimbrarmos": "descimbrar",
    "descimbrará": "descimbrar",
    "descimbrarás": "descimbrar",
    "descimbrarão": "descimbrar",
    "descimbraríamos": "descimbrar",
    "descimbraríeis": "descimbrar",
    "descimbras": "descimbrar",
    "descimbrasse": "descimbrar",
    "descimbrassem": "descimbrar",
    "descimbrasses": "descimbrar",
    "descimbraste": "descimbrar",
    "descimbrastes": "descimbrar",
    "descimbrava": "descimbrar",
    "descimbravam": "descimbrar",
    "descimbravas": "descimbrar",
    "descimbre": "descimbrar",
    "descimbrei": "descimbrar",
    "descimbreis": "descimbrar",
    "descimbrem": "descimbrar",
    "descimbremo": "descimbrar",
    "descimbremos": "descimbrar",
    "descimbres": "descimbrar",
    "descimbro": "descimbrar",
    "descimbrou": "descimbrar",
    "descimbrá": "descimbrar",
    "descimbrámo": "descimbrar",
    "descimbrámos": "descimbrar",
    "descimbráramo": "descimbrar",
    "descimbráramos": "descimbrar",
    "descimbrárei": "descimbrar",
    "descimbráreis": "descimbrar",
    "descimbrásseis": "descimbrar",
    "descimbrássemos": "descimbrar",
    "descimbrávamo": "descimbrar",
    "descimbrávamos": "descimbrar",
    "descimbrávei": "descimbrar",
    "descimbráveis": "descimbrar",
    "descimenta": "descimentar",
    "descimentada": "descimentar",
    "descimentadas": "descimentar",
    "descimentado": "descimentar",
    "descimentados": "descimentar",
    "descimentai": "descimentar",
    "descimentais": "descimentar",
    "descimentam": "descimentar",
    "descimentamo": "descimentar",
    "descimentamos": "descimentar",
    "descimentando": "descimentar",
    "descimentara": "descimentar",
    "descimentaram": "descimentar",
    "descimentaras": "descimentar",
    "descimentarde": "descimentar",
    "descimentardes": "descimentar",
    "descimentare": "descimentar",
    "descimentarei": "descimentar",
    "descimentareis": "descimentar",
    "descimentarem": "descimentar",
    "descimentaremos": "descimentar",
    "descimentares": "descimentar",
    "descimentaria": "descimentar",
    "descimentariam": "descimentar",
    "descimentarias": "descimentar",
    "descimentarmo": "descimentar",
    "descimentarmos": "descimentar",
    "descimentará": "descimentar",
    "descimentarás": "descimentar",
    "descimentarão": "descimentar",
    "descimentaríamos": "descimentar",
    "descimentaríeis": "descimentar",
    "descimentas": "descimentar",
    "descimentasse": "descimentar",
    "descimentassem": "descimentar",
    "descimentasses": "descimentar",
    "descimentaste": "descimentar",
    "descimentastes": "descimentar",
    "descimentava": "descimentar",
    "descimentavam": "descimentar",
    "descimentavas": "descimentar",
    "descimentações": "descimentação",
    "descimente": "descimentar",
    "descimentei": "descimentar",
    "descimenteis": "descimentar",
    "descimentem": "descimentar",
    "descimentemo": "descimentar",
    "descimentemos": "descimentar",
    "descimentes": "descimentar",
    "descimento": "descimentar",
    "descimentou": "descimentar",
    "descimentá": "descimentar",
    "descimentámo": "descimentar",
    "descimentámos": "descimentar",
    "descimentáramo": "descimentar",
    "descimentáramos": "descimentar",
    "descimentárei": "descimentar",
    "descimentáreis": "descimentar",
    "descimentásseis": "descimentar",
    "descimentássemos": "descimentar",
    "descimentávamo": "descimentar",
    "descimentávamos": "descimentar",
    "descimentávei": "descimentar",
    "descimentáveis": "descimentar",
    "descinge": "descingir",
    "descingem": "descingir",
    "descinges": "descingir",
    "descingi": "descingir",
    "descingia": "descingir",
    "descingiam": "descingir",
    "descingias": "descingir",
    "descingida": "descingir",
    "descingidas": "descingir",
    "descingido": "descingir",
    "descingidos": "descingir",
    "descingimo": "descingir",
    "descingimos": "descingir",
    "descingindo": "descingir",
    "descingira": "descingir",
    "descingiram": "descingir",
    "descingiras": "descingir",
    "descingirde": "descingir",
    "descingirdes": "descingir",
    "descingire": "descingir",
    "descingirei": "descingir",
    "descingireis": "descingir",
    "descingirem": "descingir",
    "descingiremos": "descingir",
    "descingires": "descingir",
    "descingiria": "descingir",
    "descingiriam": "descingir",
    "descingirias": "descingir",
    "descingirmo": "descingir",
    "descingirmos": "descingir",
    "descingirá": "descingir",
    "descingirás": "descingir",
    "descingirão": "descingir",
    "descingiríamos": "descingir",
    "descingiríeis": "descingir",
    "descingis": "descingir",
    "descingisse": "descingir",
    "descingissem": "descingir",
    "descingisses": "descingir",
    "descingiste": "descingir",
    "descingistes": "descingir",
    "descingiu": "descingir",
    "descingíamo": "descingir",
    "descingíamos": "descingir",
    "descingíei": "descingir",
    "descingíeis": "descingir",
    "descingíramo": "descingir",
    "descingíramos": "descingir",
    "descingírei": "descingir",
    "descingíreis": "descingir",
    "descingísseis": "descingir",
    "descingíssemos": "descingir",
    "descinja": "descingir",
    "descinjais": "descingir",
    "descinjam": "descingir",
    "descinjamo": "descingir",
    "descinjamos": "descingir",
    "descinjas": "descingir",
    "descinjo": "descingir",
    "descinta": "descintar",
    "descintada": "descintar",
    "descintadas": "descintar",
    "descintado": "descintar",
    "descintados": "descintar",
    "descintai": "descintar",
    "descintais": "descintar",
    "descintam": "descintar",
    "descintamo": "descintar",
    "descintamos": "descintar",
    "descintando": "descintar",
    "descintara": "descintar",
    "descintaram": "descintar",
    "descintaras": "descintar",
    "descintarde": "descintar",
    "descintardes": "descintar",
    "descintare": "descintar",
    "descintarei": "descintar",
    "descintareis": "descintar",
    "descintarem": "descintar",
    "descintaremos": "descintar",
    "descintares": "descintar",
    "descintaria": "descintar",
    "descintariam": "descintar",
    "descintarias": "descintar",
    "descintarmo": "descintar",
    "descintarmos": "descintar",
    "descintará": "descintar",
    "descintarás": "descintar",
    "descintarão": "descintar",
    "descintaríamos": "descintar",
    "descintaríeis": "descintar",
    "descintas": "descintar",
    "descintasse": "descintar",
    "descintassem": "descintar",
    "descintasses": "descintar",
    "descintaste": "descintar",
    "descintastes": "descintar",
    "descintava": "descintar",
    "descintavam": "descintar",
    "descintavas": "descintar",
    "descinte": "descintar",
    "descintei": "descintar",
    "descinteis": "descintar",
    "descintem": "descintar",
    "descintemo": "descintar",
    "descintemos": "descintar",
    "descintes": "descintar",
    "descinto": "descintar",
    "descintou": "descintar",
    "descintá": "descintar",
    "descintámo": "descintar",
    "descintámos": "descintar",
    "descintáramo": "descintar",
    "descintáramos": "descintar",
    "descintárei": "descintar",
    "descintáreis": "descintar",
    "descintásseis": "descintar",
    "descintássemos": "descintar",
    "descintávamo": "descintar",
    "descintávamos": "descintar",
    "descintávei": "descintar",
    "descintáveis": "descintar",
    "desciviliza": "descivilizar",
    "descivilizada": "descivilizar",
    "descivilizadas": "descivilizar",
    "descivilizado": "descivilizar",
    "descivilizados": "descivilizar",
    "descivilizai": "descivilizar",
    "descivilizais": "descivilizar",
    "descivilizam": "descivilizar",
    "descivilizamo": "descivilizar",
    "descivilizamos": "descivilizar",
    "descivilizando": "descivilizar",
    "descivilizara": "descivilizar",
    "descivilizaram": "descivilizar",
    "descivilizaras": "descivilizar",
    "descivilizarde": "descivilizar",
    "descivilizardes": "descivilizar",
    "descivilizare": "descivilizar",
    "descivilizarei": "descivilizar",
    "descivilizareis": "descivilizar",
    "descivilizarem": "descivilizar",
    "descivilizaremos": "descivilizar",
    "descivilizares": "descivilizar",
    "descivilizaria": "descivilizar",
    "descivilizariam": "descivilizar",
    "descivilizarias": "descivilizar",
    "descivilizarmo": "descivilizar",
    "descivilizarmos": "descivilizar",
    "descivilizará": "descivilizar",
    "descivilizarás": "descivilizar",
    "descivilizarão": "descivilizar",
    "descivilizaríamos": "descivilizar",
    "descivilizaríeis": "descivilizar",
    "descivilizas": "descivilizar",
    "descivilizasse": "descivilizar",
    "descivilizassem": "descivilizar",
    "descivilizasses": "descivilizar",
    "descivilizaste": "descivilizar",
    "descivilizastes": "descivilizar",
    "descivilizava": "descivilizar",
    "descivilizavam": "descivilizar",
    "descivilizavas": "descivilizar",
    "descivilize": "descivilizar",
    "descivilizei": "descivilizar",
    "descivilizeis": "descivilizar",
    "descivilizem": "descivilizar",
    "descivilizemo": "descivilizar",
    "descivilizemos": "descivilizar",
    "descivilizes": "descivilizar",
    "descivilizo": "descivilizar",
    "descivilizou": "descivilizar",
    "descivilizá": "descivilizar",
    "descivilizámo": "descivilizar",
    "descivilizámos": "descivilizar",
    "descivilizáramo": "descivilizar",
    "descivilizáramos": "descivilizar",
    "descivilizárei": "descivilizar",
    "descivilizáreis": "descivilizar",
    "descivilizásseis": "descivilizar",
    "descivilizássemos": "descivilizar",
    "descivilizávamo": "descivilizar",
    "descivilizávamos": "descivilizar",
    "descivilizávei": "descivilizar",
    "descivilizáveis": "descivilizar",
    "desclaridades": "desclaridade",
    "desclassifica": "desclassificar",
    "desclassificada": "desclassificar",
    "desclassificadas": "desclassificar",
    "desclassificado": "desclassificar",
    "desclassificados": "desclassificar",
    "desclassificai": "desclassificar",
    "desclassificais": "desclassificar",
    "desclassificam": "desclassificar",
    "desclassificamo": "desclassificar",
    "desclassificamos": "desclassificar",
    "desclassificando": "desclassificar",
    "desclassificara": "desclassificar",
    "desclassificaram": "desclassificar",
    "desclassificaras": "desclassificar",
    "desclassificarde": "desclassificar",
    "desclassificardes": "desclassificar",
    "desclassificare": "desclassificar",
    "desclassificarei": "desclassificar",
    "desclassificareis": "desclassificar",
    "desclassificarem": "desclassificar",
    "desclassificaremos": "desclassificar",
    "desclassificares": "desclassificar",
    "desclassificaria": "desclassificar",
    "desclassificariam": "desclassificar",
    "desclassificarias": "desclassificar",
    "desclassificarmo": "desclassificar",
    "desclassificarmos": "desclassificar",
    "desclassificará": "desclassificar",
    "desclassificarás": "desclassificar",
    "desclassificarão": "desclassificar",
    "desclassificaríamos": "desclassificar",
    "desclassificaríeis": "desclassificar",
    "desclassificas": "desclassificar",
    "desclassificasse": "desclassificar",
    "desclassificassem": "desclassificar",
    "desclassificasses": "desclassificar",
    "desclassificaste": "desclassificar",
    "desclassificastes": "desclassificar",
    "desclassificava": "desclassificar",
    "desclassificavam": "desclassificar",
    "desclassificavas": "desclassificar",
    "desclassificações": "desclassificação",
    "desclassifico": "desclassificar",
    "desclassificou": "desclassificar",
    "desclassificá": "desclassificar",
    "desclassificámo": "desclassificar",
    "desclassificámos": "desclassificar",
    "desclassificáramo": "desclassificar",
    "desclassificáramos": "desclassificar",
    "desclassificárei": "desclassificar",
    "desclassificáreis": "desclassificar",
    "desclassificásseis": "desclassificar",
    "desclassificássemos": "desclassificar",
    "desclassificávamo": "desclassificar",
    "desclassificávamos": "desclassificar",
    "desclassificávei": "desclassificar",
    "desclassificáveis": "desclassificável",
    "desclassifique": "desclassificar",
    "desclassifiquei": "desclassificar",
    "desclassifiqueis": "desclassificar",
    "desclassifiquem": "desclassificar",
    "desclassifiquemo": "desclassificar",
    "desclassifiquemos": "desclassificar",
    "desclassifiques": "desclassificar",
    "descloreta": "descloretar",
    "descloretada": "descloretar",
    "descloretadas": "descloretar",
    "descloretado": "descloretar",
    "descloretados": "descloretar",
    "descloretai": "descloretar",
    "descloretais": "descloretar",
    "descloretam": "descloretar",
    "descloretamo": "descloretar",
    "descloretamos": "descloretar",
    "descloretando": "descloretar",
    "descloretara": "descloretar",
    "descloretaram": "descloretar",
    "descloretaras": "descloretar",
    "descloretarde": "descloretar",
    "descloretardes": "descloretar",
    "descloretare": "descloretar",
    "descloretarei": "descloretar",
    "descloretareis": "descloretar",
    "descloretarem": "descloretar",
    "descloretaremos": "descloretar",
    "descloretares": "descloretar",
    "descloretaria": "descloretar",
    "descloretariam": "descloretar",
    "descloretarias": "descloretar",
    "descloretarmo": "descloretar",
    "descloretarmos": "descloretar",
    "descloretará": "descloretar",
    "descloretarás": "descloretar",
    "descloretarão": "descloretar",
    "descloretaríamos": "descloretar",
    "descloretaríeis": "descloretar",
    "descloretas": "descloretar",
    "descloretasse": "descloretar",
    "descloretassem": "descloretar",
    "descloretasses": "descloretar",
    "descloretaste": "descloretar",
    "descloretastes": "descloretar",
    "descloretava": "descloretar",
    "descloretavam": "descloretar",
    "descloretavas": "descloretar",
    "desclorete": "descloretar",
    "descloretei": "descloretar",
    "descloreteis": "descloretar",
    "descloretem": "descloretar",
    "descloretemo": "descloretar",
    "descloretemos": "descloretar",
    "descloretes": "descloretar",
    "descloreto": "descloretar",
    "descloretou": "descloretar",
    "descloretá": "descloretar",
    "descloretámo": "descloretar",
    "descloretámos": "descloretar",
    "descloretáramo": "descloretar",
    "descloretáramos": "descloretar",
    "descloretárei": "descloretar",
    "descloretáreis": "descloretar",
    "descloretásseis": "descloretar",
    "descloretássemos": "descloretar",
    "descloretávamo": "descloretar",
    "descloretávamos": "descloretar",
    "descloretávei": "descloretar",
    "descloretáveis": "descloretar",
    "descoagula": "descoagular",
    "descoagulada": "descoagular",
    "descoaguladas": "descoagular",
    "descoagulado": "descoagular",
    "descoagulados": "descoagular",
    "descoagulai": "descoagular",
    "descoagulais": "descoagular",
    "descoagulam": "descoagular",
    "descoagulamentos": "descoagulamento",
    "descoagulamo": "descoagular",
    "descoagulamos": "descoagular",
    "descoagulando": "descoagular",
    "descoagulantes": "descoagulante",
    "descoagulara": "descoagular",
    "descoagularam": "descoagular",
    "descoagularas": "descoagular",
    "descoagularde": "descoagular",
    "descoagulardes": "descoagular",
    "descoagulare": "descoagular",
    "descoagularei": "descoagular",
    "descoagulareis": "descoagular",
    "descoagularem": "descoagular",
    "descoagularemos": "descoagular",
    "descoagulares": "descoagular",
    "descoagularia": "descoagular",
    "descoagulariam": "descoagular",
    "descoagularias": "descoagular",
    "descoagularmo": "descoagular",
    "descoagularmos": "descoagular",
    "descoagulará": "descoagular",
    "descoagularás": "descoagular",
    "descoagularão": "descoagular",
    "descoagularíamos": "descoagular",
    "descoagularíeis": "descoagular",
    "descoagulas": "descoagular",
    "descoagulasse": "descoagular",
    "descoagulassem": "descoagular",
    "descoagulasses": "descoagular",
    "descoagulaste": "descoagular",
    "descoagulastes": "descoagular",
    "descoagulava": "descoagular",
    "descoagulavam": "descoagular",
    "descoagulavas": "descoagular",
    "descoagulações": "descoagulação",
    "descoagule": "descoagular",
    "descoagulei": "descoagular",
    "descoaguleis": "descoagular",
    "descoagulem": "descoagular",
    "descoagulemo": "descoagular",
    "descoagulemos": "descoagular",
    "descoagules": "descoagular",
    "descoagulo": "descoagular",
    "descoagulou": "descoagular",
    "descoagulá": "descoagular",
    "descoagulámo": "descoagular",
    "descoagulámos": "descoagular",
    "descoaguláramo": "descoagular",
    "descoaguláramos": "descoagular",
    "descoagulárei": "descoagular",
    "descoaguláreis": "descoagular",
    "descoagulásseis": "descoagular",
    "descoagulássemos": "descoagular",
    "descoagulávamo": "descoagular",
    "descoagulávamos": "descoagular",
    "descoagulávei": "descoagular",
    "descoaguláveis": "descoagular",
    "descoalha": "descoalhar",
    "descoalhada": "descoalhar",
    "descoalhadas": "descoalhar",
    "descoalhado": "descoalhar",
    "descoalhados": "descoalhar",
    "descoalhai": "descoalhar",
    "descoalhais": "descoalhar",
    "descoalham": "descoalhar",
    "descoalhamo": "descoalhar",
    "descoalhamos": "descoalhar",
    "descoalhando": "descoalhar",
    "descoalhara": "descoalhar",
    "descoalharam": "descoalhar",
    "descoalharas": "descoalhar",
    "descoalharde": "descoalhar",
    "descoalhardes": "descoalhar",
    "descoalhare": "descoalhar",
    "descoalharei": "descoalhar",
    "descoalhareis": "descoalhar",
    "descoalharem": "descoalhar",
    "descoalharemos": "descoalhar",
    "descoalhares": "descoalhar",
    "descoalharia": "descoalhar",
    "descoalhariam": "descoalhar",
    "descoalharias": "descoalhar",
    "descoalharmo": "descoalhar",
    "descoalharmos": "descoalhar",
    "descoalhará": "descoalhar",
    "descoalharás": "descoalhar",
    "descoalharão": "descoalhar",
    "descoalharíamos": "descoalhar",
    "descoalharíeis": "descoalhar",
    "descoalhas": "descoalhar",
    "descoalhasse": "descoalhar",
    "descoalhassem": "descoalhar",
    "descoalhasses": "descoalhar",
    "descoalhaste": "descoalhar",
    "descoalhastes": "descoalhar",
    "descoalhava": "descoalhar",
    "descoalhavam": "descoalhar",
    "descoalhavas": "descoalhar",
    "descoalhe": "descoalhar",
    "descoalhei": "descoalhar",
    "descoalheis": "descoalhar",
    "descoalhem": "descoalhar",
    "descoalhemo": "descoalhar",
    "descoalhemos": "descoalhar",
    "descoalhes": "descoalhar",
    "descoalho": "descoalhar",
    "descoalhos": "descoalho",
    "descoalhou": "descoalhar",
    "descoalhá": "descoalhar",
    "descoalhámo": "descoalhar",
    "descoalhámos": "descoalhar",
    "descoalháramo": "descoalhar",
    "descoalháramos": "descoalhar",
    "descoalhárei": "descoalhar",
    "descoalháreis": "descoalhar",
    "descoalhásseis": "descoalhar",
    "descoalhássemos": "descoalhar",
    "descoalhávamo": "descoalhar",
    "descoalhávamos": "descoalhar",
    "descoalhávei": "descoalhar",
    "descoalháveis": "descoalhar",
    "descoberta": "descobrir",
    "descobertas": "descobrir",
    "descoberto": "descobrir",
    "descobertos": "descobrir",
    "descobre": "descobrir",
    "descobrem": "descobrir",
    "descobres": "descobrir",
    "descobri": "descobrir",
    "descobria": "descobrir",
    "descobriam": "descobrir",
    "descobrias": "descobrir",
    "descobrida": "descobrir",
    "descobridas": "descobrir",
    "descobrido": "descobrir",
    "descobridora": "descobridor",
    "descobridoras": "descobridor",
    "descobridores": "descobridor",
    "descobridos": "descobrir",
    "descobrimentos": "descobrimento",
    "descobrimo": "descobrir",
    "descobrimos": "descobrir",
    "descobrindo": "descobrir",
    "descobrira": "descobrir",
    "descobriram": "descobrir",
    "descobriras": "descobrir",
    "descobrirde": "descobrir",
    "descobrirdes": "descobrir",
    "descobrire": "descobrir",
    "descobrirei": "descobrir",
    "descobrireis": "descobrir",
    "descobrirem": "descobrir",
    "descobriremos": "descobrir",
    "descobrires": "descobrir",
    "descobriria": "descobrir",
    "descobririam": "descobrir",
    "descobririas": "descobrir",
    "descobrirmo": "descobrir",
    "descobrirmos": "descobrir",
    "descobrirá": "descobrir",
    "descobrirás": "descobrir",
    "descobrirão": "descobrir",
    "descobriríamos": "descobrir",
    "descobriríeis": "descobrir",
    "descobris": "descobrir",
    "descobrisse": "descobrir",
    "descobrissem": "descobrir",
    "descobrisses": "descobrir",
    "descobriste": "descobrir",
    "descobristes": "descobrir",
    "descobriu": "descobrir",
    "descobríamo": "descobrir",
    "descobríamos": "descobrir",
    "descobríei": "descobrir",
    "descobríeis": "descobrir",
    "descobríramo": "descobrir",
    "descobríramos": "descobrir",
    "descobrírei": "descobrir",
    "descobríreis": "descobrir",
    "descobrísseis": "descobrir",
    "descobríssemos": "descobrir",
    "descocha": "descochar",
    "descochada": "descochar",
    "descochadas": "descochar",
    "descochado": "descochar",
    "descochados": "descochar",
    "descochai": "descochar",
    "descochais": "descochar",
    "descocham": "descochar",
    "descochamo": "descochar",
    "descochamos": "descochar",
    "descochando": "descochar",
    "descochara": "descochar",
    "descocharam": "descochar",
    "descocharas": "descochar",
    "descocharde": "descochar",
    "descochardes": "descochar",
    "descochare": "descochar",
    "descocharei": "descochar",
    "descochareis": "descochar",
    "descocharem": "descochar",
    "descocharemos": "descochar",
    "descochares": "descochar",
    "descocharia": "descochar",
    "descochariam": "descochar",
    "descocharias": "descochar",
    "descocharmo": "descochar",
    "descocharmos": "descochar",
    "descochará": "descochar",
    "descocharás": "descochar",
    "descocharão": "descochar",
    "descocharíamos": "descochar",
    "descocharíeis": "descochar",
    "descochas": "descochar",
    "descochasse": "descochar",
    "descochassem": "descochar",
    "descochasses": "descochar",
    "descochaste": "descochar",
    "descochastes": "descochar",
    "descochava": "descochar",
    "descochavam": "descochar",
    "descochavas": "descochar",
    "descoche": "descochar",
    "descochei": "descochar",
    "descocheis": "descochar",
    "descochem": "descochar",
    "descochemo": "descochar",
    "descochemos": "descochar",
    "descoches": "descochar",
    "descocho": "descochar",
    "descochou": "descochar",
    "descochá": "descochar",
    "descochámo": "descochar",
    "descochámos": "descochar",
    "descocháramo": "descochar",
    "descocháramos": "descochar",
    "descochárei": "descochar",
    "descocháreis": "descochar",
    "descochásseis": "descochar",
    "descochássemos": "descochar",
    "descochávamo": "descochar",
    "descochávamos": "descochar",
    "descochávei": "descochar",
    "descocháveis": "descochar",
    "descocos": "descoco",
    "descodifica": "descodificar",
    "descodificada": "descodificar",
    "descodificadas": "descodificar",
    "descodificado": "descodificar",
    "descodificadores": "descodificador",
    "descodificados": "descodificar",
    "descodificai": "descodificar",
    "descodificais": "descodificar",
    "descodificam": "descodificar",
    "descodificamo": "descodificar",
    "descodificamos": "descodificar",
    "descodificando": "descodificar",
    "descodificara": "descodificar",
    "descodificaram": "descodificar",
    "descodificaras": "descodificar",
    "descodificarde": "descodificar",
    "descodificardes": "descodificar",
    "descodificare": "descodificar",
    "descodificarei": "descodificar",
    "descodificareis": "descodificar",
    "descodificarem": "descodificar",
    "descodificaremos": "descodificar",
    "descodificares": "descodificar",
    "descodificaria": "descodificar",
    "descodificariam": "descodificar",
    "descodificarias": "descodificar",
    "descodificarmo": "descodificar",
    "descodificarmos": "descodificar",
    "descodificará": "descodificar",
    "descodificarás": "descodificar",
    "descodificarão": "descodificar",
    "descodificaríamos": "descodificar",
    "descodificaríeis": "descodificar",
    "descodificas": "descodificar",
    "descodificasse": "descodificar",
    "descodificassem": "descodificar",
    "descodificasses": "descodificar",
    "descodificaste": "descodificar",
    "descodificastes": "descodificar",
    "descodificava": "descodificar",
    "descodificavam": "descodificar",
    "descodificavas": "descodificar",
    "descodificações": "descodificação",
    "descodifico": "descodificar",
    "descodificou": "descodificar",
    "descodificá": "descodificar",
    "descodificámo": "descodificar",
    "descodificámos": "descodificar",
    "descodificáramo": "descodificar",
    "descodificáramos": "descodificar",
    "descodificárei": "descodificar",
    "descodificáreis": "descodificar",
    "descodificásseis": "descodificar",
    "descodificássemos": "descodificar",
    "descodificávamo": "descodificar",
    "descodificávamos": "descodificar",
    "descodificávei": "descodificar",
    "descodificáveis": "descodificar",
    "descodifique": "descodificar",
    "descodifiquei": "descodificar",
    "descodifiqueis": "descodificar",
    "descodifiquem": "descodificar",
    "descodifiquemo": "descodificar",
    "descodifiquemos": "descodificar",
    "descodifiques": "descodificar",
    "descofragens": "descofragem",
    "descola": "descolar",
    "descolada": "descolar",
    "descoladas": "descolar",
    "descolado": "descolar",
    "descolados": "descolar",
    "descolagens": "descolagem",
    "descolai": "descolar",
    "descolais": "descolar",
    "descolam": "descolar",
    "descolamentos": "descolamento",
    "descolamo": "descolar",
    "descolamos": "descolar",
    "descolando": "descolar",
    "descolara": "descolar",
    "descolaram": "descolar",
    "descolaras": "descolar",
    "descolarde": "descolar",
    "descolardes": "descolar",
    "descolare": "descolar",
    "descolarei": "descolar",
    "descolareis": "descolar",
    "descolarem": "descolar",
    "descolaremos": "descolar",
    "descolares": "descolar",
    "descolaria": "descolar",
    "descolariam": "descolar",
    "descolarias": "descolar",
    "descolarmo": "descolar",
    "descolarmos": "descolar",
    "descolará": "descolar",
    "descolarás": "descolar",
    "descolarão": "descolar",
    "descolaríamos": "descolar",
    "descolaríeis": "descolar",
    "descolas": "descolar",
    "descolasse": "descolar",
    "descolassem": "descolar",
    "descolasses": "descolar",
    "descolaste": "descolar",
    "descolastes": "descolar",
    "descolava": "descolar",
    "descolavam": "descolar",
    "descolavas": "descolar",
    "descole": "descolar",
    "descolectivações": "descolectivação",
    "descolei": "descolar",
    "descoleis": "descolar",
    "descolem": "descolar",
    "descolemo": "descolar",
    "descolemos": "descolar",
    "descoles": "descolar",
    "descolma": "descolmar",
    "descolmada": "descolmar",
    "descolmadas": "descolmar",
    "descolmado": "descolmar",
    "descolmados": "descolmar",
    "descolmai": "descolmar",
    "descolmais": "descolmar",
    "descolmam": "descolmar",
    "descolmamo": "descolmar",
    "descolmamos": "descolmar",
    "descolmando": "descolmar",
    "descolmara": "descolmar",
    "descolmaram": "descolmar",
    "descolmaras": "descolmar",
    "descolmarde": "descolmar",
    "descolmardes": "descolmar",
    "descolmare": "descolmar",
    "descolmarei": "descolmar",
    "descolmareis": "descolmar",
    "descolmarem": "descolmar",
    "descolmaremos": "descolmar",
    "descolmares": "descolmar",
    "descolmaria": "descolmar",
    "descolmariam": "descolmar",
    "descolmarias": "descolmar",
    "descolmarmo": "descolmar",
    "descolmarmos": "descolmar",
    "descolmará": "descolmar",
    "descolmarás": "descolmar",
    "descolmarão": "descolmar",
    "descolmaríamos": "descolmar",
    "descolmaríeis": "descolmar",
    "descolmas": "descolmar",
    "descolmasse": "descolmar",
    "descolmassem": "descolmar",
    "descolmasses": "descolmar",
    "descolmaste": "descolmar",
    "descolmastes": "descolmar",
    "descolmava": "descolmar",
    "descolmavam": "descolmar",
    "descolmavas": "descolmar",
    "descolme": "descolmar",
    "descolmei": "descolmar",
    "descolmeis": "descolmar",
    "descolmem": "descolmar",
    "descolmemo": "descolmar",
    "descolmemos": "descolmar",
    "descolmes": "descolmar",
    "descolmo": "descolmar",
    "descolmou": "descolmar",
    "descolmá": "descolmar",
    "descolmámo": "descolmar",
    "descolmámos": "descolmar",
    "descolmáramo": "descolmar",
    "descolmáramos": "descolmar",
    "descolmárei": "descolmar",
    "descolmáreis": "descolmar",
    "descolmásseis": "descolmar",
    "descolmássemos": "descolmar",
    "descolmávamo": "descolmar",
    "descolmávamos": "descolmar",
    "descolmávei": "descolmar",
    "descolmáveis": "descolmar",
    "descolo": "descolar",
    "descolonizações": "descolonização",
    "descolonizáveis": "descolonizável",
    "descolora": "descolorir",
    "descolorada": "descolorar",
    "descoloradas": "descolorar",
    "descolorado": "descolorar",
    "descolorados": "descolorar",
    "descolorai": "descolorar",
    "descolorais": "descolorir",
    "descoloram": "descolorir",
    "descoloramo": "descolorir",
    "descoloramos": "descolorir",
    "descolorando": "descolorar",
    "descolorantes": "descolorante",
    "descolorara": "descolorar",
    "descoloraram": "descolorar",
    "descoloraras": "descolorar",
    "descolorarde": "descolorar",
    "descolorardes": "descolorar",
    "descolorare": "descolorar",
    "descolorarei": "descolorar",
    "descolorareis": "descolorar",
    "descolorarem": "descolorar",
    "descoloraremos": "descolorar",
    "descolorares": "descolorar",
    "descoloraria": "descolorar",
    "descolorariam": "descolorar",
    "descolorarias": "descolorar",
    "descolorarmo": "descolorar",
    "descolorarmos": "descolorar",
    "descolorará": "descolorar",
    "descolorarás": "descolorar",
    "descolorarão": "descolorar",
    "descoloraríamos": "descolorar",
    "descoloraríeis": "descolorar",
    "descoloras": "descolorir",
    "descolorasse": "descolorar",
    "descolorassem": "descolorar",
    "descolorasses": "descolorar",
    "descoloraste": "descolorar",
    "descolorastes": "descolorar",
    "descolorava": "descolorar",
    "descoloravam": "descolorar",
    "descoloravas": "descolorar",
    "descolorações": "descoloração",
    "descolore": "descolorir",
    "descolorei": "descolorar",
    "descoloreis": "descolorar",
    "descolorem": "descolorir",
    "descoloremo": "descolorar",
    "descoloremos": "descolorar",
    "descolores": "descolorir",
    "descolori": "descolorir",
    "descoloria": "descolorir",
    "descoloriam": "descolorir",
    "descolorias": "descolorir",
    "descolorida": "descolorir",
    "descoloridas": "descolorir",
    "descolorido": "descolorir",
    "descoloridos": "descolorir",
    "descolorimo": "descolorir",
    "descolorimos": "descolorir",
    "descolorindo": "descolorir",
    "descolorira": "descolorir",
    "descoloriram": "descolorir",
    "descoloriras": "descolorir",
    "descolorirde": "descolorir",
    "descolorirdes": "descolorir",
    "descolorire": "descolorir",
    "descolorirei": "descolorir",
    "descolorireis": "descolorir",
    "descolorirem": "descolorir",
    "descoloriremos": "descolorir",
    "descolorires": "descolorir",
    "descoloriria": "descolorir",
    "descoloririam": "descolorir",
    "descoloririas": "descolorir",
    "descolorirmo": "descolorir",
    "descolorirmos": "descolorir",
    "descolorirá": "descolorir",
    "descolorirás": "descolorir",
    "descolorirão": "descolorir",
    "descoloriríamos": "descolorir",
    "descoloriríeis": "descolorir",
    "descoloris": "descolorir",
    "descolorisse": "descolorir",
    "descolorissem": "descolorir",
    "descolorisses": "descolorir",
    "descoloriste": "descolorir",
    "descoloristes": "descolorir",
    "descoloriu": "descolorir",
    "descoloro": "descolorir",
    "descolorou": "descolorar",
    "descolorá": "descolorar",
    "descolorámo": "descolorar",
    "descolorámos": "descolorar",
    "descoloráramo": "descolorar",
    "descoloráramos": "descolorar",
    "descolorárei": "descolorar",
    "descoloráreis": "descolorar",
    "descolorásseis": "descolorar",
    "descolorássemos": "descolorar",
    "descolorávamo": "descolorar",
    "descolorávamos": "descolorar",
    "descolorávei": "descolorar",
    "descoloráveis": "descolorar",
    "descoloríamo": "descolorir",
    "descoloríamos": "descolorir",
    "descoloríei": "descolorir",
    "descoloríeis": "descolorir",
    "descoloríramo": "descolorir",
    "descoloríramos": "descolorir",
    "descolorírei": "descolorir",
    "descoloríreis": "descolorir",
    "descolorísseis": "descolorir",
    "descoloríssemos": "descolorir",
    "descolou": "descolar",
    "descolá": "descolar",
    "descolámo": "descolar",
    "descolámos": "descolar",
    "descoláramo": "descolar",
    "descoláramos": "descolar",
    "descolárei": "descolar",
    "descoláreis": "descolar",
    "descolásseis": "descolar",
    "descolássemos": "descolar",
    "descolávamo": "descolar",
    "descolávamos": "descolar",
    "descolávei": "descolar",
    "descoláveis": "descolável",
    "descomanda": "descomandar",
    "descomandada": "descomandar",
    "descomandadas": "descomandar",
    "descomandado": "descomandar",
    "descomandados": "descomandar",
    "descomandai": "descomandar",
    "descomandais": "descomandar",
    "descomandam": "descomandar",
    "descomandamo": "descomandar",
    "descomandamos": "descomandar",
    "descomandando": "descomandar",
    "descomandara": "descomandar",
    "descomandaram": "descomandar",
    "descomandaras": "descomandar",
    "descomandarde": "descomandar",
    "descomandardes": "descomandar",
    "descomandare": "descomandar",
    "descomandarei": "descomandar",
    "descomandareis": "descomandar",
    "descomandarem": "descomandar",
    "descomandaremos": "descomandar",
    "descomandares": "descomandar",
    "descomandaria": "descomandar",
    "descomandariam": "descomandar",
    "descomandarias": "descomandar",
    "descomandarmo": "descomandar",
    "descomandarmos": "descomandar",
    "descomandará": "descomandar",
    "descomandarás": "descomandar",
    "descomandarão": "descomandar",
    "descomandaríamos": "descomandar",
    "descomandaríeis": "descomandar",
    "descomandas": "descomandar",
    "descomandasse": "descomandar",
    "descomandassem": "descomandar",
    "descomandasses": "descomandar",
    "descomandaste": "descomandar",
    "descomandastes": "descomandar",
    "descomandava": "descomandar",
    "descomandavam": "descomandar",
    "descomandavas": "descomandar",
    "descomande": "descomandar",
    "descomandei": "descomandar",
    "descomandeis": "descomandar",
    "descomandem": "descomandar",
    "descomandemo": "descomandar",
    "descomandemos": "descomandar",
    "descomandes": "descomandar",
    "descomando": "descomandar",
    "descomandou": "descomandar",
    "descomandá": "descomandar",
    "descomandámo": "descomandar",
    "descomandámos": "descomandar",
    "descomandáramo": "descomandar",
    "descomandáramos": "descomandar",
    "descomandárei": "descomandar",
    "descomandáreis": "descomandar",
    "descomandásseis": "descomandar",
    "descomandássemos": "descomandar",
    "descomandávamo": "descomandar",
    "descomandávamos": "descomandar",
    "descomandávei": "descomandar",
    "descomandáveis": "descomandar",
    "descomede": "descomedir",
    "descomedem": "descomedir",
    "descomedes": "descomedir",
    "descomedi": "descomedir",
    "descomedia": "descomedir",
    "descomediam": "descomedir",
    "descomedias": "descomedir",
    "descomedida": "descomedir",
    "descomedidas": "descomedir",
    "descomedido": "descomedir",
    "descomedidos": "descomedir",
    "descomedimentos": "descomedimento",
    "descomedimo": "descomedir",
    "descomedimos": "descomedir",
    "descomedindo": "descomedir",
    "descomedira": "descomedir",
    "descomediram": "descomedir",
    "descomediras": "descomedir",
    "descomedirde": "descomedir",
    "descomedirdes": "descomedir",
    "descomedire": "descomedir",
    "descomedirei": "descomedir",
    "descomedireis": "descomedir",
    "descomedirem": "descomedir",
    "descomediremos": "descomedir",
    "descomedires": "descomedir",
    "descomediria": "descomedir",
    "descomediriam": "descomedir",
    "descomedirias": "descomedir",
    "descomedirmo": "descomedir",
    "descomedirmos": "descomedir",
    "descomedirá": "descomedir",
    "descomedirás": "descomedir",
    "descomedirão": "descomedir",
    "descomediríamos": "descomedir",
    "descomediríeis": "descomedir",
    "descomedis": "descomedir",
    "descomedisse": "descomedir",
    "descomedissem": "descomedir",
    "descomedisses": "descomedir",
    "descomediste": "descomedir",
    "descomedistes": "descomedir",
    "descomediu": "descomedir",
    "descomedíamo": "descomedir",
    "descomedíamos": "descomedir",
    "descomedíei": "descomedir",
    "descomedíeis": "descomedir",
    "descomedíramo": "descomedir",
    "descomedíramos": "descomedir",
    "descomedírei": "descomedir",
    "descomedíreis": "descomedir",
    "descomedísseis": "descomedir",
    "descomedíssemos": "descomedir",
    "descometa": "descometer",
    "descometais": "descometer",
    "descometam": "descometer",
    "descometamo": "descometer",
    "descometamos": "descometer",
    "descometas": "descometer",
    "descomete": "descometer",
    "descometei": "descometer",
    "descometeis": "descometer",
    "descometem": "descometer",
    "descometemo": "descometer",
    "descometemos": "descometer",
    "descometendo": "descometer",
    "descometera": "descometer",
    "descometeram": "descometer",
    "descometeras": "descometer",
    "descometerde": "descometer",
    "descometerdes": "descometer",
    "descometere": "descometer",
    "descometerei": "descometer",
    "descometereis": "descometer",
    "descometerem": "descometer",
    "descometeremos": "descometer",
    "descometeres": "descometer",
    "descometeria": "descometer",
    "descometeriam": "descometer",
    "descometerias": "descometer",
    "descometermo": "descometer",
    "descometermos": "descometer",
    "descometerá": "descometer",
    "descometerás": "descometer",
    "descometerão": "descometer",
    "descometeríamos": "descometer",
    "descometeríeis": "descometer",
    "descometes": "descometer",
    "descometesse": "descometer",
    "descometessem": "descometer",
    "descometesses": "descometer",
    "descometeste": "descometer",
    "descometestes": "descometer",
    "descometeu": "descometer",
    "descometi": "descometer",
    "descometia": "descometer",
    "descometiam": "descometer",
    "descometias": "descometer",
    "descometida": "descometido",
    "descometidas": "descometido",
    "descometido": "descometer",
    "descometidos": "descometido",
    "descometo": "descometer",
    "descometê": "descometer",
    "descometêramo": "descometer",
    "descometêramos": "descometer",
    "descometêrei": "descometer",
    "descometêreis": "descometer",
    "descometêsseis": "descometer",
    "descometêssemos": "descometer",
    "descometíamo": "descometer",
    "descometíamos": "descometer",
    "descometíei": "descometer",
    "descometíeis": "descometer",
    "descomeça": "descomedir",
    "descomeçais": "descomedir",
    "descomeçam": "descomedir",
    "descomeçamo": "descomedir",
    "descomeçamos": "descomedir",
    "descomeças": "descomedir",
    "descomeço": "descomedir",
    "descomodidades": "descomodidade",
    "descomova": "descomover",
    "descomovais": "descomover",
    "descomovam": "descomover",
    "descomovamo": "descomover",
    "descomovamos": "descomover",
    "descomovas": "descomover",
    "descomove": "descomover",
    "descomovei": "descomover",
    "descomoveis": "descomover",
    "descomovem": "descomover",
    "descomovemo": "descomover",
    "descomovemos": "descomover",
    "descomovendo": "descomover",
    "descomovera": "descomover",
    "descomoveram": "descomover",
    "descomoveras": "descomover",
    "descomoverde": "descomover",
    "descomoverdes": "descomover",
    "descomovere": "descomover",
    "descomoverei": "descomover",
    "descomovereis": "descomover",
    "descomoverem": "descomover",
    "descomoveremos": "descomover",
    "descomoveres": "descomover",
    "descomoveria": "descomover",
    "descomoveriam": "descomover",
    "descomoverias": "descomover",
    "descomovermo": "descomover",
    "descomovermos": "descomover",
    "descomoverá": "descomover",
    "descomoverás": "descomover",
    "descomoverão": "descomover",
    "descomoveríamos": "descomover",
    "descomoveríeis": "descomover",
    "descomoves": "descomover",
    "descomovesse": "descomover",
    "descomovessem": "descomover",
    "descomovesses": "descomover",
    "descomoveste": "descomover",
    "descomovestes": "descomover",
    "descomoveu": "descomover",
    "descomovi": "descomover",
    "descomovia": "descomover",
    "descomoviam": "descomover",
    "descomovias": "descomover",
    "descomovida": "descomover",
    "descomovidas": "descomover",
    "descomovido": "descomover",
    "descomovidos": "descomover",
    "descomovo": "descomover",
    "descomovê": "descomover",
    "descomovêramo": "descomover",
    "descomovêramos": "descomover",
    "descomovêrei": "descomover",
    "descomovêreis": "descomover",
    "descomovêsseis": "descomover",
    "descomovêssemos": "descomover",
    "descomovíamo": "descomover",
    "descomovíamos": "descomover",
    "descomovíei": "descomover",
    "descomovíeis": "descomover",
    "descompadece": "descompadecer",
    "descompadecei": "descompadecer",
    "descompadeceis": "descompadecer",
    "descompadecem": "descompadecer",
    "descompadecemo": "descompadecer",
    "descompadecemos": "descompadecer",
    "descompadecendo": "descompadecer",
    "descompadecera": "descompadecer",
    "descompadeceram": "descompadecer",
    "descompadeceras": "descompadecer",
    "descompadecerde": "descompadecer",
    "descompadecerdes": "descompadecer",
    "descompadecere": "descompadecer",
    "descompadecerei": "descompadecer",
    "descompadecereis": "descompadecer",
    "descompadecerem": "descompadecer",
    "descompadeceremos": "descompadecer",
    "descompadeceres": "descompadecer",
    "descompadeceria": "descompadecer",
    "descompadeceriam": "descompadecer",
    "descompadecerias": "descompadecer",
    "descompadecermo": "descompadecer",
    "descompadecermos": "descompadecer",
    "descompadecerá": "descompadecer",
    "descompadecerás": "descompadecer",
    "descompadecerão": "descompadecer",
    "descompadeceríamos": "descompadecer",
    "descompadeceríeis": "descompadecer",
    "descompadeces": "descompadecer",
    "descompadecesse": "descompadecer",
    "descompadecessem": "descompadecer",
    "descompadecesses": "descompadecer",
    "descompadeceste": "descompadecer",
    "descompadecestes": "descompadecer",
    "descompadeceu": "descompadecer",
    "descompadeci": "descompadecer",
    "descompadecia": "descompadecer",
    "descompadeciam": "descompadecer",
    "descompadecias": "descompadecer",
    "descompadecida": "descompadecer",
    "descompadecidas": "descompadecer",
    "descompadecido": "descompadecer",
    "descompadecidos": "descompadecer",
    "descompadecê": "descompadecer",
    "descompadecêramo": "descompadecer",
    "descompadecêramos": "descompadecer",
    "descompadecêrei": "descompadecer",
    "descompadecêreis": "descompadecer",
    "descompadecêsseis": "descompadecer",
    "descompadecêssemos": "descompadecer",
    "descompadecíamo": "descompadecer",
    "descompadecíamos": "descompadecer",
    "descompadecíei": "descompadecer",
    "descompadecíeis": "descompadecer",
    "descompadeça": "descompadecer",
    "descompadeçais": "descompadecer",
    "descompadeçam": "descompadecer",
    "descompadeçamo": "descompadecer",
    "descompadeçamos": "descompadecer",
    "descompadeças": "descompadecer",
    "descompadeço": "descompadecer",
    "descompagina": "descompaginar",
    "descompaginada": "descompaginar",
    "descompaginadas": "descompaginar",
    "descompaginado": "descompaginar",
    "descompaginados": "descompaginar",
    "descompaginai": "descompaginar",
    "descompaginais": "descompaginar",
    "descompaginam": "descompaginar",
    "descompaginamo": "descompaginar",
    "descompaginamos": "descompaginar",
    "descompaginando": "descompaginar",
    "descompaginara": "descompaginar",
    "descompaginaram": "descompaginar",
    "descompaginaras": "descompaginar",
    "descompaginarde": "descompaginar",
    "descompaginardes": "descompaginar",
    "descompaginare": "descompaginar",
    "descompaginarei": "descompaginar",
    "descompaginareis": "descompaginar",
    "descompaginarem": "descompaginar",
    "descompaginaremos": "descompaginar",
    "descompaginares": "descompaginar",
    "descompaginaria": "descompaginar",
    "descompaginariam": "descompaginar",
    "descompaginarias": "descompaginar",
    "descompaginarmo": "descompaginar",
    "descompaginarmos": "descompaginar",
    "descompaginará": "descompaginar",
    "descompaginarás": "descompaginar",
    "descompaginarão": "descompaginar",
    "descompaginaríamos": "descompaginar",
    "descompaginaríeis": "descompaginar",
    "descompaginas": "descompaginar",
    "descompaginasse": "descompaginar",
    "descompaginassem": "descompaginar",
    "descompaginasses": "descompaginar",
    "descompaginaste": "descompaginar",
    "descompaginastes": "descompaginar",
    "descompaginava": "descompaginar",
    "descompaginavam": "descompaginar",
    "descompaginavas": "descompaginar",
    "descompagine": "descompaginar",
    "descompaginei": "descompaginar",
    "descompagineis": "descompaginar",
    "descompaginem": "descompaginar",
    "descompaginemo": "descompaginar",
    "descompaginemos": "descompaginar",
    "descompagines": "descompaginar",
    "descompagino": "descompaginar",
    "descompaginou": "descompaginar",
    "descompaginá": "descompaginar",
    "descompaginámo": "descompaginar",
    "descompaginámos": "descompaginar",
    "descompagináramo": "descompaginar",
    "descompagináramos": "descompaginar",
    "descompaginárei": "descompaginar",
    "descompagináreis": "descompaginar",
    "descompaginásseis": "descompaginar",
    "descompaginássemos": "descompaginar",
    "descompaginávamo": "descompaginar",
    "descompaginávamos": "descompaginar",
    "descompaginávei": "descompaginar",
    "descompagináveis": "descompaginar",
    "descompaixões": "descompaixão",
    "descompassa": "descompassar",
    "descompassada": "descompassar",
    "descompassadas": "descompassar",
    "descompassado": "descompassar",
    "descompassados": "descompassar",
    "descompassai": "descompassar",
    "descompassais": "descompassar",
    "descompassam": "descompassar",
    "descompassamo": "descompassar",
    "descompassamos": "descompassar",
    "descompassando": "descompassar",
    "descompassara": "descompassar",
    "descompassaram": "descompassar",
    "descompassaras": "descompassar",
    "descompassarde": "descompassar",
    "descompassardes": "descompassar",
    "descompassare": "descompassar",
    "descompassarei": "descompassar",
    "descompassareis": "descompassar",
    "descompassarem": "descompassar",
    "descompassaremos": "descompassar",
    "descompassares": "descompassar",
    "descompassaria": "descompassar",
    "descompassariam": "descompassar",
    "descompassarias": "descompassar",
    "descompassarmo": "descompassar",
    "descompassarmos": "descompassar",
    "descompassará": "descompassar",
    "descompassarás": "descompassar",
    "descompassarão": "descompassar",
    "descompassaríamos": "descompassar",
    "descompassaríeis": "descompassar",
    "descompassas": "descompassar",
    "descompassasse": "descompassar",
    "descompassassem": "descompassar",
    "descompassasses": "descompassar",
    "descompassaste": "descompassar",
    "descompassastes": "descompassar",
    "descompassava": "descompassar",
    "descompassavam": "descompassar",
    "descompassavas": "descompassar",
    "descompasse": "descompassar",
    "descompassei": "descompassar",
    "descompasseis": "descompassar",
    "descompassem": "descompassar",
    "descompassemo": "descompassar",
    "descompassemos": "descompassar",
    "descompasses": "descompassar",
    "descompassiva": "descompassivo",
    "descompassivas": "descompassivo",
    "descompassivos": "descompassivo",
    "descompasso": "descompassar",
    "descompassos": "descompasso",
    "descompassou": "descompassar",
    "descompassá": "descompassar",
    "descompassámo": "descompassar",
    "descompassámos": "descompassar",
    "descompassáramo": "descompassar",
    "descompassáramos": "descompassar",
    "descompassárei": "descompassar",
    "descompassáreis": "descompassar",
    "descompassásseis": "descompassar",
    "descompassássemos": "descompassar",
    "descompassávamo": "descompassar",
    "descompassávamos": "descompassar",
    "descompassávei": "descompassar",
    "descompassáveis": "descompassar",
    "descompensa": "descompensar",
    "descompensada": "descompensar",
    "descompensadas": "descompensar",
    "descompensado": "descompensar",
    "descompensados": "descompensar",
    "descompensai": "descompensar",
    "descompensais": "descompensar",
    "descompensam": "descompensar",
    "descompensamo": "descompensar",
    "descompensamos": "descompensar",
    "descompensando": "descompensar",
    "descompensara": "descompensar",
    "descompensaram": "descompensar",
    "descompensaras": "descompensar",
    "descompensarde": "descompensar",
    "descompensardes": "descompensar",
    "descompensare": "descompensar",
    "descompensarei": "descompensar",
    "descompensareis": "descompensar",
    "descompensarem": "descompensar",
    "descompensaremos": "descompensar",
    "descompensares": "descompensar",
    "descompensaria": "descompensar",
    "descompensariam": "descompensar",
    "descompensarias": "descompensar",
    "descompensarmo": "descompensar",
    "descompensarmos": "descompensar",
    "descompensará": "descompensar",
    "descompensarás": "descompensar",
    "descompensarão": "descompensar",
    "descompensaríamos": "descompensar",
    "descompensaríeis": "descompensar",
    "descompensas": "descompensar",
    "descompensasse": "descompensar",
    "descompensassem": "descompensar",
    "descompensasses": "descompensar",
    "descompensaste": "descompensar",
    "descompensastes": "descompensar",
    "descompensava": "descompensar",
    "descompensavam": "descompensar",
    "descompensavas": "descompensar",
    "descompensações": "descompensação",
    "descompense": "descompensar",
    "descompensei": "descompensar",
    "descompenseis": "descompensar",
    "descompensem": "descompensar",
    "descompensemo": "descompensar",
    "descompensemos": "descompensar",
    "descompenses": "descompensar",
    "descompenso": "descompensar",
    "descompensou": "descompensar",
    "descompensá": "descompensar",
    "descompensámo": "descompensar",
    "descompensámos": "descompensar",
    "descompensáramo": "descompensar",
    "descompensáramos": "descompensar",
    "descompensárei": "descompensar",
    "descompensáreis": "descompensar",
    "descompensásseis": "descompensar",
    "descompensássemos": "descompensar",
    "descompensávamo": "descompensar",
    "descompensávamos": "descompensar",
    "descompensávei": "descompensar",
    "descompensáveis": "descompensar",
    "descomplexada": "descomplexado",
    "descomplexadas": "descomplexado",
    "descomplexados": "descomplexado",
    "descomplexadíssima": "descomplexado",
    "descomplexadíssimas": "descomplexado",
    "descomplexadíssimo": "descomplexado",
    "descomplexadíssimos": "descomplexado",
    "descomplica": "descomplicar",
    "descomplicada": "descomplicar",
    "descomplicadas": "descomplicar",
    "descomplicado": "descomplicar",
    "descomplicados": "descomplicar",
    "descomplicai": "descomplicar",
    "descomplicais": "descomplicar",
    "descomplicam": "descomplicar",
    "descomplicamo": "descomplicar",
    "descomplicamos": "descomplicar",
    "descomplicando": "descomplicar",
    "descomplicara": "descomplicar",
    "descomplicaram": "descomplicar",
    "descomplicaras": "descomplicar",
    "descomplicarde": "descomplicar",
    "descomplicardes": "descomplicar",
    "descomplicare": "descomplicar",
    "descomplicarei": "descomplicar",
    "descomplicareis": "descomplicar",
    "descomplicarem": "descomplicar",
    "descomplicaremos": "descomplicar",
    "descomplicares": "descomplicar",
    "descomplicaria": "descomplicar",
    "descomplicariam": "descomplicar",
    "descomplicarias": "descomplicar",
    "descomplicarmo": "descomplicar",
    "descomplicarmos": "descomplicar",
    "descomplicará": "descomplicar",
    "descomplicarás": "descomplicar",
    "descomplicarão": "descomplicar",
    "descomplicaríamos": "descomplicar",
    "descomplicaríeis": "descomplicar",
    "descomplicas": "descomplicar",
    "descomplicasse": "descomplicar",
    "descomplicassem": "descomplicar",
    "descomplicasses": "descomplicar",
    "descomplicaste": "descomplicar",
    "descomplicastes": "descomplicar",
    "descomplicava": "descomplicar",
    "descomplicavam": "descomplicar",
    "descomplicavas": "descomplicar",
    "descomplicações": "descomplicação",
    "descomplico": "descomplicar",
    "descomplicou": "descomplicar",
    "descomplicá": "descomplicar",
    "descomplicámo": "descomplicar",
    "descomplicámos": "descomplicar",
    "descomplicáramo": "descomplicar",
    "descomplicáramos": "descomplicar",
    "descomplicárei": "descomplicar",
    "descomplicáreis": "descomplicar",
    "descomplicásseis": "descomplicar",
    "descomplicássemos": "descomplicar",
    "descomplicávamo": "descomplicar",
    "descomplicávamos": "descomplicar",
    "descomplicávei": "descomplicar",
    "descomplicáveis": "descomplicar",
    "descomplique": "descomplicar",
    "descompliquei": "descomplicar",
    "descompliqueis": "descomplicar",
    "descompliquem": "descomplicar",
    "descompliquemo": "descomplicar",
    "descompliquemos": "descomplicar",
    "descompliques": "descomplicar",
    "descompomo": "descompor",
    "descompomos": "descompor",
    "descomponde": "descompor",
    "descompondes": "descompor",
    "descompondo": "descompor",
    "descomponendas": "descomponenda",
    "descomponha": "descompor",
    "descomponhais": "descompor",
    "descomponham": "descompor",
    "descomponhamo": "descompor",
    "descomponhamos": "descompor",
    "descomponhas": "descompor",
    "descomponho": "descompor",
    "descomporde": "descompor",
    "descompordes": "descompor",
    "descompore": "descompor",
    "descomporei": "descompor",
    "descomporeis": "descompor",
    "descomporem": "descompor",
    "descomporemos": "descompor",
    "descompores": "descompor",
    "descomporia": "descompor",
    "descomporiam": "descompor",
    "descomporias": "descompor",
    "descompormo": "descompor",
    "descompormos": "descompor",
    "descomporá": "descompor",
    "descomporás": "descompor",
    "descomporão": "descompor",
    "descomporíamos": "descompor",
    "descomporíeis": "descompor",
    "descomposições": "descomposição",
    "descomposta": "descomposto",
    "descompostas": "descomposto",
    "descomposto": "descompor",
    "descompostos": "descomposto",
    "descomposturas": "descompostura",
    "descompraz": "descomprazer",
    "descompraza": "descomprazer",
    "descomprazam": "descomprazer",
    "descomprazem": "descomprazer",
    "descomprazendo": "descomprazer",
    "descomprazerem": "descomprazer",
    "descomprazeria": "descomprazer",
    "descomprazeriam": "descomprazer",
    "descomprazerá": "descomprazer",
    "descomprazerão": "descomprazer",
    "descomprazia": "descomprazer",
    "descompraziam": "descomprazer",
    "descomprazida": "descomprazer",
    "descomprazidas": "descomprazer",
    "descomprazido": "descomprazer",
    "descomprazidos": "descomprazer",
    "descompressiva": "descompressivo",
    "descompressivas": "descompressivo",
    "descompressivos": "descompressivo",
    "descompressões": "descompressão",
    "descomprima": "descomprimir",
    "descomprimais": "descomprimir",
    "descomprimam": "descomprimir",
    "descomprimamo": "descomprimir",
    "descomprimamos": "descomprimir",
    "descomprimas": "descomprimir",
    "descomprime": "descomprimir",
    "descomprimem": "descomprimir",
    "descomprimes": "descomprimir",
    "descomprimi": "descomprimir",
    "descomprimia": "descomprimir",
    "descomprimiam": "descomprimir",
    "descomprimias": "descomprimir",
    "descomprimida": "descomprimir",
    "descomprimidas": "descomprimir",
    "descomprimido": "descomprimir",
    "descomprimidos": "descomprimir",
    "descomprimimo": "descomprimir",
    "descomprimimos": "descomprimir",
    "descomprimindo": "descomprimir",
    "descomprimira": "descomprimir",
    "descomprimiram": "descomprimir",
    "descomprimiras": "descomprimir",
    "descomprimirde": "descomprimir",
    "descomprimirdes": "descomprimir",
    "descomprimire": "descomprimir",
    "descomprimirei": "descomprimir",
    "descomprimireis": "descomprimir",
    "descomprimirem": "descomprimir",
    "descomprimiremos": "descomprimir",
    "descomprimires": "descomprimir",
    "descomprimiria": "descomprimir",
    "descomprimiriam": "descomprimir",
    "descomprimirias": "descomprimir",
    "descomprimirmo": "descomprimir",
    "descomprimirmos": "descomprimir",
    "descomprimirá": "descomprimir",
    "descomprimirás": "descomprimir",
    "descomprimirão": "descomprimir",
    "descomprimiríamos": "descomprimir",
    "descomprimiríeis": "descomprimir",
    "descomprimis": "descomprimir",
    "descomprimisse": "descomprimir",
    "descomprimissem": "descomprimir",
    "descomprimisses": "descomprimir",
    "descomprimiste": "descomprimir",
    "descomprimistes": "descomprimir",
    "descomprimiu": "descomprimir",
    "descomprimo": "descomprimir",
    "descomprimíamo": "descomprimir",
    "descomprimíamos": "descomprimir",
    "descomprimíei": "descomprimir",
    "descomprimíeis": "descomprimir",
    "descomprimíramo": "descomprimir",
    "descomprimíramos": "descomprimir",
    "descomprimírei": "descomprimir",
    "descomprimíreis": "descomprimir",
    "descomprimísseis": "descomprimir",
    "descomprimíssemos": "descomprimir",
    "descomprometida": "descomprometido",
    "descomprometidas": "descomprometido",
    "descomprometidos": "descomprometido",
    "descomprometimentos": "descomprometimento",
    "descomprouve": "descomprazer",
    "descomprouver": "descomprazer",
    "descomprouvera": "descomprazer",
    "descomprouveram": "descomprazer",
    "descomprouverem": "descomprazer",
    "descomprouvesse": "descomprazer",
    "descomprouvessem": "descomprazer",
    "descompunha": "descompor",
    "descompunham": "descompor",
    "descompunhas": "descompor",
    "descompus": "descompor",
    "descompusemo": "descompor",
    "descompusemos": "descompor",
    "descompuser": "descompor",
    "descompusera": "descompor",
    "descompuseram": "descompor",
    "descompuseras": "descompor",
    "descompuserdes": "descompor",
    "descompuserem": "descompor",
    "descompuseres": "descompor",
    "descompusermos": "descompor",
    "descompusesse": "descompor",
    "descompusessem": "descompor",
    "descompusesses": "descompor",
    "descompuseste": "descompor",
    "descompusestes": "descompor",
    "descompuséramo": "descompor",
    "descompuséramos": "descompor",
    "descompusérei": "descompor",
    "descompuséreis": "descompor",
    "descompusésseis": "descompor",
    "descompuséssemos": "descompor",
    "descompô": "descompor",
    "descompôs": "descompor",
    "descompõe": "descompor",
    "descompõem": "descompor",
    "descompões": "descompor",
    "descompúnhamo": "descompor",
    "descompúnhamos": "descompor",
    "descompúnhei": "descompor",
    "descompúnheis": "descompor",
    "descomunais": "descomunal",
    "descomunalidades": "descomunalidade",
    "descomunizáveis": "descomunizável",
    "desconceitos": "desconceito",
    "desconceitua": "desconceituar",
    "desconceituada": "desconceituar",
    "desconceituadas": "desconceituar",
    "desconceituado": "desconceituar",
    "desconceituados": "desconceituar",
    "desconceituai": "desconceituar",
    "desconceituais": "desconceituar",
    "desconceituam": "desconceituar",
    "desconceituamo": "desconceituar",
    "desconceituamos": "desconceituar",
    "desconceituando": "desconceituar",
    "desconceituara": "desconceituar",
    "desconceituaram": "desconceituar",
    "desconceituaras": "desconceituar",
    "desconceituarde": "desconceituar",
    "desconceituardes": "desconceituar",
    "desconceituare": "desconceituar",
    "desconceituarei": "desconceituar",
    "desconceituareis": "desconceituar",
    "desconceituarem": "desconceituar",
    "desconceituaremos": "desconceituar",
    "desconceituares": "desconceituar",
    "desconceituaria": "desconceituar",
    "desconceituariam": "desconceituar",
    "desconceituarias": "desconceituar",
    "desconceituarmo": "desconceituar",
    "desconceituarmos": "desconceituar",
    "desconceituará": "desconceituar",
    "desconceituarás": "desconceituar",
    "desconceituarão": "desconceituar",
    "desconceituaríamos": "desconceituar",
    "desconceituaríeis": "desconceituar",
    "desconceituas": "desconceituar",
    "desconceituasse": "desconceituar",
    "desconceituassem": "desconceituar",
    "desconceituasses": "desconceituar",
    "desconceituaste": "desconceituar",
    "desconceituastes": "desconceituar",
    "desconceituava": "desconceituar",
    "desconceituavam": "desconceituar",
    "desconceituavas": "desconceituar",
    "desconceitue": "desconceituar",
    "desconceituei": "desconceituar",
    "desconceitueis": "desconceituar",
    "desconceituem": "desconceituar",
    "desconceituemo": "desconceituar",
    "desconceituemos": "desconceituar",
    "desconceitues": "desconceituar",
    "desconceituo": "desconceituar",
    "desconceituou": "desconceituar",
    "desconceituá": "desconceituar",
    "desconceituámo": "desconceituar",
    "desconceituámos": "desconceituar",
    "desconceituáramo": "desconceituar",
    "desconceituáramos": "desconceituar",
    "desconceituárei": "desconceituar",
    "desconceituáreis": "desconceituar",
    "desconceituásseis": "desconceituar",
    "desconceituássemos": "desconceituar",
    "desconceituávamo": "desconceituar",
    "desconceituávamos": "desconceituar",
    "desconceituávei": "desconceituar",
    "desconceituáveis": "desconceituar",
    "desconcentra": "desconcentrar",
    "desconcentrada": "desconcentrar",
    "desconcentradas": "desconcentrar",
    "desconcentrado": "desconcentrar",
    "desconcentrados": "desconcentrar",
    "desconcentrai": "desconcentrar",
    "desconcentrais": "desconcentrar",
    "desconcentram": "desconcentrar",
    "desconcentramo": "desconcentrar",
    "desconcentramos": "desconcentrar",
    "desconcentrando": "desconcentrar",
    "desconcentrara": "desconcentrar",
    "desconcentraram": "desconcentrar",
    "desconcentraras": "desconcentrar",
    "desconcentrarde": "desconcentrar",
    "desconcentrardes": "desconcentrar",
    "desconcentrare": "desconcentrar",
    "desconcentrarei": "desconcentrar",
    "desconcentrareis": "desconcentrar",
    "desconcentrarem": "desconcentrar",
    "desconcentraremos": "desconcentrar",
    "desconcentrares": "desconcentrar",
    "desconcentraria": "desconcentrar",
    "desconcentrariam": "desconcentrar",
    "desconcentrarias": "desconcentrar",
    "desconcentrarmo": "desconcentrar",
    "desconcentrarmos": "desconcentrar",
    "desconcentrará": "desconcentrar",
    "desconcentrarás": "desconcentrar",
    "desconcentrarão": "desconcentrar",
    "desconcentraríamos": "desconcentrar",
    "desconcentraríeis": "desconcentrar",
    "desconcentras": "desconcentrar",
    "desconcentrasse": "desconcentrar",
    "desconcentrassem": "desconcentrar",
    "desconcentrasses": "desconcentrar",
    "desconcentraste": "desconcentrar",
    "desconcentrastes": "desconcentrar",
    "desconcentrava": "desconcentrar",
    "desconcentravam": "desconcentrar",
    "desconcentravas": "desconcentrar",
    "desconcentrações": "desconcentração",
    "desconcentre": "desconcentrar",
    "desconcentrei": "desconcentrar",
    "desconcentreis": "desconcentrar",
    "desconcentrem": "desconcentrar",
    "desconcentremo": "desconcentrar",
    "desconcentremos": "desconcentrar",
    "desconcentres": "desconcentrar",
    "desconcentro": "desconcentrar",
    "desconcentrou": "desconcentrar",
    "desconcentrá": "desconcentrar",
    "desconcentrámo": "desconcentrar",
    "desconcentrámos": "desconcentrar",
    "desconcentráramo": "desconcentrar",
    "desconcentráramos": "desconcentrar",
    "desconcentrárei": "desconcentrar",
    "desconcentráreis": "desconcentrar",
    "desconcentrásseis": "desconcentrar",
    "desconcentrássemos": "desconcentrar",
    "desconcentrávamo": "desconcentrar",
    "desconcentrávamos": "desconcentrar",
    "desconcentrávei": "desconcentrar",
    "desconcentráveis": "desconcentrar",
    "desconcerta": "desconcertar",
    "desconcertada": "desconcertar",
    "desconcertadas": "desconcertar",
    "desconcertado": "desconcertar",
    "desconcertadora": "desconcertador",
    "desconcertadoras": "desconcertador",
    "desconcertadores": "desconcertador",
    "desconcertados": "desconcertar",
    "desconcertai": "desconcertar",
    "desconcertais": "desconcertar",
    "desconcertam": "desconcertar",
    "desconcertamo": "desconcertar",
    "desconcertamos": "desconcertar",
    "desconcertando": "desconcertar",
    "desconcertantes": "desconcertante",
    "desconcertara": "desconcertar",
    "desconcertaram": "desconcertar",
    "desconcertaras": "desconcertar",
    "desconcertarde": "desconcertar",
    "desconcertardes": "desconcertar",
    "desconcertare": "desconcertar",
    "desconcertarei": "desconcertar",
    "desconcertareis": "desconcertar",
    "desconcertarem": "desconcertar",
    "desconcertaremos": "desconcertar",
    "desconcertares": "desconcertar",
    "desconcertaria": "desconcertar",
    "desconcertariam": "desconcertar",
    "desconcertarias": "desconcertar",
    "desconcertarmo": "desconcertar",
    "desconcertarmos": "desconcertar",
    "desconcertará": "desconcertar",
    "desconcertarás": "desconcertar",
    "desconcertarão": "desconcertar",
    "desconcertaríamos": "desconcertar",
    "desconcertaríeis": "desconcertar",
    "desconcertas": "desconcertar",
    "desconcertasse": "desconcertar",
    "desconcertassem": "desconcertar",
    "desconcertasses": "desconcertar",
    "desconcertaste": "desconcertar",
    "desconcertastes": "desconcertar",
    "desconcertava": "desconcertar",
    "desconcertavam": "desconcertar",
    "desconcertavas": "desconcertar",
    "desconcerte": "desconcertar",
    "desconcertei": "desconcertar",
    "desconcerteis": "desconcertar",
    "desconcertem": "desconcertar",
    "desconcertemo": "desconcertar",
    "desconcertemos": "desconcertar",
    "desconcertes": "desconcertar",
    "desconcerto": "desconcertar",
    "desconcertos": "desconcerto",
    "desconcertou": "desconcertar",
    "desconcertá": "desconcertar",
    "desconcertámo": "desconcertar",
    "desconcertámos": "desconcertar",
    "desconcertáramo": "desconcertar",
    "desconcertáramos": "desconcertar",
    "desconcertárei": "desconcertar",
    "desconcertáreis": "desconcertar",
    "desconcertásseis": "desconcertar",
    "desconcertássemos": "desconcertar",
    "desconcertávamo": "desconcertar",
    "desconcertávamos": "desconcertar",
    "desconcertávei": "desconcertar",
    "desconcertáveis": "desconcertar",
    "desconchava": "desconchavar",
    "desconchavada": "desconchavar",
    "desconchavadas": "desconchavar",
    "desconchavado": "desconchavar",
    "desconchavados": "desconchavar",
    "desconchavai": "desconchavar",
    "desconchavais": "desconchavar",
    "desconchavam": "desconchavar",
    "desconchavamo": "desconchavar",
    "desconchavamos": "desconchavar",
    "desconchavando": "desconchavar",
    "desconchavara": "desconchavar",
    "desconchavaram": "desconchavar",
    "desconchavaras": "desconchavar",
    "desconchavarde": "desconchavar",
    "desconchavardes": "desconchavar",
    "desconchavare": "desconchavar",
    "desconchavarei": "desconchavar",
    "desconchavareis": "desconchavar",
    "desconchavarem": "desconchavar",
    "desconchavaremos": "desconchavar",
    "desconchavares": "desconchavar",
    "desconchavaria": "desconchavar",
    "desconchavariam": "desconchavar",
    "desconchavarias": "desconchavar",
    "desconchavarmo": "desconchavar",
    "desconchavarmos": "desconchavar",
    "desconchavará": "desconchavar",
    "desconchavarás": "desconchavar",
    "desconchavarão": "desconchavar",
    "desconchavaríamos": "desconchavar",
    "desconchavaríeis": "desconchavar",
    "desconchavas": "desconchavar",
    "desconchavasse": "desconchavar",
    "desconchavassem": "desconchavar",
    "desconchavasses": "desconchavar",
    "desconchavaste": "desconchavar",
    "desconchavastes": "desconchavar",
    "desconchavava": "desconchavar",
    "desconchavavam": "desconchavar",
    "desconchavavas": "desconchavar",
    "desconchave": "desconchavar",
    "desconchavei": "desconchavar",
    "desconchaveis": "desconchavar",
    "desconchavem": "desconchavar",
    "desconchavemo": "desconchavar",
    "desconchavemos": "desconchavar",
    "desconchaves": "desconchavar",
    "desconchavo": "desconchavar",
    "desconchavos": "desconchavo",
    "desconchavou": "desconchavar",
    "desconchavá": "desconchavar",
    "desconchavámo": "desconchavar",
    "desconchavámos": "desconchavar",
    "desconchaváramo": "desconchavar",
    "desconchaváramos": "desconchavar",
    "desconchavárei": "desconchavar",
    "desconchaváreis": "desconchavar",
    "desconchavásseis": "desconchavar",
    "desconchavássemos": "desconchavar",
    "desconchavávamo": "desconchavar",
    "desconchavávamos": "desconchavar",
    "desconchavávei": "desconchavar",
    "desconchaváveis": "desconchavar",
    "desconchega": "desconchegar",
    "desconchegada": "desconchegar",
    "desconchegadas": "desconchegar",
    "desconchegado": "desconchegar",
    "desconchegados": "desconchegar",
    "desconchegai": "desconchegar",
    "desconchegais": "desconchegar",
    "desconchegam": "desconchegar",
    "desconchegamo": "desconchegar",
    "desconchegamos": "desconchegar",
    "desconchegando": "desconchegar",
    "desconchegara": "desconchegar",
    "desconchegaram": "desconchegar",
    "desconchegaras": "desconchegar",
    "desconchegarde": "desconchegar",
    "desconchegardes": "desconchegar",
    "desconchegare": "desconchegar",
    "desconchegarei": "desconchegar",
    "desconchegareis": "desconchegar",
    "desconchegarem": "desconchegar",
    "desconchegaremos": "desconchegar",
    "desconchegares": "desconchegar",
    "desconchegaria": "desconchegar",
    "desconchegariam": "desconchegar",
    "desconchegarias": "desconchegar",
    "desconchegarmo": "desconchegar",
    "desconchegarmos": "desconchegar",
    "desconchegará": "desconchegar",
    "desconchegarás": "desconchegar",
    "desconchegarão": "desconchegar",
    "desconchegaríamos": "desconchegar",
    "desconchegaríeis": "desconchegar",
    "desconchegas": "desconchegar",
    "desconchegasse": "desconchegar",
    "desconchegassem": "desconchegar",
    "desconchegasses": "desconchegar",
    "desconchegaste": "desconchegar",
    "desconchegastes": "desconchegar",
    "desconchegava": "desconchegar",
    "desconchegavam": "desconchegar",
    "desconchegavas": "desconchegar",
    "desconchego": "desconchegar",
    "desconchegos": "desconchego",
    "desconchegou": "desconchegar",
    "desconchegue": "desconchegar",
    "desconcheguei": "desconchegar",
    "desconchegueis": "desconchegar",
    "desconcheguem": "desconchegar",
    "desconcheguemo": "desconchegar",
    "desconcheguemos": "desconchegar",
    "desconchegues": "desconchegar",
    "desconchegá": "desconchegar",
    "desconchegámo": "desconchegar",
    "desconchegámos": "desconchegar",
    "desconchegáramo": "desconchegar",
    "desconchegáramos": "desconchegar",
    "desconchegárei": "desconchegar",
    "desconchegáreis": "desconchegar",
    "desconchegásseis": "desconchegar",
    "desconchegássemos": "desconchegar",
    "desconchegávamo": "desconchegar",
    "desconchegávamos": "desconchegar",
    "desconchegávei": "desconchegar",
    "desconchegáveis": "desconchegar",
    "desconcilia": "desconciliar",
    "desconciliada": "desconciliar",
    "desconciliadas": "desconciliar",
    "desconciliado": "desconciliar",
    "desconciliados": "desconciliar",
    "desconciliai": "desconciliar",
    "desconciliais": "desconciliar",
    "desconciliam": "desconciliar",
    "desconciliamo": "desconciliar",
    "desconciliamos": "desconciliar",
    "desconciliando": "desconciliar",
    "desconciliara": "desconciliar",
    "desconciliaram": "desconciliar",
    "desconciliaras": "desconciliar",
    "desconciliarde": "desconciliar",
    "desconciliardes": "desconciliar",
    "desconciliare": "desconciliar",
    "desconciliarei": "desconciliar",
    "desconciliareis": "desconciliar",
    "desconciliarem": "desconciliar",
    "desconciliaremos": "desconciliar",
    "desconciliares": "desconciliar",
    "desconciliaria": "desconciliar",
    "desconciliariam": "desconciliar",
    "desconciliarias": "desconciliar",
    "desconciliarmo": "desconciliar",
    "desconciliarmos": "desconciliar",
    "desconciliará": "desconciliar",
    "desconciliarás": "desconciliar",
    "desconciliarão": "desconciliar",
    "desconciliaríamos": "desconciliar",
    "desconciliaríeis": "desconciliar",
    "desconcilias": "desconciliar",
    "desconciliasse": "desconciliar",
    "desconciliassem": "desconciliar",
    "desconciliasses": "desconciliar",
    "desconciliaste": "desconciliar",
    "desconciliastes": "desconciliar",
    "desconciliava": "desconciliar",
    "desconciliavam": "desconciliar",
    "desconciliavas": "desconciliar",
    "desconciliações": "desconciliação",
    "desconcilie": "desconciliar",
    "desconciliei": "desconciliar",
    "desconcilieis": "desconciliar",
    "desconciliem": "desconciliar",
    "desconciliemo": "desconciliar",
    "desconciliemos": "desconciliar",
    "desconcilies": "desconciliar",
    "desconcilio": "desconciliar",
    "desconciliou": "desconciliar",
    "desconciliá": "desconciliar",
    "desconciliámo": "desconciliar",
    "desconciliámos": "desconciliar",
    "desconciliáramo": "desconciliar",
    "desconciliáramos": "desconciliar",
    "desconciliárei": "desconciliar",
    "desconciliáreis": "desconciliar",
    "desconciliásseis": "desconciliar",
    "desconciliássemos": "desconciliar",
    "desconciliávamo": "desconciliar",
    "desconciliávamos": "desconciliar",
    "desconciliávei": "desconciliar",
    "desconciliáveis": "desconciliar",
    "desconcorda": "desconcordar",
    "desconcordada": "desconcordar",
    "desconcordadas": "desconcordar",
    "desconcordado": "desconcordar",
    "desconcordados": "desconcordar",
    "desconcordai": "desconcordar",
    "desconcordais": "desconcordar",
    "desconcordam": "desconcordar",
    "desconcordamo": "desconcordar",
    "desconcordamos": "desconcordar",
    "desconcordando": "desconcordar",
    "desconcordantes": "desconcordante",
    "desconcordara": "desconcordar",
    "desconcordaram": "desconcordar",
    "desconcordaras": "desconcordar",
    "desconcordardes": "desconcordar",
    "desconcordarei": "desconcordar",
    "desconcordareis": "desconcordar",
    "desconcordarem": "desconcordar",
    "desconcordaremos": "desconcordar",
    "desconcordares": "desconcordar",
    "desconcordaria": "desconcordar",
    "desconcordariam": "desconcordar",
    "desconcordarias": "desconcordar",
    "desconcordarmo": "desconcordar",
    "desconcordarmos": "desconcordar",
    "desconcordará": "desconcordar",
    "desconcordarás": "desconcordar",
    "desconcordarão": "desconcordar",
    "desconcordaríamos": "desconcordar",
    "desconcordaríeis": "desconcordar",
    "desconcordas": "desconcordar",
    "desconcordasse": "desconcordar",
    "desconcordassem": "desconcordar",
    "desconcordasses": "desconcordar",
    "desconcordaste": "desconcordar",
    "desconcordastes": "desconcordar",
    "desconcordava": "desconcordar",
    "desconcordavam": "desconcordar",
    "desconcordavas": "desconcordar",
    "desconcorde": "desconcordar",
    "desconcordei": "desconcordar",
    "desconcordeis": "desconcordar",
    "desconcordem": "desconcordar",
    "desconcordemo": "desconcordar",
    "desconcordemos": "desconcordar",
    "desconcordes": "desconcorde",
    "desconcordo": "desconcordar",
    "desconcordou": "desconcordar",
    "desconcordámo": "desconcordar",
    "desconcordámos": "desconcordar",
    "desconcordáramo": "desconcordar",
    "desconcordáramos": "desconcordar",
    "desconcordáreis": "desconcordar",
    "desconcordásseis": "desconcordar",
    "desconcordássemos": "desconcordar",
    "desconcordávamo": "desconcordar",
    "desconcordávamos": "desconcordar",
    "desconcordáveis": "desconcordar",
    "desconcordâncias": "desconcordância",
    "desconcórdias": "desconcórdia",
    "descondensa": "descondensar",
    "descondensada": "descondensar",
    "descondensadas": "descondensar",
    "descondensado": "descondensar",
    "descondensados": "descondensar",
    "descondensai": "descondensar",
    "descondensais": "descondensar",
    "descondensam": "descondensar",
    "descondensamo": "descondensar",
    "descondensamos": "descondensar",
    "descondensando": "descondensar",
    "descondensara": "descondensar",
    "descondensaram": "descondensar",
    "descondensaras": "descondensar",
    "descondensarde": "descondensar",
    "descondensardes": "descondensar",
    "descondensare": "descondensar",
    "descondensarei": "descondensar",
    "descondensareis": "descondensar",
    "descondensarem": "descondensar",
    "descondensaremos": "descondensar",
    "descondensares": "descondensar",
    "descondensaria": "descondensar",
    "descondensariam": "descondensar",
    "descondensarias": "descondensar",
    "descondensarmo": "descondensar",
    "descondensarmos": "descondensar",
    "descondensará": "descondensar",
    "descondensarás": "descondensar",
    "descondensarão": "descondensar",
    "descondensaríamos": "descondensar",
    "descondensaríeis": "descondensar",
    "descondensas": "descondensar",
    "descondensasse": "descondensar",
    "descondensassem": "descondensar",
    "descondensasses": "descondensar",
    "descondensaste": "descondensar",
    "descondensastes": "descondensar",
    "descondensava": "descondensar",
    "descondensavam": "descondensar",
    "descondensavas": "descondensar",
    "descondense": "descondensar",
    "descondensei": "descondensar",
    "descondenseis": "descondensar",
    "descondensem": "descondensar",
    "descondensemo": "descondensar",
    "descondensemos": "descondensar",
    "descondenses": "descondensar",
    "descondenso": "descondensar",
    "descondensou": "descondensar",
    "descondensá": "descondensar",
    "descondensámo": "descondensar",
    "descondensámos": "descondensar",
    "descondensáramo": "descondensar",
    "descondensáramos": "descondensar",
    "descondensárei": "descondensar",
    "descondensáreis": "descondensar",
    "descondensásseis": "descondensar",
    "descondensássemos": "descondensar",
    "descondensávamo": "descondensar",
    "descondensávamos": "descondensar",
    "descondensávei": "descondensar",
    "descondensáveis": "descondensar",
    "descondiga": "descondizer",
    "descondigais": "descondizer",
    "descondigam": "descondizer",
    "descondigamo": "descondizer",
    "descondigamos": "descondizer",
    "descondigas": "descondizer",
    "descondigo": "descondizer",
    "descondirei": "descondizer",
    "descondireis": "descondizer",
    "descondiremos": "descondizer",
    "descondiria": "descondizer",
    "descondiriam": "descondizer",
    "descondirias": "descondizer",
    "descondirá": "descondizer",
    "descondirás": "descondizer",
    "descondirão": "descondizer",
    "descondiríamos": "descondizer",
    "descondiríeis": "descondizer",
    "descondisse": "descondizer",
    "descondissemo": "descondizer",
    "descondissemos": "descondizer",
    "descondisser": "descondizer",
    "descondissera": "descondizer",
    "descondisseram": "descondizer",
    "descondisseras": "descondizer",
    "descondisserdes": "descondizer",
    "descondisserem": "descondizer",
    "descondisseres": "descondizer",
    "descondissermos": "descondizer",
    "descondissesse": "descondizer",
    "descondissessem": "descondizer",
    "descondissesses": "descondizer",
    "descondisseste": "descondizer",
    "descondissestes": "descondizer",
    "descondisséramo": "descondizer",
    "descondisséramos": "descondizer",
    "descondisséreis": "descondizer",
    "descondissésseis": "descondizer",
    "descondisséssemos": "descondizer",
    "descondita": "descondizer",
    "desconditas": "descondizer",
    "descondito": "descondizer",
    "desconditos": "descondizer",
    "descondiz": "descondizer",
    "descondize": "descondizer",
    "descondizei": "descondizer",
    "descondizeis": "descondizer",
    "descondizem": "descondizer",
    "descondizemo": "descondizer",
    "descondizemos": "descondizer",
    "descondizendo": "descondizer",
    "descondizentes": "descondizente",
    "descondizerdes": "descondizer",
    "descondizerem": "descondizer",
    "descondizeres": "descondizer",
    "descondizermo": "descondizer",
    "descondizermos": "descondizer",
    "descondizes": "descondizer",
    "descondizia": "descondizer",
    "descondiziam": "descondizer",
    "descondizias": "descondizer",
    "descondizíamo": "descondizer",
    "descondizíamos": "descondizer",
    "descondizíeis": "descondizer",
    "desconexa": "desconexo",
    "desconexas": "desconexo",
    "desconexos": "desconexo",
    "desconexões": "desconexão",
    "desconfeita": "desconfeito",
    "desconfeitas": "desconfeito",
    "desconfeitos": "desconfeito",
    "desconfessa": "desconfessar",
    "desconfessada": "desconfessar",
    "desconfessadas": "desconfessar",
    "desconfessado": "desconfessar",
    "desconfessados": "desconfessar",
    "desconfessai": "desconfessar",
    "desconfessais": "desconfessar",
    "desconfessam": "desconfessar",
    "desconfessamo": "desconfessar",
    "desconfessamos": "desconfessar",
    "desconfessando": "desconfessar",
    "desconfessara": "desconfessar",
    "desconfessaram": "desconfessar",
    "desconfessaras": "desconfessar",
    "desconfessarde": "desconfessar",
    "desconfessardes": "desconfessar",
    "desconfessare": "desconfessar",
    "desconfessarei": "desconfessar",
    "desconfessareis": "desconfessar",
    "desconfessarem": "desconfessar",
    "desconfessaremos": "desconfessar",
    "desconfessares": "desconfessar",
    "desconfessaria": "desconfessar",
    "desconfessariam": "desconfessar",
    "desconfessarias": "desconfessar",
    "desconfessarmo": "desconfessar",
    "desconfessarmos": "desconfessar",
    "desconfessará": "desconfessar",
    "desconfessarás": "desconfessar",
    "desconfessarão": "desconfessar",
    "desconfessaríamos": "desconfessar",
    "desconfessaríeis": "desconfessar",
    "desconfessas": "desconfessar",
    "desconfessasse": "desconfessar",
    "desconfessassem": "desconfessar",
    "desconfessasses": "desconfessar",
    "desconfessaste": "desconfessar",
    "desconfessastes": "desconfessar",
    "desconfessava": "desconfessar",
    "desconfessavam": "desconfessar",
    "desconfessavas": "desconfessar",
    "desconfesse": "desconfessar",
    "desconfessei": "desconfessar",
    "desconfesseis": "desconfessar",
    "desconfessem": "desconfessar",
    "desconfessemo": "desconfessar",
    "desconfessemos": "desconfessar",
    "desconfesses": "desconfessar",
    "desconfesso": "desconfessar",
    "desconfessou": "desconfessar",
    "desconfessá": "desconfessar",
    "desconfessámo": "desconfessar",
    "desconfessámos": "desconfessar",
    "desconfessáramo": "desconfessar",
    "desconfessáramos": "desconfessar",
    "desconfessárei": "desconfessar",
    "desconfessáreis": "desconfessar",
    "desconfessásseis": "desconfessar",
    "desconfessássemos": "desconfessar",
    "desconfessávamo": "desconfessar",
    "desconfessávamos": "desconfessar",
    "desconfessávei": "desconfessar",
    "desconfessáveis": "desconfessar",
    "desconfia": "desconfiar",
    "desconfiada": "desconfiar",
    "desconfiadas": "desconfiar",
    "desconfiado": "desconfiar",
    "desconfiados": "desconfiar",
    "desconfiadíssima": "desconfiado",
    "desconfiadíssimas": "desconfiado",
    "desconfiadíssimo": "desconfiado",
    "desconfiadíssimos": "desconfiado",
    "desconfiai": "desconfiar",
    "desconfiais": "desconfiar",
    "desconfiam": "desconfiar",
    "desconfiamo": "desconfiar",
    "desconfiamos": "desconfiar",
    "desconfiando": "desconfiar",
    "desconfiantes": "desconfiante",
    "desconfianças": "desconfiança",
    "desconfiara": "desconfiar",
    "desconfiaram": "desconfiar",
    "desconfiaras": "desconfiar",
    "desconfiardes": "desconfiar",
    "desconfiarei": "desconfiar",
    "desconfiareis": "desconfiar",
    "desconfiarem": "desconfiar",
    "desconfiaremos": "desconfiar",
    "desconfiares": "desconfiar",
    "desconfiaria": "desconfiar",
    "desconfiariam": "desconfiar",
    "desconfiarias": "desconfiar",
    "desconfiarmo": "desconfiar",
    "desconfiarmos": "desconfiar",
    "desconfiará": "desconfiar",
    "desconfiarás": "desconfiar",
    "desconfiarão": "desconfiar",
    "desconfiaríamos": "desconfiar",
    "desconfiaríeis": "desconfiar",
    "desconfias": "desconfiar",
    "desconfiasse": "desconfiar",
    "desconfiassem": "desconfiar",
    "desconfiasses": "desconfiar",
    "desconfiaste": "desconfiar",
    "desconfiastes": "desconfiar",
    "desconfiava": "desconfiar",
    "desconfiavam": "desconfiar",
    "desconfiavas": "desconfiar",
    "desconfie": "desconfiar",
    "desconfiei": "desconfiar",
    "desconfieis": "desconfiar",
    "desconfiem": "desconfiar",
    "desconfiemo": "desconfiar",
    "desconfiemos": "desconfiar",
    "desconfies": "desconfiar",
    "desconfio": "desconfiar",
    "desconfiou": "desconfiar",
    "desconfiámo": "desconfiar",
    "desconfiámos": "desconfiar",
    "desconfiáramo": "desconfiar",
    "desconfiáramos": "desconfiar",
    "desconfiáreis": "desconfiar",
    "desconfiásseis": "desconfiar",
    "desconfiássemos": "desconfiar",
    "desconfiávamo": "desconfiar",
    "desconfiávamos": "desconfiar",
    "desconfiáveis": "desconfiar",
    "desconforma": "desconformar",
    "desconformada": "desconformar",
    "desconformadas": "desconformar",
    "desconformado": "desconformar",
    "desconformados": "desconformar",
    "desconformai": "desconformar",
    "desconformais": "desconformar",
    "desconformam": "desconformar",
    "desconformamo": "desconformar",
    "desconformamos": "desconformar",
    "desconformando": "desconformar",
    "desconformara": "desconformar",
    "desconformaram": "desconformar",
    "desconformaras": "desconformar",
    "desconformardes": "desconformar",
    "desconformarei": "desconformar",
    "desconformareis": "desconformar",
    "desconformarem": "desconformar",
    "desconformaremos": "desconformar",
    "desconformares": "desconformar",
    "desconformaria": "desconformar",
    "desconformariam": "desconformar",
    "desconformarias": "desconformar",
    "desconformarmo": "desconformar",
    "desconformarmos": "desconformar",
    "desconformará": "desconformar",
    "desconformarás": "desconformar",
    "desconformarão": "desconformar",
    "desconformaríamos": "desconformar",
    "desconformaríeis": "desconformar",
    "desconformas": "desconformar",
    "desconformasse": "desconformar",
    "desconformassem": "desconformar",
    "desconformasses": "desconformar",
    "desconformaste": "desconformar",
    "desconformastes": "desconformar",
    "desconformava": "desconformar",
    "desconformavam": "desconformar",
    "desconformavas": "desconformar",
    "desconforme": "desconformar",
    "desconformei": "desconformar",
    "desconformeis": "desconformar",
    "desconformem": "desconformar",
    "desconformemo": "desconformar",
    "desconformemos": "desconformar",
    "desconformes": "desconforme",
    "desconformidades": "desconformidade",
    "desconformo": "desconformar",
    "desconformou": "desconformar",
    "desconformámo": "desconformar",
    "desconformámos": "desconformar",
    "desconformáramo": "desconformar",
    "desconformáramos": "desconformar",
    "desconformáreis": "desconformar",
    "desconformásseis": "desconformar",
    "desconformássemos": "desconformar",
    "desconformávamo": "desconformar",
    "desconformávamos": "desconformar",
    "desconformáveis": "desconformar",
    "desconforta": "desconfortar",
    "desconfortada": "desconfortar",
    "desconfortadas": "desconfortar",
    "desconfortado": "desconfortar",
    "desconfortados": "desconfortar",
    "desconfortai": "desconfortar",
    "desconfortais": "desconfortar",
    "desconfortam": "desconfortar",
    "desconfortamo": "desconfortar",
    "desconfortamos": "desconfortar",
    "desconfortando": "desconfortar",
    "desconfortantes": "desconfortante",
    "desconfortara": "desconfortar",
    "desconfortaram": "desconfortar",
    "desconfortaras": "desconfortar",
    "desconfortarde": "desconfortar",
    "desconfortardes": "desconfortar",
    "desconfortare": "desconfortar",
    "desconfortarei": "desconfortar",
    "desconfortareis": "desconfortar",
    "desconfortarem": "desconfortar",
    "desconfortaremos": "desconfortar",
    "desconfortares": "desconfortar",
    "desconfortaria": "desconfortar",
    "desconfortariam": "desconfortar",
    "desconfortarias": "desconfortar",
    "desconfortarmo": "desconfortar",
    "desconfortarmos": "desconfortar",
    "desconfortará": "desconfortar",
    "desconfortarás": "desconfortar",
    "desconfortarão": "desconfortar",
    "desconfortaríamos": "desconfortar",
    "desconfortaríeis": "desconfortar",
    "desconfortas": "desconfortar",
    "desconfortasse": "desconfortar",
    "desconfortassem": "desconfortar",
    "desconfortasses": "desconfortar",
    "desconfortaste": "desconfortar",
    "desconfortastes": "desconfortar",
    "desconfortava": "desconfortar",
    "desconfortavam": "desconfortar",
    "desconfortavas": "desconfortar",
    "desconforte": "desconfortar",
    "desconfortei": "desconfortar",
    "desconforteis": "desconfortar",
    "desconfortem": "desconfortar",
    "desconfortemo": "desconfortar",
    "desconfortemos": "desconfortar",
    "desconfortes": "desconfortar",
    "desconforto": "desconfortar",
    "desconfortos": "desconforto",
    "desconfortou": "desconfortar",
    "desconfortá": "desconfortar",
    "desconfortámo": "desconfortar",
    "desconfortámos": "desconfortar",
    "desconfortáramo": "desconfortar",
    "desconfortáramos": "desconfortar",
    "desconfortárei": "desconfortar",
    "desconfortáreis": "desconfortar",
    "desconfortásseis": "desconfortar",
    "desconfortássemos": "desconfortar",
    "desconfortávamo": "desconfortar",
    "desconfortávamos": "desconfortar",
    "desconfortávei": "desconfortar",
    "desconfortáveis": "desconfortável",
    "desconfrange": "desconfranger",
    "desconfrangei": "desconfranger",
    "desconfrangeis": "desconfranger",
    "desconfrangem": "desconfranger",
    "desconfrangemo": "desconfranger",
    "desconfrangemos": "desconfranger",
    "desconfrangendo": "desconfranger",
    "desconfrangera": "desconfranger",
    "desconfrangeram": "desconfranger",
    "desconfrangeras": "desconfranger",
    "desconfrangerde": "desconfranger",
    "desconfrangerdes": "desconfranger",
    "desconfrangere": "desconfranger",
    "desconfrangerei": "desconfranger",
    "desconfrangereis": "desconfranger",
    "desconfrangerem": "desconfranger",
    "desconfrangeremos": "desconfranger",
    "desconfrangeres": "desconfranger",
    "desconfrangeria": "desconfranger",
    "desconfrangeriam": "desconfranger",
    "desconfrangerias": "desconfranger",
    "desconfrangermo": "desconfranger",
    "desconfrangermos": "desconfranger",
    "desconfrangerá": "desconfranger",
    "desconfrangerás": "desconfranger",
    "desconfrangerão": "desconfranger",
    "desconfrangeríamos": "desconfranger",
    "desconfrangeríeis": "desconfranger",
    "desconfranges": "desconfranger",
    "desconfrangesse": "desconfranger",
    "desconfrangessem": "desconfranger",
    "desconfrangesses": "desconfranger",
    "desconfrangeste": "desconfranger",
    "desconfrangestes": "desconfranger",
    "desconfrangeu": "desconfranger",
    "desconfrangi": "desconfranger",
    "desconfrangia": "desconfranger",
    "desconfrangiam": "desconfranger",
    "desconfrangias": "desconfranger",
    "desconfrangida": "desconfranger",
    "desconfrangidas": "desconfranger",
    "desconfrangido": "desconfranger",
    "desconfrangidos": "desconfranger",
    "desconfrangimentos": "desconfrangimento",
    "desconfrangê": "desconfranger",
    "desconfrangêramo": "desconfranger",
    "desconfrangêramos": "desconfranger",
    "desconfrangêrei": "desconfranger",
    "desconfrangêreis": "desconfranger",
    "desconfrangêsseis": "desconfranger",
    "desconfrangêssemos": "desconfranger",
    "desconfrangíamo": "desconfranger",
    "desconfrangíamos": "desconfranger",
    "desconfrangíei": "desconfranger",
    "desconfrangíeis": "desconfranger",
    "desconfranja": "desconfranger",
    "desconfranjais": "desconfranger",
    "desconfranjam": "desconfranger",
    "desconfranjamo": "desconfranger",
    "desconfranjamos": "desconfranger",
    "desconfranjas": "desconfranger",
    "desconfranjo": "desconfranger",
    "desconfunda": "desconfundir",
    "desconfundais": "desconfundir",
    "desconfundam": "desconfundir",
    "desconfundamo": "desconfundir",
    "desconfundamos": "desconfundir",
    "desconfundas": "desconfundir",
    "desconfunde": "desconfundir",
    "desconfundem": "desconfundir",
    "desconfundes": "desconfundir",
    "desconfundi": "desconfundir",
    "desconfundia": "desconfundir",
    "desconfundiam": "desconfundir",
    "desconfundias": "desconfundir",
    "desconfundida": "desconfundir",
    "desconfundidas": "desconfundir",
    "desconfundido": "desconfundir",
    "desconfundidos": "desconfundir",
    "desconfundimo": "desconfundir",
    "desconfundimos": "desconfundir",
    "desconfundindo": "desconfundir",
    "desconfundira": "desconfundir",
    "desconfundiram": "desconfundir",
    "desconfundiras": "desconfundir",
    "desconfundirde": "desconfundir",
    "desconfundirdes": "desconfundir",
    "desconfundire": "desconfundir",
    "desconfundirei": "desconfundir",
    "desconfundireis": "desconfundir",
    "desconfundirem": "desconfundir",
    "desconfundiremos": "desconfundir",
    "desconfundires": "desconfundir",
    "desconfundiria": "desconfundir",
    "desconfundiriam": "desconfundir",
    "desconfundirias": "desconfundir",
    "desconfundirmo": "desconfundir",
    "desconfundirmos": "desconfundir",
    "desconfundirá": "desconfundir",
    "desconfundirás": "desconfundir",
    "desconfundirão": "desconfundir",
    "desconfundiríamos": "desconfundir",
    "desconfundiríeis": "desconfundir",
    "desconfundis": "desconfundir",
    "desconfundisse": "desconfundir",
    "desconfundissem": "desconfundir",
    "desconfundisses": "desconfundir",
    "desconfundiste": "desconfundir",
    "desconfundistes": "desconfundir",
    "desconfundiu": "desconfundir",
    "desconfundo": "desconfundir",
    "desconfundíamo": "desconfundir",
    "desconfundíamos": "desconfundir",
    "desconfundíei": "desconfundir",
    "desconfundíeis": "desconfundir",
    "desconfundíramo": "desconfundir",
    "desconfundíramos": "desconfundir",
    "desconfundírei": "desconfundir",
    "desconfundíreis": "desconfundir",
    "desconfundísseis": "desconfundir",
    "desconfundíssemos": "desconfundir",
    "desconfusões": "desconfusão",
    "descongela": "descongelar",
    "descongelada": "descongelar",
    "descongeladas": "descongelar",
    "descongelado": "descongelar",
    "descongeladora": "descongelador",
    "descongeladoras": "descongelador",
    "descongeladores": "descongelador",
    "descongelados": "descongelar",
    "descongelai": "descongelar",
    "descongelais": "descongelar",
    "descongelam": "descongelar",
    "descongelamentos": "descongelamento",
    "descongelamo": "descongelar",
    "descongelamos": "descongelar",
    "descongelando": "descongelar",
    "descongelara": "descongelar",
    "descongelaram": "descongelar",
    "descongelaras": "descongelar",
    "descongelarde": "descongelar",
    "descongelardes": "descongelar",
    "descongelare": "descongelar",
    "descongelarei": "descongelar",
    "descongelareis": "descongelar",
    "descongelarem": "descongelar",
    "descongelaremos": "descongelar",
    "descongelares": "descongelar",
    "descongelaria": "descongelar",
    "descongelariam": "descongelar",
    "descongelarias": "descongelar",
    "descongelarmo": "descongelar",
    "descongelarmos": "descongelar",
    "descongelará": "descongelar",
    "descongelarás": "descongelar",
    "descongelarão": "descongelar",
    "descongelaríamos": "descongelar",
    "descongelaríeis": "descongelar",
    "descongelas": "descongelar",
    "descongelasse": "descongelar",
    "descongelassem": "descongelar",
    "descongelasses": "descongelar",
    "descongelaste": "descongelar",
    "descongelastes": "descongelar",
    "descongelava": "descongelar",
    "descongelavam": "descongelar",
    "descongelavas": "descongelar",
    "descongelações": "descongelação",
    "descongele": "descongelar",
    "descongelei": "descongelar",
    "descongeleis": "descongelar",
    "descongelem": "descongelar",
    "descongelemo": "descongelar",
    "descongelemos": "descongelar",
    "descongeles": "descongelar",
    "descongelo": "descongelar",
    "descongelou": "descongelar",
    "descongelá": "descongelar",
    "descongelámo": "descongelar",
    "descongelámos": "descongelar",
    "descongeláramo": "descongelar",
    "descongeláramos": "descongelar",
    "descongelárei": "descongelar",
    "descongeláreis": "descongelar",
    "descongelásseis": "descongelar",
    "descongelássemos": "descongelar",
    "descongelávamo": "descongelar",
    "descongelávamos": "descongelar",
    "descongelávei": "descongelar",
    "descongeláveis": "descongelável",
    "descongestiona": "descongestionar",
    "descongestionada": "descongestionar",
    "descongestionadas": "descongestionar",
    "descongestionado": "descongestionar",
    "descongestionados": "descongestionar",
    "descongestionai": "descongestionar",
    "descongestionais": "descongestionar",
    "descongestionam": "descongestionar",
    "descongestionamentos": "descongestionamento",
    "descongestionamo": "descongestionar",
    "descongestionamos": "descongestionar",
    "descongestionando": "descongestionar",
    "descongestionantes": "descongestionante",
    "descongestionara": "descongestionar",
    "descongestionaram": "descongestionar",
    "descongestionaras": "descongestionar",
    "descongestionarde": "descongestionar",
    "descongestionardes": "descongestionar",
    "descongestionare": "descongestionar",
    "descongestionarei": "descongestionar",
    "descongestionareis": "descongestionar",
    "descongestionarem": "descongestionar",
    "descongestionaremos": "descongestionar",
    "descongestionares": "descongestionar",
    "descongestionaria": "descongestionar",
    "descongestionariam": "descongestionar",
    "descongestionarias": "descongestionar",
    "descongestionarmo": "descongestionar",
    "descongestionarmos": "descongestionar",
    "descongestionará": "descongestionar",
    "descongestionarás": "descongestionar",
    "descongestionarão": "descongestionar",
    "descongestionaríamos": "descongestionar",
    "descongestionaríeis": "descongestionar",
    "descongestionas": "descongestionar",
    "descongestionasse": "descongestionar",
    "descongestionassem": "descongestionar",
    "descongestionasses": "descongestionar",
    "descongestionaste": "descongestionar",
    "descongestionastes": "descongestionar",
    "descongestionava": "descongestionar",
    "descongestionavam": "descongestionar",
    "descongestionavas": "descongestionar",
    "descongestione": "descongestionar",
    "descongestionei": "descongestionar",
    "descongestioneis": "descongestionar",
    "descongestionem": "descongestionar",
    "descongestionemo": "descongestionar",
    "descongestionemos": "descongestionar",
    "descongestiones": "descongestionar",
    "descongestiono": "descongestionar",
    "descongestionou": "descongestionar",
    "descongestioná": "descongestionar",
    "descongestionámo": "descongestionar",
    "descongestionámos": "descongestionar",
    "descongestionáramo": "descongestionar",
    "descongestionáramos": "descongestionar",
    "descongestionárei": "descongestionar",
    "descongestionáreis": "descongestionar",
    "descongestionásseis": "descongestionar",
    "descongestionássemos": "descongestionar",
    "descongestionávamo": "descongestionar",
    "descongestionávamos": "descongestionar",
    "descongestionávei": "descongestionar",
    "descongestionáveis": "descongestionável",
    "descongestiva": "descongestivo",
    "descongestivas": "descongestivo",
    "descongestivos": "descongestivo",
    "desconhece": "desconhecer",
    "desconhecedora": "desconhecedor",
    "desconhecedoras": "desconhecedor",
    "desconhecedores": "desconhecedor",
    "desconhecei": "desconhecer",
    "desconheceis": "desconhecer",
    "desconhecem": "desconhecer",
    "desconhecemo": "desconhecer",
    "desconhecemos": "desconhecer",
    "desconhecendo": "desconhecer",
    "desconhecera": "desconhecer",
    "desconheceram": "desconhecer",
    "desconheceras": "desconhecer",
    "desconhecerde": "desconhecer",
    "desconhecerdes": "desconhecer",
    "desconhecere": "desconhecer",
    "desconhecerei": "desconhecer",
    "desconhecereis": "desconhecer",
    "desconhecerem": "desconhecer",
    "desconheceremos": "desconhecer",
    "desconheceres": "desconhecer",
    "desconheceria": "desconhecer",
    "desconheceriam": "desconhecer",
    "desconhecerias": "desconhecer",
    "desconhecermo": "desconhecer",
    "desconhecermos": "desconhecer",
    "desconhecerá": "desconhecer",
    "desconhecerás": "desconhecer",
    "desconhecerão": "desconhecer",
    "desconheceríamos": "desconhecer",
    "desconheceríeis": "desconhecer",
    "desconheces": "desconhecer",
    "desconhecesse": "desconhecer",
    "desconhecessem": "desconhecer",
    "desconhecesses": "desconhecer",
    "desconheceste": "desconhecer",
    "desconhecestes": "desconhecer",
    "desconheceu": "desconhecer",
    "desconheci": "desconhecer",
    "desconhecia": "desconhecer",
    "desconheciam": "desconhecer",
    "desconhecias": "desconhecer",
    "desconhecida": "desconhecido",
    "desconhecidas": "desconhecido",
    "desconhecido": "desconhecer",
    "desconhecidos": "desconhecido",
    "desconhecimentos": "desconhecimento",
    "desconhecê": "desconhecer",
    "desconhecêramo": "desconhecer",
    "desconhecêramos": "desconhecer",
    "desconhecêrei": "desconhecer",
    "desconhecêreis": "desconhecer",
    "desconhecêsseis": "desconhecer",
    "desconhecêssemos": "desconhecer",
    "desconhecíamo": "desconhecer",
    "desconhecíamos": "desconhecer",
    "desconhecíei": "desconhecer",
    "desconhecíeis": "desconhecer",
    "desconhecíveis": "desconhecível",
    "desconheça": "desconhecer",
    "desconheçais": "desconhecer",
    "desconheçam": "desconhecer",
    "desconheçamo": "desconhecer",
    "desconheçamos": "desconhecer",
    "desconheças": "desconhecer",
    "desconheço": "desconhecer",
    "desconjuga": "desconjugar",
    "desconjugada": "desconjugar",
    "desconjugadas": "desconjugar",
    "desconjugado": "desconjugar",
    "desconjugados": "desconjugar",
    "desconjugai": "desconjugar",
    "desconjugais": "desconjugar",
    "desconjugam": "desconjugar",
    "desconjugamo": "desconjugar",
    "desconjugamos": "desconjugar",
    "desconjugando": "desconjugar",
    "desconjugara": "desconjugar",
    "desconjugaram": "desconjugar",
    "desconjugaras": "desconjugar",
    "desconjugarde": "desconjugar",
    "desconjugardes": "desconjugar",
    "desconjugare": "desconjugar",
    "desconjugarei": "desconjugar",
    "desconjugareis": "desconjugar",
    "desconjugarem": "desconjugar",
    "desconjugaremos": "desconjugar",
    "desconjugares": "desconjugar",
    "desconjugaria": "desconjugar",
    "desconjugariam": "desconjugar",
    "desconjugarias": "desconjugar",
    "desconjugarmo": "desconjugar",
    "desconjugarmos": "desconjugar",
    "desconjugará": "desconjugar",
    "desconjugarás": "desconjugar",
    "desconjugarão": "desconjugar",
    "desconjugaríamos": "desconjugar",
    "desconjugaríeis": "desconjugar",
    "desconjugas": "desconjugar",
    "desconjugasse": "desconjugar",
    "desconjugassem": "desconjugar",
    "desconjugasses": "desconjugar",
    "desconjugaste": "desconjugar",
    "desconjugastes": "desconjugar",
    "desconjugava": "desconjugar",
    "desconjugavam": "desconjugar",
    "desconjugavas": "desconjugar",
    "desconjugo": "desconjugar",
    "desconjugou": "desconjugar",
    "desconjugue": "desconjugar",
    "desconjuguei": "desconjugar",
    "desconjugueis": "desconjugar",
    "desconjuguem": "desconjugar",
    "desconjuguemo": "desconjugar",
    "desconjuguemos": "desconjugar",
    "desconjugues": "desconjugar",
    "desconjugá": "desconjugar",
    "desconjugámo": "desconjugar",
    "desconjugámos": "desconjugar",
    "desconjugáramo": "desconjugar",
    "desconjugáramos": "desconjugar",
    "desconjugárei": "desconjugar",
    "desconjugáreis": "desconjugar",
    "desconjugásseis": "desconjugar",
    "desconjugássemos": "desconjugar",
    "desconjugávamo": "desconjugar",
    "desconjugávamos": "desconjugar",
    "desconjugávei": "desconjugar",
    "desconjugáveis": "desconjugar",
    "desconjunta": "desconjuntar",
    "desconjuntada": "desconjuntar",
    "desconjuntadas": "desconjuntar",
    "desconjuntado": "desconjuntar",
    "desconjuntados": "desconjuntar",
    "desconjuntai": "desconjuntar",
    "desconjuntais": "desconjuntar",
    "desconjuntam": "desconjuntar",
    "desconjuntamentos": "desconjuntamento",
    "desconjuntamo": "desconjuntar",
    "desconjuntamos": "desconjuntar",
    "desconjuntando": "desconjuntar",
    "desconjuntara": "desconjuntar",
    "desconjuntaram": "desconjuntar",
    "desconjuntaras": "desconjuntar",
    "desconjuntarde": "desconjuntar",
    "desconjuntardes": "desconjuntar",
    "desconjuntare": "desconjuntar",
    "desconjuntarei": "desconjuntar",
    "desconjuntareis": "desconjuntar",
    "desconjuntarem": "desconjuntar",
    "desconjuntaremos": "desconjuntar",
    "desconjuntares": "desconjuntar",
    "desconjuntaria": "desconjuntar",
    "desconjuntariam": "desconjuntar",
    "desconjuntarias": "desconjuntar",
    "desconjuntarmo": "desconjuntar",
    "desconjuntarmos": "desconjuntar",
    "desconjuntará": "desconjuntar",
    "desconjuntarás": "desconjuntar",
    "desconjuntarão": "desconjuntar",
    "desconjuntaríamos": "desconjuntar",
    "desconjuntaríeis": "desconjuntar",
    "desconjuntas": "desconjuntar",
    "desconjuntasse": "desconjuntar",
    "desconjuntassem": "desconjuntar",
    "desconjuntasses": "desconjuntar",
    "desconjuntaste": "desconjuntar",
    "desconjuntastes": "desconjuntar",
    "desconjuntava": "desconjuntar",
    "desconjuntavam": "desconjuntar",
    "desconjuntavas": "desconjuntar",
    "desconjunte": "desconjuntar",
    "desconjuntei": "desconjuntar",
    "desconjunteis": "desconjuntar",
    "desconjuntem": "desconjuntar",
    "desconjuntemo": "desconjuntar",
    "desconjuntemos": "desconjuntar",
    "desconjuntes": "desconjuntar",
    "desconjunto": "desconjuntar",
    "desconjuntou": "desconjuntar",
    "desconjunturas": "desconjuntura",
    "desconjuntá": "desconjuntar",
    "desconjuntámo": "desconjuntar",
    "desconjuntámos": "desconjuntar",
    "desconjuntáramo": "desconjuntar",
    "desconjuntáramos": "desconjuntar",
    "desconjuntárei": "desconjuntar",
    "desconjuntáreis": "desconjuntar",
    "desconjuntásseis": "desconjuntar",
    "desconjuntássemos": "desconjuntar",
    "desconjuntávamo": "desconjuntar",
    "desconjuntávamos": "desconjuntar",
    "desconjuntávei": "desconjuntar",
    "desconjuntáveis": "desconjuntar",
    "desconjunções": "desconjunção",
    "desconjura": "desconjurar",
    "desconjurada": "desconjurar",
    "desconjuradas": "desconjurar",
    "desconjurado": "desconjurar",
    "desconjurados": "desconjurar",
    "desconjurai": "desconjurar",
    "desconjurais": "desconjurar",
    "desconjuram": "desconjurar",
    "desconjuramo": "desconjurar",
    "desconjuramos": "desconjurar",
    "desconjurando": "desconjurar",
    "desconjurara": "desconjurar",
    "desconjuraram": "desconjurar",
    "desconjuraras": "desconjurar",
    "desconjurarde": "desconjurar",
    "desconjurardes": "desconjurar",
    "desconjurare": "desconjurar",
    "desconjurarei": "desconjurar",
    "desconjurareis": "desconjurar",
    "desconjurarem": "desconjurar",
    "desconjuraremos": "desconjurar",
    "desconjurares": "desconjurar",
    "desconjuraria": "desconjurar",
    "desconjurariam": "desconjurar",
    "desconjurarias": "desconjurar",
    "desconjurarmo": "desconjurar",
    "desconjurarmos": "desconjurar",
    "desconjurará": "desconjurar",
    "desconjurarás": "desconjurar",
    "desconjurarão": "desconjurar",
    "desconjuraríamos": "desconjurar",
    "desconjuraríeis": "desconjurar",
    "desconjuras": "desconjurar",
    "desconjurasse": "desconjurar",
    "desconjurassem": "desconjurar",
    "desconjurasses": "desconjurar",
    "desconjuraste": "desconjurar",
    "desconjurastes": "desconjurar",
    "desconjurava": "desconjurar",
    "desconjuravam": "desconjurar",
    "desconjuravas": "desconjurar",
    "desconjure": "desconjurar",
    "desconjurei": "desconjurar",
    "desconjureis": "desconjurar",
    "desconjurem": "desconjurar",
    "desconjuremo": "desconjurar",
    "desconjuremos": "desconjurar",
    "desconjures": "desconjurar",
    "desconjuro": "desconjurar",
    "desconjurou": "desconjurar",
    "desconjurá": "desconjurar",
    "desconjurámo": "desconjurar",
    "desconjurámos": "desconjurar",
    "desconjuráramo": "desconjurar",
    "desconjuráramos": "desconjurar",
    "desconjurárei": "desconjurar",
    "desconjuráreis": "desconjurar",
    "desconjurásseis": "desconjurar",
    "desconjurássemos": "desconjurar",
    "desconjurávamo": "desconjurar",
    "desconjurávamos": "desconjurar",
    "desconjurávei": "desconjurar",
    "desconjuráveis": "desconjurar",
    "desconsagra": "desconsagrar",
    "desconsagrada": "desconsagrar",
    "desconsagradas": "desconsagrar",
    "desconsagrado": "desconsagrar",
    "desconsagrados": "desconsagrar",
    "desconsagrai": "desconsagrar",
    "desconsagrais": "desconsagrar",
    "desconsagram": "desconsagrar",
    "desconsagramo": "desconsagrar",
    "desconsagramos": "desconsagrar",
    "desconsagrando": "desconsagrar",
    "desconsagrara": "desconsagrar",
    "desconsagraram": "desconsagrar",
    "desconsagraras": "desconsagrar",
    "desconsagrarde": "desconsagrar",
    "desconsagrardes": "desconsagrar",
    "desconsagrare": "desconsagrar",
    "desconsagrarei": "desconsagrar",
    "desconsagrareis": "desconsagrar",
    "desconsagrarem": "desconsagrar",
    "desconsagraremos": "desconsagrar",
    "desconsagrares": "desconsagrar",
    "desconsagraria": "desconsagrar",
    "desconsagrariam": "desconsagrar",
    "desconsagrarias": "desconsagrar",
    "desconsagrarmo": "desconsagrar",
    "desconsagrarmos": "desconsagrar",
    "desconsagrará": "desconsagrar",
    "desconsagrarás": "desconsagrar",
    "desconsagrarão": "desconsagrar",
    "desconsagraríamos": "desconsagrar",
    "desconsagraríeis": "desconsagrar",
    "desconsagras": "desconsagrar",
    "desconsagrasse": "desconsagrar",
    "desconsagrassem": "desconsagrar",
    "desconsagrasses": "desconsagrar",
    "desconsagraste": "desconsagrar",
    "desconsagrastes": "desconsagrar",
    "desconsagrava": "desconsagrar",
    "desconsagravam": "desconsagrar",
    "desconsagravas": "desconsagrar",
    "desconsagrações": "desconsagração",
    "desconsagre": "desconsagrar",
    "desconsagrei": "desconsagrar",
    "desconsagreis": "desconsagrar",
    "desconsagrem": "desconsagrar",
    "desconsagremo": "desconsagrar",
    "desconsagremos": "desconsagrar",
    "desconsagres": "desconsagrar",
    "desconsagro": "desconsagrar",
    "desconsagrou": "desconsagrar",
    "desconsagrá": "desconsagrar",
    "desconsagrámo": "desconsagrar",
    "desconsagrámos": "desconsagrar",
    "desconsagráramo": "desconsagrar",
    "desconsagráramos": "desconsagrar",
    "desconsagrárei": "desconsagrar",
    "desconsagráreis": "desconsagrar",
    "desconsagrásseis": "desconsagrar",
    "desconsagrássemos": "desconsagrar",
    "desconsagrávamo": "desconsagrar",
    "desconsagrávamos": "desconsagrar",
    "desconsagrávei": "desconsagrar",
    "desconsagráveis": "desconsagrar",
    "desconsciências": "desconsciência",
    "desconsente": "desconsentir",
    "desconsentem": "desconsentir",
    "desconsentes": "desconsentir",
    "desconsenti": "desconsentir",
    "desconsentia": "desconsentir",
    "desconsentiam": "desconsentir",
    "desconsentias": "desconsentir",
    "desconsentida": "desconsentir",
    "desconsentidas": "desconsentir",
    "desconsentido": "desconsentir",
    "desconsentidos": "desconsentir",
    "desconsentimentos": "desconsentimento",
    "desconsentimo": "desconsentir",
    "desconsentimos": "desconsentir",
    "desconsentindo": "desconsentir",
    "desconsentira": "desconsentir",
    "desconsentiram": "desconsentir",
    "desconsentiras": "desconsentir",
    "desconsentirde": "desconsentir",
    "desconsentirdes": "desconsentir",
    "desconsentire": "desconsentir",
    "desconsentirei": "desconsentir",
    "desconsentireis": "desconsentir",
    "desconsentirem": "desconsentir",
    "desconsentiremos": "desconsentir",
    "desconsentires": "desconsentir",
    "desconsentiria": "desconsentir",
    "desconsentiriam": "desconsentir",
    "desconsentirias": "desconsentir",
    "desconsentirmo": "desconsentir",
    "desconsentirmos": "desconsentir",
    "desconsentirá": "desconsentir",
    "desconsentirás": "desconsentir",
    "desconsentirão": "desconsentir",
    "desconsentiríamos": "desconsentir",
    "desconsentiríeis": "desconsentir",
    "desconsentis": "desconsentir",
    "desconsentisse": "desconsentir",
    "desconsentissem": "desconsentir",
    "desconsentisses": "desconsentir",
    "desconsentiste": "desconsentir",
    "desconsentistes": "desconsentir",
    "desconsentiu": "desconsentir",
    "desconsentíamo": "desconsentir",
    "desconsentíamos": "desconsentir",
    "desconsentíei": "desconsentir",
    "desconsentíeis": "desconsentir",
    "desconsentíramo": "desconsentir",
    "desconsentíramos": "desconsentir",
    "desconsentírei": "desconsentir",
    "desconsentíreis": "desconsentir",
    "desconsentísseis": "desconsentir",
    "desconsentíssemos": "desconsentir",
    "desconserta": "desconsertar",
    "desconsertada": "desconsertar",
    "desconsertadas": "desconsertar",
    "desconsertado": "desconsertar",
    "desconsertadora": "desconsertador",
    "desconsertadoras": "desconsertador",
    "desconsertadores": "desconsertador",
    "desconsertados": "desconsertar",
    "desconsertai": "desconsertar",
    "desconsertais": "desconsertar",
    "desconsertam": "desconsertar",
    "desconsertamo": "desconsertar",
    "desconsertamos": "desconsertar",
    "desconsertando": "desconsertar",
    "desconsertara": "desconsertar",
    "desconsertaram": "desconsertar",
    "desconsertaras": "desconsertar",
    "desconsertarde": "desconsertar",
    "desconsertardes": "desconsertar",
    "desconsertare": "desconsertar",
    "desconsertarei": "desconsertar",
    "desconsertareis": "desconsertar",
    "desconsertarem": "desconsertar",
    "desconsertaremos": "desconsertar",
    "desconsertares": "desconsertar",
    "desconsertaria": "desconsertar",
    "desconsertariam": "desconsertar",
    "desconsertarias": "desconsertar",
    "desconsertarmo": "desconsertar",
    "desconsertarmos": "desconsertar",
    "desconsertará": "desconsertar",
    "desconsertarás": "desconsertar",
    "desconsertarão": "desconsertar",
    "desconsertaríamos": "desconsertar",
    "desconsertaríeis": "desconsertar",
    "desconsertas": "desconsertar",
    "desconsertasse": "desconsertar",
    "desconsertassem": "desconsertar",
    "desconsertasses": "desconsertar",
    "desconsertaste": "desconsertar",
    "desconsertastes": "desconsertar",
    "desconsertava": "desconsertar",
    "desconsertavam": "desconsertar",
    "desconsertavas": "desconsertar",
    "desconserte": "desconsertar",
    "desconsertei": "desconsertar",
    "desconserteis": "desconsertar",
    "desconsertem": "desconsertar",
    "desconsertemo": "desconsertar",
    "desconsertemos": "desconsertar",
    "desconsertes": "desconsertar",
    "desconserto": "desconsertar",
    "desconsertos": "desconserto",
    "desconsertou": "desconsertar",
    "desconsertá": "desconsertar",
    "desconsertámo": "desconsertar",
    "desconsertámos": "desconsertar",
    "desconsertáramo": "desconsertar",
    "desconsertáramos": "desconsertar",
    "desconsertárei": "desconsertar",
    "desconsertáreis": "desconsertar",
    "desconsertásseis": "desconsertar",
    "desconsertássemos": "desconsertar",
    "desconsertávamo": "desconsertar",
    "desconsertávamos": "desconsertar",
    "desconsertávei": "desconsertar",
    "desconsertáveis": "desconsertar",
    "desconsidera": "desconsiderar",
    "desconsiderada": "desconsiderar",
    "desconsideradas": "desconsiderar",
    "desconsiderado": "desconsiderar",
    "desconsiderados": "desconsiderar",
    "desconsiderai": "desconsiderar",
    "desconsiderais": "desconsiderar",
    "desconsideram": "desconsiderar",
    "desconsideramo": "desconsiderar",
    "desconsideramos": "desconsiderar",
    "desconsiderando": "desconsiderar",
    "desconsiderara": "desconsiderar",
    "desconsideraram": "desconsiderar",
    "desconsideraras": "desconsiderar",
    "desconsiderarde": "desconsiderar",
    "desconsiderardes": "desconsiderar",
    "desconsiderare": "desconsiderar",
    "desconsiderarei": "desconsiderar",
    "desconsiderareis": "desconsiderar",
    "desconsiderarem": "desconsiderar",
    "desconsideraremos": "desconsiderar",
    "desconsiderares": "desconsiderar",
    "desconsideraria": "desconsiderar",
    "desconsiderariam": "desconsiderar",
    "desconsiderarias": "desconsiderar",
    "desconsiderarmo": "desconsiderar",
    "desconsiderarmos": "desconsiderar",
    "desconsiderará": "desconsiderar",
    "desconsiderarás": "desconsiderar",
    "desconsiderarão": "desconsiderar",
    "desconsideraríamos": "desconsiderar",
    "desconsideraríeis": "desconsiderar",
    "desconsideras": "desconsiderar",
    "desconsiderasse": "desconsiderar",
    "desconsiderassem": "desconsiderar",
    "desconsiderasses": "desconsiderar",
    "desconsideraste": "desconsiderar",
    "desconsiderastes": "desconsiderar",
    "desconsiderava": "desconsiderar",
    "desconsideravam": "desconsiderar",
    "desconsideravas": "desconsiderar",
    "desconsiderações": "desconsideração",
    "desconsidere": "desconsiderar",
    "desconsiderei": "desconsiderar",
    "desconsidereis": "desconsiderar",
    "desconsiderem": "desconsiderar",
    "desconsideremo": "desconsiderar",
    "desconsideremos": "desconsiderar",
    "desconsideres": "desconsiderar",
    "desconsidero": "desconsiderar",
    "desconsiderou": "desconsiderar",
    "desconsiderá": "desconsiderar",
    "desconsiderámo": "desconsiderar",
    "desconsiderámos": "desconsiderar",
    "desconsideráramo": "desconsiderar",
    "desconsideráramos": "desconsiderar",
    "desconsiderárei": "desconsiderar",
    "desconsideráreis": "desconsiderar",
    "desconsiderásseis": "desconsiderar",
    "desconsiderássemos": "desconsiderar",
    "desconsiderávamo": "desconsiderar",
    "desconsiderávamos": "desconsiderar",
    "desconsiderávei": "desconsiderar",
    "desconsideráveis": "desconsiderar",
    "desconsinta": "desconsentir",
    "desconsintais": "desconsentir",
    "desconsintam": "desconsentir",
    "desconsintamo": "desconsentir",
    "desconsintamos": "desconsentir",
    "desconsintas": "desconsentir",
    "desconsinto": "desconsentir",
    "desconsoantes": "desconsoante",
    "desconsola": "desconsolar",
    "desconsolada": "desconsolar",
    "desconsoladas": "desconsolar",
    "desconsolado": "desconsolar",
    "desconsoladora": "desconsolador",
    "desconsoladoras": "desconsolador",
    "desconsoladores": "desconsolador",
    "desconsolados": "desconsolar",
    "desconsolai": "desconsolar",
    "desconsolais": "desconsolar",
    "desconsolam": "desconsolar",
    "desconsolamo": "desconsolar",
    "desconsolamos": "desconsolar",
    "desconsolando": "desconsolar",
    "desconsolara": "desconsolar",
    "desconsolaram": "desconsolar",
    "desconsolaras": "desconsolar",
    "desconsolarde": "desconsolar",
    "desconsolardes": "desconsolar",
    "desconsolare": "desconsolar",
    "desconsolarei": "desconsolar",
    "desconsolareis": "desconsolar",
    "desconsolarem": "desconsolar",
    "desconsolaremos": "desconsolar",
    "desconsolares": "desconsolar",
    "desconsolaria": "desconsolar",
    "desconsolariam": "desconsolar",
    "desconsolarias": "desconsolar",
    "desconsolarmo": "desconsolar",
    "desconsolarmos": "desconsolar",
    "desconsolará": "desconsolar",
    "desconsolarás": "desconsolar",
    "desconsolarão": "desconsolar",
    "desconsolaríamos": "desconsolar",
    "desconsolaríeis": "desconsolar",
    "desconsolas": "desconsolar",
    "desconsolasse": "desconsolar",
    "desconsolassem": "desconsolar",
    "desconsolasses": "desconsolar",
    "desconsolaste": "desconsolar",
    "desconsolastes": "desconsolar",
    "desconsolativa": "desconsolativo",
    "desconsolativas": "desconsolativo",
    "desconsolativos": "desconsolativo",
    "desconsolava": "desconsolar",
    "desconsolavam": "desconsolar",
    "desconsolavas": "desconsolar",
    "desconsolações": "desconsolação",
    "desconsole": "desconsolar",
    "desconsolei": "desconsolar",
    "desconsoleis": "desconsolar",
    "desconsolem": "desconsolar",
    "desconsolemo": "desconsolar",
    "desconsolemos": "desconsolar",
    "desconsoles": "desconsolar",
    "desconsolo": "desconsolar",
    "desconsolos": "desconsolo",
    "desconsolou": "desconsolar",
    "desconsolá": "desconsolar",
    "desconsolámo": "desconsolar",
    "desconsolámos": "desconsolar",
    "desconsoláramo": "desconsolar",
    "desconsoláramos": "desconsolar",
    "desconsolárei": "desconsolar",
    "desconsoláreis": "desconsolar",
    "desconsolásseis": "desconsolar",
    "desconsolássemos": "desconsolar",
    "desconsolávamo": "desconsolar",
    "desconsolávamos": "desconsolar",
    "desconsolávei": "desconsolar",
    "desconsoláveis": "desconsolável",
    "desconstitucionaliza": "desconstitucionalizar",
    "desconstitucionalizada": "desconstitucionalizar",
    "desconstitucionalizadas": "desconstitucionalizar",
    "desconstitucionalizado": "desconstitucionalizar",
    "desconstitucionalizados": "desconstitucionalizar",
    "desconstitucionalizai": "desconstitucionalizar",
    "desconstitucionalizais": "desconstitucionalizar",
    "desconstitucionalizam": "desconstitucionalizar",
    "desconstitucionalizamo": "desconstitucionalizar",
    "desconstitucionalizamos": "desconstitucionalizar",
    "desconstitucionalizando": "desconstitucionalizar",
    "desconstitucionalizara": "desconstitucionalizar",
    "desconstitucionalizaram": "desconstitucionalizar",
    "desconstitucionalizaras": "desconstitucionalizar",
    "desconstitucionalizarde": "desconstitucionalizar",
    "desconstitucionalizardes": "desconstitucionalizar",
    "desconstitucionalizare": "desconstitucionalizar",
    "desconstitucionalizarei": "desconstitucionalizar",
    "desconstitucionalizareis": "desconstitucionalizar",
    "desconstitucionalizarem": "desconstitucionalizar",
    "desconstitucionalizaremos": "desconstitucionalizar",
    "desconstitucionalizares": "desconstitucionalizar",
    "desconstitucionalizaria": "desconstitucionalizar",
    "desconstitucionalizariam": "desconstitucionalizar",
    "desconstitucionalizarias": "desconstitucionalizar",
    "desconstitucionalizarmo": "desconstitucionalizar",
    "desconstitucionalizarmos": "desconstitucionalizar",
    "desconstitucionalizará": "desconstitucionalizar",
    "desconstitucionalizarás": "desconstitucionalizar",
    "desconstitucionalizarão": "desconstitucionalizar",
    "desconstitucionalizaríamos": "desconstitucionalizar",
    "desconstitucionalizaríeis": "desconstitucionalizar",
    "desconstitucionalizas": "desconstitucionalizar",
    "desconstitucionalizasse": "desconstitucionalizar",
    "desconstitucionalizassem": "desconstitucionalizar",
    "desconstitucionalizasses": "desconstitucionalizar",
    "desconstitucionalizaste": "desconstitucionalizar",
    "desconstitucionalizastes": "desconstitucionalizar",
    "desconstitucionalizava": "desconstitucionalizar",
    "desconstitucionalizavam": "desconstitucionalizar",
    "desconstitucionalizavas": "desconstitucionalizar",
    "desconstitucionalize": "desconstitucionalizar",
    "desconstitucionalizei": "desconstitucionalizar",
    "desconstitucionalizeis": "desconstitucionalizar",
    "desconstitucionalizem": "desconstitucionalizar",
    "desconstitucionalizemo": "desconstitucionalizar",
    "desconstitucionalizemos": "desconstitucionalizar",
    "desconstitucionalizes": "desconstitucionalizar",
    "desconstitucionalizo": "desconstitucionalizar",
    "desconstitucionalizou": "desconstitucionalizar",
    "desconstitucionalizá": "desconstitucionalizar",
    "desconstitucionalizámo": "desconstitucionalizar",
    "desconstitucionalizámos": "desconstitucionalizar",
    "desconstitucionalizáramo": "desconstitucionalizar",
    "desconstitucionalizáramos": "desconstitucionalizar",
    "desconstitucionalizárei": "desconstitucionalizar",
    "desconstitucionalizáreis": "desconstitucionalizar",
    "desconstitucionalizásseis": "desconstitucionalizar",
    "desconstitucionalizássemos": "desconstitucionalizar",
    "desconstitucionalizávamo": "desconstitucionalizar",
    "desconstitucionalizávamos": "desconstitucionalizar",
    "desconstitucionalizávei": "desconstitucionalizar",
    "desconstitucionalizáveis": "desconstitucionalizar",
    "desconstrange": "desconstranger",
    "desconstrangei": "desconstranger",
    "desconstrangeis": "desconstranger",
    "desconstrangem": "desconstranger",
    "desconstrangemo": "desconstranger",
    "desconstrangemos": "desconstranger",
    "desconstrangendo": "desconstranger",
    "desconstrangera": "desconstranger",
    "desconstrangeram": "desconstranger",
    "desconstrangeras": "desconstranger",
    "desconstrangerde": "desconstranger",
    "desconstrangerdes": "desconstranger",
    "desconstrangere": "desconstranger",
    "desconstrangerei": "desconstranger",
    "desconstrangereis": "desconstranger",
    "desconstrangerem": "desconstranger",
    "desconstrangeremos": "desconstranger",
    "desconstrangeres": "desconstranger",
    "desconstrangeria": "desconstranger",
    "desconstrangeriam": "desconstranger",
    "desconstrangerias": "desconstranger",
    "desconstrangermo": "desconstranger",
    "desconstrangermos": "desconstranger",
    "desconstrangerá": "desconstranger",
    "desconstrangerás": "desconstranger",
    "desconstrangerão": "desconstranger",
    "desconstrangeríamos": "desconstranger",
    "desconstrangeríeis": "desconstranger",
    "desconstranges": "desconstranger",
    "desconstrangesse": "desconstranger",
    "desconstrangessem": "desconstranger",
    "desconstrangesses": "desconstranger",
    "desconstrangeste": "desconstranger",
    "desconstrangestes": "desconstranger",
    "desconstrangeu": "desconstranger",
    "desconstrangi": "desconstranger",
    "desconstrangia": "desconstranger",
    "desconstrangiam": "desconstranger",
    "desconstrangias": "desconstranger",
    "desconstrangida": "desconstranger",
    "desconstrangidas": "desconstranger",
    "desconstrangido": "desconstranger",
    "desconstrangidos": "desconstranger",
    "desconstrangê": "desconstranger",
    "desconstrangêramo": "desconstranger",
    "desconstrangêramos": "desconstranger",
    "desconstrangêrei": "desconstranger",
    "desconstrangêreis": "desconstranger",
    "desconstrangêsseis": "desconstranger",
    "desconstrangêssemos": "desconstranger",
    "desconstrangíamo": "desconstranger",
    "desconstrangíamos": "desconstranger",
    "desconstrangíei": "desconstranger",
    "desconstrangíeis": "desconstranger",
    "desconstranja": "desconstranger",
    "desconstranjais": "desconstranger",
    "desconstranjam": "desconstranger",
    "desconstranjamo": "desconstranger",
    "desconstranjamos": "desconstranger",
    "desconstranjas": "desconstranger",
    "desconstranjo": "desconstranger",
    "desconstri": "desconstruir",
    "desconstroem": "desconstruir",
    "desconstrua": "desconstruir",
    "desconstruais": "desconstruir",
    "desconstruam": "desconstruir",
    "desconstruamo": "desconstruir",
    "desconstruamos": "desconstruir",
    "desconstruas": "desconstruir",
    "desconstruem": "desconstruir",
    "desconstrui": "desconstruir",
    "desconstruindo": "desconstruir",
    "desconstruirde": "desconstruir",
    "desconstruirdes": "desconstruir",
    "desconstruirei": "desconstruir",
    "desconstruireis": "desconstruir",
    "desconstruiremos": "desconstruir",
    "desconstruiria": "desconstruir",
    "desconstruiriam": "desconstruir",
    "desconstruirias": "desconstruir",
    "desconstruirmo": "desconstruir",
    "desconstruirmos": "desconstruir",
    "desconstruirá": "desconstruir",
    "desconstruirás": "desconstruir",
    "desconstruirão": "desconstruir",
    "desconstruiríamos": "desconstruir",
    "desconstruiríeis": "desconstruir",
    "desconstruis": "desconstruir",
    "desconstruiu": "desconstruir",
    "desconstruo": "desconstruir",
    "desconstrutivistas": "desconstrutivista",
    "desconstruções": "desconstrução",
    "desconstruí": "desconstruir",
    "desconstruía": "desconstruir",
    "desconstruíam": "desconstruir",
    "desconstruíamo": "desconstruir",
    "desconstruíamos": "desconstruir",
    "desconstruías": "desconstruir",
    "desconstruída": "desconstruir",
    "desconstruídas": "desconstruir",
    "desconstruído": "desconstruir",
    "desconstruídos": "desconstruir",
    "desconstruíei": "desconstruir",
    "desconstruíeis": "desconstruir",
    "desconstruímo": "desconstruir",
    "desconstruímos": "desconstruir",
    "desconstruíra": "desconstruir",
    "desconstruíram": "desconstruir",
    "desconstruíramo": "desconstruir",
    "desconstruíramos": "desconstruir",
    "desconstruíras": "desconstruir",
    "desconstruíre": "desconstruir",
    "desconstruírei": "desconstruir",
    "desconstruíreis": "desconstruir",
    "desconstruírem": "desconstruir",
    "desconstruíres": "desconstruir",
    "desconstruís": "desconstruir",
    "desconstruísse": "desconstruir",
    "desconstruísseis": "desconstruir",
    "desconstruíssem": "desconstruir",
    "desconstruíssemos": "desconstruir",
    "desconstruísses": "desconstruir",
    "desconstruíste": "desconstruir",
    "desconstruístes": "desconstruir",
    "desconstrói": "desconstruir",
    "desconstróis": "desconstruir",
    "desconta": "descontar",
    "descontada": "descontar",
    "descontadas": "descontar",
    "descontado": "descontar",
    "descontados": "descontar",
    "descontai": "descontar",
    "descontais": "descontar",
    "descontam": "descontar",
    "descontaminada": "descontaminado",
    "descontaminadas": "descontaminado",
    "descontaminados": "descontaminado",
    "descontaminações": "descontaminação",
    "descontamo": "descontar",
    "descontamos": "descontar",
    "descontando": "descontar",
    "descontara": "descontar",
    "descontaram": "descontar",
    "descontaras": "descontar",
    "descontarde": "descontar",
    "descontardes": "descontar",
    "descontare": "descontar",
    "descontarei": "descontar",
    "descontareis": "descontar",
    "descontarem": "descontar",
    "descontaremos": "descontar",
    "descontares": "descontar",
    "descontaria": "descontar",
    "descontariam": "descontar",
    "descontarias": "descontar",
    "descontarmo": "descontar",
    "descontarmos": "descontar",
    "descontará": "descontar",
    "descontarás": "descontar",
    "descontarão": "descontar",
    "descontaríamos": "descontar",
    "descontaríeis": "descontar",
    "descontas": "descontar",
    "descontasse": "descontar",
    "descontassem": "descontar",
    "descontasses": "descontar",
    "descontaste": "descontar",
    "descontastes": "descontar",
    "descontava": "descontar",
    "descontavam": "descontar",
    "descontavas": "descontar",
    "desconte": "descontar",
    "descontei": "descontar",
    "desconteis": "descontar",
    "descontem": "descontar",
    "descontemo": "descontar",
    "descontemos": "descontar",
    "descontenta": "descontentar",
    "descontentada": "descontentar",
    "descontentadas": "descontentar",
    "descontentadiça": "descontentadiço",
    "descontentadiças": "descontentadiço",
    "descontentadiços": "descontentadiço",
    "descontentado": "descontentar",
    "descontentados": "descontentar",
    "descontentai": "descontentar",
    "descontentais": "descontentar",
    "descontentam": "descontentar",
    "descontentamentos": "descontentamento",
    "descontentamo": "descontentar",
    "descontentamos": "descontentar",
    "descontentando": "descontentar",
    "descontentara": "descontentar",
    "descontentaram": "descontentar",
    "descontentaras": "descontentar",
    "descontentarde": "descontentar",
    "descontentardes": "descontentar",
    "descontentare": "descontentar",
    "descontentarei": "descontentar",
    "descontentareis": "descontentar",
    "descontentarem": "descontentar",
    "descontentaremos": "descontentar",
    "descontentares": "descontentar",
    "descontentaria": "descontentar",
    "descontentariam": "descontentar",
    "descontentarias": "descontentar",
    "descontentarmo": "descontentar",
    "descontentarmos": "descontentar",
    "descontentará": "descontentar",
    "descontentarás": "descontentar",
    "descontentarão": "descontentar",
    "descontentaríamos": "descontentar",
    "descontentaríeis": "descontentar",
    "descontentas": "descontentar",
    "descontentasse": "descontentar",
    "descontentassem": "descontentar",
    "descontentasses": "descontentar",
    "descontentaste": "descontentar",
    "descontentastes": "descontentar",
    "descontentava": "descontentar",
    "descontentavam": "descontentar",
    "descontentavas": "descontentar",
    "descontente": "descontentar",
    "descontentei": "descontentar",
    "descontenteis": "descontentar",
    "descontentem": "descontentar",
    "descontentemo": "descontentar",
    "descontentemos": "descontentar",
    "descontentes": "descontente",
    "descontento": "descontentar",
    "descontentou": "descontentar",
    "descontentá": "descontentar",
    "descontentámo": "descontentar",
    "descontentámos": "descontentar",
    "descontentáramo": "descontentar",
    "descontentáramos": "descontentar",
    "descontentárei": "descontentar",
    "descontentáreis": "descontentar",
    "descontentásseis": "descontentar",
    "descontentássemos": "descontentar",
    "descontentávamo": "descontentar",
    "descontentávamos": "descontentar",
    "descontentávei": "descontentar",
    "descontentáveis": "descontentar",
    "descontentíssima": "descontente",
    "descontentíssimas": "descontente",
    "descontentíssimo": "descontente",
    "descontentíssimos": "descontente",
    "descontes": "descontar",
    "descontextualizada": "descontextualizado",
    "descontextualizadas": "descontextualizado",
    "descontextualizados": "descontextualizado",
    "descontextualizações": "descontextualização",
    "descontinho": "desconto",
    "descontinhos": "desconto",
    "descontinua": "descontinuar",
    "descontinuada": "descontinuar",
    "descontinuadas": "descontinuar",
    "descontinuado": "descontinuar",
    "descontinuadora": "descontinuador",
    "descontinuadoras": "descontinuador",
    "descontinuadores": "descontinuador",
    "descontinuados": "descontinuar",
    "descontinuai": "descontinuar",
    "descontinuais": "descontinuar",
    "descontinuam": "descontinuar",
    "descontinuamo": "descontinuar",
    "descontinuamos": "descontinuar",
    "descontinuando": "descontinuar",
    "descontinuara": "descontinuar",
    "descontinuaram": "descontinuar",
    "descontinuaras": "descontinuar",
    "descontinuarde": "descontinuar",
    "descontinuardes": "descontinuar",
    "descontinuare": "descontinuar",
    "descontinuarei": "descontinuar",
    "descontinuareis": "descontinuar",
    "descontinuarem": "descontinuar",
    "descontinuaremos": "descontinuar",
    "descontinuares": "descontinuar",
    "descontinuaria": "descontinuar",
    "descontinuariam": "descontinuar",
    "descontinuarias": "descontinuar",
    "descontinuarmo": "descontinuar",
    "descontinuarmos": "descontinuar",
    "descontinuará": "descontinuar",
    "descontinuarás": "descontinuar",
    "descontinuarão": "descontinuar",
    "descontinuaríamos": "descontinuar",
    "descontinuaríeis": "descontinuar",
    "descontinuas": "descontinuar",
    "descontinuasse": "descontinuar",
    "descontinuassem": "descontinuar",
    "descontinuasses": "descontinuar",
    "descontinuaste": "descontinuar",
    "descontinuastes": "descontinuar",
    "descontinuava": "descontinuar",
    "descontinuavam": "descontinuar",
    "descontinuavas": "descontinuar",
    "descontinuações": "descontinuação",
    "descontinue": "descontinuar",
    "descontinuei": "descontinuar",
    "descontinueis": "descontinuar",
    "descontinuem": "descontinuar",
    "descontinuemo": "descontinuar",
    "descontinuemos": "descontinuar",
    "descontinues": "descontinuar",
    "descontinuidades": "descontinuidade",
    "descontinuo": "descontinuar",
    "descontinuou": "descontinuar",
    "descontinuá": "descontinuar",
    "descontinuámo": "descontinuar",
    "descontinuámos": "descontinuar",
    "descontinuáramo": "descontinuar",
    "descontinuáramos": "descontinuar",
    "descontinuárei": "descontinuar",
    "descontinuáreis": "descontinuar",
    "descontinuásseis": "descontinuar",
    "descontinuássemos": "descontinuar",
    "descontinuávamo": "descontinuar",
    "descontinuávamos": "descontinuar",
    "descontinuávei": "descontinuar",
    "descontinuáveis": "descontinuar",
    "descontito": "desconto",
    "descontitos": "desconto",
    "desconto": "descontar",
    "descontos": "desconto",
    "descontou": "descontar",
    "descontozinho": "desconto",
    "descontozinhos": "desconto",
    "descontozito": "desconto",
    "descontozitos": "desconto",
    "descontracções": "descontracção",
    "descontraem": "descontrair",
    "descontrai": "descontrair",
    "descontraia": "descontrair",
    "descontraiais": "descontrair",
    "descontraiam": "descontrair",
    "descontraiamo": "descontrair",
    "descontraiamos": "descontrair",
    "descontraias": "descontrair",
    "descontraida": "descontraido",
    "descontraidas": "descontraido",
    "descontraidos": "descontraido",
    "descontraindo": "descontrair",
    "descontraio": "descontrair",
    "descontrairde": "descontrair",
    "descontrairdes": "descontrair",
    "descontrairei": "descontrair",
    "descontraireis": "descontrair",
    "descontrairemos": "descontrair",
    "descontrairia": "descontrair",
    "descontrairiam": "descontrair",
    "descontrairias": "descontrair",
    "descontrairmo": "descontrair",
    "descontrairmos": "descontrair",
    "descontrairá": "descontrair",
    "descontrairás": "descontrair",
    "descontrairão": "descontrair",
    "descontrairíamos": "descontrair",
    "descontrairíeis": "descontrair",
    "descontrais": "descontrair",
    "descontraiu": "descontrair",
    "descontrata": "descontratar",
    "descontratada": "descontratar",
    "descontratadas": "descontratar",
    "descontratado": "descontratar",
    "descontratados": "descontratar",
    "descontratai": "descontratar",
    "descontratais": "descontratar",
    "descontratam": "descontratar",
    "descontratamo": "descontratar",
    "descontratamos": "descontratar",
    "descontratando": "descontratar",
    "descontratara": "descontratar",
    "descontrataram": "descontratar",
    "descontrataras": "descontratar",
    "descontratarde": "descontratar",
    "descontratardes": "descontratar",
    "descontratare": "descontratar",
    "descontratarei": "descontratar",
    "descontratareis": "descontratar",
    "descontratarem": "descontratar",
    "descontrataremos": "descontratar",
    "descontratares": "descontratar",
    "descontrataria": "descontratar",
    "descontratariam": "descontratar",
    "descontratarias": "descontratar",
    "descontratarmo": "descontratar",
    "descontratarmos": "descontratar",
    "descontratará": "descontratar",
    "descontratarás": "descontratar",
    "descontratarão": "descontratar",
    "descontrataríamos": "descontratar",
    "descontrataríeis": "descontratar",
    "descontratas": "descontratar",
    "descontratasse": "descontratar",
    "descontratassem": "descontratar",
    "descontratasses": "descontratar",
    "descontrataste": "descontratar",
    "descontratastes": "descontratar",
    "descontratava": "descontratar",
    "descontratavam": "descontratar",
    "descontratavas": "descontratar",
    "descontrate": "descontratar",
    "descontratei": "descontratar",
    "descontrateis": "descontratar",
    "descontratem": "descontratar",
    "descontratemo": "descontratar",
    "descontratemos": "descontratar",
    "descontrates": "descontratar",
    "descontrato": "descontratar",
    "descontratou": "descontratar",
    "descontratá": "descontratar",
    "descontratámo": "descontratar",
    "descontratámos": "descontratar",
    "descontratáramo": "descontratar",
    "descontratáramos": "descontratar",
    "descontratárei": "descontratar",
    "descontratáreis": "descontratar",
    "descontratásseis": "descontratar",
    "descontratássemos": "descontratar",
    "descontratávamo": "descontratar",
    "descontratávamos": "descontratar",
    "descontratávei": "descontratar",
    "descontratáveis": "descontratar",
    "descontraí": "descontrair",
    "descontraía": "descontrair",
    "descontraíam": "descontrair",
    "descontraíamo": "descontrair",
    "descontraíamos": "descontrair",
    "descontraías": "descontrair",
    "descontraída": "descontrair",
    "descontraídas": "descontrair",
    "descontraído": "descontrair",
    "descontraídos": "descontrair",
    "descontraíei": "descontrair",
    "descontraíeis": "descontrair",
    "descontraímo": "descontrair",
    "descontraímos": "descontrair",
    "descontraíra": "descontrair",
    "descontraíram": "descontrair",
    "descontraíramo": "descontrair",
    "descontraíramos": "descontrair",
    "descontraíras": "descontrair",
    "descontraíre": "descontrair",
    "descontraírei": "descontrair",
    "descontraíreis": "descontrair",
    "descontraírem": "descontrair",
    "descontraíres": "descontrair",
    "descontraís": "descontrair",
    "descontraísse": "descontrair",
    "descontraísseis": "descontrair",
    "descontraíssem": "descontrair",
    "descontraíssemos": "descontrair",
    "descontraísses": "descontrair",
    "descontraíste": "descontrair",
    "descontraístes": "descontrair",
    "descontrola": "descontrolar",
    "descontrolada": "descontrolar",
    "descontroladas": "descontrolar",
    "descontrolado": "descontrolar",
    "descontrolados": "descontrolar",
    "descontrolai": "descontrolar",
    "descontrolais": "descontrolar",
    "descontrolam": "descontrolar",
    "descontrolamo": "descontrolar",
    "descontrolamos": "descontrolar",
    "descontrolando": "descontrolar",
    "descontrolara": "descontrolar",
    "descontrolaram": "descontrolar",
    "descontrolaras": "descontrolar",
    "descontrolarde": "descontrolar",
    "descontrolardes": "descontrolar",
    "descontrolare": "descontrolar",
    "descontrolarei": "descontrolar",
    "descontrolareis": "descontrolar",
    "descontrolarem": "descontrolar",
    "descontrolaremos": "descontrolar",
    "descontrolares": "descontrolar",
    "descontrolaria": "descontrolar",
    "descontrolariam": "descontrolar",
    "descontrolarias": "descontrolar",
    "descontrolarmo": "descontrolar",
    "descontrolarmos": "descontrolar",
    "descontrolará": "descontrolar",
    "descontrolarás": "descontrolar",
    "descontrolarão": "descontrolar",
    "descontrolaríamos": "descontrolar",
    "descontrolaríeis": "descontrolar",
    "descontrolas": "descontrolar",
    "descontrolasse": "descontrolar",
    "descontrolassem": "descontrolar",
    "descontrolasses": "descontrolar",
    "descontrolaste": "descontrolar",
    "descontrolastes": "descontrolar",
    "descontrolava": "descontrolar",
    "descontrolavam": "descontrolar",
    "descontrolavas": "descontrolar",
    "descontrole": "descontrolar",
    "descontrolei": "descontrolar",
    "descontroleis": "descontrolar",
    "descontrolem": "descontrolar",
    "descontrolemo": "descontrolar",
    "descontrolemos": "descontrolar",
    "descontroles": "descontrole",
    "descontrolo": "descontrolar",
    "descontrolos": "descontrolo",
    "descontrolou": "descontrolar",
    "descontrolá": "descontrolar",
    "descontrolámo": "descontrolar",
    "descontrolámos": "descontrolar",
    "descontroláramo": "descontrolar",
    "descontroláramos": "descontrolar",
    "descontrolárei": "descontrolar",
    "descontroláreis": "descontrolar",
    "descontrolásseis": "descontrolar",
    "descontrolássemos": "descontrolar",
    "descontrolávamo": "descontrolar",
    "descontrolávamos": "descontrolar",
    "descontrolávei": "descontrolar",
    "descontroláveis": "descontrolar",
    "descontá": "descontar",
    "descontámo": "descontar",
    "descontámos": "descontar",
    "descontáramo": "descontar",
    "descontáramos": "descontar",
    "descontárei": "descontar",
    "descontáreis": "descontar",
    "descontásseis": "descontar",
    "descontássemos": "descontar",
    "descontávamo": "descontar",
    "descontávamos": "descontar",
    "descontávei": "descontar",
    "descontáveis": "descontável",
    "descontínua": "descontínuo",
    "descontínuas": "descontínuo",
    "descontínuos": "descontínuo",
    "desconva": "desconvir",
    "desconvais": "desconvir",
    "desconvam": "desconvir",
    "desconvamo": "desconvir",
    "desconvamos": "desconvir",
    "desconvas": "desconvir",
    "desconve": "desconvir",
    "desconvem": "desconvir",
    "desconvence": "desconvencer",
    "desconvencei": "desconvencer",
    "desconvenceis": "desconvencer",
    "desconvencem": "desconvencer",
    "desconvencemo": "desconvencer",
    "desconvencemos": "desconvencer",
    "desconvencendo": "desconvencer",
    "desconvencera": "desconvencer",
    "desconvenceram": "desconvencer",
    "desconvenceras": "desconvencer",
    "desconvencerde": "desconvencer",
    "desconvencerdes": "desconvencer",
    "desconvencere": "desconvencer",
    "desconvencerei": "desconvencer",
    "desconvencereis": "desconvencer",
    "desconvencerem": "desconvencer",
    "desconvenceremos": "desconvencer",
    "desconvenceres": "desconvencer",
    "desconvenceria": "desconvencer",
    "desconvenceriam": "desconvencer",
    "desconvencerias": "desconvencer",
    "desconvencermo": "desconvencer",
    "desconvencermos": "desconvencer",
    "desconvencerá": "desconvencer",
    "desconvencerás": "desconvencer",
    "desconvencerão": "desconvencer",
    "desconvenceríamos": "desconvencer",
    "desconvenceríeis": "desconvencer",
    "desconvences": "desconvencer",
    "desconvencesse": "desconvencer",
    "desconvencessem": "desconvencer",
    "desconvencesses": "desconvencer",
    "desconvenceste": "desconvencer",
    "desconvencestes": "desconvencer",
    "desconvenceu": "desconvencer",
    "desconvenci": "desconvencer",
    "desconvencia": "desconvencer",
    "desconvenciam": "desconvencer",
    "desconvencias": "desconvencer",
    "desconvencida": "desconvencido",
    "desconvencidas": "desconvencido",
    "desconvencido": "desconvencer",
    "desconvencidos": "desconvencido",
    "desconvencê": "desconvencer",
    "desconvencêramo": "desconvencer",
    "desconvencêramos": "desconvencer",
    "desconvencêrei": "desconvencer",
    "desconvencêreis": "desconvencer",
    "desconvencêsseis": "desconvencer",
    "desconvencêssemos": "desconvencer",
    "desconvencíamo": "desconvencer",
    "desconvencíamos": "desconvencer",
    "desconvencíei": "desconvencer",
    "desconvencíeis": "desconvencer",
    "desconvenientes": "desconveniente",
    "desconveniências": "desconveniência",
    "desconvença": "desconvencer",
    "desconvençais": "desconvencer",
    "desconvençam": "desconvencer",
    "desconvençamo": "desconvencer",
    "desconvençamos": "desconvencer",
    "desconvenças": "desconvencer",
    "desconvenço": "desconvencer",
    "desconversa": "desconversar",
    "desconversada": "desconversar",
    "desconversadas": "desconversar",
    "desconversado": "desconversar",
    "desconversados": "desconversar",
    "desconversai": "desconversar",
    "desconversais": "desconversar",
    "desconversam": "desconversar",
    "desconversamo": "desconversar",
    "desconversamos": "desconversar",
    "desconversando": "desconversar",
    "desconversara": "desconversar",
    "desconversaram": "desconversar",
    "desconversaras": "desconversar",
    "desconversardes": "desconversar",
    "desconversarei": "desconversar",
    "desconversareis": "desconversar",
    "desconversarem": "desconversar",
    "desconversaremos": "desconversar",
    "desconversares": "desconversar",
    "desconversaria": "desconversar",
    "desconversariam": "desconversar",
    "desconversarias": "desconversar",
    "desconversarmo": "desconversar",
    "desconversarmos": "desconversar",
    "desconversará": "desconversar",
    "desconversarás": "desconversar",
    "desconversarão": "desconversar",
    "desconversaríamos": "desconversar",
    "desconversaríeis": "desconversar",
    "desconversas": "desconversar",
    "desconversasse": "desconversar",
    "desconversassem": "desconversar",
    "desconversasses": "desconversar",
    "desconversaste": "desconversar",
    "desconversastes": "desconversar",
    "desconversava": "desconversar",
    "desconversavam": "desconversar",
    "desconversavas": "desconversar",
    "desconversações": "desconversação",
    "desconverse": "desconversar",
    "desconversei": "desconversar",
    "desconverseis": "desconversar",
    "desconversem": "desconversar",
    "desconversemo": "desconversar",
    "desconversemos": "desconversar",
    "desconverses": "desconversar",
    "desconverso": "desconversar",
    "desconversou": "desconversar",
    "desconversámo": "desconversar",
    "desconversámos": "desconversar",
    "desconversáramo": "desconversar",
    "desconversáramos": "desconversar",
    "desconversáreis": "desconversar",
    "desconversásseis": "desconversar",
    "desconversássemos": "desconversar",
    "desconversávamo": "desconversar",
    "desconversávamos": "desconversar",
    "desconversáveis": "desconversável",
    "desconversões": "desconversão",
    "desconverta": "desconverter",
    "desconvertais": "desconverter",
    "desconvertam": "desconverter",
    "desconvertamo": "desconverter",
    "desconvertamos": "desconverter",
    "desconvertas": "desconverter",
    "desconverte": "desconverter",
    "desconvertei": "desconverter",
    "desconverteis": "desconverter",
    "desconvertem": "desconverter",
    "desconvertemo": "desconverter",
    "desconvertemos": "desconverter",
    "desconvertendo": "desconverter",
    "desconvertera": "desconverter",
    "desconverteram": "desconverter",
    "desconverteras": "desconverter",
    "desconverterde": "desconverter",
    "desconverterdes": "desconverter",
    "desconvertere": "desconverter",
    "desconverterei": "desconverter",
    "desconvertereis": "desconverter",
    "desconverterem": "desconverter",
    "desconverteremos": "desconverter",
    "desconverteres": "desconverter",
    "desconverteria": "desconverter",
    "desconverteriam": "desconverter",
    "desconverterias": "desconverter",
    "desconvertermo": "desconverter",
    "desconvertermos": "desconverter",
    "desconverterá": "desconverter",
    "desconverterás": "desconverter",
    "desconverterão": "desconverter",
    "desconverteríamos": "desconverter",
    "desconverteríeis": "desconverter",
    "desconvertes": "desconverter",
    "desconvertesse": "desconverter",
    "desconvertessem": "desconverter",
    "desconvertesses": "desconverter",
    "desconverteste": "desconverter",
    "desconvertestes": "desconverter",
    "desconverteu": "desconverter",
    "desconverti": "desconverter",
    "desconvertia": "desconverter",
    "desconvertiam": "desconverter",
    "desconvertias": "desconverter",
    "desconvertida": "desconvertido",
    "desconvertidas": "desconvertido",
    "desconvertido": "desconverter",
    "desconvertidos": "desconvertido",
    "desconverto": "desconverter",
    "desconvertê": "desconverter",
    "desconvertêramo": "desconverter",
    "desconvertêramos": "desconverter",
    "desconvertêrei": "desconverter",
    "desconvertêreis": "desconverter",
    "desconvertêsseis": "desconverter",
    "desconvertêssemos": "desconverter",
    "desconvertíamo": "desconverter",
    "desconvertíamos": "desconverter",
    "desconvertíei": "desconverter",
    "desconvertíeis": "desconverter",
    "desconves": "desconvir",
    "desconvi": "desconvir",
    "desconvia": "desconvir",
    "desconviam": "desconvir",
    "desconvias": "desconvir",
    "desconvida": "desconvir",
    "desconvidada": "desconvidar",
    "desconvidadas": "desconvidar",
    "desconvidado": "desconvidar",
    "desconvidados": "desconvidar",
    "desconvidai": "desconvidar",
    "desconvidais": "desconvidar",
    "desconvidam": "desconvidar",
    "desconvidamo": "desconvidar",
    "desconvidamos": "desconvidar",
    "desconvidando": "desconvidar",
    "desconvidara": "desconvidar",
    "desconvidaram": "desconvidar",
    "desconvidaras": "desconvidar",
    "desconvidarde": "desconvidar",
    "desconvidardes": "desconvidar",
    "desconvidare": "desconvidar",
    "desconvidarei": "desconvidar",
    "desconvidareis": "desconvidar",
    "desconvidarem": "desconvidar",
    "desconvidaremos": "desconvidar",
    "desconvidares": "desconvidar",
    "desconvidaria": "desconvidar",
    "desconvidariam": "desconvidar",
    "desconvidarias": "desconvidar",
    "desconvidarmo": "desconvidar",
    "desconvidarmos": "desconvidar",
    "desconvidará": "desconvidar",
    "desconvidarás": "desconvidar",
    "desconvidarão": "desconvidar",
    "desconvidaríamos": "desconvidar",
    "desconvidaríeis": "desconvidar",
    "desconvidas": "desconvir",
    "desconvidasse": "desconvidar",
    "desconvidassem": "desconvidar",
    "desconvidasses": "desconvidar",
    "desconvidaste": "desconvidar",
    "desconvidastes": "desconvidar",
    "desconvidativa": "desconvidativo",
    "desconvidativas": "desconvidativo",
    "desconvidativos": "desconvidativo",
    "desconvidava": "desconvidar",
    "desconvidavam": "desconvidar",
    "desconvidavas": "desconvidar",
    "desconvide": "desconvidar",
    "desconvidei": "desconvidar",
    "desconvideis": "desconvidar",
    "desconvidem": "desconvidar",
    "desconvidemo": "desconvidar",
    "desconvidemos": "desconvidar",
    "desconvides": "desconvidar",
    "desconvido": "desconvir",
    "desconvidos": "desconvir",
    "desconvidou": "desconvidar",
    "desconvidá": "desconvidar",
    "desconvidámo": "desconvidar",
    "desconvidámos": "desconvidar",
    "desconvidáramo": "desconvidar",
    "desconvidáramos": "desconvidar",
    "desconvidárei": "desconvidar",
    "desconvidáreis": "desconvidar",
    "desconvidásseis": "desconvidar",
    "desconvidássemos": "desconvidar",
    "desconvidávamo": "desconvidar",
    "desconvidávamos": "desconvidar",
    "desconvidávei": "desconvidar",
    "desconvidáveis": "desconvidar",
    "desconvimo": "desconvir",
    "desconvimos": "desconvir",
    "desconvindo": "desconvir",
    "desconvira": "desconvir",
    "desconviram": "desconvir",
    "desconviras": "desconvir",
    "desconvirdes": "desconvir",
    "desconvirei": "desconvir",
    "desconvireis": "desconvir",
    "desconvirem": "desconvir",
    "desconviremos": "desconvir",
    "desconvires": "desconvir",
    "desconviria": "desconvir",
    "desconviriam": "desconvir",
    "desconvirias": "desconvir",
    "desconvirmo": "desconvir",
    "desconvirmos": "desconvir",
    "desconvirá": "desconvir",
    "desconvirás": "desconvir",
    "desconvirão": "desconvir",
    "desconviríamos": "desconvir",
    "desconviríeis": "desconvir",
    "desconvis": "desconvir",
    "desconvisse": "desconvir",
    "desconvissem": "desconvir",
    "desconvisses": "desconvir",
    "desconviste": "desconvir",
    "desconvistes": "desconvir",
    "desconviu": "desconvir",
    "desconvivências": "desconvivência",
    "desconvizinha": "desconvizinho",
    "desconvizinhas": "desconvizinho",
    "desconvizinhos": "desconvizinho",
    "desconvo": "desconvir",
    "desconvoca": "desconvocar",
    "desconvocada": "desconvocar",
    "desconvocadas": "desconvocar",
    "desconvocado": "desconvocar",
    "desconvocados": "desconvocar",
    "desconvocai": "desconvocar",
    "desconvocais": "desconvocar",
    "desconvocam": "desconvocar",
    "desconvocamo": "desconvocar",
    "desconvocamos": "desconvocar",
    "desconvocando": "desconvocar",
    "desconvocara": "desconvocar",
    "desconvocaram": "desconvocar",
    "desconvocaras": "desconvocar",
    "desconvocarde": "desconvocar",
    "desconvocardes": "desconvocar",
    "desconvocare": "desconvocar",
    "desconvocarei": "desconvocar",
    "desconvocareis": "desconvocar",
    "desconvocarem": "desconvocar",
    "desconvocaremos": "desconvocar",
    "desconvocares": "desconvocar",
    "desconvocaria": "desconvocar",
    "desconvocariam": "desconvocar",
    "desconvocarias": "desconvocar",
    "desconvocarmo": "desconvocar",
    "desconvocarmos": "desconvocar",
    "desconvocará": "desconvocar",
    "desconvocarás": "desconvocar",
    "desconvocarão": "desconvocar",
    "desconvocaríamos": "desconvocar",
    "desconvocaríeis": "desconvocar",
    "desconvocas": "desconvocar",
    "desconvocasse": "desconvocar",
    "desconvocassem": "desconvocar",
    "desconvocasses": "desconvocar",
    "desconvocaste": "desconvocar",
    "desconvocastes": "desconvocar",
    "desconvocava": "desconvocar",
    "desconvocavam": "desconvocar",
    "desconvocavas": "desconvocar",
    "desconvocações": "desconvocação",
    "desconvoco": "desconvocar",
    "desconvocou": "desconvocar",
    "desconvocá": "desconvocar",
    "desconvocámo": "desconvocar",
    "desconvocámos": "desconvocar",
    "desconvocáramo": "desconvocar",
    "desconvocáramos": "desconvocar",
    "desconvocárei": "desconvocar",
    "desconvocáreis": "desconvocar",
    "desconvocásseis": "desconvocar",
    "desconvocássemos": "desconvocar",
    "desconvocávamo": "desconvocar",
    "desconvocávamos": "desconvocar",
    "desconvocávei": "desconvocar",
    "desconvocáveis": "desconvocar",
    "desconvoque": "desconvocar",
    "desconvoquei": "desconvocar",
    "desconvoqueis": "desconvocar",
    "desconvoquem": "desconvocar",
    "desconvoquemo": "desconvocar",
    "desconvoquemos": "desconvocar",
    "desconvoques": "desconvocar",
    "desconvíamo": "desconvir",
    "desconvíamos": "desconvir",
    "desconvíeis": "desconvir",
    "desconvíramo": "desconvir",
    "desconvíramos": "desconvir",
    "desconvíreis": "desconvir",
    "desconvísseis": "desconvir",
    "desconvíssemos": "desconvir",
    "descoordena": "descoordenar",
    "descoordenada": "descoordenar",
    "descoordenadas": "descoordenar",
    "descoordenado": "descoordenar",
    "descoordenados": "descoordenar",
    "descoordenai": "descoordenar",
    "descoordenais": "descoordenar",
    "descoordenam": "descoordenar",
    "descoordenamo": "descoordenar",
    "descoordenamos": "descoordenar",
    "descoordenando": "descoordenar",
    "descoordenara": "descoordenar",
    "descoordenaram": "descoordenar",
    "descoordenaras": "descoordenar",
    "descoordenarde": "descoordenar",
    "descoordenardes": "descoordenar",
    "descoordenare": "descoordenar",
    "descoordenarei": "descoordenar",
    "descoordenareis": "descoordenar",
    "descoordenarem": "descoordenar",
    "descoordenaremos": "descoordenar",
    "descoordenares": "descoordenar",
    "descoordenaria": "descoordenar",
    "descoordenariam": "descoordenar",
    "descoordenarias": "descoordenar",
    "descoordenarmo": "descoordenar",
    "descoordenarmos": "descoordenar",
    "descoordenará": "descoordenar",
    "descoordenarás": "descoordenar",
    "descoordenarão": "descoordenar",
    "descoordenaríamos": "descoordenar",
    "descoordenaríeis": "descoordenar",
    "descoordenas": "descoordenar",
    "descoordenasse": "descoordenar",
    "descoordenassem": "descoordenar",
    "descoordenasses": "descoordenar",
    "descoordenaste": "descoordenar",
    "descoordenastes": "descoordenar",
    "descoordenava": "descoordenar",
    "descoordenavam": "descoordenar",
    "descoordenavas": "descoordenar",
    "descoordenações": "descoordenação",
    "descoordene": "descoordenar",
    "descoordenei": "descoordenar",
    "descoordeneis": "descoordenar",
    "descoordenem": "descoordenar",
    "descoordenemo": "descoordenar",
    "descoordenemos": "descoordenar",
    "descoordenes": "descoordenar",
    "descoordeno": "descoordenar",
    "descoordenou": "descoordenar",
    "descoordená": "descoordenar",
    "descoordenámo": "descoordenar",
    "descoordenámos": "descoordenar",
    "descoordenáramo": "descoordenar",
    "descoordenáramos": "descoordenar",
    "descoordenárei": "descoordenar",
    "descoordenáreis": "descoordenar",
    "descoordenásseis": "descoordenar",
    "descoordenássemos": "descoordenar",
    "descoordenávamo": "descoordenar",
    "descoordenávamos": "descoordenar",
    "descoordenávei": "descoordenar",
    "descoordenáveis": "descoordenar",
    "descora": "descorar",
    "descorada": "descorar",
    "descoradas": "descorar",
    "descorado": "descorar",
    "descorados": "descorar",
    "descoradíssima": "descorado",
    "descoradíssimas": "descorado",
    "descoradíssimo": "descorado",
    "descoradíssimos": "descorado",
    "descoragens": "descoragem",
    "descorai": "descorar",
    "descorais": "descorar",
    "descoram": "descorar",
    "descoramo": "descorar",
    "descoramos": "descorar",
    "descorando": "descorar",
    "descorantes": "descorante",
    "descorara": "descorar",
    "descoraram": "descorar",
    "descoraras": "descorar",
    "descorarde": "descorar",
    "descorardes": "descorar",
    "descorare": "descorar",
    "descorarei": "descorar",
    "descorareis": "descorar",
    "descorarem": "descorar",
    "descoraremos": "descorar",
    "descorares": "descorar",
    "descoraria": "descorar",
    "descorariam": "descorar",
    "descorarias": "descorar",
    "descorarmo": "descorar",
    "descorarmos": "descorar",
    "descorará": "descorar",
    "descorarás": "descorar",
    "descorarão": "descorar",
    "descoraríamos": "descorar",
    "descoraríeis": "descorar",
    "descoras": "descorar",
    "descorasse": "descorar",
    "descorassem": "descorar",
    "descorasses": "descorar",
    "descoraste": "descorar",
    "descorastes": "descorar",
    "descorava": "descorar",
    "descoravam": "descorar",
    "descoravas": "descorar",
    "descorda": "descordar",
    "descordada": "descordar",
    "descordadas": "descordar",
    "descordado": "descordar",
    "descordados": "descordar",
    "descordai": "descordar",
    "descordais": "descordar",
    "descordam": "descordar",
    "descordamo": "descordar",
    "descordamos": "descordar",
    "descordando": "descordar",
    "descordara": "descordar",
    "descordaram": "descordar",
    "descordaras": "descordar",
    "descordarde": "descordar",
    "descordardes": "descordar",
    "descordare": "descordar",
    "descordarei": "descordar",
    "descordareis": "descordar",
    "descordarem": "descordar",
    "descordaremos": "descordar",
    "descordares": "descordar",
    "descordaria": "descordar",
    "descordariam": "descordar",
    "descordarias": "descordar",
    "descordarmo": "descordar",
    "descordarmos": "descordar",
    "descordará": "descordar",
    "descordarás": "descordar",
    "descordarão": "descordar",
    "descordaríamos": "descordar",
    "descordaríeis": "descordar",
    "descordas": "descordar",
    "descordasse": "descordar",
    "descordassem": "descordar",
    "descordasses": "descordar",
    "descordaste": "descordar",
    "descordastes": "descordar",
    "descordava": "descordar",
    "descordavam": "descordar",
    "descordavas": "descordar",
    "descorde": "descordar",
    "descordei": "descordar",
    "descordeis": "descordar",
    "descordem": "descordar",
    "descordemo": "descordar",
    "descordemos": "descordar",
    "descordes": "descordar",
    "descordo": "descordar",
    "descordos": "descordo",
    "descordou": "descordar",
    "descordá": "descordar",
    "descordámo": "descordar",
    "descordámos": "descordar",
    "descordáramo": "descordar",
    "descordáramos": "descordar",
    "descordárei": "descordar",
    "descordáreis": "descordar",
    "descordásseis": "descordar",
    "descordássemos": "descordar",
    "descordávamo": "descordar",
    "descordávamos": "descordar",
    "descordávei": "descordar",
    "descordáveis": "descordar",
    "descore": "descorar",
    "descorei": "descorar",
    "descoreis": "descorar",
    "descorem": "descorar",
    "descoremo": "descorar",
    "descoremos": "descorar",
    "descores": "descorar",
    "descorna": "descornar",
    "descornada": "descornar",
    "descornadas": "descornar",
    "descornado": "descornar",
    "descornados": "descornar",
    "descornai": "descornar",
    "descornais": "descornar",
    "descornam": "descornar",
    "descornamo": "descornar",
    "descornamos": "descornar",
    "descornando": "descornar",
    "descornara": "descornar",
    "descornaram": "descornar",
    "descornaras": "descornar",
    "descornarde": "descornar",
    "descornardes": "descornar",
    "descornare": "descornar",
    "descornarei": "descornar",
    "descornareis": "descornar",
    "descornarem": "descornar",
    "descornaremos": "descornar",
    "descornares": "descornar",
    "descornaria": "descornar",
    "descornariam": "descornar",
    "descornarias": "descornar",
    "descornarmo": "descornar",
    "descornarmos": "descornar",
    "descornará": "descornar",
    "descornarás": "descornar",
    "descornarão": "descornar",
    "descornaríamos": "descornar",
    "descornaríeis": "descornar",
    "descornas": "descornar",
    "descornasse": "descornar",
    "descornassem": "descornar",
    "descornasses": "descornar",
    "descornaste": "descornar",
    "descornastes": "descornar",
    "descornava": "descornar",
    "descornavam": "descornar",
    "descornavas": "descornar",
    "descorne": "descornar",
    "descornei": "descornar",
    "descorneis": "descornar",
    "descornem": "descornar",
    "descornemo": "descornar",
    "descornemos": "descornar",
    "descornes": "descornar",
    "descorno": "descornar",
    "descornou": "descornar",
    "descorná": "descornar",
    "descornámo": "descornar",
    "descornámos": "descornar",
    "descornáramo": "descornar",
    "descornáramos": "descornar",
    "descornárei": "descornar",
    "descornáreis": "descornar",
    "descornásseis": "descornar",
    "descornássemos": "descornar",
    "descornávamo": "descornar",
    "descornávamos": "descornar",
    "descornávei": "descornar",
    "descornáveis": "descornar",
    "descoro": "descorar",
    "descoroa": "descoroar",
    "descoroada": "descoroar",
    "descoroadas": "descoroar",
    "descoroado": "descoroar",
    "descoroados": "descoroar",
    "descoroai": "descoroar",
    "descoroais": "descoroar",
    "descoroam": "descoroar",
    "descoroamo": "descoroar",
    "descoroamos": "descoroar",
    "descoroando": "descoroar",
    "descoroara": "descoroar",
    "descoroaram": "descoroar",
    "descoroaras": "descoroar",
    "descoroarde": "descoroar",
    "descoroardes": "descoroar",
    "descoroare": "descoroar",
    "descoroarei": "descoroar",
    "descoroareis": "descoroar",
    "descoroarem": "descoroar",
    "descoroaremos": "descoroar",
    "descoroares": "descoroar",
    "descoroaria": "descoroar",
    "descoroariam": "descoroar",
    "descoroarias": "descoroar",
    "descoroarmo": "descoroar",
    "descoroarmos": "descoroar",
    "descoroará": "descoroar",
    "descoroarás": "descoroar",
    "descoroarão": "descoroar",
    "descoroaríamos": "descoroar",
    "descoroaríeis": "descoroar",
    "descoroas": "descoroar",
    "descoroasse": "descoroar",
    "descoroassem": "descoroar",
    "descoroasses": "descoroar",
    "descoroaste": "descoroar",
    "descoroastes": "descoroar",
    "descoroava": "descoroar",
    "descoroavam": "descoroar",
    "descoroavas": "descoroar",
    "descoroe": "descoroar",
    "descoroei": "descoroar",
    "descoroeis": "descoroar",
    "descoroem": "descoroar",
    "descoroemo": "descoroar",
    "descoroemos": "descoroar",
    "descoroes": "descoroar",
    "descorolada": "descorolado",
    "descoroladas": "descorolado",
    "descorolados": "descorolado",
    "descoroo": "descoroar",
    "descoroou": "descoroar",
    "descorou": "descorar",
    "descoroá": "descoroar",
    "descoroámo": "descoroar",
    "descoroámos": "descoroar",
    "descoroáramo": "descoroar",
    "descoroáramos": "descoroar",
    "descoroárei": "descoroar",
    "descoroáreis": "descoroar",
    "descoroásseis": "descoroar",
    "descoroássemos": "descoroar",
    "descoroávamo": "descoroar",
    "descoroávamos": "descoroar",
    "descoroávei": "descoroar",
    "descoroáveis": "descoroar",
    "descoroçoada": "descoroçoado",
    "descoroçoadas": "descoroçoado",
    "descoroçoadora": "descoroçoador",
    "descoroçoadoras": "descoroçoador",
    "descoroçoadores": "descoroçoador",
    "descoroçoados": "descoroçoado",
    "descoroçoamentos": "descoroçoamento",
    "descoroçoantes": "descoroçoante",
    "descorrelaciona": "descorrelacionar",
    "descorrelacionada": "descorrelacionar",
    "descorrelacionadas": "descorrelacionar",
    "descorrelacionado": "descorrelacionar",
    "descorrelacionados": "descorrelacionar",
    "descorrelacionai": "descorrelacionar",
    "descorrelacionais": "descorrelacionar",
    "descorrelacionam": "descorrelacionar",
    "descorrelacionamo": "descorrelacionar",
    "descorrelacionamos": "descorrelacionar",
    "descorrelacionando": "descorrelacionar",
    "descorrelacionara": "descorrelacionar",
    "descorrelacionaram": "descorrelacionar",
    "descorrelacionaras": "descorrelacionar",
    "descorrelacionarde": "descorrelacionar",
    "descorrelacionardes": "descorrelacionar",
    "descorrelacionare": "descorrelacionar",
    "descorrelacionarei": "descorrelacionar",
    "descorrelacionareis": "descorrelacionar",
    "descorrelacionarem": "descorrelacionar",
    "descorrelacionaremos": "descorrelacionar",
    "descorrelacionares": "descorrelacionar",
    "descorrelacionaria": "descorrelacionar",
    "descorrelacionariam": "descorrelacionar",
    "descorrelacionarias": "descorrelacionar",
    "descorrelacionarmo": "descorrelacionar",
    "descorrelacionarmos": "descorrelacionar",
    "descorrelacionará": "descorrelacionar",
    "descorrelacionarás": "descorrelacionar",
    "descorrelacionarão": "descorrelacionar",
    "descorrelacionaríamos": "descorrelacionar",
    "descorrelacionaríeis": "descorrelacionar",
    "descorrelacionas": "descorrelacionar",
    "descorrelacionasse": "descorrelacionar",
    "descorrelacionassem": "descorrelacionar",
    "descorrelacionasses": "descorrelacionar",
    "descorrelacionaste": "descorrelacionar",
    "descorrelacionastes": "descorrelacionar",
    "descorrelacionava": "descorrelacionar",
    "descorrelacionavam": "descorrelacionar",
    "descorrelacionavas": "descorrelacionar",
    "descorrelacione": "descorrelacionar",
    "descorrelacionei": "descorrelacionar",
    "descorrelacioneis": "descorrelacionar",
    "descorrelacionem": "descorrelacionar",
    "descorrelacionemo": "descorrelacionar",
    "descorrelacionemos": "descorrelacionar",
    "descorrelaciones": "descorrelacionar",
    "descorrelaciono": "descorrelacionar",
    "descorrelacionou": "descorrelacionar",
    "descorrelacioná": "descorrelacionar",
    "descorrelacionámo": "descorrelacionar",
    "descorrelacionámos": "descorrelacionar",
    "descorrelacionáramo": "descorrelacionar",
    "descorrelacionáramos": "descorrelacionar",
    "descorrelacionárei": "descorrelacionar",
    "descorrelacionáreis": "descorrelacionar",
    "descorrelacionásseis": "descorrelacionar",
    "descorrelacionássemos": "descorrelacionar",
    "descorrelacionávamo": "descorrelacionar",
    "descorrelacionávamos": "descorrelacionar",
    "descorrelacionávei": "descorrelacionar",
    "descorrelacionáveis": "descorrelacionar",
    "descorrelações": "descorrelação",
    "descorrenta": "descorrentar",
    "descorrentada": "descorrentar",
    "descorrentadas": "descorrentar",
    "descorrentado": "descorrentar",
    "descorrentados": "descorrentar",
    "descorrentai": "descorrentar",
    "descorrentais": "descorrentar",
    "descorrentam": "descorrentar",
    "descorrentamo": "descorrentar",
    "descorrentamos": "descorrentar",
    "descorrentando": "descorrentar",
    "descorrentara": "descorrentar",
    "descorrentaram": "descorrentar",
    "descorrentaras": "descorrentar",
    "descorrentarde": "descorrentar",
    "descorrentardes": "descorrentar",
    "descorrentare": "descorrentar",
    "descorrentarei": "descorrentar",
    "descorrentareis": "descorrentar",
    "descorrentarem": "descorrentar",
    "descorrentaremos": "descorrentar",
    "descorrentares": "descorrentar",
    "descorrentaria": "descorrentar",
    "descorrentariam": "descorrentar",
    "descorrentarias": "descorrentar",
    "descorrentarmo": "descorrentar",
    "descorrentarmos": "descorrentar",
    "descorrentará": "descorrentar",
    "descorrentarás": "descorrentar",
    "descorrentarão": "descorrentar",
    "descorrentaríamos": "descorrentar",
    "descorrentaríeis": "descorrentar",
    "descorrentas": "descorrentar",
    "descorrentasse": "descorrentar",
    "descorrentassem": "descorrentar",
    "descorrentasses": "descorrentar",
    "descorrentaste": "descorrentar",
    "descorrentastes": "descorrentar",
    "descorrentava": "descorrentar",
    "descorrentavam": "descorrentar",
    "descorrentavas": "descorrentar",
    "descorrente": "descorrentar",
    "descorrentei": "descorrentar",
    "descorrenteis": "descorrentar",
    "descorrentem": "descorrentar",
    "descorrentemo": "descorrentar",
    "descorrentemos": "descorrentar",
    "descorrentes": "descorrentar",
    "descorrento": "descorrentar",
    "descorrentou": "descorrentar",
    "descorrentá": "descorrentar",
    "descorrentámo": "descorrentar",
    "descorrentámos": "descorrentar",
    "descorrentáramo": "descorrentar",
    "descorrentáramos": "descorrentar",
    "descorrentárei": "descorrentar",
    "descorrentáreis": "descorrentar",
    "descorrentásseis": "descorrentar",
    "descorrentássemos": "descorrentar",
    "descorrentávamo": "descorrentar",
    "descorrentávamos": "descorrentar",
    "descorrentávei": "descorrentar",
    "descorrentáveis": "descorrentar",
    "descorteja": "descortejar",
    "descortejada": "descortejar",
    "descortejadas": "descortejar",
    "descortejado": "descortejar",
    "descortejados": "descortejar",
    "descortejai": "descortejar",
    "descortejais": "descortejar",
    "descortejam": "descortejar",
    "descortejamo": "descortejar",
    "descortejamos": "descortejar",
    "descortejando": "descortejar",
    "descortejara": "descortejar",
    "descortejaram": "descortejar",
    "descortejaras": "descortejar",
    "descortejarde": "descortejar",
    "descortejardes": "descortejar",
    "descortejare": "descortejar",
    "descortejarei": "descortejar",
    "descortejareis": "descortejar",
    "descortejarem": "descortejar",
    "descortejaremos": "descortejar",
    "descortejares": "descortejar",
    "descortejaria": "descortejar",
    "descortejariam": "descortejar",
    "descortejarias": "descortejar",
    "descortejarmo": "descortejar",
    "descortejarmos": "descortejar",
    "descortejará": "descortejar",
    "descortejarás": "descortejar",
    "descortejarão": "descortejar",
    "descortejaríamos": "descortejar",
    "descortejaríeis": "descortejar",
    "descortejas": "descortejar",
    "descortejasse": "descortejar",
    "descortejassem": "descortejar",
    "descortejasses": "descortejar",
    "descortejaste": "descortejar",
    "descortejastes": "descortejar",
    "descortejava": "descortejar",
    "descortejavam": "descortejar",
    "descortejavas": "descortejar",
    "descorteje": "descortejar",
    "descortejei": "descortejar",
    "descortejeis": "descortejar",
    "descortejem": "descortejar",
    "descortejemo": "descortejar",
    "descortejemos": "descortejar",
    "descortejes": "descortejar",
    "descortejo": "descortejar",
    "descortejou": "descortejar",
    "descortejá": "descortejar",
    "descortejámo": "descortejar",
    "descortejámos": "descortejar",
    "descortejáramo": "descortejar",
    "descortejáramos": "descortejar",
    "descortejárei": "descortejar",
    "descortejáreis": "descortejar",
    "descortejásseis": "descortejar",
    "descortejássemos": "descortejar",
    "descortejávamo": "descortejar",
    "descortejávamos": "descortejar",
    "descortejávei": "descortejar",
    "descortejáveis": "descortejar",
    "descorteses": "descortês",
    "descortesias": "descortesia",
    "descortica": "descorticar",
    "descorticada": "descorticar",
    "descorticadas": "descorticar",
    "descorticado": "descorticar",
    "descorticadora": "descorticador",
    "descorticadoras": "descorticador",
    "descorticadores": "descorticador",
    "descorticados": "descorticar",
    "descorticai": "descorticar",
    "descorticais": "descorticar",
    "descorticam": "descorticar",
    "descorticamo": "descorticar",
    "descorticamos": "descorticar",
    "descorticando": "descorticar",
    "descorticara": "descorticar",
    "descorticaram": "descorticar",
    "descorticaras": "descorticar",
    "descorticarde": "descorticar",
    "descorticardes": "descorticar",
    "descorticare": "descorticar",
    "descorticarei": "descorticar",
    "descorticareis": "descorticar",
    "descorticarem": "descorticar",
    "descorticaremos": "descorticar",
    "descorticares": "descorticar",
    "descorticaria": "descorticar",
    "descorticariam": "descorticar",
    "descorticarias": "descorticar",
    "descorticarmo": "descorticar",
    "descorticarmos": "descorticar",
    "descorticará": "descorticar",
    "descorticarás": "descorticar",
    "descorticarão": "descorticar",
    "descorticaríamos": "descorticar",
    "descorticaríeis": "descorticar",
    "descorticas": "descorticar",
    "descorticasse": "descorticar",
    "descorticassem": "descorticar",
    "descorticasses": "descorticar",
    "descorticaste": "descorticar",
    "descorticastes": "descorticar",
    "descorticava": "descorticar",
    "descorticavam": "descorticar",
    "descorticavas": "descorticar",
    "descorticações": "descorticação",
    "descortice": "descortiçar",
    "descorticei": "descortiçar",
    "descorticeis": "descortiçar",
    "descorticem": "descortiçar",
    "descorticemo": "descortiçar",
    "descorticemos": "descortiçar",
    "descortices": "descortiçar",
    "descortico": "descorticar",
    "descorticou": "descorticar",
    "descorticá": "descorticar",
    "descorticámo": "descorticar",
    "descorticámos": "descorticar",
    "descorticáramo": "descorticar",
    "descorticáramos": "descorticar",
    "descorticárei": "descorticar",
    "descorticáreis": "descorticar",
    "descorticásseis": "descorticar",
    "descorticássemos": "descorticar",
    "descorticávamo": "descorticar",
    "descorticávamos": "descorticar",
    "descorticávei": "descorticar",
    "descorticáveis": "descorticar",
    "descortina": "descortinar",
    "descortinada": "descortinar",
    "descortinadas": "descortinar",
    "descortinado": "descortinar",
    "descortinados": "descortinar",
    "descortinai": "descortinar",
    "descortinais": "descortinar",
    "descortinam": "descortinar",
    "descortinamo": "descortinar",
    "descortinamos": "descortinar",
    "descortinando": "descortinar",
    "descortinara": "descortinar",
    "descortinaram": "descortinar",
    "descortinaras": "descortinar",
    "descortinarde": "descortinar",
    "descortinardes": "descortinar",
    "descortinare": "descortinar",
    "descortinarei": "descortinar",
    "descortinareis": "descortinar",
    "descortinarem": "descortinar",
    "descortinaremos": "descortinar",
    "descortinares": "descortinar",
    "descortinaria": "descortinar",
    "descortinariam": "descortinar",
    "descortinarias": "descortinar",
    "descortinarmo": "descortinar",
    "descortinarmos": "descortinar",
    "descortinará": "descortinar",
    "descortinarás": "descortinar",
    "descortinarão": "descortinar",
    "descortinaríamos": "descortinar",
    "descortinaríeis": "descortinar",
    "descortinas": "descortinar",
    "descortinasse": "descortinar",
    "descortinassem": "descortinar",
    "descortinasses": "descortinar",
    "descortinaste": "descortinar",
    "descortinastes": "descortinar",
    "descortinava": "descortinar",
    "descortinavam": "descortinar",
    "descortinavas": "descortinar",
    "descortine": "descortinar",
    "descortinei": "descortinar",
    "descortineis": "descortinar",
    "descortinem": "descortinar",
    "descortinemo": "descortinar",
    "descortinemos": "descortinar",
    "descortines": "descortinar",
    "descortino": "descortinar",
    "descortinou": "descortinar",
    "descortiná": "descortinar",
    "descortinámo": "descortinar",
    "descortinámos": "descortinar",
    "descortináramo": "descortinar",
    "descortináramos": "descortinar",
    "descortinárei": "descortinar",
    "descortináreis": "descortinar",
    "descortinásseis": "descortinar",
    "descortinássemos": "descortinar",
    "descortinávamo": "descortinar",
    "descortinávamos": "descortinar",
    "descortinávei": "descortinar",
    "descortináveis": "descortinável",
    "descortique": "descorticar",
    "descortiquei": "descorticar",
    "descortiqueis": "descorticar",
    "descortiquem": "descorticar",
    "descortiquemo": "descorticar",
    "descortiquemos": "descorticar",
    "descortiques": "descorticar",
    "descortiça": "descortiçar",
    "descortiçada": "descortiçar",
    "descortiçadas": "descortiçar",
    "descortiçado": "descortiçar",
    "descortiçados": "descortiçar",
    "descortiçai": "descortiçar",
    "descortiçais": "descortiçar",
    "descortiçam": "descortiçar",
    "descortiçamentos": "descortiçamento",
    "descortiçamo": "descortiçar",
    "descortiçamos": "descortiçar",
    "descortiçando": "descortiçar",
    "descortiçara": "descortiçar",
    "descortiçaram": "descortiçar",
    "descortiçaras": "descortiçar",
    "descortiçarde": "descortiçar",
    "descortiçardes": "descortiçar",
    "descortiçare": "descortiçar",
    "descortiçarei": "descortiçar",
    "descortiçareis": "descortiçar",
    "descortiçarem": "descortiçar",
    "descortiçaremos": "descortiçar",
    "descortiçares": "descortiçar",
    "descortiçaria": "descortiçar",
    "descortiçariam": "descortiçar",
    "descortiçarias": "descortiçar",
    "descortiçarmo": "descortiçar",
    "descortiçarmos": "descortiçar",
    "descortiçará": "descortiçar",
    "descortiçarás": "descortiçar",
    "descortiçarão": "descortiçar",
    "descortiçaríamos": "descortiçar",
    "descortiçaríeis": "descortiçar",
    "descortiças": "descortiçar",
    "descortiçasse": "descortiçar",
    "descortiçassem": "descortiçar",
    "descortiçasses": "descortiçar",
    "descortiçaste": "descortiçar",
    "descortiçastes": "descortiçar",
    "descortiçava": "descortiçar",
    "descortiçavam": "descortiçar",
    "descortiçavas": "descortiçar",
    "descortiço": "descortiçar",
    "descortiçou": "descortiçar",
    "descortiçá": "descortiçar",
    "descortiçámo": "descortiçar",
    "descortiçámos": "descortiçar",
    "descortiçáramo": "descortiçar",
    "descortiçáramos": "descortiçar",
    "descortiçárei": "descortiçar",
    "descortiçáreis": "descortiçar",
    "descortiçásseis": "descortiçar",
    "descortiçássemos": "descortiçar",
    "descortiçávamo": "descortiçar",
    "descortiçávamos": "descortiçar",
    "descortiçávei": "descortiçar",
    "descortiçáveis": "descortiçar",
    "descorá": "descorar",
    "descorámo": "descorar",
    "descorámos": "descorar",
    "descoráramo": "descorar",
    "descoráramos": "descorar",
    "descorárei": "descorar",
    "descoráreis": "descorar",
    "descorásseis": "descorar",
    "descorássemos": "descorar",
    "descorávamo": "descorar",
    "descorávamos": "descorar",
    "descorávei": "descorar",
    "descoráveis": "descorar",
    "descorçoada": "descorçoado",
    "descorçoadas": "descorçoado",
    "descorçoados": "descorçoado",
    "descorçoamentos": "descorçoamento",
    "descosa": "descoser",
    "descosais": "descoser",
    "descosam": "descoser",
    "descosamo": "descoser",
    "descosamos": "descoser",
    "descosas": "descoser",
    "descose": "descoser",
    "descoseduras": "descosedura",
    "descosei": "descoser",
    "descoseis": "descoser",
    "descosem": "descoser",
    "descosemo": "descoser",
    "descosemos": "descoser",
    "descosendo": "descoser",
    "descosera": "descoser",
    "descoseram": "descoser",
    "descoseras": "descoser",
    "descoserde": "descoser",
    "descoserdes": "descoser",
    "descosere": "descoser",
    "descoserei": "descoser",
    "descosereis": "descoser",
    "descoserem": "descoser",
    "descoseremos": "descoser",
    "descoseres": "descoser",
    "descoseria": "descoser",
    "descoseriam": "descoser",
    "descoserias": "descoser",
    "descosermo": "descoser",
    "descosermos": "descoser",
    "descoserá": "descoser",
    "descoserás": "descoser",
    "descoserão": "descoser",
    "descoseríamos": "descoser",
    "descoseríeis": "descoser",
    "descoses": "descoser",
    "descosesse": "descoser",
    "descosessem": "descoser",
    "descosesses": "descoser",
    "descoseste": "descoser",
    "descosestes": "descoser",
    "descoseu": "descoser",
    "descosi": "descoser",
    "descosia": "descoser",
    "descosiam": "descoser",
    "descosias": "descoser",
    "descosida": "descosido",
    "descosidas": "descosido",
    "descosido": "descoser",
    "descosidos": "descosido",
    "descoso": "descoser",
    "descostuma": "descostumar",
    "descostumada": "descostumar",
    "descostumadas": "descostumar",
    "descostumado": "descostumar",
    "descostumados": "descostumar",
    "descostumai": "descostumar",
    "descostumais": "descostumar",
    "descostumam": "descostumar",
    "descostumamo": "descostumar",
    "descostumamos": "descostumar",
    "descostumando": "descostumar",
    "descostumara": "descostumar",
    "descostumaram": "descostumar",
    "descostumaras": "descostumar",
    "descostumarde": "descostumar",
    "descostumardes": "descostumar",
    "descostumare": "descostumar",
    "descostumarei": "descostumar",
    "descostumareis": "descostumar",
    "descostumarem": "descostumar",
    "descostumaremos": "descostumar",
    "descostumares": "descostumar",
    "descostumaria": "descostumar",
    "descostumariam": "descostumar",
    "descostumarias": "descostumar",
    "descostumarmo": "descostumar",
    "descostumarmos": "descostumar",
    "descostumará": "descostumar",
    "descostumarás": "descostumar",
    "descostumarão": "descostumar",
    "descostumaríamos": "descostumar",
    "descostumaríeis": "descostumar",
    "descostumas": "descostumar",
    "descostumasse": "descostumar",
    "descostumassem": "descostumar",
    "descostumasses": "descostumar",
    "descostumaste": "descostumar",
    "descostumastes": "descostumar",
    "descostumava": "descostumar",
    "descostumavam": "descostumar",
    "descostumavas": "descostumar",
    "descostume": "descostumar",
    "descostumei": "descostumar",
    "descostumeis": "descostumar",
    "descostumem": "descostumar",
    "descostumemo": "descostumar",
    "descostumemos": "descostumar",
    "descostumes": "descostume",
    "descostumo": "descostumar",
    "descostumou": "descostumar",
    "descostumá": "descostumar",
    "descostumámo": "descostumar",
    "descostumámos": "descostumar",
    "descostumáramo": "descostumar",
    "descostumáramos": "descostumar",
    "descostumárei": "descostumar",
    "descostumáreis": "descostumar",
    "descostumásseis": "descostumar",
    "descostumássemos": "descostumar",
    "descostumávamo": "descostumar",
    "descostumávamos": "descostumar",
    "descostumávei": "descostumar",
    "descostumáveis": "descostumar",
    "descosê": "descoser",
    "descosêramo": "descoser",
    "descosêramos": "descoser",
    "descosêrei": "descoser",
    "descosêreis": "descoser",
    "descosêsseis": "descoser",
    "descosêssemos": "descoser",
    "descosíamo": "descoser",
    "descosíamos": "descoser",
    "descosíei": "descoser",
    "descosíeis": "descoser",
    "descotada": "descotado",
    "descotadas": "descotado",
    "descotados": "descotado",
    "descotoa": "descotoar",
    "descotoada": "descotoar",
    "descotoadas": "descotoar",
    "descotoado": "descotoar",
    "descotoados": "descotoar",
    "descotoai": "descotoar",
    "descotoais": "descotoar",
    "descotoam": "descotoar",
    "descotoamo": "descotoar",
    "descotoamos": "descotoar",
    "descotoando": "descotoar",
    "descotoara": "descotoar",
    "descotoaram": "descotoar",
    "descotoaras": "descotoar",
    "descotoarde": "descotoar",
    "descotoardes": "descotoar",
    "descotoare": "descotoar",
    "descotoarei": "descotoar",
    "descotoareis": "descotoar",
    "descotoarem": "descotoar",
    "descotoaremos": "descotoar",
    "descotoares": "descotoar",
    "descotoaria": "descotoar",
    "descotoariam": "descotoar",
    "descotoarias": "descotoar",
    "descotoarmo": "descotoar",
    "descotoarmos": "descotoar",
    "descotoará": "descotoar",
    "descotoarás": "descotoar",
    "descotoarão": "descotoar",
    "descotoaríamos": "descotoar",
    "descotoaríeis": "descotoar",
    "descotoas": "descotoar",
    "descotoasse": "descotoar",
    "descotoassem": "descotoar",
    "descotoasses": "descotoar",
    "descotoaste": "descotoar",
    "descotoastes": "descotoar",
    "descotoava": "descotoar",
    "descotoavam": "descotoar",
    "descotoavas": "descotoar",
    "descotoe": "descotoar",
    "descotoei": "descotoar",
    "descotoeis": "descotoar",
    "descotoem": "descotoar",
    "descotoemo": "descotoar",
    "descotoemos": "descotoar",
    "descotoes": "descotoar",
    "descotoo": "descotoar",
    "descotoou": "descotoar",
    "descotoá": "descotoar",
    "descotoámo": "descotoar",
    "descotoámos": "descotoar",
    "descotoáramo": "descotoar",
    "descotoáramos": "descotoar",
    "descotoárei": "descotoar",
    "descotoáreis": "descotoar",
    "descotoásseis": "descotoar",
    "descotoássemos": "descotoar",
    "descotoávamo": "descotoar",
    "descotoávamos": "descotoar",
    "descotoávei": "descotoar",
    "descotoáveis": "descotoar",
    "descoube": "descaber",
    "descoubemo": "descaber",
    "descoubemos": "descaber",
    "descouber": "descaber",
    "descoubera": "descaber",
    "descouberam": "descaber",
    "descouberas": "descaber",
    "descouberdes": "descaber",
    "descouberem": "descaber",
    "descouberes": "descaber",
    "descoubermos": "descaber",
    "descoubesse": "descaber",
    "descoubessem": "descaber",
    "descoubesses": "descaber",
    "descoubeste": "descaber",
    "descoubestes": "descaber",
    "descoubéramo": "descaber",
    "descoubéramos": "descaber",
    "descoubéreis": "descaber",
    "descoubésseis": "descaber",
    "descoubéssemos": "descaber",
    "descouta": "descoutar",
    "descoutada": "descoutar",
    "descoutadas": "descoutar",
    "descoutado": "descoutar",
    "descoutados": "descoutar",
    "descoutai": "descoutar",
    "descoutais": "descoutar",
    "descoutam": "descoutar",
    "descoutamo": "descoutar",
    "descoutamos": "descoutar",
    "descoutando": "descoutar",
    "descoutara": "descoutar",
    "descoutaram": "descoutar",
    "descoutaras": "descoutar",
    "descoutarde": "descoutar",
    "descoutardes": "descoutar",
    "descoutare": "descoutar",
    "descoutarei": "descoutar",
    "descoutareis": "descoutar",
    "descoutarem": "descoutar",
    "descoutaremos": "descoutar",
    "descoutares": "descoutar",
    "descoutaria": "descoutar",
    "descoutariam": "descoutar",
    "descoutarias": "descoutar",
    "descoutarmo": "descoutar",
    "descoutarmos": "descoutar",
    "descoutará": "descoutar",
    "descoutarás": "descoutar",
    "descoutarão": "descoutar",
    "descoutaríamos": "descoutar",
    "descoutaríeis": "descoutar",
    "descoutas": "descoutar",
    "descoutasse": "descoutar",
    "descoutassem": "descoutar",
    "descoutasses": "descoutar",
    "descoutaste": "descoutar",
    "descoutastes": "descoutar",
    "descoutava": "descoutar",
    "descoutavam": "descoutar",
    "descoutavas": "descoutar",
    "descoute": "descoutar",
    "descoutei": "descoutar",
    "descouteis": "descoutar",
    "descoutem": "descoutar",
    "descoutemo": "descoutar",
    "descoutemos": "descoutar",
    "descoutes": "descoutar",
    "descouto": "descoutar",
    "descoutou": "descoutar",
    "descoutá": "descoutar",
    "descoutámo": "descoutar",
    "descoutámos": "descoutar",
    "descoutáramo": "descoutar",
    "descoutáramos": "descoutar",
    "descoutárei": "descoutar",
    "descoutáreis": "descoutar",
    "descoutásseis": "descoutar",
    "descoutássemos": "descoutar",
    "descoutávamo": "descoutar",
    "descoutávamos": "descoutar",
    "descoutávei": "descoutar",
    "descoutáveis": "descoutar",
    "descraseada": "descrasear",
    "descraseadas": "descrasear",
    "descraseado": "descrasear",
    "descraseados": "descrasear",
    "descraseai": "descrasear",
    "descraseais": "descrasear",
    "descraseamo": "descrasear",
    "descraseamos": "descrasear",
    "descraseando": "descrasear",
    "descraseara": "descrasear",
    "descrasearam": "descrasear",
    "descrasearas": "descrasear",
    "descrasearde": "descrasear",
    "descraseardes": "descrasear",
    "descraseare": "descrasear",
    "descrasearei": "descrasear",
    "descraseareis": "descrasear",
    "descrasearem": "descrasear",
    "descrasearemos": "descrasear",
    "descraseares": "descrasear",
    "descrasearia": "descrasear",
    "descraseariam": "descrasear",
    "descrasearias": "descrasear",
    "descrasearmo": "descrasear",
    "descrasearmos": "descrasear",
    "descraseará": "descrasear",
    "descrasearás": "descrasear",
    "descrasearão": "descrasear",
    "descrasearíamos": "descrasear",
    "descrasearíeis": "descrasear",
    "descraseasse": "descrasear",
    "descraseassem": "descrasear",
    "descraseasses": "descrasear",
    "descraseaste": "descrasear",
    "descraseastes": "descrasear",
    "descraseava": "descrasear",
    "descraseavam": "descrasear",
    "descraseavas": "descrasear",
    "descraseei": "descrasear",
    "descraseeis": "descrasear",
    "descraseemo": "descrasear",
    "descraseemos": "descrasear",
    "descraseia": "descrasear",
    "descraseiam": "descrasear",
    "descraseias": "descrasear",
    "descraseie": "descrasear",
    "descraseiem": "descrasear",
    "descraseies": "descrasear",
    "descraseio": "descrasear",
    "descraseou": "descrasear",
    "descraseá": "descrasear",
    "descraseámo": "descrasear",
    "descraseámos": "descrasear",
    "descraseáramo": "descrasear",
    "descraseáramos": "descrasear",
    "descraseárei": "descrasear",
    "descraseáreis": "descrasear",
    "descraseásseis": "descrasear",
    "descraseássemos": "descrasear",
    "descraseávamo": "descrasear",
    "descraseávamos": "descrasear",
    "descraseávei": "descrasear",
    "descraseáveis": "descrasear",
    "descrava": "descravar",
    "descravada": "descravar",
    "descravadas": "descravar",
    "descravado": "descravar",
    "descravados": "descravar",
    "descravai": "descravar",
    "descravais": "descravar",
    "descravam": "descravar",
    "descravamo": "descravar",
    "descravamos": "descravar",
    "descravando": "descravar",
    "descravara": "descravar",
    "descravaram": "descravar",
    "descravaras": "descravar",
    "descravarde": "descravar",
    "descravardes": "descravar",
    "descravare": "descravar",
    "descravarei": "descravar",
    "descravareis": "descravar",
    "descravarem": "descravar",
    "descravaremos": "descravar",
    "descravares": "descravar",
    "descravaria": "descravar",
    "descravariam": "descravar",
    "descravarias": "descravar",
    "descravarmo": "descravar",
    "descravarmos": "descravar",
    "descravará": "descravar",
    "descravarás": "descravar",
    "descravarão": "descravar",
    "descravaríamos": "descravar",
    "descravaríeis": "descravar",
    "descravas": "descravar",
    "descravasse": "descravar",
    "descravassem": "descravar",
    "descravasses": "descravar",
    "descravaste": "descravar",
    "descravastes": "descravar",
    "descravava": "descravar",
    "descravavam": "descravar",
    "descravavas": "descravar",
    "descrave": "descravar",
    "descravei": "descravar",
    "descraveis": "descravar",
    "descraveja": "descravejar",
    "descravejada": "descravejar",
    "descravejadas": "descravejar",
    "descravejado": "descravejar",
    "descravejados": "descravejar",
    "descravejai": "descravejar",
    "descravejais": "descravejar",
    "descravejam": "descravejar",
    "descravejamo": "descravejar",
    "descravejamos": "descravejar",
    "descravejando": "descravejar",
    "descravejara": "descravejar",
    "descravejaram": "descravejar",
    "descravejaras": "descravejar",
    "descravejarde": "descravejar",
    "descravejardes": "descravejar",
    "descravejare": "descravejar",
    "descravejarei": "descravejar",
    "descravejareis": "descravejar",
    "descravejarem": "descravejar",
    "descravejaremos": "descravejar",
    "descravejares": "descravejar",
    "descravejaria": "descravejar",
    "descravejariam": "descravejar",
    "descravejarias": "descravejar",
    "descravejarmo": "descravejar",
    "descravejarmos": "descravejar",
    "descravejará": "descravejar",
    "descravejarás": "descravejar",
    "descravejarão": "descravejar",
    "descravejaríamos": "descravejar",
    "descravejaríeis": "descravejar",
    "descravejas": "descravejar",
    "descravejasse": "descravejar",
    "descravejassem": "descravejar",
    "descravejasses": "descravejar",
    "descravejaste": "descravejar",
    "descravejastes": "descravejar",
    "descravejava": "descravejar",
    "descravejavam": "descravejar",
    "descravejavas": "descravejar",
    "descraveje": "descravejar",
    "descravejei": "descravejar",
    "descravejeis": "descravejar",
    "descravejem": "descravejar",
    "descravejemo": "descravejar",
    "descravejemos": "descravejar",
    "descravejes": "descravejar",
    "descravejo": "descravejar",
    "descravejou": "descravejar",
    "descravejá": "descravejar",
    "descravejámo": "descravejar",
    "descravejámos": "descravejar",
    "descravejáramo": "descravejar",
    "descravejáramos": "descravejar",
    "descravejárei": "descravejar",
    "descravejáreis": "descravejar",
    "descravejásseis": "descravejar",
    "descravejássemos": "descravejar",
    "descravejávamo": "descravejar",
    "descravejávamos": "descravejar",
    "descravejávei": "descravejar",
    "descravejáveis": "descravejar",
    "descravem": "descravar",
    "descravemo": "descravar",
    "descravemos": "descravar",
    "descraves": "descravar",
    "descraviza": "descravizar",
    "descravizada": "descravizar",
    "descravizadas": "descravizar",
    "descravizado": "descravizar",
    "descravizados": "descravizar",
    "descravizai": "descravizar",
    "descravizais": "descravizar",
    "descravizam": "descravizar",
    "descravizamo": "descravizar",
    "descravizamos": "descravizar",
    "descravizando": "descravizar",
    "descravizara": "descravizar",
    "descravizaram": "descravizar",
    "descravizaras": "descravizar",
    "descravizarde": "descravizar",
    "descravizardes": "descravizar",
    "descravizare": "descravizar",
    "descravizarei": "descravizar",
    "descravizareis": "descravizar",
    "descravizarem": "descravizar",
    "descravizaremos": "descravizar",
    "descravizares": "descravizar",
    "descravizaria": "descravizar",
    "descravizariam": "descravizar",
    "descravizarias": "descravizar",
    "descravizarmo": "descravizar",
    "descravizarmos": "descravizar",
    "descravizará": "descravizar",
    "descravizarás": "descravizar",
    "descravizarão": "descravizar",
    "descravizaríamos": "descravizar",
    "descravizaríeis": "descravizar",
    "descravizas": "descravizar",
    "descravizasse": "descravizar",
    "descravizassem": "descravizar",
    "descravizasses": "descravizar",
    "descravizaste": "descravizar",
    "descravizastes": "descravizar",
    "descravizava": "descravizar",
    "descravizavam": "descravizar",
    "descravizavas": "descravizar",
    "descravize": "descravizar",
    "descravizei": "descravizar",
    "descravizeis": "descravizar",
    "descravizem": "descravizar",
    "descravizemo": "descravizar",
    "descravizemos": "descravizar",
    "descravizes": "descravizar",
    "descravizo": "descravizar",
    "descravizou": "descravizar",
    "descravizá": "descravizar",
    "descravizámo": "descravizar",
    "descravizámos": "descravizar",
    "descravizáramo": "descravizar",
    "descravizáramos": "descravizar",
    "descravizárei": "descravizar",
    "descravizáreis": "descravizar",
    "descravizásseis": "descravizar",
    "descravizássemos": "descravizar",
    "descravizávamo": "descravizar",
    "descravizávamos": "descravizar",
    "descravizávei": "descravizar",
    "descravizáveis": "descravizar",
    "descravo": "descravar",
    "descravou": "descravar",
    "descravá": "descravar",
    "descravámo": "descravar",
    "descravámos": "descravar",
    "descraváramo": "descravar",
    "descraváramos": "descravar",
    "descravárei": "descravar",
    "descraváreis": "descravar",
    "descravásseis": "descravar",
    "descravássemos": "descravar",
    "descravávamo": "descravar",
    "descravávamos": "descravar",
    "descravávei": "descravar",
    "descraváveis": "descravar",
    "descreais": "descrer",
    "descreamo": "descrer",
    "descreamos": "descrer",
    "descrede": "descrer",
    "descredenciamentos": "descredenciamento",
    "descredes": "descrer",
    "descreia": "descrer",
    "descreiam": "descrer",
    "descreias": "descrer",
    "descreio": "descrer",
    "descremações": "descremação",
    "descremo": "descrer",
    "descremos": "descrer",
    "descrendo": "descrer",
    "descrentes": "descrente",
    "descrenças": "descrença",
    "descrera": "descrer",
    "descreram": "descrer",
    "descreras": "descrer",
    "descrerde": "descrer",
    "descrerdes": "descrer",
    "descrere": "descrer",
    "descrerei": "descrer",
    "descrereis": "descrer",
    "descrerem": "descrer",
    "descreremos": "descrer",
    "descreres": "descrer",
    "descreria": "descrer",
    "descreriam": "descrer",
    "descrerias": "descrer",
    "descrermo": "descrer",
    "descrermos": "descrer",
    "descrerá": "descrer",
    "descrerás": "descrer",
    "descrerão": "descrer",
    "descreríamos": "descrer",
    "descreríeis": "descrer",
    "descresse": "descrer",
    "descressem": "descrer",
    "descresses": "descrer",
    "descreste": "descrer",
    "descrestes": "descrer",
    "descreu": "descrer",
    "descreva": "descrever",
    "descrevais": "descrever",
    "descrevam": "descrever",
    "descrevamo": "descrever",
    "descrevamos": "descrever",
    "descrevas": "descrever",
    "descreve": "descrever",
    "descrevei": "descrever",
    "descreveis": "descrever",
    "descrevem": "descrever",
    "descrevemo": "descrever",
    "descrevemos": "descrever",
    "descrevendo": "descrever",
    "descrevera": "descrever",
    "descreveram": "descrever",
    "descreveras": "descrever",
    "descreverde": "descrever",
    "descreverdes": "descrever",
    "descrevere": "descrever",
    "descreverei": "descrever",
    "descrevereis": "descrever",
    "descreverem": "descrever",
    "descreveremos": "descrever",
    "descreveres": "descrever",
    "descreveria": "descrever",
    "descreveriam": "descrever",
    "descreverias": "descrever",
    "descrevermo": "descrever",
    "descrevermos": "descrever",
    "descreverá": "descrever",
    "descreverás": "descrever",
    "descreverão": "descrever",
    "descreveríamos": "descrever",
    "descreveríeis": "descrever",
    "descreves": "descrever",
    "descrevesse": "descrever",
    "descrevessem": "descrever",
    "descrevesses": "descrever",
    "descreveste": "descrever",
    "descrevestes": "descrever",
    "descreveu": "descrever",
    "descrevi": "descrever",
    "descrevia": "descrever",
    "descreviam": "descrever",
    "descrevias": "descrever",
    "descrevo": "descrever",
    "descrevê": "descrever",
    "descrevêramo": "descrever",
    "descrevêramos": "descrever",
    "descrevêrei": "descrever",
    "descrevêreis": "descrever",
    "descrevêsseis": "descrever",
    "descrevêssemos": "descrever",
    "descrevíamo": "descrever",
    "descrevíamos": "descrever",
    "descrevíei": "descrever",
    "descrevíeis": "descrever",
    "descri": "descrer",
    "descria": "descrer",
    "descriada": "descriado",
    "descriadas": "descriado",
    "descriados": "descriado",
    "descriam": "descrer",
    "descrias": "descrer",
    "descrida": "descrido",
    "descridas": "descrido",
    "descrido": "descrer",
    "descridos": "descrido",
    "descrimina": "descriminar",
    "descriminada": "descriminar",
    "descriminadas": "descriminar",
    "descriminado": "descriminar",
    "descriminados": "descriminar",
    "descriminai": "descriminar",
    "descriminais": "descriminar",
    "descriminam": "descriminar",
    "descriminamo": "descriminar",
    "descriminamos": "descriminar",
    "descriminando": "descriminar",
    "descriminara": "descriminar",
    "descriminaram": "descriminar",
    "descriminaras": "descriminar",
    "descriminarde": "descriminar",
    "descriminardes": "descriminar",
    "descriminare": "descriminar",
    "descriminarei": "descriminar",
    "descriminareis": "descriminar",
    "descriminarem": "descriminar",
    "descriminaremos": "descriminar",
    "descriminares": "descriminar",
    "descriminaria": "descriminar",
    "descriminariam": "descriminar",
    "descriminarias": "descriminar",
    "descriminarmo": "descriminar",
    "descriminarmos": "descriminar",
    "descriminará": "descriminar",
    "descriminarás": "descriminar",
    "descriminarão": "descriminar",
    "descriminaríamos": "descriminar",
    "descriminaríeis": "descriminar",
    "descriminas": "descriminar",
    "descriminasse": "descriminar",
    "descriminassem": "descriminar",
    "descriminasses": "descriminar",
    "descriminaste": "descriminar",
    "descriminastes": "descriminar",
    "descriminava": "descriminar",
    "descriminavam": "descriminar",
    "descriminavas": "descriminar",
    "descriminações": "descriminação",
    "descrimine": "descriminar",
    "descriminei": "descriminar",
    "descrimineis": "descriminar",
    "descriminem": "descriminar",
    "descriminemo": "descriminar",
    "descriminemos": "descriminar",
    "descrimines": "descriminar",
    "descrimino": "descriminar",
    "descriminou": "descriminar",
    "descriminá": "descriminar",
    "descriminámo": "descriminar",
    "descriminámos": "descriminar",
    "descrimináramo": "descriminar",
    "descrimináramos": "descriminar",
    "descriminárei": "descriminar",
    "descrimináreis": "descriminar",
    "descriminásseis": "descriminar",
    "descriminássemos": "descriminar",
    "descriminávamo": "descriminar",
    "descriminávamos": "descriminar",
    "descriminávei": "descriminar",
    "descrimináveis": "descriminar",
    "descristianiza": "descristianizar",
    "descristianizada": "descristianizar",
    "descristianizadas": "descristianizar",
    "descristianizado": "descristianizar",
    "descristianizados": "descristianizar",
    "descristianizai": "descristianizar",
    "descristianizais": "descristianizar",
    "descristianizam": "descristianizar",
    "descristianizamo": "descristianizar",
    "descristianizamos": "descristianizar",
    "descristianizando": "descristianizar",
    "descristianizara": "descristianizar",
    "descristianizaram": "descristianizar",
    "descristianizaras": "descristianizar",
    "descristianizarde": "descristianizar",
    "descristianizardes": "descristianizar",
    "descristianizare": "descristianizar",
    "descristianizarei": "descristianizar",
    "descristianizareis": "descristianizar",
    "descristianizarem": "descristianizar",
    "descristianizaremos": "descristianizar",
    "descristianizares": "descristianizar",
    "descristianizaria": "descristianizar",
    "descristianizariam": "descristianizar",
    "descristianizarias": "descristianizar",
    "descristianizarmo": "descristianizar",
    "descristianizarmos": "descristianizar",
    "descristianizará": "descristianizar",
    "descristianizarás": "descristianizar",
    "descristianizarão": "descristianizar",
    "descristianizaríamos": "descristianizar",
    "descristianizaríeis": "descristianizar",
    "descristianizas": "descristianizar",
    "descristianizasse": "descristianizar",
    "descristianizassem": "descristianizar",
    "descristianizasses": "descristianizar",
    "descristianizaste": "descristianizar",
    "descristianizastes": "descristianizar",
    "descristianizava": "descristianizar",
    "descristianizavam": "descristianizar",
    "descristianizavas": "descristianizar",
    "descristianizações": "descristianização",
    "descristianize": "descristianizar",
    "descristianizei": "descristianizar",
    "descristianizeis": "descristianizar",
    "descristianizem": "descristianizar",
    "descristianizemo": "descristianizar",
    "descristianizemos": "descristianizar",
    "descristianizes": "descristianizar",
    "descristianizo": "descristianizar",
    "descristianizou": "descristianizar",
    "descristianizá": "descristianizar",
    "descristianizámo": "descristianizar",
    "descristianizámos": "descristianizar",
    "descristianizáramo": "descristianizar",
    "descristianizáramos": "descristianizar",
    "descristianizárei": "descristianizar",
    "descristianizáreis": "descristianizar",
    "descristianizásseis": "descristianizar",
    "descristianizássemos": "descristianizar",
    "descristianizávamo": "descristianizar",
    "descristianizávamos": "descristianizar",
    "descristianizávei": "descristianizar",
    "descristianizáveis": "descristianizar",
    "descrita": "descrito",
    "descritas": "descrito",
    "descritiva": "descritivo",
    "descritivas": "descritivo",
    "descritivos": "descritivo",
    "descrito": "descrever",
    "descritora": "descritor",
    "descritoras": "descritor",
    "descritores": "descritor",
    "descritos": "descrito",
    "descritíveis": "descritível",
    "descrições": "descrição",
    "descruza": "descruzar",
    "descruzada": "descruzar",
    "descruzadas": "descruzar",
    "descruzado": "descruzar",
    "descruzados": "descruzar",
    "descruzai": "descruzar",
    "descruzais": "descruzar",
    "descruzam": "descruzar",
    "descruzamentos": "descruzamento",
    "descruzamo": "descruzar",
    "descruzamos": "descruzar",
    "descruzando": "descruzar",
    "descruzara": "descruzar",
    "descruzaram": "descruzar",
    "descruzaras": "descruzar",
    "descruzarde": "descruzar",
    "descruzardes": "descruzar",
    "descruzare": "descruzar",
    "descruzarei": "descruzar",
    "descruzareis": "descruzar",
    "descruzarem": "descruzar",
    "descruzaremos": "descruzar",
    "descruzares": "descruzar",
    "descruzaria": "descruzar",
    "descruzariam": "descruzar",
    "descruzarias": "descruzar",
    "descruzarmo": "descruzar",
    "descruzarmos": "descruzar",
    "descruzará": "descruzar",
    "descruzarás": "descruzar",
    "descruzarão": "descruzar",
    "descruzaríamos": "descruzar",
    "descruzaríeis": "descruzar",
    "descruzas": "descruzar",
    "descruzasse": "descruzar",
    "descruzassem": "descruzar",
    "descruzasses": "descruzar",
    "descruzaste": "descruzar",
    "descruzastes": "descruzar",
    "descruzava": "descruzar",
    "descruzavam": "descruzar",
    "descruzavas": "descruzar",
    "descruze": "descruzar",
    "descruzei": "descruzar",
    "descruzeis": "descruzar",
    "descruzem": "descruzar",
    "descruzemo": "descruzar",
    "descruzemos": "descruzar",
    "descruzes": "descruzar",
    "descruzo": "descruzar",
    "descruzou": "descruzar",
    "descruzá": "descruzar",
    "descruzámo": "descruzar",
    "descruzámos": "descruzar",
    "descruzáramo": "descruzar",
    "descruzáramos": "descruzar",
    "descruzárei": "descruzar",
    "descruzáreis": "descruzar",
    "descruzásseis": "descruzar",
    "descruzássemos": "descruzar",
    "descruzávamo": "descruzar",
    "descruzávamos": "descruzar",
    "descruzávei": "descruzar",
    "descruzáveis": "descruzável",
    "descréditos": "descrédito",
    "descrê": "descrer",
    "descrêem": "descrer",
    "descrêramo": "descrer",
    "descrêramos": "descrer",
    "descrêrei": "descrer",
    "descrêreis": "descrer",
    "descrês": "descrer",
    "descrêsseis": "descrer",
    "descrêssemos": "descrer",
    "descríamo": "descrer",
    "descríamos": "descrer",
    "descríei": "descrer",
    "descríeis": "descrer",
    "descubra": "descobrir",
    "descubrais": "descobrir",
    "descubram": "descobrir",
    "descubramo": "descobrir",
    "descubramos": "descobrir",
    "descubras": "descobrir",
    "descubro": "descobrir",
    "descuida": "descuidar",
    "descuidada": "descuidar",
    "descuidadas": "descuidar",
    "descuidado": "descuidar",
    "descuidados": "descuidar",
    "descuidadosa": "descuidadoso",
    "descuidadosas": "descuidadoso",
    "descuidadosos": "descuidadoso",
    "descuidadíssima": "descuidado",
    "descuidadíssimas": "descuidado",
    "descuidadíssimo": "descuidado",
    "descuidadíssimos": "descuidado",
    "descuidai": "descuidar",
    "descuidais": "descuidar",
    "descuidam": "descuidar",
    "descuidamo": "descuidar",
    "descuidamos": "descuidar",
    "descuidando": "descuidar",
    "descuidara": "descuidar",
    "descuidaram": "descuidar",
    "descuidaras": "descuidar",
    "descuidarde": "descuidar",
    "descuidardes": "descuidar",
    "descuidare": "descuidar",
    "descuidarei": "descuidar",
    "descuidareis": "descuidar",
    "descuidarem": "descuidar",
    "descuidaremos": "descuidar",
    "descuidares": "descuidar",
    "descuidaria": "descuidar",
    "descuidariam": "descuidar",
    "descuidarias": "descuidar",
    "descuidarmo": "descuidar",
    "descuidarmos": "descuidar",
    "descuidará": "descuidar",
    "descuidarás": "descuidar",
    "descuidarão": "descuidar",
    "descuidaríamos": "descuidar",
    "descuidaríeis": "descuidar",
    "descuidas": "descuidar",
    "descuidasse": "descuidar",
    "descuidassem": "descuidar",
    "descuidasses": "descuidar",
    "descuidaste": "descuidar",
    "descuidastes": "descuidar",
    "descuidava": "descuidar",
    "descuidavam": "descuidar",
    "descuidavas": "descuidar",
    "descuide": "descuidar",
    "descuidei": "descuidar",
    "descuideis": "descuidar",
    "descuidem": "descuidar",
    "descuidemo": "descuidar",
    "descuidemos": "descuidar",
    "descuides": "descuidar",
    "descuido": "descuidar",
    "descuidos": "descuido",
    "descuidosa": "descuidoso",
    "descuidosas": "descuidoso",
    "descuidosos": "descuidoso",
    "descuidou": "descuidar",
    "descuidá": "descuidar",
    "descuidámo": "descuidar",
    "descuidámos": "descuidar",
    "descuidáramo": "descuidar",
    "descuidáramos": "descuidar",
    "descuidárei": "descuidar",
    "descuidáreis": "descuidar",
    "descuidásseis": "descuidar",
    "descuidássemos": "descuidar",
    "descuidávamo": "descuidar",
    "descuidávamos": "descuidar",
    "descuidávei": "descuidar",
    "descuidáveis": "descuidar",
    "desculpa": "desculpar",
    "desculpabiliza": "desculpabilizar",
    "desculpabilizada": "desculpabilizar",
    "desculpabilizadas": "desculpabilizar",
    "desculpabilizado": "desculpabilizar",
    "desculpabilizados": "desculpabilizar",
    "desculpabilizai": "desculpabilizar",
    "desculpabilizais": "desculpabilizar",
    "desculpabilizam": "desculpabilizar",
    "desculpabilizamo": "desculpabilizar",
    "desculpabilizamos": "desculpabilizar",
    "desculpabilizando": "desculpabilizar",
    "desculpabilizantes": "desculpabilizante",
    "desculpabilizara": "desculpabilizar",
    "desculpabilizaram": "desculpabilizar",
    "desculpabilizaras": "desculpabilizar",
    "desculpabilizarde": "desculpabilizar",
    "desculpabilizardes": "desculpabilizar",
    "desculpabilizare": "desculpabilizar",
    "desculpabilizarei": "desculpabilizar",
    "desculpabilizareis": "desculpabilizar",
    "desculpabilizarem": "desculpabilizar",
    "desculpabilizaremos": "desculpabilizar",
    "desculpabilizares": "desculpabilizar",
    "desculpabilizaria": "desculpabilizar",
    "desculpabilizariam": "desculpabilizar",
    "desculpabilizarias": "desculpabilizar",
    "desculpabilizarmo": "desculpabilizar",
    "desculpabilizarmos": "desculpabilizar",
    "desculpabilizará": "desculpabilizar",
    "desculpabilizarás": "desculpabilizar",
    "desculpabilizarão": "desculpabilizar",
    "desculpabilizaríamos": "desculpabilizar",
    "desculpabilizaríeis": "desculpabilizar",
    "desculpabilizas": "desculpabilizar",
    "desculpabilizasse": "desculpabilizar",
    "desculpabilizassem": "desculpabilizar",
    "desculpabilizasses": "desculpabilizar",
    "desculpabilizaste": "desculpabilizar",
    "desculpabilizastes": "desculpabilizar",
    "desculpabilizava": "desculpabilizar",
    "desculpabilizavam": "desculpabilizar",
    "desculpabilizavas": "desculpabilizar",
    "desculpabilize": "desculpabilizar",
    "desculpabilizei": "desculpabilizar",
    "desculpabilizeis": "desculpabilizar",
    "desculpabilizem": "desculpabilizar",
    "desculpabilizemo": "desculpabilizar",
    "desculpabilizemos": "desculpabilizar",
    "desculpabilizes": "desculpabilizar",
    "desculpabilizo": "desculpabilizar",
    "desculpabilizou": "desculpabilizar",
    "desculpabilizá": "desculpabilizar",
    "desculpabilizámo": "desculpabilizar",
    "desculpabilizámos": "desculpabilizar",
    "desculpabilizáramo": "desculpabilizar",
    "desculpabilizáramos": "desculpabilizar",
    "desculpabilizárei": "desculpabilizar",
    "desculpabilizáreis": "desculpabilizar",
    "desculpabilizásseis": "desculpabilizar",
    "desculpabilizássemos": "desculpabilizar",
    "desculpabilizávamo": "desculpabilizar",
    "desculpabilizávamos": "desculpabilizar",
    "desculpabilizávei": "desculpabilizar",
    "desculpabilizáveis": "desculpabilizar",
    "desculpada": "desculpar",
    "desculpadas": "desculpar",
    "desculpado": "desculpar",
    "desculpadora": "desculpador",
    "desculpadoras": "desculpador",
    "desculpadores": "desculpador",
    "desculpados": "desculpar",
    "desculpai": "desculpar",
    "desculpais": "desculpar",
    "desculpam": "desculpar",
    "desculpamo": "desculpar",
    "desculpamos": "desculpar",
    "desculpando": "desculpar",
    "desculpara": "desculpar",
    "desculparam": "desculpar",
    "desculparas": "desculpar",
    "desculparde": "desculpar",
    "desculpardes": "desculpar",
    "desculpare": "desculpar",
    "desculparei": "desculpar",
    "desculpareis": "desculpar",
    "desculparem": "desculpar",
    "desculparemos": "desculpar",
    "desculpares": "desculpar",
    "desculparia": "desculpar",
    "desculpariam": "desculpar",
    "desculparias": "desculpar",
    "desculparmo": "desculpar",
    "desculparmos": "desculpar",
    "desculpará": "desculpar",
    "desculparás": "desculpar",
    "desculparão": "desculpar",
    "desculparíamos": "desculpar",
    "desculparíeis": "desculpar",
    "desculpas": "desculpar",
    "desculpasse": "desculpar",
    "desculpassem": "desculpar",
    "desculpasses": "desculpar",
    "desculpaste": "desculpar",
    "desculpastes": "desculpar",
    "desculpava": "desculpar",
    "desculpavam": "desculpar",
    "desculpavas": "desculpar",
    "desculpe": "desculpar",
    "desculpei": "desculpar",
    "desculpeis": "desculpar",
    "desculpem": "desculpar",
    "desculpemo": "desculpar",
    "desculpemos": "desculpar",
    "desculpes": "desculpar",
    "desculpo": "desculpar",
    "desculpou": "desculpar",
    "desculpá": "desculpar",
    "desculpámo": "desculpar",
    "desculpámos": "desculpar",
    "desculpáramo": "desculpar",
    "desculpáramos": "desculpar",
    "desculpárei": "desculpar",
    "desculpáreis": "desculpar",
    "desculpásseis": "desculpar",
    "desculpássemos": "desculpar",
    "desculpávamo": "desculpar",
    "desculpávamos": "desculpar",
    "desculpávei": "desculpar",
    "desculpáveis": "desculpável",
    "descultiva": "descultivar",
    "descultivada": "descultivar",
    "descultivadas": "descultivar",
    "descultivado": "descultivar",
    "descultivados": "descultivar",
    "descultivai": "descultivar",
    "descultivais": "descultivar",
    "descultivam": "descultivar",
    "descultivamo": "descultivar",
    "descultivamos": "descultivar",
    "descultivando": "descultivar",
    "descultivara": "descultivar",
    "descultivaram": "descultivar",
    "descultivaras": "descultivar",
    "descultivarde": "descultivar",
    "descultivardes": "descultivar",
    "descultivare": "descultivar",
    "descultivarei": "descultivar",
    "descultivareis": "descultivar",
    "descultivarem": "descultivar",
    "descultivaremos": "descultivar",
    "descultivares": "descultivar",
    "descultivaria": "descultivar",
    "descultivariam": "descultivar",
    "descultivarias": "descultivar",
    "descultivarmo": "descultivar",
    "descultivarmos": "descultivar",
    "descultivará": "descultivar",
    "descultivarás": "descultivar",
    "descultivarão": "descultivar",
    "descultivaríamos": "descultivar",
    "descultivaríeis": "descultivar",
    "descultivas": "descultivar",
    "descultivasse": "descultivar",
    "descultivassem": "descultivar",
    "descultivasses": "descultivar",
    "descultivaste": "descultivar",
    "descultivastes": "descultivar",
    "descultivava": "descultivar",
    "descultivavam": "descultivar",
    "descultivavas": "descultivar",
    "descultive": "descultivar",
    "descultivei": "descultivar",
    "descultiveis": "descultivar",
    "descultivem": "descultivar",
    "descultivemo": "descultivar",
    "descultivemos": "descultivar",
    "descultives": "descultivar",
    "descultivo": "descultivar",
    "descultivos": "descultivo",
    "descultivou": "descultivar",
    "descultivá": "descultivar",
    "descultivámo": "descultivar",
    "descultivámos": "descultivar",
    "descultiváramo": "descultivar",
    "descultiváramos": "descultivar",
    "descultivárei": "descultivar",
    "descultiváreis": "descultivar",
    "descultivásseis": "descultivar",
    "descultivássemos": "descultivar",
    "descultivávamo": "descultivar",
    "descultivávamos": "descultivar",
    "descultivávei": "descultivar",
    "descultiváveis": "descultivar",
    "desculturas": "descultura",
    "descumpra": "descumprir",
    "descumprais": "descumprir",
    "descumpram": "descumprir",
    "descumpramo": "descumprir",
    "descumpramos": "descumprir",
    "descumpras": "descumprir",
    "descumpre": "descumprir",
    "descumprem": "descumprir",
    "descumpres": "descumprir",
    "descumpri": "descumprir",
    "descumpria": "descumprir",
    "descumpriam": "descumprir",
    "descumprias": "descumprir",
    "descumprida": "descumprir",
    "descumpridas": "descumprir",
    "descumprido": "descumprir",
    "descumpridos": "descumprir",
    "descumprimo": "descumprir",
    "descumprimos": "descumprir",
    "descumprindo": "descumprir",
    "descumprira": "descumprir",
    "descumpriram": "descumprir",
    "descumpriras": "descumprir",
    "descumprirde": "descumprir",
    "descumprirdes": "descumprir",
    "descumprire": "descumprir",
    "descumprirei": "descumprir",
    "descumprireis": "descumprir",
    "descumprirem": "descumprir",
    "descumpriremos": "descumprir",
    "descumprires": "descumprir",
    "descumpriria": "descumprir",
    "descumpririam": "descumprir",
    "descumpririas": "descumprir",
    "descumprirmo": "descumprir",
    "descumprirmos": "descumprir",
    "descumprirá": "descumprir",
    "descumprirás": "descumprir",
    "descumprirão": "descumprir",
    "descumpriríamos": "descumprir",
    "descumpriríeis": "descumprir",
    "descumpris": "descumprir",
    "descumprisse": "descumprir",
    "descumprissem": "descumprir",
    "descumprisses": "descumprir",
    "descumpriste": "descumprir",
    "descumpristes": "descumprir",
    "descumpriu": "descumprir",
    "descumpro": "descumprir",
    "descumpríamo": "descumprir",
    "descumpríamos": "descumprir",
    "descumpríei": "descumprir",
    "descumpríeis": "descumprir",
    "descumpríramo": "descumprir",
    "descumpríramos": "descumprir",
    "descumprírei": "descumprir",
    "descumpríreis": "descumprir",
    "descumprísseis": "descumprir",
    "descumpríssemos": "descumprir",
    "descunha": "descunhar",
    "descunhada": "descunhar",
    "descunhadas": "descunhar",
    "descunhado": "descunhar",
    "descunhados": "descunhar",
    "descunhai": "descunhar",
    "descunhais": "descunhar",
    "descunham": "descunhar",
    "descunhamo": "descunhar",
    "descunhamos": "descunhar",
    "descunhando": "descunhar",
    "descunhara": "descunhar",
    "descunharam": "descunhar",
    "descunharas": "descunhar",
    "descunharde": "descunhar",
    "descunhardes": "descunhar",
    "descunhare": "descunhar",
    "descunharei": "descunhar",
    "descunhareis": "descunhar",
    "descunharem": "descunhar",
    "descunharemos": "descunhar",
    "descunhares": "descunhar",
    "descunharia": "descunhar",
    "descunhariam": "descunhar",
    "descunharias": "descunhar",
    "descunharmo": "descunhar",
    "descunharmos": "descunhar",
    "descunhará": "descunhar",
    "descunharás": "descunhar",
    "descunharão": "descunhar",
    "descunharíamos": "descunhar",
    "descunharíeis": "descunhar",
    "descunhas": "descunhar",
    "descunhasse": "descunhar",
    "descunhassem": "descunhar",
    "descunhasses": "descunhar",
    "descunhaste": "descunhar",
    "descunhastes": "descunhar",
    "descunhava": "descunhar",
    "descunhavam": "descunhar",
    "descunhavas": "descunhar",
    "descunhe": "descunhar",
    "descunhei": "descunhar",
    "descunheis": "descunhar",
    "descunhem": "descunhar",
    "descunhemo": "descunhar",
    "descunhemos": "descunhar",
    "descunhes": "descunhar",
    "descunho": "descunhar",
    "descunhou": "descunhar",
    "descunhá": "descunhar",
    "descunhámo": "descunhar",
    "descunhámos": "descunhar",
    "descunháramo": "descunhar",
    "descunháramos": "descunhar",
    "descunhárei": "descunhar",
    "descunháreis": "descunhar",
    "descunhásseis": "descunhar",
    "descunhássemos": "descunhar",
    "descunhávamo": "descunhar",
    "descunhávamos": "descunhar",
    "descunhávei": "descunhar",
    "descunháveis": "descunhar",
    "descura": "descurar",
    "descurada": "descurar",
    "descuradas": "descurar",
    "descurado": "descurar",
    "descurados": "descurar",
    "descurai": "descurar",
    "descurais": "descurar",
    "descuram": "descurar",
    "descuramentos": "descuramento",
    "descuramo": "descurar",
    "descuramos": "descurar",
    "descurando": "descurar",
    "descurara": "descurar",
    "descuraram": "descurar",
    "descuraras": "descurar",
    "descurarde": "descurar",
    "descurardes": "descurar",
    "descurare": "descurar",
    "descurarei": "descurar",
    "descurareis": "descurar",
    "descurarem": "descurar",
    "descuraremos": "descurar",
    "descurares": "descurar",
    "descuraria": "descurar",
    "descurariam": "descurar",
    "descurarias": "descurar",
    "descurarmo": "descurar",
    "descurarmos": "descurar",
    "descurará": "descurar",
    "descurarás": "descurar",
    "descurarão": "descurar",
    "descuraríamos": "descurar",
    "descuraríeis": "descurar",
    "descuras": "descurar",
    "descurasse": "descurar",
    "descurassem": "descurar",
    "descurasses": "descurar",
    "descuraste": "descurar",
    "descurastes": "descurar",
    "descurava": "descurar",
    "descuravam": "descurar",
    "descuravas": "descurar",
    "descure": "descurar",
    "descurei": "descurar",
    "descureis": "descurar",
    "descurem": "descurar",
    "descuremo": "descurar",
    "descuremos": "descurar",
    "descures": "descurar",
    "descuriosa": "descurioso",
    "descuriosas": "descurioso",
    "descuriosidades": "descuriosidade",
    "descuriosos": "descurioso",
    "descuro": "descurar",
    "descurou": "descurar",
    "descurva": "descurvar",
    "descurvada": "descurvar",
    "descurvadas": "descurvar",
    "descurvado": "descurvar",
    "descurvados": "descurvar",
    "descurvai": "descurvar",
    "descurvais": "descurvar",
    "descurvam": "descurvar",
    "descurvamo": "descurvar",
    "descurvamos": "descurvar",
    "descurvando": "descurvar",
    "descurvara": "descurvar",
    "descurvaram": "descurvar",
    "descurvaras": "descurvar",
    "descurvarde": "descurvar",
    "descurvardes": "descurvar",
    "descurvare": "descurvar",
    "descurvarei": "descurvar",
    "descurvareis": "descurvar",
    "descurvarem": "descurvar",
    "descurvaremos": "descurvar",
    "descurvares": "descurvar",
    "descurvaria": "descurvar",
    "descurvariam": "descurvar",
    "descurvarias": "descurvar",
    "descurvarmo": "descurvar",
    "descurvarmos": "descurvar",
    "descurvará": "descurvar",
    "descurvarás": "descurvar",
    "descurvarão": "descurvar",
    "descurvaríamos": "descurvar",
    "descurvaríeis": "descurvar",
    "descurvas": "descurvar",
    "descurvasse": "descurvar",
    "descurvassem": "descurvar",
    "descurvasses": "descurvar",
    "descurvaste": "descurvar",
    "descurvastes": "descurvar",
    "descurvava": "descurvar",
    "descurvavam": "descurvar",
    "descurvavas": "descurvar",
    "descurve": "descurvar",
    "descurvei": "descurvar",
    "descurveis": "descurvar",
    "descurvem": "descurvar",
    "descurvemo": "descurvar",
    "descurvemos": "descurvar",
    "descurves": "descurvar",
    "descurvo": "descurvar",
    "descurvou": "descurvar",
    "descurvá": "descurvar",
    "descurvámo": "descurvar",
    "descurvámos": "descurvar",
    "descurváramo": "descurvar",
    "descurváramos": "descurvar",
    "descurvárei": "descurvar",
    "descurváreis": "descurvar",
    "descurvásseis": "descurvar",
    "descurvássemos": "descurvar",
    "descurvávamo": "descurvar",
    "descurvávamos": "descurvar",
    "descurvávei": "descurvar",
    "descurváveis": "descurvar",
    "descurá": "descurar",
    "descurámo": "descurar",
    "descurámos": "descurar",
    "descuráramo": "descurar",
    "descuráramos": "descurar",
    "descurárei": "descurar",
    "descuráreis": "descurar",
    "descurásseis": "descurar",
    "descurássemos": "descurar",
    "descurávamo": "descurar",
    "descurávamos": "descurar",
    "descurávei": "descurar",
    "descuráveis": "descurar",
    "descê": "descer",
    "descêramo": "descer",
    "descêramos": "descer",
    "descêrei": "descer",
    "descêreis": "descer",
    "descêsseis": "descer",
    "descêssemos": "descer",
    "descíamo": "descer",
    "descíamos": "descer",
    "descíei": "descer",
    "descíeis": "descer",
    "descómodos": "descómodo",
    "desdenha": "desdenhar",
    "desdenhada": "desdenhar",
    "desdenhadas": "desdenhar",
    "desdenhado": "desdenhar",
    "desdenhadora": "desdenhador",
    "desdenhadoras": "desdenhador",
    "desdenhadores": "desdenhador",
    "desdenhados": "desdenhar",
    "desdenhai": "desdenhar",
    "desdenhais": "desdenhar",
    "desdenham": "desdenhar",
    "desdenhamo": "desdenhar",
    "desdenhamos": "desdenhar",
    "desdenhando": "desdenhar",
    "desdenhara": "desdenhar",
    "desdenharam": "desdenhar",
    "desdenharas": "desdenhar",
    "desdenharde": "desdenhar",
    "desdenhardes": "desdenhar",
    "desdenhare": "desdenhar",
    "desdenharei": "desdenhar",
    "desdenhareis": "desdenhar",
    "desdenharem": "desdenhar",
    "desdenharemos": "desdenhar",
    "desdenhares": "desdenhar",
    "desdenharia": "desdenhar",
    "desdenhariam": "desdenhar",
    "desdenharias": "desdenhar",
    "desdenharmo": "desdenhar",
    "desdenharmos": "desdenhar",
    "desdenhará": "desdenhar",
    "desdenharás": "desdenhar",
    "desdenharão": "desdenhar",
    "desdenharíamos": "desdenhar",
    "desdenharíeis": "desdenhar",
    "desdenhas": "desdenhar",
    "desdenhasse": "desdenhar",
    "desdenhassem": "desdenhar",
    "desdenhasses": "desdenhar",
    "desdenhaste": "desdenhar",
    "desdenhastes": "desdenhar",
    "desdenhativa": "desdenhativo",
    "desdenhativas": "desdenhativo",
    "desdenhativos": "desdenhativo",
    "desdenhava": "desdenhar",
    "desdenhavam": "desdenhar",
    "desdenhavas": "desdenhar",
    "desdenhe": "desdenhar",
    "desdenhei": "desdenhar",
    "desdenheis": "desdenhar",
    "desdenhem": "desdenhar",
    "desdenhemo": "desdenhar",
    "desdenhemos": "desdenhar",
    "desdenhes": "desdenhar",
    "desdenho": "desdenhar",
    "desdenhos": "desdenho",
    "desdenhosa": "desdenhoso",
    "desdenhosas": "desdenhoso",
    "desdenhosos": "desdenhoso",
    "desdenhou": "desdenhar",
    "desdenhá": "desdenhar",
    "desdenhámo": "desdenhar",
    "desdenhámos": "desdenhar",
    "desdenháramo": "desdenhar",
    "desdenháramos": "desdenhar",
    "desdenhárei": "desdenhar",
    "desdenháreis": "desdenhar",
    "desdenhásseis": "desdenhar",
    "desdenhássemos": "desdenhar",
    "desdenhávamo": "desdenhar",
    "desdenhávamos": "desdenhar",
    "desdenhávei": "desdenhar",
    "desdenháveis": "desdenhável",
    "desdenta": "desdentar",
    "desdentada": "desdentar",
    "desdentadas": "desdentar",
    "desdentado": "desdentar",
    "desdentados": "desdentar",
    "desdentai": "desdentar",
    "desdentais": "desdentar",
    "desdentam": "desdentar",
    "desdentamo": "desdentar",
    "desdentamos": "desdentar",
    "desdentando": "desdentar",
    "desdentara": "desdentar",
    "desdentaram": "desdentar",
    "desdentaras": "desdentar",
    "desdentarde": "desdentar",
    "desdentardes": "desdentar",
    "desdentare": "desdentar",
    "desdentarei": "desdentar",
    "desdentareis": "desdentar",
    "desdentarem": "desdentar",
    "desdentaremos": "desdentar",
    "desdentares": "desdentar",
    "desdentaria": "desdentar",
    "desdentariam": "desdentar",
    "desdentarias": "desdentar",
    "desdentarmo": "desdentar",
    "desdentarmos": "desdentar",
    "desdentará": "desdentar",
    "desdentarás": "desdentar",
    "desdentarão": "desdentar",
    "desdentaríamos": "desdentar",
    "desdentaríeis": "desdentar",
    "desdentas": "desdentar",
    "desdentasse": "desdentar",
    "desdentassem": "desdentar",
    "desdentasses": "desdentar",
    "desdentaste": "desdentar",
    "desdentastes": "desdentar",
    "desdentava": "desdentar",
    "desdentavam": "desdentar",
    "desdentavas": "desdentar",
    "desdente": "desdentar",
    "desdentei": "desdentar",
    "desdenteis": "desdentar",
    "desdentem": "desdentar",
    "desdentemo": "desdentar",
    "desdentemos": "desdentar",
    "desdentes": "desdentar",
    "desdento": "desdentar",
    "desdentou": "desdentar",
    "desdentá": "desdentar",
    "desdentámo": "desdentar",
    "desdentámos": "desdentar",
    "desdentáramo": "desdentar",
    "desdentáramos": "desdentar",
    "desdentárei": "desdentar",
    "desdentáreis": "desdentar",
    "desdentásseis": "desdentar",
    "desdentássemos": "desdentar",
    "desdentávamo": "desdentar",
    "desdentávamos": "desdentar",
    "desdentávei": "desdentar",
    "desdentáveis": "desdentar",
    "desdiga": "desdizer",
    "desdigais": "desdizer",
    "desdigam": "desdizer",
    "desdigamo": "desdizer",
    "desdigamos": "desdizer",
    "desdigas": "desdizer",
    "desdigo": "desdizer",
    "desdirei": "desdizer",
    "desdireis": "desdizer",
    "desdiremos": "desdizer",
    "desdiria": "desdizer",
    "desdiriam": "desdizer",
    "desdirias": "desdizer",
    "desdirá": "desdizer",
    "desdirás": "desdizer",
    "desdirão": "desdizer",
    "desdiríamos": "desdizer",
    "desdiríeis": "desdizer",
    "desdisse": "desdizer",
    "desdissemo": "desdizer",
    "desdissemos": "desdizer",
    "desdisser": "desdizer",
    "desdissera": "desdizer",
    "desdisseram": "desdizer",
    "desdisseras": "desdizer",
    "desdisserdes": "desdizer",
    "desdisserem": "desdizer",
    "desdisseres": "desdizer",
    "desdissermos": "desdizer",
    "desdissesse": "desdizer",
    "desdissessem": "desdizer",
    "desdissesses": "desdizer",
    "desdisseste": "desdizer",
    "desdissestes": "desdizer",
    "desdisséramo": "desdizer",
    "desdisséramos": "desdizer",
    "desdissérei": "desdizer",
    "desdisséreis": "desdizer",
    "desdissésseis": "desdizer",
    "desdisséssemos": "desdizer",
    "desdita": "desdizer",
    "desditada": "desditado",
    "desditadas": "desditado",
    "desditados": "desditado",
    "desditas": "desdizer",
    "desdito": "desdizer",
    "desditos": "desdizer",
    "desditosa": "desditoso",
    "desditosas": "desditoso",
    "desditosos": "desditoso",
    "desdiz": "desdizer",
    "desdize": "desdizer",
    "desdizei": "desdizer",
    "desdizeis": "desdizer",
    "desdizem": "desdizer",
    "desdizemo": "desdizer",
    "desdizemos": "desdizer",
    "desdizendo": "desdizer",
    "desdizerde": "desdizer",
    "desdizerdes": "desdizer",
    "desdizere": "desdizer",
    "desdizerem": "desdizer",
    "desdizeres": "desdizer",
    "desdizermo": "desdizer",
    "desdizermos": "desdizer",
    "desdizes": "desdizer",
    "desdizia": "desdizer",
    "desdiziam": "desdizer",
    "desdizias": "desdizer",
    "desdizê": "desdizer",
    "desdizíamo": "desdizer",
    "desdizíamos": "desdizer",
    "desdizíei": "desdizer",
    "desdizíeis": "desdizer",
    "desdoba": "desdobar",
    "desdobada": "desdobar",
    "desdobadas": "desdobar",
    "desdobado": "desdobar",
    "desdobados": "desdobar",
    "desdobai": "desdobar",
    "desdobais": "desdobar",
    "desdobam": "desdobar",
    "desdobamo": "desdobar",
    "desdobamos": "desdobar",
    "desdobando": "desdobar",
    "desdobara": "desdobar",
    "desdobaram": "desdobar",
    "desdobaras": "desdobar",
    "desdobarde": "desdobar",
    "desdobardes": "desdobar",
    "desdobare": "desdobar",
    "desdobarei": "desdobar",
    "desdobareis": "desdobar",
    "desdobarem": "desdobar",
    "desdobaremos": "desdobar",
    "desdobares": "desdobar",
    "desdobaria": "desdobar",
    "desdobariam": "desdobar",
    "desdobarias": "desdobar",
    "desdobarmo": "desdobar",
    "desdobarmos": "desdobar",
    "desdobará": "desdobar",
    "desdobarás": "desdobar",
    "desdobarão": "desdobar",
    "desdobaríamos": "desdobar",
    "desdobaríeis": "desdobar",
    "desdobas": "desdobar",
    "desdobasse": "desdobar",
    "desdobassem": "desdobar",
    "desdobasses": "desdobar",
    "desdobaste": "desdobar",
    "desdobastes": "desdobar",
    "desdobava": "desdobar",
    "desdobavam": "desdobar",
    "desdobavas": "desdobar",
    "desdobe": "desdobar",
    "desdobei": "desdobar",
    "desdobeis": "desdobar",
    "desdobem": "desdobar",
    "desdobemo": "desdobar",
    "desdobemos": "desdobar",
    "desdobes": "desdobar",
    "desdobo": "desdobar",
    "desdobou": "desdobar",
    "desdobra": "desdobrar",
    "desdobrada": "desdobrar",
    "desdobradas": "desdobrar",
    "desdobrado": "desdobrar",
    "desdobrados": "desdobrar",
    "desdobrai": "desdobrar",
    "desdobrais": "desdobrar",
    "desdobram": "desdobrar",
    "desdobramentos": "desdobramento",
    "desdobramo": "desdobrar",
    "desdobramos": "desdobrar",
    "desdobrando": "desdobrar",
    "desdobrara": "desdobrar",
    "desdobraram": "desdobrar",
    "desdobraras": "desdobrar",
    "desdobrarde": "desdobrar",
    "desdobrardes": "desdobrar",
    "desdobrare": "desdobrar",
    "desdobrarei": "desdobrar",
    "desdobrareis": "desdobrar",
    "desdobrarem": "desdobrar",
    "desdobraremos": "desdobrar",
    "desdobrares": "desdobrar",
    "desdobraria": "desdobrar",
    "desdobrariam": "desdobrar",
    "desdobrarias": "desdobrar",
    "desdobrarmo": "desdobrar",
    "desdobrarmos": "desdobrar",
    "desdobrará": "desdobrar",
    "desdobrarás": "desdobrar",
    "desdobrarão": "desdobrar",
    "desdobraríamos": "desdobrar",
    "desdobraríeis": "desdobrar",
    "desdobras": "desdobrar",
    "desdobrasse": "desdobrar",
    "desdobrassem": "desdobrar",
    "desdobrasses": "desdobrar",
    "desdobraste": "desdobrar",
    "desdobrastes": "desdobrar",
    "desdobrava": "desdobrar",
    "desdobravam": "desdobrar",
    "desdobravas": "desdobrar",
    "desdobre": "desdobrar",
    "desdobrei": "desdobrar",
    "desdobreis": "desdobrar",
    "desdobrem": "desdobrar",
    "desdobremo": "desdobrar",
    "desdobremos": "desdobrar",
    "desdobres": "desdobrar",
    "desdobro": "desdobrar",
    "desdobros": "desdobro",
    "desdobrou": "desdobrar",
    "desdobrá": "desdobrar",
    "desdobrámo": "desdobrar",
    "desdobrámos": "desdobrar",
    "desdobráramo": "desdobrar",
    "desdobráramos": "desdobrar",
    "desdobrárei": "desdobrar",
    "desdobráreis": "desdobrar",
    "desdobrásseis": "desdobrar",
    "desdobrássemos": "desdobrar",
    "desdobrávamo": "desdobrar",
    "desdobrávamos": "desdobrar",
    "desdobrávei": "desdobrar",
    "desdobráveis": "desdobrável",
    "desdobá": "desdobar",
    "desdobámo": "desdobar",
    "desdobámos": "desdobar",
    "desdobáramo": "desdobar",
    "desdobáramos": "desdobar",
    "desdobárei": "desdobar",
    "desdobáreis": "desdobar",
    "desdobásseis": "desdobar",
    "desdobássemos": "desdobar",
    "desdobávamo": "desdobar",
    "desdobávamos": "desdobar",
    "desdobávei": "desdobar",
    "desdobáveis": "desdobar",
    "desdoira": "desdoirar",
    "desdoirada": "desdoirar",
    "desdoiradas": "desdoirar",
    "desdoirado": "desdoirar",
    "desdoirados": "desdoirar",
    "desdoirai": "desdoirar",
    "desdoirais": "desdoirar",
    "desdoiram": "desdoirar",
    "desdoiramo": "desdoirar",
    "desdoiramos": "desdoirar",
    "desdoirando": "desdoirar",
    "desdoirara": "desdoirar",
    "desdoiraram": "desdoirar",
    "desdoiraras": "desdoirar",
    "desdoirarde": "desdoirar",
    "desdoirardes": "desdoirar",
    "desdoirare": "desdoirar",
    "desdoirarei": "desdoirar",
    "desdoirareis": "desdoirar",
    "desdoirarem": "desdoirar",
    "desdoiraremos": "desdoirar",
    "desdoirares": "desdoirar",
    "desdoiraria": "desdoirar",
    "desdoirariam": "desdoirar",
    "desdoirarias": "desdoirar",
    "desdoirarmo": "desdoirar",
    "desdoirarmos": "desdoirar",
    "desdoirará": "desdoirar",
    "desdoirarás": "desdoirar",
    "desdoirarão": "desdoirar",
    "desdoiraríamos": "desdoirar",
    "desdoiraríeis": "desdoirar",
    "desdoiras": "desdoirar",
    "desdoirasse": "desdoirar",
    "desdoirassem": "desdoirar",
    "desdoirasses": "desdoirar",
    "desdoiraste": "desdoirar",
    "desdoirastes": "desdoirar",
    "desdoirava": "desdoirar",
    "desdoiravam": "desdoirar",
    "desdoiravas": "desdoirar",
    "desdoire": "desdoirar",
    "desdoirei": "desdoirar",
    "desdoireis": "desdoirar",
    "desdoirem": "desdoirar",
    "desdoiremo": "desdoirar",
    "desdoiremos": "desdoirar",
    "desdoires": "desdoirar",
    "desdoiro": "desdoirar",
    "desdoiros": "desdoiro",
    "desdoirou": "desdoirar",
    "desdoirá": "desdoirar",
    "desdoirámo": "desdoirar",
    "desdoirámos": "desdoirar",
    "desdoiráramo": "desdoirar",
    "desdoiráramos": "desdoirar",
    "desdoirárei": "desdoirar",
    "desdoiráreis": "desdoirar",
    "desdoirásseis": "desdoirar",
    "desdoirássemos": "desdoirar",
    "desdoirávamo": "desdoirar",
    "desdoirávamos": "desdoirar",
    "desdoirávei": "desdoirar",
    "desdoiráveis": "desdoirar",
    "desdoura": "desdourar",
    "desdourada": "desdourar",
    "desdouradas": "desdourar",
    "desdourado": "desdourar",
    "desdourados": "desdourar",
    "desdourai": "desdourar",
    "desdourais": "desdourar",
    "desdouram": "desdourar",
    "desdouramo": "desdourar",
    "desdouramos": "desdourar",
    "desdourando": "desdourar",
    "desdourara": "desdourar",
    "desdouraram": "desdourar",
    "desdouraras": "desdourar",
    "desdourarde": "desdourar",
    "desdourardes": "desdourar",
    "desdourare": "desdourar",
    "desdourarei": "desdourar",
    "desdourareis": "desdourar",
    "desdourarem": "desdourar",
    "desdouraremos": "desdourar",
    "desdourares": "desdourar",
    "desdouraria": "desdourar",
    "desdourariam": "desdourar",
    "desdourarias": "desdourar",
    "desdourarmo": "desdourar",
    "desdourarmos": "desdourar",
    "desdourará": "desdourar",
    "desdourarás": "desdourar",
    "desdourarão": "desdourar",
    "desdouraríamos": "desdourar",
    "desdouraríeis": "desdourar",
    "desdouras": "desdourar",
    "desdourasse": "desdourar",
    "desdourassem": "desdourar",
    "desdourasses": "desdourar",
    "desdouraste": "desdourar",
    "desdourastes": "desdourar",
    "desdourava": "desdourar",
    "desdouravam": "desdourar",
    "desdouravas": "desdourar",
    "desdoure": "desdourar",
    "desdourei": "desdourar",
    "desdoureis": "desdourar",
    "desdourem": "desdourar",
    "desdouremo": "desdourar",
    "desdouremos": "desdourar",
    "desdoures": "desdourar",
    "desdouro": "desdourar",
    "desdouros": "desdouro",
    "desdourou": "desdourar",
    "desdourá": "desdourar",
    "desdourámo": "desdourar",
    "desdourámos": "desdourar",
    "desdouráramo": "desdourar",
    "desdouráramos": "desdourar",
    "desdourárei": "desdourar",
    "desdouráreis": "desdourar",
    "desdourásseis": "desdourar",
    "desdourássemos": "desdourar",
    "desdourávamo": "desdourar",
    "desdourávamos": "desdourar",
    "desdourávei": "desdourar",
    "desdouráveis": "desdourar",
    "desdoutrina": "desdoutrinar",
    "desdoutrinada": "desdoutrinar",
    "desdoutrinadas": "desdoutrinar",
    "desdoutrinado": "desdoutrinar",
    "desdoutrinados": "desdoutrinar",
    "desdoutrinai": "desdoutrinar",
    "desdoutrinais": "desdoutrinar",
    "desdoutrinam": "desdoutrinar",
    "desdoutrinamo": "desdoutrinar",
    "desdoutrinamos": "desdoutrinar",
    "desdoutrinando": "desdoutrinar",
    "desdoutrinara": "desdoutrinar",
    "desdoutrinaram": "desdoutrinar",
    "desdoutrinaras": "desdoutrinar",
    "desdoutrinarde": "desdoutrinar",
    "desdoutrinardes": "desdoutrinar",
    "desdoutrinare": "desdoutrinar",
    "desdoutrinarei": "desdoutrinar",
    "desdoutrinareis": "desdoutrinar",
    "desdoutrinarem": "desdoutrinar",
    "desdoutrinaremos": "desdoutrinar",
    "desdoutrinares": "desdoutrinar",
    "desdoutrinaria": "desdoutrinar",
    "desdoutrinariam": "desdoutrinar",
    "desdoutrinarias": "desdoutrinar",
    "desdoutrinarmo": "desdoutrinar",
    "desdoutrinarmos": "desdoutrinar",
    "desdoutrinará": "desdoutrinar",
    "desdoutrinarás": "desdoutrinar",
    "desdoutrinarão": "desdoutrinar",
    "desdoutrinaríamos": "desdoutrinar",
    "desdoutrinaríeis": "desdoutrinar",
    "desdoutrinas": "desdoutrinar",
    "desdoutrinasse": "desdoutrinar",
    "desdoutrinassem": "desdoutrinar",
    "desdoutrinasses": "desdoutrinar",
    "desdoutrinaste": "desdoutrinar",
    "desdoutrinastes": "desdoutrinar",
    "desdoutrinava": "desdoutrinar",
    "desdoutrinavam": "desdoutrinar",
    "desdoutrinavas": "desdoutrinar",
    "desdoutrinações": "desdoutrinação",
    "desdoutrine": "desdoutrinar",
    "desdoutrinei": "desdoutrinar",
    "desdoutrineis": "desdoutrinar",
    "desdoutrinem": "desdoutrinar",
    "desdoutrinemo": "desdoutrinar",
    "desdoutrinemos": "desdoutrinar",
    "desdoutrines": "desdoutrinar",
    "desdoutrino": "desdoutrinar",
    "desdoutrinou": "desdoutrinar",
    "desdoutriná": "desdoutrinar",
    "desdoutrinámo": "desdoutrinar",
    "desdoutrinámos": "desdoutrinar",
    "desdoutrináramo": "desdoutrinar",
    "desdoutrináramos": "desdoutrinar",
    "desdoutrinárei": "desdoutrinar",
    "desdoutrináreis": "desdoutrinar",
    "desdoutrinásseis": "desdoutrinar",
    "desdoutrinássemos": "desdoutrinar",
    "desdoutrinávamo": "desdoutrinar",
    "desdoutrinávamos": "desdoutrinar",
    "desdoutrinávei": "desdoutrinar",
    "desdoutrináveis": "desdoutrinar",
    "desdramatiza": "desdramatizar",
    "desdramatizada": "desdramatizar",
    "desdramatizadas": "desdramatizar",
    "desdramatizado": "desdramatizar",
    "desdramatizados": "desdramatizar",
    "desdramatizai": "desdramatizar",
    "desdramatizais": "desdramatizar",
    "desdramatizam": "desdramatizar",
    "desdramatizamo": "desdramatizar",
    "desdramatizamos": "desdramatizar",
    "desdramatizando": "desdramatizar",
    "desdramatizara": "desdramatizar",
    "desdramatizaram": "desdramatizar",
    "desdramatizaras": "desdramatizar",
    "desdramatizarde": "desdramatizar",
    "desdramatizardes": "desdramatizar",
    "desdramatizare": "desdramatizar",
    "desdramatizarei": "desdramatizar",
    "desdramatizareis": "desdramatizar",
    "desdramatizarem": "desdramatizar",
    "desdramatizaremos": "desdramatizar",
    "desdramatizares": "desdramatizar",
    "desdramatizaria": "desdramatizar",
    "desdramatizariam": "desdramatizar",
    "desdramatizarias": "desdramatizar",
    "desdramatizarmo": "desdramatizar",
    "desdramatizarmos": "desdramatizar",
    "desdramatizará": "desdramatizar",
    "desdramatizarás": "desdramatizar",
    "desdramatizarão": "desdramatizar",
    "desdramatizaríamos": "desdramatizar",
    "desdramatizaríeis": "desdramatizar",
    "desdramatizas": "desdramatizar",
    "desdramatizasse": "desdramatizar",
    "desdramatizassem": "desdramatizar",
    "desdramatizasses": "desdramatizar",
    "desdramatizaste": "desdramatizar",
    "desdramatizastes": "desdramatizar",
    "desdramatizava": "desdramatizar",
    "desdramatizavam": "desdramatizar",
    "desdramatizavas": "desdramatizar",
    "desdramatizações": "desdramatização",
    "desdramatize": "desdramatizar",
    "desdramatizei": "desdramatizar",
    "desdramatizeis": "desdramatizar",
    "desdramatizem": "desdramatizar",
    "desdramatizemo": "desdramatizar",
    "desdramatizemos": "desdramatizar",
    "desdramatizes": "desdramatizar",
    "desdramatizo": "desdramatizar",
    "desdramatizou": "desdramatizar",
    "desdramatizá": "desdramatizar",
    "desdramatizámo": "desdramatizar",
    "desdramatizámos": "desdramatizar",
    "desdramatizáramo": "desdramatizar",
    "desdramatizáramos": "desdramatizar",
    "desdramatizárei": "desdramatizar",
    "desdramatizáreis": "desdramatizar",
    "desdramatizásseis": "desdramatizar",
    "desdramatizássemos": "desdramatizar",
    "desdramatizávamo": "desdramatizar",
    "desdramatizávamos": "desdramatizar",
    "desdramatizávei": "desdramatizar",
    "desdramatizáveis": "desdramatizar",
    "desdéns": "desdém",
    "desealmada": "desealmado",
    "desealmadas": "desealmado",
    "desealmados": "desealmado",
    "deseclipsa": "deseclipsar",
    "deseclipsada": "deseclipsar",
    "deseclipsadas": "deseclipsar",
    "deseclipsado": "deseclipsar",
    "deseclipsados": "deseclipsar",
    "deseclipsai": "deseclipsar",
    "deseclipsais": "deseclipsar",
    "deseclipsam": "deseclipsar",
    "deseclipsamo": "deseclipsar",
    "deseclipsamos": "deseclipsar",
    "deseclipsando": "deseclipsar",
    "deseclipsara": "deseclipsar",
    "deseclipsaram": "deseclipsar",
    "deseclipsaras": "deseclipsar",
    "deseclipsarde": "deseclipsar",
    "deseclipsardes": "deseclipsar",
    "deseclipsare": "deseclipsar",
    "deseclipsarei": "deseclipsar",
    "deseclipsareis": "deseclipsar",
    "deseclipsarem": "deseclipsar",
    "deseclipsaremos": "deseclipsar",
    "deseclipsares": "deseclipsar",
    "deseclipsaria": "deseclipsar",
    "deseclipsariam": "deseclipsar",
    "deseclipsarias": "deseclipsar",
    "deseclipsarmo": "deseclipsar",
    "deseclipsarmos": "deseclipsar",
    "deseclipsará": "deseclipsar",
    "deseclipsarás": "deseclipsar",
    "deseclipsarão": "deseclipsar",
    "deseclipsaríamos": "deseclipsar",
    "deseclipsaríeis": "deseclipsar",
    "deseclipsas": "deseclipsar",
    "deseclipsasse": "deseclipsar",
    "deseclipsassem": "deseclipsar",
    "deseclipsasses": "deseclipsar",
    "deseclipsaste": "deseclipsar",
    "deseclipsastes": "deseclipsar",
    "deseclipsava": "deseclipsar",
    "deseclipsavam": "deseclipsar",
    "deseclipsavas": "deseclipsar",
    "deseclipse": "deseclipsar",
    "deseclipsei": "deseclipsar",
    "deseclipseis": "deseclipsar",
    "deseclipsem": "deseclipsar",
    "deseclipsemo": "deseclipsar",
    "deseclipsemos": "deseclipsar",
    "deseclipses": "deseclipsar",
    "deseclipso": "deseclipsar",
    "deseclipsou": "deseclipsar",
    "deseclipsá": "deseclipsar",
    "deseclipsámo": "deseclipsar",
    "deseclipsámos": "deseclipsar",
    "deseclipsáramo": "deseclipsar",
    "deseclipsáramos": "deseclipsar",
    "deseclipsárei": "deseclipsar",
    "deseclipsáreis": "deseclipsar",
    "deseclipsásseis": "deseclipsar",
    "deseclipsássemos": "deseclipsar",
    "deseclipsávamo": "deseclipsar",
    "deseclipsávamos": "deseclipsar",
    "deseclipsávei": "deseclipsar",
    "deseclipsáveis": "deseclipsar",
    "desedifica": "desedificar",
    "desedificada": "desedificar",
    "desedificadas": "desedificar",
    "desedificado": "desedificar",
    "desedificadora": "desedificador",
    "desedificadoras": "desedificador",
    "desedificadores": "desedificador",
    "desedificados": "desedificar",
    "desedificai": "desedificar",
    "desedificais": "desedificar",
    "desedificam": "desedificar",
    "desedificamo": "desedificar",
    "desedificamos": "desedificar",
    "desedificando": "desedificar",
    "desedificantes": "desedificante",
    "desedificara": "desedificar",
    "desedificaram": "desedificar",
    "desedificaras": "desedificar",
    "desedificarde": "desedificar",
    "desedificardes": "desedificar",
    "desedificare": "desedificar",
    "desedificarei": "desedificar",
    "desedificareis": "desedificar",
    "desedificarem": "desedificar",
    "desedificaremos": "desedificar",
    "desedificares": "desedificar",
    "desedificaria": "desedificar",
    "desedificariam": "desedificar",
    "desedificarias": "desedificar",
    "desedificarmo": "desedificar",
    "desedificarmos": "desedificar",
    "desedificará": "desedificar",
    "desedificarás": "desedificar",
    "desedificarão": "desedificar",
    "desedificaríamos": "desedificar",
    "desedificaríeis": "desedificar",
    "desedificas": "desedificar",
    "desedificasse": "desedificar",
    "desedificassem": "desedificar",
    "desedificasses": "desedificar",
    "desedificaste": "desedificar",
    "desedificastes": "desedificar",
    "desedificativa": "desedificativo",
    "desedificativas": "desedificativo",
    "desedificativos": "desedificativo",
    "desedificava": "desedificar",
    "desedificavam": "desedificar",
    "desedificavas": "desedificar",
    "desedificações": "desedificação",
    "desedifico": "desedificar",
    "desedificou": "desedificar",
    "desedificá": "desedificar",
    "desedificámo": "desedificar",
    "desedificámos": "desedificar",
    "desedificáramo": "desedificar",
    "desedificáramos": "desedificar",
    "desedificárei": "desedificar",
    "desedificáreis": "desedificar",
    "desedificásseis": "desedificar",
    "desedificássemos": "desedificar",
    "desedificávamo": "desedificar",
    "desedificávamos": "desedificar",
    "desedificávei": "desedificar",
    "desedificáveis": "desedificar",
    "desedifique": "desedificar",
    "desedifiquei": "desedificar",
    "desedifiqueis": "desedificar",
    "desedifiquem": "desedificar",
    "desedifiquemo": "desedificar",
    "desedifiquemos": "desedificar",
    "desedifiques": "desedificar",
    "deseduca": "deseducar",
    "deseducada": "deseducar",
    "deseducadas": "deseducar",
    "deseducado": "deseducar",
    "deseducadora": "deseducador",
    "deseducadoras": "deseducador",
    "deseducadores": "deseducador",
    "deseducados": "deseducar",
    "deseducai": "deseducar",
    "deseducais": "deseducar",
    "deseducam": "deseducar",
    "deseducamo": "deseducar",
    "deseducamos": "deseducar",
    "deseducando": "deseducar",
    "deseducara": "deseducar",
    "deseducaram": "deseducar",
    "deseducaras": "deseducar",
    "deseducarde": "deseducar",
    "deseducardes": "deseducar",
    "deseducare": "deseducar",
    "deseducarei": "deseducar",
    "deseducareis": "deseducar",
    "deseducarem": "deseducar",
    "deseducaremos": "deseducar",
    "deseducares": "deseducar",
    "deseducaria": "deseducar",
    "deseducariam": "deseducar",
    "deseducarias": "deseducar",
    "deseducarmo": "deseducar",
    "deseducarmos": "deseducar",
    "deseducará": "deseducar",
    "deseducarás": "deseducar",
    "deseducarão": "deseducar",
    "deseducaríamos": "deseducar",
    "deseducaríeis": "deseducar",
    "deseducas": "deseducar",
    "deseducasse": "deseducar",
    "deseducassem": "deseducar",
    "deseducasses": "deseducar",
    "deseducaste": "deseducar",
    "deseducastes": "deseducar",
    "deseducativa": "deseducativo",
    "deseducativas": "deseducativo",
    "deseducativos": "deseducativo",
    "deseducava": "deseducar",
    "deseducavam": "deseducar",
    "deseducavas": "deseducar",
    "deseducações": "deseducação",
    "deseduco": "deseducar",
    "deseducou": "deseducar",
    "deseducá": "deseducar",
    "deseducámo": "deseducar",
    "deseducámos": "deseducar",
    "deseducáramo": "deseducar",
    "deseducáramos": "deseducar",
    "deseducárei": "deseducar",
    "deseducáreis": "deseducar",
    "deseducásseis": "deseducar",
    "deseducássemos": "deseducar",
    "deseducávamo": "deseducar",
    "deseducávamos": "deseducar",
    "deseducávei": "deseducar",
    "deseducáveis": "deseducar",
    "deseduque": "deseducar",
    "deseduquei": "deseducar",
    "deseduqueis": "deseducar",
    "deseduquem": "deseducar",
    "deseduquemo": "deseducar",
    "deseduquemos": "deseducar",
    "deseduques": "deseducar",
    "deseixa": "deseixar",
    "deseixada": "deseixar",
    "deseixadas": "deseixar",
    "deseixado": "deseixar",
    "deseixados": "deseixar",
    "deseixai": "deseixar",
    "deseixais": "deseixar",
    "deseixam": "deseixar",
    "deseixamo": "deseixar",
    "deseixamos": "deseixar",
    "deseixando": "deseixar",
    "deseixara": "deseixar",
    "deseixaram": "deseixar",
    "deseixaras": "deseixar",
    "deseixarde": "deseixar",
    "deseixardes": "deseixar",
    "deseixare": "deseixar",
    "deseixarei": "deseixar",
    "deseixareis": "deseixar",
    "deseixarem": "deseixar",
    "deseixaremos": "deseixar",
    "deseixares": "deseixar",
    "deseixaria": "deseixar",
    "deseixariam": "deseixar",
    "deseixarias": "deseixar",
    "deseixarmo": "deseixar",
    "deseixarmos": "deseixar",
    "deseixará": "deseixar",
    "deseixarás": "deseixar",
    "deseixarão": "deseixar",
    "deseixaríamos": "deseixar",
    "deseixaríeis": "deseixar",
    "deseixas": "deseixar",
    "deseixasse": "deseixar",
    "deseixassem": "deseixar",
    "deseixasses": "deseixar",
    "deseixaste": "deseixar",
    "deseixastes": "deseixar",
    "deseixava": "deseixar",
    "deseixavam": "deseixar",
    "deseixavas": "deseixar",
    "deseixe": "deseixar",
    "deseixei": "deseixar",
    "deseixeis": "deseixar",
    "deseixem": "deseixar",
    "deseixemo": "deseixar",
    "deseixemos": "deseixar",
    "deseixes": "deseixar",
    "deseixo": "deseixar",
    "deseixou": "deseixar",
    "deseixá": "deseixar",
    "deseixámo": "deseixar",
    "deseixámos": "deseixar",
    "deseixáramo": "deseixar",
    "deseixáramos": "deseixar",
    "deseixárei": "deseixar",
    "deseixáreis": "deseixar",
    "deseixásseis": "deseixar",
    "deseixássemos": "deseixar",
    "deseixávamo": "deseixar",
    "deseixávamos": "deseixar",
    "deseixávei": "deseixar",
    "deseixáveis": "deseixar",
    "deseja": "desejar",
    "desejada": "desejar",
    "desejadas": "desejar",
    "desejado": "desejar",
    "desejadora": "desejador",
    "desejadoras": "desejador",
    "desejadores": "desejador",
    "desejados": "desejar",
    "desejai": "desejar",
    "desejais": "desejar",
    "desejam": "desejar",
    "desejamo": "desejar",
    "desejamos": "desejar",
    "desejando": "desejar",
    "desejara": "desejar",
    "desejaram": "desejar",
    "desejaras": "desejar",
    "desejarde": "desejar",
    "desejardes": "desejar",
    "desejare": "desejar",
    "desejarei": "desejar",
    "desejareis": "desejar",
    "desejarem": "desejar",
    "desejaremos": "desejar",
    "desejares": "desejar",
    "desejaria": "desejar",
    "desejariam": "desejar",
    "desejarias": "desejar",
    "desejarmo": "desejar",
    "desejarmos": "desejar",
    "desejará": "desejar",
    "desejarás": "desejar",
    "desejarão": "desejar",
    "desejaríamos": "desejar",
    "desejaríeis": "desejar",
    "desejas": "desejar",
    "desejasse": "desejar",
    "desejassem": "desejar",
    "desejasses": "desejar",
    "desejaste": "desejar",
    "desejastes": "desejar",
    "desejava": "desejar",
    "desejavam": "desejar",
    "desejavas": "desejar",
    "deseje": "desejar",
    "desejei": "desejar",
    "desejeis": "desejar",
    "desejem": "desejar",
    "desejemo": "desejar",
    "desejemos": "desejar",
    "desejes": "desejar",
    "desejo": "desejar",
    "desejos": "desejo",
    "desejosa": "desejoso",
    "desejosas": "desejoso",
    "desejosos": "desejoso",
    "desejou": "desejar",
    "desejá": "desejar",
    "desejámo": "desejar",
    "desejámos": "desejar",
    "desejáramo": "desejar",
    "desejáramos": "desejar",
    "desejárei": "desejar",
    "desejáreis": "desejar",
    "desejásseis": "desejar",
    "desejássemos": "desejar",
    "desejávamo": "desejar",
    "desejávamos": "desejar",
    "desejávei": "desejar",
    "desejáveis": "desejável",
    "deselectriza": "deselectrizar",
    "deselectrizada": "deselectrizar",
    "deselectrizadas": "deselectrizar",
    "deselectrizado": "deselectrizar",
    "deselectrizados": "deselectrizar",
    "deselectrizai": "deselectrizar",
    "deselectrizais": "deselectrizar",
    "deselectrizam": "deselectrizar",
    "deselectrizamo": "deselectrizar",
    "deselectrizamos": "deselectrizar",
    "deselectrizando": "deselectrizar",
    "deselectrizara": "deselectrizar",
    "deselectrizaram": "deselectrizar",
    "deselectrizaras": "deselectrizar",
    "deselectrizarde": "deselectrizar",
    "deselectrizardes": "deselectrizar",
    "deselectrizare": "deselectrizar",
    "deselectrizarei": "deselectrizar",
    "deselectrizareis": "deselectrizar",
    "deselectrizarem": "deselectrizar",
    "deselectrizaremos": "deselectrizar",
    "deselectrizares": "deselectrizar",
    "deselectrizaria": "deselectrizar",
    "deselectrizariam": "deselectrizar",
    "deselectrizarias": "deselectrizar",
    "deselectrizarmo": "deselectrizar",
    "deselectrizarmos": "deselectrizar",
    "deselectrizará": "deselectrizar",
    "deselectrizarás": "deselectrizar",
    "deselectrizarão": "deselectrizar",
    "deselectrizaríamos": "deselectrizar",
    "deselectrizaríeis": "deselectrizar",
    "deselectrizas": "deselectrizar",
    "deselectrizasse": "deselectrizar",
    "deselectrizassem": "deselectrizar",
    "deselectrizasses": "deselectrizar",
    "deselectrizaste": "deselectrizar",
    "deselectrizastes": "deselectrizar",
    "deselectrizava": "deselectrizar",
    "deselectrizavam": "deselectrizar",
    "deselectrizavas": "deselectrizar",
    "deselectrize": "deselectrizar",
    "deselectrizei": "deselectrizar",
    "deselectrizeis": "deselectrizar",
    "deselectrizem": "deselectrizar",
    "deselectrizemo": "deselectrizar",
    "deselectrizemos": "deselectrizar",
    "deselectrizes": "deselectrizar",
    "deselectrizo": "deselectrizar",
    "deselectrizou": "deselectrizar",
    "deselectrizá": "deselectrizar",
    "deselectrizámo": "deselectrizar",
    "deselectrizámos": "deselectrizar",
    "deselectrizáramo": "deselectrizar",
    "deselectrizáramos": "deselectrizar",
    "deselectrizárei": "deselectrizar",
    "deselectrizáreis": "deselectrizar",
    "deselectrizásseis": "deselectrizar",
    "deselectrizássemos": "deselectrizar",
    "deselectrizávamo": "deselectrizar",
    "deselectrizávamos": "deselectrizar",
    "deselectrizávei": "deselectrizar",
    "deselectrizáveis": "deselectrizar",
    "deselegantes": "deselegante",
    "deselegâncias": "deselegância",
    "deselimina": "deseliminar",
    "deseliminada": "deseliminar",
    "deseliminadas": "deseliminar",
    "deseliminado": "deseliminar",
    "deseliminados": "deseliminar",
    "deseliminai": "deseliminar",
    "deseliminais": "deseliminar",
    "deseliminam": "deseliminar",
    "deseliminamo": "deseliminar",
    "deseliminamos": "deseliminar",
    "deseliminando": "deseliminar",
    "deseliminara": "deseliminar",
    "deseliminaram": "deseliminar",
    "deseliminaras": "deseliminar",
    "deseliminarde": "deseliminar",
    "deseliminardes": "deseliminar",
    "deseliminare": "deseliminar",
    "deseliminarei": "deseliminar",
    "deseliminareis": "deseliminar",
    "deseliminarem": "deseliminar",
    "deseliminaremos": "deseliminar",
    "deseliminares": "deseliminar",
    "deseliminaria": "deseliminar",
    "deseliminariam": "deseliminar",
    "deseliminarias": "deseliminar",
    "deseliminarmo": "deseliminar",
    "deseliminarmos": "deseliminar",
    "deseliminará": "deseliminar",
    "deseliminarás": "deseliminar",
    "deseliminarão": "deseliminar",
    "deseliminaríamos": "deseliminar",
    "deseliminaríeis": "deseliminar",
    "deseliminas": "deseliminar",
    "deseliminasse": "deseliminar",
    "deseliminassem": "deseliminar",
    "deseliminasses": "deseliminar",
    "deseliminaste": "deseliminar",
    "deseliminastes": "deseliminar",
    "deseliminava": "deseliminar",
    "deseliminavam": "deseliminar",
    "deseliminavas": "deseliminar",
    "deselimine": "deseliminar",
    "deseliminei": "deseliminar",
    "deselimineis": "deseliminar",
    "deseliminem": "deseliminar",
    "deseliminemo": "deseliminar",
    "deseliminemos": "deseliminar",
    "deselimines": "deseliminar",
    "deselimino": "deseliminar",
    "deseliminou": "deseliminar",
    "deseliminá": "deseliminar",
    "deseliminámo": "deseliminar",
    "deseliminámos": "deseliminar",
    "deselimináramo": "deseliminar",
    "deselimináramos": "deseliminar",
    "deseliminárei": "deseliminar",
    "deselimináreis": "deseliminar",
    "deseliminásseis": "deseliminar",
    "deseliminássemos": "deseliminar",
    "deseliminávamo": "deseliminar",
    "deseliminávamos": "deseliminar",
    "deseliminávei": "deseliminar",
    "deselimináveis": "deseliminar",
    "desemace": "desemaçar",
    "desemacei": "desemaçar",
    "desemaceis": "desemaçar",
    "desemacem": "desemaçar",
    "desemacemo": "desemaçar",
    "desemacemos": "desemaçar",
    "desemaces": "desemaçar",
    "desemadeira": "desemadeirar",
    "desemadeirada": "desemadeirar",
    "desemadeiradas": "desemadeirar",
    "desemadeirado": "desemadeirar",
    "desemadeirados": "desemadeirar",
    "desemadeirai": "desemadeirar",
    "desemadeirais": "desemadeirar",
    "desemadeiram": "desemadeirar",
    "desemadeiramo": "desemadeirar",
    "desemadeiramos": "desemadeirar",
    "desemadeirando": "desemadeirar",
    "desemadeirara": "desemadeirar",
    "desemadeiraram": "desemadeirar",
    "desemadeiraras": "desemadeirar",
    "desemadeirarde": "desemadeirar",
    "desemadeirardes": "desemadeirar",
    "desemadeirare": "desemadeirar",
    "desemadeirarei": "desemadeirar",
    "desemadeirareis": "desemadeirar",
    "desemadeirarem": "desemadeirar",
    "desemadeiraremos": "desemadeirar",
    "desemadeirares": "desemadeirar",
    "desemadeiraria": "desemadeirar",
    "desemadeirariam": "desemadeirar",
    "desemadeirarias": "desemadeirar",
    "desemadeirarmo": "desemadeirar",
    "desemadeirarmos": "desemadeirar",
    "desemadeirará": "desemadeirar",
    "desemadeirarás": "desemadeirar",
    "desemadeirarão": "desemadeirar",
    "desemadeiraríamos": "desemadeirar",
    "desemadeiraríeis": "desemadeirar",
    "desemadeiras": "desemadeirar",
    "desemadeirasse": "desemadeirar",
    "desemadeirassem": "desemadeirar",
    "desemadeirasses": "desemadeirar",
    "desemadeiraste": "desemadeirar",
    "desemadeirastes": "desemadeirar",
    "desemadeirava": "desemadeirar",
    "desemadeiravam": "desemadeirar",
    "desemadeiravas": "desemadeirar",
    "desemadeire": "desemadeirar",
    "desemadeirei": "desemadeirar",
    "desemadeireis": "desemadeirar",
    "desemadeirem": "desemadeirar",
    "desemadeiremo": "desemadeirar",
    "desemadeiremos": "desemadeirar",
    "desemadeires": "desemadeirar",
    "desemadeiro": "desemadeirar",
    "desemadeirou": "desemadeirar",
    "desemadeirá": "desemadeirar",
    "desemadeirámo": "desemadeirar",
    "desemadeirámos": "desemadeirar",
    "desemadeiráramo": "desemadeirar",
    "desemadeiráramos": "desemadeirar",
    "desemadeirárei": "desemadeirar",
    "desemadeiráreis": "desemadeirar",
    "desemadeirásseis": "desemadeirar",
    "desemadeirássemos": "desemadeirar",
    "desemadeirávamo": "desemadeirar",
    "desemadeirávamos": "desemadeirar",
    "desemadeirávei": "desemadeirar",
    "desemadeiráveis": "desemadeirar",
    "desemala": "desemalar",
    "desemalada": "desemalar",
    "desemaladas": "desemalar",
    "desemalado": "desemalar",
    "desemalados": "desemalar",
    "desemalai": "desemalar",
    "desemalais": "desemalar",
    "desemalam": "desemalar",
    "desemalamo": "desemalar",
    "desemalamos": "desemalar",
    "desemalando": "desemalar",
    "desemalara": "desemalar",
    "desemalaram": "desemalar",
    "desemalaras": "desemalar",
    "desemalarde": "desemalar",
    "desemalardes": "desemalar",
    "desemalare": "desemalar",
    "desemalarei": "desemalar",
    "desemalareis": "desemalar",
    "desemalarem": "desemalar",
    "desemalaremos": "desemalar",
    "desemalares": "desemalar",
    "desemalaria": "desemalar",
    "desemalariam": "desemalar",
    "desemalarias": "desemalar",
    "desemalarmo": "desemalar",
    "desemalarmos": "desemalar",
    "desemalará": "desemalar",
    "desemalarás": "desemalar",
    "desemalarão": "desemalar",
    "desemalaríamos": "desemalar",
    "desemalaríeis": "desemalar",
    "desemalas": "desemalar",
    "desemalasse": "desemalar",
    "desemalassem": "desemalar",
    "desemalasses": "desemalar",
    "desemalaste": "desemalar",
    "desemalastes": "desemalar",
    "desemalava": "desemalar",
    "desemalavam": "desemalar",
    "desemalavas": "desemalar",
    "desemale": "desemalar",
    "desemalei": "desemalar",
    "desemaleis": "desemalar",
    "desemalem": "desemalar",
    "desemalemo": "desemalar",
    "desemalemos": "desemalar",
    "desemales": "desemalar",
    "desemalha": "desemalhar",
    "desemalhada": "desemalhar",
    "desemalhadas": "desemalhar",
    "desemalhado": "desemalhar",
    "desemalhados": "desemalhar",
    "desemalhai": "desemalhar",
    "desemalhais": "desemalhar",
    "desemalham": "desemalhar",
    "desemalhamo": "desemalhar",
    "desemalhamos": "desemalhar",
    "desemalhando": "desemalhar",
    "desemalhara": "desemalhar",
    "desemalharam": "desemalhar",
    "desemalharas": "desemalhar",
    "desemalharde": "desemalhar",
    "desemalhardes": "desemalhar",
    "desemalhare": "desemalhar",
    "desemalharei": "desemalhar",
    "desemalhareis": "desemalhar",
    "desemalharem": "desemalhar",
    "desemalharemos": "desemalhar",
    "desemalhares": "desemalhar",
    "desemalharia": "desemalhar",
    "desemalhariam": "desemalhar",
    "desemalharias": "desemalhar",
    "desemalharmo": "desemalhar",
    "desemalharmos": "desemalhar",
    "desemalhará": "desemalhar",
    "desemalharás": "desemalhar",
    "desemalharão": "desemalhar",
    "desemalharíamos": "desemalhar",
    "desemalharíeis": "desemalhar",
    "desemalhas": "desemalhar",
    "desemalhasse": "desemalhar",
    "desemalhassem": "desemalhar",
    "desemalhasses": "desemalhar",
    "desemalhaste": "desemalhar",
    "desemalhastes": "desemalhar",
    "desemalhava": "desemalhar",
    "desemalhavam": "desemalhar",
    "desemalhavas": "desemalhar",
    "desemalhe": "desemalhar",
    "desemalhei": "desemalhar",
    "desemalheis": "desemalhar",
    "desemalhem": "desemalhar",
    "desemalhemo": "desemalhar",
    "desemalhemos": "desemalhar",
    "desemalhes": "desemalhar",
    "desemalho": "desemalhar",
    "desemalhou": "desemalhar",
    "desemalhá": "desemalhar",
    "desemalhámo": "desemalhar",
    "desemalhámos": "desemalhar",
    "desemalháramo": "desemalhar",
    "desemalháramos": "desemalhar",
    "desemalhárei": "desemalhar",
    "desemalháreis": "desemalhar",
    "desemalhásseis": "desemalhar",
    "desemalhássemos": "desemalhar",
    "desemalhávamo": "desemalhar",
    "desemalhávamos": "desemalhar",
    "desemalhávei": "desemalhar",
    "desemalháveis": "desemalhar",
    "desemalo": "desemalar",
    "desemalou": "desemalar",
    "desemalá": "desemalar",
    "desemalámo": "desemalar",
    "desemalámos": "desemalar",
    "desemaláramo": "desemalar",
    "desemaláramos": "desemalar",
    "desemalárei": "desemalar",
    "desemaláreis": "desemalar",
    "desemalásseis": "desemalar",
    "desemalássemos": "desemalar",
    "desemalávamo": "desemalar",
    "desemalávamos": "desemalar",
    "desemalávei": "desemalar",
    "desemaláveis": "desemalar",
    "desemaranha": "desemaranhar",
    "desemaranhada": "desemaranhar",
    "desemaranhadas": "desemaranhar",
    "desemaranhado": "desemaranhar",
    "desemaranhados": "desemaranhar",
    "desemaranhai": "desemaranhar",
    "desemaranhais": "desemaranhar",
    "desemaranham": "desemaranhar",
    "desemaranhamo": "desemaranhar",
    "desemaranhamos": "desemaranhar",
    "desemaranhando": "desemaranhar",
    "desemaranhara": "desemaranhar",
    "desemaranharam": "desemaranhar",
    "desemaranharas": "desemaranhar",
    "desemaranharde": "desemaranhar",
    "desemaranhardes": "desemaranhar",
    "desemaranhare": "desemaranhar",
    "desemaranharei": "desemaranhar",
    "desemaranhareis": "desemaranhar",
    "desemaranharem": "desemaranhar",
    "desemaranharemos": "desemaranhar",
    "desemaranhares": "desemaranhar",
    "desemaranharia": "desemaranhar",
    "desemaranhariam": "desemaranhar",
    "desemaranharias": "desemaranhar",
    "desemaranharmo": "desemaranhar",
    "desemaranharmos": "desemaranhar",
    "desemaranhará": "desemaranhar",
    "desemaranharás": "desemaranhar",
    "desemaranharão": "desemaranhar",
    "desemaranharíamos": "desemaranhar",
    "desemaranharíeis": "desemaranhar",
    "desemaranhas": "desemaranhar",
    "desemaranhasse": "desemaranhar",
    "desemaranhassem": "desemaranhar",
    "desemaranhasses": "desemaranhar",
    "desemaranhaste": "desemaranhar",
    "desemaranhastes": "desemaranhar",
    "desemaranhava": "desemaranhar",
    "desemaranhavam": "desemaranhar",
    "desemaranhavas": "desemaranhar",
    "desemaranhe": "desemaranhar",
    "desemaranhei": "desemaranhar",
    "desemaranheis": "desemaranhar",
    "desemaranhem": "desemaranhar",
    "desemaranhemo": "desemaranhar",
    "desemaranhemos": "desemaranhar",
    "desemaranhes": "desemaranhar",
    "desemaranho": "desemaranhar",
    "desemaranhou": "desemaranhar",
    "desemaranhá": "desemaranhar",
    "desemaranhámo": "desemaranhar",
    "desemaranhámos": "desemaranhar",
    "desemaranháramo": "desemaranhar",
    "desemaranháramos": "desemaranhar",
    "desemaranhárei": "desemaranhar",
    "desemaranháreis": "desemaranhar",
    "desemaranhásseis": "desemaranhar",
    "desemaranhássemos": "desemaranhar",
    "desemaranhávamo": "desemaranhar",
    "desemaranhávamos": "desemaranhar",
    "desemaranhávei": "desemaranhar",
    "desemaranháveis": "desemaranhar",
    "desemaça": "desemaçar",
    "desemaçada": "desemaçar",
    "desemaçadas": "desemaçar",
    "desemaçado": "desemaçar",
    "desemaçados": "desemaçar",
    "desemaçai": "desemaçar",
    "desemaçais": "desemaçar",
    "desemaçam": "desemaçar",
    "desemaçamo": "desemaçar",
    "desemaçamos": "desemaçar",
    "desemaçando": "desemaçar",
    "desemaçara": "desemaçar",
    "desemaçaram": "desemaçar",
    "desemaçaras": "desemaçar",
    "desemaçarde": "desemaçar",
    "desemaçardes": "desemaçar",
    "desemaçare": "desemaçar",
    "desemaçarei": "desemaçar",
    "desemaçareis": "desemaçar",
    "desemaçarem": "desemaçar",
    "desemaçaremos": "desemaçar",
    "desemaçares": "desemaçar",
    "desemaçaria": "desemaçar",
    "desemaçariam": "desemaçar",
    "desemaçarias": "desemaçar",
    "desemaçarmo": "desemaçar",
    "desemaçarmos": "desemaçar",
    "desemaçará": "desemaçar",
    "desemaçarás": "desemaçar",
    "desemaçarão": "desemaçar",
    "desemaçaríamos": "desemaçar",
    "desemaçaríeis": "desemaçar",
    "desemaças": "desemaçar",
    "desemaçasse": "desemaçar",
    "desemaçassem": "desemaçar",
    "desemaçasses": "desemaçar",
    "desemaçaste": "desemaçar",
    "desemaçastes": "desemaçar",
    "desemaçava": "desemaçar",
    "desemaçavam": "desemaçar",
    "desemaçavas": "desemaçar",
    "desemaço": "desemaçar",
    "desemaçou": "desemaçar",
    "desemaçá": "desemaçar",
    "desemaçámo": "desemaçar",
    "desemaçámos": "desemaçar",
    "desemaçáramo": "desemaçar",
    "desemaçáramos": "desemaçar",
    "desemaçárei": "desemaçar",
    "desemaçáreis": "desemaçar",
    "desemaçásseis": "desemaçar",
    "desemaçássemos": "desemaçar",
    "desemaçávamo": "desemaçar",
    "desemaçávamos": "desemaçar",
    "desemaçávei": "desemaçar",
    "desemaçáveis": "desemaçar",
    "desembace": "desembaçar",
    "desembacei": "desembaçar",
    "desembaceis": "desembaçar",
    "desembacem": "desembaçar",
    "desembacemo": "desembaçar",
    "desembacemos": "desembaçar",
    "desembaces": "desembaçar",
    "desembacia": "desembaciar",
    "desembaciada": "desembaciar",
    "desembaciadas": "desembaciar",
    "desembaciado": "desembaciar",
    "desembaciados": "desembaciar",
    "desembaciai": "desembaciar",
    "desembaciais": "desembaciar",
    "desembaciam": "desembaciar",
    "desembaciamentos": "desembaciamento",
    "desembaciamo": "desembaciar",
    "desembaciamos": "desembaciar",
    "desembaciando": "desembaciar",
    "desembaciara": "desembaciar",
    "desembaciaram": "desembaciar",
    "desembaciaras": "desembaciar",
    "desembaciarde": "desembaciar",
    "desembaciardes": "desembaciar",
    "desembaciare": "desembaciar",
    "desembaciarei": "desembaciar",
    "desembaciareis": "desembaciar",
    "desembaciarem": "desembaciar",
    "desembaciaremos": "desembaciar",
    "desembaciares": "desembaciar",
    "desembaciaria": "desembaciar",
    "desembaciariam": "desembaciar",
    "desembaciarias": "desembaciar",
    "desembaciarmo": "desembaciar",
    "desembaciarmos": "desembaciar",
    "desembaciará": "desembaciar",
    "desembaciarás": "desembaciar",
    "desembaciarão": "desembaciar",
    "desembaciaríamos": "desembaciar",
    "desembaciaríeis": "desembaciar",
    "desembacias": "desembaciar",
    "desembaciasse": "desembaciar",
    "desembaciassem": "desembaciar",
    "desembaciasses": "desembaciar",
    "desembaciaste": "desembaciar",
    "desembaciastes": "desembaciar",
    "desembaciava": "desembaciar",
    "desembaciavam": "desembaciar",
    "desembaciavas": "desembaciar",
    "desembacie": "desembaciar",
    "desembaciei": "desembaciar",
    "desembacieis": "desembaciar",
    "desembaciem": "desembaciar",
    "desembaciemo": "desembaciar",
    "desembaciemos": "desembaciar",
    "desembacies": "desembaciar",
    "desembacio": "desembaciar",
    "desembaciou": "desembaciar",
    "desembaciá": "desembaciar",
    "desembaciámo": "desembaciar",
    "desembaciámos": "desembaciar",
    "desembaciáramo": "desembaciar",
    "desembaciáramos": "desembaciar",
    "desembaciárei": "desembaciar",
    "desembaciáreis": "desembaciar",
    "desembaciásseis": "desembaciar",
    "desembaciássemos": "desembaciar",
    "desembaciávamo": "desembaciar",
    "desembaciávamos": "desembaciar",
    "desembaciávei": "desembaciar",
    "desembaciáveis": "desembaciável",
    "desembainha": "desembainhar",
    "desembainhada": "desembainhar",
    "desembainhadas": "desembainhar",
    "desembainhado": "desembainhar",
    "desembainhados": "desembainhar",
    "desembainhai": "desembainhar",
    "desembainhais": "desembainhar",
    "desembainham": "desembainhar",
    "desembainhamo": "desembainhar",
    "desembainhamos": "desembainhar",
    "desembainhando": "desembainhar",
    "desembainhara": "desembainhar",
    "desembainharam": "desembainhar",
    "desembainharas": "desembainhar",
    "desembainharde": "desembainhar",
    "desembainhardes": "desembainhar",
    "desembainhare": "desembainhar",
    "desembainharei": "desembainhar",
    "desembainhareis": "desembainhar",
    "desembainharem": "desembainhar",
    "desembainharemos": "desembainhar",
    "desembainhares": "desembainhar",
    "desembainharia": "desembainhar",
    "desembainhariam": "desembainhar",
    "desembainharias": "desembainhar",
    "desembainharmo": "desembainhar",
    "desembainharmos": "desembainhar",
    "desembainhará": "desembainhar",
    "desembainharás": "desembainhar",
    "desembainharão": "desembainhar",
    "desembainharíamos": "desembainhar",
    "desembainharíeis": "desembainhar",
    "desembainhas": "desembainhar",
    "desembainhasse": "desembainhar",
    "desembainhassem": "desembainhar",
    "desembainhasses": "desembainhar",
    "desembainhaste": "desembainhar",
    "desembainhastes": "desembainhar",
    "desembainhava": "desembainhar",
    "desembainhavam": "desembainhar",
    "desembainhavas": "desembainhar",
    "desembainhe": "desembainhar",
    "desembainhei": "desembainhar",
    "desembainheis": "desembainhar",
    "desembainhem": "desembainhar",
    "desembainhemo": "desembainhar",
    "desembainhemos": "desembainhar",
    "desembainhes": "desembainhar",
    "desembainho": "desembainhar",
    "desembainhou": "desembainhar",
    "desembainhá": "desembainhar",
    "desembainhámo": "desembainhar",
    "desembainhámos": "desembainhar",
    "desembainháramo": "desembainhar",
    "desembainháramos": "desembainhar",
    "desembainhárei": "desembainhar",
    "desembainháreis": "desembainhar",
    "desembainhásseis": "desembainhar",
    "desembainhássemos": "desembainhar",
    "desembainhávamo": "desembainhar",
    "desembainhávamos": "desembainhar",
    "desembainhávei": "desembainhar",
    "desembainháveis": "desembainhar",
    "desembala": "desembalar",
    "desembalada": "desembalar",
    "desembaladas": "desembalar",
    "desembalado": "desembalar",
    "desembalados": "desembalar",
    "desembalai": "desembalar",
    "desembalais": "desembalar",
    "desembalam": "desembalar",
    "desembalamo": "desembalar",
    "desembalamos": "desembalar",
    "desembalando": "desembalar",
    "desembalara": "desembalar",
    "desembalaram": "desembalar",
    "desembalaras": "desembalar",
    "desembalarde": "desembalar",
    "desembalardes": "desembalar",
    "desembalare": "desembalar",
    "desembalarei": "desembalar",
    "desembalareis": "desembalar",
    "desembalarem": "desembalar",
    "desembalaremos": "desembalar",
    "desembalares": "desembalar",
    "desembalaria": "desembalar",
    "desembalariam": "desembalar",
    "desembalarias": "desembalar",
    "desembalarmo": "desembalar",
    "desembalarmos": "desembalar",
    "desembalará": "desembalar",
    "desembalarás": "desembalar",
    "desembalarão": "desembalar",
    "desembalaríamos": "desembalar",
    "desembalaríeis": "desembalar",
    "desembalas": "desembalar",
    "desembalasse": "desembalar",
    "desembalassem": "desembalar",
    "desembalasses": "desembalar",
    "desembalaste": "desembalar",
    "desembalastes": "desembalar",
    "desembalava": "desembalar",
    "desembalavam": "desembalar",
    "desembalavas": "desembalar",
    "desembale": "desembalar",
    "desembalei": "desembalar",
    "desembaleis": "desembalar",
    "desembalem": "desembalar",
    "desembalemo": "desembalar",
    "desembalemos": "desembalar",
    "desembales": "desembalar",
    "desembalo": "desembalar",
    "desembalou": "desembalar",
    "desembalsa": "desembalsar",
    "desembalsada": "desembalsar",
    "desembalsadas": "desembalsar",
    "desembalsado": "desembalsar",
    "desembalsados": "desembalsar",
    "desembalsai": "desembalsar",
    "desembalsais": "desembalsar",
    "desembalsam": "desembalsar",
    "desembalsamo": "desembalsar",
    "desembalsamos": "desembalsar",
    "desembalsando": "desembalsar",
    "desembalsara": "desembalsar",
    "desembalsaram": "desembalsar",
    "desembalsaras": "desembalsar",
    "desembalsarde": "desembalsar",
    "desembalsardes": "desembalsar",
    "desembalsare": "desembalsar",
    "desembalsarei": "desembalsar",
    "desembalsareis": "desembalsar",
    "desembalsarem": "desembalsar",
    "desembalsaremos": "desembalsar",
    "desembalsares": "desembalsar",
    "desembalsaria": "desembalsar",
    "desembalsariam": "desembalsar",
    "desembalsarias": "desembalsar",
    "desembalsarmo": "desembalsar",
    "desembalsarmos": "desembalsar",
    "desembalsará": "desembalsar",
    "desembalsarás": "desembalsar",
    "desembalsarão": "desembalsar",
    "desembalsaríamos": "desembalsar",
    "desembalsaríeis": "desembalsar",
    "desembalsas": "desembalsar",
    "desembalsasse": "desembalsar",
    "desembalsassem": "desembalsar",
    "desembalsasses": "desembalsar",
    "desembalsaste": "desembalsar",
    "desembalsastes": "desembalsar",
    "desembalsava": "desembalsar",
    "desembalsavam": "desembalsar",
    "desembalsavas": "desembalsar",
    "desembalse": "desembalsar",
    "desembalsei": "desembalsar",
    "desembalseis": "desembalsar",
    "desembalsem": "desembalsar",
    "desembalsemo": "desembalsar",
    "desembalsemos": "desembalsar",
    "desembalses": "desembalsar",
    "desembalso": "desembalsar",
    "desembalsou": "desembalsar",
    "desembalsá": "desembalsar",
    "desembalsámo": "desembalsar",
    "desembalsámos": "desembalsar",
    "desembalsáramo": "desembalsar",
    "desembalsáramos": "desembalsar",
    "desembalsárei": "desembalsar",
    "desembalsáreis": "desembalsar",
    "desembalsásseis": "desembalsar",
    "desembalsássemos": "desembalsar",
    "desembalsávamo": "desembalsar",
    "desembalsávamos": "desembalsar",
    "desembalsávei": "desembalsar",
    "desembalsáveis": "desembalsar",
    "desembalá": "desembalar",
    "desembalámo": "desembalar",
    "desembalámos": "desembalar",
    "desembaláramo": "desembalar",
    "desembaláramos": "desembalar",
    "desembalárei": "desembalar",
    "desembaláreis": "desembalar",
    "desembalásseis": "desembalar",
    "desembalássemos": "desembalar",
    "desembalávamo": "desembalar",
    "desembalávamos": "desembalar",
    "desembalávei": "desembalar",
    "desembaláveis": "desembalar",
    "desembandeira": "desembandeirar",
    "desembandeirada": "desembandeirar",
    "desembandeiradas": "desembandeirar",
    "desembandeirado": "desembandeirar",
    "desembandeirados": "desembandeirar",
    "desembandeirai": "desembandeirar",
    "desembandeirais": "desembandeirar",
    "desembandeiram": "desembandeirar",
    "desembandeiramo": "desembandeirar",
    "desembandeiramos": "desembandeirar",
    "desembandeirando": "desembandeirar",
    "desembandeirara": "desembandeirar",
    "desembandeiraram": "desembandeirar",
    "desembandeiraras": "desembandeirar",
    "desembandeirarde": "desembandeirar",
    "desembandeirardes": "desembandeirar",
    "desembandeirare": "desembandeirar",
    "desembandeirarei": "desembandeirar",
    "desembandeirareis": "desembandeirar",
    "desembandeirarem": "desembandeirar",
    "desembandeiraremos": "desembandeirar",
    "desembandeirares": "desembandeirar",
    "desembandeiraria": "desembandeirar",
    "desembandeirariam": "desembandeirar",
    "desembandeirarias": "desembandeirar",
    "desembandeirarmo": "desembandeirar",
    "desembandeirarmos": "desembandeirar",
    "desembandeirará": "desembandeirar",
    "desembandeirarás": "desembandeirar",
    "desembandeirarão": "desembandeirar",
    "desembandeiraríamos": "desembandeirar",
    "desembandeiraríeis": "desembandeirar",
    "desembandeiras": "desembandeirar",
    "desembandeirasse": "desembandeirar",
    "desembandeirassem": "desembandeirar",
    "desembandeirasses": "desembandeirar",
    "desembandeiraste": "desembandeirar",
    "desembandeirastes": "desembandeirar",
    "desembandeirava": "desembandeirar",
    "desembandeiravam": "desembandeirar",
    "desembandeiravas": "desembandeirar",
    "desembandeire": "desembandeirar",
    "desembandeirei": "desembandeirar",
    "desembandeireis": "desembandeirar",
    "desembandeirem": "desembandeirar",
    "desembandeiremo": "desembandeirar",
    "desembandeiremos": "desembandeirar",
    "desembandeires": "desembandeirar",
    "desembandeiro": "desembandeirar",
    "desembandeirou": "desembandeirar",
    "desembandeirá": "desembandeirar",
    "desembandeirámo": "desembandeirar",
    "desembandeirámos": "desembandeirar",
    "desembandeiráramo": "desembandeirar",
    "desembandeiráramos": "desembandeirar",
    "desembandeirárei": "desembandeirar",
    "desembandeiráreis": "desembandeirar",
    "desembandeirásseis": "desembandeirar",
    "desembandeirássemos": "desembandeirar",
    "desembandeirávamo": "desembandeirar",
    "desembandeirávamos": "desembandeirar",
    "desembandeirávei": "desembandeirar",
    "desembandeiráveis": "desembandeirar",
    "desembarace": "desembaraçar",
    "desembaracei": "desembaraçar",
    "desembaraceis": "desembaraçar",
    "desembaracem": "desembaraçar",
    "desembaracemo": "desembaraçar",
    "desembaracemos": "desembaraçar",
    "desembaraces": "desembaraçar",
    "desembaralha": "desembaralhar",
    "desembaralhada": "desembaralhar",
    "desembaralhadas": "desembaralhar",
    "desembaralhado": "desembaralhar",
    "desembaralhados": "desembaralhar",
    "desembaralhai": "desembaralhar",
    "desembaralhais": "desembaralhar",
    "desembaralham": "desembaralhar",
    "desembaralhamo": "desembaralhar",
    "desembaralhamos": "desembaralhar",
    "desembaralhando": "desembaralhar",
    "desembaralhara": "desembaralhar",
    "desembaralharam": "desembaralhar",
    "desembaralharas": "desembaralhar",
    "desembaralharde": "desembaralhar",
    "desembaralhardes": "desembaralhar",
    "desembaralhare": "desembaralhar",
    "desembaralharei": "desembaralhar",
    "desembaralhareis": "desembaralhar",
    "desembaralharem": "desembaralhar",
    "desembaralharemos": "desembaralhar",
    "desembaralhares": "desembaralhar",
    "desembaralharia": "desembaralhar",
    "desembaralhariam": "desembaralhar",
    "desembaralharias": "desembaralhar",
    "desembaralharmo": "desembaralhar",
    "desembaralharmos": "desembaralhar",
    "desembaralhará": "desembaralhar",
    "desembaralharás": "desembaralhar",
    "desembaralharão": "desembaralhar",
    "desembaralharíamos": "desembaralhar",
    "desembaralharíeis": "desembaralhar",
    "desembaralhas": "desembaralhar",
    "desembaralhasse": "desembaralhar",
    "desembaralhassem": "desembaralhar",
    "desembaralhasses": "desembaralhar",
    "desembaralhaste": "desembaralhar",
    "desembaralhastes": "desembaralhar",
    "desembaralhava": "desembaralhar",
    "desembaralhavam": "desembaralhar",
    "desembaralhavas": "desembaralhar",
    "desembaralhe": "desembaralhar",
    "desembaralhei": "desembaralhar",
    "desembaralheis": "desembaralhar",
    "desembaralhem": "desembaralhar",
    "desembaralhemo": "desembaralhar",
    "desembaralhemos": "desembaralhar",
    "desembaralhes": "desembaralhar",
    "desembaralho": "desembaralhar",
    "desembaralhou": "desembaralhar",
    "desembaralhá": "desembaralhar",
    "desembaralhámo": "desembaralhar",
    "desembaralhámos": "desembaralhar",
    "desembaralháramo": "desembaralhar",
    "desembaralháramos": "desembaralhar",
    "desembaralhárei": "desembaralhar",
    "desembaralháreis": "desembaralhar",
    "desembaralhásseis": "desembaralhar",
    "desembaralhássemos": "desembaralhar",
    "desembaralhávamo": "desembaralhar",
    "desembaralhávamos": "desembaralhar",
    "desembaralhávei": "desembaralhar",
    "desembaralháveis": "desembaralhar",
    "desembaraça": "desembaraçar",
    "desembaraçada": "desembaraçar",
    "desembaraçadas": "desembaraçar",
    "desembaraçado": "desembaraçar",
    "desembaraçados": "desembaraçar",
    "desembaraçai": "desembaraçar",
    "desembaraçais": "desembaraçar",
    "desembaraçam": "desembaraçar",
    "desembaraçamo": "desembaraçar",
    "desembaraçamos": "desembaraçar",
    "desembaraçando": "desembaraçar",
    "desembaraçara": "desembaraçar",
    "desembaraçaram": "desembaraçar",
    "desembaraçaras": "desembaraçar",
    "desembaraçarde": "desembaraçar",
    "desembaraçardes": "desembaraçar",
    "desembaraçare": "desembaraçar",
    "desembaraçarei": "desembaraçar",
    "desembaraçareis": "desembaraçar",
    "desembaraçarem": "desembaraçar",
    "desembaraçaremos": "desembaraçar",
    "desembaraçares": "desembaraçar",
    "desembaraçaria": "desembaraçar",
    "desembaraçariam": "desembaraçar",
    "desembaraçarias": "desembaraçar",
    "desembaraçarmo": "desembaraçar",
    "desembaraçarmos": "desembaraçar",
    "desembaraçará": "desembaraçar",
    "desembaraçarás": "desembaraçar",
    "desembaraçarão": "desembaraçar",
    "desembaraçaríamos": "desembaraçar",
    "desembaraçaríeis": "desembaraçar",
    "desembaraças": "desembaraçar",
    "desembaraçasse": "desembaraçar",
    "desembaraçassem": "desembaraçar",
    "desembaraçasses": "desembaraçar",
    "desembaraçaste": "desembaraçar",
    "desembaraçastes": "desembaraçar",
    "desembaraçava": "desembaraçar",
    "desembaraçavam": "desembaraçar",
    "desembaraçavas": "desembaraçar",
    "desembaraço": "desembaraçar",
    "desembaraços": "desembaraço",
    "desembaraçou": "desembaraçar",
    "desembaraçá": "desembaraçar",
    "desembaraçámo": "desembaraçar",
    "desembaraçámos": "desembaraçar",
    "desembaraçáramo": "desembaraçar",
    "desembaraçáramos": "desembaraçar",
    "desembaraçárei": "desembaraçar",
    "desembaraçáreis": "desembaraçar",
    "desembaraçásseis": "desembaraçar",
    "desembaraçássemos": "desembaraçar",
    "desembaraçávamo": "desembaraçar",
    "desembaraçávamos": "desembaraçar",
    "desembaraçávei": "desembaraçar",
    "desembaraçáveis": "desembaraçável",
    "desembarca": "desembarcar",
    "desembarcada": "desembarcar",
    "desembarcadas": "desembarcar",
    "desembarcado": "desembarcar",
    "desembarcadoiros": "desembarcadoiro",
    "desembarcados": "desembarcar",
    "desembarcadouros": "desembarcadouro",
    "desembarcai": "desembarcar",
    "desembarcais": "desembarcar",
    "desembarcam": "desembarcar",
    "desembarcamo": "desembarcar",
    "desembarcamos": "desembarcar",
    "desembarcando": "desembarcar",
    "desembarcara": "desembarcar",
    "desembarcaram": "desembarcar",
    "desembarcaras": "desembarcar",
    "desembarcarde": "desembarcar",
    "desembarcardes": "desembarcar",
    "desembarcare": "desembarcar",
    "desembarcarei": "desembarcar",
    "desembarcareis": "desembarcar",
    "desembarcarem": "desembarcar",
    "desembarcaremos": "desembarcar",
    "desembarcares": "desembarcar",
    "desembarcaria": "desembarcar",
    "desembarcariam": "desembarcar",
    "desembarcarias": "desembarcar",
    "desembarcarmo": "desembarcar",
    "desembarcarmos": "desembarcar",
    "desembarcará": "desembarcar",
    "desembarcarás": "desembarcar",
    "desembarcarão": "desembarcar",
    "desembarcaríamos": "desembarcar",
    "desembarcaríeis": "desembarcar",
    "desembarcas": "desembarcar",
    "desembarcasse": "desembarcar",
    "desembarcassem": "desembarcar",
    "desembarcasses": "desembarcar",
    "desembarcaste": "desembarcar",
    "desembarcastes": "desembarcar",
    "desembarcava": "desembarcar",
    "desembarcavam": "desembarcar",
    "desembarcavas": "desembarcar",
    "desembarco": "desembarcar",
    "desembarcou": "desembarcar",
    "desembarcá": "desembarcar",
    "desembarcámo": "desembarcar",
    "desembarcámos": "desembarcar",
    "desembarcáramo": "desembarcar",
    "desembarcáramos": "desembarcar",
    "desembarcárei": "desembarcar",
    "desembarcáreis": "desembarcar",
    "desembarcásseis": "desembarcar",
    "desembarcássemos": "desembarcar",
    "desembarcávamo": "desembarcar",
    "desembarcávamos": "desembarcar",
    "desembarcávei": "desembarcar",
    "desembarcáveis": "desembarcável",
    "desembarga": "desembargar",
    "desembargada": "desembargar",
    "desembargadas": "desembargar",
    "desembargado": "desembargar",
    "desembargadora": "desembargador",
    "desembargadoras": "desembargador",
    "desembargadores": "desembargador",
    "desembargados": "desembargar",
    "desembargai": "desembargar",
    "desembargais": "desembargar",
    "desembargam": "desembargar",
    "desembargamo": "desembargar",
    "desembargamos": "desembargar",
    "desembargando": "desembargar",
    "desembargara": "desembargar",
    "desembargaram": "desembargar",
    "desembargaras": "desembargar",
    "desembargarde": "desembargar",
    "desembargardes": "desembargar",
    "desembargare": "desembargar",
    "desembargarei": "desembargar",
    "desembargareis": "desembargar",
    "desembargarem": "desembargar",
    "desembargaremos": "desembargar",
    "desembargares": "desembargar",
    "desembargaria": "desembargar",
    "desembargariam": "desembargar",
    "desembargarias": "desembargar",
    "desembargarmo": "desembargar",
    "desembargarmos": "desembargar",
    "desembargará": "desembargar",
    "desembargarás": "desembargar",
    "desembargarão": "desembargar",
    "desembargaríamos": "desembargar",
    "desembargaríeis": "desembargar",
    "desembargas": "desembargar",
    "desembargasse": "desembargar",
    "desembargassem": "desembargar",
    "desembargasses": "desembargar",
    "desembargaste": "desembargar",
    "desembargastes": "desembargar",
    "desembargatória": "desembargatório",
    "desembargatórias": "desembargatório",
    "desembargatórios": "desembargatório",
    "desembargava": "desembargar",
    "desembargavam": "desembargar",
    "desembargavas": "desembargar",
    "desembargo": "desembargar",
    "desembargos": "desembargo",
    "desembargou": "desembargar",
    "desembargue": "desembargar",
    "desembarguei": "desembargar",
    "desembargueis": "desembargar",
    "desembarguem": "desembargar",
    "desembarguemo": "desembargar",
    "desembarguemos": "desembargar",
    "desembargues": "desembargar",
    "desembargá": "desembargar",
    "desembargámo": "desembargar",
    "desembargámos": "desembargar",
    "desembargáramo": "desembargar",
    "desembargáramos": "desembargar",
    "desembargárei": "desembargar",
    "desembargáreis": "desembargar",
    "desembargásseis": "desembargar",
    "desembargássemos": "desembargar",
    "desembargávamo": "desembargar",
    "desembargávamos": "desembargar",
    "desembargávei": "desembargar",
    "desembargáveis": "desembargável",
    "desembarque": "desembarcar",
    "desembarquei": "desembarcar",
    "desembarqueis": "desembarcar",
    "desembarquem": "desembarcar",
    "desembarquemo": "desembarcar",
    "desembarquemos": "desembarcar",
    "desembarques": "desembarque",
    "desembarrila": "desembarrilar",
    "desembarrilada": "desembarrilar",
    "desembarriladas": "desembarrilar",
    "desembarrilado": "desembarrilar",
    "desembarrilados": "desembarrilar",
    "desembarrilai": "desembarrilar",
    "desembarrilais": "desembarrilar",
    "desembarrilam": "desembarrilar",
    "desembarrilamo": "desembarrilar",
    "desembarrilamos": "desembarrilar",
    "desembarrilando": "desembarrilar",
    "desembarrilara": "desembarrilar",
    "desembarrilaram": "desembarrilar",
    "desembarrilaras": "desembarrilar",
    "desembarrilarde": "desembarrilar",
    "desembarrilardes": "desembarrilar",
    "desembarrilare": "desembarrilar",
    "desembarrilarei": "desembarrilar",
    "desembarrilareis": "desembarrilar",
    "desembarrilarem": "desembarrilar",
    "desembarrilaremos": "desembarrilar",
    "desembarrilares": "desembarrilar",
    "desembarrilaria": "desembarrilar",
    "desembarrilariam": "desembarrilar",
    "desembarrilarias": "desembarrilar",
    "desembarrilarmo": "desembarrilar",
    "desembarrilarmos": "desembarrilar",
    "desembarrilará": "desembarrilar",
    "desembarrilarás": "desembarrilar",
    "desembarrilarão": "desembarrilar",
    "desembarrilaríamos": "desembarrilar",
    "desembarrilaríeis": "desembarrilar",
    "desembarrilas": "desembarrilar",
    "desembarrilasse": "desembarrilar",
    "desembarrilassem": "desembarrilar",
    "desembarrilasses": "desembarrilar",
    "desembarrilaste": "desembarrilar",
    "desembarrilastes": "desembarrilar",
    "desembarrilava": "desembarrilar",
    "desembarrilavam": "desembarrilar",
    "desembarrilavas": "desembarrilar",
    "desembarrile": "desembarrilar",
    "desembarrilei": "desembarrilar",
    "desembarrileis": "desembarrilar",
    "desembarrilem": "desembarrilar",
    "desembarrilemo": "desembarrilar",
    "desembarrilemos": "desembarrilar",
    "desembarriles": "desembarrilar",
    "desembarrilo": "desembarrilar",
    "desembarrilou": "desembarrilar",
    "desembarrilá": "desembarrilar",
    "desembarrilámo": "desembarrilar",
    "desembarrilámos": "desembarrilar",
    "desembarriláramo": "desembarrilar",
    "desembarriláramos": "desembarrilar",
    "desembarrilárei": "desembarrilar",
    "desembarriláreis": "desembarrilar",
    "desembarrilásseis": "desembarrilar",
    "desembarrilássemos": "desembarrilar",
    "desembarrilávamo": "desembarrilar",
    "desembarrilávamos": "desembarrilar",
    "desembarrilávei": "desembarrilar",
    "desembarriláveis": "desembarrilar",
    "desembaça": "desembaçar",
    "desembaçada": "desembaçar",
    "desembaçadas": "desembaçar",
    "desembaçado": "desembaçar",
    "desembaçados": "desembaçar",
    "desembaçai": "desembaçar",
    "desembaçais": "desembaçar",
    "desembaçam": "desembaçar",
    "desembaçamo": "desembaçar",
    "desembaçamos": "desembaçar",
    "desembaçando": "desembaçar",
    "desembaçara": "desembaçar",
    "desembaçaram": "desembaçar",
    "desembaçaras": "desembaçar",
    "desembaçarde": "desembaçar",
    "desembaçardes": "desembaçar",
    "desembaçare": "desembaçar",
    "desembaçarei": "desembaçar",
    "desembaçareis": "desembaçar",
    "desembaçarem": "desembaçar",
    "desembaçaremos": "desembaçar",
    "desembaçares": "desembaçar",
    "desembaçaria": "desembaçar",
    "desembaçariam": "desembaçar",
    "desembaçarias": "desembaçar",
    "desembaçarmo": "desembaçar",
    "desembaçarmos": "desembaçar",
    "desembaçará": "desembaçar",
    "desembaçarás": "desembaçar",
    "desembaçarão": "desembaçar",
    "desembaçaríamos": "desembaçar",
    "desembaçaríeis": "desembaçar",
    "desembaças": "desembaçar",
    "desembaçasse": "desembaçar",
    "desembaçassem": "desembaçar",
    "desembaçasses": "desembaçar",
    "desembaçaste": "desembaçar",
    "desembaçastes": "desembaçar",
    "desembaçava": "desembaçar",
    "desembaçavam": "desembaçar",
    "desembaçavas": "desembaçar",
    "desembaço": "desembaçar",
    "desembaçou": "desembaçar",
    "desembaçá": "desembaçar",
    "desembaçámo": "desembaçar",
    "desembaçámos": "desembaçar",
    "desembaçáramo": "desembaçar",
    "desembaçáramos": "desembaçar",
    "desembaçárei": "desembaçar",
    "desembaçáreis": "desembaçar",
    "desembaçásseis": "desembaçar",
    "desembaçássemos": "desembaçar",
    "desembaçávamo": "desembaçar",
    "desembaçávamos": "desembaçar",
    "desembaçávei": "desembaçar",
    "desembaçáveis": "desembaçar",
    "desembebeda": "desembebedar",
    "desembebedada": "desembebedar",
    "desembebedadas": "desembebedar",
    "desembebedado": "desembebedar",
    "desembebedados": "desembebedar",
    "desembebedai": "desembebedar",
    "desembebedais": "desembebedar",
    "desembebedam": "desembebedar",
    "desembebedamo": "desembebedar",
    "desembebedamos": "desembebedar",
    "desembebedando": "desembebedar",
    "desembebedara": "desembebedar",
    "desembebedaram": "desembebedar",
    "desembebedaras": "desembebedar",
    "desembebedarde": "desembebedar",
    "desembebedardes": "desembebedar",
    "desembebedare": "desembebedar",
    "desembebedarei": "desembebedar",
    "desembebedareis": "desembebedar",
    "desembebedarem": "desembebedar",
    "desembebedaremos": "desembebedar",
    "desembebedares": "desembebedar",
    "desembebedaria": "desembebedar",
    "desembebedariam": "desembebedar",
    "desembebedarias": "desembebedar",
    "desembebedarmo": "desembebedar",
    "desembebedarmos": "desembebedar",
    "desembebedará": "desembebedar",
    "desembebedarás": "desembebedar",
    "desembebedarão": "desembebedar",
    "desembebedaríamos": "desembebedar",
    "desembebedaríeis": "desembebedar",
    "desembebedas": "desembebedar",
    "desembebedasse": "desembebedar",
    "desembebedassem": "desembebedar",
    "desembebedasses": "desembebedar",
    "desembebedaste": "desembebedar",
    "desembebedastes": "desembebedar",
    "desembebedava": "desembebedar",
    "desembebedavam": "desembebedar",
    "desembebedavas": "desembebedar",
    "desembebede": "desembebedar",
    "desembebedei": "desembebedar",
    "desembebedeis": "desembebedar",
    "desembebedem": "desembebedar",
    "desembebedemo": "desembebedar",
    "desembebedemos": "desembebedar",
    "desembebedes": "desembebedar",
    "desembebedo": "desembebedar",
    "desembebedou": "desembebedar",
    "desembebedá": "desembebedar",
    "desembebedámo": "desembebedar",
    "desembebedámos": "desembebedar",
    "desembebedáramo": "desembebedar",
    "desembebedáramos": "desembebedar",
    "desembebedárei": "desembebedar",
    "desembebedáreis": "desembebedar",
    "desembebedásseis": "desembebedar",
    "desembebedássemos": "desembebedar",
    "desembebedávamo": "desembebedar",
    "desembebedávamos": "desembebedar",
    "desembebedávei": "desembebedar",
    "desembebedáveis": "desembebedar",
    "desembesta": "desembestar",
    "desembestada": "desembestar",
    "desembestadas": "desembestar",
    "desembestado": "desembestar",
    "desembestados": "desembestar",
    "desembestai": "desembestar",
    "desembestais": "desembestar",
    "desembestam": "desembestar",
    "desembestamo": "desembestar",
    "desembestamos": "desembestar",
    "desembestando": "desembestar",
    "desembestara": "desembestar",
    "desembestaram": "desembestar",
    "desembestaras": "desembestar",
    "desembestarde": "desembestar",
    "desembestardes": "desembestar",
    "desembestare": "desembestar",
    "desembestarei": "desembestar",
    "desembestareis": "desembestar",
    "desembestarem": "desembestar",
    "desembestaremos": "desembestar",
    "desembestares": "desembestar",
    "desembestaria": "desembestar",
    "desembestariam": "desembestar",
    "desembestarias": "desembestar",
    "desembestarmo": "desembestar",
    "desembestarmos": "desembestar",
    "desembestará": "desembestar",
    "desembestarás": "desembestar",
    "desembestarão": "desembestar",
    "desembestaríamos": "desembestar",
    "desembestaríeis": "desembestar",
    "desembestas": "desembestar",
    "desembestasse": "desembestar",
    "desembestassem": "desembestar",
    "desembestasses": "desembestar",
    "desembestaste": "desembestar",
    "desembestastes": "desembestar",
    "desembestava": "desembestar",
    "desembestavam": "desembestar",
    "desembestavas": "desembestar",
    "desembeste": "desembestar",
    "desembestei": "desembestar",
    "desembesteis": "desembestar",
    "desembestem": "desembestar",
    "desembestemo": "desembestar",
    "desembestemos": "desembestar",
    "desembestes": "desembestar",
    "desembesto": "desembestar",
    "desembestou": "desembestar",
    "desembestá": "desembestar",
    "desembestámo": "desembestar",
    "desembestámos": "desembestar",
    "desembestáramo": "desembestar",
    "desembestáramos": "desembestar",
    "desembestárei": "desembestar",
    "desembestáreis": "desembestar",
    "desembestásseis": "desembestar",
    "desembestássemos": "desembestar",
    "desembestávamo": "desembestar",
    "desembestávamos": "desembestar",
    "desembestávei": "desembestar",
    "desembestáveis": "desembestar",
    "desembezerra": "desembezerrar",
    "desembezerrada": "desembezerrar",
    "desembezerradas": "desembezerrar",
    "desembezerrado": "desembezerrar",
    "desembezerrados": "desembezerrar",
    "desembezerrai": "desembezerrar",
    "desembezerrais": "desembezerrar",
    "desembezerram": "desembezerrar",
    "desembezerramo": "desembezerrar",
    "desembezerramos": "desembezerrar",
    "desembezerrando": "desembezerrar",
    "desembezerrara": "desembezerrar",
    "desembezerraram": "desembezerrar",
    "desembezerraras": "desembezerrar",
    "desembezerrardes": "desembezerrar",
    "desembezerrarei": "desembezerrar",
    "desembezerrareis": "desembezerrar",
    "desembezerrarem": "desembezerrar",
    "desembezerraremos": "desembezerrar",
    "desembezerrares": "desembezerrar",
    "desembezerraria": "desembezerrar",
    "desembezerrariam": "desembezerrar",
    "desembezerrarias": "desembezerrar",
    "desembezerrarmo": "desembezerrar",
    "desembezerrarmos": "desembezerrar",
    "desembezerrará": "desembezerrar",
    "desembezerrarás": "desembezerrar",
    "desembezerrarão": "desembezerrar",
    "desembezerraríamos": "desembezerrar",
    "desembezerraríeis": "desembezerrar",
    "desembezerras": "desembezerrar",
    "desembezerrasse": "desembezerrar",
    "desembezerrassem": "desembezerrar",
    "desembezerrasses": "desembezerrar",
    "desembezerraste": "desembezerrar",
    "desembezerrastes": "desembezerrar",
    "desembezerrava": "desembezerrar",
    "desembezerravam": "desembezerrar",
    "desembezerravas": "desembezerrar",
    "desembezerre": "desembezerrar",
    "desembezerrei": "desembezerrar",
    "desembezerreis": "desembezerrar",
    "desembezerrem": "desembezerrar",
    "desembezerremo": "desembezerrar",
    "desembezerremos": "desembezerrar",
    "desembezerres": "desembezerrar",
    "desembezerro": "desembezerrar",
    "desembezerrou": "desembezerrar",
    "desembezerrámo": "desembezerrar",
    "desembezerrámos": "desembezerrar",
    "desembezerráramo": "desembezerrar",
    "desembezerráramos": "desembezerrar",
    "desembezerráreis": "desembezerrar",
    "desembezerrásseis": "desembezerrar",
    "desembezerrássemos": "desembezerrar",
    "desembezerrávamo": "desembezerrar",
    "desembezerrávamos": "desembezerrar",
    "desembezerráveis": "desembezerrar",
    "desembirra": "desembirrar",
    "desembirrada": "desembirrar",
    "desembirradas": "desembirrar",
    "desembirrado": "desembirrar",
    "desembirrados": "desembirrar",
    "desembirrai": "desembirrar",
    "desembirrais": "desembirrar",
    "desembirram": "desembirrar",
    "desembirramo": "desembirrar",
    "desembirramos": "desembirrar",
    "desembirrando": "desembirrar",
    "desembirrara": "desembirrar",
    "desembirraram": "desembirrar",
    "desembirraras": "desembirrar",
    "desembirrardes": "desembirrar",
    "desembirrarei": "desembirrar",
    "desembirrareis": "desembirrar",
    "desembirrarem": "desembirrar",
    "desembirraremos": "desembirrar",
    "desembirrares": "desembirrar",
    "desembirraria": "desembirrar",
    "desembirrariam": "desembirrar",
    "desembirrarias": "desembirrar",
    "desembirrarmo": "desembirrar",
    "desembirrarmos": "desembirrar",
    "desembirrará": "desembirrar",
    "desembirrarás": "desembirrar",
    "desembirrarão": "desembirrar",
    "desembirraríamos": "desembirrar",
    "desembirraríeis": "desembirrar",
    "desembirras": "desembirrar",
    "desembirrasse": "desembirrar",
    "desembirrassem": "desembirrar",
    "desembirrasses": "desembirrar",
    "desembirraste": "desembirrar",
    "desembirrastes": "desembirrar",
    "desembirrava": "desembirrar",
    "desembirravam": "desembirrar",
    "desembirravas": "desembirrar",
    "desembirre": "desembirrar",
    "desembirrei": "desembirrar",
    "desembirreis": "desembirrar",
    "desembirrem": "desembirrar",
    "desembirremo": "desembirrar",
    "desembirremos": "desembirrar",
    "desembirres": "desembirrar",
    "desembirro": "desembirrar",
    "desembirrou": "desembirrar",
    "desembirrámo": "desembirrar",
    "desembirrámos": "desembirrar",
    "desembirráramo": "desembirrar",
    "desembirráramos": "desembirrar",
    "desembirráreis": "desembirrar",
    "desembirrásseis": "desembirrar",
    "desembirrássemos": "desembirrar",
    "desembirrávamo": "desembirrar",
    "desembirrávamos": "desembirrar",
    "desembirráveis": "desembirrar",
    "desemboca": "desembocar",
    "desembocada": "desembocar",
    "desembocadas": "desembocar",
    "desembocado": "desembocar",
    "desembocados": "desembocar",
    "desembocaduras": "desembocadura",
    "desembocais": "desembocar",
    "desembocam": "desembocar",
    "desembocamo": "desembocar",
    "desembocamos": "desembocar",
    "desembocando": "desembocar",
    "desembocara": "desembocar",
    "desembocaram": "desembocar",
    "desembocaras": "desembocar",
    "desembocardes": "desembocar",
    "desembocarei": "desembocar",
    "desembocareis": "desembocar",
    "desembocarem": "desembocar",
    "desembocaremos": "desembocar",
    "desembocares": "desembocar",
    "desembocaria": "desembocar",
    "desembocariam": "desembocar",
    "desembocarias": "desembocar",
    "desembocarmo": "desembocar",
    "desembocarmos": "desembocar",
    "desembocará": "desembocar",
    "desembocarás": "desembocar",
    "desembocarão": "desembocar",
    "desembocaríamos": "desembocar",
    "desembocaríeis": "desembocar",
    "desembocas": "desembocar",
    "desembocasse": "desembocar",
    "desembocassem": "desembocar",
    "desembocasses": "desembocar",
    "desembocaste": "desembocar",
    "desembocastes": "desembocar",
    "desembocava": "desembocar",
    "desembocavam": "desembocar",
    "desembocavas": "desembocar",
    "desemboco": "desembocar",
    "desembocou": "desembocar",
    "desembocámo": "desembocar",
    "desembocámos": "desembocar",
    "desembocáramo": "desembocar",
    "desembocáramos": "desembocar",
    "desembocáreis": "desembocar",
    "desembocásseis": "desembocar",
    "desembocássemos": "desembocar",
    "desembocávamo": "desembocar",
    "desembocávamos": "desembocar",
    "desembocáveis": "desembocar",
    "desembola": "desembolar",
    "desembolada": "desembolar",
    "desemboladas": "desembolar",
    "desembolado": "desembolar",
    "desembolados": "desembolar",
    "desembolai": "desembolar",
    "desembolais": "desembolar",
    "desembolam": "desembolar",
    "desembolamo": "desembolar",
    "desembolamos": "desembolar",
    "desembolando": "desembolar",
    "desembolara": "desembolar",
    "desembolaram": "desembolar",
    "desembolaras": "desembolar",
    "desembolarde": "desembolar",
    "desembolardes": "desembolar",
    "desembolare": "desembolar",
    "desembolarei": "desembolar",
    "desembolareis": "desembolar",
    "desembolarem": "desembolar",
    "desembolaremos": "desembolar",
    "desembolares": "desembolar",
    "desembolaria": "desembolar",
    "desembolariam": "desembolar",
    "desembolarias": "desembolar",
    "desembolarmo": "desembolar",
    "desembolarmos": "desembolar",
    "desembolará": "desembolar",
    "desembolarás": "desembolar",
    "desembolarão": "desembolar",
    "desembolaríamos": "desembolar",
    "desembolaríeis": "desembolar",
    "desembolas": "desembolar",
    "desembolasse": "desembolar",
    "desembolassem": "desembolar",
    "desembolasses": "desembolar",
    "desembolaste": "desembolar",
    "desembolastes": "desembolar",
    "desembolava": "desembolar",
    "desembolavam": "desembolar",
    "desembolavas": "desembolar",
    "desembole": "desembolar",
    "desembolei": "desembolar",
    "desemboleis": "desembolar",
    "desembolem": "desembolar",
    "desembolemo": "desembolar",
    "desembolemos": "desembolar",
    "desemboles": "desembolar",
    "desembolo": "desembolar",
    "desembolou": "desembolar",
    "desembolsa": "desembolsar",
    "desembolsada": "desembolsar",
    "desembolsadas": "desembolsar",
    "desembolsado": "desembolsar",
    "desembolsados": "desembolsar",
    "desembolsai": "desembolsar",
    "desembolsais": "desembolsar",
    "desembolsam": "desembolsar",
    "desembolsamo": "desembolsar",
    "desembolsamos": "desembolsar",
    "desembolsando": "desembolsar",
    "desembolsara": "desembolsar",
    "desembolsaram": "desembolsar",
    "desembolsaras": "desembolsar",
    "desembolsarde": "desembolsar",
    "desembolsardes": "desembolsar",
    "desembolsare": "desembolsar",
    "desembolsarei": "desembolsar",
    "desembolsareis": "desembolsar",
    "desembolsarem": "desembolsar",
    "desembolsaremos": "desembolsar",
    "desembolsares": "desembolsar",
    "desembolsaria": "desembolsar",
    "desembolsariam": "desembolsar",
    "desembolsarias": "desembolsar",
    "desembolsarmo": "desembolsar",
    "desembolsarmos": "desembolsar",
    "desembolsará": "desembolsar",
    "desembolsarás": "desembolsar",
    "desembolsarão": "desembolsar",
    "desembolsaríamos": "desembolsar",
    "desembolsaríeis": "desembolsar",
    "desembolsas": "desembolsar",
    "desembolsasse": "desembolsar",
    "desembolsassem": "desembolsar",
    "desembolsasses": "desembolsar",
    "desembolsaste": "desembolsar",
    "desembolsastes": "desembolsar",
    "desembolsava": "desembolsar",
    "desembolsavam": "desembolsar",
    "desembolsavas": "desembolsar",
    "desembolse": "desembolsar",
    "desembolsei": "desembolsar",
    "desembolseis": "desembolsar",
    "desembolsem": "desembolsar",
    "desembolsemo": "desembolsar",
    "desembolsemos": "desembolsar",
    "desembolses": "desembolsar",
    "desembolso": "desembolsar",
    "desembolsos": "desembolso",
    "desembolsou": "desembolsar",
    "desembolsá": "desembolsar",
    "desembolsámo": "desembolsar",
    "desembolsámos": "desembolsar",
    "desembolsáramo": "desembolsar",
    "desembolsáramos": "desembolsar",
    "desembolsárei": "desembolsar",
    "desembolsáreis": "desembolsar",
    "desembolsásseis": "desembolsar",
    "desembolsássemos": "desembolsar",
    "desembolsávamo": "desembolsar",
    "desembolsávamos": "desembolsar",
    "desembolsávei": "desembolsar",
    "desembolsáveis": "desembolsável",
    "desembolá": "desembolar",
    "desembolámo": "desembolar",
    "desembolámos": "desembolar",
    "desemboláramo": "desembolar",
    "desemboláramos": "desembolar",
    "desembolárei": "desembolar",
    "desemboláreis": "desembolar",
    "desembolásseis": "desembolar",
    "desembolássemos": "desembolar",
    "desembolávamo": "desembolar",
    "desembolávamos": "desembolar",
    "desembolávei": "desembolar",
    "desemboláveis": "desembolar",
    "desemboque": "desembocar",
    "desemboquei": "desembocar",
    "desemboqueis": "desembocar",
    "desemboquem": "desembocar",
    "desemboquemos": "desembocar",
    "desemboques": "desembocar",
    "desemborca": "desemborcar",
    "desemborcada": "desemborcar",
    "desemborcadas": "desemborcar",
    "desemborcado": "desemborcar",
    "desemborcados": "desemborcar",
    "desemborcai": "desemborcar",
    "desemborcais": "desemborcar",
    "desemborcam": "desemborcar",
    "desemborcamo": "desemborcar",
    "desemborcamos": "desemborcar",
    "desemborcando": "desemborcar",
    "desemborcara": "desemborcar",
    "desemborcaram": "desemborcar",
    "desemborcaras": "desemborcar",
    "desemborcarde": "desemborcar",
    "desemborcardes": "desemborcar",
    "desemborcare": "desemborcar",
    "desemborcarei": "desemborcar",
    "desemborcareis": "desemborcar",
    "desemborcarem": "desemborcar",
    "desemborcaremos": "desemborcar",
    "desemborcares": "desemborcar",
    "desemborcaria": "desemborcar",
    "desemborcariam": "desemborcar",
    "desemborcarias": "desemborcar",
    "desemborcarmo": "desemborcar",
    "desemborcarmos": "desemborcar",
    "desemborcará": "desemborcar",
    "desemborcarás": "desemborcar",
    "desemborcarão": "desemborcar",
    "desemborcaríamos": "desemborcar",
    "desemborcaríeis": "desemborcar",
    "desemborcas": "desemborcar",
    "desemborcasse": "desemborcar",
    "desemborcassem": "desemborcar",
    "desemborcasses": "desemborcar",
    "desemborcaste": "desemborcar",
    "desemborcastes": "desemborcar",
    "desemborcava": "desemborcar",
    "desemborcavam": "desemborcar",
    "desemborcavas": "desemborcar",
    "desemborco": "desemborcar",
    "desemborcou": "desemborcar",
    "desemborcá": "desemborcar",
    "desemborcámo": "desemborcar",
    "desemborcámos": "desemborcar",
    "desemborcáramo": "desemborcar",
    "desemborcáramos": "desemborcar",
    "desemborcárei": "desemborcar",
    "desemborcáreis": "desemborcar",
    "desemborcásseis": "desemborcar",
    "desemborcássemos": "desemborcar",
    "desemborcávamo": "desemborcar",
    "desemborcávamos": "desemborcar",
    "desemborcávei": "desemborcar",
    "desemborcáveis": "desemborcar",
    "desemborque": "desemborcar",
    "desemborquei": "desemborcar",
    "desemborqueis": "desemborcar",
    "desemborquem": "desemborcar",
    "desemborquemo": "desemborcar",
    "desemborquemos": "desemborcar",
    "desemborques": "desemborcar",
    "desemborracha": "desemborrachar",
    "desemborrachada": "desemborrachar",
    "desemborrachadas": "desemborrachar",
    "desemborrachado": "desemborrachar",
    "desemborrachados": "desemborrachar",
    "desemborrachai": "desemborrachar",
    "desemborrachais": "desemborrachar",
    "desemborracham": "desemborrachar",
    "desemborrachamo": "desemborrachar",
    "desemborrachamos": "desemborrachar",
    "desemborrachando": "desemborrachar",
    "desemborrachara": "desemborrachar",
    "desemborracharam": "desemborrachar",
    "desemborracharas": "desemborrachar",
    "desemborracharde": "desemborrachar",
    "desemborrachardes": "desemborrachar",
    "desemborrachare": "desemborrachar",
    "desemborracharei": "desemborrachar",
    "desemborrachareis": "desemborrachar",
    "desemborracharem": "desemborrachar",
    "desemborracharemos": "desemborrachar",
    "desemborrachares": "desemborrachar",
    "desemborracharia": "desemborrachar",
    "desemborrachariam": "desemborrachar",
    "desemborracharias": "desemborrachar",
    "desemborracharmo": "desemborrachar",
    "desemborracharmos": "desemborrachar",
    "desemborrachará": "desemborrachar",
    "desemborracharás": "desemborrachar",
    "desemborracharão": "desemborrachar",
    "desemborracharíamos": "desemborrachar",
    "desemborracharíeis": "desemborrachar",
    "desemborrachas": "desemborrachar",
    "desemborrachasse": "desemborrachar",
    "desemborrachassem": "desemborrachar",
    "desemborrachasses": "desemborrachar",
    "desemborrachaste": "desemborrachar",
    "desemborrachastes": "desemborrachar",
    "desemborrachava": "desemborrachar",
    "desemborrachavam": "desemborrachar",
    "desemborrachavas": "desemborrachar",
    "desemborrache": "desemborrachar",
    "desemborrachei": "desemborrachar",
    "desemborracheis": "desemborrachar",
    "desemborrachem": "desemborrachar",
    "desemborrachemo": "desemborrachar",
    "desemborrachemos": "desemborrachar",
    "desemborraches": "desemborrachar",
    "desemborracho": "desemborrachar",
    "desemborrachou": "desemborrachar",
    "desemborrachá": "desemborrachar",
    "desemborrachámo": "desemborrachar",
    "desemborrachámos": "desemborrachar",
    "desemborracháramo": "desemborrachar",
    "desemborracháramos": "desemborrachar",
    "desemborrachárei": "desemborrachar",
    "desemborracháreis": "desemborrachar",
    "desemborrachásseis": "desemborrachar",
    "desemborrachássemos": "desemborrachar",
    "desemborrachávamo": "desemborrachar",
    "desemborrachávamos": "desemborrachar",
    "desemborrachávei": "desemborrachar",
    "desemborracháveis": "desemborrachar",
    "desemborrada": "desemborrado",
    "desemborradas": "desemborrado",
    "desemborradelas": "desemborradela",
    "desemborrados": "desemborrado",
    "desemborros": "desemborro",
    "desemboscada": "desemboscado",
    "desemboscadas": "desemboscado",
    "desemboscados": "desemboscado",
    "desembrace": "desembraçar",
    "desembracei": "desembraçar",
    "desembraceis": "desembraçar",
    "desembracem": "desembraçar",
    "desembracemo": "desembraçar",
    "desembracemos": "desembraçar",
    "desembraces": "desembraçar",
    "desembraia": "desembraiar",
    "desembraiada": "desembraiar",
    "desembraiadas": "desembraiar",
    "desembraiado": "desembraiar",
    "desembraiados": "desembraiar",
    "desembraiai": "desembraiar",
    "desembraiais": "desembraiar",
    "desembraiam": "desembraiar",
    "desembraiamo": "desembraiar",
    "desembraiamos": "desembraiar",
    "desembraiando": "desembraiar",
    "desembraiara": "desembraiar",
    "desembraiaram": "desembraiar",
    "desembraiaras": "desembraiar",
    "desembraiarde": "desembraiar",
    "desembraiardes": "desembraiar",
    "desembraiare": "desembraiar",
    "desembraiarei": "desembraiar",
    "desembraiareis": "desembraiar",
    "desembraiarem": "desembraiar",
    "desembraiaremos": "desembraiar",
    "desembraiares": "desembraiar",
    "desembraiaria": "desembraiar",
    "desembraiariam": "desembraiar",
    "desembraiarias": "desembraiar",
    "desembraiarmo": "desembraiar",
    "desembraiarmos": "desembraiar",
    "desembraiará": "desembraiar",
    "desembraiarás": "desembraiar",
    "desembraiarão": "desembraiar",
    "desembraiaríamos": "desembraiar",
    "desembraiaríeis": "desembraiar",
    "desembraias": "desembraiar",
    "desembraiasse": "desembraiar",
    "desembraiassem": "desembraiar",
    "desembraiasses": "desembraiar",
    "desembraiaste": "desembraiar",
    "desembraiastes": "desembraiar",
    "desembraiava": "desembraiar",
    "desembraiavam": "desembraiar",
    "desembraiavas": "desembraiar",
    "desembraie": "desembraiar",
    "desembraiei": "desembraiar",
    "desembraieis": "desembraiar",
    "desembraiem": "desembraiar",
    "desembraiemo": "desembraiar",
    "desembraiemos": "desembraiar",
    "desembraies": "desembraiar",
    "desembraio": "desembraiar",
    "desembraiou": "desembraiar",
    "desembraiá": "desembraiar",
    "desembraiámo": "desembraiar",
    "desembraiámos": "desembraiar",
    "desembraiáramo": "desembraiar",
    "desembraiáramos": "desembraiar",
    "desembraiárei": "desembraiar",
    "desembraiáreis": "desembraiar",
    "desembraiásseis": "desembraiar",
    "desembraiássemos": "desembraiar",
    "desembraiávamo": "desembraiar",
    "desembraiávamos": "desembraiar",
    "desembraiávei": "desembraiar",
    "desembraiáveis": "desembraiar",
    "desembrama": "desembramar",
    "desembramada": "desembramar",
    "desembramadas": "desembramar",
    "desembramado": "desembramar",
    "desembramados": "desembramar",
    "desembramai": "desembramar",
    "desembramais": "desembramar",
    "desembramam": "desembramar",
    "desembramamo": "desembramar",
    "desembramamos": "desembramar",
    "desembramando": "desembramar",
    "desembramara": "desembramar",
    "desembramaram": "desembramar",
    "desembramaras": "desembramar",
    "desembramarde": "desembramar",
    "desembramardes": "desembramar",
    "desembramare": "desembramar",
    "desembramarei": "desembramar",
    "desembramareis": "desembramar",
    "desembramarem": "desembramar",
    "desembramaremos": "desembramar",
    "desembramares": "desembramar",
    "desembramaria": "desembramar",
    "desembramariam": "desembramar",
    "desembramarias": "desembramar",
    "desembramarmo": "desembramar",
    "desembramarmos": "desembramar",
    "desembramará": "desembramar",
    "desembramarás": "desembramar",
    "desembramarão": "desembramar",
    "desembramaríamos": "desembramar",
    "desembramaríeis": "desembramar",
    "desembramas": "desembramar",
    "desembramasse": "desembramar",
    "desembramassem": "desembramar",
    "desembramasses": "desembramar",
    "desembramaste": "desembramar",
    "desembramastes": "desembramar",
    "desembramava": "desembramar",
    "desembramavam": "desembramar",
    "desembramavas": "desembramar",
    "desembrame": "desembramar",
    "desembramei": "desembramar",
    "desembrameis": "desembramar",
    "desembramem": "desembramar",
    "desembramemo": "desembramar",
    "desembramemos": "desembramar",
    "desembrames": "desembramar",
    "desembramo": "desembramar",
    "desembramou": "desembramar",
    "desembramá": "desembramar",
    "desembramámo": "desembramar",
    "desembramámos": "desembramar",
    "desembramáramo": "desembramar",
    "desembramáramos": "desembramar",
    "desembramárei": "desembramar",
    "desembramáreis": "desembramar",
    "desembramásseis": "desembramar",
    "desembramássemos": "desembramar",
    "desembramávamo": "desembramar",
    "desembramávamos": "desembramar",
    "desembramávei": "desembramar",
    "desembramáveis": "desembramar",
    "desembravece": "desembravecer",
    "desembravecei": "desembravecer",
    "desembraveceis": "desembravecer",
    "desembravecem": "desembravecer",
    "desembravecemo": "desembravecer",
    "desembravecemos": "desembravecer",
    "desembravecendo": "desembravecer",
    "desembravecera": "desembravecer",
    "desembraveceram": "desembravecer",
    "desembraveceras": "desembravecer",
    "desembravecerde": "desembravecer",
    "desembravecerdes": "desembravecer",
    "desembravecere": "desembravecer",
    "desembravecerei": "desembravecer",
    "desembravecereis": "desembravecer",
    "desembravecerem": "desembravecer",
    "desembraveceremos": "desembravecer",
    "desembraveceres": "desembravecer",
    "desembraveceria": "desembravecer",
    "desembraveceriam": "desembravecer",
    "desembravecerias": "desembravecer",
    "desembravecermo": "desembravecer",
    "desembravecermos": "desembravecer",
    "desembravecerá": "desembravecer",
    "desembravecerás": "desembravecer",
    "desembravecerão": "desembravecer",
    "desembraveceríamos": "desembravecer",
    "desembraveceríeis": "desembravecer",
    "desembraveces": "desembravecer",
    "desembravecesse": "desembravecer",
    "desembravecessem": "desembravecer",
    "desembravecesses": "desembravecer",
    "desembraveceste": "desembravecer",
    "desembravecestes": "desembravecer",
    "desembraveceu": "desembravecer",
    "desembraveci": "desembravecer",
    "desembravecia": "desembravecer",
    "desembraveciam": "desembravecer",
    "desembravecias": "desembravecer",
    "desembravecida": "desembravecer",
    "desembravecidas": "desembravecer",
    "desembravecido": "desembravecer",
    "desembravecidos": "desembravecer",
    "desembravecê": "desembravecer",
    "desembravecêramo": "desembravecer",
    "desembravecêramos": "desembravecer",
    "desembravecêrei": "desembravecer",
    "desembravecêreis": "desembravecer",
    "desembravecêsseis": "desembravecer",
    "desembravecêssemos": "desembravecer",
    "desembravecíamo": "desembravecer",
    "desembravecíamos": "desembravecer",
    "desembravecíei": "desembravecer",
    "desembravecíeis": "desembravecer",
    "desembraveça": "desembravecer",
    "desembraveçais": "desembravecer",
    "desembraveçam": "desembravecer",
    "desembraveçamo": "desembravecer",
    "desembraveçamos": "desembravecer",
    "desembraveças": "desembravecer",
    "desembraveço": "desembravecer",
    "desembraça": "desembraçar",
    "desembraçada": "desembraçar",
    "desembraçadas": "desembraçar",
    "desembraçado": "desembraçar",
    "desembraçados": "desembraçar",
    "desembraçai": "desembraçar",
    "desembraçais": "desembraçar",
    "desembraçam": "desembraçar",
    "desembraçamo": "desembraçar",
    "desembraçamos": "desembraçar",
    "desembraçando": "desembraçar",
    "desembraçara": "desembraçar",
    "desembraçaram": "desembraçar",
    "desembraçaras": "desembraçar",
    "desembraçarde": "desembraçar",
    "desembraçardes": "desembraçar",
    "desembraçare": "desembraçar",
    "desembraçarei": "desembraçar",
    "desembraçareis": "desembraçar",
    "desembraçarem": "desembraçar",
    "desembraçaremos": "desembraçar",
    "desembraçares": "desembraçar",
    "desembraçaria": "desembraçar",
    "desembraçariam": "desembraçar",
    "desembraçarias": "desembraçar",
    "desembraçarmo": "desembraçar",
    "desembraçarmos": "desembraçar",
    "desembraçará": "desembraçar",
    "desembraçarás": "desembraçar",
    "desembraçarão": "desembraçar",
    "desembraçaríamos": "desembraçar",
    "desembraçaríeis": "desembraçar",
    "desembraças": "desembraçar",
    "desembraçasse": "desembraçar",
    "desembraçassem": "desembraçar",
    "desembraçasses": "desembraçar",
    "desembraçaste": "desembraçar",
    "desembraçastes": "desembraçar",
    "desembraçava": "desembraçar",
    "desembraçavam": "desembraçar",
    "desembraçavas": "desembraçar",
    "desembraço": "desembraçar",
    "desembraçou": "desembraçar",
    "desembraçá": "desembraçar",
    "desembraçámo": "desembraçar",
    "desembraçámos": "desembraçar",
    "desembraçáramo": "desembraçar",
    "desembraçáramos": "desembraçar",
    "desembraçárei": "desembraçar",
    "desembraçáreis": "desembraçar",
    "desembraçásseis": "desembraçar",
    "desembraçássemos": "desembraçar",
    "desembraçávamo": "desembraçar",
    "desembraçávamos": "desembraçar",
    "desembraçávei": "desembraçar",
    "desembraçáveis": "desembraçar",
    "desembreada": "desembreado",
    "desembreadas": "desembreado",
    "desembreados": "desembreado",
    "desembrecha": "desembrechar",
    "desembrechada": "desembrechar",
    "desembrechadas": "desembrechar",
    "desembrechado": "desembrechar",
    "desembrechados": "desembrechar",
    "desembrechai": "desembrechar",
    "desembrechais": "desembrechar",
    "desembrecham": "desembrechar",
    "desembrechamo": "desembrechar",
    "desembrechamos": "desembrechar",
    "desembrechando": "desembrechar",
    "desembrechara": "desembrechar",
    "desembrecharam": "desembrechar",
    "desembrecharas": "desembrechar",
    "desembrecharde": "desembrechar",
    "desembrechardes": "desembrechar",
    "desembrechare": "desembrechar",
    "desembrecharei": "desembrechar",
    "desembrechareis": "desembrechar",
    "desembrecharem": "desembrechar",
    "desembrecharemos": "desembrechar",
    "desembrechares": "desembrechar",
    "desembrecharia": "desembrechar",
    "desembrechariam": "desembrechar",
    "desembrecharias": "desembrechar",
    "desembrecharmo": "desembrechar",
    "desembrecharmos": "desembrechar",
    "desembrechará": "desembrechar",
    "desembrecharás": "desembrechar",
    "desembrecharão": "desembrechar",
    "desembrecharíamos": "desembrechar",
    "desembrecharíeis": "desembrechar",
    "desembrechas": "desembrechar",
    "desembrechasse": "desembrechar",
    "desembrechassem": "desembrechar",
    "desembrechasses": "desembrechar",
    "desembrechaste": "desembrechar",
    "desembrechastes": "desembrechar",
    "desembrechava": "desembrechar",
    "desembrechavam": "desembrechar",
    "desembrechavas": "desembrechar",
    "desembreche": "desembrechar",
    "desembrechei": "desembrechar",
    "desembrecheis": "desembrechar",
    "desembrechem": "desembrechar",
    "desembrechemo": "desembrechar",
    "desembrechemos": "desembrechar",
    "desembreches": "desembrechar",
    "desembrecho": "desembrechar",
    "desembrechou": "desembrechar",
    "desembrechá": "desembrechar",
    "desembrechámo": "desembrechar",
    "desembrechámos": "desembrechar",
    "desembrecháramo": "desembrechar",
    "desembrecháramos": "desembrechar",
    "desembrechárei": "desembrechar",
    "desembrecháreis": "desembrechar",
    "desembrechásseis": "desembrechar",
    "desembrechássemos": "desembrechar",
    "desembrechávamo": "desembrechar",
    "desembrechávamos": "desembrechar",
    "desembrechávei": "desembrechar",
    "desembrecháveis": "desembrechar",
    "desembrenha": "desembrenhar",
    "desembrenhada": "desembrenhar",
    "desembrenhadas": "desembrenhar",
    "desembrenhado": "desembrenhar",
    "desembrenhados": "desembrenhar",
    "desembrenhai": "desembrenhar",
    "desembrenhais": "desembrenhar",
    "desembrenham": "desembrenhar",
    "desembrenhamo": "desembrenhar",
    "desembrenhamos": "desembrenhar",
    "desembrenhando": "desembrenhar",
    "desembrenhara": "desembrenhar",
    "desembrenharam": "desembrenhar",
    "desembrenharas": "desembrenhar",
    "desembrenharde": "desembrenhar",
    "desembrenhardes": "desembrenhar",
    "desembrenhare": "desembrenhar",
    "desembrenharei": "desembrenhar",
    "desembrenhareis": "desembrenhar",
    "desembrenharem": "desembrenhar",
    "desembrenharemos": "desembrenhar",
    "desembrenhares": "desembrenhar",
    "desembrenharia": "desembrenhar",
    "desembrenhariam": "desembrenhar",
    "desembrenharias": "desembrenhar",
    "desembrenharmo": "desembrenhar",
    "desembrenharmos": "desembrenhar",
    "desembrenhará": "desembrenhar",
    "desembrenharás": "desembrenhar",
    "desembrenharão": "desembrenhar",
    "desembrenharíamos": "desembrenhar",
    "desembrenharíeis": "desembrenhar",
    "desembrenhas": "desembrenhar",
    "desembrenhasse": "desembrenhar",
    "desembrenhassem": "desembrenhar",
    "desembrenhasses": "desembrenhar",
    "desembrenhaste": "desembrenhar",
    "desembrenhastes": "desembrenhar",
    "desembrenhava": "desembrenhar",
    "desembrenhavam": "desembrenhar",
    "desembrenhavas": "desembrenhar",
    "desembrenhe": "desembrenhar",
    "desembrenhei": "desembrenhar",
    "desembrenheis": "desembrenhar",
    "desembrenhem": "desembrenhar",
    "desembrenhemo": "desembrenhar",
    "desembrenhemos": "desembrenhar",
    "desembrenhes": "desembrenhar",
    "desembrenho": "desembrenhar",
    "desembrenhou": "desembrenhar",
    "desembrenhá": "desembrenhar",
    "desembrenhámo": "desembrenhar",
    "desembrenhámos": "desembrenhar",
    "desembrenháramo": "desembrenhar",
    "desembrenháramos": "desembrenhar",
    "desembrenhárei": "desembrenhar",
    "desembrenháreis": "desembrenhar",
    "desembrenhásseis": "desembrenhar",
    "desembrenhássemos": "desembrenhar",
    "desembrenhávamo": "desembrenhar",
    "desembrenhávamos": "desembrenhar",
    "desembrenhávei": "desembrenhar",
    "desembrenháveis": "desembrenhar",
    "desembriaga": "desembriagar",
    "desembriagada": "desembriagar",
    "desembriagadas": "desembriagar",
    "desembriagado": "desembriagar",
    "desembriagados": "desembriagar",
    "desembriagai": "desembriagar",
    "desembriagais": "desembriagar",
    "desembriagam": "desembriagar",
    "desembriagamo": "desembriagar",
    "desembriagamos": "desembriagar",
    "desembriagando": "desembriagar",
    "desembriagara": "desembriagar",
    "desembriagaram": "desembriagar",
    "desembriagaras": "desembriagar",
    "desembriagarde": "desembriagar",
    "desembriagardes": "desembriagar",
    "desembriagare": "desembriagar",
    "desembriagarei": "desembriagar",
    "desembriagareis": "desembriagar",
    "desembriagarem": "desembriagar",
    "desembriagaremos": "desembriagar",
    "desembriagares": "desembriagar",
    "desembriagaria": "desembriagar",
    "desembriagariam": "desembriagar",
    "desembriagarias": "desembriagar",
    "desembriagarmo": "desembriagar",
    "desembriagarmos": "desembriagar",
    "desembriagará": "desembriagar",
    "desembriagarás": "desembriagar",
    "desembriagarão": "desembriagar",
    "desembriagaríamos": "desembriagar",
    "desembriagaríeis": "desembriagar",
    "desembriagas": "desembriagar",
    "desembriagasse": "desembriagar",
    "desembriagassem": "desembriagar",
    "desembriagasses": "desembriagar",
    "desembriagaste": "desembriagar",
    "desembriagastes": "desembriagar",
    "desembriagava": "desembriagar",
    "desembriagavam": "desembriagar",
    "desembriagavas": "desembriagar",
    "desembriago": "desembriagar",
    "desembriagou": "desembriagar",
    "desembriague": "desembriagar",
    "desembriaguei": "desembriagar",
    "desembriagueis": "desembriagar",
    "desembriaguem": "desembriagar",
    "desembriaguemo": "desembriagar",
    "desembriaguemos": "desembriagar",
    "desembriagues": "desembriagar",
    "desembriagá": "desembriagar",
    "desembriagámo": "desembriagar",
    "desembriagámos": "desembriagar",
    "desembriagáramo": "desembriagar",
    "desembriagáramos": "desembriagar",
    "desembriagárei": "desembriagar",
    "desembriagáreis": "desembriagar",
    "desembriagásseis": "desembriagar",
    "desembriagássemos": "desembriagar",
    "desembriagávamo": "desembriagar",
    "desembriagávamos": "desembriagar",
    "desembriagávei": "desembriagar",
    "desembriagáveis": "desembriagar",
    "desembrulha": "desembrulhar",
    "desembrulhada": "desembrulhar",
    "desembrulhadas": "desembrulhar",
    "desembrulhado": "desembrulhar",
    "desembrulhados": "desembrulhar",
    "desembrulhai": "desembrulhar",
    "desembrulhais": "desembrulhar",
    "desembrulham": "desembrulhar",
    "desembrulhamo": "desembrulhar",
    "desembrulhamos": "desembrulhar",
    "desembrulhando": "desembrulhar",
    "desembrulhara": "desembrulhar",
    "desembrulharam": "desembrulhar",
    "desembrulharas": "desembrulhar",
    "desembrulharde": "desembrulhar",
    "desembrulhardes": "desembrulhar",
    "desembrulhare": "desembrulhar",
    "desembrulharei": "desembrulhar",
    "desembrulhareis": "desembrulhar",
    "desembrulharem": "desembrulhar",
    "desembrulharemos": "desembrulhar",
    "desembrulhares": "desembrulhar",
    "desembrulharia": "desembrulhar",
    "desembrulhariam": "desembrulhar",
    "desembrulharias": "desembrulhar",
    "desembrulharmo": "desembrulhar",
    "desembrulharmos": "desembrulhar",
    "desembrulhará": "desembrulhar",
    "desembrulharás": "desembrulhar",
    "desembrulharão": "desembrulhar",
    "desembrulharíamos": "desembrulhar",
    "desembrulharíeis": "desembrulhar",
    "desembrulhas": "desembrulhar",
    "desembrulhasse": "desembrulhar",
    "desembrulhassem": "desembrulhar",
    "desembrulhasses": "desembrulhar",
    "desembrulhaste": "desembrulhar",
    "desembrulhastes": "desembrulhar",
    "desembrulhava": "desembrulhar",
    "desembrulhavam": "desembrulhar",
    "desembrulhavas": "desembrulhar",
    "desembrulhe": "desembrulhar",
    "desembrulhei": "desembrulhar",
    "desembrulheis": "desembrulhar",
    "desembrulhem": "desembrulhar",
    "desembrulhemo": "desembrulhar",
    "desembrulhemos": "desembrulhar",
    "desembrulhes": "desembrulhar",
    "desembrulho": "desembrulhar",
    "desembrulhos": "desembrulho",
    "desembrulhou": "desembrulhar",
    "desembrulhá": "desembrulhar",
    "desembrulhámo": "desembrulhar",
    "desembrulhámos": "desembrulhar",
    "desembrulháramo": "desembrulhar",
    "desembrulháramos": "desembrulhar",
    "desembrulhárei": "desembrulhar",
    "desembrulháreis": "desembrulhar",
    "desembrulhásseis": "desembrulhar",
    "desembrulhássemos": "desembrulhar",
    "desembrulhávamo": "desembrulhar",
    "desembrulhávamos": "desembrulhar",
    "desembrulhávei": "desembrulhar",
    "desembrulháveis": "desembrulhar",
    "desembrusca": "desembruscar",
    "desembruscada": "desembruscar",
    "desembruscadas": "desembruscar",
    "desembruscado": "desembruscar",
    "desembruscados": "desembruscar",
    "desembruscai": "desembruscar",
    "desembruscais": "desembruscar",
    "desembruscam": "desembruscar",
    "desembruscamo": "desembruscar",
    "desembruscamos": "desembruscar",
    "desembruscando": "desembruscar",
    "desembruscara": "desembruscar",
    "desembruscaram": "desembruscar",
    "desembruscaras": "desembruscar",
    "desembruscarde": "desembruscar",
    "desembruscardes": "desembruscar",
    "desembruscare": "desembruscar",
    "desembruscarei": "desembruscar",
    "desembruscareis": "desembruscar",
    "desembruscarem": "desembruscar",
    "desembruscaremos": "desembruscar",
    "desembruscares": "desembruscar",
    "desembruscaria": "desembruscar",
    "desembruscariam": "desembruscar",
    "desembruscarias": "desembruscar",
    "desembruscarmo": "desembruscar",
    "desembruscarmos": "desembruscar",
    "desembruscará": "desembruscar",
    "desembruscarás": "desembruscar",
    "desembruscarão": "desembruscar",
    "desembruscaríamos": "desembruscar",
    "desembruscaríeis": "desembruscar",
    "desembruscas": "desembruscar",
    "desembruscasse": "desembruscar",
    "desembruscassem": "desembruscar",
    "desembruscasses": "desembruscar",
    "desembruscaste": "desembruscar",
    "desembruscastes": "desembruscar",
    "desembruscava": "desembruscar",
    "desembruscavam": "desembruscar",
    "desembruscavas": "desembruscar",
    "desembrusco": "desembruscar",
    "desembruscou": "desembruscar",
    "desembruscá": "desembruscar",
    "desembruscámo": "desembruscar",
    "desembruscámos": "desembruscar",
    "desembruscáramo": "desembruscar",
    "desembruscáramos": "desembruscar",
    "desembruscárei": "desembruscar",
    "desembruscáreis": "desembruscar",
    "desembruscásseis": "desembruscar",
    "desembruscássemos": "desembruscar",
    "desembruscávamo": "desembruscar",
    "desembruscávamos": "desembruscar",
    "desembruscávei": "desembruscar",
    "desembruscáveis": "desembruscar",
    "desembrusque": "desembruscar",
    "desembrusquei": "desembruscar",
    "desembrusqueis": "desembruscar",
    "desembrusquem": "desembruscar",
    "desembrusquemo": "desembruscar",
    "desembrusquemos": "desembruscar",
    "desembrusques": "desembruscar",
    "desembrutece": "desembrutecer",
    "desembrutecei": "desembrutecer",
    "desembruteceis": "desembrutecer",
    "desembrutecem": "desembrutecer",
    "desembrutecemo": "desembrutecer",
    "desembrutecemos": "desembrutecer",
    "desembrutecendo": "desembrutecer",
    "desembrutecera": "desembrutecer",
    "desembruteceram": "desembrutecer",
    "desembruteceras": "desembrutecer",
    "desembrutecerde": "desembrutecer",
    "desembrutecerdes": "desembrutecer",
    "desembrutecere": "desembrutecer",
    "desembrutecerei": "desembrutecer",
    "desembrutecereis": "desembrutecer",
    "desembrutecerem": "desembrutecer",
    "desembruteceremos": "desembrutecer",
    "desembruteceres": "desembrutecer",
    "desembruteceria": "desembrutecer",
    "desembruteceriam": "desembrutecer",
    "desembrutecerias": "desembrutecer",
    "desembrutecermo": "desembrutecer",
    "desembrutecermos": "desembrutecer",
    "desembrutecerá": "desembrutecer",
    "desembrutecerás": "desembrutecer",
    "desembrutecerão": "desembrutecer",
    "desembruteceríamos": "desembrutecer",
    "desembruteceríeis": "desembrutecer",
    "desembruteces": "desembrutecer",
    "desembrutecesse": "desembrutecer",
    "desembrutecessem": "desembrutecer",
    "desembrutecesses": "desembrutecer",
    "desembruteceste": "desembrutecer",
    "desembrutecestes": "desembrutecer",
    "desembruteceu": "desembrutecer",
    "desembruteci": "desembrutecer",
    "desembrutecia": "desembrutecer",
    "desembruteciam": "desembrutecer",
    "desembrutecias": "desembrutecer",
    "desembrutecida": "desembrutecido",
    "desembrutecidas": "desembrutecido",
    "desembrutecido": "desembrutecer",
    "desembrutecidos": "desembrutecido",
    "desembrutecê": "desembrutecer",
    "desembrutecêramo": "desembrutecer",
    "desembrutecêramos": "desembrutecer",
    "desembrutecêrei": "desembrutecer",
    "desembrutecêreis": "desembrutecer",
    "desembrutecêsseis": "desembrutecer",
    "desembrutecêssemos": "desembrutecer",
    "desembrutecíamo": "desembrutecer",
    "desembrutecíamos": "desembrutecer",
    "desembrutecíei": "desembrutecer",
    "desembrutecíeis": "desembrutecer",
    "desembruteça": "desembrutecer",
    "desembruteçais": "desembrutecer",
    "desembruteçam": "desembrutecer",
    "desembruteçamo": "desembrutecer",
    "desembruteçamos": "desembrutecer",
    "desembruteças": "desembrutecer",
    "desembruteço": "desembrutecer",
    "desembruxa": "desembruxar",
    "desembruxada": "desembruxar",
    "desembruxadas": "desembruxar",
    "desembruxado": "desembruxar",
    "desembruxados": "desembruxar",
    "desembruxai": "desembruxar",
    "desembruxais": "desembruxar",
    "desembruxam": "desembruxar",
    "desembruxamo": "desembruxar",
    "desembruxamos": "desembruxar",
    "desembruxando": "desembruxar",
    "desembruxara": "desembruxar",
    "desembruxaram": "desembruxar",
    "desembruxaras": "desembruxar",
    "desembruxarde": "desembruxar",
    "desembruxardes": "desembruxar",
    "desembruxare": "desembruxar",
    "desembruxarei": "desembruxar",
    "desembruxareis": "desembruxar",
    "desembruxarem": "desembruxar",
    "desembruxaremos": "desembruxar",
    "desembruxares": "desembruxar",
    "desembruxaria": "desembruxar",
    "desembruxariam": "desembruxar",
    "desembruxarias": "desembruxar",
    "desembruxarmo": "desembruxar",
    "desembruxarmos": "desembruxar",
    "desembruxará": "desembruxar",
    "desembruxarás": "desembruxar",
    "desembruxarão": "desembruxar",
    "desembruxaríamos": "desembruxar",
    "desembruxaríeis": "desembruxar",
    "desembruxas": "desembruxar",
    "desembruxasse": "desembruxar",
    "desembruxassem": "desembruxar",
    "desembruxasses": "desembruxar",
    "desembruxaste": "desembruxar",
    "desembruxastes": "desembruxar",
    "desembruxava": "desembruxar",
    "desembruxavam": "desembruxar",
    "desembruxavas": "desembruxar",
    "desembruxe": "desembruxar",
    "desembruxei": "desembruxar",
    "desembruxeis": "desembruxar",
    "desembruxem": "desembruxar",
    "desembruxemo": "desembruxar",
    "desembruxemos": "desembruxar",
    "desembruxes": "desembruxar",
    "desembruxo": "desembruxar",
    "desembruxou": "desembruxar",
    "desembruxá": "desembruxar",
    "desembruxámo": "desembruxar",
    "desembruxámos": "desembruxar",
    "desembruxáramo": "desembruxar",
    "desembruxáramos": "desembruxar",
    "desembruxárei": "desembruxar",
    "desembruxáreis": "desembruxar",
    "desembruxásseis": "desembruxar",
    "desembruxássemos": "desembruxar",
    "desembruxávamo": "desembruxar",
    "desembruxávamos": "desembruxar",
    "desembruxávei": "desembruxar",
    "desembruxáveis": "desembruxar",
    "desembuce": "desembuçar",
    "desembucei": "desembuçar",
    "desembuceis": "desembuçar",
    "desembucem": "desembuçar",
    "desembucemo": "desembuçar",
    "desembucemos": "desembuçar",
    "desembuces": "desembuçar",
    "desembucha": "desembuchar",
    "desembuchada": "desembuchar",
    "desembuchadas": "desembuchar",
    "desembuchado": "desembuchar",
    "desembuchados": "desembuchar",
    "desembuchai": "desembuchar",
    "desembuchais": "desembuchar",
    "desembucham": "desembuchar",
    "desembuchamo": "desembuchar",
    "desembuchamos": "desembuchar",
    "desembuchando": "desembuchar",
    "desembuchara": "desembuchar",
    "desembucharam": "desembuchar",
    "desembucharas": "desembuchar",
    "desembuchardes": "desembuchar",
    "desembucharei": "desembuchar",
    "desembuchareis": "desembuchar",
    "desembucharem": "desembuchar",
    "desembucharemos": "desembuchar",
    "desembuchares": "desembuchar",
    "desembucharia": "desembuchar",
    "desembuchariam": "desembuchar",
    "desembucharias": "desembuchar",
    "desembucharmo": "desembuchar",
    "desembucharmos": "desembuchar",
    "desembuchará": "desembuchar",
    "desembucharás": "desembuchar",
    "desembucharão": "desembuchar",
    "desembucharíamos": "desembuchar",
    "desembucharíeis": "desembuchar",
    "desembuchas": "desembuchar",
    "desembuchasse": "desembuchar",
    "desembuchassem": "desembuchar",
    "desembuchasses": "desembuchar",
    "desembuchaste": "desembuchar",
    "desembuchastes": "desembuchar",
    "desembuchava": "desembuchar",
    "desembuchavam": "desembuchar",
    "desembuchavas": "desembuchar",
    "desembuche": "desembuchar",
    "desembuchei": "desembuchar",
    "desembucheis": "desembuchar",
    "desembuchem": "desembuchar",
    "desembuchemo": "desembuchar",
    "desembuchemos": "desembuchar",
    "desembuches": "desembuchar",
    "desembucho": "desembuchar",
    "desembuchou": "desembuchar",
    "desembuchámo": "desembuchar",
    "desembuchámos": "desembuchar",
    "desembucháramo": "desembuchar",
    "desembucháramos": "desembuchar",
    "desembucháreis": "desembuchar",
    "desembuchásseis": "desembuchar",
    "desembuchássemos": "desembuchar",
    "desembuchávamo": "desembuchar",
    "desembuchávamos": "desembuchar",
    "desembucháveis": "desembuchar",
    "desemburra": "desemburrar",
    "desemburrada": "desemburrar",
    "desemburradas": "desemburrar",
    "desemburradelas": "desemburradela",
    "desemburrado": "desemburrar",
    "desemburrados": "desemburrar",
    "desemburrai": "desemburrar",
    "desemburrais": "desemburrar",
    "desemburram": "desemburrar",
    "desemburramo": "desemburrar",
    "desemburramos": "desemburrar",
    "desemburrando": "desemburrar",
    "desemburrara": "desemburrar",
    "desemburraram": "desemburrar",
    "desemburraras": "desemburrar",
    "desemburrarde": "desemburrar",
    "desemburrardes": "desemburrar",
    "desemburrare": "desemburrar",
    "desemburrarei": "desemburrar",
    "desemburrareis": "desemburrar",
    "desemburrarem": "desemburrar",
    "desemburraremos": "desemburrar",
    "desemburrares": "desemburrar",
    "desemburraria": "desemburrar",
    "desemburrariam": "desemburrar",
    "desemburrarias": "desemburrar",
    "desemburrarmo": "desemburrar",
    "desemburrarmos": "desemburrar",
    "desemburrará": "desemburrar",
    "desemburrarás": "desemburrar",
    "desemburrarão": "desemburrar",
    "desemburraríamos": "desemburrar",
    "desemburraríeis": "desemburrar",
    "desemburras": "desemburrar",
    "desemburrasse": "desemburrar",
    "desemburrassem": "desemburrar",
    "desemburrasses": "desemburrar",
    "desemburraste": "desemburrar",
    "desemburrastes": "desemburrar",
    "desemburrava": "desemburrar",
    "desemburravam": "desemburrar",
    "desemburravas": "desemburrar",
    "desemburre": "desemburrar",
    "desemburrei": "desemburrar",
    "desemburreis": "desemburrar",
    "desemburrem": "desemburrar",
    "desemburremo": "desemburrar",
    "desemburremos": "desemburrar",
    "desemburres": "desemburrar",
    "desemburro": "desemburrar",
    "desemburrou": "desemburrar",
    "desemburrá": "desemburrar",
    "desemburrámo": "desemburrar",
    "desemburrámos": "desemburrar",
    "desemburráramo": "desemburrar",
    "desemburráramos": "desemburrar",
    "desemburrárei": "desemburrar",
    "desemburráreis": "desemburrar",
    "desemburrásseis": "desemburrar",
    "desemburrássemos": "desemburrar",
    "desemburrávamo": "desemburrar",
    "desemburrávamos": "desemburrar",
    "desemburrávei": "desemburrar",
    "desemburráveis": "desemburrar",
    "desembuta": "desembutir",
    "desembutais": "desembutir",
    "desembutam": "desembutir",
    "desembutamo": "desembutir",
    "desembutamos": "desembutir",
    "desembutas": "desembutir",
    "desembute": "desembutir",
    "desembutem": "desembutir",
    "desembutes": "desembutir",
    "desembuti": "desembutir",
    "desembutia": "desembutir",
    "desembutiam": "desembutir",
    "desembutias": "desembutir",
    "desembutida": "desembutir",
    "desembutidas": "desembutir",
    "desembutido": "desembutir",
    "desembutidos": "desembutir",
    "desembutimo": "desembutir",
    "desembutimos": "desembutir",
    "desembutindo": "desembutir",
    "desembutira": "desembutir",
    "desembutiram": "desembutir",
    "desembutiras": "desembutir",
    "desembutirde": "desembutir",
    "desembutirdes": "desembutir",
    "desembutire": "desembutir",
    "desembutirei": "desembutir",
    "desembutireis": "desembutir",
    "desembutirem": "desembutir",
    "desembutiremos": "desembutir",
    "desembutires": "desembutir",
    "desembutiria": "desembutir",
    "desembutiriam": "desembutir",
    "desembutirias": "desembutir",
    "desembutirmo": "desembutir",
    "desembutirmos": "desembutir",
    "desembutirá": "desembutir",
    "desembutirás": "desembutir",
    "desembutirão": "desembutir",
    "desembutiríamos": "desembutir",
    "desembutiríeis": "desembutir",
    "desembutis": "desembutir",
    "desembutisse": "desembutir",
    "desembutissem": "desembutir",
    "desembutisses": "desembutir",
    "desembutiste": "desembutir",
    "desembutistes": "desembutir",
    "desembutiu": "desembutir",
    "desembuto": "desembutir",
    "desembutíamo": "desembutir",
    "desembutíamos": "desembutir",
    "desembutíei": "desembutir",
    "desembutíeis": "desembutir",
    "desembutíramo": "desembutir",
    "desembutíramos": "desembutir",
    "desembutírei": "desembutir",
    "desembutíreis": "desembutir",
    "desembutísseis": "desembutir",
    "desembutíssemos": "desembutir",
    "desembuça": "desembuçar",
    "desembuçada": "desembuçar",
    "desembuçadas": "desembuçar",
    "desembuçado": "desembuçar",
    "desembuçados": "desembuçar",
    "desembuçai": "desembuçar",
    "desembuçais": "desembuçar",
    "desembuçam": "desembuçar",
    "desembuçamo": "desembuçar",
    "desembuçamos": "desembuçar",
    "desembuçando": "desembuçar",
    "desembuçara": "desembuçar",
    "desembuçaram": "desembuçar",
    "desembuçaras": "desembuçar",
    "desembuçarde": "desembuçar",
    "desembuçardes": "desembuçar",
    "desembuçare": "desembuçar",
    "desembuçarei": "desembuçar",
    "desembuçareis": "desembuçar",
    "desembuçarem": "desembuçar",
    "desembuçaremos": "desembuçar",
    "desembuçares": "desembuçar",
    "desembuçaria": "desembuçar",
    "desembuçariam": "desembuçar",
    "desembuçarias": "desembuçar",
    "desembuçarmo": "desembuçar",
    "desembuçarmos": "desembuçar",
    "desembuçará": "desembuçar",
    "desembuçarás": "desembuçar",
    "desembuçarão": "desembuçar",
    "desembuçaríamos": "desembuçar",
    "desembuçaríeis": "desembuçar",
    "desembuças": "desembuçar",
    "desembuçasse": "desembuçar",
    "desembuçassem": "desembuçar",
    "desembuçasses": "desembuçar",
    "desembuçaste": "desembuçar",
    "desembuçastes": "desembuçar",
    "desembuçava": "desembuçar",
    "desembuçavam": "desembuçar",
    "desembuçavas": "desembuçar",
    "desembuço": "desembuçar",
    "desembuços": "desembuço",
    "desembuçou": "desembuçar",
    "desembuçá": "desembuçar",
    "desembuçámo": "desembuçar",
    "desembuçámos": "desembuçar",
    "desembuçáramo": "desembuçar",
    "desembuçáramos": "desembuçar",
    "desembuçárei": "desembuçar",
    "desembuçáreis": "desembuçar",
    "desembuçásseis": "desembuçar",
    "desembuçássemos": "desembuçar",
    "desembuçávamo": "desembuçar",
    "desembuçávamos": "desembuçar",
    "desembuçávei": "desembuçar",
    "desembuçáveis": "desembuçar",
    "desemeda": "desemedar",
    "desemedada": "desemedar",
    "desemedadas": "desemedar",
    "desemedado": "desemedar",
    "desemedados": "desemedar",
    "desemedai": "desemedar",
    "desemedais": "desemedar",
    "desemedam": "desemedar",
    "desemedamo": "desemedar",
    "desemedamos": "desemedar",
    "desemedando": "desemedar",
    "desemedara": "desemedar",
    "desemedaram": "desemedar",
    "desemedaras": "desemedar",
    "desemedarde": "desemedar",
    "desemedardes": "desemedar",
    "desemedare": "desemedar",
    "desemedarei": "desemedar",
    "desemedareis": "desemedar",
    "desemedarem": "desemedar",
    "desemedaremos": "desemedar",
    "desemedares": "desemedar",
    "desemedaria": "desemedar",
    "desemedariam": "desemedar",
    "desemedarias": "desemedar",
    "desemedarmo": "desemedar",
    "desemedarmos": "desemedar",
    "desemedará": "desemedar",
    "desemedarás": "desemedar",
    "desemedarão": "desemedar",
    "desemedaríamos": "desemedar",
    "desemedaríeis": "desemedar",
    "desemedas": "desemedar",
    "desemedasse": "desemedar",
    "desemedassem": "desemedar",
    "desemedasses": "desemedar",
    "desemedaste": "desemedar",
    "desemedastes": "desemedar",
    "desemedava": "desemedar",
    "desemedavam": "desemedar",
    "desemedavas": "desemedar",
    "desemede": "desemedar",
    "desemedei": "desemedar",
    "desemedeis": "desemedar",
    "desemedem": "desemedar",
    "desemedemo": "desemedar",
    "desemedemos": "desemedar",
    "desemedes": "desemedar",
    "desemedo": "desemedar",
    "desemedou": "desemedar",
    "desemedá": "desemedar",
    "desemedámo": "desemedar",
    "desemedámos": "desemedar",
    "desemedáramo": "desemedar",
    "desemedáramos": "desemedar",
    "desemedárei": "desemedar",
    "desemedáreis": "desemedar",
    "desemedásseis": "desemedar",
    "desemedássemos": "desemedar",
    "desemedávamo": "desemedar",
    "desemedávamos": "desemedar",
    "desemedávei": "desemedar",
    "desemedáveis": "desemedar",
    "desemoinha": "desemoinhar",
    "desemoinhada": "desemoinhar",
    "desemoinhadas": "desemoinhar",
    "desemoinhado": "desemoinhar",
    "desemoinhados": "desemoinhar",
    "desemoinhai": "desemoinhar",
    "desemoinhais": "desemoinhar",
    "desemoinham": "desemoinhar",
    "desemoinhamo": "desemoinhar",
    "desemoinhamos": "desemoinhar",
    "desemoinhando": "desemoinhar",
    "desemoinhara": "desemoinhar",
    "desemoinharam": "desemoinhar",
    "desemoinharas": "desemoinhar",
    "desemoinharde": "desemoinhar",
    "desemoinhardes": "desemoinhar",
    "desemoinhare": "desemoinhar",
    "desemoinharei": "desemoinhar",
    "desemoinhareis": "desemoinhar",
    "desemoinharem": "desemoinhar",
    "desemoinharemos": "desemoinhar",
    "desemoinhares": "desemoinhar",
    "desemoinharia": "desemoinhar",
    "desemoinhariam": "desemoinhar",
    "desemoinharias": "desemoinhar",
    "desemoinharmo": "desemoinhar",
    "desemoinharmos": "desemoinhar",
    "desemoinhará": "desemoinhar",
    "desemoinharás": "desemoinhar",
    "desemoinharão": "desemoinhar",
    "desemoinharíamos": "desemoinhar",
    "desemoinharíeis": "desemoinhar",
    "desemoinhas": "desemoinhar",
    "desemoinhasse": "desemoinhar",
    "desemoinhassem": "desemoinhar",
    "desemoinhasses": "desemoinhar",
    "desemoinhaste": "desemoinhar",
    "desemoinhastes": "desemoinhar",
    "desemoinhava": "desemoinhar",
    "desemoinhavam": "desemoinhar",
    "desemoinhavas": "desemoinhar",
    "desemoinhe": "desemoinhar",
    "desemoinhei": "desemoinhar",
    "desemoinheis": "desemoinhar",
    "desemoinhem": "desemoinhar",
    "desemoinhemo": "desemoinhar",
    "desemoinhemos": "desemoinhar",
    "desemoinhes": "desemoinhar",
    "desemoinho": "desemoinhar",
    "desemoinhou": "desemoinhar",
    "desemoinhá": "desemoinhar",
    "desemoinhámo": "desemoinhar",
    "desemoinhámos": "desemoinhar",
    "desemoinháramo": "desemoinhar",
    "desemoinháramos": "desemoinhar",
    "desemoinhárei": "desemoinhar",
    "desemoinháreis": "desemoinhar",
    "desemoinhásseis": "desemoinhar",
    "desemoinhássemos": "desemoinhar",
    "desemoinhávamo": "desemoinhar",
    "desemoinhávamos": "desemoinhar",
    "desemoinhávei": "desemoinhar",
    "desemoinháveis": "desemoinhar",
    "desemoldura": "desemoldurar",
    "desemoldurada": "desemoldurar",
    "desemolduradas": "desemoldurar",
    "desemoldurado": "desemoldurar",
    "desemoldurados": "desemoldurar",
    "desemoldurai": "desemoldurar",
    "desemoldurais": "desemoldurar",
    "desemolduram": "desemoldurar",
    "desemolduramo": "desemoldurar",
    "desemolduramos": "desemoldurar",
    "desemoldurando": "desemoldurar",
    "desemoldurara": "desemoldurar",
    "desemolduraram": "desemoldurar",
    "desemolduraras": "desemoldurar",
    "desemoldurarde": "desemoldurar",
    "desemoldurardes": "desemoldurar",
    "desemoldurare": "desemoldurar",
    "desemoldurarei": "desemoldurar",
    "desemoldurareis": "desemoldurar",
    "desemoldurarem": "desemoldurar",
    "desemolduraremos": "desemoldurar",
    "desemoldurares": "desemoldurar",
    "desemolduraria": "desemoldurar",
    "desemoldurariam": "desemoldurar",
    "desemoldurarias": "desemoldurar",
    "desemoldurarmo": "desemoldurar",
    "desemoldurarmos": "desemoldurar",
    "desemoldurará": "desemoldurar",
    "desemoldurarás": "desemoldurar",
    "desemoldurarão": "desemoldurar",
    "desemolduraríamos": "desemoldurar",
    "desemolduraríeis": "desemoldurar",
    "desemolduras": "desemoldurar",
    "desemoldurasse": "desemoldurar",
    "desemoldurassem": "desemoldurar",
    "desemoldurasses": "desemoldurar",
    "desemolduraste": "desemoldurar",
    "desemoldurastes": "desemoldurar",
    "desemoldurava": "desemoldurar",
    "desemolduravam": "desemoldurar",
    "desemolduravas": "desemoldurar",
    "desemoldure": "desemoldurar",
    "desemoldurei": "desemoldurar",
    "desemoldureis": "desemoldurar",
    "desemoldurem": "desemoldurar",
    "desemolduremo": "desemoldurar",
    "desemolduremos": "desemoldurar",
    "desemoldures": "desemoldurar",
    "desemolduro": "desemoldurar",
    "desemoldurou": "desemoldurar",
    "desemoldurá": "desemoldurar",
    "desemoldurámo": "desemoldurar",
    "desemoldurámos": "desemoldurar",
    "desemolduráramo": "desemoldurar",
    "desemolduráramos": "desemoldurar",
    "desemoldurárei": "desemoldurar",
    "desemolduráreis": "desemoldurar",
    "desemoldurásseis": "desemoldurar",
    "desemoldurássemos": "desemoldurar",
    "desemoldurávamo": "desemoldurar",
    "desemoldurávamos": "desemoldurar",
    "desemoldurávei": "desemoldurar",
    "desemolduráveis": "desemoldurar",
    "desempa": "desempar",
    "desempacha": "desempachar",
    "desempachada": "desempachar",
    "desempachadas": "desempachar",
    "desempachado": "desempachar",
    "desempachados": "desempachar",
    "desempachai": "desempachar",
    "desempachais": "desempachar",
    "desempacham": "desempachar",
    "desempachamo": "desempachar",
    "desempachamos": "desempachar",
    "desempachando": "desempachar",
    "desempachara": "desempachar",
    "desempacharam": "desempachar",
    "desempacharas": "desempachar",
    "desempacharde": "desempachar",
    "desempachardes": "desempachar",
    "desempachare": "desempachar",
    "desempacharei": "desempachar",
    "desempachareis": "desempachar",
    "desempacharem": "desempachar",
    "desempacharemos": "desempachar",
    "desempachares": "desempachar",
    "desempacharia": "desempachar",
    "desempachariam": "desempachar",
    "desempacharias": "desempachar",
    "desempacharmo": "desempachar",
    "desempacharmos": "desempachar",
    "desempachará": "desempachar",
    "desempacharás": "desempachar",
    "desempacharão": "desempachar",
    "desempacharíamos": "desempachar",
    "desempacharíeis": "desempachar",
    "desempachas": "desempachar",
    "desempachasse": "desempachar",
    "desempachassem": "desempachar",
    "desempachasses": "desempachar",
    "desempachaste": "desempachar",
    "desempachastes": "desempachar",
    "desempachava": "desempachar",
    "desempachavam": "desempachar",
    "desempachavas": "desempachar",
    "desempache": "desempachar",
    "desempachei": "desempachar",
    "desempacheis": "desempachar",
    "desempachem": "desempachar",
    "desempachemo": "desempachar",
    "desempachemos": "desempachar",
    "desempaches": "desempachar",
    "desempacho": "desempachar",
    "desempachos": "desempacho",
    "desempachou": "desempachar",
    "desempachá": "desempachar",
    "desempachámo": "desempachar",
    "desempachámos": "desempachar",
    "desempacháramo": "desempachar",
    "desempacháramos": "desempachar",
    "desempachárei": "desempachar",
    "desempacháreis": "desempachar",
    "desempachásseis": "desempachar",
    "desempachássemos": "desempachar",
    "desempachávamo": "desempachar",
    "desempachávamos": "desempachar",
    "desempachávei": "desempachar",
    "desempacháveis": "desempachar",
    "desempacota": "desempacotar",
    "desempacotada": "desempacotar",
    "desempacotadas": "desempacotar",
    "desempacotado": "desempacotar",
    "desempacotados": "desempacotar",
    "desempacotai": "desempacotar",
    "desempacotais": "desempacotar",
    "desempacotam": "desempacotar",
    "desempacotamentos": "desempacotamento",
    "desempacotamo": "desempacotar",
    "desempacotamos": "desempacotar",
    "desempacotando": "desempacotar",
    "desempacotara": "desempacotar",
    "desempacotaram": "desempacotar",
    "desempacotaras": "desempacotar",
    "desempacotarde": "desempacotar",
    "desempacotardes": "desempacotar",
    "desempacotare": "desempacotar",
    "desempacotarei": "desempacotar",
    "desempacotareis": "desempacotar",
    "desempacotarem": "desempacotar",
    "desempacotaremos": "desempacotar",
    "desempacotares": "desempacotar",
    "desempacotaria": "desempacotar",
    "desempacotariam": "desempacotar",
    "desempacotarias": "desempacotar",
    "desempacotarmo": "desempacotar",
    "desempacotarmos": "desempacotar",
    "desempacotará": "desempacotar",
    "desempacotarás": "desempacotar",
    "desempacotarão": "desempacotar",
    "desempacotaríamos": "desempacotar",
    "desempacotaríeis": "desempacotar",
    "desempacotas": "desempacotar",
    "desempacotasse": "desempacotar",
    "desempacotassem": "desempacotar",
    "desempacotasses": "desempacotar",
    "desempacotaste": "desempacotar",
    "desempacotastes": "desempacotar",
    "desempacotava": "desempacotar",
    "desempacotavam": "desempacotar",
    "desempacotavas": "desempacotar",
    "desempacote": "desempacotar",
    "desempacotei": "desempacotar",
    "desempacoteis": "desempacotar",
    "desempacotem": "desempacotar",
    "desempacotemo": "desempacotar",
    "desempacotemos": "desempacotar",
    "desempacotes": "desempacotar",
    "desempacoto": "desempacotar",
    "desempacotou": "desempacotar",
    "desempacotá": "desempacotar",
    "desempacotámo": "desempacotar",
    "desempacotámos": "desempacotar",
    "desempacotáramo": "desempacotar",
    "desempacotáramos": "desempacotar",
    "desempacotárei": "desempacotar",
    "desempacotáreis": "desempacotar",
    "desempacotásseis": "desempacotar",
    "desempacotássemos": "desempacotar",
    "desempacotávamo": "desempacotar",
    "desempacotávamos": "desempacotar",
    "desempacotávei": "desempacotar",
    "desempacotáveis": "desempacotar",
    "desempada": "desempar",
    "desempadas": "desempar",
    "desempado": "desempar",
    "desempados": "desempar",
    "desempai": "desempar",
    "desempais": "desempar",
    "desempala": "desempalar",
    "desempalada": "desempalar",
    "desempaladas": "desempalar",
    "desempalado": "desempalar",
    "desempalados": "desempalar",
    "desempalai": "desempalar",
    "desempalais": "desempalar",
    "desempalam": "desempalar",
    "desempalamo": "desempalar",
    "desempalamos": "desempalar",
    "desempalando": "desempalar",
    "desempalara": "desempalar",
    "desempalaram": "desempalar",
    "desempalaras": "desempalar",
    "desempalarde": "desempalar",
    "desempalardes": "desempalar",
    "desempalare": "desempalar",
    "desempalarei": "desempalar",
    "desempalareis": "desempalar",
    "desempalarem": "desempalar",
    "desempalaremos": "desempalar",
    "desempalares": "desempalar",
    "desempalaria": "desempalar",
    "desempalariam": "desempalar",
    "desempalarias": "desempalar",
    "desempalarmo": "desempalar",
    "desempalarmos": "desempalar",
    "desempalará": "desempalar",
    "desempalarás": "desempalar",
    "desempalarão": "desempalar",
    "desempalaríamos": "desempalar",
    "desempalaríeis": "desempalar",
    "desempalas": "desempalar",
    "desempalasse": "desempalar",
    "desempalassem": "desempalar",
    "desempalasses": "desempalar",
    "desempalaste": "desempalar",
    "desempalastes": "desempalar",
    "desempalava": "desempalar",
    "desempalavam": "desempalar",
    "desempalavas": "desempalar",
    "desempale": "desempalar",
    "desempalei": "desempalar",
    "desempaleis": "desempalar",
    "desempalem": "desempalar",
    "desempalemo": "desempalar",
    "desempalemos": "desempalar",
    "desempales": "desempalar",
    "desempalha": "desempalhar",
    "desempalhada": "desempalhar",
    "desempalhadas": "desempalhar",
    "desempalhado": "desempalhar",
    "desempalhados": "desempalhar",
    "desempalhai": "desempalhar",
    "desempalhais": "desempalhar",
    "desempalham": "desempalhar",
    "desempalhamo": "desempalhar",
    "desempalhamos": "desempalhar",
    "desempalhando": "desempalhar",
    "desempalhara": "desempalhar",
    "desempalharam": "desempalhar",
    "desempalharas": "desempalhar",
    "desempalharde": "desempalhar",
    "desempalhardes": "desempalhar",
    "desempalhare": "desempalhar",
    "desempalharei": "desempalhar",
    "desempalhareis": "desempalhar",
    "desempalharem": "desempalhar",
    "desempalharemos": "desempalhar",
    "desempalhares": "desempalhar",
    "desempalharia": "desempalhar",
    "desempalhariam": "desempalhar",
    "desempalharias": "desempalhar",
    "desempalharmo": "desempalhar",
    "desempalharmos": "desempalhar",
    "desempalhará": "desempalhar",
    "desempalharás": "desempalhar",
    "desempalharão": "desempalhar",
    "desempalharíamos": "desempalhar",
    "desempalharíeis": "desempalhar",
    "desempalhas": "desempalhar",
    "desempalhasse": "desempalhar",
    "desempalhassem": "desempalhar",
    "desempalhasses": "desempalhar",
    "desempalhaste": "desempalhar",
    "desempalhastes": "desempalhar",
    "desempalhava": "desempalhar",
    "desempalhavam": "desempalhar",
    "desempalhavas": "desempalhar",
    "desempalhe": "desempalhar",
    "desempalhei": "desempalhar",
    "desempalheis": "desempalhar",
    "desempalhem": "desempalhar",
    "desempalhemo": "desempalhar",
    "desempalhemos": "desempalhar",
    "desempalhes": "desempalhar",
    "desempalho": "desempalhar",
    "desempalhou": "desempalhar",
    "desempalhá": "desempalhar",
    "desempalhámo": "desempalhar",
    "desempalhámos": "desempalhar",
    "desempalháramo": "desempalhar",
    "desempalháramos": "desempalhar",
    "desempalhárei": "desempalhar",
    "desempalháreis": "desempalhar",
    "desempalhásseis": "desempalhar",
    "desempalhássemos": "desempalhar",
    "desempalhávamo": "desempalhar",
    "desempalhávamos": "desempalhar",
    "desempalhávei": "desempalhar",
    "desempalháveis": "desempalhar",
    "desempalma": "desempalmar",
    "desempalmada": "desempalmar",
    "desempalmadas": "desempalmar",
    "desempalmado": "desempalmar",
    "desempalmados": "desempalmar",
    "desempalmai": "desempalmar",
    "desempalmais": "desempalmar",
    "desempalmam": "desempalmar",
    "desempalmamo": "desempalmar",
    "desempalmamos": "desempalmar",
    "desempalmando": "desempalmar",
    "desempalmara": "desempalmar",
    "desempalmaram": "desempalmar",
    "desempalmaras": "desempalmar",
    "desempalmarde": "desempalmar",
    "desempalmardes": "desempalmar",
    "desempalmare": "desempalmar",
    "desempalmarei": "desempalmar",
    "desempalmareis": "desempalmar",
    "desempalmarem": "desempalmar",
    "desempalmaremos": "desempalmar",
    "desempalmares": "desempalmar",
    "desempalmaria": "desempalmar",
    "desempalmariam": "desempalmar",
    "desempalmarias": "desempalmar",
    "desempalmarmo": "desempalmar",
    "desempalmarmos": "desempalmar",
    "desempalmará": "desempalmar",
    "desempalmarás": "desempalmar",
    "desempalmarão": "desempalmar",
    "desempalmaríamos": "desempalmar",
    "desempalmaríeis": "desempalmar",
    "desempalmas": "desempalmar",
    "desempalmasse": "desempalmar",
    "desempalmassem": "desempalmar",
    "desempalmasses": "desempalmar",
    "desempalmaste": "desempalmar",
    "desempalmastes": "desempalmar",
    "desempalmava": "desempalmar",
    "desempalmavam": "desempalmar",
    "desempalmavas": "desempalmar",
    "desempalme": "desempalmar",
    "desempalmei": "desempalmar",
    "desempalmeis": "desempalmar",
    "desempalmem": "desempalmar",
    "desempalmemo": "desempalmar",
    "desempalmemos": "desempalmar",
    "desempalmes": "desempalmar",
    "desempalmo": "desempalmar",
    "desempalmou": "desempalmar",
    "desempalmá": "desempalmar",
    "desempalmámo": "desempalmar",
    "desempalmámos": "desempalmar",
    "desempalmáramo": "desempalmar",
    "desempalmáramos": "desempalmar",
    "desempalmárei": "desempalmar",
    "desempalmáreis": "desempalmar",
    "desempalmásseis": "desempalmar",
    "desempalmássemos": "desempalmar",
    "desempalmávamo": "desempalmar",
    "desempalmávamos": "desempalmar",
    "desempalmávei": "desempalmar",
    "desempalmáveis": "desempalmar",
    "desempalo": "desempalar",
    "desempalou": "desempalar",
    "desempalá": "desempalar",
    "desempalámo": "desempalar",
    "desempalámos": "desempalar",
    "desempaláramo": "desempalar",
    "desempaláramos": "desempalar",
    "desempalárei": "desempalar",
    "desempaláreis": "desempalar",
    "desempalásseis": "desempalar",
    "desempalássemos": "desempalar",
    "desempalávamo": "desempalar",
    "desempalávamos": "desempalar",
    "desempalávei": "desempalar",
    "desempaláveis": "desempalar",
    "desempam": "desempar",
    "desempamo": "desempar",
    "desempamos": "desempar",
    "desempana": "desempanar",
    "desempanada": "desempanar",
    "desempanadas": "desempanar",
    "desempanado": "desempanar",
    "desempanados": "desempanar",
    "desempanai": "desempanar",
    "desempanais": "desempanar",
    "desempanam": "desempanar",
    "desempanamo": "desempanar",
    "desempanamos": "desempanar",
    "desempanando": "desempanar",
    "desempanara": "desempanar",
    "desempanaram": "desempanar",
    "desempanaras": "desempanar",
    "desempanarde": "desempanar",
    "desempanardes": "desempanar",
    "desempanare": "desempanar",
    "desempanarei": "desempanar",
    "desempanareis": "desempanar",
    "desempanarem": "desempanar",
    "desempanaremos": "desempanar",
    "desempanares": "desempanar",
    "desempanaria": "desempanar",
    "desempanariam": "desempanar",
    "desempanarias": "desempanar",
    "desempanarmo": "desempanar",
    "desempanarmos": "desempanar",
    "desempanará": "desempanar",
    "desempanarás": "desempanar",
    "desempanarão": "desempanar",
    "desempanaríamos": "desempanar",
    "desempanaríeis": "desempanar",
    "desempanas": "desempanar",
    "desempanasse": "desempanar",
    "desempanassem": "desempanar",
    "desempanasses": "desempanar",
    "desempanaste": "desempanar",
    "desempanastes": "desempanar",
    "desempanava": "desempanar",
    "desempanavam": "desempanar",
    "desempanavas": "desempanar",
    "desempando": "desempar",
    "desempane": "desempanar",
    "desempanei": "desempanar",
    "desempaneis": "desempanar",
    "desempanem": "desempanar",
    "desempanemo": "desempanar",
    "desempanemos": "desempanar",
    "desempanes": "desempanar",
    "desempano": "desempanar",
    "desempanou": "desempanar",
    "desempanturra": "desempanturrar",
    "desempanturrada": "desempanturrar",
    "desempanturradas": "desempanturrar",
    "desempanturrado": "desempanturrar",
    "desempanturrados": "desempanturrar",
    "desempanturrai": "desempanturrar",
    "desempanturrais": "desempanturrar",
    "desempanturram": "desempanturrar",
    "desempanturramo": "desempanturrar",
    "desempanturramos": "desempanturrar",
    "desempanturrando": "desempanturrar",
    "desempanturrara": "desempanturrar",
    "desempanturraram": "desempanturrar",
    "desempanturraras": "desempanturrar",
    "desempanturrarde": "desempanturrar",
    "desempanturrardes": "desempanturrar",
    "desempanturrare": "desempanturrar",
    "desempanturrarei": "desempanturrar",
    "desempanturrareis": "desempanturrar",
    "desempanturrarem": "desempanturrar",
    "desempanturraremos": "desempanturrar",
    "desempanturrares": "desempanturrar",
    "desempanturraria": "desempanturrar",
    "desempanturrariam": "desempanturrar",
    "desempanturrarias": "desempanturrar",
    "desempanturrarmo": "desempanturrar",
    "desempanturrarmos": "desempanturrar",
    "desempanturrará": "desempanturrar",
    "desempanturrarás": "desempanturrar",
    "desempanturrarão": "desempanturrar",
    "desempanturraríamos": "desempanturrar",
    "desempanturraríeis": "desempanturrar",
    "desempanturras": "desempanturrar",
    "desempanturrasse": "desempanturrar",
    "desempanturrassem": "desempanturrar",
    "desempanturrasses": "desempanturrar",
    "desempanturraste": "desempanturrar",
    "desempanturrastes": "desempanturrar",
    "desempanturrava": "desempanturrar",
    "desempanturravam": "desempanturrar",
    "desempanturravas": "desempanturrar",
    "desempanturre": "desempanturrar",
    "desempanturrei": "desempanturrar",
    "desempanturreis": "desempanturrar",
    "desempanturrem": "desempanturrar",
    "desempanturremo": "desempanturrar",
    "desempanturremos": "desempanturrar",
    "desempanturres": "desempanturrar",
    "desempanturro": "desempanturrar",
    "desempanturrou": "desempanturrar",
    "desempanturrá": "desempanturrar",
    "desempanturrámo": "desempanturrar",
    "desempanturrámos": "desempanturrar",
    "desempanturráramo": "desempanturrar",
    "desempanturráramos": "desempanturrar",
    "desempanturrárei": "desempanturrar",
    "desempanturráreis": "desempanturrar",
    "desempanturrásseis": "desempanturrar",
    "desempanturrássemos": "desempanturrar",
    "desempanturrávamo": "desempanturrar",
    "desempanturrávamos": "desempanturrar",
    "desempanturrávei": "desempanturrar",
    "desempanturráveis": "desempanturrar",
    "desempaná": "desempanar",
    "desempanámo": "desempanar",
    "desempanámos": "desempanar",
    "desempanáramo": "desempanar",
    "desempanáramos": "desempanar",
    "desempanárei": "desempanar",
    "desempanáreis": "desempanar",
    "desempanásseis": "desempanar",
    "desempanássemos": "desempanar",
    "desempanávamo": "desempanar",
    "desempanávamos": "desempanar",
    "desempanávei": "desempanar",
    "desempanáveis": "desempanar",
    "desempapa": "desempapar",
    "desempapada": "desempapar",
    "desempapadas": "desempapar",
    "desempapado": "desempapar",
    "desempapados": "desempapar",
    "desempapai": "desempapar",
    "desempapais": "desempapar",
    "desempapam": "desempapar",
    "desempapamo": "desempapar",
    "desempapamos": "desempapar",
    "desempapando": "desempapar",
    "desempapara": "desempapar",
    "desempaparam": "desempapar",
    "desempaparas": "desempapar",
    "desempaparde": "desempapar",
    "desempapardes": "desempapar",
    "desempapare": "desempapar",
    "desempaparei": "desempapar",
    "desempapareis": "desempapar",
    "desempaparem": "desempapar",
    "desempaparemos": "desempapar",
    "desempapares": "desempapar",
    "desempaparia": "desempapar",
    "desempapariam": "desempapar",
    "desempaparias": "desempapar",
    "desempaparmo": "desempapar",
    "desempaparmos": "desempapar",
    "desempapará": "desempapar",
    "desempaparás": "desempapar",
    "desempaparão": "desempapar",
    "desempaparíamos": "desempapar",
    "desempaparíeis": "desempapar",
    "desempapas": "desempapar",
    "desempapasse": "desempapar",
    "desempapassem": "desempapar",
    "desempapasses": "desempapar",
    "desempapaste": "desempapar",
    "desempapastes": "desempapar",
    "desempapava": "desempapar",
    "desempapavam": "desempapar",
    "desempapavas": "desempapar",
    "desempape": "desempapar",
    "desempapei": "desempapar",
    "desempapeis": "desempapar",
    "desempapela": "desempapelar",
    "desempapelada": "desempapelar",
    "desempapeladas": "desempapelar",
    "desempapelado": "desempapelar",
    "desempapelados": "desempapelar",
    "desempapelai": "desempapelar",
    "desempapelais": "desempapelar",
    "desempapelam": "desempapelar",
    "desempapelamo": "desempapelar",
    "desempapelamos": "desempapelar",
    "desempapelando": "desempapelar",
    "desempapelara": "desempapelar",
    "desempapelaram": "desempapelar",
    "desempapelaras": "desempapelar",
    "desempapelarde": "desempapelar",
    "desempapelardes": "desempapelar",
    "desempapelare": "desempapelar",
    "desempapelarei": "desempapelar",
    "desempapelareis": "desempapelar",
    "desempapelarem": "desempapelar",
    "desempapelaremos": "desempapelar",
    "desempapelares": "desempapelar",
    "desempapelaria": "desempapelar",
    "desempapelariam": "desempapelar",
    "desempapelarias": "desempapelar",
    "desempapelarmo": "desempapelar",
    "desempapelarmos": "desempapelar",
    "desempapelará": "desempapelar",
    "desempapelarás": "desempapelar",
    "desempapelarão": "desempapelar",
    "desempapelaríamos": "desempapelar",
    "desempapelaríeis": "desempapelar",
    "desempapelas": "desempapelar",
    "desempapelasse": "desempapelar",
    "desempapelassem": "desempapelar",
    "desempapelasses": "desempapelar",
    "desempapelaste": "desempapelar",
    "desempapelastes": "desempapelar",
    "desempapelava": "desempapelar",
    "desempapelavam": "desempapelar",
    "desempapelavas": "desempapelar",
    "desempapele": "desempapelar",
    "desempapelei": "desempapelar",
    "desempapeleis": "desempapelar",
    "desempapelem": "desempapelar",
    "desempapelemo": "desempapelar",
    "desempapelemos": "desempapelar",
    "desempapeles": "desempapelar",
    "desempapelo": "desempapelar",
    "desempapelou": "desempapelar",
    "desempapelá": "desempapelar",
    "desempapelámo": "desempapelar",
    "desempapelámos": "desempapelar",
    "desempapeláramo": "desempapelar",
    "desempapeláramos": "desempapelar",
    "desempapelárei": "desempapelar",
    "desempapeláreis": "desempapelar",
    "desempapelásseis": "desempapelar",
    "desempapelássemos": "desempapelar",
    "desempapelávamo": "desempapelar",
    "desempapelávamos": "desempapelar",
    "desempapelávei": "desempapelar",
    "desempapeláveis": "desempapelar",
    "desempapem": "desempapar",
    "desempapemo": "desempapar",
    "desempapemos": "desempapar",
    "desempapes": "desempapar",
    "desempapo": "desempapar",
    "desempapou": "desempapar",
    "desempapá": "desempapar",
    "desempapámo": "desempapar",
    "desempapámos": "desempapar",
    "desempapáramo": "desempapar",
    "desempapáramos": "desempapar",
    "desempapárei": "desempapar",
    "desempapáreis": "desempapar",
    "desempapásseis": "desempapar",
    "desempapássemos": "desempapar",
    "desempapávamo": "desempapar",
    "desempapávamos": "desempapar",
    "desempapávei": "desempapar",
    "desempapáveis": "desempapar",
    "desempara": "desempar",
    "desemparam": "desempar",
    "desemparas": "desempar",
    "desemparceira": "desemparceirar",
    "desemparceirada": "desemparceirar",
    "desemparceiradas": "desemparceirar",
    "desemparceirado": "desemparceirar",
    "desemparceirados": "desemparceirar",
    "desemparceirai": "desemparceirar",
    "desemparceirais": "desemparceirar",
    "desemparceiram": "desemparceirar",
    "desemparceiramo": "desemparceirar",
    "desemparceiramos": "desemparceirar",
    "desemparceirando": "desemparceirar",
    "desemparceirara": "desemparceirar",
    "desemparceiraram": "desemparceirar",
    "desemparceiraras": "desemparceirar",
    "desemparceirarde": "desemparceirar",
    "desemparceirardes": "desemparceirar",
    "desemparceirare": "desemparceirar",
    "desemparceirarei": "desemparceirar",
    "desemparceirareis": "desemparceirar",
    "desemparceirarem": "desemparceirar",
    "desemparceiraremos": "desemparceirar",
    "desemparceirares": "desemparceirar",
    "desemparceiraria": "desemparceirar",
    "desemparceirariam": "desemparceirar",
    "desemparceirarias": "desemparceirar",
    "desemparceirarmo": "desemparceirar",
    "desemparceirarmos": "desemparceirar",
    "desemparceirará": "desemparceirar",
    "desemparceirarás": "desemparceirar",
    "desemparceirarão": "desemparceirar",
    "desemparceiraríamos": "desemparceirar",
    "desemparceiraríeis": "desemparceirar",
    "desemparceiras": "desemparceirar",
    "desemparceirasse": "desemparceirar",
    "desemparceirassem": "desemparceirar",
    "desemparceirasses": "desemparceirar",
    "desemparceiraste": "desemparceirar",
    "desemparceirastes": "desemparceirar",
    "desemparceirava": "desemparceirar",
    "desemparceiravam": "desemparceirar",
    "desemparceiravas": "desemparceirar",
    "desemparceire": "desemparceirar",
    "desemparceirei": "desemparceirar",
    "desemparceireis": "desemparceirar",
    "desemparceirem": "desemparceirar",
    "desemparceiremo": "desemparceirar",
    "desemparceiremos": "desemparceirar",
    "desemparceires": "desemparceirar",
    "desemparceiro": "desemparceirar",
    "desemparceirou": "desemparceirar",
    "desemparceirá": "desemparceirar",
    "desemparceirámo": "desemparceirar",
    "desemparceirámos": "desemparceirar",
    "desemparceiráramo": "desemparceirar",
    "desemparceiráramos": "desemparceirar",
    "desemparceirárei": "desemparceirar",
    "desemparceiráreis": "desemparceirar",
    "desemparceirásseis": "desemparceirar",
    "desemparceirássemos": "desemparceirar",
    "desemparceirávamo": "desemparceirar",
    "desemparceirávamos": "desemparceirar",
    "desemparceirávei": "desemparceirar",
    "desemparceiráveis": "desemparceirar",
    "desemparde": "desempar",
    "desempardes": "desempar",
    "desempare": "desempar",
    "desempareda": "desemparedar",
    "desemparedada": "desemparedar",
    "desemparedadas": "desemparedar",
    "desemparedado": "desemparedar",
    "desemparedados": "desemparedar",
    "desemparedai": "desemparedar",
    "desemparedais": "desemparedar",
    "desemparedam": "desemparedar",
    "desemparedamo": "desemparedar",
    "desemparedamos": "desemparedar",
    "desemparedando": "desemparedar",
    "desemparedara": "desemparedar",
    "desemparedaram": "desemparedar",
    "desemparedaras": "desemparedar",
    "desemparedarde": "desemparedar",
    "desemparedardes": "desemparedar",
    "desemparedare": "desemparedar",
    "desemparedarei": "desemparedar",
    "desemparedareis": "desemparedar",
    "desemparedarem": "desemparedar",
    "desemparedaremos": "desemparedar",
    "desemparedares": "desemparedar",
    "desemparedaria": "desemparedar",
    "desemparedariam": "desemparedar",
    "desemparedarias": "desemparedar",
    "desemparedarmo": "desemparedar",
    "desemparedarmos": "desemparedar",
    "desemparedará": "desemparedar",
    "desemparedarás": "desemparedar",
    "desemparedarão": "desemparedar",
    "desemparedaríamos": "desemparedar",
    "desemparedaríeis": "desemparedar",
    "desemparedas": "desemparedar",
    "desemparedasse": "desemparedar",
    "desemparedassem": "desemparedar",
    "desemparedasses": "desemparedar",
    "desemparedaste": "desemparedar",
    "desemparedastes": "desemparedar",
    "desemparedava": "desemparedar",
    "desemparedavam": "desemparedar",
    "desemparedavas": "desemparedar",
    "desemparede": "desemparedar",
    "desemparedei": "desemparedar",
    "desemparedeis": "desemparedar",
    "desemparedem": "desemparedar",
    "desemparedemo": "desemparedar",
    "desemparedemos": "desemparedar",
    "desemparedes": "desemparedar",
    "desemparedo": "desemparedar",
    "desemparedou": "desemparedar",
    "desemparedá": "desemparedar",
    "desemparedámo": "desemparedar",
    "desemparedámos": "desemparedar",
    "desemparedáramo": "desemparedar",
    "desemparedáramos": "desemparedar",
    "desemparedárei": "desemparedar",
    "desemparedáreis": "desemparedar",
    "desemparedásseis": "desemparedar",
    "desemparedássemos": "desemparedar",
    "desemparedávamo": "desemparedar",
    "desemparedávamos": "desemparedar",
    "desemparedávei": "desemparedar",
    "desemparedáveis": "desemparedar",
    "desemparei": "desempar",
    "desempareis": "desempar",
    "desemparelha": "desemparelhar",
    "desemparelhada": "desemparelhar",
    "desemparelhadas": "desemparelhar",
    "desemparelhado": "desemparelhar",
    "desemparelhados": "desemparelhar",
    "desemparelhai": "desemparelhar",
    "desemparelhais": "desemparelhar",
    "desemparelham": "desemparelhar",
    "desemparelhamentos": "desemparelhamento",
    "desemparelhamo": "desemparelhar",
    "desemparelhamos": "desemparelhar",
    "desemparelhando": "desemparelhar",
    "desemparelhara": "desemparelhar",
    "desemparelharam": "desemparelhar",
    "desemparelharas": "desemparelhar",
    "desemparelharde": "desemparelhar",
    "desemparelhardes": "desemparelhar",
    "desemparelhare": "desemparelhar",
    "desemparelharei": "desemparelhar",
    "desemparelhareis": "desemparelhar",
    "desemparelharem": "desemparelhar",
    "desemparelharemos": "desemparelhar",
    "desemparelhares": "desemparelhar",
    "desemparelharia": "desemparelhar",
    "desemparelhariam": "desemparelhar",
    "desemparelharias": "desemparelhar",
    "desemparelharmo": "desemparelhar",
    "desemparelharmos": "desemparelhar",
    "desemparelhará": "desemparelhar",
    "desemparelharás": "desemparelhar",
    "desemparelharão": "desemparelhar",
    "desemparelharíamos": "desemparelhar",
    "desemparelharíeis": "desemparelhar",
    "desemparelhas": "desemparelhar",
    "desemparelhasse": "desemparelhar",
    "desemparelhassem": "desemparelhar",
    "desemparelhasses": "desemparelhar",
    "desemparelhaste": "desemparelhar",
    "desemparelhastes": "desemparelhar",
    "desemparelhava": "desemparelhar",
    "desemparelhavam": "desemparelhar",
    "desemparelhavas": "desemparelhar",
    "desemparelhe": "desemparelhar",
    "desemparelhei": "desemparelhar",
    "desemparelheis": "desemparelhar",
    "desemparelhem": "desemparelhar",
    "desemparelhemo": "desemparelhar",
    "desemparelhemos": "desemparelhar",
    "desemparelhes": "desemparelhar",
    "desemparelho": "desemparelhar",
    "desemparelhou": "desemparelhar",
    "desemparelhá": "desemparelhar",
    "desemparelhámo": "desemparelhar",
    "desemparelhámos": "desemparelhar",
    "desemparelháramo": "desemparelhar",
    "desemparelháramos": "desemparelhar",
    "desemparelhárei": "desemparelhar",
    "desemparelháreis": "desemparelhar",
    "desemparelhásseis": "desemparelhar",
    "desemparelhássemos": "desemparelhar",
    "desemparelhávamo": "desemparelhar",
    "desemparelhávamos": "desemparelhar",
    "desemparelhávei": "desemparelhar",
    "desemparelháveis": "desemparelhar",
    "desemparem": "desempar",
    "desemparemos": "desempar",
    "desempares": "desempar",
    "desemparia": "desempar",
    "desempariam": "desempar",
    "desemparias": "desempar",
    "desemparmo": "desempar",
    "desemparmos": "desempar",
    "desempará": "desempar",
    "desemparás": "desempar",
    "desemparão": "desempar",
    "desemparíamos": "desempar",
    "desemparíeis": "desempar",
    "desempas": "desempar",
    "desempasse": "desempar",
    "desempassem": "desempar",
    "desempasses": "desempar",
    "desempasta": "desempastar",
    "desempastada": "desempastar",
    "desempastadas": "desempastar",
    "desempastado": "desempastar",
    "desempastados": "desempastar",
    "desempastai": "desempastar",
    "desempastais": "desempastar",
    "desempastam": "desempastar",
    "desempastamo": "desempastar",
    "desempastamos": "desempastar",
    "desempastando": "desempastar",
    "desempastara": "desempastar",
    "desempastaram": "desempastar",
    "desempastaras": "desempastar",
    "desempastarde": "desempastar",
    "desempastardes": "desempastar",
    "desempastare": "desempastar",
    "desempastarei": "desempastar",
    "desempastareis": "desempastar",
    "desempastarem": "desempastar",
    "desempastaremos": "desempastar",
    "desempastares": "desempastar",
    "desempastaria": "desempastar",
    "desempastariam": "desempastar",
    "desempastarias": "desempastar",
    "desempastarmo": "desempastar",
    "desempastarmos": "desempastar",
    "desempastará": "desempastar",
    "desempastarás": "desempastar",
    "desempastarão": "desempastar",
    "desempastaríamos": "desempastar",
    "desempastaríeis": "desempastar",
    "desempastas": "desempastar",
    "desempastasse": "desempastar",
    "desempastassem": "desempastar",
    "desempastasses": "desempastar",
    "desempastaste": "desempastar",
    "desempastastes": "desempastar",
    "desempastava": "desempastar",
    "desempastavam": "desempastar",
    "desempastavas": "desempastar",
    "desempaste": "desempastar",
    "desempastei": "desempastar",
    "desempasteis": "desempastar",
    "desempastela": "desempastelar",
    "desempastelada": "desempastelar",
    "desempasteladas": "desempastelar",
    "desempastelado": "desempastelar",
    "desempastelados": "desempastelar",
    "desempastelai": "desempastelar",
    "desempastelais": "desempastelar",
    "desempastelam": "desempastelar",
    "desempastelamo": "desempastelar",
    "desempastelamos": "desempastelar",
    "desempastelando": "desempastelar",
    "desempastelara": "desempastelar",
    "desempastelaram": "desempastelar",
    "desempastelaras": "desempastelar",
    "desempastelarde": "desempastelar",
    "desempastelardes": "desempastelar",
    "desempastelare": "desempastelar",
    "desempastelarei": "desempastelar",
    "desempastelareis": "desempastelar",
    "desempastelarem": "desempastelar",
    "desempastelaremos": "desempastelar",
    "desempastelares": "desempastelar",
    "desempastelaria": "desempastelar",
    "desempastelariam": "desempastelar",
    "desempastelarias": "desempastelar",
    "desempastelarmo": "desempastelar",
    "desempastelarmos": "desempastelar",
    "desempastelará": "desempastelar",
    "desempastelarás": "desempastelar",
    "desempastelarão": "desempastelar",
    "desempastelaríamos": "desempastelar",
    "desempastelaríeis": "desempastelar",
    "desempastelas": "desempastelar",
    "desempastelasse": "desempastelar",
    "desempastelassem": "desempastelar",
    "desempastelasses": "desempastelar",
    "desempastelaste": "desempastelar",
    "desempastelastes": "desempastelar",
    "desempastelava": "desempastelar",
    "desempastelavam": "desempastelar",
    "desempastelavas": "desempastelar",
    "desempastele": "desempastelar",
    "desempastelei": "desempastelar",
    "desempasteleis": "desempastelar",
    "desempastelem": "desempastelar",
    "desempastelemo": "desempastelar",
    "desempastelemos": "desempastelar",
    "desempasteles": "desempastelar",
    "desempastelo": "desempastelar",
    "desempastelou": "desempastelar",
    "desempastelá": "desempastelar",
    "desempastelámo": "desempastelar",
    "desempastelámos": "desempastelar",
    "desempasteláramo": "desempastelar",
    "desempasteláramos": "desempastelar",
    "desempastelárei": "desempastelar",
    "desempasteláreis": "desempastelar",
    "desempastelásseis": "desempastelar",
    "desempastelássemos": "desempastelar",
    "desempastelávamo": "desempastelar",
    "desempastelávamos": "desempastelar",
    "desempastelávei": "desempastelar",
    "desempasteláveis": "desempastelar",
    "desempastem": "desempastar",
    "desempastemo": "desempastar",
    "desempastemos": "desempastar",
    "desempastes": "desempastar",
    "desempasto": "desempastar",
    "desempastou": "desempastar",
    "desempastá": "desempastar",
    "desempastámo": "desempastar",
    "desempastámos": "desempastar",
    "desempastáramo": "desempastar",
    "desempastáramos": "desempastar",
    "desempastárei": "desempastar",
    "desempastáreis": "desempastar",
    "desempastásseis": "desempastar",
    "desempastássemos": "desempastar",
    "desempastávamo": "desempastar",
    "desempastávamos": "desempastar",
    "desempastávei": "desempastar",
    "desempastáveis": "desempastar",
    "desempata": "desempatar",
    "desempatada": "desempatar",
    "desempatadas": "desempatar",
    "desempatado": "desempatar",
    "desempatados": "desempatar",
    "desempatai": "desempatar",
    "desempatais": "desempatar",
    "desempatam": "desempatar",
    "desempatamo": "desempatar",
    "desempatamos": "desempatar",
    "desempatando": "desempatar",
    "desempatara": "desempatar",
    "desempataram": "desempatar",
    "desempataras": "desempatar",
    "desempatarde": "desempatar",
    "desempatardes": "desempatar",
    "desempatare": "desempatar",
    "desempatarei": "desempatar",
    "desempatareis": "desempatar",
    "desempatarem": "desempatar",
    "desempataremos": "desempatar",
    "desempatares": "desempatar",
    "desempataria": "desempatar",
    "desempatariam": "desempatar",
    "desempatarias": "desempatar",
    "desempatarmo": "desempatar",
    "desempatarmos": "desempatar",
    "desempatará": "desempatar",
    "desempatarás": "desempatar",
    "desempatarão": "desempatar",
    "desempataríamos": "desempatar",
    "desempataríeis": "desempatar",
    "desempatas": "desempatar",
    "desempatasse": "desempatar",
    "desempatassem": "desempatar",
    "desempatasses": "desempatar",
    "desempataste": "desempatar",
    "desempatastes": "desempatar",
    "desempatava": "desempatar",
    "desempatavam": "desempatar",
    "desempatavas": "desempatar",
    "desempate": "desempatar",
    "desempatei": "desempatar",
    "desempateis": "desempatar",
    "desempatem": "desempatar",
    "desempatemo": "desempatar",
    "desempatemos": "desempatar",
    "desempates": "desempate",
    "desempato": "desempatar",
    "desempatou": "desempatar",
    "desempatá": "desempatar",
    "desempatámo": "desempatar",
    "desempatámos": "desempatar",
    "desempatáramo": "desempatar",
    "desempatáramos": "desempatar",
    "desempatárei": "desempatar",
    "desempatáreis": "desempatar",
    "desempatásseis": "desempatar",
    "desempatássemos": "desempatar",
    "desempatávamo": "desempatar",
    "desempatávamos": "desempatar",
    "desempatávei": "desempatar",
    "desempatáveis": "desempatável",
    "desempava": "desempar",
    "desempavam": "desempar",
    "desempavas": "desempar",
    "desempe": "desempar",
    "desempece": "desempecer",
    "desempecei": "desempecer",
    "desempeceis": "desempecer",
    "desempecem": "desempecer",
    "desempecemo": "desempecer",
    "desempecemos": "desempecer",
    "desempecendo": "desempecer",
    "desempecera": "desempecer",
    "desempeceram": "desempecer",
    "desempeceras": "desempecer",
    "desempecerde": "desempecer",
    "desempecerdes": "desempecer",
    "desempecere": "desempecer",
    "desempecerei": "desempecer",
    "desempecereis": "desempecer",
    "desempecerem": "desempecer",
    "desempeceremos": "desempecer",
    "desempeceres": "desempecer",
    "desempeceria": "desempecer",
    "desempeceriam": "desempecer",
    "desempecerias": "desempecer",
    "desempecermo": "desempecer",
    "desempecermos": "desempecer",
    "desempecerá": "desempecer",
    "desempecerás": "desempecer",
    "desempecerão": "desempecer",
    "desempeceríamos": "desempecer",
    "desempeceríeis": "desempecer",
    "desempeces": "desempecer",
    "desempecesse": "desempecer",
    "desempecessem": "desempecer",
    "desempecesses": "desempecer",
    "desempeceste": "desempecer",
    "desempecestes": "desempecer",
    "desempeceu": "desempecer",
    "desempeci": "desempecer",
    "desempecia": "desempecer",
    "desempeciam": "desempecer",
    "desempecias": "desempecer",
    "desempecida": "desempecer",
    "desempecidas": "desempecer",
    "desempecido": "desempecer",
    "desempecidos": "desempecer",
    "desempecilha": "desempecilhar",
    "desempecilhada": "desempecilhar",
    "desempecilhadas": "desempecilhar",
    "desempecilhado": "desempecilhar",
    "desempecilhados": "desempecilhar",
    "desempecilhai": "desempecilhar",
    "desempecilhais": "desempecilhar",
    "desempecilham": "desempecilhar",
    "desempecilhamo": "desempecilhar",
    "desempecilhamos": "desempecilhar",
    "desempecilhando": "desempecilhar",
    "desempecilhara": "desempecilhar",
    "desempecilharam": "desempecilhar",
    "desempecilharas": "desempecilhar",
    "desempecilharde": "desempecilhar",
    "desempecilhardes": "desempecilhar",
    "desempecilhare": "desempecilhar",
    "desempecilharei": "desempecilhar",
    "desempecilhareis": "desempecilhar",
    "desempecilharem": "desempecilhar",
    "desempecilharemos": "desempecilhar",
    "desempecilhares": "desempecilhar",
    "desempecilharia": "desempecilhar",
    "desempecilhariam": "desempecilhar",
    "desempecilharias": "desempecilhar",
    "desempecilharmo": "desempecilhar",
    "desempecilharmos": "desempecilhar",
    "desempecilhará": "desempecilhar",
    "desempecilharás": "desempecilhar",
    "desempecilharão": "desempecilhar",
    "desempecilharíamos": "desempecilhar",
    "desempecilharíeis": "desempecilhar",
    "desempecilhas": "desempecilhar",
    "desempecilhasse": "desempecilhar",
    "desempecilhassem": "desempecilhar",
    "desempecilhasses": "desempecilhar",
    "desempecilhaste": "desempecilhar",
    "desempecilhastes": "desempecilhar",
    "desempecilhava": "desempecilhar",
    "desempecilhavam": "desempecilhar",
    "desempecilhavas": "desempecilhar",
    "desempecilhe": "desempecilhar",
    "desempecilhei": "desempecilhar",
    "desempecilheis": "desempecilhar",
    "desempecilhem": "desempecilhar",
    "desempecilhemo": "desempecilhar",
    "desempecilhemos": "desempecilhar",
    "desempecilhes": "desempecilhar",
    "desempecilho": "desempecilhar",
    "desempecilhou": "desempecilhar",
    "desempecilhá": "desempecilhar",
    "desempecilhámo": "desempecilhar",
    "desempecilhámos": "desempecilhar",
    "desempecilháramo": "desempecilhar",
    "desempecilháramos": "desempecilhar",
    "desempecilhárei": "desempecilhar",
    "desempecilháreis": "desempecilhar",
    "desempecilhásseis": "desempecilhar",
    "desempecilhássemos": "desempecilhar",
    "desempecilhávamo": "desempecilhar",
    "desempecilhávamos": "desempecilhar",
    "desempecilhávei": "desempecilhar",
    "desempecilháveis": "desempecilhar",
    "desempecê": "desempecer",
    "desempecêramo": "desempecer",
    "desempecêramos": "desempecer",
    "desempecêrei": "desempecer",
    "desempecêreis": "desempecer",
    "desempecêsseis": "desempecer",
    "desempecêssemos": "desempecer",
    "desempecíamo": "desempecer",
    "desempecíamos": "desempecer",
    "desempecíei": "desempecer",
    "desempecíeis": "desempecer",
    "desempederna": "desempedernir",
    "desempedernais": "desempedernir",
    "desempedernam": "desempedernir",
    "desempedernamo": "desempedernir",
    "desempedernamos": "desempedernir",
    "desempedernas": "desempedernir",
    "desempederne": "desempedernir",
    "desempedernem": "desempedernir",
    "desempedernes": "desempedernir",
    "desempederni": "desempedernir",
    "desempedernia": "desempedernir",
    "desempederniam": "desempedernir",
    "desempedernias": "desempedernir",
    "desempedernida": "desempedernir",
    "desempedernidas": "desempedernir",
    "desempedernido": "desempedernir",
    "desempedernidos": "desempedernir",
    "desempedernimo": "desempedernir",
    "desempedernimos": "desempedernir",
    "desempedernindo": "desempedernir",
    "desempedernira": "desempedernir",
    "desempederniram": "desempedernir",
    "desempederniras": "desempedernir",
    "desempedernirde": "desempedernir",
    "desempedernirdes": "desempedernir",
    "desempedernire": "desempedernir",
    "desempedernirei": "desempedernir",
    "desempedernireis": "desempedernir",
    "desempedernirem": "desempedernir",
    "desempederniremos": "desempedernir",
    "desempedernires": "desempedernir",
    "desempederniria": "desempedernir",
    "desempederniriam": "desempedernir",
    "desempedernirias": "desempedernir",
    "desempedernirmo": "desempedernir",
    "desempedernirmos": "desempedernir",
    "desempedernirá": "desempedernir",
    "desempedernirás": "desempedernir",
    "desempedernirão": "desempedernir",
    "desempederniríamos": "desempedernir",
    "desempederniríeis": "desempedernir",
    "desempedernis": "desempedernir",
    "desempedernisse": "desempedernir",
    "desempedernissem": "desempedernir",
    "desempedernisses": "desempedernir",
    "desempederniste": "desempedernir",
    "desempedernistes": "desempedernir",
    "desempederniu": "desempedernir",
    "desempederno": "desempedernir",
    "desempederníamo": "desempedernir",
    "desempederníamos": "desempedernir",
    "desempederníei": "desempedernir",
    "desempederníeis": "desempedernir",
    "desempederníramo": "desempedernir",
    "desempederníramos": "desempedernir",
    "desempedernírei": "desempedernir",
    "desempederníreis": "desempedernir",
    "desempedernísseis": "desempedernir",
    "desempederníssemos": "desempedernir",
    "desempedra": "desempedrar",
    "desempedrada": "desempedrar",
    "desempedradas": "desempedrar",
    "desempedrado": "desempedrar",
    "desempedrados": "desempedrar",
    "desempedrai": "desempedrar",
    "desempedrais": "desempedrar",
    "desempedram": "desempedrar",
    "desempedramo": "desempedrar",
    "desempedramos": "desempedrar",
    "desempedrando": "desempedrar",
    "desempedrara": "desempedrar",
    "desempedraram": "desempedrar",
    "desempedraras": "desempedrar",
    "desempedrarde": "desempedrar",
    "desempedrardes": "desempedrar",
    "desempedrare": "desempedrar",
    "desempedrarei": "desempedrar",
    "desempedrareis": "desempedrar",
    "desempedrarem": "desempedrar",
    "desempedraremos": "desempedrar",
    "desempedrares": "desempedrar",
    "desempedraria": "desempedrar",
    "desempedrariam": "desempedrar",
    "desempedrarias": "desempedrar",
    "desempedrarmo": "desempedrar",
    "desempedrarmos": "desempedrar",
    "desempedrará": "desempedrar",
    "desempedrarás": "desempedrar",
    "desempedrarão": "desempedrar",
    "desempedraríamos": "desempedrar",
    "desempedraríeis": "desempedrar",
    "desempedras": "desempedrar",
    "desempedrasse": "desempedrar",
    "desempedrassem": "desempedrar",
    "desempedrasses": "desempedrar",
    "desempedraste": "desempedrar",
    "desempedrastes": "desempedrar",
    "desempedrava": "desempedrar",
    "desempedravam": "desempedrar",
    "desempedravas": "desempedrar",
    "desempedre": "desempedrar",
    "desempedrei": "desempedrar",
    "desempedreis": "desempedrar",
    "desempedrem": "desempedrar",
    "desempedremo": "desempedrar",
    "desempedremos": "desempedrar",
    "desempedres": "desempedrar",
    "desempedro": "desempedrar",
    "desempedrou": "desempedrar",
    "desempedrá": "desempedrar",
    "desempedrámo": "desempedrar",
    "desempedrámos": "desempedrar",
    "desempedráramo": "desempedrar",
    "desempedráramos": "desempedrar",
    "desempedrárei": "desempedrar",
    "desempedráreis": "desempedrar",
    "desempedrásseis": "desempedrar",
    "desempedrássemos": "desempedrar",
    "desempedrávamo": "desempedrar",
    "desempedrávamos": "desempedrar",
    "desempedrávei": "desempedrar",
    "desempedráveis": "desempedrar",
    "desempei": "desempar",
    "desempeis": "desempar",
    "desempem": "desempar",
    "desempemo": "desempar",
    "desempemos": "desempar",
    "desempena": "desempenar",
    "desempenada": "desempenar",
    "desempenadas": "desempenar",
    "desempenadeiras": "desempenadeira",
    "desempenado": "desempenar",
    "desempenados": "desempenar",
    "desempenadíssima": "desempenado",
    "desempenadíssimas": "desempenado",
    "desempenadíssimo": "desempenado",
    "desempenadíssimos": "desempenado",
    "desempenai": "desempenar",
    "desempenais": "desempenar",
    "desempenam": "desempenar",
    "desempenamo": "desempenar",
    "desempenamos": "desempenar",
    "desempenando": "desempenar",
    "desempenara": "desempenar",
    "desempenaram": "desempenar",
    "desempenaras": "desempenar",
    "desempenarde": "desempenar",
    "desempenardes": "desempenar",
    "desempenare": "desempenar",
    "desempenarei": "desempenar",
    "desempenareis": "desempenar",
    "desempenarem": "desempenar",
    "desempenaremos": "desempenar",
    "desempenares": "desempenar",
    "desempenaria": "desempenar",
    "desempenariam": "desempenar",
    "desempenarias": "desempenar",
    "desempenarmo": "desempenar",
    "desempenarmos": "desempenar",
    "desempenará": "desempenar",
    "desempenarás": "desempenar",
    "desempenarão": "desempenar",
    "desempenaríamos": "desempenar",
    "desempenaríeis": "desempenar",
    "desempenas": "desempenar",
    "desempenasse": "desempenar",
    "desempenassem": "desempenar",
    "desempenasses": "desempenar",
    "desempenaste": "desempenar",
    "desempenastes": "desempenar",
    "desempenava": "desempenar",
    "desempenavam": "desempenar",
    "desempenavas": "desempenar",
    "desempene": "desempenar",
    "desempenei": "desempenar",
    "desempeneis": "desempenar",
    "desempenem": "desempenar",
    "desempenemo": "desempenar",
    "desempenemos": "desempenar",
    "desempenes": "desempenar",
    "desempenha": "desempenhar",
    "desempenhada": "desempenhar",
    "desempenhadas": "desempenhar",
    "desempenhado": "desempenhar",
    "desempenhados": "desempenhar",
    "desempenhai": "desempenhar",
    "desempenhais": "desempenhar",
    "desempenham": "desempenhar",
    "desempenhamo": "desempenhar",
    "desempenhamos": "desempenhar",
    "desempenhando": "desempenhar",
    "desempenhara": "desempenhar",
    "desempenharam": "desempenhar",
    "desempenharas": "desempenhar",
    "desempenharde": "desempenhar",
    "desempenhardes": "desempenhar",
    "desempenhare": "desempenhar",
    "desempenharei": "desempenhar",
    "desempenhareis": "desempenhar",
    "desempenharem": "desempenhar",
    "desempenharemos": "desempenhar",
    "desempenhares": "desempenhar",
    "desempenharia": "desempenhar",
    "desempenhariam": "desempenhar",
    "desempenharias": "desempenhar",
    "desempenharmo": "desempenhar",
    "desempenharmos": "desempenhar",
    "desempenhará": "desempenhar",
    "desempenharás": "desempenhar",
    "desempenharão": "desempenhar",
    "desempenharíamos": "desempenhar",
    "desempenharíeis": "desempenhar",
    "desempenhas": "desempenhar",
    "desempenhasse": "desempenhar",
    "desempenhassem": "desempenhar",
    "desempenhasses": "desempenhar",
    "desempenhaste": "desempenhar",
    "desempenhastes": "desempenhar",
    "desempenhava": "desempenhar",
    "desempenhavam": "desempenhar",
    "desempenhavas": "desempenhar",
    "desempenhe": "desempenhar",
    "desempenhei": "desempenhar",
    "desempenheis": "desempenhar",
    "desempenhem": "desempenhar",
    "desempenhemo": "desempenhar",
    "desempenhemos": "desempenhar",
    "desempenhes": "desempenhar",
    "desempenho": "desempenhar",
    "desempenhos": "desempenho",
    "desempenhou": "desempenhar",
    "desempenhá": "desempenhar",
    "desempenhámo": "desempenhar",
    "desempenhámos": "desempenhar",
    "desempenháramo": "desempenhar",
    "desempenháramos": "desempenhar",
    "desempenhárei": "desempenhar",
    "desempenháreis": "desempenhar",
    "desempenhásseis": "desempenhar",
    "desempenhássemos": "desempenhar",
    "desempenhávamo": "desempenhar",
    "desempenhávamos": "desempenhar",
    "desempenhávei": "desempenhar",
    "desempenháveis": "desempenhar",
    "desempeno": "desempenar",
    "desempenos": "desempeno",
    "desempenou": "desempenar",
    "desempená": "desempenar",
    "desempenámo": "desempenar",
    "desempenámos": "desempenar",
    "desempenáramo": "desempenar",
    "desempenáramos": "desempenar",
    "desempenárei": "desempenar",
    "desempenáreis": "desempenar",
    "desempenásseis": "desempenar",
    "desempenássemos": "desempenar",
    "desempenávamo": "desempenar",
    "desempenávamos": "desempenar",
    "desempenávei": "desempenar",
    "desempenáveis": "desempenar",
    "desemperra": "desemperrar",
    "desemperrada": "desemperrar",
    "desemperradas": "desemperrar",
    "desemperrado": "desemperrar",
    "desemperrados": "desemperrar",
    "desemperrai": "desemperrar",
    "desemperrais": "desemperrar",
    "desemperram": "desemperrar",
    "desemperramentos": "desemperramento",
    "desemperramo": "desemperrar",
    "desemperramos": "desemperrar",
    "desemperrando": "desemperrar",
    "desemperrara": "desemperrar",
    "desemperraram": "desemperrar",
    "desemperraras": "desemperrar",
    "desemperrarde": "desemperrar",
    "desemperrardes": "desemperrar",
    "desemperrare": "desemperrar",
    "desemperrarei": "desemperrar",
    "desemperrareis": "desemperrar",
    "desemperrarem": "desemperrar",
    "desemperraremos": "desemperrar",
    "desemperrares": "desemperrar",
    "desemperraria": "desemperrar",
    "desemperrariam": "desemperrar",
    "desemperrarias": "desemperrar",
    "desemperrarmo": "desemperrar",
    "desemperrarmos": "desemperrar",
    "desemperrará": "desemperrar",
    "desemperrarás": "desemperrar",
    "desemperrarão": "desemperrar",
    "desemperraríamos": "desemperrar",
    "desemperraríeis": "desemperrar",
    "desemperras": "desemperrar",
    "desemperrasse": "desemperrar",
    "desemperrassem": "desemperrar",
    "desemperrasses": "desemperrar",
    "desemperraste": "desemperrar",
    "desemperrastes": "desemperrar",
    "desemperrava": "desemperrar",
    "desemperravam": "desemperrar",
    "desemperravas": "desemperrar",
    "desemperre": "desemperrar",
    "desemperrei": "desemperrar",
    "desemperreis": "desemperrar",
    "desemperrem": "desemperrar",
    "desemperremo": "desemperrar",
    "desemperremos": "desemperrar",
    "desemperres": "desemperrar",
    "desemperro": "desemperrar",
    "desemperros": "desemperro",
    "desemperrou": "desemperrar",
    "desemperrá": "desemperrar",
    "desemperrámo": "desemperrar",
    "desemperrámos": "desemperrar",
    "desemperráramo": "desemperrar",
    "desemperráramos": "desemperrar",
    "desemperrárei": "desemperrar",
    "desemperráreis": "desemperrar",
    "desemperrásseis": "desemperrar",
    "desemperrássemos": "desemperrar",
    "desemperrávamo": "desemperrar",
    "desemperrávamos": "desemperrar",
    "desemperrávei": "desemperrar",
    "desemperráveis": "desemperrar",
    "desempertiga": "desempertigar",
    "desempertigada": "desempertigar",
    "desempertigadas": "desempertigar",
    "desempertigado": "desempertigar",
    "desempertigados": "desempertigar",
    "desempertigai": "desempertigar",
    "desempertigais": "desempertigar",
    "desempertigam": "desempertigar",
    "desempertigamo": "desempertigar",
    "desempertigamos": "desempertigar",
    "desempertigando": "desempertigar",
    "desempertigara": "desempertigar",
    "desempertigaram": "desempertigar",
    "desempertigaras": "desempertigar",
    "desempertigarde": "desempertigar",
    "desempertigardes": "desempertigar",
    "desempertigare": "desempertigar",
    "desempertigarei": "desempertigar",
    "desempertigareis": "desempertigar",
    "desempertigarem": "desempertigar",
    "desempertigaremos": "desempertigar",
    "desempertigares": "desempertigar",
    "desempertigaria": "desempertigar",
    "desempertigariam": "desempertigar",
    "desempertigarias": "desempertigar",
    "desempertigarmo": "desempertigar",
    "desempertigarmos": "desempertigar",
    "desempertigará": "desempertigar",
    "desempertigarás": "desempertigar",
    "desempertigarão": "desempertigar",
    "desempertigaríamos": "desempertigar",
    "desempertigaríeis": "desempertigar",
    "desempertigas": "desempertigar",
    "desempertigasse": "desempertigar",
    "desempertigassem": "desempertigar",
    "desempertigasses": "desempertigar",
    "desempertigaste": "desempertigar",
    "desempertigastes": "desempertigar",
    "desempertigava": "desempertigar",
    "desempertigavam": "desempertigar",
    "desempertigavas": "desempertigar",
    "desempertigo": "desempertigar",
    "desempertigou": "desempertigar",
    "desempertigue": "desempertigar",
    "desempertiguei": "desempertigar",
    "desempertigueis": "desempertigar",
    "desempertiguem": "desempertigar",
    "desempertiguemo": "desempertigar",
    "desempertiguemos": "desempertigar",
    "desempertigues": "desempertigar",
    "desempertigá": "desempertigar",
    "desempertigámo": "desempertigar",
    "desempertigámos": "desempertigar",
    "desempertigáramo": "desempertigar",
    "desempertigáramos": "desempertigar",
    "desempertigárei": "desempertigar",
    "desempertigáreis": "desempertigar",
    "desempertigásseis": "desempertigar",
    "desempertigássemos": "desempertigar",
    "desempertigávamo": "desempertigar",
    "desempertigávamos": "desempertigar",
    "desempertigávei": "desempertigar",
    "desempertigáveis": "desempertigar",
    "desempes": "desempar",
    "desempesta": "desempestar",
    "desempestada": "desempestar",
    "desempestadas": "desempestar",
    "desempestado": "desempestar",
    "desempestados": "desempestar",
    "desempestai": "desempestar",
    "desempestais": "desempestar",
    "desempestam": "desempestar",
    "desempestamo": "desempestar",
    "desempestamos": "desempestar",
    "desempestando": "desempestar",
    "desempestara": "desempestar",
    "desempestaram": "desempestar",
    "desempestaras": "desempestar",
    "desempestarde": "desempestar",
    "desempestardes": "desempestar",
    "desempestare": "desempestar",
    "desempestarei": "desempestar",
    "desempestareis": "desempestar",
    "desempestarem": "desempestar",
    "desempestaremos": "desempestar",
    "desempestares": "desempestar",
    "desempestaria": "desempestar",
    "desempestariam": "desempestar",
    "desempestarias": "desempestar",
    "desempestarmo": "desempestar",
    "desempestarmos": "desempestar",
    "desempestará": "desempestar",
    "desempestarás": "desempestar",
    "desempestarão": "desempestar",
    "desempestaríamos": "desempestar",
    "desempestaríeis": "desempestar",
    "desempestas": "desempestar",
    "desempestasse": "desempestar",
    "desempestassem": "desempestar",
    "desempestasses": "desempestar",
    "desempestaste": "desempestar",
    "desempestastes": "desempestar",
    "desempestava": "desempestar",
    "desempestavam": "desempestar",
    "desempestavas": "desempestar",
    "desempeste": "desempestar",
    "desempestei": "desempestar",
    "desempesteis": "desempestar",
    "desempestem": "desempestar",
    "desempestemo": "desempestar",
    "desempestemos": "desempestar",
    "desempestes": "desempestar",
    "desempesto": "desempestar",
    "desempestou": "desempestar",
    "desempestá": "desempestar",
    "desempestámo": "desempestar",
    "desempestámos": "desempestar",
    "desempestáramo": "desempestar",
    "desempestáramos": "desempestar",
    "desempestárei": "desempestar",
    "desempestáreis": "desempestar",
    "desempestásseis": "desempestar",
    "desempestássemos": "desempestar",
    "desempestávamo": "desempestar",
    "desempestávamos": "desempestar",
    "desempestávei": "desempestar",
    "desempestáveis": "desempestar",
    "desempeça": "desempecer",
    "desempeçada": "desempeçar",
    "desempeçadas": "desempeçar",
    "desempeçado": "desempeçar",
    "desempeçados": "desempeçar",
    "desempeçai": "desempeçar",
    "desempeçais": "desempecer",
    "desempeçam": "desempecer",
    "desempeçamo": "desempecer",
    "desempeçamos": "desempecer",
    "desempeçando": "desempeçar",
    "desempeçara": "desempeçar",
    "desempeçaram": "desempeçar",
    "desempeçaras": "desempeçar",
    "desempeçarde": "desempeçar",
    "desempeçardes": "desempeçar",
    "desempeçare": "desempeçar",
    "desempeçarei": "desempeçar",
    "desempeçareis": "desempeçar",
    "desempeçarem": "desempeçar",
    "desempeçaremos": "desempeçar",
    "desempeçares": "desempeçar",
    "desempeçaria": "desempeçar",
    "desempeçariam": "desempeçar",
    "desempeçarias": "desempeçar",
    "desempeçarmo": "desempeçar",
    "desempeçarmos": "desempeçar",
    "desempeçará": "desempeçar",
    "desempeçarás": "desempeçar",
    "desempeçarão": "desempeçar",
    "desempeçaríamos": "desempeçar",
    "desempeçaríeis": "desempeçar",
    "desempeças": "desempecer",
    "desempeçasse": "desempeçar",
    "desempeçassem": "desempeçar",
    "desempeçasses": "desempeçar",
    "desempeçaste": "desempeçar",
    "desempeçastes": "desempeçar",
    "desempeçava": "desempeçar",
    "desempeçavam": "desempeçar",
    "desempeçavas": "desempeçar",
    "desempeço": "desempecer",
    "desempeçonha": "onhar",
    "desempeçonhada": "desempeçonhar",
    "desempeçonhadas": "desempeçonhar",
    "desempeçonhado": "desempeçonhar",
    "desempeçonhados": "desempeçonhar",
    "desempeçonhai": "desempeçonhar",
    "desempeçonhais": "desempeçonhar",
    "desempeçonham": "desempeçonhar",
    "desempeçonhamo": "desempeçonhar",
    "desempeçonhamos": "desempeçonhar",
    "desempeçonhando": "desempeçonhar",
    "desempeçonhar": "onhar",
    "desempeçonhara": "onhar",
    "desempeçonharam": "onhar",
    "desempeçonharas": "desempeçonhar",
    "desempeçonharde": "desempeçonhar",
    "desempeçonhardes": "desempeçonhar",
    "desempeçonhare": "desempeçonhar",
    "desempeçonharei": "desempeçonhar",
    "desempeçonhareis": "desempeçonhar",
    "desempeçonharem": "onhar",
    "desempeçonharemos": "desempeçonhar",
    "desempeçonhares": "desempeçonhar",
    "desempeçonharia": "onhar",
    "desempeçonhariam": "desempeçonhar",
    "desempeçonharias": "desempeçonhar",
    "desempeçonharmo": "desempeçonhar",
    "desempeçonharmos": "desempeçonhar",
    "desempeçonhará": "desempeçonhar",
    "desempeçonharás": "desempeçonhar",
    "desempeçonharão": "desempeçonhar",
    "desempeçonharíamos": "desempeçonhar",
    "desempeçonharíeis": "desempeçonhar",
    "desempeçonhas": "desempeçonhar",
    "desempeçonhasse": "onhar",
    "desempeçonhassem": "desempeçonhar",
    "desempeçonhasses": "desempeçonhar",
    "desempeçonhaste": "desempeçonhar",
    "desempeçonhastes": "desempeçonhar",
    "desempeçonhava": "onhar",
    "desempeçonhavam": "desempeçonhar",
    "desempeçonhavas": "desempeçonhar",
    "desempeçonhe": "onhar",
    "desempeçonhei": "desempeçonhar",
    "desempeçonheis": "desempeçonhar",
    "desempeçonhem": "onhar",
    "desempeçonhemo": "desempeçonhar",
    "desempeçonhemos": "desempeçonhar",
    "desempeçonhes": "desempeçonhar",
    "desempeçonho": "desempeçonhar",
    "desempeçonhou": "desempeçonhar",
    "desempeçonhá": "onhar",
    "desempeçonhámo": "desempeçonhar",
    "desempeçonhámos": "desempeçonhar",
    "desempeçonháramo": "desempeçonhar",
    "desempeçonháramos": "desempeçonhar",
    "desempeçonhárei": "desempeçonhar",
    "desempeçonháreis": "desempeçonhar",
    "desempeçonhásseis": "desempeçonhar",
    "desempeçonhássemos": "desempeçonhar",
    "desempeçonhávamo": "desempeçonhar",
    "desempeçonhávamos": "desempeçonhar",
    "desempeçonhávei": "desempeçonhar",
    "desempeçonháveis": "desempeçonhar",
    "desempeços": "desempeço",
    "desempeçou": "desempeçar",
    "desempeçá": "desempeçar",
    "desempeçámo": "desempeçar",
    "desempeçámos": "desempeçar",
    "desempeçáramo": "desempeçar",
    "desempeçáramos": "desempeçar",
    "desempeçárei": "desempeçar",
    "desempeçáreis": "desempeçar",
    "desempeçásseis": "desempeçar",
    "desempeçássemos": "desempeçar",
    "desempeçávamo": "desempeçar",
    "desempeçávamos": "desempeçar",
    "desempeçávei": "desempeçar",
    "desempeçáveis": "desempeçar",
    "desempilha": "desempilhar",
    "desempilhada": "desempilhar",
    "desempilhadas": "desempilhar",
    "desempilhado": "desempilhar",
    "desempilhados": "desempilhar",
    "desempilhai": "desempilhar",
    "desempilhais": "desempilhar",
    "desempilham": "desempilhar",
    "desempilhamo": "desempilhar",
    "desempilhamos": "desempilhar",
    "desempilhando": "desempilhar",
    "desempilhara": "desempilhar",
    "desempilharam": "desempilhar",
    "desempilharas": "desempilhar",
    "desempilharde": "desempilhar",
    "desempilhardes": "desempilhar",
    "desempilhare": "desempilhar",
    "desempilharei": "desempilhar",
    "desempilhareis": "desempilhar",
    "desempilharem": "desempilhar",
    "desempilharemos": "desempilhar",
    "desempilhares": "desempilhar",
    "desempilharia": "desempilhar",
    "desempilhariam": "desempilhar",
    "desempilharias": "desempilhar",
    "desempilharmo": "desempilhar",
    "desempilharmos": "desempilhar",
    "desempilhará": "desempilhar",
    "desempilharás": "desempilhar",
    "desempilharão": "desempilhar",
    "desempilharíamos": "desempilhar",
    "desempilharíeis": "desempilhar",
    "desempilhas": "desempilhar",
    "desempilhasse": "desempilhar",
    "desempilhassem": "desempilhar",
    "desempilhasses": "desempilhar",
    "desempilhaste": "desempilhar",
    "desempilhastes": "desempilhar",
    "desempilhava": "desempilhar",
    "desempilhavam": "desempilhar",
    "desempilhavas": "desempilhar",
    "desempilhe": "desempilhar",
    "desempilhei": "desempilhar",
    "desempilheis": "desempilhar",
    "desempilhem": "desempilhar",
    "desempilhemo": "desempilhar",
    "desempilhemos": "desempilhar",
    "desempilhes": "desempilhar",
    "desempilho": "desempilhar",
    "desempilhou": "desempilhar",
    "desempilhá": "desempilhar",
    "desempilhámo": "desempilhar",
    "desempilhámos": "desempilhar",
    "desempilháramo": "desempilhar",
    "desempilháramos": "desempilhar",
    "desempilhárei": "desempilhar",
    "desempilháreis": "desempilhar",
    "desempilhásseis": "desempilhar",
    "desempilhássemos": "desempilhar",
    "desempilhávamo": "desempilhar",
    "desempilhávamos": "desempilhar",
    "desempilhávei": "desempilhar",
    "desempilháveis": "desempilhável",
    "desempina": "desempinar",
    "desempinada": "desempinar",
    "desempinadas": "desempinar",
    "desempinado": "desempinar",
    "desempinados": "desempinar",
    "desempinai": "desempinar",
    "desempinais": "desempinar",
    "desempinam": "desempinar",
    "desempinamo": "desempinar",
    "desempinamos": "desempinar",
    "desempinando": "desempinar",
    "desempinara": "desempinar",
    "desempinaram": "desempinar",
    "desempinaras": "desempinar",
    "desempinarde": "desempinar",
    "desempinardes": "desempinar",
    "desempinare": "desempinar",
    "desempinarei": "desempinar",
    "desempinareis": "desempinar",
    "desempinarem": "desempinar",
    "desempinaremos": "desempinar",
    "desempinares": "desempinar",
    "desempinaria": "desempinar",
    "desempinariam": "desempinar",
    "desempinarias": "desempinar",
    "desempinarmo": "desempinar",
    "desempinarmos": "desempinar",
    "desempinará": "desempinar",
    "desempinarás": "desempinar",
    "desempinarão": "desempinar",
    "desempinaríamos": "desempinar",
    "desempinaríeis": "desempinar",
    "desempinas": "desempinar",
    "desempinasse": "desempinar",
    "desempinassem": "desempinar",
    "desempinasses": "desempinar",
    "desempinaste": "desempinar",
    "desempinastes": "desempinar",
    "desempinava": "desempinar",
    "desempinavam": "desempinar",
    "desempinavas": "desempinar",
    "desempine": "desempinar",
    "desempinei": "desempinar",
    "desempineis": "desempinar",
    "desempinem": "desempinar",
    "desempinemo": "desempinar",
    "desempinemos": "desempinar",
    "desempines": "desempinar",
    "desempino": "desempinar",
    "desempinou": "desempinar",
    "desempiná": "desempinar",
    "desempinámo": "desempinar",
    "desempinámos": "desempinar",
    "desempináramo": "desempinar",
    "desempináramos": "desempinar",
    "desempinárei": "desempinar",
    "desempináreis": "desempinar",
    "desempinásseis": "desempinar",
    "desempinássemos": "desempinar",
    "desempinávamo": "desempinar",
    "desempinávamos": "desempinar",
    "desempinávei": "desempinar",
    "desempináveis": "desempinar",
    "desemplastra": "desemplastrar",
    "desemplastrada": "desemplastrar",
    "desemplastradas": "desemplastrar",
    "desemplastrado": "desemplastrar",
    "desemplastrados": "desemplastrar",
    "desemplastrai": "desemplastrar",
    "desemplastrais": "desemplastrar",
    "desemplastram": "desemplastrar",
    "desemplastramo": "desemplastrar",
    "desemplastramos": "desemplastrar",
    "desemplastrando": "desemplastrar",
    "desemplastrara": "desemplastrar",
    "desemplastraram": "desemplastrar",
    "desemplastraras": "desemplastrar",
    "desemplastrarde": "desemplastrar",
    "desemplastrardes": "desemplastrar",
    "desemplastrare": "desemplastrar",
    "desemplastrarei": "desemplastrar",
    "desemplastrareis": "desemplastrar",
    "desemplastrarem": "desemplastrar",
    "desemplastraremos": "desemplastrar",
    "desemplastrares": "desemplastrar",
    "desemplastraria": "desemplastrar",
    "desemplastrariam": "desemplastrar",
    "desemplastrarias": "desemplastrar",
    "desemplastrarmo": "desemplastrar",
    "desemplastrarmos": "desemplastrar",
    "desemplastrará": "desemplastrar",
    "desemplastrarás": "desemplastrar",
    "desemplastrarão": "desemplastrar",
    "desemplastraríamos": "desemplastrar",
    "desemplastraríeis": "desemplastrar",
    "desemplastras": "desemplastrar",
    "desemplastrasse": "desemplastrar",
    "desemplastrassem": "desemplastrar",
    "desemplastrasses": "desemplastrar",
    "desemplastraste": "desemplastrar",
    "desemplastrastes": "desemplastrar",
    "desemplastrava": "desemplastrar",
    "desemplastravam": "desemplastrar",
    "desemplastravas": "desemplastrar",
    "desemplastre": "desemplastrar",
    "desemplastrei": "desemplastrar",
    "desemplastreis": "desemplastrar",
    "desemplastrem": "desemplastrar",
    "desemplastremo": "desemplastrar",
    "desemplastremos": "desemplastrar",
    "desemplastres": "desemplastrar",
    "desemplastro": "desemplastrar",
    "desemplastrou": "desemplastrar",
    "desemplastrá": "desemplastrar",
    "desemplastrámo": "desemplastrar",
    "desemplastrámos": "desemplastrar",
    "desemplastráramo": "desemplastrar",
    "desemplastráramos": "desemplastrar",
    "desemplastrárei": "desemplastrar",
    "desemplastráreis": "desemplastrar",
    "desemplastrásseis": "desemplastrar",
    "desemplastrássemos": "desemplastrar",
    "desemplastrávamo": "desemplastrar",
    "desemplastrávamos": "desemplastrar",
    "desemplastrávei": "desemplastrar",
    "desemplastráveis": "desemplastrar",
    "desempluma": "desemplumar",
    "desemplumada": "desemplumar",
    "desemplumadas": "desemplumar",
    "desemplumado": "desemplumar",
    "desemplumados": "desemplumar",
    "desemplumai": "desemplumar",
    "desemplumais": "desemplumar",
    "desemplumam": "desemplumar",
    "desemplumamo": "desemplumar",
    "desemplumamos": "desemplumar",
    "desemplumando": "desemplumar",
    "desemplumara": "desemplumar",
    "desemplumaram": "desemplumar",
    "desemplumaras": "desemplumar",
    "desemplumarde": "desemplumar",
    "desemplumardes": "desemplumar",
    "desemplumare": "desemplumar",
    "desemplumarei": "desemplumar",
    "desemplumareis": "desemplumar",
    "desemplumarem": "desemplumar",
    "desemplumaremos": "desemplumar",
    "desemplumares": "desemplumar",
    "desemplumaria": "desemplumar",
    "desemplumariam": "desemplumar",
    "desemplumarias": "desemplumar",
    "desemplumarmo": "desemplumar",
    "desemplumarmos": "desemplumar",
    "desemplumará": "desemplumar",
    "desemplumarás": "desemplumar",
    "desemplumarão": "desemplumar",
    "desemplumaríamos": "desemplumar",
    "desemplumaríeis": "desemplumar",
    "desemplumas": "desemplumar",
    "desemplumasse": "desemplumar",
    "desemplumassem": "desemplumar",
    "desemplumasses": "desemplumar",
    "desemplumaste": "desemplumar",
    "desemplumastes": "desemplumar",
    "desemplumava": "desemplumar",
    "desemplumavam": "desemplumar",
    "desemplumavas": "desemplumar",
    "desemplume": "desemplumar",
    "desemplumei": "desemplumar",
    "desemplumeis": "desemplumar",
    "desemplumem": "desemplumar",
    "desemplumemo": "desemplumar",
    "desemplumemos": "desemplumar",
    "desemplumes": "desemplumar",
    "desemplumo": "desemplumar",
    "desemplumou": "desemplumar",
    "desemplumá": "desemplumar",
    "desemplumámo": "desemplumar",
    "desemplumámos": "desemplumar",
    "desemplumáramo": "desemplumar",
    "desemplumáramos": "desemplumar",
    "desemplumárei": "desemplumar",
    "desemplumáreis": "desemplumar",
    "desemplumásseis": "desemplumar",
    "desemplumássemos": "desemplumar",
    "desemplumávamo": "desemplumar",
    "desemplumávamos": "desemplumar",
    "desemplumávei": "desemplumar",
    "desemplumáveis": "desemplumar",
    "desempo": "desempar",
    "desempoa": "desempoar",
    "desempoada": "desempoar",
    "desempoadas": "desempoar",
    "desempoado": "desempoar",
    "desempoados": "desempoar",
    "desempoai": "desempoar",
    "desempoais": "desempoar",
    "desempoam": "desempoar",
    "desempoamo": "desempoar",
    "desempoamos": "desempoar",
    "desempoando": "desempoar",
    "desempoara": "desempoar",
    "desempoaram": "desempoar",
    "desempoaras": "desempoar",
    "desempoarde": "desempoar",
    "desempoardes": "desempoar",
    "desempoare": "desempoar",
    "desempoarei": "desempoar",
    "desempoareis": "desempoar",
    "desempoarem": "desempoar",
    "desempoaremos": "desempoar",
    "desempoares": "desempoar",
    "desempoaria": "desempoar",
    "desempoariam": "desempoar",
    "desempoarias": "desempoar",
    "desempoarmo": "desempoar",
    "desempoarmos": "desempoar",
    "desempoará": "desempoar",
    "desempoarás": "desempoar",
    "desempoarão": "desempoar",
    "desempoaríamos": "desempoar",
    "desempoaríeis": "desempoar",
    "desempoas": "desempoar",
    "desempoasse": "desempoar",
    "desempoassem": "desempoar",
    "desempoasses": "desempoar",
    "desempoaste": "desempoar",
    "desempoastes": "desempoar",
    "desempoava": "desempoar",
    "desempoavam": "desempoar",
    "desempoavas": "desempoar",
    "desempobrece": "desempobrecer",
    "desempobrecei": "desempobrecer",
    "desempobreceis": "desempobrecer",
    "desempobrecem": "desempobrecer",
    "desempobrecemo": "desempobrecer",
    "desempobrecemos": "desempobrecer",
    "desempobrecendo": "desempobrecer",
    "desempobrecera": "desempobrecer",
    "desempobreceram": "desempobrecer",
    "desempobreceras": "desempobrecer",
    "desempobrecerde": "desempobrecer",
    "desempobrecerdes": "desempobrecer",
    "desempobrecere": "desempobrecer",
    "desempobrecerei": "desempobrecer",
    "desempobrecereis": "desempobrecer",
    "desempobrecerem": "desempobrecer",
    "desempobreceremos": "desempobrecer",
    "desempobreceres": "desempobrecer",
    "desempobreceria": "desempobrecer",
    "desempobreceriam": "desempobrecer",
    "desempobrecerias": "desempobrecer",
    "desempobrecermo": "desempobrecer",
    "desempobrecermos": "desempobrecer",
    "desempobrecerá": "desempobrecer",
    "desempobrecerás": "desempobrecer",
    "desempobrecerão": "desempobrecer",
    "desempobreceríamos": "desempobrecer",
    "desempobreceríeis": "desempobrecer",
    "desempobreces": "desempobrecer",
    "desempobrecesse": "desempobrecer",
    "desempobrecessem": "desempobrecer",
    "desempobrecesses": "desempobrecer",
    "desempobreceste": "desempobrecer",
    "desempobrecestes": "desempobrecer",
    "desempobreceu": "desempobrecer",
    "desempobreci": "desempobrecer",
    "desempobrecia": "desempobrecer",
    "desempobreciam": "desempobrecer",
    "desempobrecias": "desempobrecer",
    "desempobrecida": "desempobrecido",
    "desempobrecidas": "desempobrecido",
    "desempobrecido": "desempobrecer",
    "desempobrecidos": "desempobrecido",
    "desempobrecê": "desempobrecer",
    "desempobrecêramo": "desempobrecer",
    "desempobrecêramos": "desempobrecer",
    "desempobrecêrei": "desempobrecer",
    "desempobrecêreis": "desempobrecer",
    "desempobrecêsseis": "desempobrecer",
    "desempobrecêssemos": "desempobrecer",
    "desempobrecíamo": "desempobrecer",
    "desempobrecíamos": "desempobrecer",
    "desempobrecíei": "desempobrecer",
    "desempobrecíeis": "desempobrecer",
    "desempobreça": "desempobrecer",
    "desempobreçais": "desempobrecer",
    "desempobreçam": "desempobrecer",
    "desempobreçamo": "desempobrecer",
    "desempobreçamos": "desempobrecer",
    "desempobreças": "desempobrecer",
    "desempobreço": "desempobrecer",
    "desempoce": "desempoçar",
    "desempocei": "desempoçar",
    "desempoceis": "desempoçar",
    "desempocem": "desempoçar",
    "desempocemo": "desempoçar",
    "desempocemos": "desempoçar",
    "desempoces": "desempoçar",
    "desempoe": "desempoar",
    "desempoei": "desempoar",
    "desempoeira": "desempoeirar",
    "desempoeirada": "desempoeirar",
    "desempoeiradas": "desempoeirar",
    "desempoeirado": "desempoeirar",
    "desempoeirados": "desempoeirar",
    "desempoeirai": "desempoeirar",
    "desempoeirais": "desempoeirar",
    "desempoeiram": "desempoeirar",
    "desempoeiramo": "desempoeirar",
    "desempoeiramos": "desempoeirar",
    "desempoeirando": "desempoeirar",
    "desempoeirara": "desempoeirar",
    "desempoeiraram": "desempoeirar",
    "desempoeiraras": "desempoeirar",
    "desempoeirarde": "desempoeirar",
    "desempoeirardes": "desempoeirar",
    "desempoeirare": "desempoeirar",
    "desempoeirarei": "desempoeirar",
    "desempoeirareis": "desempoeirar",
    "desempoeirarem": "desempoeirar",
    "desempoeiraremos": "desempoeirar",
    "desempoeirares": "desempoeirar",
    "desempoeiraria": "desempoeirar",
    "desempoeirariam": "desempoeirar",
    "desempoeirarias": "desempoeirar",
    "desempoeirarmo": "desempoeirar",
    "desempoeirarmos": "desempoeirar",
    "desempoeirará": "desempoeirar",
    "desempoeirarás": "desempoeirar",
    "desempoeirarão": "desempoeirar",
    "desempoeiraríamos": "desempoeirar",
    "desempoeiraríeis": "desempoeirar",
    "desempoeiras": "desempoeirar",
    "desempoeirasse": "desempoeirar",
    "desempoeirassem": "desempoeirar",
    "desempoeirasses": "desempoeirar",
    "desempoeiraste": "desempoeirar",
    "desempoeirastes": "desempoeirar",
    "desempoeirava": "desempoeirar",
    "desempoeiravam": "desempoeirar",
    "desempoeiravas": "desempoeirar",
    "desempoeire": "desempoeirar",
    "desempoeirei": "desempoeirar",
    "desempoeireis": "desempoeirar",
    "desempoeirem": "desempoeirar",
    "desempoeiremo": "desempoeirar",
    "desempoeiremos": "desempoeirar",
    "desempoeires": "desempoeirar",
    "desempoeiro": "desempoeirar",
    "desempoeirou": "desempoeirar",
    "desempoeirá": "desempoeirar",
    "desempoeirámo": "desempoeirar",
    "desempoeirámos": "desempoeirar",
    "desempoeiráramo": "desempoeirar",
    "desempoeiráramos": "desempoeirar",
    "desempoeirárei": "desempoeirar",
    "desempoeiráreis": "desempoeirar",
    "desempoeirásseis": "desempoeirar",
    "desempoeirássemos": "desempoeirar",
    "desempoeirávamo": "desempoeirar",
    "desempoeirávamos": "desempoeirar",
    "desempoeirávei": "desempoeirar",
    "desempoeiráveis": "desempoeirar",
    "desempoeis": "desempoar",
    "desempoem": "desempoar",
    "desempoemo": "desempoar",
    "desempoemos": "desempoar",
    "desempoes": "desempoar",
    "desempola": "desempolar",
    "desempolada": "desempolar",
    "desempoladas": "desempolar",
    "desempolado": "desempolar",
    "desempolados": "desempolar",
    "desempolai": "desempolar",
    "desempolais": "desempolar",
    "desempolam": "desempolar",
    "desempolamo": "desempolar",
    "desempolamos": "desempolar",
    "desempolando": "desempolar",
    "desempolara": "desempolar",
    "desempolaram": "desempolar",
    "desempolaras": "desempolar",
    "desempolarde": "desempolar",
    "desempolardes": "desempolar",
    "desempolare": "desempolar",
    "desempolarei": "desempolar",
    "desempolareis": "desempolar",
    "desempolarem": "desempolar",
    "desempolaremos": "desempolar",
    "desempolares": "desempolar",
    "desempolaria": "desempolar",
    "desempolariam": "desempolar",
    "desempolarias": "desempolar",
    "desempolarmo": "desempolar",
    "desempolarmos": "desempolar",
    "desempolará": "desempolar",
    "desempolarás": "desempolar",
    "desempolarão": "desempolar",
    "desempolaríamos": "desempolar",
    "desempolaríeis": "desempolar",
    "desempolas": "desempolar",
    "desempolasse": "desempolar",
    "desempolassem": "desempolar",
    "desempolasses": "desempolar",
    "desempolaste": "desempolar",
    "desempolastes": "desempolar",
    "desempolava": "desempolar",
    "desempolavam": "desempolar",
    "desempolavas": "desempolar",
    "desempole": "desempolar",
    "desempolei": "desempolar",
    "desempoleira": "desempoleirar",
    "desempoleirada": "desempoleirar",
    "desempoleiradas": "desempoleirar",
    "desempoleirado": "desempoleirar",
    "desempoleirados": "desempoleirar",
    "desempoleirai": "desempoleirar",
    "desempoleirais": "desempoleirar",
    "desempoleiram": "desempoleirar",
    "desempoleiramo": "desempoleirar",
    "desempoleiramos": "desempoleirar",
    "desempoleirando": "desempoleirar",
    "desempoleirara": "desempoleirar",
    "desempoleiraram": "desempoleirar",
    "desempoleiraras": "desempoleirar",
    "desempoleirarde": "desempoleirar",
    "desempoleirardes": "desempoleirar",
    "desempoleirare": "desempoleirar",
    "desempoleirarei": "desempoleirar",
    "desempoleirareis": "desempoleirar",
    "desempoleirarem": "desempoleirar",
    "desempoleiraremos": "desempoleirar",
    "desempoleirares": "desempoleirar",
    "desempoleiraria": "desempoleirar",
    "desempoleirariam": "desempoleirar",
    "desempoleirarias": "desempoleirar",
    "desempoleirarmo": "desempoleirar",
    "desempoleirarmos": "desempoleirar",
    "desempoleirará": "desempoleirar",
    "desempoleirarás": "desempoleirar",
    "desempoleirarão": "desempoleirar",
    "desempoleiraríamos": "desempoleirar",
    "desempoleiraríeis": "desempoleirar",
    "desempoleiras": "desempoleirar",
    "desempoleirasse": "desempoleirar",
    "desempoleirassem": "desempoleirar",
    "desempoleirasses": "desempoleirar",
    "desempoleiraste": "desempoleirar",
    "desempoleirastes": "desempoleirar",
    "desempoleirava": "desempoleirar",
    "desempoleiravam": "desempoleirar",
    "desempoleiravas": "desempoleirar",
    "desempoleire": "desempoleirar",
    "desempoleirei": "desempoleirar",
    "desempoleireis": "desempoleirar",
    "desempoleirem": "desempoleirar",
    "desempoleiremo": "desempoleirar",
    "desempoleiremos": "desempoleirar",
    "desempoleires": "desempoleirar",
    "desempoleiro": "desempoleirar",
    "desempoleirou": "desempoleirar",
    "desempoleirá": "desempoleirar",
    "desempoleirámo": "desempoleirar",
    "desempoleirámos": "desempoleirar",
    "desempoleiráramo": "desempoleirar",
    "desempoleiráramos": "desempoleirar",
    "desempoleirárei": "desempoleirar",
    "desempoleiráreis": "desempoleirar",
    "desempoleirásseis": "desempoleirar",
    "desempoleirássemos": "desempoleirar",
    "desempoleirávamo": "desempoleirar",
    "desempoleirávamos": "desempoleirar",
    "desempoleirávei": "desempoleirar",
    "desempoleiráveis": "desempoleirar",
    "desempoleis": "desempolar",
    "desempolem": "desempolar",
    "desempolemo": "desempolar",
    "desempolemos": "desempolar",
    "desempoles": "desempolar",
    "desempolga": "desempolgar",
    "desempolgada": "desempolgar",
    "desempolgadas": "desempolgar",
    "desempolgado": "desempolgar",
    "desempolgados": "desempolgar",
    "desempolgai": "desempolgar",
    "desempolgais": "desempolgar",
    "desempolgam": "desempolgar",
    "desempolgamo": "desempolgar",
    "desempolgamos": "desempolgar",
    "desempolgando": "desempolgar",
    "desempolgara": "desempolgar",
    "desempolgaram": "desempolgar",
    "desempolgaras": "desempolgar",
    "desempolgarde": "desempolgar",
    "desempolgardes": "desempolgar",
    "desempolgare": "desempolgar",
    "desempolgarei": "desempolgar",
    "desempolgareis": "desempolgar",
    "desempolgarem": "desempolgar",
    "desempolgaremos": "desempolgar",
    "desempolgares": "desempolgar",
    "desempolgaria": "desempolgar",
    "desempolgariam": "desempolgar",
    "desempolgarias": "desempolgar",
    "desempolgarmo": "desempolgar",
    "desempolgarmos": "desempolgar",
    "desempolgará": "desempolgar",
    "desempolgarás": "desempolgar",
    "desempolgarão": "desempolgar",
    "desempolgaríamos": "desempolgar",
    "desempolgaríeis": "desempolgar",
    "desempolgas": "desempolgar",
    "desempolgasse": "desempolgar",
    "desempolgassem": "desempolgar",
    "desempolgasses": "desempolgar",
    "desempolgaste": "desempolgar",
    "desempolgastes": "desempolgar",
    "desempolgava": "desempolgar",
    "desempolgavam": "desempolgar",
    "desempolgavas": "desempolgar",
    "desempolgo": "desempolgar",
    "desempolgou": "desempolgar",
    "desempolgue": "desempolgar",
    "desempolguei": "desempolgar",
    "desempolgueis": "desempolgar",
    "desempolguem": "desempolgar",
    "desempolguemo": "desempolgar",
    "desempolguemos": "desempolgar",
    "desempolgues": "desempolgar",
    "desempolgá": "desempolgar",
    "desempolgámo": "desempolgar",
    "desempolgámos": "desempolgar",
    "desempolgáramo": "desempolgar",
    "desempolgáramos": "desempolgar",
    "desempolgárei": "desempolgar",
    "desempolgáreis": "desempolgar",
    "desempolgásseis": "desempolgar",
    "desempolgássemos": "desempolgar",
    "desempolgávamo": "desempolgar",
    "desempolgávamos": "desempolgar",
    "desempolgávei": "desempolgar",
    "desempolgáveis": "desempolgar",
    "desempolo": "desempolar",
    "desempolou": "desempolar",
    "desempolá": "desempolar",
    "desempolámo": "desempolar",
    "desempolámos": "desempolar",
    "desempoláramo": "desempolar",
    "desempoláramos": "desempolar",
    "desempolárei": "desempolar",
    "desempoláreis": "desempolar",
    "desempolásseis": "desempolar",
    "desempolássemos": "desempolar",
    "desempolávamo": "desempolar",
    "desempolávamos": "desempolar",
    "desempolávei": "desempolar",
    "desempoláveis": "desempolar",
    "desempoo": "desempoar",
    "desempoou": "desempoar",
    "desempossa": "desempossar",
    "desempossada": "desempossar",
    "desempossadas": "desempossar",
    "desempossado": "desempossar",
    "desempossados": "desempossar",
    "desempossai": "desempossar",
    "desempossais": "desempossar",
    "desempossam": "desempossar",
    "desempossamo": "desempossar",
    "desempossamos": "desempossar",
    "desempossando": "desempossar",
    "desempossara": "desempossar",
    "desempossaram": "desempossar",
    "desempossaras": "desempossar",
    "desempossarde": "desempossar",
    "desempossardes": "desempossar",
    "desempossare": "desempossar",
    "desempossarei": "desempossar",
    "desempossareis": "desempossar",
    "desempossarem": "desempossar",
    "desempossaremos": "desempossar",
    "desempossares": "desempossar",
    "desempossaria": "desempossar",
    "desempossariam": "desempossar",
    "desempossarias": "desempossar",
    "desempossarmo": "desempossar",
    "desempossarmos": "desempossar",
    "desempossará": "desempossar",
    "desempossarás": "desempossar",
    "desempossarão": "desempossar",
    "desempossaríamos": "desempossar",
    "desempossaríeis": "desempossar",
    "desempossas": "desempossar",
    "desempossasse": "desempossar",
    "desempossassem": "desempossar",
    "desempossasses": "desempossar",
    "desempossaste": "desempossar",
    "desempossastes": "desempossar",
    "desempossava": "desempossar",
    "desempossavam": "desempossar",
    "desempossavas": "desempossar",
    "desemposse": "desempossar",
    "desempossei": "desempossar",
    "desemposseis": "desempossar",
    "desempossem": "desempossar",
    "desempossemo": "desempossar",
    "desempossemos": "desempossar",
    "desemposses": "desempossar",
    "desemposso": "desempossar",
    "desempossou": "desempossar",
    "desempossá": "desempossar",
    "desempossámo": "desempossar",
    "desempossámos": "desempossar",
    "desempossáramo": "desempossar",
    "desempossáramos": "desempossar",
    "desempossárei": "desempossar",
    "desempossáreis": "desempossar",
    "desempossásseis": "desempossar",
    "desempossássemos": "desempossar",
    "desempossávamo": "desempossar",
    "desempossávamos": "desempossar",
    "desempossávei": "desempossar",
    "desempossáveis": "desempossar",
    "desempou": "desempar",
    "desempoá": "desempoar",
    "desempoámo": "desempoar",
    "desempoámos": "desempoar",
    "desempoáramo": "desempoar",
    "desempoáramos": "desempoar",
    "desempoárei": "desempoar",
    "desempoáreis": "desempoar",
    "desempoásseis": "desempoar",
    "desempoássemos": "desempoar",
    "desempoávamo": "desempoar",
    "desempoávamos": "desempoar",
    "desempoávei": "desempoar",
    "desempoáveis": "desempoar",
    "desempoça": "desempoçar",
    "desempoçada": "desempoçar",
    "desempoçadas": "desempoçar",
    "desempoçado": "desempoçar",
    "desempoçados": "desempoçar",
    "desempoçai": "desempoçar",
    "desempoçais": "desempoçar",
    "desempoçam": "desempoçar",
    "desempoçamo": "desempoçar",
    "desempoçamos": "desempoçar",
    "desempoçando": "desempoçar",
    "desempoçara": "desempoçar",
    "desempoçaram": "desempoçar",
    "desempoçaras": "desempoçar",
    "desempoçarde": "desempoçar",
    "desempoçardes": "desempoçar",
    "desempoçare": "desempoçar",
    "desempoçarei": "desempoçar",
    "desempoçareis": "desempoçar",
    "desempoçarem": "desempoçar",
    "desempoçaremos": "desempoçar",
    "desempoçares": "desempoçar",
    "desempoçaria": "desempoçar",
    "desempoçariam": "desempoçar",
    "desempoçarias": "desempoçar",
    "desempoçarmo": "desempoçar",
    "desempoçarmos": "desempoçar",
    "desempoçará": "desempoçar",
    "desempoçarás": "desempoçar",
    "desempoçarão": "desempoçar",
    "desempoçaríamos": "desempoçar",
    "desempoçaríeis": "desempoçar",
    "desempoças": "desempoçar",
    "desempoçasse": "desempoçar",
    "desempoçassem": "desempoçar",
    "desempoçasses": "desempoçar",
    "desempoçaste": "desempoçar",
    "desempoçastes": "desempoçar",
    "desempoçava": "desempoçar",
    "desempoçavam": "desempoçar",
    "desempoçavas": "desempoçar",
    "desempoço": "desempoçar",
    "desempoçou": "desempoçar",
    "desempoçá": "desempoçar",
    "desempoçámo": "desempoçar",
    "desempoçámos": "desempoçar",
    "desempoçáramo": "desempoçar",
    "desempoçáramos": "desempoçar",
    "desempoçárei": "desempoçar",
    "desempoçáreis": "desempoçar",
    "desempoçásseis": "desempoçar",
    "desempoçássemos": "desempoçar",
    "desempoçávamo": "desempoçar",
    "desempoçávamos": "desempoçar",
    "desempoçávei": "desempoçar",
    "desempoçáveis": "desempoçar",
    "desemprega": "desempregar",
    "desempregada": "desempregar",
    "desempregadas": "desempregar",
    "desempregado": "desempregar",
    "desempregados": "desempregar",
    "desempregai": "desempregar",
    "desempregais": "desempregar",
    "desempregam": "desempregar",
    "desempregamo": "desempregar",
    "desempregamos": "desempregar",
    "desempregando": "desempregar",
    "desempregara": "desempregar",
    "desempregaram": "desempregar",
    "desempregaras": "desempregar",
    "desempregarde": "desempregar",
    "desempregardes": "desempregar",
    "desempregare": "desempregar",
    "desempregarei": "desempregar",
    "desempregareis": "desempregar",
    "desempregarem": "desempregar",
    "desempregaremos": "desempregar",
    "desempregares": "desempregar",
    "desempregaria": "desempregar",
    "desempregariam": "desempregar",
    "desempregarias": "desempregar",
    "desempregarmo": "desempregar",
    "desempregarmos": "desempregar",
    "desempregará": "desempregar",
    "desempregarás": "desempregar",
    "desempregarão": "desempregar",
    "desempregaríamos": "desempregar",
    "desempregaríeis": "desempregar",
    "desempregas": "desempregar",
    "desempregasse": "desempregar",
    "desempregassem": "desempregar",
    "desempregasses": "desempregar",
    "desempregaste": "desempregar",
    "desempregastes": "desempregar",
    "desempregava": "desempregar",
    "desempregavam": "desempregar",
    "desempregavas": "desempregar",
    "desemprego": "desempregar",
    "desempregos": "desemprego",
    "desempregou": "desempregar",
    "desempregue": "desempregar",
    "desempreguei": "desempregar",
    "desempregueis": "desempregar",
    "desempreguem": "desempregar",
    "desempreguemo": "desempregar",
    "desempreguemos": "desempregar",
    "desempregues": "desempregar",
    "desempregá": "desempregar",
    "desempregámo": "desempregar",
    "desempregámos": "desempregar",
    "desempregáramo": "desempregar",
    "desempregáramos": "desempregar",
    "desempregárei": "desempregar",
    "desempregáreis": "desempregar",
    "desempregásseis": "desempregar",
    "desempregássemos": "desempregar",
    "desempregávamo": "desempregar",
    "desempregávamos": "desempregar",
    "desempregávei": "desempregar",
    "desempregáveis": "desempregar",
    "desemprenha": "desemprenhar",
    "desemprenhada": "desemprenhar",
    "desemprenhadas": "desemprenhar",
    "desemprenhado": "desemprenhar",
    "desemprenhados": "desemprenhar",
    "desemprenhai": "desemprenhar",
    "desemprenhais": "desemprenhar",
    "desemprenham": "desemprenhar",
    "desemprenhamo": "desemprenhar",
    "desemprenhamos": "desemprenhar",
    "desemprenhando": "desemprenhar",
    "desemprenhara": "desemprenhar",
    "desemprenharam": "desemprenhar",
    "desemprenharas": "desemprenhar",
    "desemprenharde": "desemprenhar",
    "desemprenhardes": "desemprenhar",
    "desemprenhare": "desemprenhar",
    "desemprenharei": "desemprenhar",
    "desemprenhareis": "desemprenhar",
    "desemprenharem": "desemprenhar",
    "desemprenharemos": "desemprenhar",
    "desemprenhares": "desemprenhar",
    "desemprenharia": "desemprenhar",
    "desemprenhariam": "desemprenhar",
    "desemprenharias": "desemprenhar",
    "desemprenharmo": "desemprenhar",
    "desemprenharmos": "desemprenhar",
    "desemprenhará": "desemprenhar",
    "desemprenharás": "desemprenhar",
    "desemprenharão": "desemprenhar",
    "desemprenharíamos": "desemprenhar",
    "desemprenharíeis": "desemprenhar",
    "desemprenhas": "desemprenhar",
    "desemprenhasse": "desemprenhar",
    "desemprenhassem": "desemprenhar",
    "desemprenhasses": "desemprenhar",
    "desemprenhaste": "desemprenhar",
    "desemprenhastes": "desemprenhar",
    "desemprenhava": "desemprenhar",
    "desemprenhavam": "desemprenhar",
    "desemprenhavas": "desemprenhar",
    "desemprenhe": "desemprenhar",
    "desemprenhei": "desemprenhar",
    "desemprenheis": "desemprenhar",
    "desemprenhem": "desemprenhar",
    "desemprenhemo": "desemprenhar",
    "desemprenhemos": "desemprenhar",
    "desemprenhes": "desemprenhar",
    "desemprenho": "desemprenhar",
    "desemprenhou": "desemprenhar",
    "desemprenhá": "desemprenhar",
    "desemprenhámo": "desemprenhar",
    "desemprenhámos": "desemprenhar",
    "desemprenháramo": "desemprenhar",
    "desemprenháramos": "desemprenhar",
    "desemprenhárei": "desemprenhar",
    "desemprenháreis": "desemprenhar",
    "desemprenhásseis": "desemprenhar",
    "desemprenhássemos": "desemprenhar",
    "desemprenhávamo": "desemprenhar",
    "desemprenhávamos": "desemprenhar",
    "desemprenhávei": "desemprenhar",
    "desemprenháveis": "desemprenhar",
    "desemproa": "desemproar",
    "desemproada": "desemproar",
    "desemproadas": "desemproar",
    "desemproado": "desemproar",
    "desemproados": "desemproar",
    "desemproai": "desemproar",
    "desemproais": "desemproar",
    "desemproam": "desemproar",
    "desemproamo": "desemproar",
    "desemproamos": "desemproar",
    "desemproando": "desemproar",
    "desemproara": "desemproar",
    "desemproaram": "desemproar",
    "desemproaras": "desemproar",
    "desemproarde": "desemproar",
    "desemproardes": "desemproar",
    "desemproare": "desemproar",
    "desemproarei": "desemproar",
    "desemproareis": "desemproar",
    "desemproarem": "desemproar",
    "desemproaremos": "desemproar",
    "desemproares": "desemproar",
    "desemproaria": "desemproar",
    "desemproariam": "desemproar",
    "desemproarias": "desemproar",
    "desemproarmo": "desemproar",
    "desemproarmos": "desemproar",
    "desemproará": "desemproar",
    "desemproarás": "desemproar",
    "desemproarão": "desemproar",
    "desemproaríamos": "desemproar",
    "desemproaríeis": "desemproar",
    "desemproas": "desemproar",
    "desemproasse": "desemproar",
    "desemproassem": "desemproar",
    "desemproasses": "desemproar",
    "desemproaste": "desemproar",
    "desemproastes": "desemproar",
    "desemproava": "desemproar",
    "desemproavam": "desemproar",
    "desemproavas": "desemproar",
    "desemproe": "desemproar",
    "desemproei": "desemproar",
    "desemproeis": "desemproar",
    "desemproem": "desemproar",
    "desemproemo": "desemproar",
    "desemproemos": "desemproar",
    "desemproes": "desemproar",
    "desemproo": "desemproar",
    "desemproou": "desemproar",
    "desemproá": "desemproar",
    "desemproámo": "desemproar",
    "desemproámos": "desemproar",
    "desemproáramo": "desemproar",
    "desemproáramos": "desemproar",
    "desemproárei": "desemproar",
    "desemproáreis": "desemproar",
    "desemproásseis": "desemproar",
    "desemproássemos": "desemproar",
    "desemproávamo": "desemproar",
    "desemproávamos": "desemproar",
    "desemproávei": "desemproar",
    "desemproáveis": "desemproar",
    "desempunha": "desempunhar",
    "desempunhada": "desempunhar",
    "desempunhadas": "desempunhar",
    "desempunhado": "desempunhar",
    "desempunhados": "desempunhar",
    "desempunhai": "desempunhar",
    "desempunhais": "desempunhar",
    "desempunham": "desempunhar",
    "desempunhamo": "desempunhar",
    "desempunhamos": "desempunhar",
    "desempunhando": "desempunhar",
    "desempunhara": "desempunhar",
    "desempunharam": "desempunhar",
    "desempunharas": "desempunhar",
    "desempunharde": "desempunhar",
    "desempunhardes": "desempunhar",
    "desempunhare": "desempunhar",
    "desempunharei": "desempunhar",
    "desempunhareis": "desempunhar",
    "desempunharem": "desempunhar",
    "desempunharemos": "desempunhar",
    "desempunhares": "desempunhar",
    "desempunharia": "desempunhar",
    "desempunhariam": "desempunhar",
    "desempunharias": "desempunhar",
    "desempunharmo": "desempunhar",
    "desempunharmos": "desempunhar",
    "desempunhará": "desempunhar",
    "desempunharás": "desempunhar",
    "desempunharão": "desempunhar",
    "desempunharíamos": "desempunhar",
    "desempunharíeis": "desempunhar",
    "desempunhas": "desempunhar",
    "desempunhasse": "desempunhar",
    "desempunhassem": "desempunhar",
    "desempunhasses": "desempunhar",
    "desempunhaste": "desempunhar",
    "desempunhastes": "desempunhar",
    "desempunhava": "desempunhar",
    "desempunhavam": "desempunhar",
    "desempunhavas": "desempunhar",
    "desempunhe": "desempunhar",
    "desempunhei": "desempunhar",
    "desempunheis": "desempunhar",
    "desempunhem": "desempunhar",
    "desempunhemo": "desempunhar",
    "desempunhemos": "desempunhar",
    "desempunhes": "desempunhar",
    "desempunho": "desempunhar",
    "desempunhou": "desempunhar",
    "desempunhá": "desempunhar",
    "desempunhámo": "desempunhar",
    "desempunhámos": "desempunhar",
    "desempunháramo": "desempunhar",
    "desempunháramos": "desempunhar",
    "desempunhárei": "desempunhar",
    "desempunháreis": "desempunhar",
    "desempunhásseis": "desempunhar",
    "desempunhássemos": "desempunhar",
    "desempunhávamo": "desempunhar",
    "desempunhávamos": "desempunhar",
    "desempunhávei": "desempunhar",
    "desempunháveis": "desempunhar",
    "desempá": "desempar",
    "desempámo": "desempar",
    "desempámos": "desempar",
    "desempáramo": "desempar",
    "desempáramos": "desempar",
    "desempárei": "desempar",
    "desempáreis": "desempar",
    "desempásseis": "desempar",
    "desempássemos": "desempar",
    "desempávamo": "desempar",
    "desempávamos": "desempar",
    "desempávei": "desempar",
    "desempáveis": "desempar",
    "desemudece": "desemudecer",
    "desemudecei": "desemudecer",
    "desemudeceis": "desemudecer",
    "desemudecem": "desemudecer",
    "desemudecemo": "desemudecer",
    "desemudecemos": "desemudecer",
    "desemudecendo": "desemudecer",
    "desemudecera": "desemudecer",
    "desemudeceram": "desemudecer",
    "desemudeceras": "desemudecer",
    "desemudecerdes": "desemudecer",
    "desemudecerei": "desemudecer",
    "desemudecereis": "desemudecer",
    "desemudecerem": "desemudecer",
    "desemudeceremos": "desemudecer",
    "desemudeceres": "desemudecer",
    "desemudeceria": "desemudecer",
    "desemudeceriam": "desemudecer",
    "desemudecerias": "desemudecer",
    "desemudecermo": "desemudecer",
    "desemudecermos": "desemudecer",
    "desemudecerá": "desemudecer",
    "desemudecerás": "desemudecer",
    "desemudecerão": "desemudecer",
    "desemudeceríamos": "desemudecer",
    "desemudeceríeis": "desemudecer",
    "desemudeces": "desemudecer",
    "desemudecesse": "desemudecer",
    "desemudecessem": "desemudecer",
    "desemudecesses": "desemudecer",
    "desemudeceste": "desemudecer",
    "desemudecestes": "desemudecer",
    "desemudeceu": "desemudecer",
    "desemudeci": "desemudecer",
    "desemudecia": "desemudecer",
    "desemudeciam": "desemudecer",
    "desemudecias": "desemudecer",
    "desemudecida": "desemudecer",
    "desemudecidas": "desemudecer",
    "desemudecido": "desemudecer",
    "desemudecidos": "desemudecer",
    "desemudecêramo": "desemudecer",
    "desemudecêramos": "desemudecer",
    "desemudecêreis": "desemudecer",
    "desemudecêsseis": "desemudecer",
    "desemudecêssemos": "desemudecer",
    "desemudecíamo": "desemudecer",
    "desemudecíamos": "desemudecer",
    "desemudecíeis": "desemudecer",
    "desemudeça": "desemudecer",
    "desemudeçais": "desemudecer",
    "desemudeçam": "desemudecer",
    "desemudeçamo": "desemudecer",
    "desemudeçamos": "desemudecer",
    "desemudeças": "desemudecer",
    "desemudeço": "desemudecer",
    "desenamora": "desenamorar",
    "desenamorada": "desenamorar",
    "desenamoradas": "desenamorar",
    "desenamorado": "desenamorar",
    "desenamorados": "desenamorar",
    "desenamorai": "desenamorar",
    "desenamorais": "desenamorar",
    "desenamoram": "desenamorar",
    "desenamoramo": "desenamorar",
    "desenamoramos": "desenamorar",
    "desenamorando": "desenamorar",
    "desenamorara": "desenamorar",
    "desenamoraram": "desenamorar",
    "desenamoraras": "desenamorar",
    "desenamorarde": "desenamorar",
    "desenamorardes": "desenamorar",
    "desenamorare": "desenamorar",
    "desenamorarei": "desenamorar",
    "desenamorareis": "desenamorar",
    "desenamorarem": "desenamorar",
    "desenamoraremos": "desenamorar",
    "desenamorares": "desenamorar",
    "desenamoraria": "desenamorar",
    "desenamorariam": "desenamorar",
    "desenamorarias": "desenamorar",
    "desenamorarmo": "desenamorar",
    "desenamorarmos": "desenamorar",
    "desenamorará": "desenamorar",
    "desenamorarás": "desenamorar",
    "desenamorarão": "desenamorar",
    "desenamoraríamos": "desenamorar",
    "desenamoraríeis": "desenamorar",
    "desenamoras": "desenamorar",
    "desenamorasse": "desenamorar",
    "desenamorassem": "desenamorar",
    "desenamorasses": "desenamorar",
    "desenamoraste": "desenamorar",
    "desenamorastes": "desenamorar",
    "desenamorava": "desenamorar",
    "desenamoravam": "desenamorar",
    "desenamoravas": "desenamorar",
    "desenamore": "desenamorar",
    "desenamorei": "desenamorar",
    "desenamoreis": "desenamorar",
    "desenamorem": "desenamorar",
    "desenamoremo": "desenamorar",
    "desenamoremos": "desenamorar",
    "desenamores": "desenamorar",
    "desenamoro": "desenamorar",
    "desenamorou": "desenamorar",
    "desenamorá": "desenamorar",
    "desenamorámo": "desenamorar",
    "desenamorámos": "desenamorar",
    "desenamoráramo": "desenamorar",
    "desenamoráramos": "desenamorar",
    "desenamorárei": "desenamorar",
    "desenamoráreis": "desenamorar",
    "desenamorásseis": "desenamorar",
    "desenamorássemos": "desenamorar",
    "desenamorávamo": "desenamorar",
    "desenamorávamos": "desenamorar",
    "desenamorávei": "desenamorar",
    "desenamoráveis": "desenamorar",
    "desenastra": "desenastrar",
    "desenastrada": "desenastrar",
    "desenastradas": "desenastrar",
    "desenastrado": "desenastrar",
    "desenastrados": "desenastrar",
    "desenastrai": "desenastrar",
    "desenastrais": "desenastrar",
    "desenastram": "desenastrar",
    "desenastramo": "desenastrar",
    "desenastramos": "desenastrar",
    "desenastrando": "desenastrar",
    "desenastrara": "desenastrar",
    "desenastraram": "desenastrar",
    "desenastraras": "desenastrar",
    "desenastrarde": "desenastrar",
    "desenastrardes": "desenastrar",
    "desenastrare": "desenastrar",
    "desenastrarei": "desenastrar",
    "desenastrareis": "desenastrar",
    "desenastrarem": "desenastrar",
    "desenastraremos": "desenastrar",
    "desenastrares": "desenastrar",
    "desenastraria": "desenastrar",
    "desenastrariam": "desenastrar",
    "desenastrarias": "desenastrar",
    "desenastrarmo": "desenastrar",
    "desenastrarmos": "desenastrar",
    "desenastrará": "desenastrar",
    "desenastrarás": "desenastrar",
    "desenastrarão": "desenastrar",
    "desenastraríamos": "desenastrar",
    "desenastraríeis": "desenastrar",
    "desenastras": "desenastrar",
    "desenastrasse": "desenastrar",
    "desenastrassem": "desenastrar",
    "desenastrasses": "desenastrar",
    "desenastraste": "desenastrar",
    "desenastrastes": "desenastrar",
    "desenastrava": "desenastrar",
    "desenastravam": "desenastrar",
    "desenastravas": "desenastrar",
    "desenastre": "desenastrar",
    "desenastrei": "desenastrar",
    "desenastreis": "desenastrar",
    "desenastrem": "desenastrar",
    "desenastremo": "desenastrar",
    "desenastremos": "desenastrar",
    "desenastres": "desenastrar",
    "desenastro": "desenastrar",
    "desenastrou": "desenastrar",
    "desenastrá": "desenastrar",
    "desenastrámo": "desenastrar",
    "desenastrámos": "desenastrar",
    "desenastráramo": "desenastrar",
    "desenastráramos": "desenastrar",
    "desenastrárei": "desenastrar",
    "desenastráreis": "desenastrar",
    "desenastrásseis": "desenastrar",
    "desenastrássemos": "desenastrar",
    "desenastrávamo": "desenastrar",
    "desenastrávamos": "desenastrar",
    "desenastrávei": "desenastrar",
    "desenastráveis": "desenastrar",
    "desenbrestada": "desenbrestado",
    "desenbrestadas": "desenbrestado",
    "desenbrestados": "desenbrestado",
    "desencabada": "desencabado",
    "desencabadas": "desencabado",
    "desencabados": "desencabado",
    "desencabece": "desencabeçar",
    "desencabecei": "desencabeçar",
    "desencabeceis": "desencabeçar",
    "desencabecem": "desencabeçar",
    "desencabecemo": "desencabeçar",
    "desencabecemos": "desencabeçar",
    "desencabeces": "desencabeçar",
    "desencabela": "desencabelar",
    "desencabelada": "desencabelar",
    "desencabeladas": "desencabelar",
    "desencabelado": "desencabelar",
    "desencabelados": "desencabelar",
    "desencabelai": "desencabelar",
    "desencabelais": "desencabelar",
    "desencabelam": "desencabelar",
    "desencabelamo": "desencabelar",
    "desencabelamos": "desencabelar",
    "desencabelando": "desencabelar",
    "desencabelara": "desencabelar",
    "desencabelaram": "desencabelar",
    "desencabelaras": "desencabelar",
    "desencabelarde": "desencabelar",
    "desencabelardes": "desencabelar",
    "desencabelare": "desencabelar",
    "desencabelarei": "desencabelar",
    "desencabelareis": "desencabelar",
    "desencabelarem": "desencabelar",
    "desencabelaremos": "desencabelar",
    "desencabelares": "desencabelar",
    "desencabelaria": "desencabelar",
    "desencabelariam": "desencabelar",
    "desencabelarias": "desencabelar",
    "desencabelarmo": "desencabelar",
    "desencabelarmos": "desencabelar",
    "desencabelará": "desencabelar",
    "desencabelarás": "desencabelar",
    "desencabelarão": "desencabelar",
    "desencabelaríamos": "desencabelar",
    "desencabelaríeis": "desencabelar",
    "desencabelas": "desencabelar",
    "desencabelasse": "desencabelar",
    "desencabelassem": "desencabelar",
    "desencabelasses": "desencabelar",
    "desencabelaste": "desencabelar",
    "desencabelastes": "desencabelar",
    "desencabelava": "desencabelar",
    "desencabelavam": "desencabelar",
    "desencabelavas": "desencabelar",
    "desencabele": "desencabelar",
    "desencabelei": "desencabelar",
    "desencabeleis": "desencabelar",
    "desencabelem": "desencabelar",
    "desencabelemo": "desencabelar",
    "desencabelemos": "desencabelar",
    "desencabeles": "desencabelar",
    "desencabelo": "desencabelar",
    "desencabelou": "desencabelar",
    "desencabelá": "desencabelar",
    "desencabelámo": "desencabelar",
    "desencabelámos": "desencabelar",
    "desencabeláramo": "desencabelar",
    "desencabeláramos": "desencabelar",
    "desencabelárei": "desencabelar",
    "desencabeláreis": "desencabelar",
    "desencabelásseis": "desencabelar",
    "desencabelássemos": "desencabelar",
    "desencabelávamo": "desencabelar",
    "desencabelávamos": "desencabelar",
    "desencabelávei": "desencabelar",
    "desencabeláveis": "desencabelar",
    "desencabeça": "desencabeçar",
    "desencabeçada": "desencabeçar",
    "desencabeçadas": "desencabeçar",
    "desencabeçado": "desencabeçar",
    "desencabeçados": "desencabeçar",
    "desencabeçai": "desencabeçar",
    "desencabeçais": "desencabeçar",
    "desencabeçam": "desencabeçar",
    "desencabeçamo": "desencabeçar",
    "desencabeçamos": "desencabeçar",
    "desencabeçando": "desencabeçar",
    "desencabeçara": "desencabeçar",
    "desencabeçaram": "desencabeçar",
    "desencabeçaras": "desencabeçar",
    "desencabeçarde": "desencabeçar",
    "desencabeçardes": "desencabeçar",
    "desencabeçare": "desencabeçar",
    "desencabeçarei": "desencabeçar",
    "desencabeçareis": "desencabeçar",
    "desencabeçarem": "desencabeçar",
    "desencabeçaremos": "desencabeçar",
    "desencabeçares": "desencabeçar",
    "desencabeçaria": "desencabeçar",
    "desencabeçariam": "desencabeçar",
    "desencabeçarias": "desencabeçar",
    "desencabeçarmo": "desencabeçar",
    "desencabeçarmos": "desencabeçar",
    "desencabeçará": "desencabeçar",
    "desencabeçarás": "desencabeçar",
    "desencabeçarão": "desencabeçar",
    "desencabeçaríamos": "desencabeçar",
    "desencabeçaríeis": "desencabeçar",
    "desencabeças": "desencabeçar",
    "desencabeçasse": "desencabeçar",
    "desencabeçassem": "desencabeçar",
    "desencabeçasses": "desencabeçar",
    "desencabeçaste": "desencabeçar",
    "desencabeçastes": "desencabeçar",
    "desencabeçava": "desencabeçar",
    "desencabeçavam": "desencabeçar",
    "desencabeçavas": "desencabeçar",
    "desencabeço": "desencabeçar",
    "desencabeçou": "desencabeçar",
    "desencabeçá": "desencabeçar",
    "desencabeçámo": "desencabeçar",
    "desencabeçámos": "desencabeçar",
    "desencabeçáramo": "desencabeçar",
    "desencabeçáramos": "desencabeçar",
    "desencabeçárei": "desencabeçar",
    "desencabeçáreis": "desencabeçar",
    "desencabeçásseis": "desencabeçar",
    "desencabeçássemos": "desencabeçar",
    "desencabeçávamo": "desencabeçar",
    "desencabeçávamos": "desencabeçar",
    "desencabeçávei": "desencabeçar",
    "desencabeçáveis": "desencabeçar",
    "desencabresta": "desencabrestar",
    "desencabrestada": "desencabrestar",
    "desencabrestadas": "desencabrestar",
    "desencabrestado": "desencabrestar",
    "desencabrestados": "desencabrestar",
    "desencabrestai": "desencabrestar",
    "desencabrestais": "desencabrestar",
    "desencabrestam": "desencabrestar",
    "desencabrestamo": "desencabrestar",
    "desencabrestamos": "desencabrestar",
    "desencabrestando": "desencabrestar",
    "desencabrestara": "desencabrestar",
    "desencabrestaram": "desencabrestar",
    "desencabrestaras": "desencabrestar",
    "desencabrestarde": "desencabrestar",
    "desencabrestardes": "desencabrestar",
    "desencabrestare": "desencabrestar",
    "desencabrestarei": "desencabrestar",
    "desencabrestareis": "desencabrestar",
    "desencabrestarem": "desencabrestar",
    "desencabrestaremos": "desencabrestar",
    "desencabrestares": "desencabrestar",
    "desencabrestaria": "desencabrestar",
    "desencabrestariam": "desencabrestar",
    "desencabrestarias": "desencabrestar",
    "desencabrestarmo": "desencabrestar",
    "desencabrestarmos": "desencabrestar",
    "desencabrestará": "desencabrestar",
    "desencabrestarás": "desencabrestar",
    "desencabrestarão": "desencabrestar",
    "desencabrestaríamos": "desencabrestar",
    "desencabrestaríeis": "desencabrestar",
    "desencabrestas": "desencabrestar",
    "desencabrestasse": "desencabrestar",
    "desencabrestassem": "desencabrestar",
    "desencabrestasses": "desencabrestar",
    "desencabrestaste": "desencabrestar",
    "desencabrestastes": "desencabrestar",
    "desencabrestava": "desencabrestar",
    "desencabrestavam": "desencabrestar",
    "desencabrestavas": "desencabrestar",
    "desencabreste": "desencabrestar",
    "desencabrestei": "desencabrestar",
    "desencabresteis": "desencabrestar",
    "desencabrestem": "desencabrestar",
    "desencabrestemo": "desencabrestar",
    "desencabrestemos": "desencabrestar",
    "desencabrestes": "desencabrestar",
    "desencabresto": "desencabrestar",
    "desencabrestou": "desencabrestar",
    "desencabrestá": "desencabrestar",
    "desencabrestámo": "desencabrestar",
    "desencabrestámos": "desencabrestar",
    "desencabrestáramo": "desencabrestar",
    "desencabrestáramos": "desencabrestar",
    "desencabrestárei": "desencabrestar",
    "desencabrestáreis": "desencabrestar",
    "desencabrestásseis": "desencabrestar",
    "desencabrestássemos": "desencabrestar",
    "desencabrestávamo": "desencabrestar",
    "desencabrestávamos": "desencabrestar",
    "desencabrestávei": "desencabrestar",
    "desencabrestáveis": "desencabrestar",
    "desencachada": "desencachado",
    "desencachadas": "desencachado",
    "desencachados": "desencachado",
    "desencadeada": "desencadear",
    "desencadeadas": "desencadear",
    "desencadeado": "desencadear",
    "desencadeados": "desencadear",
    "desencadeai": "desencadear",
    "desencadeais": "desencadear",
    "desencadeamentos": "desencadeamento",
    "desencadeamo": "desencadear",
    "desencadeamos": "desencadear",
    "desencadeando": "desencadear",
    "desencadeara": "desencadear",
    "desencadearam": "desencadear",
    "desencadearas": "desencadear",
    "desencadearde": "desencadear",
    "desencadeardes": "desencadear",
    "desencadeare": "desencadear",
    "desencadearei": "desencadear",
    "desencadeareis": "desencadear",
    "desencadearem": "desencadear",
    "desencadearemos": "desencadear",
    "desencadeares": "desencadear",
    "desencadearia": "desencadear",
    "desencadeariam": "desencadear",
    "desencadearias": "desencadear",
    "desencadearmo": "desencadear",
    "desencadearmos": "desencadear",
    "desencadeará": "desencadear",
    "desencadearás": "desencadear",
    "desencadearão": "desencadear",
    "desencadearíamos": "desencadear",
    "desencadearíeis": "desencadear",
    "desencadeasse": "desencadear",
    "desencadeassem": "desencadear",
    "desencadeasses": "desencadear",
    "desencadeaste": "desencadear",
    "desencadeastes": "desencadear",
    "desencadeava": "desencadear",
    "desencadeavam": "desencadear",
    "desencadeavas": "desencadear",
    "desencadeei": "desencadear",
    "desencadeeis": "desencadear",
    "desencadeemo": "desencadear",
    "desencadeemos": "desencadear",
    "desencadeia": "desencadear",
    "desencadeiam": "desencadear",
    "desencadeias": "desencadear",
    "desencadeie": "desencadear",
    "desencadeiem": "desencadear",
    "desencadeies": "desencadear",
    "desencadeio": "desencadear",
    "desencadeou": "desencadear",
    "desencaderna": "desencadernar",
    "desencadernada": "desencadernar",
    "desencadernadas": "desencadernar",
    "desencadernado": "desencadernar",
    "desencadernados": "desencadernar",
    "desencadernai": "desencadernar",
    "desencadernais": "desencadernar",
    "desencadernam": "desencadernar",
    "desencadernamo": "desencadernar",
    "desencadernamos": "desencadernar",
    "desencadernando": "desencadernar",
    "desencadernara": "desencadernar",
    "desencadernaram": "desencadernar",
    "desencadernaras": "desencadernar",
    "desencadernarde": "desencadernar",
    "desencadernardes": "desencadernar",
    "desencadernare": "desencadernar",
    "desencadernarei": "desencadernar",
    "desencadernareis": "desencadernar",
    "desencadernarem": "desencadernar",
    "desencadernaremos": "desencadernar",
    "desencadernares": "desencadernar",
    "desencadernaria": "desencadernar",
    "desencadernariam": "desencadernar",
    "desencadernarias": "desencadernar",
    "desencadernarmo": "desencadernar",
    "desencadernarmos": "desencadernar",
    "desencadernará": "desencadernar",
    "desencadernarás": "desencadernar",
    "desencadernarão": "desencadernar",
    "desencadernaríamos": "desencadernar",
    "desencadernaríeis": "desencadernar",
    "desencadernas": "desencadernar",
    "desencadernasse": "desencadernar",
    "desencadernassem": "desencadernar",
    "desencadernasses": "desencadernar",
    "desencadernaste": "desencadernar",
    "desencadernastes": "desencadernar",
    "desencadernava": "desencadernar",
    "desencadernavam": "desencadernar",
    "desencadernavas": "desencadernar",
    "desencadernações": "desencadernação",
    "desencaderne": "desencadernar",
    "desencadernei": "desencadernar",
    "desencaderneis": "desencadernar",
    "desencadernem": "desencadernar",
    "desencadernemo": "desencadernar",
    "desencadernemos": "desencadernar",
    "desencadernes": "desencadernar",
    "desencaderno": "desencadernar",
    "desencadernou": "desencadernar",
    "desencaderná": "desencadernar",
    "desencadernámo": "desencadernar",
    "desencadernámos": "desencadernar",
    "desencadernáramo": "desencadernar",
    "desencadernáramos": "desencadernar",
    "desencadernárei": "desencadernar",
    "desencadernáreis": "desencadernar",
    "desencadernásseis": "desencadernar",
    "desencadernássemos": "desencadernar",
    "desencadernávamo": "desencadernar",
    "desencadernávamos": "desencadernar",
    "desencadernávei": "desencadernar",
    "desencadernáveis": "desencadernar",
    "desencadeá": "desencadear",
    "desencadeámo": "desencadear",
    "desencadeámos": "desencadear",
    "desencadeáramo": "desencadear",
    "desencadeáramos": "desencadear",
    "desencadeárei": "desencadear",
    "desencadeáreis": "desencadear",
    "desencadeásseis": "desencadear",
    "desencadeássemos": "desencadear",
    "desencadeávamo": "desencadear",
    "desencadeávamos": "desencadear",
    "desencadeávei": "desencadear",
    "desencadeáveis": "desencadear",
    "desencaixa": "desencaixar",
    "desencaixada": "desencaixar",
    "desencaixadas": "desencaixar",
    "desencaixado": "desencaixar",
    "desencaixados": "desencaixar",
    "desencaixaduras": "desencaixadura",
    "desencaixai": "desencaixar",
    "desencaixais": "desencaixar",
    "desencaixam": "desencaixar",
    "desencaixamentos": "desencaixamento",
    "desencaixamo": "desencaixar",
    "desencaixamos": "desencaixar",
    "desencaixando": "desencaixar",
    "desencaixara": "desencaixar",
    "desencaixaram": "desencaixar",
    "desencaixaras": "desencaixar",
    "desencaixarde": "desencaixar",
    "desencaixardes": "desencaixar",
    "desencaixare": "desencaixar",
    "desencaixarei": "desencaixar",
    "desencaixareis": "desencaixar",
    "desencaixarem": "desencaixar",
    "desencaixaremos": "desencaixar",
    "desencaixares": "desencaixar",
    "desencaixaria": "desencaixar",
    "desencaixariam": "desencaixar",
    "desencaixarias": "desencaixar",
    "desencaixarmo": "desencaixar",
    "desencaixarmos": "desencaixar",
    "desencaixará": "desencaixar",
    "desencaixarás": "desencaixar",
    "desencaixarão": "desencaixar",
    "desencaixaríamos": "desencaixar",
    "desencaixaríeis": "desencaixar",
    "desencaixas": "desencaixar",
    "desencaixasse": "desencaixar",
    "desencaixassem": "desencaixar",
    "desencaixasses": "desencaixar",
    "desencaixaste": "desencaixar",
    "desencaixastes": "desencaixar",
    "desencaixava": "desencaixar",
    "desencaixavam": "desencaixar",
    "desencaixavas": "desencaixar",
    "desencaixe": "desencaixar",
    "desencaixei": "desencaixar",
    "desencaixeis": "desencaixar",
    "desencaixem": "desencaixar",
    "desencaixemo": "desencaixar",
    "desencaixemos": "desencaixar",
    "desencaixes": "desencaixe",
    "desencaixilha": "desencaixilhar",
    "desencaixilhada": "desencaixilhar",
    "desencaixilhadas": "desencaixilhar",
    "desencaixilhado": "desencaixilhar",
    "desencaixilhados": "desencaixilhar",
    "desencaixilhai": "desencaixilhar",
    "desencaixilhais": "desencaixilhar",
    "desencaixilham": "desencaixilhar",
    "desencaixilhamo": "desencaixilhar",
    "desencaixilhamos": "desencaixilhar",
    "desencaixilhando": "desencaixilhar",
    "desencaixilhara": "desencaixilhar",
    "desencaixilharam": "desencaixilhar",
    "desencaixilharas": "desencaixilhar",
    "desencaixilharde": "desencaixilhar",
    "desencaixilhardes": "desencaixilhar",
    "desencaixilhare": "desencaixilhar",
    "desencaixilharei": "desencaixilhar",
    "desencaixilhareis": "desencaixilhar",
    "desencaixilharem": "desencaixilhar",
    "desencaixilharemos": "desencaixilhar",
    "desencaixilhares": "desencaixilhar",
    "desencaixilharia": "desencaixilhar",
    "desencaixilhariam": "desencaixilhar",
    "desencaixilharias": "desencaixilhar",
    "desencaixilharmo": "desencaixilhar",
    "desencaixilharmos": "desencaixilhar",
    "desencaixilhará": "desencaixilhar",
    "desencaixilharás": "desencaixilhar",
    "desencaixilharão": "desencaixilhar",
    "desencaixilharíamos": "desencaixilhar",
    "desencaixilharíeis": "desencaixilhar",
    "desencaixilhas": "desencaixilhar",
    "desencaixilhasse": "desencaixilhar",
    "desencaixilhassem": "desencaixilhar",
    "desencaixilhasses": "desencaixilhar",
    "desencaixilhaste": "desencaixilhar",
    "desencaixilhastes": "desencaixilhar",
    "desencaixilhava": "desencaixilhar",
    "desencaixilhavam": "desencaixilhar",
    "desencaixilhavas": "desencaixilhar",
    "desencaixilhe": "desencaixilhar",
    "desencaixilhei": "desencaixilhar",
    "desencaixilheis": "desencaixilhar",
    "desencaixilhem": "desencaixilhar",
    "desencaixilhemo": "desencaixilhar",
    "desencaixilhemos": "desencaixilhar",
    "desencaixilhes": "desencaixilhar",
    "desencaixilho": "desencaixilhar",
    "desencaixilhou": "desencaixilhar",
    "desencaixilhá": "desencaixilhar",
    "desencaixilhámo": "desencaixilhar",
    "desencaixilhámos": "desencaixilhar",
    "desencaixilháramo": "desencaixilhar",
    "desencaixilháramos": "desencaixilhar",
    "desencaixilhárei": "desencaixilhar",
    "desencaixilháreis": "desencaixilhar",
    "desencaixilhásseis": "desencaixilhar",
    "desencaixilhássemos": "desencaixilhar",
    "desencaixilhávamo": "desencaixilhar",
    "desencaixilhávamos": "desencaixilhar",
    "desencaixilhávei": "desencaixilhar",
    "desencaixilháveis": "desencaixilhar",
    "desencaixo": "desencaixar",
    "desencaixota": "desencaixotar",
    "desencaixotada": "desencaixotar",
    "desencaixotadas": "desencaixotar",
    "desencaixotado": "desencaixotar",
    "desencaixotados": "desencaixotar",
    "desencaixotai": "desencaixotar",
    "desencaixotais": "desencaixotar",
    "desencaixotam": "desencaixotar",
    "desencaixotamentos": "desencaixotamento",
    "desencaixotamo": "desencaixotar",
    "desencaixotamos": "desencaixotar",
    "desencaixotando": "desencaixotar",
    "desencaixotara": "desencaixotar",
    "desencaixotaram": "desencaixotar",
    "desencaixotaras": "desencaixotar",
    "desencaixotarde": "desencaixotar",
    "desencaixotardes": "desencaixotar",
    "desencaixotare": "desencaixotar",
    "desencaixotarei": "desencaixotar",
    "desencaixotareis": "desencaixotar",
    "desencaixotarem": "desencaixotar",
    "desencaixotaremos": "desencaixotar",
    "desencaixotares": "desencaixotar",
    "desencaixotaria": "desencaixotar",
    "desencaixotariam": "desencaixotar",
    "desencaixotarias": "desencaixotar",
    "desencaixotarmo": "desencaixotar",
    "desencaixotarmos": "desencaixotar",
    "desencaixotará": "desencaixotar",
    "desencaixotarás": "desencaixotar",
    "desencaixotarão": "desencaixotar",
    "desencaixotaríamos": "desencaixotar",
    "desencaixotaríeis": "desencaixotar",
    "desencaixotas": "desencaixotar",
    "desencaixotasse": "desencaixotar",
    "desencaixotassem": "desencaixotar",
    "desencaixotasses": "desencaixotar",
    "desencaixotaste": "desencaixotar",
    "desencaixotastes": "desencaixotar",
    "desencaixotava": "desencaixotar",
    "desencaixotavam": "desencaixotar",
    "desencaixotavas": "desencaixotar",
    "desencaixote": "desencaixotar",
    "desencaixotei": "desencaixotar",
    "desencaixoteis": "desencaixotar",
    "desencaixotem": "desencaixotar",
    "desencaixotemo": "desencaixotar",
    "desencaixotemos": "desencaixotar",
    "desencaixotes": "desencaixotar",
    "desencaixoto": "desencaixotar",
    "desencaixotou": "desencaixotar",
    "desencaixotá": "desencaixotar",
    "desencaixotámo": "desencaixotar",
    "desencaixotámos": "desencaixotar",
    "desencaixotáramo": "desencaixotar",
    "desencaixotáramos": "desencaixotar",
    "desencaixotárei": "desencaixotar",
    "desencaixotáreis": "desencaixotar",
    "desencaixotásseis": "desencaixotar",
    "desencaixotássemos": "desencaixotar",
    "desencaixotávamo": "desencaixotar",
    "desencaixotávamos": "desencaixotar",
    "desencaixotávei": "desencaixotar",
    "desencaixotáveis": "desencaixotar",
    "desencaixou": "desencaixar",
    "desencaixá": "desencaixar",
    "desencaixámo": "desencaixar",
    "desencaixámos": "desencaixar",
    "desencaixáramo": "desencaixar",
    "desencaixáramos": "desencaixar",
    "desencaixárei": "desencaixar",
    "desencaixáreis": "desencaixar",
    "desencaixásseis": "desencaixar",
    "desencaixássemos": "desencaixar",
    "desencaixávamo": "desencaixar",
    "desencaixávamos": "desencaixar",
    "desencaixávei": "desencaixar",
    "desencaixáveis": "desencaixar",
    "desencalacra": "desencalacrar",
    "desencalacrada": "desencalacrar",
    "desencalacradas": "desencalacrar",
    "desencalacrado": "desencalacrar",
    "desencalacrados": "desencalacrar",
    "desencalacrai": "desencalacrar",
    "desencalacrais": "desencalacrar",
    "desencalacram": "desencalacrar",
    "desencalacramo": "desencalacrar",
    "desencalacramos": "desencalacrar",
    "desencalacrando": "desencalacrar",
    "desencalacrara": "desencalacrar",
    "desencalacraram": "desencalacrar",
    "desencalacraras": "desencalacrar",
    "desencalacrarde": "desencalacrar",
    "desencalacrardes": "desencalacrar",
    "desencalacrare": "desencalacrar",
    "desencalacrarei": "desencalacrar",
    "desencalacrareis": "desencalacrar",
    "desencalacrarem": "desencalacrar",
    "desencalacraremos": "desencalacrar",
    "desencalacrares": "desencalacrar",
    "desencalacraria": "desencalacrar",
    "desencalacrariam": "desencalacrar",
    "desencalacrarias": "desencalacrar",
    "desencalacrarmo": "desencalacrar",
    "desencalacrarmos": "desencalacrar",
    "desencalacrará": "desencalacrar",
    "desencalacrarás": "desencalacrar",
    "desencalacrarão": "desencalacrar",
    "desencalacraríamos": "desencalacrar",
    "desencalacraríeis": "desencalacrar",
    "desencalacras": "desencalacrar",
    "desencalacrasse": "desencalacrar",
    "desencalacrassem": "desencalacrar",
    "desencalacrasses": "desencalacrar",
    "desencalacraste": "desencalacrar",
    "desencalacrastes": "desencalacrar",
    "desencalacrava": "desencalacrar",
    "desencalacravam": "desencalacrar",
    "desencalacravas": "desencalacrar",
    "desencalacrações": "desencalacração",
    "desencalacre": "desencalacrar",
    "desencalacrei": "desencalacrar",
    "desencalacreis": "desencalacrar",
    "desencalacrem": "desencalacrar",
    "desencalacremo": "desencalacrar",
    "desencalacremos": "desencalacrar",
    "desencalacres": "desencalacrar",
    "desencalacro": "desencalacrar",
    "desencalacrou": "desencalacrar",
    "desencalacrá": "desencalacrar",
    "desencalacrámo": "desencalacrar",
    "desencalacrámos": "desencalacrar",
    "desencalacráramo": "desencalacrar",
    "desencalacráramos": "desencalacrar",
    "desencalacrárei": "desencalacrar",
    "desencalacráreis": "desencalacrar",
    "desencalacrásseis": "desencalacrar",
    "desencalacrássemos": "desencalacrar",
    "desencalacrávamo": "desencalacrar",
    "desencalacrávamos": "desencalacrar",
    "desencalacrávei": "desencalacrar",
    "desencalacráveis": "desencalacrar",
    "desencalha": "desencalhar",
    "desencalhada": "desencalhar",
    "desencalhadas": "desencalhar",
    "desencalhado": "desencalhar",
    "desencalhados": "desencalhar",
    "desencalhai": "desencalhar",
    "desencalhais": "desencalhar",
    "desencalham": "desencalhar",
    "desencalhamo": "desencalhar",
    "desencalhamos": "desencalhar",
    "desencalhando": "desencalhar",
    "desencalhara": "desencalhar",
    "desencalharam": "desencalhar",
    "desencalharas": "desencalhar",
    "desencalharde": "desencalhar",
    "desencalhardes": "desencalhar",
    "desencalhare": "desencalhar",
    "desencalharei": "desencalhar",
    "desencalhareis": "desencalhar",
    "desencalharem": "desencalhar",
    "desencalharemos": "desencalhar",
    "desencalhares": "desencalhar",
    "desencalharia": "desencalhar",
    "desencalhariam": "desencalhar",
    "desencalharias": "desencalhar",
    "desencalharmo": "desencalhar",
    "desencalharmos": "desencalhar",
    "desencalhará": "desencalhar",
    "desencalharás": "desencalhar",
    "desencalharão": "desencalhar",
    "desencalharíamos": "desencalhar",
    "desencalharíeis": "desencalhar",
    "desencalhas": "desencalhar",
    "desencalhasse": "desencalhar",
    "desencalhassem": "desencalhar",
    "desencalhasses": "desencalhar",
    "desencalhaste": "desencalhar",
    "desencalhastes": "desencalhar",
    "desencalhava": "desencalhar",
    "desencalhavam": "desencalhar",
    "desencalhavas": "desencalhar",
    "desencalhe": "desencalhar",
    "desencalhei": "desencalhar",
    "desencalheis": "desencalhar",
    "desencalhem": "desencalhar",
    "desencalhemo": "desencalhar",
    "desencalhemos": "desencalhar",
    "desencalhes": "desencalhe",
    "desencalho": "desencalhar",
    "desencalhou": "desencalhar",
    "desencalhá": "desencalhar",
    "desencalhámo": "desencalhar",
    "desencalhámos": "desencalhar",
    "desencalháramo": "desencalhar",
    "desencalháramos": "desencalhar",
    "desencalhárei": "desencalhar",
    "desencalháreis": "desencalhar",
    "desencalhásseis": "desencalhar",
    "desencalhássemos": "desencalhar",
    "desencalhávamo": "desencalhar",
    "desencalhávamos": "desencalhar",
    "desencalhávei": "desencalhar",
    "desencalháveis": "desencalhar",
    "desencalma": "desencalmar",
    "desencalmada": "desencalmar",
    "desencalmadas": "desencalmar",
    "desencalmado": "desencalmar",
    "desencalmados": "desencalmar",
    "desencalmai": "desencalmar",
    "desencalmais": "desencalmar",
    "desencalmam": "desencalmar",
    "desencalmamo": "desencalmar",
    "desencalmamos": "desencalmar",
    "desencalmando": "desencalmar",
    "desencalmara": "desencalmar",
    "desencalmaram": "desencalmar",
    "desencalmaras": "desencalmar",
    "desencalmarde": "desencalmar",
    "desencalmardes": "desencalmar",
    "desencalmare": "desencalmar",
    "desencalmarei": "desencalmar",
    "desencalmareis": "desencalmar",
    "desencalmarem": "desencalmar",
    "desencalmaremos": "desencalmar",
    "desencalmares": "desencalmar",
    "desencalmaria": "desencalmar",
    "desencalmariam": "desencalmar",
    "desencalmarias": "desencalmar",
    "desencalmarmo": "desencalmar",
    "desencalmarmos": "desencalmar",
    "desencalmará": "desencalmar",
    "desencalmarás": "desencalmar",
    "desencalmarão": "desencalmar",
    "desencalmaríamos": "desencalmar",
    "desencalmaríeis": "desencalmar",
    "desencalmas": "desencalmar",
    "desencalmasse": "desencalmar",
    "desencalmassem": "desencalmar",
    "desencalmasses": "desencalmar",
    "desencalmaste": "desencalmar",
    "desencalmastes": "desencalmar",
    "desencalmava": "desencalmar",
    "desencalmavam": "desencalmar",
    "desencalmavas": "desencalmar",
    "desencalme": "desencalmar",
    "desencalmei": "desencalmar",
    "desencalmeis": "desencalmar",
    "desencalmem": "desencalmar",
    "desencalmemo": "desencalmar",
    "desencalmemos": "desencalmar",
    "desencalmes": "desencalmar",
    "desencalmo": "desencalmar",
    "desencalmou": "desencalmar",
    "desencalmá": "desencalmar",
    "desencalmámo": "desencalmar",
    "desencalmámos": "desencalmar",
    "desencalmáramo": "desencalmar",
    "desencalmáramos": "desencalmar",
    "desencalmárei": "desencalmar",
    "desencalmáreis": "desencalmar",
    "desencalmásseis": "desencalmar",
    "desencalmássemos": "desencalmar",
    "desencalmávamo": "desencalmar",
    "desencalmávamos": "desencalmar",
    "desencalmávei": "desencalmar",
    "desencalmáveis": "desencalmar",
    "desencaminha": "desencaminhar",
    "desencaminhada": "desencaminhar",
    "desencaminhadas": "desencaminhar",
    "desencaminhado": "desencaminhar",
    "desencaminhadora": "desencaminhador",
    "desencaminhadoras": "desencaminhador",
    "desencaminhadores": "desencaminhador",
    "desencaminhados": "desencaminhar",
    "desencaminhai": "desencaminhar",
    "desencaminhais": "desencaminhar",
    "desencaminham": "desencaminhar",
    "desencaminhamentos": "desencaminhamento",
    "desencaminhamo": "desencaminhar",
    "desencaminhamos": "desencaminhar",
    "desencaminhando": "desencaminhar",
    "desencaminhara": "desencaminhar",
    "desencaminharam": "desencaminhar",
    "desencaminharas": "desencaminhar",
    "desencaminharde": "desencaminhar",
    "desencaminhardes": "desencaminhar",
    "desencaminhare": "desencaminhar",
    "desencaminharei": "desencaminhar",
    "desencaminhareis": "desencaminhar",
    "desencaminharem": "desencaminhar",
    "desencaminharemos": "desencaminhar",
    "desencaminhares": "desencaminhar",
    "desencaminharia": "desencaminhar",
    "desencaminhariam": "desencaminhar",
    "desencaminharias": "desencaminhar",
    "desencaminharmo": "desencaminhar",
    "desencaminharmos": "desencaminhar",
    "desencaminhará": "desencaminhar",
    "desencaminharás": "desencaminhar",
    "desencaminharão": "desencaminhar",
    "desencaminharíamos": "desencaminhar",
    "desencaminharíeis": "desencaminhar",
    "desencaminhas": "desencaminhar",
    "desencaminhasse": "desencaminhar",
    "desencaminhassem": "desencaminhar",
    "desencaminhasses": "desencaminhar",
    "desencaminhaste": "desencaminhar",
    "desencaminhastes": "desencaminhar",
    "desencaminhava": "desencaminhar",
    "desencaminhavam": "desencaminhar",
    "desencaminhavas": "desencaminhar",
    "desencaminhe": "desencaminhar",
    "desencaminhei": "desencaminhar",
    "desencaminheis": "desencaminhar",
    "desencaminhem": "desencaminhar",
    "desencaminhemo": "desencaminhar",
    "desencaminhemos": "desencaminhar",
    "desencaminhes": "desencaminhar",
    "desencaminho": "desencaminhar",
    "desencaminhou": "desencaminhar",
    "desencaminhá": "desencaminhar",
    "desencaminhámo": "desencaminhar",
    "desencaminhámos": "desencaminhar",
    "desencaminháramo": "desencaminhar",
    "desencaminháramos": "desencaminhar",
    "desencaminhárei": "desencaminhar",
    "desencaminháreis": "desencaminhar",
    "desencaminhásseis": "desencaminhar",
    "desencaminhássemos": "desencaminhar",
    "desencaminhávamo": "desencaminhar",
    "desencaminhávamos": "desencaminhar",
    "desencaminhávei": "desencaminhar",
    "desencaminháveis": "desencaminhar",
    "desencana": "desencanar",
    "desencanada": "desencanar",
    "desencanadas": "desencanar",
    "desencanado": "desencanar",
    "desencanados": "desencanar",
    "desencanai": "desencanar",
    "desencanais": "desencanar",
    "desencanam": "desencanar",
    "desencanamo": "desencanar",
    "desencanamos": "desencanar",
    "desencanando": "desencanar",
    "desencanara": "desencanar",
    "desencanaram": "desencanar",
    "desencanaras": "desencanar",
    "desencanarde": "desencanar",
    "desencanardes": "desencanar",
    "desencanare": "desencanar",
    "desencanarei": "desencanar",
    "desencanareis": "desencanar",
    "desencanarem": "desencanar",
    "desencanaremos": "desencanar",
    "desencanares": "desencanar",
    "desencanaria": "desencanar",
    "desencanariam": "desencanar",
    "desencanarias": "desencanar",
    "desencanarmo": "desencanar",
    "desencanarmos": "desencanar",
    "desencanará": "desencanar",
    "desencanarás": "desencanar",
    "desencanarão": "desencanar",
    "desencanaríamos": "desencanar",
    "desencanaríeis": "desencanar",
    "desencanas": "desencanar",
    "desencanasse": "desencanar",
    "desencanassem": "desencanar",
    "desencanasses": "desencanar",
    "desencanaste": "desencanar",
    "desencanastes": "desencanar",
    "desencanastra": "desencanastrar",
    "desencanastrada": "desencanastrar",
    "desencanastradas": "desencanastrar",
    "desencanastrado": "desencanastrar",
    "desencanastrados": "desencanastrar",
    "desencanastrai": "desencanastrar",
    "desencanastrais": "desencanastrar",
    "desencanastram": "desencanastrar",
    "desencanastramo": "desencanastrar",
    "desencanastramos": "desencanastrar",
    "desencanastrando": "desencanastrar",
    "desencanastrara": "desencanastrar",
    "desencanastraram": "desencanastrar",
    "desencanastraras": "desencanastrar",
    "desencanastrarde": "desencanastrar",
    "desencanastrardes": "desencanastrar",
    "desencanastrare": "desencanastrar",
    "desencanastrarei": "desencanastrar",
    "desencanastrareis": "desencanastrar",
    "desencanastrarem": "desencanastrar",
    "desencanastraremos": "desencanastrar",
    "desencanastrares": "desencanastrar",
    "desencanastraria": "desencanastrar",
    "desencanastrariam": "desencanastrar",
    "desencanastrarias": "desencanastrar",
    "desencanastrarmo": "desencanastrar",
    "desencanastrarmos": "desencanastrar",
    "desencanastrará": "desencanastrar",
    "desencanastrarás": "desencanastrar",
    "desencanastrarão": "desencanastrar",
    "desencanastraríamos": "desencanastrar",
    "desencanastraríeis": "desencanastrar",
    "desencanastras": "desencanastrar",
    "desencanastrasse": "desencanastrar",
    "desencanastrassem": "desencanastrar",
    "desencanastrasses": "desencanastrar",
    "desencanastraste": "desencanastrar",
    "desencanastrastes": "desencanastrar",
    "desencanastrava": "desencanastrar",
    "desencanastravam": "desencanastrar",
    "desencanastravas": "desencanastrar",
    "desencanastre": "desencanastrar",
    "desencanastrei": "desencanastrar",
    "desencanastreis": "desencanastrar",
    "desencanastrem": "desencanastrar",
    "desencanastremo": "desencanastrar",
    "desencanastremos": "desencanastrar",
    "desencanastres": "desencanastrar",
    "desencanastro": "desencanastrar",
    "desencanastrou": "desencanastrar",
    "desencanastrá": "desencanastrar",
    "desencanastrámo": "desencanastrar",
    "desencanastrámos": "desencanastrar",
    "desencanastráramo": "desencanastrar",
    "desencanastráramos": "desencanastrar",
    "desencanastrárei": "desencanastrar",
    "desencanastráreis": "desencanastrar",
    "desencanastrásseis": "desencanastrar",
    "desencanastrássemos": "desencanastrar",
    "desencanastrávamo": "desencanastrar",
    "desencanastrávamos": "desencanastrar",
    "desencanastrávei": "desencanastrar",
    "desencanastráveis": "desencanastrar",
    "desencanava": "desencanar",
    "desencanavam": "desencanar",
    "desencanavas": "desencanar",
    "desencane": "desencanar",
    "desencanei": "desencanar",
    "desencaneis": "desencanar",
    "desencanem": "desencanar",
    "desencanemo": "desencanar",
    "desencanemos": "desencanar",
    "desencanes": "desencanar",
    "desencano": "desencanar",
    "desencanou": "desencanar",
    "desencanta": "desencantar",
    "desencantada": "desencantar",
    "desencantadas": "desencantar",
    "desencantado": "desencantar",
    "desencantados": "desencantar",
    "desencantai": "desencantar",
    "desencantais": "desencantar",
    "desencantam": "desencantar",
    "desencantamentos": "desencantamento",
    "desencantamo": "desencantar",
    "desencantamos": "desencantar",
    "desencantando": "desencantar",
    "desencantara": "desencantar",
    "desencantaram": "desencantar",
    "desencantaras": "desencantar",
    "desencantarde": "desencantar",
    "desencantardes": "desencantar",
    "desencantare": "desencantar",
    "desencantarei": "desencantar",
    "desencantareis": "desencantar",
    "desencantarem": "desencantar",
    "desencantaremos": "desencantar",
    "desencantares": "desencantar",
    "desencantaria": "desencantar",
    "desencantariam": "desencantar",
    "desencantarias": "desencantar",
    "desencantarmo": "desencantar",
    "desencantarmos": "desencantar",
    "desencantará": "desencantar",
    "desencantarás": "desencantar",
    "desencantarão": "desencantar",
    "desencantaríamos": "desencantar",
    "desencantaríeis": "desencantar",
    "desencantas": "desencantar",
    "desencantasse": "desencantar",
    "desencantassem": "desencantar",
    "desencantasses": "desencantar",
    "desencantaste": "desencantar",
    "desencantastes": "desencantar",
    "desencantava": "desencantar",
    "desencantavam": "desencantar",
    "desencantavas": "desencantar",
    "desencantações": "desencantação",
    "desencante": "desencantar",
    "desencantei": "desencantar",
    "desencanteis": "desencantar",
    "desencantem": "desencantar",
    "desencantemo": "desencantar",
    "desencantemos": "desencantar",
    "desencantes": "desencantar",
    "desencanto": "desencantar",
    "desencantos": "desencanto",
    "desencantou": "desencantar",
    "desencantá": "desencantar",
    "desencantámo": "desencantar",
    "desencantámos": "desencantar",
    "desencantáramo": "desencantar",
    "desencantáramos": "desencantar",
    "desencantárei": "desencantar",
    "desencantáreis": "desencantar",
    "desencantásseis": "desencantar",
    "desencantássemos": "desencantar",
    "desencantávamo": "desencantar",
    "desencantávamos": "desencantar",
    "desencantávei": "desencantar",
    "desencantáveis": "desencantar",
    "desencanuda": "desencanudar",
    "desencanudada": "desencanudar",
    "desencanudadas": "desencanudar",
    "desencanudado": "desencanudar",
    "desencanudados": "desencanudar",
    "desencanudai": "desencanudar",
    "desencanudais": "desencanudar",
    "desencanudam": "desencanudar",
    "desencanudamo": "desencanudar",
    "desencanudamos": "desencanudar",
    "desencanudando": "desencanudar",
    "desencanudara": "desencanudar",
    "desencanudaram": "desencanudar",
    "desencanudaras": "desencanudar",
    "desencanudarde": "desencanudar",
    "desencanudardes": "desencanudar",
    "desencanudare": "desencanudar",
    "desencanudarei": "desencanudar",
    "desencanudareis": "desencanudar",
    "desencanudarem": "desencanudar",
    "desencanudaremos": "desencanudar",
    "desencanudares": "desencanudar",
    "desencanudaria": "desencanudar",
    "desencanudariam": "desencanudar",
    "desencanudarias": "desencanudar",
    "desencanudarmo": "desencanudar",
    "desencanudarmos": "desencanudar",
    "desencanudará": "desencanudar",
    "desencanudarás": "desencanudar",
    "desencanudarão": "desencanudar",
    "desencanudaríamos": "desencanudar",
    "desencanudaríeis": "desencanudar",
    "desencanudas": "desencanudar",
    "desencanudasse": "desencanudar",
    "desencanudassem": "desencanudar",
    "desencanudasses": "desencanudar",
    "desencanudaste": "desencanudar",
    "desencanudastes": "desencanudar",
    "desencanudava": "desencanudar",
    "desencanudavam": "desencanudar",
    "desencanudavas": "desencanudar",
    "desencanude": "desencanudar",
    "desencanudei": "desencanudar",
    "desencanudeis": "desencanudar",
    "desencanudem": "desencanudar",
    "desencanudemo": "desencanudar",
    "desencanudemos": "desencanudar",
    "desencanudes": "desencanudar",
    "desencanudo": "desencanudar",
    "desencanudou": "desencanudar",
    "desencanudá": "desencanudar",
    "desencanudámo": "desencanudar",
    "desencanudámos": "desencanudar",
    "desencanudáramo": "desencanudar",
    "desencanudáramos": "desencanudar",
    "desencanudárei": "desencanudar",
    "desencanudáreis": "desencanudar",
    "desencanudásseis": "desencanudar",
    "desencanudássemos": "desencanudar",
    "desencanudávamo": "desencanudar",
    "desencanudávamos": "desencanudar",
    "desencanudávei": "desencanudar",
    "desencanudáveis": "desencanudar",
    "desencaná": "desencanar",
    "desencanámo": "desencanar",
    "desencanámos": "desencanar",
    "desencanáramo": "desencanar",
    "desencanáramos": "desencanar",
    "desencanárei": "desencanar",
    "desencanáreis": "desencanar",
    "desencanásseis": "desencanar",
    "desencanássemos": "desencanar",
    "desencanávamo": "desencanar",
    "desencanávamos": "desencanar",
    "desencanávei": "desencanar",
    "desencanáveis": "desencanar",
    "desencapa": "desencapar",
    "desencapada": "desencapar",
    "desencapadas": "desencapar",
    "desencapado": "desencapar",
    "desencapados": "desencapar",
    "desencapai": "desencapar",
    "desencapais": "desencapar",
    "desencapam": "desencapar",
    "desencapamo": "desencapar",
    "desencapamos": "desencapar",
    "desencapando": "desencapar",
    "desencapara": "desencapar",
    "desencaparam": "desencapar",
    "desencaparas": "desencapar",
    "desencaparde": "desencapar",
    "desencapardes": "desencapar",
    "desencapare": "desencapar",
    "desencaparei": "desencapar",
    "desencapareis": "desencapar",
    "desencaparem": "desencapar",
    "desencaparemos": "desencapar",
    "desencapares": "desencapar",
    "desencaparia": "desencapar",
    "desencapariam": "desencapar",
    "desencaparias": "desencapar",
    "desencaparmo": "desencapar",
    "desencaparmos": "desencapar",
    "desencapará": "desencapar",
    "desencaparás": "desencapar",
    "desencaparão": "desencapar",
    "desencaparíamos": "desencapar",
    "desencaparíeis": "desencapar",
    "desencapas": "desencapar",
    "desencapasse": "desencapar",
    "desencapassem": "desencapar",
    "desencapasses": "desencapar",
    "desencapaste": "desencapar",
    "desencapastes": "desencapar",
    "desencapava": "desencapar",
    "desencapavam": "desencapar",
    "desencapavas": "desencapar",
    "desencape": "desencapar",
    "desencapei": "desencapar",
    "desencapeis": "desencapar",
    "desencapela": "desencapelar",
    "desencapelada": "desencapelar",
    "desencapeladas": "desencapelar",
    "desencapelado": "desencapelar",
    "desencapelados": "desencapelar",
    "desencapelai": "desencapelar",
    "desencapelais": "desencapelar",
    "desencapelam": "desencapelar",
    "desencapelamo": "desencapelar",
    "desencapelamos": "desencapelar",
    "desencapelando": "desencapelar",
    "desencapelara": "desencapelar",
    "desencapelaram": "desencapelar",
    "desencapelaras": "desencapelar",
    "desencapelarde": "desencapelar",
    "desencapelardes": "desencapelar",
    "desencapelare": "desencapelar",
    "desencapelarei": "desencapelar",
    "desencapelareis": "desencapelar",
    "desencapelarem": "desencapelar",
    "desencapelaremos": "desencapelar",
    "desencapelares": "desencapelar",
    "desencapelaria": "desencapelar",
    "desencapelariam": "desencapelar",
    "desencapelarias": "desencapelar",
    "desencapelarmo": "desencapelar",
    "desencapelarmos": "desencapelar",
    "desencapelará": "desencapelar",
    "desencapelarás": "desencapelar",
    "desencapelarão": "desencapelar",
    "desencapelaríamos": "desencapelar",
    "desencapelaríeis": "desencapelar",
    "desencapelas": "desencapelar",
    "desencapelasse": "desencapelar",
    "desencapelassem": "desencapelar",
    "desencapelasses": "desencapelar",
    "desencapelaste": "desencapelar",
    "desencapelastes": "desencapelar",
    "desencapelava": "desencapelar",
    "desencapelavam": "desencapelar",
    "desencapelavas": "desencapelar",
    "desencapele": "desencapelar",
    "desencapelei": "desencapelar",
    "desencapeleis": "desencapelar",
    "desencapelem": "desencapelar",
    "desencapelemo": "desencapelar",
    "desencapelemos": "desencapelar",
    "desencapeles": "desencapelar",
    "desencapelo": "desencapelar",
    "desencapelou": "desencapelar",
    "desencapelá": "desencapelar",
    "desencapelámo": "desencapelar",
    "desencapelámos": "desencapelar",
    "desencapeláramo": "desencapelar",
    "desencapeláramos": "desencapelar",
    "desencapelárei": "desencapelar",
    "desencapeláreis": "desencapelar",
    "desencapelásseis": "desencapelar",
    "desencapelássemos": "desencapelar",
    "desencapelávamo": "desencapelar",
    "desencapelávamos": "desencapelar",
    "desencapelávei": "desencapelar",
    "desencapeláveis": "desencapelar",
    "desencapem": "desencapar",
    "desencapemo": "desencapar",
    "desencapemos": "desencapar",
    "desencapes": "desencapar",
    "desencapo": "desencapar",
    "desencapoeira": "desencapoeirar",
    "desencapoeirada": "desencapoeirar",
    "desencapoeiradas": "desencapoeirar",
    "desencapoeirado": "desencapoeirar",
    "desencapoeirados": "desencapoeirar",
    "desencapoeirai": "desencapoeirar",
    "desencapoeirais": "desencapoeirar",
    "desencapoeiram": "desencapoeirar",
    "desencapoeiramo": "desencapoeirar",
    "desencapoeiramos": "desencapoeirar",
    "desencapoeirando": "desencapoeirar",
    "desencapoeirara": "desencapoeirar",
    "desencapoeiraram": "desencapoeirar",
    "desencapoeiraras": "desencapoeirar",
    "desencapoeirarde": "desencapoeirar",
    "desencapoeirardes": "desencapoeirar",
    "desencapoeirare": "desencapoeirar",
    "desencapoeirarei": "desencapoeirar",
    "desencapoeirareis": "desencapoeirar",
    "desencapoeirarem": "desencapoeirar",
    "desencapoeiraremos": "desencapoeirar",
    "desencapoeirares": "desencapoeirar",
    "desencapoeiraria": "desencapoeirar",
    "desencapoeirariam": "desencapoeirar",
    "desencapoeirarias": "desencapoeirar",
    "desencapoeirarmo": "desencapoeirar",
    "desencapoeirarmos": "desencapoeirar",
    "desencapoeirará": "desencapoeirar",
    "desencapoeirarás": "desencapoeirar",
    "desencapoeirarão": "desencapoeirar",
    "desencapoeiraríamos": "desencapoeirar",
    "desencapoeiraríeis": "desencapoeirar",
    "desencapoeiras": "desencapoeirar",
    "desencapoeirasse": "desencapoeirar",
    "desencapoeirassem": "desencapoeirar",
    "desencapoeirasses": "desencapoeirar",
    "desencapoeiraste": "desencapoeirar",
    "desencapoeirastes": "desencapoeirar",
    "desencapoeirava": "desencapoeirar",
    "desencapoeiravam": "desencapoeirar",
    "desencapoeiravas": "desencapoeirar",
    "desencapoeire": "desencapoeirar",
    "desencapoeirei": "desencapoeirar",
    "desencapoeireis": "desencapoeirar",
    "desencapoeirem": "desencapoeirar",
    "desencapoeiremo": "desencapoeirar",
    "desencapoeiremos": "desencapoeirar",
    "desencapoeires": "desencapoeirar",
    "desencapoeiro": "desencapoeirar",
    "desencapoeirou": "desencapoeirar",
    "desencapoeirá": "desencapoeirar",
    "desencapoeirámo": "desencapoeirar",
    "desencapoeirámos": "desencapoeirar",
    "desencapoeiráramo": "desencapoeirar",
    "desencapoeiráramos": "desencapoeirar",
    "desencapoeirárei": "desencapoeirar",
    "desencapoeiráreis": "desencapoeirar",
    "desencapoeirásseis": "desencapoeirar",
    "desencapoeirássemos": "desencapoeirar",
    "desencapoeirávamo": "desencapoeirar",
    "desencapoeirávamos": "desencapoeirar",
    "desencapoeirávei": "desencapoeirar",
    "desencapoeiráveis": "desencapoeirar",
    "desencapota": "desencapotar",
    "desencapotada": "desencapotar",
    "desencapotadas": "desencapotar",
    "desencapotado": "desencapotar",
    "desencapotados": "desencapotar",
    "desencapotai": "desencapotar",
    "desencapotais": "desencapotar",
    "desencapotam": "desencapotar",
    "desencapotamo": "desencapotar",
    "desencapotamos": "desencapotar",
    "desencapotando": "desencapotar",
    "desencapotara": "desencapotar",
    "desencapotaram": "desencapotar",
    "desencapotaras": "desencapotar",
    "desencapotarde": "desencapotar",
    "desencapotardes": "desencapotar",
    "desencapotare": "desencapotar",
    "desencapotarei": "desencapotar",
    "desencapotareis": "desencapotar",
    "desencapotarem": "desencapotar",
    "desencapotaremos": "desencapotar",
    "desencapotares": "desencapotar",
    "desencapotaria": "desencapotar",
    "desencapotariam": "desencapotar",
    "desencapotarias": "desencapotar",
    "desencapotarmo": "desencapotar",
    "desencapotarmos": "desencapotar",
    "desencapotará": "desencapotar",
    "desencapotarás": "desencapotar",
    "desencapotarão": "desencapotar",
    "desencapotaríamos": "desencapotar",
    "desencapotaríeis": "desencapotar",
    "desencapotas": "desencapotar",
    "desencapotasse": "desencapotar",
    "desencapotassem": "desencapotar",
    "desencapotasses": "desencapotar",
    "desencapotaste": "desencapotar",
    "desencapotastes": "desencapotar",
    "desencapotava": "desencapotar",
    "desencapotavam": "desencapotar",
    "desencapotavas": "desencapotar",
    "desencapote": "desencapotar",
    "desencapotei": "desencapotar",
    "desencapoteis": "desencapotar",
    "desencapotem": "desencapotar",
    "desencapotemo": "desencapotar",
    "desencapotemos": "desencapotar",
    "desencapotes": "desencapotar",
    "desencapoto": "desencapotar",
    "desencapotou": "desencapotar",
    "desencapotá": "desencapotar",
    "desencapotámo": "desencapotar",
    "desencapotámos": "desencapotar",
    "desencapotáramo": "desencapotar",
    "desencapotáramos": "desencapotar",
    "desencapotárei": "desencapotar",
    "desencapotáreis": "desencapotar",
    "desencapotásseis": "desencapotar",
    "desencapotássemos": "desencapotar",
    "desencapotávamo": "desencapotar",
    "desencapotávamos": "desencapotar",
    "desencapotávei": "desencapotar",
    "desencapotáveis": "desencapotar",
    "desencapou": "desencapar",
    "desencapá": "desencapar",
    "desencapámo": "desencapar",
    "desencapámos": "desencapar",
    "desencapáramo": "desencapar",
    "desencapáramos": "desencapar",
    "desencapárei": "desencapar",
    "desencapáreis": "desencapar",
    "desencapásseis": "desencapar",
    "desencapássemos": "desencapar",
    "desencapávamo": "desencapar",
    "desencapávamos": "desencapar",
    "desencapávei": "desencapar",
    "desencapáveis": "desencapar",
    "desencaracola": "desencaracolar",
    "desencaracolada": "desencaracolar",
    "desencaracoladas": "desencaracolar",
    "desencaracolado": "desencaracolar",
    "desencaracolados": "desencaracolar",
    "desencaracolai": "desencaracolar",
    "desencaracolais": "desencaracolar",
    "desencaracolam": "desencaracolar",
    "desencaracolamo": "desencaracolar",
    "desencaracolamos": "desencaracolar",
    "desencaracolando": "desencaracolar",
    "desencaracolara": "desencaracolar",
    "desencaracolaram": "desencaracolar",
    "desencaracolaras": "desencaracolar",
    "desencaracolarde": "desencaracolar",
    "desencaracolardes": "desencaracolar",
    "desencaracolare": "desencaracolar",
    "desencaracolarei": "desencaracolar",
    "desencaracolareis": "desencaracolar",
    "desencaracolarem": "desencaracolar",
    "desencaracolaremos": "desencaracolar",
    "desencaracolares": "desencaracolar",
    "desencaracolaria": "desencaracolar",
    "desencaracolariam": "desencaracolar",
    "desencaracolarias": "desencaracolar",
    "desencaracolarmo": "desencaracolar",
    "desencaracolarmos": "desencaracolar",
    "desencaracolará": "desencaracolar",
    "desencaracolarás": "desencaracolar",
    "desencaracolarão": "desencaracolar",
    "desencaracolaríamos": "desencaracolar",
    "desencaracolaríeis": "desencaracolar",
    "desencaracolas": "desencaracolar",
    "desencaracolasse": "desencaracolar",
    "desencaracolassem": "desencaracolar",
    "desencaracolasses": "desencaracolar",
    "desencaracolaste": "desencaracolar",
    "desencaracolastes": "desencaracolar",
    "desencaracolava": "desencaracolar",
    "desencaracolavam": "desencaracolar",
    "desencaracolavas": "desencaracolar",
    "desencaracole": "desencaracolar",
    "desencaracolei": "desencaracolar",
    "desencaracoleis": "desencaracolar",
    "desencaracolem": "desencaracolar",
    "desencaracolemo": "desencaracolar",
    "desencaracolemos": "desencaracolar",
    "desencaracoles": "desencaracolar",
    "desencaracolo": "desencaracolar",
    "desencaracolou": "desencaracolar",
    "desencaracolá": "desencaracolar",
    "desencaracolámo": "desencaracolar",
    "desencaracolámos": "desencaracolar",
    "desencaracoláramo": "desencaracolar",
    "desencaracoláramos": "desencaracolar",
    "desencaracolárei": "desencaracolar",
    "desencaracoláreis": "desencaracolar",
    "desencaracolásseis": "desencaracolar",
    "desencaracolássemos": "desencaracolar",
    "desencaracolávamo": "desencaracolar",
    "desencaracolávamos": "desencaracolar",
    "desencaracolávei": "desencaracolar",
    "desencaracoláveis": "desencaracolar",
    "desencarapela": "desencarapelar",
    "desencarapelada": "desencarapelar",
    "desencarapeladas": "desencarapelar",
    "desencarapelado": "desencarapelar",
    "desencarapelados": "desencarapelar",
    "desencarapelai": "desencarapelar",
    "desencarapelais": "desencarapelar",
    "desencarapelam": "desencarapelar",
    "desencarapelamo": "desencarapelar",
    "desencarapelamos": "desencarapelar",
    "desencarapelando": "desencarapelar",
    "desencarapelara": "desencarapelar",
    "desencarapelaram": "desencarapelar",
    "desencarapelaras": "desencarapelar",
    "desencarapelarde": "desencarapelar",
    "desencarapelardes": "desencarapelar",
    "desencarapelare": "desencarapelar",
    "desencarapelarei": "desencarapelar",
    "desencarapelareis": "desencarapelar",
    "desencarapelarem": "desencarapelar",
    "desencarapelaremos": "desencarapelar",
    "desencarapelares": "desencarapelar",
    "desencarapelaria": "desencarapelar",
    "desencarapelariam": "desencarapelar",
    "desencarapelarias": "desencarapelar",
    "desencarapelarmo": "desencarapelar",
    "desencarapelarmos": "desencarapelar",
    "desencarapelará": "desencarapelar",
    "desencarapelarás": "desencarapelar",
    "desencarapelarão": "desencarapelar",
    "desencarapelaríamos": "desencarapelar",
    "desencarapelaríeis": "desencarapelar",
    "desencarapelas": "desencarapelar",
    "desencarapelasse": "desencarapelar",
    "desencarapelassem": "desencarapelar",
    "desencarapelasses": "desencarapelar",
    "desencarapelaste": "desencarapelar",
    "desencarapelastes": "desencarapelar",
    "desencarapelava": "desencarapelar",
    "desencarapelavam": "desencarapelar",
    "desencarapelavas": "desencarapelar",
    "desencarapele": "desencarapelar",
    "desencarapelei": "desencarapelar",
    "desencarapeleis": "desencarapelar",
    "desencarapelem": "desencarapelar",
    "desencarapelemo": "desencarapelar",
    "desencarapelemos": "desencarapelar",
    "desencarapeles": "desencarapelar",
    "desencarapelo": "desencarapelar",
    "desencarapelou": "desencarapelar",
    "desencarapelá": "desencarapelar",
    "desencarapelámo": "desencarapelar",
    "desencarapelámos": "desencarapelar",
    "desencarapeláramo": "desencarapelar",
    "desencarapeláramos": "desencarapelar",
    "desencarapelárei": "desencarapelar",
    "desencarapeláreis": "desencarapelar",
    "desencarapelásseis": "desencarapelar",
    "desencarapelássemos": "desencarapelar",
    "desencarapelávamo": "desencarapelar",
    "desencarapelávamos": "desencarapelar",
    "desencarapelávei": "desencarapelar",
    "desencarapeláveis": "desencarapelar",
    "desencarapinha": "desencarapinhar",
    "desencarapinhada": "desencarapinhar",
    "desencarapinhadas": "desencarapinhar",
    "desencarapinhado": "desencarapinhar",
    "desencarapinhados": "desencarapinhar",
    "desencarapinhai": "desencarapinhar",
    "desencarapinhais": "desencarapinhar",
    "desencarapinham": "desencarapinhar",
    "desencarapinhamo": "desencarapinhar",
    "desencarapinhamos": "desencarapinhar",
    "desencarapinhando": "desencarapinhar",
    "desencarapinhara": "desencarapinhar",
    "desencarapinharam": "desencarapinhar",
    "desencarapinharas": "desencarapinhar",
    "desencarapinharde": "desencarapinhar",
    "desencarapinhardes": "desencarapinhar",
    "desencarapinhare": "desencarapinhar",
    "desencarapinharei": "desencarapinhar",
    "desencarapinhareis": "desencarapinhar",
    "desencarapinharem": "desencarapinhar",
    "desencarapinharemos": "desencarapinhar",
    "desencarapinhares": "desencarapinhar",
    "desencarapinharia": "desencarapinhar",
    "desencarapinhariam": "desencarapinhar",
    "desencarapinharias": "desencarapinhar",
    "desencarapinharmo": "desencarapinhar",
    "desencarapinharmos": "desencarapinhar",
    "desencarapinhará": "desencarapinhar",
    "desencarapinharás": "desencarapinhar",
    "desencarapinharão": "desencarapinhar",
    "desencarapinharíamos": "desencarapinhar",
    "desencarapinharíeis": "desencarapinhar",
    "desencarapinhas": "desencarapinhar",
    "desencarapinhasse": "desencarapinhar",
    "desencarapinhassem": "desencarapinhar",
    "desencarapinhasses": "desencarapinhar",
    "desencarapinhaste": "desencarapinhar",
    "desencarapinhastes": "desencarapinhar",
    "desencarapinhava": "desencarapinhar",
    "desencarapinhavam": "desencarapinhar",
    "desencarapinhavas": "desencarapinhar",
    "desencarapinhe": "desencarapinhar",
    "desencarapinhei": "desencarapinhar",
    "desencarapinheis": "desencarapinhar",
    "desencarapinhem": "desencarapinhar",
    "desencarapinhemo": "desencarapinhar",
    "desencarapinhemos": "desencarapinhar",
    "desencarapinhes": "desencarapinhar",
    "desencarapinho": "desencarapinhar",
    "desencarapinhou": "desencarapinhar",
    "desencarapinhá": "desencarapinhar",
    "desencarapinhámo": "desencarapinhar",
    "desencarapinhámos": "desencarapinhar",
    "desencarapinháramo": "desencarapinhar",
    "desencarapinháramos": "desencarapinhar",
    "desencarapinhárei": "desencarapinhar",
    "desencarapinháreis": "desencarapinhar",
    "desencarapinhásseis": "desencarapinhar",
    "desencarapinhássemos": "desencarapinhar",
    "desencarapinhávamo": "desencarapinhar",
    "desencarapinhávamos": "desencarapinhar",
    "desencarapinhávei": "desencarapinhar",
    "desencarapinháveis": "desencarapinhar",
    "desencarapuce": "desencarapuçar",
    "desencarapucei": "desencarapuçar",
    "desencarapuceis": "desencarapuçar",
    "desencarapucem": "desencarapuçar",
    "desencarapucemo": "desencarapuçar",
    "desencarapucemos": "desencarapuçar",
    "desencarapuces": "desencarapuçar",
    "desencarapuça": "desencarapuçar",
    "desencarapuçada": "desencarapuçar",
    "desencarapuçadas": "desencarapuçar",
    "desencarapuçado": "desencarapuçar",
    "desencarapuçados": "desencarapuçar",
    "desencarapuçai": "desencarapuçar",
    "desencarapuçais": "desencarapuçar",
    "desencarapuçam": "desencarapuçar",
    "desencarapuçamo": "desencarapuçar",
    "desencarapuçamos": "desencarapuçar",
    "desencarapuçando": "desencarapuçar",
    "desencarapuçara": "desencarapuçar",
    "desencarapuçaram": "desencarapuçar",
    "desencarapuçaras": "desencarapuçar",
    "desencarapuçarde": "desencarapuçar",
    "desencarapuçardes": "desencarapuçar",
    "desencarapuçare": "desencarapuçar",
    "desencarapuçarei": "desencarapuçar",
    "desencarapuçareis": "desencarapuçar",
    "desencarapuçarem": "desencarapuçar",
    "desencarapuçaremos": "desencarapuçar",
    "desencarapuçares": "desencarapuçar",
    "desencarapuçaria": "desencarapuçar",
    "desencarapuçariam": "desencarapuçar",
    "desencarapuçarias": "desencarapuçar",
    "desencarapuçarmo": "desencarapuçar",
    "desencarapuçarmos": "desencarapuçar",
    "desencarapuçará": "desencarapuçar",
    "desencarapuçarás": "desencarapuçar",
    "desencarapuçarão": "desencarapuçar",
    "desencarapuçaríamos": "desencarapuçar",
    "desencarapuçaríeis": "desencarapuçar",
    "desencarapuças": "desencarapuçar",
    "desencarapuçasse": "desencarapuçar",
    "desencarapuçassem": "desencarapuçar",
    "desencarapuçasses": "desencarapuçar",
    "desencarapuçaste": "desencarapuçar",
    "desencarapuçastes": "desencarapuçar",
    "desencarapuçava": "desencarapuçar",
    "desencarapuçavam": "desencarapuçar",
    "desencarapuçavas": "desencarapuçar",
    "desencarapuço": "desencarapuçar",
    "desencarapuçou": "desencarapuçar",
    "desencarapuçá": "desencarapuçar",
    "desencarapuçámo": "desencarapuçar",
    "desencarapuçámos": "desencarapuçar",
    "desencarapuçáramo": "desencarapuçar",
    "desencarapuçáramos": "desencarapuçar",
    "desencarapuçárei": "desencarapuçar",
    "desencarapuçáreis": "desencarapuçar",
    "desencarapuçásseis": "desencarapuçar",
    "desencarapuçássemos": "desencarapuçar",
    "desencarapuçávamo": "desencarapuçar",
    "desencarapuçávamos": "desencarapuçar",
    "desencarapuçávei": "desencarapuçar",
    "desencarapuçáveis": "desencarapuçar",
    "desencarcera": "desencarcerar",
    "desencarcerada": "desencarcerar",
    "desencarceradas": "desencarcerar",
    "desencarcerado": "desencarcerar",
    "desencarcerados": "desencarcerar",
    "desencarcerai": "desencarcerar",
    "desencarcerais": "desencarcerar",
    "desencarceram": "desencarcerar",
    "desencarceramentos": "desencarceramento",
    "desencarceramo": "desencarcerar",
    "desencarceramos": "desencarcerar",
    "desencarcerando": "desencarcerar",
    "desencarcerara": "desencarcerar",
    "desencarceraram": "desencarcerar",
    "desencarceraras": "desencarcerar",
    "desencarcerarde": "desencarcerar",
    "desencarcerardes": "desencarcerar",
    "desencarcerare": "desencarcerar",
    "desencarcerarei": "desencarcerar",
    "desencarcerareis": "desencarcerar",
    "desencarcerarem": "desencarcerar",
    "desencarceraremos": "desencarcerar",
    "desencarcerares": "desencarcerar",
    "desencarceraria": "desencarcerar",
    "desencarcerariam": "desencarcerar",
    "desencarcerarias": "desencarcerar",
    "desencarcerarmo": "desencarcerar",
    "desencarcerarmos": "desencarcerar",
    "desencarcerará": "desencarcerar",
    "desencarcerarás": "desencarcerar",
    "desencarcerarão": "desencarcerar",
    "desencarceraríamos": "desencarcerar",
    "desencarceraríeis": "desencarcerar",
    "desencarceras": "desencarcerar",
    "desencarcerasse": "desencarcerar",
    "desencarcerassem": "desencarcerar",
    "desencarcerasses": "desencarcerar",
    "desencarceraste": "desencarcerar",
    "desencarcerastes": "desencarcerar",
    "desencarcerava": "desencarcerar",
    "desencarceravam": "desencarcerar",
    "desencarceravas": "desencarcerar",
    "desencarcere": "desencarcerar",
    "desencarcerei": "desencarcerar",
    "desencarcereis": "desencarcerar",
    "desencarcerem": "desencarcerar",
    "desencarceremo": "desencarcerar",
    "desencarceremos": "desencarcerar",
    "desencarceres": "desencarcerar",
    "desencarcero": "desencarcerar",
    "desencarcerou": "desencarcerar",
    "desencarcerá": "desencarcerar",
    "desencarcerámo": "desencarcerar",
    "desencarcerámos": "desencarcerar",
    "desencarceráramo": "desencarcerar",
    "desencarceráramos": "desencarcerar",
    "desencarcerárei": "desencarcerar",
    "desencarceráreis": "desencarcerar",
    "desencarcerásseis": "desencarcerar",
    "desencarcerássemos": "desencarcerar",
    "desencarcerávamo": "desencarcerar",
    "desencarcerávamos": "desencarcerar",
    "desencarcerávei": "desencarcerar",
    "desencarceráveis": "desencarcerar",
    "desencarda": "desencardir",
    "desencardais": "desencardir",
    "desencardam": "desencardir",
    "desencardamo": "desencardir",
    "desencardamos": "desencardir",
    "desencardas": "desencardir",
    "desencarde": "desencardir",
    "desencardem": "desencardir",
    "desencardes": "desencardir",
    "desencardi": "desencardir",
    "desencardia": "desencardir",
    "desencardiam": "desencardir",
    "desencardias": "desencardir",
    "desencardida": "desencardir",
    "desencardidas": "desencardir",
    "desencardideiras": "desencardideira",
    "desencardido": "desencardir",
    "desencardidos": "desencardir",
    "desencardimentos": "desencardimento",
    "desencardimo": "desencardir",
    "desencardimos": "desencardir",
    "desencardindo": "desencardir",
    "desencardira": "desencardir",
    "desencardiram": "desencardir",
    "desencardiras": "desencardir",
    "desencardirde": "desencardir",
    "desencardirdes": "desencardir",
    "desencardire": "desencardir",
    "desencardirei": "desencardir",
    "desencardireis": "desencardir",
    "desencardirem": "desencardir",
    "desencardiremos": "desencardir",
    "desencardires": "desencardir",
    "desencardiria": "desencardir",
    "desencardiriam": "desencardir",
    "desencardirias": "desencardir",
    "desencardirmo": "desencardir",
    "desencardirmos": "desencardir",
    "desencardirá": "desencardir",
    "desencardirás": "desencardir",
    "desencardirão": "desencardir",
    "desencardiríamos": "desencardir",
    "desencardiríeis": "desencardir",
    "desencardis": "desencardir",
    "desencardisse": "desencardir",
    "desencardissem": "desencardir",
    "desencardisses": "desencardir",
    "desencardiste": "desencardir",
    "desencardistes": "desencardir",
    "desencardiu": "desencardir",
    "desencardo": "desencardir",
    "desencardíamo": "desencardir",
    "desencardíamos": "desencardir",
    "desencardíei": "desencardir",
    "desencardíeis": "desencardir",
    "desencardíramo": "desencardir",
    "desencardíramos": "desencardir",
    "desencardírei": "desencardir",
    "desencardíreis": "desencardir",
    "desencardísseis": "desencardir",
    "desencardíssemos": "desencardir",
    "desencarece": "desencarecer",
    "desencarecei": "desencarecer",
    "desencareceis": "desencarecer",
    "desencarecem": "desencarecer",
    "desencarecemo": "desencarecer",
    "desencarecemos": "desencarecer",
    "desencarecendo": "desencarecer",
    "desencarecera": "desencarecer",
    "desencareceram": "desencarecer",
    "desencareceras": "desencarecer",
    "desencarecerde": "desencarecer",
    "desencarecerdes": "desencarecer",
    "desencarecere": "desencarecer",
    "desencarecerei": "desencarecer",
    "desencarecereis": "desencarecer",
    "desencarecerem": "desencarecer",
    "desencareceremos": "desencarecer",
    "desencareceres": "desencarecer",
    "desencareceria": "desencarecer",
    "desencareceriam": "desencarecer",
    "desencarecerias": "desencarecer",
    "desencarecermo": "desencarecer",
    "desencarecermos": "desencarecer",
    "desencarecerá": "desencarecer",
    "desencarecerás": "desencarecer",
    "desencarecerão": "desencarecer",
    "desencareceríamos": "desencarecer",
    "desencareceríeis": "desencarecer",
    "desencareces": "desencarecer",
    "desencarecesse": "desencarecer",
    "desencarecessem": "desencarecer",
    "desencarecesses": "desencarecer",
    "desencareceste": "desencarecer",
    "desencarecestes": "desencarecer",
    "desencareceu": "desencarecer",
    "desencareci": "desencarecer",
    "desencarecia": "desencarecer",
    "desencareciam": "desencarecer",
    "desencarecias": "desencarecer",
    "desencarecida": "desencarecido",
    "desencarecidas": "desencarecido",
    "desencarecido": "desencarecer",
    "desencarecidos": "desencarecido",
    "desencarecê": "desencarecer",
    "desencarecêramo": "desencarecer",
    "desencarecêramos": "desencarecer",
    "desencarecêrei": "desencarecer",
    "desencarecêreis": "desencarecer",
    "desencarecêsseis": "desencarecer",
    "desencarecêssemos": "desencarecer",
    "desencarecíamo": "desencarecer",
    "desencarecíamos": "desencarecer",
    "desencarecíei": "desencarecer",
    "desencarecíeis": "desencarecer",
    "desencareça": "desencarecer",
    "desencareçais": "desencarecer",
    "desencareçam": "desencarecer",
    "desencareçamo": "desencarecer",
    "desencareçamos": "desencarecer",
    "desencareças": "desencarecer",
    "desencareço": "desencarecer",
    "desencargos": "desencargo",
    "desencarquilha": "desencarquilhar",
    "desencarquilhada": "desencarquilhar",
    "desencarquilhadas": "desencarquilhar",
    "desencarquilhado": "desencarquilhar",
    "desencarquilhados": "desencarquilhar",
    "desencarquilhai": "desencarquilhar",
    "desencarquilhais": "desencarquilhar",
    "desencarquilham": "desencarquilhar",
    "desencarquilhamo": "desencarquilhar",
    "desencarquilhamos": "desencarquilhar",
    "desencarquilhando": "desencarquilhar",
    "desencarquilhara": "desencarquilhar",
    "desencarquilharam": "desencarquilhar",
    "desencarquilharas": "desencarquilhar",
    "desencarquilharde": "desencarquilhar",
    "desencarquilhardes": "desencarquilhar",
    "desencarquilhare": "desencarquilhar",
    "desencarquilharei": "desencarquilhar",
    "desencarquilhareis": "desencarquilhar",
    "desencarquilharem": "desencarquilhar",
    "desencarquilharemos": "desencarquilhar",
    "desencarquilhares": "desencarquilhar",
    "desencarquilharia": "desencarquilhar",
    "desencarquilhariam": "desencarquilhar",
    "desencarquilharias": "desencarquilhar",
    "desencarquilharmo": "desencarquilhar",
    "desencarquilharmos": "desencarquilhar",
    "desencarquilhará": "desencarquilhar",
    "desencarquilharás": "desencarquilhar",
    "desencarquilharão": "desencarquilhar",
    "desencarquilharíamos": "desencarquilhar",
    "desencarquilharíeis": "desencarquilhar",
    "desencarquilhas": "desencarquilhar",
    "desencarquilhasse": "desencarquilhar",
    "desencarquilhassem": "desencarquilhar",
    "desencarquilhasses": "desencarquilhar",
    "desencarquilhaste": "desencarquilhar",
    "desencarquilhastes": "desencarquilhar",
    "desencarquilhava": "desencarquilhar",
    "desencarquilhavam": "desencarquilhar",
    "desencarquilhavas": "desencarquilhar",
    "desencarquilhe": "desencarquilhar",
    "desencarquilhei": "desencarquilhar",
    "desencarquilheis": "desencarquilhar",
    "desencarquilhem": "desencarquilhar",
    "desencarquilhemo": "desencarquilhar",
    "desencarquilhemos": "desencarquilhar",
    "desencarquilhes": "desencarquilhar",
    "desencarquilho": "desencarquilhar",
    "desencarquilhou": "desencarquilhar",
    "desencarquilhá": "desencarquilhar",
    "desencarquilhámo": "desencarquilhar",
    "desencarquilhámos": "desencarquilhar",
    "desencarquilháramo": "desencarquilhar",
    "desencarquilháramos": "desencarquilhar",
    "desencarquilhárei": "desencarquilhar",
    "desencarquilháreis": "desencarquilhar",
    "desencarquilhásseis": "desencarquilhar",
    "desencarquilhássemos": "desencarquilhar",
    "desencarquilhávamo": "desencarquilhar",
    "desencarquilhávamos": "desencarquilhar",
    "desencarquilhávei": "desencarquilhar",
    "desencarquilháveis": "desencarquilhar",
    "desencarranca": "desencarrancar",
    "desencarrancada": "desencarrancar",
    "desencarrancadas": "desencarrancar",
    "desencarrancado": "desencarrancar",
    "desencarrancados": "desencarrancar",
    "desencarrancai": "desencarrancar",
    "desencarrancais": "desencarrancar",
    "desencarrancam": "desencarrancar",
    "desencarrancamo": "desencarrancar",
    "desencarrancamos": "desencarrancar",
    "desencarrancando": "desencarrancar",
    "desencarrancara": "desencarrancar",
    "desencarrancaram": "desencarrancar",
    "desencarrancaras": "desencarrancar",
    "desencarrancarde": "desencarrancar",
    "desencarrancardes": "desencarrancar",
    "desencarrancare": "desencarrancar",
    "desencarrancarei": "desencarrancar",
    "desencarrancareis": "desencarrancar",
    "desencarrancarem": "desencarrancar",
    "desencarrancaremos": "desencarrancar",
    "desencarrancares": "desencarrancar",
    "desencarrancaria": "desencarrancar",
    "desencarrancariam": "desencarrancar",
    "desencarrancarias": "desencarrancar",
    "desencarrancarmo": "desencarrancar",
    "desencarrancarmos": "desencarrancar",
    "desencarrancará": "desencarrancar",
    "desencarrancarás": "desencarrancar",
    "desencarrancarão": "desencarrancar",
    "desencarrancaríamos": "desencarrancar",
    "desencarrancaríeis": "desencarrancar",
    "desencarrancas": "desencarrancar",
    "desencarrancasse": "desencarrancar",
    "desencarrancassem": "desencarrancar",
    "desencarrancasses": "desencarrancar",
    "desencarrancaste": "desencarrancar",
    "desencarrancastes": "desencarrancar",
    "desencarrancava": "desencarrancar",
    "desencarrancavam": "desencarrancar",
    "desencarrancavas": "desencarrancar",
    "desencarranco": "desencarrancar",
    "desencarrancou": "desencarrancar",
    "desencarrancá": "desencarrancar",
    "desencarrancámo": "desencarrancar",
    "desencarrancámos": "desencarrancar",
    "desencarrancáramo": "desencarrancar",
    "desencarrancáramos": "desencarrancar",
    "desencarrancárei": "desencarrancar",
    "desencarrancáreis": "desencarrancar",
    "desencarrancásseis": "desencarrancar",
    "desencarrancássemos": "desencarrancar",
    "desencarrancávamo": "desencarrancar",
    "desencarrancávamos": "desencarrancar",
    "desencarrancávei": "desencarrancar",
    "desencarrancáveis": "desencarrancar",
    "desencarranque": "desencarrancar",
    "desencarranquei": "desencarrancar",
    "desencarranqueis": "desencarrancar",
    "desencarranquem": "desencarrancar",
    "desencarranquemo": "desencarrancar",
    "desencarranquemos": "desencarrancar",
    "desencarranques": "desencarrancar",
    "desencarrapita": "desencarrapitar",
    "desencarrapitada": "desencarrapitar",
    "desencarrapitadas": "desencarrapitar",
    "desencarrapitado": "desencarrapitar",
    "desencarrapitados": "desencarrapitar",
    "desencarrapitai": "desencarrapitar",
    "desencarrapitais": "desencarrapitar",
    "desencarrapitam": "desencarrapitar",
    "desencarrapitamo": "desencarrapitar",
    "desencarrapitamos": "desencarrapitar",
    "desencarrapitando": "desencarrapitar",
    "desencarrapitara": "desencarrapitar",
    "desencarrapitaram": "desencarrapitar",
    "desencarrapitaras": "desencarrapitar",
    "desencarrapitarde": "desencarrapitar",
    "desencarrapitardes": "desencarrapitar",
    "desencarrapitare": "desencarrapitar",
    "desencarrapitarei": "desencarrapitar",
    "desencarrapitareis": "desencarrapitar",
    "desencarrapitarem": "desencarrapitar",
    "desencarrapitaremos": "desencarrapitar",
    "desencarrapitares": "desencarrapitar",
    "desencarrapitaria": "desencarrapitar",
    "desencarrapitariam": "desencarrapitar",
    "desencarrapitarias": "desencarrapitar",
    "desencarrapitarmo": "desencarrapitar",
    "desencarrapitarmos": "desencarrapitar",
    "desencarrapitará": "desencarrapitar",
    "desencarrapitarás": "desencarrapitar",
    "desencarrapitarão": "desencarrapitar",
    "desencarrapitaríamos": "desencarrapitar",
    "desencarrapitaríeis": "desencarrapitar",
    "desencarrapitas": "desencarrapitar",
    "desencarrapitasse": "desencarrapitar",
    "desencarrapitassem": "desencarrapitar",
    "desencarrapitasses": "desencarrapitar",
    "desencarrapitaste": "desencarrapitar",
    "desencarrapitastes": "desencarrapitar",
    "desencarrapitava": "desencarrapitar",
    "desencarrapitavam": "desencarrapitar",
    "desencarrapitavas": "desencarrapitar",
    "desencarrapite": "desencarrapitar",
    "desencarrapitei": "desencarrapitar",
    "desencarrapiteis": "desencarrapitar",
    "desencarrapitem": "desencarrapitar",
    "desencarrapitemo": "desencarrapitar",
    "desencarrapitemos": "desencarrapitar",
    "desencarrapites": "desencarrapitar",
    "desencarrapito": "desencarrapitar",
    "desencarrapitou": "desencarrapitar",
    "desencarrapitá": "desencarrapitar",
    "desencarrapitámo": "desencarrapitar",
    "desencarrapitámos": "desencarrapitar",
    "desencarrapitáramo": "desencarrapitar",
    "desencarrapitáramos": "desencarrapitar",
    "desencarrapitárei": "desencarrapitar",
    "desencarrapitáreis": "desencarrapitar",
    "desencarrapitásseis": "desencarrapitar",
    "desencarrapitássemos": "desencarrapitar",
    "desencarrapitávamo": "desencarrapitar",
    "desencarrapitávamos": "desencarrapitar",
    "desencarrapitávei": "desencarrapitar",
    "desencarrapitáveis": "desencarrapitar",
    "desencarrega": "desencarregar",
    "desencarregada": "desencarregar",
    "desencarregadas": "desencarregar",
    "desencarregado": "desencarregar",
    "desencarregados": "desencarregar",
    "desencarregai": "desencarregar",
    "desencarregais": "desencarregar",
    "desencarregam": "desencarregar",
    "desencarregamo": "desencarregar",
    "desencarregamos": "desencarregar",
    "desencarregando": "desencarregar",
    "desencarregara": "desencarregar",
    "desencarregaram": "desencarregar",
    "desencarregaras": "desencarregar",
    "desencarregarde": "desencarregar",
    "desencarregardes": "desencarregar",
    "desencarregare": "desencarregar",
    "desencarregarei": "desencarregar",
    "desencarregareis": "desencarregar",
    "desencarregarem": "desencarregar",
    "desencarregaremos": "desencarregar",
    "desencarregares": "desencarregar",
    "desencarregaria": "desencarregar",
    "desencarregariam": "desencarregar",
    "desencarregarias": "desencarregar",
    "desencarregarmo": "desencarregar",
    "desencarregarmos": "desencarregar",
    "desencarregará": "desencarregar",
    "desencarregarás": "desencarregar",
    "desencarregarão": "desencarregar",
    "desencarregaríamos": "desencarregar",
    "desencarregaríeis": "desencarregar",
    "desencarregas": "desencarregar",
    "desencarregasse": "desencarregar",
    "desencarregassem": "desencarregar",
    "desencarregasses": "desencarregar",
    "desencarregaste": "desencarregar",
    "desencarregastes": "desencarregar",
    "desencarregava": "desencarregar",
    "desencarregavam": "desencarregar",
    "desencarregavas": "desencarregar",
    "desencarrego": "desencarregar",
    "desencarregou": "desencarregar",
    "desencarregue": "desencarregar",
    "desencarreguei": "desencarregar",
    "desencarregueis": "desencarregar",
    "desencarreguem": "desencarregar",
    "desencarreguemo": "desencarregar",
    "desencarreguemos": "desencarregar",
    "desencarregues": "desencarregar",
    "desencarregá": "desencarregar",
    "desencarregámo": "desencarregar",
    "desencarregámos": "desencarregar",
    "desencarregáramo": "desencarregar",
    "desencarregáramos": "desencarregar",
    "desencarregárei": "desencarregar",
    "desencarregáreis": "desencarregar",
    "desencarregásseis": "desencarregar",
    "desencarregássemos": "desencarregar",
    "desencarregávamo": "desencarregar",
    "desencarregávamos": "desencarregar",
    "desencarregávei": "desencarregar",
    "desencarregáveis": "desencarregar",
    "desencarreira": "desencarreirar",
    "desencarreirada": "desencarreirar",
    "desencarreiradas": "desencarreirar",
    "desencarreirado": "desencarreirar",
    "desencarreirados": "desencarreirar",
    "desencarreirai": "desencarreirar",
    "desencarreirais": "desencarreirar",
    "desencarreiram": "desencarreirar",
    "desencarreiramo": "desencarreirar",
    "desencarreiramos": "desencarreirar",
    "desencarreirando": "desencarreirar",
    "desencarreirara": "desencarreirar",
    "desencarreiraram": "desencarreirar",
    "desencarreiraras": "desencarreirar",
    "desencarreirarde": "desencarreirar",
    "desencarreirardes": "desencarreirar",
    "desencarreirare": "desencarreirar",
    "desencarreirarei": "desencarreirar",
    "desencarreirareis": "desencarreirar",
    "desencarreirarem": "desencarreirar",
    "desencarreiraremos": "desencarreirar",
    "desencarreirares": "desencarreirar",
    "desencarreiraria": "desencarreirar",
    "desencarreirariam": "desencarreirar",
    "desencarreirarias": "desencarreirar",
    "desencarreirarmo": "desencarreirar",
    "desencarreirarmos": "desencarreirar",
    "desencarreirará": "desencarreirar",
    "desencarreirarás": "desencarreirar",
    "desencarreirarão": "desencarreirar",
    "desencarreiraríamos": "desencarreirar",
    "desencarreiraríeis": "desencarreirar",
    "desencarreiras": "desencarreirar",
    "desencarreirasse": "desencarreirar",
    "desencarreirassem": "desencarreirar",
    "desencarreirasses": "desencarreirar",
    "desencarreiraste": "desencarreirar",
    "desencarreirastes": "desencarreirar",
    "desencarreirava": "desencarreirar",
    "desencarreiravam": "desencarreirar",
    "desencarreiravas": "desencarreirar",
    "desencarreire": "desencarreirar",
    "desencarreirei": "desencarreirar",
    "desencarreireis": "desencarreirar",
    "desencarreirem": "desencarreirar",
    "desencarreiremo": "desencarreirar",
    "desencarreiremos": "desencarreirar",
    "desencarreires": "desencarreirar",
    "desencarreiro": "desencarreirar",
    "desencarreirou": "desencarreirar",
    "desencarreirá": "desencarreirar",
    "desencarreirámo": "desencarreirar",
    "desencarreirámos": "desencarreirar",
    "desencarreiráramo": "desencarreirar",
    "desencarreiráramos": "desencarreirar",
    "desencarreirárei": "desencarreirar",
    "desencarreiráreis": "desencarreirar",
    "desencarreirásseis": "desencarreirar",
    "desencarreirássemos": "desencarreirar",
    "desencarreirávamo": "desencarreirar",
    "desencarreirávamos": "desencarreirar",
    "desencarreirávei": "desencarreirar",
    "desencarreiráveis": "desencarreirar",
    "desencarreta": "desencarretar",
    "desencarretada": "desencarretar",
    "desencarretadas": "desencarretar",
    "desencarretado": "desencarretar",
    "desencarretados": "desencarretar",
    "desencarretai": "desencarretar",
    "desencarretais": "desencarretar",
    "desencarretam": "desencarretar",
    "desencarretamo": "desencarretar",
    "desencarretamos": "desencarretar",
    "desencarretando": "desencarretar",
    "desencarretara": "desencarretar",
    "desencarretaram": "desencarretar",
    "desencarretaras": "desencarretar",
    "desencarretarde": "desencarretar",
    "desencarretardes": "desencarretar",
    "desencarretare": "desencarretar",
    "desencarretarei": "desencarretar",
    "desencarretareis": "desencarretar",
    "desencarretarem": "desencarretar",
    "desencarretaremos": "desencarretar",
    "desencarretares": "desencarretar",
    "desencarretaria": "desencarretar",
    "desencarretariam": "desencarretar",
    "desencarretarias": "desencarretar",
    "desencarretarmo": "desencarretar",
    "desencarretarmos": "desencarretar",
    "desencarretará": "desencarretar",
    "desencarretarás": "desencarretar",
    "desencarretarão": "desencarretar",
    "desencarretaríamos": "desencarretar",
    "desencarretaríeis": "desencarretar",
    "desencarretas": "desencarretar",
    "desencarretasse": "desencarretar",
    "desencarretassem": "desencarretar",
    "desencarretasses": "desencarretar",
    "desencarretaste": "desencarretar",
    "desencarretastes": "desencarretar",
    "desencarretava": "desencarretar",
    "desencarretavam": "desencarretar",
    "desencarretavas": "desencarretar",
    "desencarrete": "desencarretar",
    "desencarretei": "desencarretar",
    "desencarreteis": "desencarretar",
    "desencarretem": "desencarretar",
    "desencarretemo": "desencarretar",
    "desencarretemos": "desencarretar",
    "desencarretes": "desencarretar",
    "desencarreto": "desencarretar",
    "desencarretou": "desencarretar",
    "desencarretá": "desencarretar",
    "desencarretámo": "desencarretar",
    "desencarretámos": "desencarretar",
    "desencarretáramo": "desencarretar",
    "desencarretáramos": "desencarretar",
    "desencarretárei": "desencarretar",
    "desencarretáreis": "desencarretar",
    "desencarretásseis": "desencarretar",
    "desencarretássemos": "desencarretar",
    "desencarretávamo": "desencarretar",
    "desencarretávamos": "desencarretar",
    "desencarretávei": "desencarretar",
    "desencarretáveis": "desencarretar",
    "desencarrila": "desencarrilar",
    "desencarrilada": "desencarrilar",
    "desencarriladas": "desencarrilar",
    "desencarrilado": "desencarrilar",
    "desencarrilados": "desencarrilar",
    "desencarrilai": "desencarrilar",
    "desencarrilais": "desencarrilar",
    "desencarrilam": "desencarrilar",
    "desencarrilamo": "desencarrilar",
    "desencarrilamos": "desencarrilar",
    "desencarrilando": "desencarrilar",
    "desencarrilara": "desencarrilar",
    "desencarrilaram": "desencarrilar",
    "desencarrilaras": "desencarrilar",
    "desencarrilarde": "desencarrilar",
    "desencarrilardes": "desencarrilar",
    "desencarrilare": "desencarrilar",
    "desencarrilarei": "desencarrilar",
    "desencarrilareis": "desencarrilar",
    "desencarrilarem": "desencarrilar",
    "desencarrilaremos": "desencarrilar",
    "desencarrilares": "desencarrilar",
    "desencarrilaria": "desencarrilar",
    "desencarrilariam": "desencarrilar",
    "desencarrilarias": "desencarrilar",
    "desencarrilarmo": "desencarrilar",
    "desencarrilarmos": "desencarrilar",
    "desencarrilará": "desencarrilar",
    "desencarrilarás": "desencarrilar",
    "desencarrilarão": "desencarrilar",
    "desencarrilaríamos": "desencarrilar",
    "desencarrilaríeis": "desencarrilar",
    "desencarrilas": "desencarrilar",
    "desencarrilasse": "desencarrilar",
    "desencarrilassem": "desencarrilar",
    "desencarrilasses": "desencarrilar",
    "desencarrilaste": "desencarrilar",
    "desencarrilastes": "desencarrilar",
    "desencarrilava": "desencarrilar",
    "desencarrilavam": "desencarrilar",
    "desencarrilavas": "desencarrilar",
    "desencarrile": "desencarrilar",
    "desencarrilei": "desencarrilar",
    "desencarrileis": "desencarrilar",
    "desencarrilem": "desencarrilar",
    "desencarrilemo": "desencarrilar",
    "desencarrilemos": "desencarrilar",
    "desencarriles": "desencarrilar",
    "desencarrilhada": "desencarrilhado",
    "desencarrilhadas": "desencarrilhado",
    "desencarrilhados": "desencarrilhado",
    "desencarrilo": "desencarrilar",
    "desencarrilou": "desencarrilar",
    "desencarrilá": "desencarrilar",
    "desencarrilámo": "desencarrilar",
    "desencarrilámos": "desencarrilar",
    "desencarriláramo": "desencarrilar",
    "desencarriláramos": "desencarrilar",
    "desencarrilárei": "desencarrilar",
    "desencarriláreis": "desencarrilar",
    "desencarrilásseis": "desencarrilar",
    "desencarrilássemos": "desencarrilar",
    "desencarrilávamo": "desencarrilar",
    "desencarrilávamos": "desencarrilar",
    "desencarrilávei": "desencarrilar",
    "desencarriláveis": "desencarrilar",
    "desencarta": "desencartar",
    "desencartada": "desencartar",
    "desencartadas": "desencartar",
    "desencartado": "desencartar",
    "desencartados": "desencartar",
    "desencartai": "desencartar",
    "desencartais": "desencartar",
    "desencartam": "desencartar",
    "desencartamo": "desencartar",
    "desencartamos": "desencartar",
    "desencartando": "desencartar",
    "desencartara": "desencartar",
    "desencartaram": "desencartar",
    "desencartaras": "desencartar",
    "desencartarde": "desencartar",
    "desencartardes": "desencartar",
    "desencartare": "desencartar",
    "desencartarei": "desencartar",
    "desencartareis": "desencartar",
    "desencartarem": "desencartar",
    "desencartaremos": "desencartar",
    "desencartares": "desencartar",
    "desencartaria": "desencartar",
    "desencartariam": "desencartar",
    "desencartarias": "desencartar",
    "desencartarmo": "desencartar",
    "desencartarmos": "desencartar",
    "desencartará": "desencartar",
    "desencartarás": "desencartar",
    "desencartarão": "desencartar",
    "desencartaríamos": "desencartar",
    "desencartaríeis": "desencartar",
    "desencartas": "desencartar",
    "desencartasse": "desencartar",
    "desencartassem": "desencartar",
    "desencartasses": "desencartar",
    "desencartaste": "desencartar",
    "desencartastes": "desencartar",
    "desencartava": "desencartar",
    "desencartavam": "desencartar",
    "desencartavas": "desencartar",
    "desencarte": "desencartar",
    "desencartei": "desencartar",
    "desencarteis": "desencartar",
    "desencartem": "desencartar",
    "desencartemo": "desencartar",
    "desencartemos": "desencartar",
    "desencartes": "desencartar",
    "desencarto": "desencartar",
    "desencartou": "desencartar",
    "desencartá": "desencartar",
    "desencartámo": "desencartar",
    "desencartámos": "desencartar",
    "desencartáramo": "desencartar",
    "desencartáramos": "desencartar",
    "desencartárei": "desencartar",
    "desencartáreis": "desencartar",
    "desencartásseis": "desencartar",
    "desencartássemos": "desencartar",
    "desencartávamo": "desencartar",
    "desencartávamos": "desencartar",
    "desencartávei": "desencartar",
    "desencartáveis": "desencartar",
    "desencasa": "desencasar",
    "desencasaca": "desencasacar",
    "desencasacada": "desencasacar",
    "desencasacadas": "desencasacar",
    "desencasacado": "desencasacar",
    "desencasacados": "desencasacar",
    "desencasacai": "desencasacar",
    "desencasacais": "desencasacar",
    "desencasacam": "desencasacar",
    "desencasacamo": "desencasacar",
    "desencasacamos": "desencasacar",
    "desencasacando": "desencasacar",
    "desencasacara": "desencasacar",
    "desencasacaram": "desencasacar",
    "desencasacaras": "desencasacar",
    "desencasacarde": "desencasacar",
    "desencasacardes": "desencasacar",
    "desencasacare": "desencasacar",
    "desencasacarei": "desencasacar",
    "desencasacareis": "desencasacar",
    "desencasacarem": "desencasacar",
    "desencasacaremos": "desencasacar",
    "desencasacares": "desencasacar",
    "desencasacaria": "desencasacar",
    "desencasacariam": "desencasacar",
    "desencasacarias": "desencasacar",
    "desencasacarmo": "desencasacar",
    "desencasacarmos": "desencasacar",
    "desencasacará": "desencasacar",
    "desencasacarás": "desencasacar",
    "desencasacarão": "desencasacar",
    "desencasacaríamos": "desencasacar",
    "desencasacaríeis": "desencasacar",
    "desencasacas": "desencasacar",
    "desencasacasse": "desencasacar",
    "desencasacassem": "desencasacar",
    "desencasacasses": "desencasacar",
    "desencasacaste": "desencasacar",
    "desencasacastes": "desencasacar",
    "desencasacava": "desencasacar",
    "desencasacavam": "desencasacar",
    "desencasacavas": "desencasacar",
    "desencasaco": "desencasacar",
    "desencasacou": "desencasacar",
    "desencasacá": "desencasacar",
    "desencasacámo": "desencasacar",
    "desencasacámos": "desencasacar",
    "desencasacáramo": "desencasacar",
    "desencasacáramos": "desencasacar",
    "desencasacárei": "desencasacar",
    "desencasacáreis": "desencasacar",
    "desencasacásseis": "desencasacar",
    "desencasacássemos": "desencasacar",
    "desencasacávamo": "desencasacar",
    "desencasacávamos": "desencasacar",
    "desencasacávei": "desencasacar",
    "desencasacáveis": "desencasacar",
    "desencasada": "desencasar",
    "desencasadas": "desencasar",
    "desencasado": "desencasar",
    "desencasados": "desencasar",
    "desencasai": "desencasar",
    "desencasais": "desencasar",
    "desencasam": "desencasar",
    "desencasamo": "desencasar",
    "desencasamos": "desencasar",
    "desencasando": "desencasar",
    "desencasaque": "desencasacar",
    "desencasaquei": "desencasacar",
    "desencasaqueis": "desencasacar",
    "desencasaquem": "desencasacar",
    "desencasaquemo": "desencasacar",
    "desencasaquemos": "desencasacar",
    "desencasaques": "desencasacar",
    "desencasara": "desencasar",
    "desencasaram": "desencasar",
    "desencasaras": "desencasar",
    "desencasarde": "desencasar",
    "desencasardes": "desencasar",
    "desencasare": "desencasar",
    "desencasarei": "desencasar",
    "desencasareis": "desencasar",
    "desencasarem": "desencasar",
    "desencasaremos": "desencasar",
    "desencasares": "desencasar",
    "desencasaria": "desencasar",
    "desencasariam": "desencasar",
    "desencasarias": "desencasar",
    "desencasarmo": "desencasar",
    "desencasarmos": "desencasar",
    "desencasará": "desencasar",
    "desencasarás": "desencasar",
    "desencasarão": "desencasar",
    "desencasaríamos": "desencasar",
    "desencasaríeis": "desencasar",
    "desencasas": "desencasar",
    "desencasasse": "desencasar",
    "desencasassem": "desencasar",
    "desencasasses": "desencasar",
    "desencasaste": "desencasar",
    "desencasastes": "desencasar",
    "desencasava": "desencasar",
    "desencasavam": "desencasar",
    "desencasavas": "desencasar",
    "desencasca": "desencascar",
    "desencascada": "desencascar",
    "desencascadas": "desencascar",
    "desencascado": "desencascar",
    "desencascados": "desencascar",
    "desencascai": "desencascar",
    "desencascais": "desencascar",
    "desencascam": "desencascar",
    "desencascamo": "desencascar",
    "desencascamos": "desencascar",
    "desencascando": "desencascar",
    "desencascara": "desencascar",
    "desencascaram": "desencascar",
    "desencascaras": "desencascar",
    "desencascarde": "desencascar",
    "desencascardes": "desencascar",
    "desencascare": "desencascar",
    "desencascarei": "desencascar",
    "desencascareis": "desencascar",
    "desencascarem": "desencascar",
    "desencascaremos": "desencascar",
    "desencascares": "desencascar",
    "desencascaria": "desencascar",
    "desencascariam": "desencascar",
    "desencascarias": "desencascar",
    "desencascarmo": "desencascar",
    "desencascarmos": "desencascar",
    "desencascará": "desencascar",
    "desencascarás": "desencascar",
    "desencascarão": "desencascar",
    "desencascaríamos": "desencascar",
    "desencascaríeis": "desencascar",
    "desencascas": "desencascar",
    "desencascasse": "desencascar",
    "desencascassem": "desencascar",
    "desencascasses": "desencascar",
    "desencascaste": "desencascar",
    "desencascastes": "desencascar",
    "desencascava": "desencascar",
    "desencascavam": "desencascar",
    "desencascavas": "desencascar",
    "desencasco": "desencascar",
    "desencascou": "desencascar",
    "desencascá": "desencascar",
    "desencascámo": "desencascar",
    "desencascámos": "desencascar",
    "desencascáramo": "desencascar",
    "desencascáramos": "desencascar",
    "desencascárei": "desencascar",
    "desencascáreis": "desencascar",
    "desencascásseis": "desencascar",
    "desencascássemos": "desencascar",
    "desencascávamo": "desencascar",
    "desencascávamos": "desencascar",
    "desencascávei": "desencascar",
    "desencascáveis": "desencascar",
    "desencase": "desencasar",
    "desencasei": "desencasar",
    "desencaseis": "desencasar",
    "desencasem": "desencasar",
    "desencasemo": "desencasar",
    "desencasemos": "desencasar",
    "desencases": "desencasar",
    "desencaso": "desencasar",
    "desencasou": "desencasar",
    "desencasque": "desencascar",
    "desencasquei": "desencascar",
    "desencasqueis": "desencascar",
    "desencasquem": "desencascar",
    "desencasquemo": "desencascar",
    "desencasquemos": "desencascar",
    "desencasques": "desencascar",
    "desencasquetada": "desencasquetado",
    "desencasquetadas": "desencasquetado",
    "desencasquetados": "desencasquetado",
    "desencastela": "desencastelar",
    "desencastelada": "desencastelar",
    "desencasteladas": "desencastelar",
    "desencastelado": "desencastelar",
    "desencastelados": "desencastelar",
    "desencastelai": "desencastelar",
    "desencastelais": "desencastelar",
    "desencastelam": "desencastelar",
    "desencastelamo": "desencastelar",
    "desencastelamos": "desencastelar",
    "desencastelando": "desencastelar",
    "desencastelara": "desencastelar",
    "desencastelaram": "desencastelar",
    "desencastelaras": "desencastelar",
    "desencastelarde": "desencastelar",
    "desencastelardes": "desencastelar",
    "desencastelare": "desencastelar",
    "desencastelarei": "desencastelar",
    "desencastelareis": "desencastelar",
    "desencastelarem": "desencastelar",
    "desencastelaremos": "desencastelar",
    "desencastelares": "desencastelar",
    "desencastelaria": "desencastelar",
    "desencastelariam": "desencastelar",
    "desencastelarias": "desencastelar",
    "desencastelarmo": "desencastelar",
    "desencastelarmos": "desencastelar",
    "desencastelará": "desencastelar",
    "desencastelarás": "desencastelar",
    "desencastelarão": "desencastelar",
    "desencastelaríamos": "desencastelar",
    "desencastelaríeis": "desencastelar",
    "desencastelas": "desencastelar",
    "desencastelasse": "desencastelar",
    "desencastelassem": "desencastelar",
    "desencastelasses": "desencastelar",
    "desencastelaste": "desencastelar",
    "desencastelastes": "desencastelar",
    "desencastelava": "desencastelar",
    "desencastelavam": "desencastelar",
    "desencastelavas": "desencastelar",
    "desencastele": "desencastelar",
    "desencastelei": "desencastelar",
    "desencasteleis": "desencastelar",
    "desencastelem": "desencastelar",
    "desencastelemo": "desencastelar",
    "desencastelemos": "desencastelar",
    "desencasteles": "desencastelar",
    "desencastelo": "desencastelar",
    "desencastelou": "desencastelar",
    "desencastelá": "desencastelar",
    "desencastelámo": "desencastelar",
    "desencastelámos": "desencastelar",
    "desencasteláramo": "desencastelar",
    "desencasteláramos": "desencastelar",
    "desencastelárei": "desencastelar",
    "desencasteláreis": "desencastelar",
    "desencastelásseis": "desencastelar",
    "desencastelássemos": "desencastelar",
    "desencastelávamo": "desencastelar",
    "desencastelávamos": "desencastelar",
    "desencastelávei": "desencastelar",
    "desencasteláveis": "desencastelar",
    "desencastoa": "desencastoar",
    "desencastoada": "desencastoar",
    "desencastoadas": "desencastoar",
    "desencastoado": "desencastoar",
    "desencastoados": "desencastoar",
    "desencastoai": "desencastoar",
    "desencastoais": "desencastoar",
    "desencastoam": "desencastoar",
    "desencastoamo": "desencastoar",
    "desencastoamos": "desencastoar",
    "desencastoando": "desencastoar",
    "desencastoara": "desencastoar",
    "desencastoaram": "desencastoar",
    "desencastoaras": "desencastoar",
    "desencastoarde": "desencastoar",
    "desencastoardes": "desencastoar",
    "desencastoare": "desencastoar",
    "desencastoarei": "desencastoar",
    "desencastoareis": "desencastoar",
    "desencastoarem": "desencastoar",
    "desencastoaremos": "desencastoar",
    "desencastoares": "desencastoar",
    "desencastoaria": "desencastoar",
    "desencastoariam": "desencastoar",
    "desencastoarias": "desencastoar",
    "desencastoarmo": "desencastoar",
    "desencastoarmos": "desencastoar",
    "desencastoará": "desencastoar",
    "desencastoarás": "desencastoar",
    "desencastoarão": "desencastoar",
    "desencastoaríamos": "desencastoar",
    "desencastoaríeis": "desencastoar",
    "desencastoas": "desencastoar",
    "desencastoasse": "desencastoar",
    "desencastoassem": "desencastoar",
    "desencastoasses": "desencastoar",
    "desencastoaste": "desencastoar",
    "desencastoastes": "desencastoar",
    "desencastoava": "desencastoar",
    "desencastoavam": "desencastoar",
    "desencastoavas": "desencastoar",
    "desencastoe": "desencastoar",
    "desencastoei": "desencastoar",
    "desencastoeis": "desencastoar",
    "desencastoem": "desencastoar",
    "desencastoemo": "desencastoar",
    "desencastoemos": "desencastoar",
    "desencastoes": "desencastoar",
    "desencastoo": "desencastoar",
    "desencastoou": "desencastoar",
    "desencastoá": "desencastoar",
    "desencastoámo": "desencastoar",
    "desencastoámos": "desencastoar",
    "desencastoáramo": "desencastoar",
    "desencastoáramos": "desencastoar",
    "desencastoárei": "desencastoar",
    "desencastoáreis": "desencastoar",
    "desencastoásseis": "desencastoar",
    "desencastoássemos": "desencastoar",
    "desencastoávamo": "desencastoar",
    "desencastoávamos": "desencastoar",
    "desencastoávei": "desencastoar",
    "desencastoáveis": "desencastoar",
    "desencasá": "desencasar",
    "desencasámo": "desencasar",
    "desencasámos": "desencasar",
    "desencasáramo": "desencasar",
    "desencasáramos": "desencasar",
    "desencasárei": "desencasar",
    "desencasáreis": "desencasar",
    "desencasásseis": "desencasar",
    "desencasássemos": "desencasar",
    "desencasávamo": "desencasar",
    "desencasávamos": "desencasar",
    "desencasávei": "desencasar",
    "desencasáveis": "desencasar",
    "desencavaca": "desencavacar",
    "desencavacada": "desencavacar",
    "desencavacadas": "desencavacar",
    "desencavacado": "desencavacar",
    "desencavacados": "desencavacar",
    "desencavacai": "desencavacar",
    "desencavacais": "desencavacar",
    "desencavacam": "desencavacar",
    "desencavacamo": "desencavacar",
    "desencavacamos": "desencavacar",
    "desencavacando": "desencavacar",
    "desencavacara": "desencavacar",
    "desencavacaram": "desencavacar",
    "desencavacaras": "desencavacar",
    "desencavacarde": "desencavacar",
    "desencavacardes": "desencavacar",
    "desencavacare": "desencavacar",
    "desencavacarei": "desencavacar",
    "desencavacareis": "desencavacar",
    "desencavacarem": "desencavacar",
    "desencavacaremos": "desencavacar",
    "desencavacares": "desencavacar",
    "desencavacaria": "desencavacar",
    "desencavacariam": "desencavacar",
    "desencavacarias": "desencavacar",
    "desencavacarmo": "desencavacar",
    "desencavacarmos": "desencavacar",
    "desencavacará": "desencavacar",
    "desencavacarás": "desencavacar",
    "desencavacarão": "desencavacar",
    "desencavacaríamos": "desencavacar",
    "desencavacaríeis": "desencavacar",
    "desencavacas": "desencavacar",
    "desencavacasse": "desencavacar",
    "desencavacassem": "desencavacar",
    "desencavacasses": "desencavacar",
    "desencavacaste": "desencavacar",
    "desencavacastes": "desencavacar",
    "desencavacava": "desencavacar",
    "desencavacavam": "desencavacar",
    "desencavacavas": "desencavacar",
    "desencavaco": "desencavacar",
    "desencavacou": "desencavacar",
    "desencavacá": "desencavacar",
    "desencavacámo": "desencavacar",
    "desencavacámos": "desencavacar",
    "desencavacáramo": "desencavacar",
    "desencavacáramos": "desencavacar",
    "desencavacárei": "desencavacar",
    "desencavacáreis": "desencavacar",
    "desencavacásseis": "desencavacar",
    "desencavacássemos": "desencavacar",
    "desencavacávamo": "desencavacar",
    "desencavacávamos": "desencavacar",
    "desencavacávei": "desencavacar",
    "desencavacáveis": "desencavacar",
    "desencavalga": "desencavalgar",
    "desencavalgada": "desencavalgar",
    "desencavalgadas": "desencavalgar",
    "desencavalgado": "desencavalgar",
    "desencavalgados": "desencavalgar",
    "desencavalgai": "desencavalgar",
    "desencavalgais": "desencavalgar",
    "desencavalgam": "desencavalgar",
    "desencavalgamo": "desencavalgar",
    "desencavalgamos": "desencavalgar",
    "desencavalgando": "desencavalgar",
    "desencavalgara": "desencavalgar",
    "desencavalgaram": "desencavalgar",
    "desencavalgaras": "desencavalgar",
    "desencavalgarde": "desencavalgar",
    "desencavalgardes": "desencavalgar",
    "desencavalgare": "desencavalgar",
    "desencavalgarei": "desencavalgar",
    "desencavalgareis": "desencavalgar",
    "desencavalgarem": "desencavalgar",
    "desencavalgaremos": "desencavalgar",
    "desencavalgares": "desencavalgar",
    "desencavalgaria": "desencavalgar",
    "desencavalgariam": "desencavalgar",
    "desencavalgarias": "desencavalgar",
    "desencavalgarmo": "desencavalgar",
    "desencavalgarmos": "desencavalgar",
    "desencavalgará": "desencavalgar",
    "desencavalgarás": "desencavalgar",
    "desencavalgarão": "desencavalgar",
    "desencavalgaríamos": "desencavalgar",
    "desencavalgaríeis": "desencavalgar",
    "desencavalgas": "desencavalgar",
    "desencavalgasse": "desencavalgar",
    "desencavalgassem": "desencavalgar",
    "desencavalgasses": "desencavalgar",
    "desencavalgaste": "desencavalgar",
    "desencavalgastes": "desencavalgar",
    "desencavalgava": "desencavalgar",
    "desencavalgavam": "desencavalgar",
    "desencavalgavas": "desencavalgar",
    "desencavalgo": "desencavalgar",
    "desencavalgou": "desencavalgar",
    "desencavalgue": "desencavalgar",
    "desencavalguei": "desencavalgar",
    "desencavalgueis": "desencavalgar",
    "desencavalguem": "desencavalgar",
    "desencavalguemo": "desencavalgar",
    "desencavalguemos": "desencavalgar",
    "desencavalgues": "desencavalgar",
    "desencavalgá": "desencavalgar",
    "desencavalgámo": "desencavalgar",
    "desencavalgámos": "desencavalgar",
    "desencavalgáramo": "desencavalgar",
    "desencavalgáramos": "desencavalgar",
    "desencavalgárei": "desencavalgar",
    "desencavalgáreis": "desencavalgar",
    "desencavalgásseis": "desencavalgar",
    "desencavalgássemos": "desencavalgar",
    "desencavalgávamo": "desencavalgar",
    "desencavalgávamos": "desencavalgar",
    "desencavalgávei": "desencavalgar",
    "desencavalgáveis": "desencavalgar",
    "desencavaque": "desencavacar",
    "desencavaquei": "desencavacar",
    "desencavaqueis": "desencavacar",
    "desencavaquem": "desencavacar",
    "desencavaquemo": "desencavacar",
    "desencavaquemos": "desencavacar",
    "desencavaques": "desencavacar",
    "desencaverna": "desencavernar",
    "desencavernada": "desencavernar",
    "desencavernadas": "desencavernar",
    "desencavernado": "desencavernar",
    "desencavernados": "desencavernar",
    "desencavernai": "desencavernar",
    "desencavernais": "desencavernar",
    "desencavernam": "desencavernar",
    "desencavernamo": "desencavernar",
    "desencavernamos": "desencavernar",
    "desencavernando": "desencavernar",
    "desencavernara": "desencavernar",
    "desencavernaram": "desencavernar",
    "desencavernaras": "desencavernar",
    "desencavernarde": "desencavernar",
    "desencavernardes": "desencavernar",
    "desencavernare": "desencavernar",
    "desencavernarei": "desencavernar",
    "desencavernareis": "desencavernar",
    "desencavernarem": "desencavernar",
    "desencavernaremos": "desencavernar",
    "desencavernares": "desencavernar",
    "desencavernaria": "desencavernar",
    "desencavernariam": "desencavernar",
    "desencavernarias": "desencavernar",
    "desencavernarmo": "desencavernar",
    "desencavernarmos": "desencavernar",
    "desencavernará": "desencavernar",
    "desencavernarás": "desencavernar",
    "desencavernarão": "desencavernar",
    "desencavernaríamos": "desencavernar",
    "desencavernaríeis": "desencavernar",
    "desencavernas": "desencavernar",
    "desencavernasse": "desencavernar",
    "desencavernassem": "desencavernar",
    "desencavernasses": "desencavernar",
    "desencavernaste": "desencavernar",
    "desencavernastes": "desencavernar",
    "desencavernava": "desencavernar",
    "desencavernavam": "desencavernar",
    "desencavernavas": "desencavernar",
    "desencaverne": "desencavernar",
    "desencavernei": "desencavernar",
    "desencaverneis": "desencavernar",
    "desencavernem": "desencavernar",
    "desencavernemo": "desencavernar",
    "desencavernemos": "desencavernar",
    "desencavernes": "desencavernar",
    "desencaverno": "desencavernar",
    "desencavernou": "desencavernar",
    "desencaverná": "desencavernar",
    "desencavernámo": "desencavernar",
    "desencavernámos": "desencavernar",
    "desencavernáramo": "desencavernar",
    "desencavernáramos": "desencavernar",
    "desencavernárei": "desencavernar",
    "desencavernáreis": "desencavernar",
    "desencavernásseis": "desencavernar",
    "desencavernássemos": "desencavernar",
    "desencavernávamo": "desencavernar",
    "desencavernávamos": "desencavernar",
    "desencavernávei": "desencavernar",
    "desencavernáveis": "desencavernar",
    "desencavilha": "desencavilhar",
    "desencavilhada": "desencavilhar",
    "desencavilhadas": "desencavilhar",
    "desencavilhado": "desencavilhar",
    "desencavilhados": "desencavilhar",
    "desencavilhai": "desencavilhar",
    "desencavilhais": "desencavilhar",
    "desencavilham": "desencavilhar",
    "desencavilhamo": "desencavilhar",
    "desencavilhamos": "desencavilhar",
    "desencavilhando": "desencavilhar",
    "desencavilhara": "desencavilhar",
    "desencavilharam": "desencavilhar",
    "desencavilharas": "desencavilhar",
    "desencavilharde": "desencavilhar",
    "desencavilhardes": "desencavilhar",
    "desencavilhare": "desencavilhar",
    "desencavilharei": "desencavilhar",
    "desencavilhareis": "desencavilhar",
    "desencavilharem": "desencavilhar",
    "desencavilharemos": "desencavilhar",
    "desencavilhares": "desencavilhar",
    "desencavilharia": "desencavilhar",
    "desencavilhariam": "desencavilhar",
    "desencavilharias": "desencavilhar",
    "desencavilharmo": "desencavilhar",
    "desencavilharmos": "desencavilhar",
    "desencavilhará": "desencavilhar",
    "desencavilharás": "desencavilhar",
    "desencavilharão": "desencavilhar",
    "desencavilharíamos": "desencavilhar",
    "desencavilharíeis": "desencavilhar",
    "desencavilhas": "desencavilhar",
    "desencavilhasse": "desencavilhar",
    "desencavilhassem": "desencavilhar",
    "desencavilhasses": "desencavilhar",
    "desencavilhaste": "desencavilhar",
    "desencavilhastes": "desencavilhar",
    "desencavilhava": "desencavilhar",
    "desencavilhavam": "desencavilhar",
    "desencavilhavas": "desencavilhar",
    "desencavilhe": "desencavilhar",
    "desencavilhei": "desencavilhar",
    "desencavilheis": "desencavilhar",
    "desencavilhem": "desencavilhar",
    "desencavilhemo": "desencavilhar",
    "desencavilhemos": "desencavilhar",
    "desencavilhes": "desencavilhar",
    "desencavilho": "desencavilhar",
    "desencavilhou": "desencavilhar",
    "desencavilhá": "desencavilhar",
    "desencavilhámo": "desencavilhar",
    "desencavilhámos": "desencavilhar",
    "desencavilháramo": "desencavilhar",
    "desencavilháramos": "desencavilhar",
    "desencavilhárei": "desencavilhar",
    "desencavilháreis": "desencavilhar",
    "desencavilhásseis": "desencavilhar",
    "desencavilhássemos": "desencavilhar",
    "desencavilhávamo": "desencavilhar",
    "desencavilhávamos": "desencavilhar",
    "desencavilhávei": "desencavilhar",
    "desencavilháveis": "desencavilhar",
    "desencera": "desencerar",
    "desencerada": "desencerar",
    "desenceradas": "desencerar",
    "desencerado": "desencerar",
    "desencerados": "desencerar",
    "desencerai": "desencerar",
    "desencerais": "desencerar",
    "desenceram": "desencerar",
    "desenceramo": "desencerar",
    "desenceramos": "desencerar",
    "desencerando": "desencerar",
    "desencerara": "desencerar",
    "desenceraram": "desencerar",
    "desenceraras": "desencerar",
    "desencerarde": "desencerar",
    "desencerardes": "desencerar",
    "desencerare": "desencerar",
    "desencerarei": "desencerar",
    "desencerareis": "desencerar",
    "desencerarem": "desencerar",
    "desenceraremos": "desencerar",
    "desencerares": "desencerar",
    "desenceraria": "desencerar",
    "desencerariam": "desencerar",
    "desencerarias": "desencerar",
    "desencerarmo": "desencerar",
    "desencerarmos": "desencerar",
    "desencerará": "desencerar",
    "desencerarás": "desencerar",
    "desencerarão": "desencerar",
    "desenceraríamos": "desencerar",
    "desenceraríeis": "desencerar",
    "desenceras": "desencerar",
    "desencerasse": "desencerar",
    "desencerassem": "desencerar",
    "desencerasses": "desencerar",
    "desenceraste": "desencerar",
    "desencerastes": "desencerar",
    "desencerava": "desencerar",
    "desenceravam": "desencerar",
    "desenceravas": "desencerar",
    "desencere": "desencerar",
    "desencerei": "desencerar",
    "desencereis": "desencerar",
    "desencerem": "desencerar",
    "desenceremo": "desencerar",
    "desenceremos": "desencerar",
    "desenceres": "desencerar",
    "desencero": "desencerar",
    "desencerou": "desencerar",
    "desencerra": "desencerrar",
    "desencerrada": "desencerrar",
    "desencerradas": "desencerrar",
    "desencerrado": "desencerrar",
    "desencerrados": "desencerrar",
    "desencerrai": "desencerrar",
    "desencerrais": "desencerrar",
    "desencerram": "desencerrar",
    "desencerramentos": "desencerramento",
    "desencerramo": "desencerrar",
    "desencerramos": "desencerrar",
    "desencerrando": "desencerrar",
    "desencerrara": "desencerrar",
    "desencerraram": "desencerrar",
    "desencerraras": "desencerrar",
    "desencerrarde": "desencerrar",
    "desencerrardes": "desencerrar",
    "desencerrare": "desencerrar",
    "desencerrarei": "desencerrar",
    "desencerrareis": "desencerrar",
    "desencerrarem": "desencerrar",
    "desencerraremos": "desencerrar",
    "desencerrares": "desencerrar",
    "desencerraria": "desencerrar",
    "desencerrariam": "desencerrar",
    "desencerrarias": "desencerrar",
    "desencerrarmo": "desencerrar",
    "desencerrarmos": "desencerrar",
    "desencerrará": "desencerrar",
    "desencerrarás": "desencerrar",
    "desencerrarão": "desencerrar",
    "desencerraríamos": "desencerrar",
    "desencerraríeis": "desencerrar",
    "desencerras": "desencerrar",
    "desencerrasse": "desencerrar",
    "desencerrassem": "desencerrar",
    "desencerrasses": "desencerrar",
    "desencerraste": "desencerrar",
    "desencerrastes": "desencerrar",
    "desencerrava": "desencerrar",
    "desencerravam": "desencerrar",
    "desencerravas": "desencerrar",
    "desencerre": "desencerrar",
    "desencerrei": "desencerrar",
    "desencerreis": "desencerrar",
    "desencerrem": "desencerrar",
    "desencerremo": "desencerrar",
    "desencerremos": "desencerrar",
    "desencerres": "desencerrar",
    "desencerro": "desencerrar",
    "desencerrou": "desencerrar",
    "desencerrá": "desencerrar",
    "desencerrámo": "desencerrar",
    "desencerrámos": "desencerrar",
    "desencerráramo": "desencerrar",
    "desencerráramos": "desencerrar",
    "desencerrárei": "desencerrar",
    "desencerráreis": "desencerrar",
    "desencerrásseis": "desencerrar",
    "desencerrássemos": "desencerrar",
    "desencerrávamo": "desencerrar",
    "desencerrávamos": "desencerrar",
    "desencerrávei": "desencerrar",
    "desencerráveis": "desencerrar",
    "desencerá": "desencerar",
    "desencerámo": "desencerar",
    "desencerámos": "desencerar",
    "desenceráramo": "desencerar",
    "desenceráramos": "desencerar",
    "desencerárei": "desencerar",
    "desenceráreis": "desencerar",
    "desencerásseis": "desencerar",
    "desencerássemos": "desencerar",
    "desencerávamo": "desencerar",
    "desencerávamos": "desencerar",
    "desencerávei": "desencerar",
    "desenceráveis": "desencerar",
    "desencharca": "desencharcar",
    "desencharcada": "desencharcar",
    "desencharcadas": "desencharcar",
    "desencharcado": "desencharcar",
    "desencharcados": "desencharcar",
    "desencharcai": "desencharcar",
    "desencharcais": "desencharcar",
    "desencharcam": "desencharcar",
    "desencharcamo": "desencharcar",
    "desencharcamos": "desencharcar",
    "desencharcando": "desencharcar",
    "desencharcara": "desencharcar",
    "desencharcaram": "desencharcar",
    "desencharcaras": "desencharcar",
    "desencharcarde": "desencharcar",
    "desencharcardes": "desencharcar",
    "desencharcare": "desencharcar",
    "desencharcarei": "desencharcar",
    "desencharcareis": "desencharcar",
    "desencharcarem": "desencharcar",
    "desencharcaremos": "desencharcar",
    "desencharcares": "desencharcar",
    "desencharcaria": "desencharcar",
    "desencharcariam": "desencharcar",
    "desencharcarias": "desencharcar",
    "desencharcarmo": "desencharcar",
    "desencharcarmos": "desencharcar",
    "desencharcará": "desencharcar",
    "desencharcarás": "desencharcar",
    "desencharcarão": "desencharcar",
    "desencharcaríamos": "desencharcar",
    "desencharcaríeis": "desencharcar",
    "desencharcas": "desencharcar",
    "desencharcasse": "desencharcar",
    "desencharcassem": "desencharcar",
    "desencharcasses": "desencharcar",
    "desencharcaste": "desencharcar",
    "desencharcastes": "desencharcar",
    "desencharcava": "desencharcar",
    "desencharcavam": "desencharcar",
    "desencharcavas": "desencharcar",
    "desencharco": "desencharcar",
    "desencharcou": "desencharcar",
    "desencharcá": "desencharcar",
    "desencharcámo": "desencharcar",
    "desencharcámos": "desencharcar",
    "desencharcáramo": "desencharcar",
    "desencharcáramos": "desencharcar",
    "desencharcárei": "desencharcar",
    "desencharcáreis": "desencharcar",
    "desencharcásseis": "desencharcar",
    "desencharcássemos": "desencharcar",
    "desencharcávamo": "desencharcar",
    "desencharcávamos": "desencharcar",
    "desencharcávei": "desencharcar",
    "desencharcáveis": "desencharcar",
    "desencharque": "desencharcar",
    "desencharquei": "desencharcar",
    "desencharqueis": "desencharcar",
    "desencharquem": "desencharcar",
    "desencharquemo": "desencharcar",
    "desencharquemos": "desencharcar",
    "desencharques": "desencharcar",
    "desencilhada": "desencilhado",
    "desencilhadas": "desencilhado",
    "desencilhados": "desencilhado",
    "desenclaustra": "desenclaustrar",
    "desenclaustrada": "desenclaustrar",
    "desenclaustradas": "desenclaustrar",
    "desenclaustrado": "desenclaustrar",
    "desenclaustrados": "desenclaustrar",
    "desenclaustrai": "desenclaustrar",
    "desenclaustrais": "desenclaustrar",
    "desenclaustram": "desenclaustrar",
    "desenclaustramo": "desenclaustrar",
    "desenclaustramos": "desenclaustrar",
    "desenclaustrando": "desenclaustrar",
    "desenclaustrara": "desenclaustrar",
    "desenclaustraram": "desenclaustrar",
    "desenclaustraras": "desenclaustrar",
    "desenclaustrarde": "desenclaustrar",
    "desenclaustrardes": "desenclaustrar",
    "desenclaustrare": "desenclaustrar",
    "desenclaustrarei": "desenclaustrar",
    "desenclaustrareis": "desenclaustrar",
    "desenclaustrarem": "desenclaustrar",
    "desenclaustraremos": "desenclaustrar",
    "desenclaustrares": "desenclaustrar",
    "desenclaustraria": "desenclaustrar",
    "desenclaustrariam": "desenclaustrar",
    "desenclaustrarias": "desenclaustrar",
    "desenclaustrarmo": "desenclaustrar",
    "desenclaustrarmos": "desenclaustrar",
    "desenclaustrará": "desenclaustrar",
    "desenclaustrarás": "desenclaustrar",
    "desenclaustrarão": "desenclaustrar",
    "desenclaustraríamos": "desenclaustrar",
    "desenclaustraríeis": "desenclaustrar",
    "desenclaustras": "desenclaustrar",
    "desenclaustrasse": "desenclaustrar",
    "desenclaustrassem": "desenclaustrar",
    "desenclaustrasses": "desenclaustrar",
    "desenclaustraste": "desenclaustrar",
    "desenclaustrastes": "desenclaustrar",
    "desenclaustrava": "desenclaustrar",
    "desenclaustravam": "desenclaustrar",
    "desenclaustravas": "desenclaustrar",
    "desenclaustre": "desenclaustrar",
    "desenclaustrei": "desenclaustrar",
    "desenclaustreis": "desenclaustrar",
    "desenclaustrem": "desenclaustrar",
    "desenclaustremo": "desenclaustrar",
    "desenclaustremos": "desenclaustrar",
    "desenclaustres": "desenclaustrar",
    "desenclaustro": "desenclaustrar",
    "desenclaustrou": "desenclaustrar",
    "desenclaustrá": "desenclaustrar",
    "desenclaustrámo": "desenclaustrar",
    "desenclaustrámos": "desenclaustrar",
    "desenclaustráramo": "desenclaustrar",
    "desenclaustráramos": "desenclaustrar",
    "desenclaustrárei": "desenclaustrar",
    "desenclaustráreis": "desenclaustrar",
    "desenclaustrásseis": "desenclaustrar",
    "desenclaustrássemos": "desenclaustrar",
    "desenclaustrávamo": "desenclaustrar",
    "desenclaustrávamos": "desenclaustrar",
    "desenclaustrávei": "desenclaustrar",
    "desenclaustráveis": "desenclaustrar",
    "desenclavinha": "desenclavinhar",
    "desenclavinhada": "desenclavinhar",
    "desenclavinhadas": "desenclavinhar",
    "desenclavinhado": "desenclavinhar",
    "desenclavinhados": "desenclavinhar",
    "desenclavinhai": "desenclavinhar",
    "desenclavinhais": "desenclavinhar",
    "desenclavinham": "desenclavinhar",
    "desenclavinhamo": "desenclavinhar",
    "desenclavinhamos": "desenclavinhar",
    "desenclavinhando": "desenclavinhar",
    "desenclavinhara": "desenclavinhar",
    "desenclavinharam": "desenclavinhar",
    "desenclavinharas": "desenclavinhar",
    "desenclavinharde": "desenclavinhar",
    "desenclavinhardes": "desenclavinhar",
    "desenclavinhare": "desenclavinhar",
    "desenclavinharei": "desenclavinhar",
    "desenclavinhareis": "desenclavinhar",
    "desenclavinharem": "desenclavinhar",
    "desenclavinharemos": "desenclavinhar",
    "desenclavinhares": "desenclavinhar",
    "desenclavinharia": "desenclavinhar",
    "desenclavinhariam": "desenclavinhar",
    "desenclavinharias": "desenclavinhar",
    "desenclavinharmo": "desenclavinhar",
    "desenclavinharmos": "desenclavinhar",
    "desenclavinhará": "desenclavinhar",
    "desenclavinharás": "desenclavinhar",
    "desenclavinharão": "desenclavinhar",
    "desenclavinharíamos": "desenclavinhar",
    "desenclavinharíeis": "desenclavinhar",
    "desenclavinhas": "desenclavinhar",
    "desenclavinhasse": "desenclavinhar",
    "desenclavinhassem": "desenclavinhar",
    "desenclavinhasses": "desenclavinhar",
    "desenclavinhaste": "desenclavinhar",
    "desenclavinhastes": "desenclavinhar",
    "desenclavinhava": "desenclavinhar",
    "desenclavinhavam": "desenclavinhar",
    "desenclavinhavas": "desenclavinhar",
    "desenclavinhe": "desenclavinhar",
    "desenclavinhei": "desenclavinhar",
    "desenclavinheis": "desenclavinhar",
    "desenclavinhem": "desenclavinhar",
    "desenclavinhemo": "desenclavinhar",
    "desenclavinhemos": "desenclavinhar",
    "desenclavinhes": "desenclavinhar",
    "desenclavinho": "desenclavinhar",
    "desenclavinhou": "desenclavinhar",
    "desenclavinhá": "desenclavinhar",
    "desenclavinhámo": "desenclavinhar",
    "desenclavinhámos": "desenclavinhar",
    "desenclavinháramo": "desenclavinhar",
    "desenclavinháramos": "desenclavinhar",
    "desenclavinhárei": "desenclavinhar",
    "desenclavinháreis": "desenclavinhar",
    "desenclavinhásseis": "desenclavinhar",
    "desenclavinhássemos": "desenclavinhar",
    "desenclavinhávamo": "desenclavinhar",
    "desenclavinhávamos": "desenclavinhar",
    "desenclavinhávei": "desenclavinhar",
    "desenclavinháveis": "desenclavinhar",
    "desencobra": "desencobrir",
    "desencobrais": "desencobrir",
    "desencobram": "desencobrir",
    "desencobramo": "desencobrir",
    "desencobramos": "desencobrir",
    "desencobras": "desencobrir",
    "desencobre": "desencobrir",
    "desencobrem": "desencobrir",
    "desencobres": "desencobrir",
    "desencobri": "desencobrir",
    "desencobria": "desencobrir",
    "desencobriam": "desencobrir",
    "desencobrias": "desencobrir",
    "desencobrida": "desencobrir",
    "desencobridas": "desencobrir",
    "desencobrido": "desencobrir",
    "desencobridos": "desencobrir",
    "desencobrimo": "desencobrir",
    "desencobrimos": "desencobrir",
    "desencobrindo": "desencobrir",
    "desencobrira": "desencobrir",
    "desencobriram": "desencobrir",
    "desencobriras": "desencobrir",
    "desencobrirde": "desencobrir",
    "desencobrirdes": "desencobrir",
    "desencobrire": "desencobrir",
    "desencobrirei": "desencobrir",
    "desencobrireis": "desencobrir",
    "desencobrirem": "desencobrir",
    "desencobriremos": "desencobrir",
    "desencobrires": "desencobrir",
    "desencobriria": "desencobrir",
    "desencobririam": "desencobrir",
    "desencobririas": "desencobrir",
    "desencobrirmo": "desencobrir",
    "desencobrirmos": "desencobrir",
    "desencobrirá": "desencobrir",
    "desencobrirás": "desencobrir",
    "desencobrirão": "desencobrir",
    "desencobriríamos": "desencobrir",
    "desencobriríeis": "desencobrir",
    "desencobris": "desencobrir",
    "desencobrisse": "desencobrir",
    "desencobrissem": "desencobrir",
    "desencobrisses": "desencobrir",
    "desencobriste": "desencobrir",
    "desencobristes": "desencobrir",
    "desencobriu": "desencobrir",
    "desencobro": "desencobrir",
    "desencobríamo": "desencobrir",
    "desencobríamos": "desencobrir",
    "desencobríei": "desencobrir",
    "desencobríeis": "desencobrir",
    "desencobríramo": "desencobrir",
    "desencobríramos": "desencobrir",
    "desencobrírei": "desencobrir",
    "desencobríreis": "desencobrir",
    "desencobrísseis": "desencobrir",
    "desencobríssemos": "desencobrir",
    "desencoleriza": "desencolerizar",
    "desencolerizada": "desencolerizar",
    "desencolerizadas": "desencolerizar",
    "desencolerizado": "desencolerizar",
    "desencolerizados": "desencolerizar",
    "desencolerizai": "desencolerizar",
    "desencolerizais": "desencolerizar",
    "desencolerizam": "desencolerizar",
    "desencolerizamo": "desencolerizar",
    "desencolerizamos": "desencolerizar",
    "desencolerizando": "desencolerizar",
    "desencolerizara": "desencolerizar",
    "desencolerizaram": "desencolerizar",
    "desencolerizaras": "desencolerizar",
    "desencolerizarde": "desencolerizar",
    "desencolerizardes": "desencolerizar",
    "desencolerizare": "desencolerizar",
    "desencolerizarei": "desencolerizar",
    "desencolerizareis": "desencolerizar",
    "desencolerizarem": "desencolerizar",
    "desencolerizaremos": "desencolerizar",
    "desencolerizares": "desencolerizar",
    "desencolerizaria": "desencolerizar",
    "desencolerizariam": "desencolerizar",
    "desencolerizarias": "desencolerizar",
    "desencolerizarmo": "desencolerizar",
    "desencolerizarmos": "desencolerizar",
    "desencolerizará": "desencolerizar",
    "desencolerizarás": "desencolerizar",
    "desencolerizarão": "desencolerizar",
    "desencolerizaríamos": "desencolerizar",
    "desencolerizaríeis": "desencolerizar",
    "desencolerizas": "desencolerizar",
    "desencolerizasse": "desencolerizar",
    "desencolerizassem": "desencolerizar",
    "desencolerizasses": "desencolerizar",
    "desencolerizaste": "desencolerizar",
    "desencolerizastes": "desencolerizar",
    "desencolerizava": "desencolerizar",
    "desencolerizavam": "desencolerizar",
    "desencolerizavas": "desencolerizar",
    "desencolerize": "desencolerizar",
    "desencolerizei": "desencolerizar",
    "desencolerizeis": "desencolerizar",
    "desencolerizem": "desencolerizar",
    "desencolerizemo": "desencolerizar",
    "desencolerizemos": "desencolerizar",
    "desencolerizes": "desencolerizar",
    "desencolerizo": "desencolerizar",
    "desencolerizou": "desencolerizar",
    "desencolerizá": "desencolerizar",
    "desencolerizámo": "desencolerizar",
    "desencolerizámos": "desencolerizar",
    "desencolerizáramo": "desencolerizar",
    "desencolerizáramos": "desencolerizar",
    "desencolerizárei": "desencolerizar",
    "desencolerizáreis": "desencolerizar",
    "desencolerizásseis": "desencolerizar",
    "desencolerizássemos": "desencolerizar",
    "desencolerizávamo": "desencolerizar",
    "desencolerizávamos": "desencolerizar",
    "desencolerizávei": "desencolerizar",
    "desencolerizáveis": "desencolerizar",
    "desencolha": "desencolher",
    "desencolhais": "desencolher",
    "desencolham": "desencolher",
    "desencolhamo": "desencolher",
    "desencolhamos": "desencolher",
    "desencolhas": "desencolher",
    "desencolhe": "desencolher",
    "desencolhei": "desencolher",
    "desencolheis": "desencolher",
    "desencolhem": "desencolher",
    "desencolhemo": "desencolher",
    "desencolhemos": "desencolher",
    "desencolhendo": "desencolher",
    "desencolhera": "desencolher",
    "desencolheram": "desencolher",
    "desencolheras": "desencolher",
    "desencolherde": "desencolher",
    "desencolherdes": "desencolher",
    "desencolhere": "desencolher",
    "desencolherei": "desencolher",
    "desencolhereis": "desencolher",
    "desencolherem": "desencolher",
    "desencolheremos": "desencolher",
    "desencolheres": "desencolher",
    "desencolheria": "desencolher",
    "desencolheriam": "desencolher",
    "desencolherias": "desencolher",
    "desencolhermo": "desencolher",
    "desencolhermos": "desencolher",
    "desencolherá": "desencolher",
    "desencolherás": "desencolher",
    "desencolherão": "desencolher",
    "desencolheríamos": "desencolher",
    "desencolheríeis": "desencolher",
    "desencolhes": "desencolher",
    "desencolhesse": "desencolher",
    "desencolhessem": "desencolher",
    "desencolhesses": "desencolher",
    "desencolheste": "desencolher",
    "desencolhestes": "desencolher",
    "desencolheu": "desencolher",
    "desencolhi": "desencolher",
    "desencolhia": "desencolher",
    "desencolhiam": "desencolher",
    "desencolhias": "desencolher",
    "desencolhida": "desencolhido",
    "desencolhidas": "desencolhido",
    "desencolhido": "desencolher",
    "desencolhidos": "desencolhido",
    "desencolhimentos": "desencolhimento",
    "desencolho": "desencolher",
    "desencolhê": "desencolher",
    "desencolhêramo": "desencolher",
    "desencolhêramos": "desencolher",
    "desencolhêrei": "desencolher",
    "desencolhêreis": "desencolher",
    "desencolhêsseis": "desencolher",
    "desencolhêssemos": "desencolher",
    "desencolhíamo": "desencolher",
    "desencolhíamos": "desencolher",
    "desencolhíei": "desencolher",
    "desencolhíeis": "desencolher",
    "desencomenda": "desencomendar",
    "desencomendada": "desencomendar",
    "desencomendadas": "desencomendar",
    "desencomendado": "desencomendar",
    "desencomendados": "desencomendar",
    "desencomendai": "desencomendar",
    "desencomendais": "desencomendar",
    "desencomendam": "desencomendar",
    "desencomendamo": "desencomendar",
    "desencomendamos": "desencomendar",
    "desencomendando": "desencomendar",
    "desencomendara": "desencomendar",
    "desencomendaram": "desencomendar",
    "desencomendaras": "desencomendar",
    "desencomendarde": "desencomendar",
    "desencomendardes": "desencomendar",
    "desencomendare": "desencomendar",
    "desencomendarei": "desencomendar",
    "desencomendareis": "desencomendar",
    "desencomendarem": "desencomendar",
    "desencomendaremos": "desencomendar",
    "desencomendares": "desencomendar",
    "desencomendaria": "desencomendar",
    "desencomendariam": "desencomendar",
    "desencomendarias": "desencomendar",
    "desencomendarmo": "desencomendar",
    "desencomendarmos": "desencomendar",
    "desencomendará": "desencomendar",
    "desencomendarás": "desencomendar",
    "desencomendarão": "desencomendar",
    "desencomendaríamos": "desencomendar",
    "desencomendaríeis": "desencomendar",
    "desencomendas": "desencomendar",
    "desencomendasse": "desencomendar",
    "desencomendassem": "desencomendar",
    "desencomendasses": "desencomendar",
    "desencomendaste": "desencomendar",
    "desencomendastes": "desencomendar",
    "desencomendava": "desencomendar",
    "desencomendavam": "desencomendar",
    "desencomendavas": "desencomendar",
    "desencomende": "desencomendar",
    "desencomendei": "desencomendar",
    "desencomendeis": "desencomendar",
    "desencomendem": "desencomendar",
    "desencomendemo": "desencomendar",
    "desencomendemos": "desencomendar",
    "desencomendes": "desencomendar",
    "desencomendo": "desencomendar",
    "desencomendou": "desencomendar",
    "desencomendá": "desencomendar",
    "desencomendámo": "desencomendar",
    "desencomendámos": "desencomendar",
    "desencomendáramo": "desencomendar",
    "desencomendáramos": "desencomendar",
    "desencomendárei": "desencomendar",
    "desencomendáreis": "desencomendar",
    "desencomendásseis": "desencomendar",
    "desencomendássemos": "desencomendar",
    "desencomendávamo": "desencomendar",
    "desencomendávamos": "desencomendar",
    "desencomendávei": "desencomendar",
    "desencomendáveis": "desencomendar",
    "desenconcha": "desenconchar",
    "desenconchada": "desenconchar",
    "desenconchadas": "desenconchar",
    "desenconchado": "desenconchar",
    "desenconchados": "desenconchar",
    "desenconchai": "desenconchar",
    "desenconchais": "desenconchar",
    "desenconcham": "desenconchar",
    "desenconchamo": "desenconchar",
    "desenconchamos": "desenconchar",
    "desenconchando": "desenconchar",
    "desenconchara": "desenconchar",
    "desenconcharam": "desenconchar",
    "desenconcharas": "desenconchar",
    "desenconcharde": "desenconchar",
    "desenconchardes": "desenconchar",
    "desenconchare": "desenconchar",
    "desenconcharei": "desenconchar",
    "desenconchareis": "desenconchar",
    "desenconcharem": "desenconchar",
    "desenconcharemos": "desenconchar",
    "desenconchares": "desenconchar",
    "desenconcharia": "desenconchar",
    "desenconchariam": "desenconchar",
    "desenconcharias": "desenconchar",
    "desenconcharmo": "desenconchar",
    "desenconcharmos": "desenconchar",
    "desenconchará": "desenconchar",
    "desenconcharás": "desenconchar",
    "desenconcharão": "desenconchar",
    "desenconcharíamos": "desenconchar",
    "desenconcharíeis": "desenconchar",
    "desenconchas": "desenconchar",
    "desenconchasse": "desenconchar",
    "desenconchassem": "desenconchar",
    "desenconchasses": "desenconchar",
    "desenconchaste": "desenconchar",
    "desenconchastes": "desenconchar",
    "desenconchava": "desenconchar",
    "desenconchavam": "desenconchar",
    "desenconchavas": "desenconchar",
    "desenconche": "desenconchar",
    "desenconchei": "desenconchar",
    "desenconcheis": "desenconchar",
    "desenconchem": "desenconchar",
    "desenconchemo": "desenconchar",
    "desenconchemos": "desenconchar",
    "desenconches": "desenconchar",
    "desenconcho": "desenconchar",
    "desenconchou": "desenconchar",
    "desenconchá": "desenconchar",
    "desenconchámo": "desenconchar",
    "desenconchámos": "desenconchar",
    "desenconcháramo": "desenconchar",
    "desenconcháramos": "desenconchar",
    "desenconchárei": "desenconchar",
    "desenconcháreis": "desenconchar",
    "desenconchásseis": "desenconchar",
    "desenconchássemos": "desenconchar",
    "desenconchávamo": "desenconchar",
    "desenconchávamos": "desenconchar",
    "desenconchávei": "desenconchar",
    "desenconcháveis": "desenconchar",
    "desencontra": "desencontrar",
    "desencontrada": "desencontrar",
    "desencontradas": "desencontrar",
    "desencontrado": "desencontrar",
    "desencontrados": "desencontrar",
    "desencontrai": "desencontrar",
    "desencontrais": "desencontrar",
    "desencontram": "desencontrar",
    "desencontramo": "desencontrar",
    "desencontramos": "desencontrar",
    "desencontrando": "desencontrar",
    "desencontrara": "desencontrar",
    "desencontraram": "desencontrar",
    "desencontraras": "desencontrar",
    "desencontrarde": "desencontrar",
    "desencontrardes": "desencontrar",
    "desencontrare": "desencontrar",
    "desencontrarei": "desencontrar",
    "desencontrareis": "desencontrar",
    "desencontrarem": "desencontrar",
    "desencontraremos": "desencontrar",
    "desencontrares": "desencontrar",
    "desencontraria": "desencontrar",
    "desencontrariam": "desencontrar",
    "desencontrarias": "desencontrar",
    "desencontrarmo": "desencontrar",
    "desencontrarmos": "desencontrar",
    "desencontrará": "desencontrar",
    "desencontrarás": "desencontrar",
    "desencontrarão": "desencontrar",
    "desencontraríamos": "desencontrar",
    "desencontraríeis": "desencontrar",
    "desencontras": "desencontrar",
    "desencontrasse": "desencontrar",
    "desencontrassem": "desencontrar",
    "desencontrasses": "desencontrar",
    "desencontraste": "desencontrar",
    "desencontrastes": "desencontrar",
    "desencontrava": "desencontrar",
    "desencontravam": "desencontrar",
    "desencontravas": "desencontrar",
    "desencontre": "desencontrar",
    "desencontrei": "desencontrar",
    "desencontreis": "desencontrar",
    "desencontrem": "desencontrar",
    "desencontremo": "desencontrar",
    "desencontremos": "desencontrar",
    "desencontres": "desencontrar",
    "desencontro": "desencontrar",
    "desencontros": "desencontro",
    "desencontrou": "desencontrar",
    "desencontrá": "desencontrar",
    "desencontrámo": "desencontrar",
    "desencontrámos": "desencontrar",
    "desencontráramo": "desencontrar",
    "desencontráramos": "desencontrar",
    "desencontrárei": "desencontrar",
    "desencontráreis": "desencontrar",
    "desencontrásseis": "desencontrar",
    "desencontrássemos": "desencontrar",
    "desencontrávamo": "desencontrar",
    "desencontrávamos": "desencontrar",
    "desencontrávei": "desencontrar",
    "desencontráveis": "desencontrar",
    "desencoraja": "desencorajar",
    "desencorajada": "desencorajar",
    "desencorajadas": "desencorajar",
    "desencorajado": "desencorajar",
    "desencorajados": "desencorajar",
    "desencorajai": "desencorajar",
    "desencorajais": "desencorajar",
    "desencorajam": "desencorajar",
    "desencorajamentos": "desencorajamento",
    "desencorajamo": "desencorajar",
    "desencorajamos": "desencorajar",
    "desencorajando": "desencorajar",
    "desencorajara": "desencorajar",
    "desencorajaram": "desencorajar",
    "desencorajaras": "desencorajar",
    "desencorajarde": "desencorajar",
    "desencorajardes": "desencorajar",
    "desencorajare": "desencorajar",
    "desencorajarei": "desencorajar",
    "desencorajareis": "desencorajar",
    "desencorajarem": "desencorajar",
    "desencorajaremos": "desencorajar",
    "desencorajares": "desencorajar",
    "desencorajaria": "desencorajar",
    "desencorajariam": "desencorajar",
    "desencorajarias": "desencorajar",
    "desencorajarmo": "desencorajar",
    "desencorajarmos": "desencorajar",
    "desencorajará": "desencorajar",
    "desencorajarás": "desencorajar",
    "desencorajarão": "desencorajar",
    "desencorajaríamos": "desencorajar",
    "desencorajaríeis": "desencorajar",
    "desencorajas": "desencorajar",
    "desencorajasse": "desencorajar",
    "desencorajassem": "desencorajar",
    "desencorajasses": "desencorajar",
    "desencorajaste": "desencorajar",
    "desencorajastes": "desencorajar",
    "desencorajava": "desencorajar",
    "desencorajavam": "desencorajar",
    "desencorajavas": "desencorajar",
    "desencoraje": "desencorajar",
    "desencorajei": "desencorajar",
    "desencorajeis": "desencorajar",
    "desencorajem": "desencorajar",
    "desencorajemo": "desencorajar",
    "desencorajemos": "desencorajar",
    "desencorajes": "desencorajar",
    "desencorajo": "desencorajar",
    "desencorajou": "desencorajar",
    "desencorajá": "desencorajar",
    "desencorajámo": "desencorajar",
    "desencorajámos": "desencorajar",
    "desencorajáramo": "desencorajar",
    "desencorajáramos": "desencorajar",
    "desencorajárei": "desencorajar",
    "desencorajáreis": "desencorajar",
    "desencorajásseis": "desencorajar",
    "desencorajássemos": "desencorajar",
    "desencorajávamo": "desencorajar",
    "desencorajávamos": "desencorajar",
    "desencorajávei": "desencorajar",
    "desencorajáveis": "desencorajar",
    "desencordoa": "desencordoar",
    "desencordoada": "desencordoar",
    "desencordoadas": "desencordoar",
    "desencordoado": "desencordoar",
    "desencordoados": "desencordoar",
    "desencordoai": "desencordoar",
    "desencordoais": "desencordoar",
    "desencordoam": "desencordoar",
    "desencordoamo": "desencordoar",
    "desencordoamos": "desencordoar",
    "desencordoando": "desencordoar",
    "desencordoara": "desencordoar",
    "desencordoaram": "desencordoar",
    "desencordoaras": "desencordoar",
    "desencordoarde": "desencordoar",
    "desencordoardes": "desencordoar",
    "desencordoare": "desencordoar",
    "desencordoarei": "desencordoar",
    "desencordoareis": "desencordoar",
    "desencordoarem": "desencordoar",
    "desencordoaremos": "desencordoar",
    "desencordoares": "desencordoar",
    "desencordoaria": "desencordoar",
    "desencordoariam": "desencordoar",
    "desencordoarias": "desencordoar",
    "desencordoarmo": "desencordoar",
    "desencordoarmos": "desencordoar",
    "desencordoará": "desencordoar",
    "desencordoarás": "desencordoar",
    "desencordoarão": "desencordoar",
    "desencordoaríamos": "desencordoar",
    "desencordoaríeis": "desencordoar",
    "desencordoas": "desencordoar",
    "desencordoasse": "desencordoar",
    "desencordoassem": "desencordoar",
    "desencordoasses": "desencordoar",
    "desencordoaste": "desencordoar",
    "desencordoastes": "desencordoar",
    "desencordoava": "desencordoar",
    "desencordoavam": "desencordoar",
    "desencordoavas": "desencordoar",
    "desencordoe": "desencordoar",
    "desencordoei": "desencordoar",
    "desencordoeis": "desencordoar",
    "desencordoem": "desencordoar",
    "desencordoemo": "desencordoar",
    "desencordoemos": "desencordoar",
    "desencordoes": "desencordoar",
    "desencordoo": "desencordoar",
    "desencordoou": "desencordoar",
    "desencordoá": "desencordoar",
    "desencordoámo": "desencordoar",
    "desencordoámos": "desencordoar",
    "desencordoáramo": "desencordoar",
    "desencordoáramos": "desencordoar",
    "desencordoárei": "desencordoar",
    "desencordoáreis": "desencordoar",
    "desencordoásseis": "desencordoar",
    "desencordoássemos": "desencordoar",
    "desencordoávamo": "desencordoar",
    "desencordoávamos": "desencordoar",
    "desencordoávei": "desencordoar",
    "desencordoáveis": "desencordoar",
    "desencorpa": "desencorpar",
    "desencorpada": "desencorpar",
    "desencorpadas": "desencorpar",
    "desencorpado": "desencorpar",
    "desencorpados": "desencorpar",
    "desencorpai": "desencorpar",
    "desencorpais": "desencorpar",
    "desencorpam": "desencorpar",
    "desencorpamo": "desencorpar",
    "desencorpamos": "desencorpar",
    "desencorpando": "desencorpar",
    "desencorpara": "desencorpar",
    "desencorparam": "desencorpar",
    "desencorparas": "desencorpar",
    "desencorparde": "desencorpar",
    "desencorpardes": "desencorpar",
    "desencorpare": "desencorpar",
    "desencorparei": "desencorpar",
    "desencorpareis": "desencorpar",
    "desencorparem": "desencorpar",
    "desencorparemos": "desencorpar",
    "desencorpares": "desencorpar",
    "desencorparia": "desencorpar",
    "desencorpariam": "desencorpar",
    "desencorparias": "desencorpar",
    "desencorparmo": "desencorpar",
    "desencorparmos": "desencorpar",
    "desencorpará": "desencorpar",
    "desencorparás": "desencorpar",
    "desencorparão": "desencorpar",
    "desencorparíamos": "desencorpar",
    "desencorparíeis": "desencorpar",
    "desencorpas": "desencorpar",
    "desencorpasse": "desencorpar",
    "desencorpassem": "desencorpar",
    "desencorpasses": "desencorpar",
    "desencorpaste": "desencorpar",
    "desencorpastes": "desencorpar",
    "desencorpava": "desencorpar",
    "desencorpavam": "desencorpar",
    "desencorpavas": "desencorpar",
    "desencorpe": "desencorpar",
    "desencorpei": "desencorpar",
    "desencorpeis": "desencorpar",
    "desencorpem": "desencorpar",
    "desencorpemo": "desencorpar",
    "desencorpemos": "desencorpar",
    "desencorpes": "desencorpar",
    "desencorpo": "desencorpar",
    "desencorpou": "desencorpar",
    "desencorpá": "desencorpar",
    "desencorpámo": "desencorpar",
    "desencorpámos": "desencorpar",
    "desencorpáramo": "desencorpar",
    "desencorpáramos": "desencorpar",
    "desencorpárei": "desencorpar",
    "desencorpáreis": "desencorpar",
    "desencorpásseis": "desencorpar",
    "desencorpássemos": "desencorpar",
    "desencorpávamo": "desencorpar",
    "desencorpávamos": "desencorpar",
    "desencorpávei": "desencorpar",
    "desencorpáveis": "desencorpar",
    "desencorrea": "desencorrear",
    "desencorreada": "desencorrear",
    "desencorreadas": "desencorrear",
    "desencorreado": "desencorrear",
    "desencorreados": "desencorrear",
    "desencorreai": "desencorrear",
    "desencorreais": "desencorrear",
    "desencorream": "desencorrear",
    "desencorreamo": "desencorrear",
    "desencorreamos": "desencorrear",
    "desencorreando": "desencorrear",
    "desencorreara": "desencorrear",
    "desencorrearam": "desencorrear",
    "desencorrearas": "desencorrear",
    "desencorrearde": "desencorrear",
    "desencorreardes": "desencorrear",
    "desencorreare": "desencorrear",
    "desencorrearei": "desencorrear",
    "desencorreareis": "desencorrear",
    "desencorrearem": "desencorrear",
    "desencorrearemos": "desencorrear",
    "desencorreares": "desencorrear",
    "desencorrearia": "desencorrear",
    "desencorreariam": "desencorrear",
    "desencorrearias": "desencorrear",
    "desencorrearmo": "desencorrear",
    "desencorrearmos": "desencorrear",
    "desencorreará": "desencorrear",
    "desencorrearás": "desencorrear",
    "desencorrearão": "desencorrear",
    "desencorrearíamos": "desencorrear",
    "desencorrearíeis": "desencorrear",
    "desencorreas": "desencorrear",
    "desencorreasse": "desencorrear",
    "desencorreassem": "desencorrear",
    "desencorreasses": "desencorrear",
    "desencorreaste": "desencorrear",
    "desencorreastes": "desencorrear",
    "desencorreava": "desencorrear",
    "desencorreavam": "desencorrear",
    "desencorreavas": "desencorrear",
    "desencorree": "desencorrear",
    "desencorreei": "desencorrear",
    "desencorreeis": "desencorrear",
    "desencorreem": "desencorrear",
    "desencorreemo": "desencorrear",
    "desencorreemos": "desencorrear",
    "desencorrees": "desencorrear",
    "desencorreo": "desencorrear",
    "desencorreou": "desencorrear",
    "desencorreá": "desencorrear",
    "desencorreámo": "desencorrear",
    "desencorreámos": "desencorrear",
    "desencorreáramo": "desencorrear",
    "desencorreáramos": "desencorrear",
    "desencorreárei": "desencorrear",
    "desencorreáreis": "desencorrear",
    "desencorreásseis": "desencorrear",
    "desencorreássemos": "desencorrear",
    "desencorreávamo": "desencorrear",
    "desencorreávamos": "desencorrear",
    "desencorreávei": "desencorrear",
    "desencorreáveis": "desencorrear",
    "desencortice": "desencortiçar",
    "desencorticei": "desencortiçar",
    "desencorticeis": "desencortiçar",
    "desencorticem": "desencortiçar",
    "desencorticemo": "desencortiçar",
    "desencorticemos": "desencortiçar",
    "desencortices": "desencortiçar",
    "desencortiça": "desencortiçar",
    "desencortiçada": "desencortiçar",
    "desencortiçadas": "desencortiçar",
    "desencortiçado": "desencortiçar",
    "desencortiçados": "desencortiçar",
    "desencortiçai": "desencortiçar",
    "desencortiçais": "desencortiçar",
    "desencortiçam": "desencortiçar",
    "desencortiçamo": "desencortiçar",
    "desencortiçamos": "desencortiçar",
    "desencortiçando": "desencortiçar",
    "desencortiçara": "desencortiçar",
    "desencortiçaram": "desencortiçar",
    "desencortiçaras": "desencortiçar",
    "desencortiçarde": "desencortiçar",
    "desencortiçardes": "desencortiçar",
    "desencortiçare": "desencortiçar",
    "desencortiçarei": "desencortiçar",
    "desencortiçareis": "desencortiçar",
    "desencortiçarem": "desencortiçar",
    "desencortiçaremos": "desencortiçar",
    "desencortiçares": "desencortiçar",
    "desencortiçaria": "desencortiçar",
    "desencortiçariam": "desencortiçar",
    "desencortiçarias": "desencortiçar",
    "desencortiçarmo": "desencortiçar",
    "desencortiçarmos": "desencortiçar",
    "desencortiçará": "desencortiçar",
    "desencortiçarás": "desencortiçar",
    "desencortiçarão": "desencortiçar",
    "desencortiçaríamos": "desencortiçar",
    "desencortiçaríeis": "desencortiçar",
    "desencortiças": "desencortiçar",
    "desencortiçasse": "desencortiçar",
    "desencortiçassem": "desencortiçar",
    "desencortiçasses": "desencortiçar",
    "desencortiçaste": "desencortiçar",
    "desencortiçastes": "desencortiçar",
    "desencortiçava": "desencortiçar",
    "desencortiçavam": "desencortiçar",
    "desencortiçavas": "desencortiçar",
    "desencortiço": "desencortiçar",
    "desencortiçou": "desencortiçar",
    "desencortiçá": "desencortiçar",
    "desencortiçámo": "desencortiçar",
    "desencortiçámos": "desencortiçar",
    "desencortiçáramo": "desencortiçar",
    "desencortiçáramos": "desencortiçar",
    "desencortiçárei": "desencortiçar",
    "desencortiçáreis": "desencortiçar",
    "desencortiçásseis": "desencortiçar",
    "desencortiçássemos": "desencortiçar",
    "desencortiçávamo": "desencortiçar",
    "desencortiçávamos": "desencortiçar",
    "desencortiçávei": "desencortiçar",
    "desencortiçáveis": "desencortiçar",
    "desencosta": "desencostar",
    "desencostada": "desencostar",
    "desencostadas": "desencostar",
    "desencostado": "desencostar",
    "desencostados": "desencostar",
    "desencostai": "desencostar",
    "desencostais": "desencostar",
    "desencostam": "desencostar",
    "desencostamo": "desencostar",
    "desencostamos": "desencostar",
    "desencostando": "desencostar",
    "desencostara": "desencostar",
    "desencostaram": "desencostar",
    "desencostaras": "desencostar",
    "desencostarde": "desencostar",
    "desencostardes": "desencostar",
    "desencostare": "desencostar",
    "desencostarei": "desencostar",
    "desencostareis": "desencostar",
    "desencostarem": "desencostar",
    "desencostaremos": "desencostar",
    "desencostares": "desencostar",
    "desencostaria": "desencostar",
    "desencostariam": "desencostar",
    "desencostarias": "desencostar",
    "desencostarmo": "desencostar",
    "desencostarmos": "desencostar",
    "desencostará": "desencostar",
    "desencostarás": "desencostar",
    "desencostarão": "desencostar",
    "desencostaríamos": "desencostar",
    "desencostaríeis": "desencostar",
    "desencostas": "desencostar",
    "desencostasse": "desencostar",
    "desencostassem": "desencostar",
    "desencostasses": "desencostar",
    "desencostaste": "desencostar",
    "desencostastes": "desencostar",
    "desencostava": "desencostar",
    "desencostavam": "desencostar",
    "desencostavas": "desencostar",
    "desencoste": "desencostar",
    "desencostei": "desencostar",
    "desencosteis": "desencostar",
    "desencostem": "desencostar",
    "desencostemo": "desencostar",
    "desencostemos": "desencostar",
    "desencostes": "desencostar",
    "desencosto": "desencostar",
    "desencostou": "desencostar",
    "desencostá": "desencostar",
    "desencostámo": "desencostar",
    "desencostámos": "desencostar",
    "desencostáramo": "desencostar",
    "desencostáramos": "desencostar",
    "desencostárei": "desencostar",
    "desencostáreis": "desencostar",
    "desencostásseis": "desencostar",
    "desencostássemos": "desencostar",
    "desencostávamo": "desencostar",
    "desencostávamos": "desencostar",
    "desencostávei": "desencostar",
    "desencostáveis": "desencostar",
    "desencova": "desencovar",
    "desencovada": "desencovar",
    "desencovadas": "desencovar",
    "desencovado": "desencovar",
    "desencovados": "desencovar",
    "desencovai": "desencovar",
    "desencovais": "desencovar",
    "desencovam": "desencovar",
    "desencovamo": "desencovar",
    "desencovamos": "desencovar",
    "desencovando": "desencovar",
    "desencovara": "desencovar",
    "desencovaram": "desencovar",
    "desencovaras": "desencovar",
    "desencovarde": "desencovar",
    "desencovardes": "desencovar",
    "desencovare": "desencovar",
    "desencovarei": "desencovar",
    "desencovareis": "desencovar",
    "desencovarem": "desencovar",
    "desencovaremos": "desencovar",
    "desencovares": "desencovar",
    "desencovaria": "desencovar",
    "desencovariam": "desencovar",
    "desencovarias": "desencovar",
    "desencovarmo": "desencovar",
    "desencovarmos": "desencovar",
    "desencovará": "desencovar",
    "desencovarás": "desencovar",
    "desencovarão": "desencovar",
    "desencovaríamos": "desencovar",
    "desencovaríeis": "desencovar",
    "desencovas": "desencovar",
    "desencovasse": "desencovar",
    "desencovassem": "desencovar",
    "desencovasses": "desencovar",
    "desencovaste": "desencovar",
    "desencovastes": "desencovar",
    "desencovava": "desencovar",
    "desencovavam": "desencovar",
    "desencovavas": "desencovar",
    "desencove": "desencovar",
    "desencovei": "desencovar",
    "desencoveis": "desencovar",
    "desencovem": "desencovar",
    "desencovemo": "desencovar",
    "desencovemos": "desencovar",
    "desencoves": "desencovar",
    "desencovila": "desencovilar",
    "desencovilada": "desencovilar",
    "desencoviladas": "desencovilar",
    "desencovilado": "desencovilar",
    "desencovilados": "desencovilar",
    "desencovilai": "desencovilar",
    "desencovilais": "desencovilar",
    "desencovilam": "desencovilar",
    "desencovilamo": "desencovilar",
    "desencovilamos": "desencovilar",
    "desencovilando": "desencovilar",
    "desencovilara": "desencovilar",
    "desencovilaram": "desencovilar",
    "desencovilaras": "desencovilar",
    "desencovilarde": "desencovilar",
    "desencovilardes": "desencovilar",
    "desencovilare": "desencovilar",
    "desencovilarei": "desencovilar",
    "desencovilareis": "desencovilar",
    "desencovilarem": "desencovilar",
    "desencovilaremos": "desencovilar",
    "desencovilares": "desencovilar",
    "desencovilaria": "desencovilar",
    "desencovilariam": "desencovilar",
    "desencovilarias": "desencovilar",
    "desencovilarmo": "desencovilar",
    "desencovilarmos": "desencovilar",
    "desencovilará": "desencovilar",
    "desencovilarás": "desencovilar",
    "desencovilarão": "desencovilar",
    "desencovilaríamos": "desencovilar",
    "desencovilaríeis": "desencovilar",
    "desencovilas": "desencovilar",
    "desencovilasse": "desencovilar",
    "desencovilassem": "desencovilar",
    "desencovilasses": "desencovilar",
    "desencovilaste": "desencovilar",
    "desencovilastes": "desencovilar",
    "desencovilava": "desencovilar",
    "desencovilavam": "desencovilar",
    "desencovilavas": "desencovilar",
    "desencovile": "desencovilar",
    "desencovilei": "desencovilar",
    "desencovileis": "desencovilar",
    "desencovilem": "desencovilar",
    "desencovilemo": "desencovilar",
    "desencovilemos": "desencovilar",
    "desencoviles": "desencovilar",
    "desencovilo": "desencovilar",
    "desencovilou": "desencovilar",
    "desencovilá": "desencovilar",
    "desencovilámo": "desencovilar",
    "desencovilámos": "desencovilar",
    "desencoviláramo": "desencovilar",
    "desencoviláramos": "desencovilar",
    "desencovilárei": "desencovilar",
    "desencoviláreis": "desencovilar",
    "desencovilásseis": "desencovilar",
    "desencovilássemos": "desencovilar",
    "desencovilávamo": "desencovilar",
    "desencovilávamos": "desencovilar",
    "desencovilávei": "desencovilar",
    "desencoviláveis": "desencovilar",
    "desencovo": "desencovar",
    "desencovou": "desencovar",
    "desencová": "desencovar",
    "desencovámo": "desencovar",
    "desencovámos": "desencovar",
    "desencováramo": "desencovar",
    "desencováramos": "desencovar",
    "desencovárei": "desencovar",
    "desencováreis": "desencovar",
    "desencovásseis": "desencovar",
    "desencovássemos": "desencovar",
    "desencovávamo": "desencovar",
    "desencovávamos": "desencovar",
    "desencovávei": "desencovar",
    "desencováveis": "desencovar",
    "desencrava": "desencravar",
    "desencravada": "desencravar",
    "desencravadas": "desencravar",
    "desencravado": "desencravar",
    "desencravados": "desencravar",
    "desencravai": "desencravar",
    "desencravais": "desencravar",
    "desencravam": "desencravar",
    "desencravamo": "desencravar",
    "desencravamos": "desencravar",
    "desencravando": "desencravar",
    "desencravara": "desencravar",
    "desencravaram": "desencravar",
    "desencravaras": "desencravar",
    "desencravarde": "desencravar",
    "desencravardes": "desencravar",
    "desencravare": "desencravar",
    "desencravarei": "desencravar",
    "desencravareis": "desencravar",
    "desencravarem": "desencravar",
    "desencravaremos": "desencravar",
    "desencravares": "desencravar",
    "desencravaria": "desencravar",
    "desencravariam": "desencravar",
    "desencravarias": "desencravar",
    "desencravarmo": "desencravar",
    "desencravarmos": "desencravar",
    "desencravará": "desencravar",
    "desencravarás": "desencravar",
    "desencravarão": "desencravar",
    "desencravaríamos": "desencravar",
    "desencravaríeis": "desencravar",
    "desencravas": "desencravar",
    "desencravasse": "desencravar",
    "desencravassem": "desencravar",
    "desencravasses": "desencravar",
    "desencravaste": "desencravar",
    "desencravastes": "desencravar",
    "desencravava": "desencravar",
    "desencravavam": "desencravar",
    "desencravavas": "desencravar",
    "desencrave": "desencravar",
    "desencravei": "desencravar",
    "desencraveis": "desencravar",
    "desencravem": "desencravar",
    "desencravemo": "desencravar",
    "desencravemos": "desencravar",
    "desencraves": "desencravar",
    "desencravilha": "desencravilhar",
    "desencravilhada": "desencravilhar",
    "desencravilhadas": "desencravilhar",
    "desencravilhado": "desencravilhar",
    "desencravilhados": "desencravilhar",
    "desencravilhai": "desencravilhar",
    "desencravilhais": "desencravilhar",
    "desencravilham": "desencravilhar",
    "desencravilhamo": "desencravilhar",
    "desencravilhamos": "desencravilhar",
    "desencravilhando": "desencravilhar",
    "desencravilhara": "desencravilhar",
    "desencravilharam": "desencravilhar",
    "desencravilharas": "desencravilhar",
    "desencravilharde": "desencravilhar",
    "desencravilhardes": "desencravilhar",
    "desencravilhare": "desencravilhar",
    "desencravilharei": "desencravilhar",
    "desencravilhareis": "desencravilhar",
    "desencravilharem": "desencravilhar",
    "desencravilharemos": "desencravilhar",
    "desencravilhares": "desencravilhar",
    "desencravilharia": "desencravilhar",
    "desencravilhariam": "desencravilhar",
    "desencravilharias": "desencravilhar",
    "desencravilharmo": "desencravilhar",
    "desencravilharmos": "desencravilhar",
    "desencravilhará": "desencravilhar",
    "desencravilharás": "desencravilhar",
    "desencravilharão": "desencravilhar",
    "desencravilharíamos": "desencravilhar",
    "desencravilharíeis": "desencravilhar",
    "desencravilhas": "desencravilhar",
    "desencravilhasse": "desencravilhar",
    "desencravilhassem": "desencravilhar",
    "desencravilhasses": "desencravilhar",
    "desencravilhaste": "desencravilhar",
    "desencravilhastes": "desencravilhar",
    "desencravilhava": "desencravilhar",
    "desencravilhavam": "desencravilhar",
    "desencravilhavas": "desencravilhar",
    "desencravilhe": "desencravilhar",
    "desencravilhei": "desencravilhar",
    "desencravilheis": "desencravilhar",
    "desencravilhem": "desencravilhar",
    "desencravilhemo": "desencravilhar",
    "desencravilhemos": "desencravilhar",
    "desencravilhes": "desencravilhar",
    "desencravilho": "desencravilhar",
    "desencravilhou": "desencravilhar",
    "desencravilhá": "desencravilhar",
    "desencravilhámo": "desencravilhar",
    "desencravilhámos": "desencravilhar",
    "desencravilháramo": "desencravilhar",
    "desencravilháramos": "desencravilhar",
    "desencravilhárei": "desencravilhar",
    "desencravilháreis": "desencravilhar",
    "desencravilhásseis": "desencravilhar",
    "desencravilhássemos": "desencravilhar",
    "desencravilhávamo": "desencravilhar",
    "desencravilhávamos": "desencravilhar",
    "desencravilhávei": "desencravilhar",
    "desencravilháveis": "desencravilhar",
    "desencravo": "desencravar",
    "desencravou": "desencravar",
    "desencravá": "desencravar",
    "desencravámo": "desencravar",
    "desencravámos": "desencravar",
    "desencraváramo": "desencravar",
    "desencraváramos": "desencravar",
    "desencravárei": "desencravar",
    "desencraváreis": "desencravar",
    "desencravásseis": "desencravar",
    "desencravássemos": "desencravar",
    "desencravávamo": "desencravar",
    "desencravávamos": "desencravar",
    "desencravávei": "desencravar",
    "desencraváveis": "desencravar",
    "desencrenca": "desencrencar",
    "desencrencada": "desencrencar",
    "desencrencadas": "desencrencar",
    "desencrencado": "desencrencar",
    "desencrencados": "desencrencar",
    "desencrencai": "desencrencar",
    "desencrencais": "desencrencar",
    "desencrencam": "desencrencar",
    "desencrencamo": "desencrencar",
    "desencrencamos": "desencrencar",
    "desencrencando": "desencrencar",
    "desencrencara": "desencrencar",
    "desencrencaram": "desencrencar",
    "desencrencaras": "desencrencar",
    "desencrencarde": "desencrencar",
    "desencrencardes": "desencrencar",
    "desencrencare": "desencrencar",
    "desencrencarei": "desencrencar",
    "desencrencareis": "desencrencar",
    "desencrencarem": "desencrencar",
    "desencrencaremos": "desencrencar",
    "desencrencares": "desencrencar",
    "desencrencaria": "desencrencar",
    "desencrencariam": "desencrencar",
    "desencrencarias": "desencrencar",
    "desencrencarmo": "desencrencar",
    "desencrencarmos": "desencrencar",
    "desencrencará": "desencrencar",
    "desencrencarás": "desencrencar",
    "desencrencarão": "desencrencar",
    "desencrencaríamos": "desencrencar",
    "desencrencaríeis": "desencrencar",
    "desencrencas": "desencrencar",
    "desencrencasse": "desencrencar",
    "desencrencassem": "desencrencar",
    "desencrencasses": "desencrencar",
    "desencrencaste": "desencrencar",
    "desencrencastes": "desencrencar",
    "desencrencava": "desencrencar",
    "desencrencavam": "desencrencar",
    "desencrencavas": "desencrencar",
    "desencrenco": "desencrencar",
    "desencrencou": "desencrencar",
    "desencrencá": "desencrencar",
    "desencrencámo": "desencrencar",
    "desencrencámos": "desencrencar",
    "desencrencáramo": "desencrencar",
    "desencrencáramos": "desencrencar",
    "desencrencárei": "desencrencar",
    "desencrencáreis": "desencrencar",
    "desencrencásseis": "desencrencar",
    "desencrencássemos": "desencrencar",
    "desencrencávamo": "desencrencar",
    "desencrencávamos": "desencrencar",
    "desencrencávei": "desencrencar",
    "desencrencáveis": "desencrencar",
    "desencrenque": "desencrencar",
    "desencrenquei": "desencrencar",
    "desencrenqueis": "desencrencar",
    "desencrenquem": "desencrencar",
    "desencrenquemo": "desencrencar",
    "desencrenquemos": "desencrencar",
    "desencrenques": "desencrencar",
    "desencrespa": "desencrespar",
    "desencrespada": "desencrespar",
    "desencrespadas": "desencrespar",
    "desencrespado": "desencrespar",
    "desencrespados": "desencrespar",
    "desencrespai": "desencrespar",
    "desencrespais": "desencrespar",
    "desencrespam": "desencrespar",
    "desencrespamo": "desencrespar",
    "desencrespamos": "desencrespar",
    "desencrespando": "desencrespar",
    "desencrespara": "desencrespar",
    "desencresparam": "desencrespar",
    "desencresparas": "desencrespar",
    "desencresparde": "desencrespar",
    "desencrespardes": "desencrespar",
    "desencrespare": "desencrespar",
    "desencresparei": "desencrespar",
    "desencrespareis": "desencrespar",
    "desencresparem": "desencrespar",
    "desencresparemos": "desencrespar",
    "desencrespares": "desencrespar",
    "desencresparia": "desencrespar",
    "desencrespariam": "desencrespar",
    "desencresparias": "desencrespar",
    "desencresparmo": "desencrespar",
    "desencresparmos": "desencrespar",
    "desencrespará": "desencrespar",
    "desencresparás": "desencrespar",
    "desencresparão": "desencrespar",
    "desencresparíamos": "desencrespar",
    "desencresparíeis": "desencrespar",
    "desencrespas": "desencrespar",
    "desencrespasse": "desencrespar",
    "desencrespassem": "desencrespar",
    "desencrespasses": "desencrespar",
    "desencrespaste": "desencrespar",
    "desencrespastes": "desencrespar",
    "desencrespava": "desencrespar",
    "desencrespavam": "desencrespar",
    "desencrespavas": "desencrespar",
    "desencrespe": "desencrespar",
    "desencrespei": "desencrespar",
    "desencrespeis": "desencrespar",
    "desencrespem": "desencrespar",
    "desencrespemo": "desencrespar",
    "desencrespemos": "desencrespar",
    "desencrespes": "desencrespar",
    "desencrespo": "desencrespar",
    "desencrespou": "desencrespar",
    "desencrespá": "desencrespar",
    "desencrespámo": "desencrespar",
    "desencrespámos": "desencrespar",
    "desencrespáramo": "desencrespar",
    "desencrespáramos": "desencrespar",
    "desencrespárei": "desencrespar",
    "desencrespáreis": "desencrespar",
    "desencrespásseis": "desencrespar",
    "desencrespássemos": "desencrespar",
    "desencrespávamo": "desencrespar",
    "desencrespávamos": "desencrespar",
    "desencrespávei": "desencrespar",
    "desencrespáveis": "desencrespar",
    "desencrua": "desencruar",
    "desencruada": "desencruar",
    "desencruadas": "desencruar",
    "desencruado": "desencruar",
    "desencruados": "desencruar",
    "desencruai": "desencruar",
    "desencruais": "desencruar",
    "desencruam": "desencruar",
    "desencruamo": "desencruar",
    "desencruamos": "desencruar",
    "desencruando": "desencruar",
    "desencruara": "desencruar",
    "desencruaram": "desencruar",
    "desencruaras": "desencruar",
    "desencruarde": "desencruar",
    "desencruardes": "desencruar",
    "desencruare": "desencruar",
    "desencruarei": "desencruar",
    "desencruareis": "desencruar",
    "desencruarem": "desencruar",
    "desencruaremos": "desencruar",
    "desencruares": "desencruar",
    "desencruaria": "desencruar",
    "desencruariam": "desencruar",
    "desencruarias": "desencruar",
    "desencruarmo": "desencruar",
    "desencruarmos": "desencruar",
    "desencruará": "desencruar",
    "desencruarás": "desencruar",
    "desencruarão": "desencruar",
    "desencruaríamos": "desencruar",
    "desencruaríeis": "desencruar",
    "desencruas": "desencruar",
    "desencruasse": "desencruar",
    "desencruassem": "desencruar",
    "desencruasses": "desencruar",
    "desencruaste": "desencruar",
    "desencruastes": "desencruar",
    "desencruava": "desencruar",
    "desencruavam": "desencruar",
    "desencruavas": "desencruar",
    "desencrue": "desencruar",
    "desencruei": "desencruar",
    "desencrueis": "desencruar",
    "desencruem": "desencruar",
    "desencruemo": "desencruar",
    "desencruemos": "desencruar",
    "desencrues": "desencruar",
    "desencruo": "desencruar",
    "desencruou": "desencruar",
    "desencruza": "desencruzar",
    "desencruzada": "desencruzar",
    "desencruzadas": "desencruzar",
    "desencruzado": "desencruzar",
    "desencruzados": "desencruzar",
    "desencruzai": "desencruzar",
    "desencruzais": "desencruzar",
    "desencruzam": "desencruzar",
    "desencruzamo": "desencruzar",
    "desencruzamos": "desencruzar",
    "desencruzando": "desencruzar",
    "desencruzara": "desencruzar",
    "desencruzaram": "desencruzar",
    "desencruzaras": "desencruzar",
    "desencruzarde": "desencruzar",
    "desencruzardes": "desencruzar",
    "desencruzare": "desencruzar",
    "desencruzarei": "desencruzar",
    "desencruzareis": "desencruzar",
    "desencruzarem": "desencruzar",
    "desencruzaremos": "desencruzar",
    "desencruzares": "desencruzar",
    "desencruzaria": "desencruzar",
    "desencruzariam": "desencruzar",
    "desencruzarias": "desencruzar",
    "desencruzarmo": "desencruzar",
    "desencruzarmos": "desencruzar",
    "desencruzará": "desencruzar",
    "desencruzarás": "desencruzar",
    "desencruzarão": "desencruzar",
    "desencruzaríamos": "desencruzar",
    "desencruzaríeis": "desencruzar",
    "desencruzas": "desencruzar",
    "desencruzasse": "desencruzar",
    "desencruzassem": "desencruzar",
    "desencruzasses": "desencruzar",
    "desencruzaste": "desencruzar",
    "desencruzastes": "desencruzar",
    "desencruzava": "desencruzar",
    "desencruzavam": "desencruzar",
    "desencruzavas": "desencruzar",
    "desencruze": "desencruzar",
    "desencruzei": "desencruzar",
    "desencruzeis": "desencruzar",
    "desencruzem": "desencruzar",
    "desencruzemo": "desencruzar",
    "desencruzemos": "desencruzar",
    "desencruzes": "desencruzar",
    "desencruzo": "desencruzar",
    "desencruzou": "desencruzar",
    "desencruzá": "desencruzar",
    "desencruzámo": "desencruzar",
    "desencruzámos": "desencruzar",
    "desencruzáramo": "desencruzar",
    "desencruzáramos": "desencruzar",
    "desencruzárei": "desencruzar",
    "desencruzáreis": "desencruzar",
    "desencruzásseis": "desencruzar",
    "desencruzássemos": "desencruzar",
    "desencruzávamo": "desencruzar",
    "desencruzávamos": "desencruzar",
    "desencruzávei": "desencruzar",
    "desencruzáveis": "desencruzar",
    "desencruá": "desencruar",
    "desencruámo": "desencruar",
    "desencruámos": "desencruar",
    "desencruáramo": "desencruar",
    "desencruáramos": "desencruar",
    "desencruárei": "desencruar",
    "desencruáreis": "desencruar",
    "desencruásseis": "desencruar",
    "desencruássemos": "desencruar",
    "desencruávamo": "desencruar",
    "desencruávamos": "desencruar",
    "desencruávei": "desencruar",
    "desencruáveis": "desencruar",
    "desencuba": "desencubar",
    "desencubada": "desencubar",
    "desencubadas": "desencubar",
    "desencubado": "desencubar",
    "desencubados": "desencubar",
    "desencubagens": "desencubagem",
    "desencubai": "desencubar",
    "desencubais": "desencubar",
    "desencubam": "desencubar",
    "desencubamo": "desencubar",
    "desencubamos": "desencubar",
    "desencubando": "desencubar",
    "desencubara": "desencubar",
    "desencubaram": "desencubar",
    "desencubaras": "desencubar",
    "desencubarde": "desencubar",
    "desencubardes": "desencubar",
    "desencubare": "desencubar",
    "desencubarei": "desencubar",
    "desencubareis": "desencubar",
    "desencubarem": "desencubar",
    "desencubaremos": "desencubar",
    "desencubares": "desencubar",
    "desencubaria": "desencubar",
    "desencubariam": "desencubar",
    "desencubarias": "desencubar",
    "desencubarmo": "desencubar",
    "desencubarmos": "desencubar",
    "desencubará": "desencubar",
    "desencubarás": "desencubar",
    "desencubarão": "desencubar",
    "desencubaríamos": "desencubar",
    "desencubaríeis": "desencubar",
    "desencubas": "desencubar",
    "desencubasse": "desencubar",
    "desencubassem": "desencubar",
    "desencubasses": "desencubar",
    "desencubaste": "desencubar",
    "desencubastes": "desencubar",
    "desencubava": "desencubar",
    "desencubavam": "desencubar",
    "desencubavas": "desencubar",
    "desencube": "desencubar",
    "desencubei": "desencubar",
    "desencubeis": "desencubar",
    "desencubem": "desencubar",
    "desencubemo": "desencubar",
    "desencubemos": "desencubar",
    "desencubes": "desencubar",
    "desencubo": "desencubar",
    "desencubou": "desencubar",
    "desencubá": "desencubar",
    "desencubámo": "desencubar",
    "desencubámos": "desencubar",
    "desencubáramo": "desencubar",
    "desencubáramos": "desencubar",
    "desencubárei": "desencubar",
    "desencubáreis": "desencubar",
    "desencubásseis": "desencubar",
    "desencubássemos": "desencubar",
    "desencubávamo": "desencubar",
    "desencubávamos": "desencubar",
    "desencubávei": "desencubar",
    "desencubáveis": "desencubar",
    "desenculatra": "desenculatrar",
    "desenculatrada": "desenculatrar",
    "desenculatradas": "desenculatrar",
    "desenculatrado": "desenculatrar",
    "desenculatrados": "desenculatrar",
    "desenculatrai": "desenculatrar",
    "desenculatrais": "desenculatrar",
    "desenculatram": "desenculatrar",
    "desenculatramo": "desenculatrar",
    "desenculatramos": "desenculatrar",
    "desenculatrando": "desenculatrar",
    "desenculatrara": "desenculatrar",
    "desenculatraram": "desenculatrar",
    "desenculatraras": "desenculatrar",
    "desenculatrarde": "desenculatrar",
    "desenculatrardes": "desenculatrar",
    "desenculatrare": "desenculatrar",
    "desenculatrarei": "desenculatrar",
    "desenculatrareis": "desenculatrar",
    "desenculatrarem": "desenculatrar",
    "desenculatraremos": "desenculatrar",
    "desenculatrares": "desenculatrar",
    "desenculatraria": "desenculatrar",
    "desenculatrariam": "desenculatrar",
    "desenculatrarias": "desenculatrar",
    "desenculatrarmo": "desenculatrar",
    "desenculatrarmos": "desenculatrar",
    "desenculatrará": "desenculatrar",
    "desenculatrarás": "desenculatrar",
    "desenculatrarão": "desenculatrar",
    "desenculatraríamos": "desenculatrar",
    "desenculatraríeis": "desenculatrar",
    "desenculatras": "desenculatrar",
    "desenculatrasse": "desenculatrar",
    "desenculatrassem": "desenculatrar",
    "desenculatrasses": "desenculatrar",
    "desenculatraste": "desenculatrar",
    "desenculatrastes": "desenculatrar",
    "desenculatrava": "desenculatrar",
    "desenculatravam": "desenculatrar",
    "desenculatravas": "desenculatrar",
    "desenculatre": "desenculatrar",
    "desenculatrei": "desenculatrar",
    "desenculatreis": "desenculatrar",
    "desenculatrem": "desenculatrar",
    "desenculatremo": "desenculatrar",
    "desenculatremos": "desenculatrar",
    "desenculatres": "desenculatrar",
    "desenculatro": "desenculatrar",
    "desenculatrou": "desenculatrar",
    "desenculatrá": "desenculatrar",
    "desenculatrámo": "desenculatrar",
    "desenculatrámos": "desenculatrar",
    "desenculatráramo": "desenculatrar",
    "desenculatráramos": "desenculatrar",
    "desenculatrárei": "desenculatrar",
    "desenculatráreis": "desenculatrar",
    "desenculatrásseis": "desenculatrar",
    "desenculatrássemos": "desenculatrar",
    "desenculatrávamo": "desenculatrar",
    "desenculatrávamos": "desenculatrar",
    "desenculatrávei": "desenculatrar",
    "desenculatráveis": "desenculatrar",
    "desencurrala": "desencurralar",
    "desencurralada": "desencurralar",
    "desencurraladas": "desencurralar",
    "desencurralado": "desencurralar",
    "desencurralados": "desencurralar",
    "desencurralai": "desencurralar",
    "desencurralais": "desencurralar",
    "desencurralam": "desencurralar",
    "desencurralamo": "desencurralar",
    "desencurralamos": "desencurralar",
    "desencurralando": "desencurralar",
    "desencurralara": "desencurralar",
    "desencurralaram": "desencurralar",
    "desencurralaras": "desencurralar",
    "desencurralarde": "desencurralar",
    "desencurralardes": "desencurralar",
    "desencurralare": "desencurralar",
    "desencurralarei": "desencurralar",
    "desencurralareis": "desencurralar",
    "desencurralarem": "desencurralar",
    "desencurralaremos": "desencurralar",
    "desencurralares": "desencurralar",
    "desencurralaria": "desencurralar",
    "desencurralariam": "desencurralar",
    "desencurralarias": "desencurralar",
    "desencurralarmo": "desencurralar",
    "desencurralarmos": "desencurralar",
    "desencurralará": "desencurralar",
    "desencurralarás": "desencurralar",
    "desencurralarão": "desencurralar",
    "desencurralaríamos": "desencurralar",
    "desencurralaríeis": "desencurralar",
    "desencurralas": "desencurralar",
    "desencurralasse": "desencurralar",
    "desencurralassem": "desencurralar",
    "desencurralasses": "desencurralar",
    "desencurralaste": "desencurralar",
    "desencurralastes": "desencurralar",
    "desencurralava": "desencurralar",
    "desencurralavam": "desencurralar",
    "desencurralavas": "desencurralar",
    "desencurrale": "desencurralar",
    "desencurralei": "desencurralar",
    "desencurraleis": "desencurralar",
    "desencurralem": "desencurralar",
    "desencurralemo": "desencurralar",
    "desencurralemos": "desencurralar",
    "desencurrales": "desencurralar",
    "desencurralo": "desencurralar",
    "desencurralou": "desencurralar",
    "desencurralá": "desencurralar",
    "desencurralámo": "desencurralar",
    "desencurralámos": "desencurralar",
    "desencurraláramo": "desencurralar",
    "desencurraláramos": "desencurralar",
    "desencurralárei": "desencurralar",
    "desencurraláreis": "desencurralar",
    "desencurralásseis": "desencurralar",
    "desencurralássemos": "desencurralar",
    "desencurralávamo": "desencurralar",
    "desencurralávamos": "desencurralar",
    "desencurralávei": "desencurralar",
    "desencurraláveis": "desencurralar",
    "desencurva": "desencurvar",
    "desencurvada": "desencurvar",
    "desencurvadas": "desencurvar",
    "desencurvado": "desencurvar",
    "desencurvados": "desencurvar",
    "desencurvai": "desencurvar",
    "desencurvais": "desencurvar",
    "desencurvam": "desencurvar",
    "desencurvamo": "desencurvar",
    "desencurvamos": "desencurvar",
    "desencurvando": "desencurvar",
    "desencurvara": "desencurvar",
    "desencurvaram": "desencurvar",
    "desencurvaras": "desencurvar",
    "desencurvarde": "desencurvar",
    "desencurvardes": "desencurvar",
    "desencurvare": "desencurvar",
    "desencurvarei": "desencurvar",
    "desencurvareis": "desencurvar",
    "desencurvarem": "desencurvar",
    "desencurvaremos": "desencurvar",
    "desencurvares": "desencurvar",
    "desencurvaria": "desencurvar",
    "desencurvariam": "desencurvar",
    "desencurvarias": "desencurvar",
    "desencurvarmo": "desencurvar",
    "desencurvarmos": "desencurvar",
    "desencurvará": "desencurvar",
    "desencurvarás": "desencurvar",
    "desencurvarão": "desencurvar",
    "desencurvaríamos": "desencurvar",
    "desencurvaríeis": "desencurvar",
    "desencurvas": "desencurvar",
    "desencurvasse": "desencurvar",
    "desencurvassem": "desencurvar",
    "desencurvasses": "desencurvar",
    "desencurvaste": "desencurvar",
    "desencurvastes": "desencurvar",
    "desencurvava": "desencurvar",
    "desencurvavam": "desencurvar",
    "desencurvavas": "desencurvar",
    "desencurve": "desencurvar",
    "desencurvei": "desencurvar",
    "desencurveis": "desencurvar",
    "desencurvem": "desencurvar",
    "desencurvemo": "desencurvar",
    "desencurvemos": "desencurvar",
    "desencurves": "desencurvar",
    "desencurvo": "desencurvar",
    "desencurvou": "desencurvar",
    "desencurvá": "desencurvar",
    "desencurvámo": "desencurvar",
    "desencurvámos": "desencurvar",
    "desencurváramo": "desencurvar",
    "desencurváramos": "desencurvar",
    "desencurvárei": "desencurvar",
    "desencurváreis": "desencurvar",
    "desencurvásseis": "desencurvar",
    "desencurvássemos": "desencurvar",
    "desencurvávamo": "desencurvar",
    "desencurvávamos": "desencurvar",
    "desencurvávei": "desencurvar",
    "desencurváveis": "desencurvar",
    "desendemoninha": "desendemoninhar",
    "desendemoninhada": "desendemoninhar",
    "desendemoninhadas": "desendemoninhar",
    "desendemoninhado": "desendemoninhar",
    "desendemoninhados": "desendemoninhar",
    "desendemoninhai": "desendemoninhar",
    "desendemoninhais": "desendemoninhar",
    "desendemoninham": "desendemoninhar",
    "desendemoninhamo": "desendemoninhar",
    "desendemoninhamos": "desendemoninhar",
    "desendemoninhando": "desendemoninhar",
    "desendemoninhara": "desendemoninhar",
    "desendemoninharam": "desendemoninhar",
    "desendemoninharas": "desendemoninhar",
    "desendemoninharde": "desendemoninhar",
    "desendemoninhardes": "desendemoninhar",
    "desendemoninhare": "desendemoninhar",
    "desendemoninharei": "desendemoninhar",
    "desendemoninhareis": "desendemoninhar",
    "desendemoninharem": "desendemoninhar",
    "desendemoninharemos": "desendemoninhar",
    "desendemoninhares": "desendemoninhar",
    "desendemoninharia": "desendemoninhar",
    "desendemoninhariam": "desendemoninhar",
    "desendemoninharias": "desendemoninhar",
    "desendemoninharmo": "desendemoninhar",
    "desendemoninharmos": "desendemoninhar",
    "desendemoninhará": "desendemoninhar",
    "desendemoninharás": "desendemoninhar",
    "desendemoninharão": "desendemoninhar",
    "desendemoninharíamos": "desendemoninhar",
    "desendemoninharíeis": "desendemoninhar",
    "desendemoninhas": "desendemoninhar",
    "desendemoninhasse": "desendemoninhar",
    "desendemoninhassem": "desendemoninhar",
    "desendemoninhasses": "desendemoninhar",
    "desendemoninhaste": "desendemoninhar",
    "desendemoninhastes": "desendemoninhar",
    "desendemoninhava": "desendemoninhar",
    "desendemoninhavam": "desendemoninhar",
    "desendemoninhavas": "desendemoninhar",
    "desendemoninhe": "desendemoninhar",
    "desendemoninhei": "desendemoninhar",
    "desendemoninheis": "desendemoninhar",
    "desendemoninhem": "desendemoninhar",
    "desendemoninhemo": "desendemoninhar",
    "desendemoninhemos": "desendemoninhar",
    "desendemoninhes": "desendemoninhar",
    "desendemoninho": "desendemoninhar",
    "desendemoninhou": "desendemoninhar",
    "desendemoninhá": "desendemoninhar",
    "desendemoninhámo": "desendemoninhar",
    "desendemoninhámos": "desendemoninhar",
    "desendemoninháramo": "desendemoninhar",
    "desendemoninháramos": "desendemoninhar",
    "desendemoninhárei": "desendemoninhar",
    "desendemoninháreis": "desendemoninhar",
    "desendemoninhásseis": "desendemoninhar",
    "desendemoninhássemos": "desendemoninhar",
    "desendemoninhávamo": "desendemoninhar",
    "desendemoninhávamos": "desendemoninhar",
    "desendemoninhávei": "desendemoninhar",
    "desendemoninháveis": "desendemoninhar",
    "desendeusa": "desendeusar",
    "desendeusada": "desendeusar",
    "desendeusadas": "desendeusar",
    "desendeusado": "desendeusar",
    "desendeusados": "desendeusar",
    "desendeusai": "desendeusar",
    "desendeusais": "desendeusar",
    "desendeusam": "desendeusar",
    "desendeusamo": "desendeusar",
    "desendeusamos": "desendeusar",
    "desendeusando": "desendeusar",
    "desendeusara": "desendeusar",
    "desendeusaram": "desendeusar",
    "desendeusaras": "desendeusar",
    "desendeusarde": "desendeusar",
    "desendeusardes": "desendeusar",
    "desendeusare": "desendeusar",
    "desendeusarei": "desendeusar",
    "desendeusareis": "desendeusar",
    "desendeusarem": "desendeusar",
    "desendeusaremos": "desendeusar",
    "desendeusares": "desendeusar",
    "desendeusaria": "desendeusar",
    "desendeusariam": "desendeusar",
    "desendeusarias": "desendeusar",
    "desendeusarmo": "desendeusar",
    "desendeusarmos": "desendeusar",
    "desendeusará": "desendeusar",
    "desendeusarás": "desendeusar",
    "desendeusarão": "desendeusar",
    "desendeusaríamos": "desendeusar",
    "desendeusaríeis": "desendeusar",
    "desendeusas": "desendeusar",
    "desendeusasse": "desendeusar",
    "desendeusassem": "desendeusar",
    "desendeusasses": "desendeusar",
    "desendeusaste": "desendeusar",
    "desendeusastes": "desendeusar",
    "desendeusava": "desendeusar",
    "desendeusavam": "desendeusar",
    "desendeusavas": "desendeusar",
    "desendeuse": "desendeusar",
    "desendeusei": "desendeusar",
    "desendeuseis": "desendeusar",
    "desendeusem": "desendeusar",
    "desendeusemo": "desendeusar",
    "desendeusemos": "desendeusar",
    "desendeuses": "desendeusar",
    "desendeuso": "desendeusar",
    "desendeusou": "desendeusar",
    "desendeusá": "desendeusar",
    "desendeusámo": "desendeusar",
    "desendeusámos": "desendeusar",
    "desendeusáramo": "desendeusar",
    "desendeusáramos": "desendeusar",
    "desendeusárei": "desendeusar",
    "desendeusáreis": "desendeusar",
    "desendeusásseis": "desendeusar",
    "desendeusássemos": "desendeusar",
    "desendeusávamo": "desendeusar",
    "desendeusávamos": "desendeusar",
    "desendeusávei": "desendeusar",
    "desendeusáveis": "desendeusar",
    "desendivida": "desendividar",
    "desendividada": "desendividar",
    "desendividadas": "desendividar",
    "desendividado": "desendividar",
    "desendividados": "desendividar",
    "desendividai": "desendividar",
    "desendividais": "desendividar",
    "desendividam": "desendividar",
    "desendividamo": "desendividar",
    "desendividamos": "desendividar",
    "desendividando": "desendividar",
    "desendividara": "desendividar",
    "desendividaram": "desendividar",
    "desendividaras": "desendividar",
    "desendividarde": "desendividar",
    "desendividardes": "desendividar",
    "desendividare": "desendividar",
    "desendividarei": "desendividar",
    "desendividareis": "desendividar",
    "desendividarem": "desendividar",
    "desendividaremos": "desendividar",
    "desendividares": "desendividar",
    "desendividaria": "desendividar",
    "desendividariam": "desendividar",
    "desendividarias": "desendividar",
    "desendividarmo": "desendividar",
    "desendividarmos": "desendividar",
    "desendividará": "desendividar",
    "desendividarás": "desendividar",
    "desendividarão": "desendividar",
    "desendividaríamos": "desendividar",
    "desendividaríeis": "desendividar",
    "desendividas": "desendividar",
    "desendividasse": "desendividar",
    "desendividassem": "desendividar",
    "desendividasses": "desendividar",
    "desendividaste": "desendividar",
    "desendividastes": "desendividar",
    "desendividava": "desendividar",
    "desendividavam": "desendividar",
    "desendividavas": "desendividar",
    "desendivide": "desendividar",
    "desendividei": "desendividar",
    "desendivideis": "desendividar",
    "desendividem": "desendividar",
    "desendividemo": "desendividar",
    "desendividemos": "desendividar",
    "desendivides": "desendividar",
    "desendivido": "desendividar",
    "desendividou": "desendividar",
    "desendividá": "desendividar",
    "desendividámo": "desendividar",
    "desendividámos": "desendividar",
    "desendividáramo": "desendividar",
    "desendividáramos": "desendividar",
    "desendividárei": "desendividar",
    "desendividáreis": "desendividar",
    "desendividásseis": "desendividar",
    "desendividássemos": "desendividar",
    "desendividávamo": "desendividar",
    "desendividávamos": "desendividar",
    "desendividávei": "desendividar",
    "desendividáveis": "desendividar",
    "desenegrece": "desenegrecer",
    "desenegrecei": "desenegrecer",
    "desenegreceis": "desenegrecer",
    "desenegrecem": "desenegrecer",
    "desenegrecemo": "desenegrecer",
    "desenegrecemos": "desenegrecer",
    "desenegrecendo": "desenegrecer",
    "desenegrecera": "desenegrecer",
    "desenegreceram": "desenegrecer",
    "desenegreceras": "desenegrecer",
    "desenegrecerde": "desenegrecer",
    "desenegrecerdes": "desenegrecer",
    "desenegrecere": "desenegrecer",
    "desenegrecerei": "desenegrecer",
    "desenegrecereis": "desenegrecer",
    "desenegrecerem": "desenegrecer",
    "desenegreceremos": "desenegrecer",
    "desenegreceres": "desenegrecer",
    "desenegreceria": "desenegrecer",
    "desenegreceriam": "desenegrecer",
    "desenegrecerias": "desenegrecer",
    "desenegrecermo": "desenegrecer",
    "desenegrecermos": "desenegrecer",
    "desenegrecerá": "desenegrecer",
    "desenegrecerás": "desenegrecer",
    "desenegrecerão": "desenegrecer",
    "desenegreceríamos": "desenegrecer",
    "desenegreceríeis": "desenegrecer",
    "desenegreces": "desenegrecer",
    "desenegrecesse": "desenegrecer",
    "desenegrecessem": "desenegrecer",
    "desenegrecesses": "desenegrecer",
    "desenegreceste": "desenegrecer",
    "desenegrecestes": "desenegrecer",
    "desenegreceu": "desenegrecer",
    "desenegreci": "desenegrecer",
    "desenegrecia": "desenegrecer",
    "desenegreciam": "desenegrecer",
    "desenegrecias": "desenegrecer",
    "desenegrecida": "desenegrecido",
    "desenegrecidas": "desenegrecido",
    "desenegrecido": "desenegrecer",
    "desenegrecidos": "desenegrecido",
    "desenegrecê": "desenegrecer",
    "desenegrecêramo": "desenegrecer",
    "desenegrecêramos": "desenegrecer",
    "desenegrecêrei": "desenegrecer",
    "desenegrecêreis": "desenegrecer",
    "desenegrecêsseis": "desenegrecer",
    "desenegrecêssemos": "desenegrecer",
    "desenegrecíamo": "desenegrecer",
    "desenegrecíamos": "desenegrecer",
    "desenegrecíei": "desenegrecer",
    "desenegrecíeis": "desenegrecer",
    "desenegreça": "desenegrecer",
    "desenegreçais": "desenegrecer",
    "desenegreçam": "desenegrecer",
    "desenegreçamo": "desenegrecer",
    "desenegreçamos": "desenegrecer",
    "desenegreças": "desenegrecer",
    "desenegreço": "desenegrecer",
    "desenerva": "desenervar",
    "desenervada": "desenervar",
    "desenervadas": "desenervar",
    "desenervado": "desenervar",
    "desenervados": "desenervar",
    "desenervai": "desenervar",
    "desenervais": "desenervar",
    "desenervam": "desenervar",
    "desenervamo": "desenervar",
    "desenervamos": "desenervar",
    "desenervando": "desenervar",
    "desenervara": "desenervar",
    "desenervaram": "desenervar",
    "desenervaras": "desenervar",
    "desenervarde": "desenervar",
    "desenervardes": "desenervar",
    "desenervare": "desenervar",
    "desenervarei": "desenervar",
    "desenervareis": "desenervar",
    "desenervarem": "desenervar",
    "desenervaremos": "desenervar",
    "desenervares": "desenervar",
    "desenervaria": "desenervar",
    "desenervariam": "desenervar",
    "desenervarias": "desenervar",
    "desenervarmo": "desenervar",
    "desenervarmos": "desenervar",
    "desenervará": "desenervar",
    "desenervarás": "desenervar",
    "desenervarão": "desenervar",
    "desenervaríamos": "desenervar",
    "desenervaríeis": "desenervar",
    "desenervas": "desenervar",
    "desenervasse": "desenervar",
    "desenervassem": "desenervar",
    "desenervasses": "desenervar",
    "desenervaste": "desenervar",
    "desenervastes": "desenervar",
    "desenervava": "desenervar",
    "desenervavam": "desenervar",
    "desenervavas": "desenervar",
    "desenervações": "desenervação",
    "desenerve": "desenervar",
    "desenervei": "desenervar",
    "desenerveis": "desenervar",
    "desenervem": "desenervar",
    "desenervemo": "desenervar",
    "desenervemos": "desenervar",
    "desenerves": "desenervar",
    "desenervo": "desenervar",
    "desenervou": "desenervar",
    "desenervá": "desenervar",
    "desenervámo": "desenervar",
    "desenervámos": "desenervar",
    "desenerváramo": "desenervar",
    "desenerváramos": "desenervar",
    "desenervárei": "desenervar",
    "desenerváreis": "desenervar",
    "desenervásseis": "desenervar",
    "desenervássemos": "desenervar",
    "desenervávamo": "desenervar",
    "desenervávamos": "desenervar",
    "desenervávei": "desenervar",
    "desenerváveis": "desenervar",
    "desenevoa": "desenevoar",
    "desenevoada": "desenevoar",
    "desenevoadas": "desenevoar",
    "desenevoado": "desenevoar",
    "desenevoados": "desenevoar",
    "desenevoai": "desenevoar",
    "desenevoais": "desenevoar",
    "desenevoam": "desenevoar",
    "desenevoamo": "desenevoar",
    "desenevoamos": "desenevoar",
    "desenevoando": "desenevoar",
    "desenevoara": "desenevoar",
    "desenevoaram": "desenevoar",
    "desenevoaras": "desenevoar",
    "desenevoarde": "desenevoar",
    "desenevoardes": "desenevoar",
    "desenevoare": "desenevoar",
    "desenevoarei": "desenevoar",
    "desenevoareis": "desenevoar",
    "desenevoarem": "desenevoar",
    "desenevoaremos": "desenevoar",
    "desenevoares": "desenevoar",
    "desenevoaria": "desenevoar",
    "desenevoariam": "desenevoar",
    "desenevoarias": "desenevoar",
    "desenevoarmo": "desenevoar",
    "desenevoarmos": "desenevoar",
    "desenevoará": "desenevoar",
    "desenevoarás": "desenevoar",
    "desenevoarão": "desenevoar",
    "desenevoaríamos": "desenevoar",
    "desenevoaríeis": "desenevoar",
    "desenevoas": "desenevoar",
    "desenevoasse": "desenevoar",
    "desenevoassem": "desenevoar",
    "desenevoasses": "desenevoar",
    "desenevoaste": "desenevoar",
    "desenevoastes": "desenevoar",
    "desenevoava": "desenevoar",
    "desenevoavam": "desenevoar",
    "desenevoavas": "desenevoar",
    "desenevoe": "desenevoar",
    "desenevoei": "desenevoar",
    "desenevoeis": "desenevoar",
    "desenevoem": "desenevoar",
    "desenevoemo": "desenevoar",
    "desenevoemos": "desenevoar",
    "desenevoes": "desenevoar",
    "desenevoo": "desenevoar",
    "desenevoou": "desenevoar",
    "desenevoá": "desenevoar",
    "desenevoámo": "desenevoar",
    "desenevoámos": "desenevoar",
    "desenevoáramo": "desenevoar",
    "desenevoáramos": "desenevoar",
    "desenevoárei": "desenevoar",
    "desenevoáreis": "desenevoar",
    "desenevoásseis": "desenevoar",
    "desenevoássemos": "desenevoar",
    "desenevoávamo": "desenevoar",
    "desenevoávamos": "desenevoar",
    "desenevoávei": "desenevoar",
    "desenevoáveis": "desenevoar",
    "desenfada": "desenfadar",
    "desenfadada": "desenfadar",
    "desenfadadas": "desenfadar",
    "desenfadadiça": "desenfadadiço",
    "desenfadadiças": "desenfadadiço",
    "desenfadadiços": "desenfadadiço",
    "desenfadado": "desenfadar",
    "desenfadados": "desenfadar",
    "desenfadai": "desenfadar",
    "desenfadais": "desenfadar",
    "desenfadam": "desenfadar",
    "desenfadamentos": "desenfadamento",
    "desenfadamo": "desenfadar",
    "desenfadamos": "desenfadar",
    "desenfadando": "desenfadar",
    "desenfadara": "desenfadar",
    "desenfadaram": "desenfadar",
    "desenfadaras": "desenfadar",
    "desenfadarde": "desenfadar",
    "desenfadardes": "desenfadar",
    "desenfadare": "desenfadar",
    "desenfadarei": "desenfadar",
    "desenfadareis": "desenfadar",
    "desenfadarem": "desenfadar",
    "desenfadaremos": "desenfadar",
    "desenfadares": "desenfadar",
    "desenfadaria": "desenfadar",
    "desenfadariam": "desenfadar",
    "desenfadarias": "desenfadar",
    "desenfadarmo": "desenfadar",
    "desenfadarmos": "desenfadar",
    "desenfadará": "desenfadar",
    "desenfadarás": "desenfadar",
    "desenfadarão": "desenfadar",
    "desenfadaríamos": "desenfadar",
    "desenfadaríeis": "desenfadar",
    "desenfadas": "desenfadar",
    "desenfadasse": "desenfadar",
    "desenfadassem": "desenfadar",
    "desenfadasses": "desenfadar",
    "desenfadaste": "desenfadar",
    "desenfadastes": "desenfadar",
    "desenfadava": "desenfadar",
    "desenfadavam": "desenfadar",
    "desenfadavas": "desenfadar",
    "desenfade": "desenfadar",
    "desenfadei": "desenfadar",
    "desenfadeis": "desenfadar",
    "desenfadem": "desenfadar",
    "desenfademo": "desenfadar",
    "desenfademos": "desenfadar",
    "desenfades": "desenfadar",
    "desenfado": "desenfadar",
    "desenfados": "desenfado",
    "desenfadou": "desenfadar",
    "desenfadá": "desenfadar",
    "desenfadámo": "desenfadar",
    "desenfadámos": "desenfadar",
    "desenfadáramo": "desenfadar",
    "desenfadáramos": "desenfadar",
    "desenfadárei": "desenfadar",
    "desenfadáreis": "desenfadar",
    "desenfadásseis": "desenfadar",
    "desenfadássemos": "desenfadar",
    "desenfadávamo": "desenfadar",
    "desenfadávamos": "desenfadar",
    "desenfadávei": "desenfadar",
    "desenfadáveis": "desenfadar",
    "desenfaixa": "desenfaixar",
    "desenfaixada": "desenfaixar",
    "desenfaixadas": "desenfaixar",
    "desenfaixado": "desenfaixar",
    "desenfaixados": "desenfaixar",
    "desenfaixai": "desenfaixar",
    "desenfaixais": "desenfaixar",
    "desenfaixam": "desenfaixar",
    "desenfaixamo": "desenfaixar",
    "desenfaixamos": "desenfaixar",
    "desenfaixando": "desenfaixar",
    "desenfaixara": "desenfaixar",
    "desenfaixaram": "desenfaixar",
    "desenfaixaras": "desenfaixar",
    "desenfaixarde": "desenfaixar",
    "desenfaixardes": "desenfaixar",
    "desenfaixare": "desenfaixar",
    "desenfaixarei": "desenfaixar",
    "desenfaixareis": "desenfaixar",
    "desenfaixarem": "desenfaixar",
    "desenfaixaremos": "desenfaixar",
    "desenfaixares": "desenfaixar",
    "desenfaixaria": "desenfaixar",
    "desenfaixariam": "desenfaixar",
    "desenfaixarias": "desenfaixar",
    "desenfaixarmo": "desenfaixar",
    "desenfaixarmos": "desenfaixar",
    "desenfaixará": "desenfaixar",
    "desenfaixarás": "desenfaixar",
    "desenfaixarão": "desenfaixar",
    "desenfaixaríamos": "desenfaixar",
    "desenfaixaríeis": "desenfaixar",
    "desenfaixas": "desenfaixar",
    "desenfaixasse": "desenfaixar",
    "desenfaixassem": "desenfaixar",
    "desenfaixasses": "desenfaixar",
    "desenfaixaste": "desenfaixar",
    "desenfaixastes": "desenfaixar",
    "desenfaixava": "desenfaixar",
    "desenfaixavam": "desenfaixar",
    "desenfaixavas": "desenfaixar",
    "desenfaixe": "desenfaixar",
    "desenfaixei": "desenfaixar",
    "desenfaixeis": "desenfaixar",
    "desenfaixem": "desenfaixar",
    "desenfaixemo": "desenfaixar",
    "desenfaixemos": "desenfaixar",
    "desenfaixes": "desenfaixar",
    "desenfaixo": "desenfaixar",
    "desenfaixou": "desenfaixar",
    "desenfaixá": "desenfaixar",
    "desenfaixámo": "desenfaixar",
    "desenfaixámos": "desenfaixar",
    "desenfaixáramo": "desenfaixar",
    "desenfaixáramos": "desenfaixar",
    "desenfaixárei": "desenfaixar",
    "desenfaixáreis": "desenfaixar",
    "desenfaixásseis": "desenfaixar",
    "desenfaixássemos": "desenfaixar",
    "desenfaixávamo": "desenfaixar",
    "desenfaixávamos": "desenfaixar",
    "desenfaixávei": "desenfaixar",
    "desenfaixáveis": "desenfaixar",
    "desenfarda": "desenfardar",
    "desenfardada": "desenfardar",
    "desenfardadas": "desenfardar",
    "desenfardado": "desenfardar",
    "desenfardados": "desenfardar",
    "desenfardai": "desenfardar",
    "desenfardais": "desenfardar",
    "desenfardam": "desenfardar",
    "desenfardamo": "desenfardar",
    "desenfardamos": "desenfardar",
    "desenfardando": "desenfardar",
    "desenfardara": "desenfardar",
    "desenfardaram": "desenfardar",
    "desenfardaras": "desenfardar",
    "desenfardarde": "desenfardar",
    "desenfardardes": "desenfardar",
    "desenfardare": "desenfardar",
    "desenfardarei": "desenfardar",
    "desenfardareis": "desenfardar",
    "desenfardarem": "desenfardar",
    "desenfardaremos": "desenfardar",
    "desenfardares": "desenfardar",
    "desenfardaria": "desenfardar",
    "desenfardariam": "desenfardar",
    "desenfardarias": "desenfardar",
    "desenfardarmo": "desenfardar",
    "desenfardarmos": "desenfardar",
    "desenfardará": "desenfardar",
    "desenfardarás": "desenfardar",
    "desenfardarão": "desenfardar",
    "desenfardaríamos": "desenfardar",
    "desenfardaríeis": "desenfardar",
    "desenfardas": "desenfardar",
    "desenfardasse": "desenfardar",
    "desenfardassem": "desenfardar",
    "desenfardasses": "desenfardar",
    "desenfardaste": "desenfardar",
    "desenfardastes": "desenfardar",
    "desenfardava": "desenfardar",
    "desenfardavam": "desenfardar",
    "desenfardavas": "desenfardar",
    "desenfarde": "desenfardar",
    "desenfardei": "desenfardar",
    "desenfardeis": "desenfardar",
    "desenfardem": "desenfardar",
    "desenfardemo": "desenfardar",
    "desenfardemos": "desenfardar",
    "desenfardes": "desenfardar",
    "desenfardo": "desenfardar",
    "desenfardou": "desenfardar",
    "desenfardá": "desenfardar",
    "desenfardámo": "desenfardar",
    "desenfardámos": "desenfardar",
    "desenfardáramo": "desenfardar",
    "desenfardáramos": "desenfardar",
    "desenfardárei": "desenfardar",
    "desenfardáreis": "desenfardar",
    "desenfardásseis": "desenfardar",
    "desenfardássemos": "desenfardar",
    "desenfardávamo": "desenfardar",
    "desenfardávamos": "desenfardar",
    "desenfardávei": "desenfardar",
    "desenfardáveis": "desenfardar",
    "desenfarpela": "desenfarpelar",
    "desenfarpelada": "desenfarpelar",
    "desenfarpeladas": "desenfarpelar",
    "desenfarpelado": "desenfarpelar",
    "desenfarpelados": "desenfarpelar",
    "desenfarpelai": "desenfarpelar",
    "desenfarpelais": "desenfarpelar",
    "desenfarpelam": "desenfarpelar",
    "desenfarpelamo": "desenfarpelar",
    "desenfarpelamos": "desenfarpelar",
    "desenfarpelando": "desenfarpelar",
    "desenfarpelara": "desenfarpelar",
    "desenfarpelaram": "desenfarpelar",
    "desenfarpelaras": "desenfarpelar",
    "desenfarpelarde": "desenfarpelar",
    "desenfarpelardes": "desenfarpelar",
    "desenfarpelare": "desenfarpelar",
    "desenfarpelarei": "desenfarpelar",
    "desenfarpelareis": "desenfarpelar",
    "desenfarpelarem": "desenfarpelar",
    "desenfarpelaremos": "desenfarpelar",
    "desenfarpelares": "desenfarpelar",
    "desenfarpelaria": "desenfarpelar",
    "desenfarpelariam": "desenfarpelar",
    "desenfarpelarias": "desenfarpelar",
    "desenfarpelarmo": "desenfarpelar",
    "desenfarpelarmos": "desenfarpelar",
    "desenfarpelará": "desenfarpelar",
    "desenfarpelarás": "desenfarpelar",
    "desenfarpelarão": "desenfarpelar",
    "desenfarpelaríamos": "desenfarpelar",
    "desenfarpelaríeis": "desenfarpelar",
    "desenfarpelas": "desenfarpelar",
    "desenfarpelasse": "desenfarpelar",
    "desenfarpelassem": "desenfarpelar",
    "desenfarpelasses": "desenfarpelar",
    "desenfarpelaste": "desenfarpelar",
    "desenfarpelastes": "desenfarpelar",
    "desenfarpelava": "desenfarpelar",
    "desenfarpelavam": "desenfarpelar",
    "desenfarpelavas": "desenfarpelar",
    "desenfarpele": "desenfarpelar",
    "desenfarpelei": "desenfarpelar",
    "desenfarpeleis": "desenfarpelar",
    "desenfarpelem": "desenfarpelar",
    "desenfarpelemo": "desenfarpelar",
    "desenfarpelemos": "desenfarpelar",
    "desenfarpeles": "desenfarpelar",
    "desenfarpelo": "desenfarpelar",
    "desenfarpelou": "desenfarpelar",
    "desenfarpelá": "desenfarpelar",
    "desenfarpelámo": "desenfarpelar",
    "desenfarpelámos": "desenfarpelar",
    "desenfarpeláramo": "desenfarpelar",
    "desenfarpeláramos": "desenfarpelar",
    "desenfarpelárei": "desenfarpelar",
    "desenfarpeláreis": "desenfarpelar",
    "desenfarpelásseis": "desenfarpelar",
    "desenfarpelássemos": "desenfarpelar",
    "desenfarpelávamo": "desenfarpelar",
    "desenfarpelávamos": "desenfarpelar",
    "desenfarpelávei": "desenfarpelar",
    "desenfarpeláveis": "desenfarpelar",
    "desenfarrusca": "desenfarruscar",
    "desenfarruscada": "desenfarruscar",
    "desenfarruscadas": "desenfarruscar",
    "desenfarruscado": "desenfarruscar",
    "desenfarruscados": "desenfarruscar",
    "desenfarruscai": "desenfarruscar",
    "desenfarruscais": "desenfarruscar",
    "desenfarruscam": "desenfarruscar",
    "desenfarruscamo": "desenfarruscar",
    "desenfarruscamos": "desenfarruscar",
    "desenfarruscando": "desenfarruscar",
    "desenfarruscara": "desenfarruscar",
    "desenfarruscaram": "desenfarruscar",
    "desenfarruscaras": "desenfarruscar",
    "desenfarruscarde": "desenfarruscar",
    "desenfarruscardes": "desenfarruscar",
    "desenfarruscare": "desenfarruscar",
    "desenfarruscarei": "desenfarruscar",
    "desenfarruscareis": "desenfarruscar",
    "desenfarruscarem": "desenfarruscar",
    "desenfarruscaremos": "desenfarruscar",
    "desenfarruscares": "desenfarruscar",
    "desenfarruscaria": "desenfarruscar",
    "desenfarruscariam": "desenfarruscar",
    "desenfarruscarias": "desenfarruscar",
    "desenfarruscarmo": "desenfarruscar",
    "desenfarruscarmos": "desenfarruscar",
    "desenfarruscará": "desenfarruscar",
    "desenfarruscarás": "desenfarruscar",
    "desenfarruscarão": "desenfarruscar",
    "desenfarruscaríamos": "desenfarruscar",
    "desenfarruscaríeis": "desenfarruscar",
    "desenfarruscas": "desenfarruscar",
    "desenfarruscasse": "desenfarruscar",
    "desenfarruscassem": "desenfarruscar",
    "desenfarruscasses": "desenfarruscar",
    "desenfarruscaste": "desenfarruscar",
    "desenfarruscastes": "desenfarruscar",
    "desenfarruscava": "desenfarruscar",
    "desenfarruscavam": "desenfarruscar",
    "desenfarruscavas": "desenfarruscar",
    "desenfarrusco": "desenfarruscar",
    "desenfarruscou": "desenfarruscar",
    "desenfarruscá": "desenfarruscar",
    "desenfarruscámo": "desenfarruscar",
    "desenfarruscámos": "desenfarruscar",
    "desenfarruscáramo": "desenfarruscar",
    "desenfarruscáramos": "desenfarruscar",
    "desenfarruscárei": "desenfarruscar",
    "desenfarruscáreis": "desenfarruscar",
    "desenfarruscásseis": "desenfarruscar",
    "desenfarruscássemos": "desenfarruscar",
    "desenfarruscávamo": "desenfarruscar",
    "desenfarruscávamos": "desenfarruscar",
    "desenfarruscávei": "desenfarruscar",
    "desenfarruscáveis": "desenfarruscar",
    "desenfarrusque": "desenfarruscar",
    "desenfarrusquei": "desenfarruscar",
    "desenfarrusqueis": "desenfarruscar",
    "desenfarrusquem": "desenfarruscar",
    "desenfarrusquemo": "desenfarruscar",
    "desenfarrusquemos": "desenfarruscar",
    "desenfarrusques": "desenfarruscar",
    "desenfarta": "desenfartar",
    "desenfartada": "desenfartar",
    "desenfartadas": "desenfartar",
    "desenfartado": "desenfartar",
    "desenfartados": "desenfartar",
    "desenfartai": "desenfartar",
    "desenfartais": "desenfartar",
    "desenfartam": "desenfartar",
    "desenfartamentos": "desenfartamento",
    "desenfartamo": "desenfartar",
    "desenfartamos": "desenfartar",
    "desenfartando": "desenfartar",
    "desenfartara": "desenfartar",
    "desenfartaram": "desenfartar",
    "desenfartaras": "desenfartar",
    "desenfartarde": "desenfartar",
    "desenfartardes": "desenfartar",
    "desenfartare": "desenfartar",
    "desenfartarei": "desenfartar",
    "desenfartareis": "desenfartar",
    "desenfartarem": "desenfartar",
    "desenfartaremos": "desenfartar",
    "desenfartares": "desenfartar",
    "desenfartaria": "desenfartar",
    "desenfartariam": "desenfartar",
    "desenfartarias": "desenfartar",
    "desenfartarmo": "desenfartar",
    "desenfartarmos": "desenfartar",
    "desenfartará": "desenfartar",
    "desenfartarás": "desenfartar",
    "desenfartarão": "desenfartar",
    "desenfartaríamos": "desenfartar",
    "desenfartaríeis": "desenfartar",
    "desenfartas": "desenfartar",
    "desenfartasse": "desenfartar",
    "desenfartassem": "desenfartar",
    "desenfartasses": "desenfartar",
    "desenfartaste": "desenfartar",
    "desenfartastes": "desenfartar",
    "desenfartava": "desenfartar",
    "desenfartavam": "desenfartar",
    "desenfartavas": "desenfartar",
    "desenfarte": "desenfartar",
    "desenfartei": "desenfartar",
    "desenfarteis": "desenfartar",
    "desenfartem": "desenfartar",
    "desenfartemo": "desenfartar",
    "desenfartemos": "desenfartar",
    "desenfartes": "desenfartar",
    "desenfarto": "desenfartar",
    "desenfartou": "desenfartar",
    "desenfartá": "desenfartar",
    "desenfartámo": "desenfartar",
    "desenfartámos": "desenfartar",
    "desenfartáramo": "desenfartar",
    "desenfartáramos": "desenfartar",
    "desenfartárei": "desenfartar",
    "desenfartáreis": "desenfartar",
    "desenfartásseis": "desenfartar",
    "desenfartássemos": "desenfartar",
    "desenfartávamo": "desenfartar",
    "desenfartávamos": "desenfartar",
    "desenfartávei": "desenfartar",
    "desenfartáveis": "desenfartar",
    "desenfastia": "desenfastiar",
    "desenfastiada": "desenfastiar",
    "desenfastiadas": "desenfastiar",
    "desenfastiadiça": "desenfastiadiço",
    "desenfastiadiças": "desenfastiadiço",
    "desenfastiadiços": "desenfastiadiço",
    "desenfastiado": "desenfastiar",
    "desenfastiadora": "desenfastiador",
    "desenfastiadoras": "desenfastiador",
    "desenfastiadores": "desenfastiador",
    "desenfastiados": "desenfastiar",
    "desenfastiai": "desenfastiar",
    "desenfastiais": "desenfastiar",
    "desenfastiam": "desenfastiar",
    "desenfastiamo": "desenfastiar",
    "desenfastiamos": "desenfastiar",
    "desenfastiando": "desenfastiar",
    "desenfastiara": "desenfastiar",
    "desenfastiaram": "desenfastiar",
    "desenfastiaras": "desenfastiar",
    "desenfastiarde": "desenfastiar",
    "desenfastiardes": "desenfastiar",
    "desenfastiare": "desenfastiar",
    "desenfastiarei": "desenfastiar",
    "desenfastiareis": "desenfastiar",
    "desenfastiarem": "desenfastiar",
    "desenfastiaremos": "desenfastiar",
    "desenfastiares": "desenfastiar",
    "desenfastiaria": "desenfastiar",
    "desenfastiariam": "desenfastiar",
    "desenfastiarias": "desenfastiar",
    "desenfastiarmo": "desenfastiar",
    "desenfastiarmos": "desenfastiar",
    "desenfastiará": "desenfastiar",
    "desenfastiarás": "desenfastiar",
    "desenfastiarão": "desenfastiar",
    "desenfastiaríamos": "desenfastiar",
    "desenfastiaríeis": "desenfastiar",
    "desenfastias": "desenfastiar",
    "desenfastiasse": "desenfastiar",
    "desenfastiassem": "desenfastiar",
    "desenfastiasses": "desenfastiar",
    "desenfastiaste": "desenfastiar",
    "desenfastiastes": "desenfastiar",
    "desenfastiava": "desenfastiar",
    "desenfastiavam": "desenfastiar",
    "desenfastiavas": "desenfastiar",
    "desenfastie": "desenfastiar",
    "desenfastiei": "desenfastiar",
    "desenfastieis": "desenfastiar",
    "desenfastiem": "desenfastiar",
    "desenfastiemo": "desenfastiar",
    "desenfastiemos": "desenfastiar",
    "desenfasties": "desenfastiar",
    "desenfastio": "desenfastiar",
    "desenfastiosa": "desenfastioso",
    "desenfastiosas": "desenfastioso",
    "desenfastiosos": "desenfastioso",
    "desenfastiou": "desenfastiar",
    "desenfastiá": "desenfastiar",
    "desenfastiámo": "desenfastiar",
    "desenfastiámos": "desenfastiar",
    "desenfastiáramo": "desenfastiar",
    "desenfastiáramos": "desenfastiar",
    "desenfastiárei": "desenfastiar",
    "desenfastiáreis": "desenfastiar",
    "desenfastiásseis": "desenfastiar",
    "desenfastiássemos": "desenfastiar",
    "desenfastiávamo": "desenfastiar",
    "desenfastiávamos": "desenfastiar",
    "desenfastiávei": "desenfastiar",
    "desenfastiáveis": "desenfastiar",
    "desenfeita": "desenfeitar",
    "desenfeitada": "desenfeitar",
    "desenfeitadas": "desenfeitar",
    "desenfeitado": "desenfeitar",
    "desenfeitados": "desenfeitar",
    "desenfeitai": "desenfeitar",
    "desenfeitais": "desenfeitar",
    "desenfeitam": "desenfeitar",
    "desenfeitamo": "desenfeitar",
    "desenfeitamos": "desenfeitar",
    "desenfeitando": "desenfeitar",
    "desenfeitara": "desenfeitar",
    "desenfeitaram": "desenfeitar",
    "desenfeitaras": "desenfeitar",
    "desenfeitarde": "desenfeitar",
    "desenfeitardes": "desenfeitar",
    "desenfeitare": "desenfeitar",
    "desenfeitarei": "desenfeitar",
    "desenfeitareis": "desenfeitar",
    "desenfeitarem": "desenfeitar",
    "desenfeitaremos": "desenfeitar",
    "desenfeitares": "desenfeitar",
    "desenfeitaria": "desenfeitar",
    "desenfeitariam": "desenfeitar",
    "desenfeitarias": "desenfeitar",
    "desenfeitarmo": "desenfeitar",
    "desenfeitarmos": "desenfeitar",
    "desenfeitará": "desenfeitar",
    "desenfeitarás": "desenfeitar",
    "desenfeitarão": "desenfeitar",
    "desenfeitaríamos": "desenfeitar",
    "desenfeitaríeis": "desenfeitar",
    "desenfeitas": "desenfeitar",
    "desenfeitasse": "desenfeitar",
    "desenfeitassem": "desenfeitar",
    "desenfeitasses": "desenfeitar",
    "desenfeitaste": "desenfeitar",
    "desenfeitastes": "desenfeitar",
    "desenfeitava": "desenfeitar",
    "desenfeitavam": "desenfeitar",
    "desenfeitavas": "desenfeitar",
    "desenfeite": "desenfeitar",
    "desenfeitei": "desenfeitar",
    "desenfeiteis": "desenfeitar",
    "desenfeitem": "desenfeitar",
    "desenfeitemo": "desenfeitar",
    "desenfeitemos": "desenfeitar",
    "desenfeites": "desenfeite",
    "desenfeitice": "desenfeitiçar",
    "desenfeiticei": "desenfeitiçar",
    "desenfeiticeis": "desenfeitiçar",
    "desenfeiticem": "desenfeitiçar",
    "desenfeiticemo": "desenfeitiçar",
    "desenfeiticemos": "desenfeitiçar",
    "desenfeitices": "desenfeitiçar",
    "desenfeitiça": "desenfeitiçar",
    "desenfeitiçada": "desenfeitiçar",
    "desenfeitiçadas": "desenfeitiçar",
    "desenfeitiçado": "desenfeitiçar",
    "desenfeitiçados": "desenfeitiçar",
    "desenfeitiçai": "desenfeitiçar",
    "desenfeitiçais": "desenfeitiçar",
    "desenfeitiçam": "desenfeitiçar",
    "desenfeitiçamo": "desenfeitiçar",
    "desenfeitiçamos": "desenfeitiçar",
    "desenfeitiçando": "desenfeitiçar",
    "desenfeitiçara": "desenfeitiçar",
    "desenfeitiçaram": "desenfeitiçar",
    "desenfeitiçaras": "desenfeitiçar",
    "desenfeitiçarde": "desenfeitiçar",
    "desenfeitiçardes": "desenfeitiçar",
    "desenfeitiçare": "desenfeitiçar",
    "desenfeitiçarei": "desenfeitiçar",
    "desenfeitiçareis": "desenfeitiçar",
    "desenfeitiçarem": "desenfeitiçar",
    "desenfeitiçaremos": "desenfeitiçar",
    "desenfeitiçares": "desenfeitiçar",
    "desenfeitiçaria": "desenfeitiçar",
    "desenfeitiçariam": "desenfeitiçar",
    "desenfeitiçarias": "desenfeitiçar",
    "desenfeitiçarmo": "desenfeitiçar",
    "desenfeitiçarmos": "desenfeitiçar",
    "desenfeitiçará": "desenfeitiçar",
    "desenfeitiçarás": "desenfeitiçar",
    "desenfeitiçarão": "desenfeitiçar",
    "desenfeitiçaríamos": "desenfeitiçar",
    "desenfeitiçaríeis": "desenfeitiçar",
    "desenfeitiças": "desenfeitiçar",
    "desenfeitiçasse": "desenfeitiçar",
    "desenfeitiçassem": "desenfeitiçar",
    "desenfeitiçasses": "desenfeitiçar",
    "desenfeitiçaste": "desenfeitiçar",
    "desenfeitiçastes": "desenfeitiçar",
    "desenfeitiçava": "desenfeitiçar",
    "desenfeitiçavam": "desenfeitiçar",
    "desenfeitiçavas": "desenfeitiçar",
    "desenfeitiço": "desenfeitiçar",
    "desenfeitiçou": "desenfeitiçar",
    "desenfeitiçá": "desenfeitiçar",
    "desenfeitiçámo": "desenfeitiçar",
    "desenfeitiçámos": "desenfeitiçar",
    "desenfeitiçáramo": "desenfeitiçar",
    "desenfeitiçáramos": "desenfeitiçar",
    "desenfeitiçárei": "desenfeitiçar",
    "desenfeitiçáreis": "desenfeitiçar",
    "desenfeitiçásseis": "desenfeitiçar",
    "desenfeitiçássemos": "desenfeitiçar",
    "desenfeitiçávamo": "desenfeitiçar",
    "desenfeitiçávamos": "desenfeitiçar",
    "desenfeitiçávei": "desenfeitiçar",
    "desenfeitiçáveis": "desenfeitiçar",
    "desenfeito": "desenfeitar",
    "desenfeitou": "desenfeitar",
    "desenfeitá": "desenfeitar",
    "desenfeitámo": "desenfeitar",
    "desenfeitámos": "desenfeitar",
    "desenfeitáramo": "desenfeitar",
    "desenfeitáramos": "desenfeitar",
    "desenfeitárei": "desenfeitar",
    "desenfeitáreis": "desenfeitar",
    "desenfeitásseis": "desenfeitar",
    "desenfeitássemos": "desenfeitar",
    "desenfeitávamo": "desenfeitar",
    "desenfeitávamos": "desenfeitar",
    "desenfeitávei": "desenfeitar",
    "desenfeitáveis": "desenfeitar",
    "desenfeixa": "desenfeixar",
    "desenfeixada": "desenfeixar",
    "desenfeixadas": "desenfeixar",
    "desenfeixado": "desenfeixar",
    "desenfeixados": "desenfeixar",
    "desenfeixai": "desenfeixar",
    "desenfeixais": "desenfeixar",
    "desenfeixam": "desenfeixar",
    "desenfeixamo": "desenfeixar",
    "desenfeixamos": "desenfeixar",
    "desenfeixando": "desenfeixar",
    "desenfeixara": "desenfeixar",
    "desenfeixaram": "desenfeixar",
    "desenfeixaras": "desenfeixar",
    "desenfeixarde": "desenfeixar",
    "desenfeixardes": "desenfeixar",
    "desenfeixare": "desenfeixar",
    "desenfeixarei": "desenfeixar",
    "desenfeixareis": "desenfeixar",
    "desenfeixarem": "desenfeixar",
    "desenfeixaremos": "desenfeixar",
    "desenfeixares": "desenfeixar",
    "desenfeixaria": "desenfeixar",
    "desenfeixariam": "desenfeixar",
    "desenfeixarias": "desenfeixar",
    "desenfeixarmo": "desenfeixar",
    "desenfeixarmos": "desenfeixar",
    "desenfeixará": "desenfeixar",
    "desenfeixarás": "desenfeixar",
    "desenfeixarão": "desenfeixar",
    "desenfeixaríamos": "desenfeixar",
    "desenfeixaríeis": "desenfeixar",
    "desenfeixas": "desenfeixar",
    "desenfeixasse": "desenfeixar",
    "desenfeixassem": "desenfeixar",
    "desenfeixasses": "desenfeixar",
    "desenfeixaste": "desenfeixar",
    "desenfeixastes": "desenfeixar",
    "desenfeixava": "desenfeixar",
    "desenfeixavam": "desenfeixar",
    "desenfeixavas": "desenfeixar",
    "desenfeixe": "desenfeixar",
    "desenfeixei": "desenfeixar",
    "desenfeixeis": "desenfeixar",
    "desenfeixem": "desenfeixar",
    "desenfeixemo": "desenfeixar",
    "desenfeixemos": "desenfeixar",
    "desenfeixes": "desenfeixar",
    "desenfeixo": "desenfeixar",
    "desenfeixou": "desenfeixar",
    "desenfeixá": "desenfeixar",
    "desenfeixámo": "desenfeixar",
    "desenfeixámos": "desenfeixar",
    "desenfeixáramo": "desenfeixar",
    "desenfeixáramos": "desenfeixar",
    "desenfeixárei": "desenfeixar",
    "desenfeixáreis": "desenfeixar",
    "desenfeixásseis": "desenfeixar",
    "desenfeixássemos": "desenfeixar",
    "desenfeixávamo": "desenfeixar",
    "desenfeixávamos": "desenfeixar",
    "desenfeixávei": "desenfeixar",
    "desenfeixáveis": "desenfeixar",
    "desenferma": "desenfermar",
    "desenfermada": "desenfermar",
    "desenfermadas": "desenfermar",
    "desenfermado": "desenfermar",
    "desenfermados": "desenfermar",
    "desenfermai": "desenfermar",
    "desenfermais": "desenfermar",
    "desenfermam": "desenfermar",
    "desenfermamo": "desenfermar",
    "desenfermamos": "desenfermar",
    "desenfermando": "desenfermar",
    "desenfermara": "desenfermar",
    "desenfermaram": "desenfermar",
    "desenfermaras": "desenfermar",
    "desenfermardes": "desenfermar",
    "desenfermarei": "desenfermar",
    "desenfermareis": "desenfermar",
    "desenfermarem": "desenfermar",
    "desenfermaremos": "desenfermar",
    "desenfermares": "desenfermar",
    "desenfermaria": "desenfermar",
    "desenfermariam": "desenfermar",
    "desenfermarias": "desenfermar",
    "desenfermarmo": "desenfermar",
    "desenfermarmos": "desenfermar",
    "desenfermará": "desenfermar",
    "desenfermarás": "desenfermar",
    "desenfermarão": "desenfermar",
    "desenfermaríamos": "desenfermar",
    "desenfermaríeis": "desenfermar",
    "desenfermas": "desenfermar",
    "desenfermasse": "desenfermar",
    "desenfermassem": "desenfermar",
    "desenfermasses": "desenfermar",
    "desenfermaste": "desenfermar",
    "desenfermastes": "desenfermar",
    "desenfermava": "desenfermar",
    "desenfermavam": "desenfermar",
    "desenfermavas": "desenfermar",
    "desenferme": "desenfermar",
    "desenfermei": "desenfermar",
    "desenfermeis": "desenfermar",
    "desenfermem": "desenfermar",
    "desenfermemo": "desenfermar",
    "desenfermemos": "desenfermar",
    "desenfermes": "desenfermar",
    "desenfermo": "desenfermar",
    "desenfermou": "desenfermar",
    "desenfermámo": "desenfermar",
    "desenfermámos": "desenfermar",
    "desenfermáramo": "desenfermar",
    "desenfermáramos": "desenfermar",
    "desenfermáreis": "desenfermar",
    "desenfermásseis": "desenfermar",
    "desenfermássemos": "desenfermar",
    "desenfermávamo": "desenfermar",
    "desenfermávamos": "desenfermar",
    "desenfermáveis": "desenfermar",
    "desenferruja": "desenferrujar",
    "desenferrujada": "desenferrujar",
    "desenferrujadas": "desenferrujar",
    "desenferrujado": "desenferrujar",
    "desenferrujados": "desenferrujar",
    "desenferrujai": "desenferrujar",
    "desenferrujais": "desenferrujar",
    "desenferrujam": "desenferrujar",
    "desenferrujamo": "desenferrujar",
    "desenferrujamos": "desenferrujar",
    "desenferrujando": "desenferrujar",
    "desenferrujara": "desenferrujar",
    "desenferrujaram": "desenferrujar",
    "desenferrujaras": "desenferrujar",
    "desenferrujarde": "desenferrujar",
    "desenferrujardes": "desenferrujar",
    "desenferrujare": "desenferrujar",
    "desenferrujarei": "desenferrujar",
    "desenferrujareis": "desenferrujar",
    "desenferrujarem": "desenferrujar",
    "desenferrujaremos": "desenferrujar",
    "desenferrujares": "desenferrujar",
    "desenferrujaria": "desenferrujar",
    "desenferrujariam": "desenferrujar",
    "desenferrujarias": "desenferrujar",
    "desenferrujarmo": "desenferrujar",
    "desenferrujarmos": "desenferrujar",
    "desenferrujará": "desenferrujar",
    "desenferrujarás": "desenferrujar",
    "desenferrujarão": "desenferrujar",
    "desenferrujaríamos": "desenferrujar",
    "desenferrujaríeis": "desenferrujar",
    "desenferrujas": "desenferrujar",
    "desenferrujasse": "desenferrujar",
    "desenferrujassem": "desenferrujar",
    "desenferrujasses": "desenferrujar",
    "desenferrujaste": "desenferrujar",
    "desenferrujastes": "desenferrujar",
    "desenferrujava": "desenferrujar",
    "desenferrujavam": "desenferrujar",
    "desenferrujavas": "desenferrujar",
    "desenferruje": "desenferrujar",
    "desenferrujei": "desenferrujar",
    "desenferrujeis": "desenferrujar",
    "desenferrujem": "desenferrujar",
    "desenferrujemo": "desenferrujar",
    "desenferrujemos": "desenferrujar",
    "desenferrujes": "desenferrujar",
    "desenferrujo": "desenferrujar",
    "desenferrujou": "desenferrujar",
    "desenferrujá": "desenferrujar",
    "desenferrujámo": "desenferrujar",
    "desenferrujámos": "desenferrujar",
    "desenferrujáramo": "desenferrujar",
    "desenferrujáramos": "desenferrujar",
    "desenferrujárei": "desenferrujar",
    "desenferrujáreis": "desenferrujar",
    "desenferrujásseis": "desenferrujar",
    "desenferrujássemos": "desenferrujar",
    "desenferrujávamo": "desenferrujar",
    "desenferrujávamos": "desenferrujar",
    "desenferrujávei": "desenferrujar",
    "desenferrujáveis": "desenferrujar",
    "desenfesta": "desenfestar",
    "desenfestada": "desenfestar",
    "desenfestadas": "desenfestar",
    "desenfestado": "desenfestar",
    "desenfestados": "desenfestar",
    "desenfestai": "desenfestar",
    "desenfestais": "desenfestar",
    "desenfestam": "desenfestar",
    "desenfestamo": "desenfestar",
    "desenfestamos": "desenfestar",
    "desenfestando": "desenfestar",
    "desenfestara": "desenfestar",
    "desenfestaram": "desenfestar",
    "desenfestaras": "desenfestar",
    "desenfestarde": "desenfestar",
    "desenfestardes": "desenfestar",
    "desenfestare": "desenfestar",
    "desenfestarei": "desenfestar",
    "desenfestareis": "desenfestar",
    "desenfestarem": "desenfestar",
    "desenfestaremos": "desenfestar",
    "desenfestares": "desenfestar",
    "desenfestaria": "desenfestar",
    "desenfestariam": "desenfestar",
    "desenfestarias": "desenfestar",
    "desenfestarmo": "desenfestar",
    "desenfestarmos": "desenfestar",
    "desenfestará": "desenfestar",
    "desenfestarás": "desenfestar",
    "desenfestarão": "desenfestar",
    "desenfestaríamos": "desenfestar",
    "desenfestaríeis": "desenfestar",
    "desenfestas": "desenfestar",
    "desenfestasse": "desenfestar",
    "desenfestassem": "desenfestar",
    "desenfestasses": "desenfestar",
    "desenfestaste": "desenfestar",
    "desenfestastes": "desenfestar",
    "desenfestava": "desenfestar",
    "desenfestavam": "desenfestar",
    "desenfestavas": "desenfestar",
    "desenfeste": "desenfestar",
    "desenfestei": "desenfestar",
    "desenfesteis": "desenfestar",
    "desenfestem": "desenfestar",
    "desenfestemo": "desenfestar",
    "desenfestemos": "desenfestar",
    "desenfestes": "desenfestar",
    "desenfesto": "desenfestar",
    "desenfestou": "desenfestar",
    "desenfestá": "desenfestar",
    "desenfestámo": "desenfestar",
    "desenfestámos": "desenfestar",
    "desenfestáramo": "desenfestar",
    "desenfestáramos": "desenfestar",
    "desenfestárei": "desenfestar",
    "desenfestáreis": "desenfestar",
    "desenfestásseis": "desenfestar",
    "desenfestássemos": "desenfestar",
    "desenfestávamo": "desenfestar",
    "desenfestávamos": "desenfestar",
    "desenfestávei": "desenfestar",
    "desenfestáveis": "desenfestar",
    "desenfeuda": "desenfeudar",
    "desenfeudada": "desenfeudar",
    "desenfeudadas": "desenfeudar",
    "desenfeudado": "desenfeudar",
    "desenfeudados": "desenfeudar",
    "desenfeudai": "desenfeudar",
    "desenfeudais": "desenfeudar",
    "desenfeudam": "desenfeudar",
    "desenfeudamo": "desenfeudar",
    "desenfeudamos": "desenfeudar",
    "desenfeudando": "desenfeudar",
    "desenfeudara": "desenfeudar",
    "desenfeudaram": "desenfeudar",
    "desenfeudaras": "desenfeudar",
    "desenfeudarde": "desenfeudar",
    "desenfeudardes": "desenfeudar",
    "desenfeudare": "desenfeudar",
    "desenfeudarei": "desenfeudar",
    "desenfeudareis": "desenfeudar",
    "desenfeudarem": "desenfeudar",
    "desenfeudaremos": "desenfeudar",
    "desenfeudares": "desenfeudar",
    "desenfeudaria": "desenfeudar",
    "desenfeudariam": "desenfeudar",
    "desenfeudarias": "desenfeudar",
    "desenfeudarmo": "desenfeudar",
    "desenfeudarmos": "desenfeudar",
    "desenfeudará": "desenfeudar",
    "desenfeudarás": "desenfeudar",
    "desenfeudarão": "desenfeudar",
    "desenfeudaríamos": "desenfeudar",
    "desenfeudaríeis": "desenfeudar",
    "desenfeudas": "desenfeudar",
    "desenfeudasse": "desenfeudar",
    "desenfeudassem": "desenfeudar",
    "desenfeudasses": "desenfeudar",
    "desenfeudaste": "desenfeudar",
    "desenfeudastes": "desenfeudar",
    "desenfeudava": "desenfeudar",
    "desenfeudavam": "desenfeudar",
    "desenfeudavas": "desenfeudar",
    "desenfeude": "desenfeudar",
    "desenfeudei": "desenfeudar",
    "desenfeudeis": "desenfeudar",
    "desenfeudem": "desenfeudar",
    "desenfeudemo": "desenfeudar",
    "desenfeudemos": "desenfeudar",
    "desenfeudes": "desenfeudar",
    "desenfeudo": "desenfeudar",
    "desenfeudou": "desenfeudar",
    "desenfeudá": "desenfeudar",
    "desenfeudámo": "desenfeudar",
    "desenfeudámos": "desenfeudar",
    "desenfeudáramo": "desenfeudar",
    "desenfeudáramos": "desenfeudar",
    "desenfeudárei": "desenfeudar",
    "desenfeudáreis": "desenfeudar",
    "desenfeudásseis": "desenfeudar",
    "desenfeudássemos": "desenfeudar",
    "desenfeudávamo": "desenfeudar",
    "desenfeudávamos": "desenfeudar",
    "desenfeudávei": "desenfeudar",
    "desenfeudáveis": "desenfeudar",
    "desenfeza": "desenfezar",
    "desenfezada": "desenfezar",
    "desenfezadas": "desenfezar",
    "desenfezado": "desenfezar",
    "desenfezados": "desenfezar",
    "desenfezai": "desenfezar",
    "desenfezais": "desenfezar",
    "desenfezam": "desenfezar",
    "desenfezamo": "desenfezar",
    "desenfezamos": "desenfezar",
    "desenfezando": "desenfezar",
    "desenfezara": "desenfezar",
    "desenfezaram": "desenfezar",
    "desenfezaras": "desenfezar",
    "desenfezarde": "desenfezar",
    "desenfezardes": "desenfezar",
    "desenfezare": "desenfezar",
    "desenfezarei": "desenfezar",
    "desenfezareis": "desenfezar",
    "desenfezarem": "desenfezar",
    "desenfezaremos": "desenfezar",
    "desenfezares": "desenfezar",
    "desenfezaria": "desenfezar",
    "desenfezariam": "desenfezar",
    "desenfezarias": "desenfezar",
    "desenfezarmo": "desenfezar",
    "desenfezarmos": "desenfezar",
    "desenfezará": "desenfezar",
    "desenfezarás": "desenfezar",
    "desenfezarão": "desenfezar",
    "desenfezaríamos": "desenfezar",
    "desenfezaríeis": "desenfezar",
    "desenfezas": "desenfezar",
    "desenfezasse": "desenfezar",
    "desenfezassem": "desenfezar",
    "desenfezasses": "desenfezar",
    "desenfezaste": "desenfezar",
    "desenfezastes": "desenfezar",
    "desenfezava": "desenfezar",
    "desenfezavam": "desenfezar",
    "desenfezavas": "desenfezar",
    "desenfeze": "desenfezar",
    "desenfezei": "desenfezar",
    "desenfezeis": "desenfezar",
    "desenfezem": "desenfezar",
    "desenfezemo": "desenfezar",
    "desenfezemos": "desenfezar",
    "desenfezes": "desenfezar",
    "desenfezo": "desenfezar",
    "desenfezou": "desenfezar",
    "desenfezá": "desenfezar",
    "desenfezámo": "desenfezar",
    "desenfezámos": "desenfezar",
    "desenfezáramo": "desenfezar",
    "desenfezáramos": "desenfezar",
    "desenfezárei": "desenfezar",
    "desenfezáreis": "desenfezar",
    "desenfezásseis": "desenfezar",
    "desenfezássemos": "desenfezar",
    "desenfezávamo": "desenfezar",
    "desenfezávamos": "desenfezar",
    "desenfezávei": "desenfezar",
    "desenfezáveis": "desenfezar",
    "desenfia": "desenfiar",
    "desenfiada": "desenfiar",
    "desenfiadas": "desenfiar",
    "desenfiado": "desenfiar",
    "desenfiados": "desenfiar",
    "desenfiai": "desenfiar",
    "desenfiais": "desenfiar",
    "desenfiam": "desenfiar",
    "desenfiamo": "desenfiar",
    "desenfiamos": "desenfiar",
    "desenfiando": "desenfiar",
    "desenfiara": "desenfiar",
    "desenfiaram": "desenfiar",
    "desenfiaras": "desenfiar",
    "desenfiarde": "desenfiar",
    "desenfiardes": "desenfiar",
    "desenfiare": "desenfiar",
    "desenfiarei": "desenfiar",
    "desenfiareis": "desenfiar",
    "desenfiarem": "desenfiar",
    "desenfiaremos": "desenfiar",
    "desenfiares": "desenfiar",
    "desenfiaria": "desenfiar",
    "desenfiariam": "desenfiar",
    "desenfiarias": "desenfiar",
    "desenfiarmo": "desenfiar",
    "desenfiarmos": "desenfiar",
    "desenfiará": "desenfiar",
    "desenfiarás": "desenfiar",
    "desenfiarão": "desenfiar",
    "desenfiaríamos": "desenfiar",
    "desenfiaríeis": "desenfiar",
    "desenfias": "desenfiar",
    "desenfiasse": "desenfiar",
    "desenfiassem": "desenfiar",
    "desenfiasses": "desenfiar",
    "desenfiaste": "desenfiar",
    "desenfiastes": "desenfiar",
    "desenfiava": "desenfiar",
    "desenfiavam": "desenfiar",
    "desenfiavas": "desenfiar",
    "desenfie": "desenfiar",
    "desenfiei": "desenfiar",
    "desenfieis": "desenfiar",
    "desenfiem": "desenfiar",
    "desenfiemo": "desenfiar",
    "desenfiemos": "desenfiar",
    "desenfies": "desenfiar",
    "desenfileira": "desenfileirar",
    "desenfileirada": "desenfileirar",
    "desenfileiradas": "desenfileirar",
    "desenfileirado": "desenfileirar",
    "desenfileirados": "desenfileirar",
    "desenfileirai": "desenfileirar",
    "desenfileirais": "desenfileirar",
    "desenfileiram": "desenfileirar",
    "desenfileiramo": "desenfileirar",
    "desenfileiramos": "desenfileirar",
    "desenfileirando": "desenfileirar",
    "desenfileirara": "desenfileirar",
    "desenfileiraram": "desenfileirar",
    "desenfileiraras": "desenfileirar",
    "desenfileirarde": "desenfileirar",
    "desenfileirardes": "desenfileirar",
    "desenfileirare": "desenfileirar",
    "desenfileirarei": "desenfileirar",
    "desenfileirareis": "desenfileirar",
    "desenfileirarem": "desenfileirar",
    "desenfileiraremos": "desenfileirar",
    "desenfileirares": "desenfileirar",
    "desenfileiraria": "desenfileirar",
    "desenfileirariam": "desenfileirar",
    "desenfileirarias": "desenfileirar",
    "desenfileirarmo": "desenfileirar",
    "desenfileirarmos": "desenfileirar",
    "desenfileirará": "desenfileirar",
    "desenfileirarás": "desenfileirar",
    "desenfileirarão": "desenfileirar",
    "desenfileiraríamos": "desenfileirar",
    "desenfileiraríeis": "desenfileirar",
    "desenfileiras": "desenfileirar",
    "desenfileirasse": "desenfileirar",
    "desenfileirassem": "desenfileirar",
    "desenfileirasses": "desenfileirar",
    "desenfileiraste": "desenfileirar",
    "desenfileirastes": "desenfileirar",
    "desenfileirava": "desenfileirar",
    "desenfileiravam": "desenfileirar",
    "desenfileiravas": "desenfileirar",
    "desenfileire": "desenfileirar",
    "desenfileirei": "desenfileirar",
    "desenfileireis": "desenfileirar",
    "desenfileirem": "desenfileirar",
    "desenfileiremo": "desenfileirar",
    "desenfileiremos": "desenfileirar",
    "desenfileires": "desenfileirar",
    "desenfileiro": "desenfileirar",
    "desenfileirou": "desenfileirar",
    "desenfileirá": "desenfileirar",
    "desenfileirámo": "desenfileirar",
    "desenfileirámos": "desenfileirar",
    "desenfileiráramo": "desenfileirar",
    "desenfileiráramos": "desenfileirar",
    "desenfileirárei": "desenfileirar",
    "desenfileiráreis": "desenfileirar",
    "desenfileirásseis": "desenfileirar",
    "desenfileirássemos": "desenfileirar",
    "desenfileirávamo": "desenfileirar",
    "desenfileirávamos": "desenfileirar",
    "desenfileirávei": "desenfileirar",
    "desenfileiráveis": "desenfileirar",
    "desenfio": "desenfiar",
    "desenfiou": "desenfiar",
    "desenfiá": "desenfiar",
    "desenfiámo": "desenfiar",
    "desenfiámos": "desenfiar",
    "desenfiáramo": "desenfiar",
    "desenfiáramos": "desenfiar",
    "desenfiárei": "desenfiar",
    "desenfiáreis": "desenfiar",
    "desenfiásseis": "desenfiar",
    "desenfiássemos": "desenfiar",
    "desenfiávamo": "desenfiar",
    "desenfiávamos": "desenfiar",
    "desenfiávei": "desenfiar",
    "desenfiáveis": "desenfiar",
    "desenflora": "desenflorar",
    "desenflorada": "desenflorar",
    "desenfloradas": "desenflorar",
    "desenflorado": "desenflorar",
    "desenflorados": "desenflorar",
    "desenflorai": "desenflorar",
    "desenflorais": "desenflorar",
    "desenfloram": "desenflorar",
    "desenfloramo": "desenflorar",
    "desenfloramos": "desenflorar",
    "desenflorando": "desenflorar",
    "desenflorara": "desenflorar",
    "desenfloraram": "desenflorar",
    "desenfloraras": "desenflorar",
    "desenflorarde": "desenflorar",
    "desenflorardes": "desenflorar",
    "desenflorare": "desenflorar",
    "desenflorarei": "desenflorar",
    "desenflorareis": "desenflorar",
    "desenflorarem": "desenflorar",
    "desenfloraremos": "desenflorar",
    "desenflorares": "desenflorar",
    "desenfloraria": "desenflorar",
    "desenflorariam": "desenflorar",
    "desenflorarias": "desenflorar",
    "desenflorarmo": "desenflorar",
    "desenflorarmos": "desenflorar",
    "desenflorará": "desenflorar",
    "desenflorarás": "desenflorar",
    "desenflorarão": "desenflorar",
    "desenfloraríamos": "desenflorar",
    "desenfloraríeis": "desenflorar",
    "desenfloras": "desenflorar",
    "desenflorasse": "desenflorar",
    "desenflorassem": "desenflorar",
    "desenflorasses": "desenflorar",
    "desenfloraste": "desenflorar",
    "desenflorastes": "desenflorar",
    "desenflorava": "desenflorar",
    "desenfloravam": "desenflorar",
    "desenfloravas": "desenflorar",
    "desenflore": "desenflorar",
    "desenflorei": "desenflorar",
    "desenfloreis": "desenflorar",
    "desenflorem": "desenflorar",
    "desenfloremo": "desenflorar",
    "desenfloremos": "desenflorar",
    "desenflores": "desenflorar",
    "desenfloro": "desenflorar",
    "desenflorou": "desenflorar",
    "desenflorá": "desenflorar",
    "desenflorámo": "desenflorar",
    "desenflorámos": "desenflorar",
    "desenfloráramo": "desenflorar",
    "desenfloráramos": "desenflorar",
    "desenflorárei": "desenflorar",
    "desenfloráreis": "desenflorar",
    "desenflorásseis": "desenflorar",
    "desenflorássemos": "desenflorar",
    "desenflorávamo": "desenflorar",
    "desenflorávamos": "desenflorar",
    "desenflorávei": "desenflorar",
    "desenfloráveis": "desenflorar",
    "desenforca": "desenforcar",
    "desenforcada": "desenforcar",
    "desenforcadas": "desenforcar",
    "desenforcado": "desenforcar",
    "desenforcados": "desenforcar",
    "desenforcai": "desenforcar",
    "desenforcais": "desenforcar",
    "desenforcam": "desenforcar",
    "desenforcamo": "desenforcar",
    "desenforcamos": "desenforcar",
    "desenforcando": "desenforcar",
    "desenforcara": "desenforcar",
    "desenforcaram": "desenforcar",
    "desenforcaras": "desenforcar",
    "desenforcarde": "desenforcar",
    "desenforcardes": "desenforcar",
    "desenforcare": "desenforcar",
    "desenforcarei": "desenforcar",
    "desenforcareis": "desenforcar",
    "desenforcarem": "desenforcar",
    "desenforcaremos": "desenforcar",
    "desenforcares": "desenforcar",
    "desenforcaria": "desenforcar",
    "desenforcariam": "desenforcar",
    "desenforcarias": "desenforcar",
    "desenforcarmo": "desenforcar",
    "desenforcarmos": "desenforcar",
    "desenforcará": "desenforcar",
    "desenforcarás": "desenforcar",
    "desenforcarão": "desenforcar",
    "desenforcaríamos": "desenforcar",
    "desenforcaríeis": "desenforcar",
    "desenforcas": "desenforcar",
    "desenforcasse": "desenforcar",
    "desenforcassem": "desenforcar",
    "desenforcasses": "desenforcar",
    "desenforcaste": "desenforcar",
    "desenforcastes": "desenforcar",
    "desenforcava": "desenforcar",
    "desenforcavam": "desenforcar",
    "desenforcavas": "desenforcar",
    "desenforco": "desenforcar",
    "desenforcou": "desenforcar",
    "desenforcá": "desenforcar",
    "desenforcámo": "desenforcar",
    "desenforcámos": "desenforcar",
    "desenforcáramo": "desenforcar",
    "desenforcáramos": "desenforcar",
    "desenforcárei": "desenforcar",
    "desenforcáreis": "desenforcar",
    "desenforcásseis": "desenforcar",
    "desenforcássemos": "desenforcar",
    "desenforcávamo": "desenforcar",
    "desenforcávamos": "desenforcar",
    "desenforcávei": "desenforcar",
    "desenforcáveis": "desenforcar",
    "desenforja": "desenforjar",
    "desenforjada": "desenforjar",
    "desenforjadas": "desenforjar",
    "desenforjado": "desenforjar",
    "desenforjados": "desenforjar",
    "desenforjai": "desenforjar",
    "desenforjais": "desenforjar",
    "desenforjam": "desenforjar",
    "desenforjamo": "desenforjar",
    "desenforjamos": "desenforjar",
    "desenforjando": "desenforjar",
    "desenforjara": "desenforjar",
    "desenforjaram": "desenforjar",
    "desenforjaras": "desenforjar",
    "desenforjarde": "desenforjar",
    "desenforjardes": "desenforjar",
    "desenforjare": "desenforjar",
    "desenforjarei": "desenforjar",
    "desenforjareis": "desenforjar",
    "desenforjarem": "desenforjar",
    "desenforjaremos": "desenforjar",
    "desenforjares": "desenforjar",
    "desenforjaria": "desenforjar",
    "desenforjariam": "desenforjar",
    "desenforjarias": "desenforjar",
    "desenforjarmo": "desenforjar",
    "desenforjarmos": "desenforjar",
    "desenforjará": "desenforjar",
    "desenforjarás": "desenforjar",
    "desenforjarão": "desenforjar",
    "desenforjaríamos": "desenforjar",
    "desenforjaríeis": "desenforjar",
    "desenforjas": "desenforjar",
    "desenforjasse": "desenforjar",
    "desenforjassem": "desenforjar",
    "desenforjasses": "desenforjar",
    "desenforjaste": "desenforjar",
    "desenforjastes": "desenforjar",
    "desenforjava": "desenforjar",
    "desenforjavam": "desenforjar",
    "desenforjavas": "desenforjar",
    "desenforje": "desenforjar",
    "desenforjei": "desenforjar",
    "desenforjeis": "desenforjar",
    "desenforjem": "desenforjar",
    "desenforjemo": "desenforjar",
    "desenforjemos": "desenforjar",
    "desenforjes": "desenforjar",
    "desenforjo": "desenforjar",
    "desenforjou": "desenforjar",
    "desenforjá": "desenforjar",
    "desenforjámo": "desenforjar",
    "desenforjámos": "desenforjar",
    "desenforjáramo": "desenforjar",
    "desenforjáramos": "desenforjar",
    "desenforjárei": "desenforjar",
    "desenforjáreis": "desenforjar",
    "desenforjásseis": "desenforjar",
    "desenforjássemos": "desenforjar",
    "desenforjávamo": "desenforjar",
    "desenforjávamos": "desenforjar",
    "desenforjávei": "desenforjar",
    "desenforjáveis": "desenforjar",
    "desenforma": "desenformar",
    "desenformada": "desenformar",
    "desenformadas": "desenformar",
    "desenformado": "desenformar",
    "desenformados": "desenformar",
    "desenformai": "desenformar",
    "desenformais": "desenformar",
    "desenformam": "desenformar",
    "desenformamo": "desenformar",
    "desenformamos": "desenformar",
    "desenformando": "desenformar",
    "desenformara": "desenformar",
    "desenformaram": "desenformar",
    "desenformaras": "desenformar",
    "desenformarde": "desenformar",
    "desenformardes": "desenformar",
    "desenformare": "desenformar",
    "desenformarei": "desenformar",
    "desenformareis": "desenformar",
    "desenformarem": "desenformar",
    "desenformaremos": "desenformar",
    "desenformares": "desenformar",
    "desenformaria": "desenformar",
    "desenformariam": "desenformar",
    "desenformarias": "desenformar",
    "desenformarmo": "desenformar",
    "desenformarmos": "desenformar",
    "desenformará": "desenformar",
    "desenformarás": "desenformar",
    "desenformarão": "desenformar",
    "desenformaríamos": "desenformar",
    "desenformaríeis": "desenformar",
    "desenformas": "desenformar",
    "desenformasse": "desenformar",
    "desenformassem": "desenformar",
    "desenformasses": "desenformar",
    "desenformaste": "desenformar",
    "desenformastes": "desenformar",
    "desenformava": "desenformar",
    "desenformavam": "desenformar",
    "desenformavas": "desenformar",
    "desenforme": "desenformar",
    "desenformei": "desenformar",
    "desenformeis": "desenformar",
    "desenformem": "desenformar",
    "desenformemo": "desenformar",
    "desenformemos": "desenformar",
    "desenformes": "desenformar",
    "desenformo": "desenformar",
    "desenformou": "desenformar",
    "desenformá": "desenformar",
    "desenformámo": "desenformar",
    "desenformámos": "desenformar",
    "desenformáramo": "desenformar",
    "desenformáramos": "desenformar",
    "desenformárei": "desenformar",
    "desenformáreis": "desenformar",
    "desenformásseis": "desenformar",
    "desenformássemos": "desenformar",
    "desenformávamo": "desenformar",
    "desenformávamos": "desenformar",
    "desenformávei": "desenformar",
    "desenformáveis": "desenformar",
    "desenforna": "desenfornar",
    "desenfornada": "desenfornar",
    "desenfornadas": "desenfornar",
    "desenfornado": "desenfornar",
    "desenfornados": "desenfornar",
    "desenfornai": "desenfornar",
    "desenfornais": "desenfornar",
    "desenfornam": "desenfornar",
    "desenfornamo": "desenfornar",
    "desenfornamos": "desenfornar",
    "desenfornando": "desenfornar",
    "desenfornara": "desenfornar",
    "desenfornaram": "desenfornar",
    "desenfornaras": "desenfornar",
    "desenfornarde": "desenfornar",
    "desenfornardes": "desenfornar",
    "desenfornare": "desenfornar",
    "desenfornarei": "desenfornar",
    "desenfornareis": "desenfornar",
    "desenfornarem": "desenfornar",
    "desenfornaremos": "desenfornar",
    "desenfornares": "desenfornar",
    "desenfornaria": "desenfornar",
    "desenfornariam": "desenfornar",
    "desenfornarias": "desenfornar",
    "desenfornarmo": "desenfornar",
    "desenfornarmos": "desenfornar",
    "desenfornará": "desenfornar",
    "desenfornarás": "desenfornar",
    "desenfornarão": "desenfornar",
    "desenfornaríamos": "desenfornar",
    "desenfornaríeis": "desenfornar",
    "desenfornas": "desenfornar",
    "desenfornasse": "desenfornar",
    "desenfornassem": "desenfornar",
    "desenfornasses": "desenfornar",
    "desenfornaste": "desenfornar",
    "desenfornastes": "desenfornar",
    "desenfornava": "desenfornar",
    "desenfornavam": "desenfornar",
    "desenfornavas": "desenfornar",
    "desenforne": "desenfornar",
    "desenfornei": "desenfornar",
    "desenforneis": "desenfornar",
    "desenfornem": "desenfornar",
    "desenfornemo": "desenfornar",
    "desenfornemos": "desenfornar",
    "desenfornes": "desenfornar",
    "desenforno": "desenfornar",
    "desenfornou": "desenfornar",
    "desenforná": "desenfornar",
    "desenfornámo": "desenfornar",
    "desenfornámos": "desenfornar",
    "desenfornáramo": "desenfornar",
    "desenfornáramos": "desenfornar",
    "desenfornárei": "desenfornar",
    "desenfornáreis": "desenfornar",
    "desenfornásseis": "desenfornar",
    "desenfornássemos": "desenfornar",
    "desenfornávamo": "desenfornar",
    "desenfornávamos": "desenfornar",
    "desenfornávei": "desenfornar",
    "desenfornáveis": "desenfornar",
    "desenforque": "desenforcar",
    "desenforquei": "desenforcar",
    "desenforqueis": "desenforcar",
    "desenforquem": "desenforcar",
    "desenforquemo": "desenforcar",
    "desenforquemos": "desenforcar",
    "desenforques": "desenforcar",
    "desenfrasca": "desenfrascar",
    "desenfrascada": "desenfrascar",
    "desenfrascadas": "desenfrascar",
    "desenfrascado": "desenfrascar",
    "desenfrascados": "desenfrascar",
    "desenfrascai": "desenfrascar",
    "desenfrascais": "desenfrascar",
    "desenfrascam": "desenfrascar",
    "desenfrascamo": "desenfrascar",
    "desenfrascamos": "desenfrascar",
    "desenfrascando": "desenfrascar",
    "desenfrascara": "desenfrascar",
    "desenfrascaram": "desenfrascar",
    "desenfrascaras": "desenfrascar",
    "desenfrascarde": "desenfrascar",
    "desenfrascardes": "desenfrascar",
    "desenfrascare": "desenfrascar",
    "desenfrascarei": "desenfrascar",
    "desenfrascareis": "desenfrascar",
    "desenfrascarem": "desenfrascar",
    "desenfrascaremos": "desenfrascar",
    "desenfrascares": "desenfrascar",
    "desenfrascaria": "desenfrascar",
    "desenfrascariam": "desenfrascar",
    "desenfrascarias": "desenfrascar",
    "desenfrascarmo": "desenfrascar",
    "desenfrascarmos": "desenfrascar",
    "desenfrascará": "desenfrascar",
    "desenfrascarás": "desenfrascar",
    "desenfrascarão": "desenfrascar",
    "desenfrascaríamos": "desenfrascar",
    "desenfrascaríeis": "desenfrascar",
    "desenfrascas": "desenfrascar",
    "desenfrascasse": "desenfrascar",
    "desenfrascassem": "desenfrascar",
    "desenfrascasses": "desenfrascar",
    "desenfrascaste": "desenfrascar",
    "desenfrascastes": "desenfrascar",
    "desenfrascava": "desenfrascar",
    "desenfrascavam": "desenfrascar",
    "desenfrascavas": "desenfrascar",
    "desenfrasco": "desenfrascar",
    "desenfrascou": "desenfrascar",
    "desenfrascá": "desenfrascar",
    "desenfrascámo": "desenfrascar",
    "desenfrascámos": "desenfrascar",
    "desenfrascáramo": "desenfrascar",
    "desenfrascáramos": "desenfrascar",
    "desenfrascárei": "desenfrascar",
    "desenfrascáreis": "desenfrascar",
    "desenfrascásseis": "desenfrascar",
    "desenfrascássemos": "desenfrascar",
    "desenfrascávamo": "desenfrascar",
    "desenfrascávamos": "desenfrascar",
    "desenfrascávei": "desenfrascar",
    "desenfrascáveis": "desenfrascar",
    "desenfrasque": "desenfrascar",
    "desenfrasquei": "desenfrascar",
    "desenfrasqueis": "desenfrascar",
    "desenfrasquem": "desenfrascar",
    "desenfrasquemo": "desenfrascar",
    "desenfrasquemos": "desenfrascar",
    "desenfrasques": "desenfrascar",
    "desenfreada": "desenfrear",
    "desenfreadas": "desenfrear",
    "desenfreado": "desenfrear",
    "desenfreados": "desenfrear",
    "desenfreai": "desenfrear",
    "desenfreais": "desenfrear",
    "desenfreamentos": "desenfreamento",
    "desenfreamo": "desenfrear",
    "desenfreamos": "desenfrear",
    "desenfreando": "desenfrear",
    "desenfreara": "desenfrear",
    "desenfrearam": "desenfrear",
    "desenfrearas": "desenfrear",
    "desenfrearde": "desenfrear",
    "desenfreardes": "desenfrear",
    "desenfreare": "desenfrear",
    "desenfrearei": "desenfrear",
    "desenfreareis": "desenfrear",
    "desenfrearem": "desenfrear",
    "desenfrearemos": "desenfrear",
    "desenfreares": "desenfrear",
    "desenfrearia": "desenfrear",
    "desenfreariam": "desenfrear",
    "desenfrearias": "desenfrear",
    "desenfrearmo": "desenfrear",
    "desenfrearmos": "desenfrear",
    "desenfreará": "desenfrear",
    "desenfrearás": "desenfrear",
    "desenfrearão": "desenfrear",
    "desenfrearíamos": "desenfrear",
    "desenfrearíeis": "desenfrear",
    "desenfreasse": "desenfrear",
    "desenfreassem": "desenfrear",
    "desenfreasses": "desenfrear",
    "desenfreaste": "desenfrear",
    "desenfreastes": "desenfrear",
    "desenfreava": "desenfrear",
    "desenfreavam": "desenfrear",
    "desenfreavas": "desenfrear",
    "desenfrecha": "desenfrechar",
    "desenfrechada": "desenfrechar",
    "desenfrechadas": "desenfrechar",
    "desenfrechado": "desenfrechar",
    "desenfrechados": "desenfrechar",
    "desenfrechai": "desenfrechar",
    "desenfrechais": "desenfrechar",
    "desenfrecham": "desenfrechar",
    "desenfrechamo": "desenfrechar",
    "desenfrechamos": "desenfrechar",
    "desenfrechando": "desenfrechar",
    "desenfrechara": "desenfrechar",
    "desenfrecharam": "desenfrechar",
    "desenfrecharas": "desenfrechar",
    "desenfrecharde": "desenfrechar",
    "desenfrechardes": "desenfrechar",
    "desenfrechare": "desenfrechar",
    "desenfrecharei": "desenfrechar",
    "desenfrechareis": "desenfrechar",
    "desenfrecharem": "desenfrechar",
    "desenfrecharemos": "desenfrechar",
    "desenfrechares": "desenfrechar",
    "desenfrecharia": "desenfrechar",
    "desenfrechariam": "desenfrechar",
    "desenfrecharias": "desenfrechar",
    "desenfrecharmo": "desenfrechar",
    "desenfrecharmos": "desenfrechar",
    "desenfrechará": "desenfrechar",
    "desenfrecharás": "desenfrechar",
    "desenfrecharão": "desenfrechar",
    "desenfrecharíamos": "desenfrechar",
    "desenfrecharíeis": "desenfrechar",
    "desenfrechas": "desenfrechar",
    "desenfrechasse": "desenfrechar",
    "desenfrechassem": "desenfrechar",
    "desenfrechasses": "desenfrechar",
    "desenfrechaste": "desenfrechar",
    "desenfrechastes": "desenfrechar",
    "desenfrechava": "desenfrechar",
    "desenfrechavam": "desenfrechar",
    "desenfrechavas": "desenfrechar",
    "desenfreche": "desenfrechar",
    "desenfrechei": "desenfrechar",
    "desenfrecheis": "desenfrechar",
    "desenfrechem": "desenfrechar",
    "desenfrechemo": "desenfrechar",
    "desenfrechemos": "desenfrechar",
    "desenfreches": "desenfrechar",
    "desenfrecho": "desenfrechar",
    "desenfrechou": "desenfrechar",
    "desenfrechá": "desenfrechar",
    "desenfrechámo": "desenfrechar",
    "desenfrechámos": "desenfrechar",
    "desenfrecháramo": "desenfrechar",
    "desenfrecháramos": "desenfrechar",
    "desenfrechárei": "desenfrechar",
    "desenfrecháreis": "desenfrechar",
    "desenfrechásseis": "desenfrechar",
    "desenfrechássemos": "desenfrechar",
    "desenfrechávamo": "desenfrechar",
    "desenfrechávamos": "desenfrechar",
    "desenfrechávei": "desenfrechar",
    "desenfrecháveis": "desenfrechar",
    "desenfreei": "desenfrear",
    "desenfreeis": "desenfrear",
    "desenfreemo": "desenfrear",
    "desenfreemos": "desenfrear",
    "desenfreia": "desenfrear",
    "desenfreiam": "desenfrear",
    "desenfreias": "desenfrear",
    "desenfreie": "desenfrear",
    "desenfreiem": "desenfrear",
    "desenfreies": "desenfrear",
    "desenfreio": "desenfrear",
    "desenfreou": "desenfrear",
    "desenfreá": "desenfrear",
    "desenfreámo": "desenfrear",
    "desenfreámos": "desenfrear",
    "desenfreáramo": "desenfrear",
    "desenfreáramos": "desenfrear",
    "desenfreárei": "desenfrear",
    "desenfreáreis": "desenfrear",
    "desenfreásseis": "desenfrear",
    "desenfreássemos": "desenfrear",
    "desenfreávamo": "desenfrear",
    "desenfreávamos": "desenfrear",
    "desenfreávei": "desenfrear",
    "desenfreáveis": "desenfrear",
    "desenfronha": "desenfronhar",
    "desenfronhada": "desenfronhar",
    "desenfronhadas": "desenfronhar",
    "desenfronhado": "desenfronhar",
    "desenfronhados": "desenfronhar",
    "desenfronhai": "desenfronhar",
    "desenfronhais": "desenfronhar",
    "desenfronham": "desenfronhar",
    "desenfronhamo": "desenfronhar",
    "desenfronhamos": "desenfronhar",
    "desenfronhando": "desenfronhar",
    "desenfronhara": "desenfronhar",
    "desenfronharam": "desenfronhar",
    "desenfronharas": "desenfronhar",
    "desenfronharde": "desenfronhar",
    "desenfronhardes": "desenfronhar",
    "desenfronhare": "desenfronhar",
    "desenfronharei": "desenfronhar",
    "desenfronhareis": "desenfronhar",
    "desenfronharem": "desenfronhar",
    "desenfronharemos": "desenfronhar",
    "desenfronhares": "desenfronhar",
    "desenfronharia": "desenfronhar",
    "desenfronhariam": "desenfronhar",
    "desenfronharias": "desenfronhar",
    "desenfronharmo": "desenfronhar",
    "desenfronharmos": "desenfronhar",
    "desenfronhará": "desenfronhar",
    "desenfronharás": "desenfronhar",
    "desenfronharão": "desenfronhar",
    "desenfronharíamos": "desenfronhar",
    "desenfronharíeis": "desenfronhar",
    "desenfronhas": "desenfronhar",
    "desenfronhasse": "desenfronhar",
    "desenfronhassem": "desenfronhar",
    "desenfronhasses": "desenfronhar",
    "desenfronhaste": "desenfronhar",
    "desenfronhastes": "desenfronhar",
    "desenfronhava": "desenfronhar",
    "desenfronhavam": "desenfronhar",
    "desenfronhavas": "desenfronhar",
    "desenfronhe": "desenfronhar",
    "desenfronhei": "desenfronhar",
    "desenfronheis": "desenfronhar",
    "desenfronhem": "desenfronhar",
    "desenfronhemo": "desenfronhar",
    "desenfronhemos": "desenfronhar",
    "desenfronhes": "desenfronhar",
    "desenfronho": "desenfronhar",
    "desenfronhou": "desenfronhar",
    "desenfronhá": "desenfronhar",
    "desenfronhámo": "desenfronhar",
    "desenfronhámos": "desenfronhar",
    "desenfronháramo": "desenfronhar",
    "desenfronháramos": "desenfronhar",
    "desenfronhárei": "desenfronhar",
    "desenfronháreis": "desenfronhar",
    "desenfronhásseis": "desenfronhar",
    "desenfronhássemos": "desenfronhar",
    "desenfronhávamo": "desenfronhar",
    "desenfronhávamos": "desenfronhar",
    "desenfronhávei": "desenfronhar",
    "desenfronháveis": "desenfronhar",
    "desenfueira": "desenfueirar",
    "desenfueirada": "desenfueirar",
    "desenfueiradas": "desenfueirar",
    "desenfueirado": "desenfueirar",
    "desenfueirados": "desenfueirar",
    "desenfueirai": "desenfueirar",
    "desenfueirais": "desenfueirar",
    "desenfueiram": "desenfueirar",
    "desenfueiramo": "desenfueirar",
    "desenfueiramos": "desenfueirar",
    "desenfueirando": "desenfueirar",
    "desenfueirara": "desenfueirar",
    "desenfueiraram": "desenfueirar",
    "desenfueiraras": "desenfueirar",
    "desenfueirarde": "desenfueirar",
    "desenfueirardes": "desenfueirar",
    "desenfueirare": "desenfueirar",
    "desenfueirarei": "desenfueirar",
    "desenfueirareis": "desenfueirar",
    "desenfueirarem": "desenfueirar",
    "desenfueiraremos": "desenfueirar",
    "desenfueirares": "desenfueirar",
    "desenfueiraria": "desenfueirar",
    "desenfueirariam": "desenfueirar",
    "desenfueirarias": "desenfueirar",
    "desenfueirarmo": "desenfueirar",
    "desenfueirarmos": "desenfueirar",
    "desenfueirará": "desenfueirar",
    "desenfueirarás": "desenfueirar",
    "desenfueirarão": "desenfueirar",
    "desenfueiraríamos": "desenfueirar",
    "desenfueiraríeis": "desenfueirar",
    "desenfueiras": "desenfueirar",
    "desenfueirasse": "desenfueirar",
    "desenfueirassem": "desenfueirar",
    "desenfueirasses": "desenfueirar",
    "desenfueiraste": "desenfueirar",
    "desenfueirastes": "desenfueirar",
    "desenfueirava": "desenfueirar",
    "desenfueiravam": "desenfueirar",
    "desenfueiravas": "desenfueirar",
    "desenfueire": "desenfueirar",
    "desenfueirei": "desenfueirar",
    "desenfueireis": "desenfueirar",
    "desenfueirem": "desenfueirar",
    "desenfueiremo": "desenfueirar",
    "desenfueiremos": "desenfueirar",
    "desenfueires": "desenfueirar",
    "desenfueiro": "desenfueirar",
    "desenfueirou": "desenfueirar",
    "desenfueirá": "desenfueirar",
    "desenfueirámo": "desenfueirar",
    "desenfueirámos": "desenfueirar",
    "desenfueiráramo": "desenfueirar",
    "desenfueiráramos": "desenfueirar",
    "desenfueirárei": "desenfueirar",
    "desenfueiráreis": "desenfueirar",
    "desenfueirásseis": "desenfueirar",
    "desenfueirássemos": "desenfueirar",
    "desenfueirávamo": "desenfueirar",
    "desenfueirávamos": "desenfueirar",
    "desenfueirávei": "desenfueirar",
    "desenfueiráveis": "desenfueirar",
    "desenfuna": "desenfunar",
    "desenfunada": "desenfunar",
    "desenfunadas": "desenfunar",
    "desenfunado": "desenfunar",
    "desenfunados": "desenfunar",
    "desenfunai": "desenfunar",
    "desenfunais": "desenfunar",
    "desenfunam": "desenfunar",
    "desenfunamo": "desenfunar",
    "desenfunamos": "desenfunar",
    "desenfunando": "desenfunar",
    "desenfunara": "desenfunar",
    "desenfunaram": "desenfunar",
    "desenfunaras": "desenfunar",
    "desenfunarde": "desenfunar",
    "desenfunardes": "desenfunar",
    "desenfunare": "desenfunar",
    "desenfunarei": "desenfunar",
    "desenfunareis": "desenfunar",
    "desenfunarem": "desenfunar",
    "desenfunaremos": "desenfunar",
    "desenfunares": "desenfunar",
    "desenfunaria": "desenfunar",
    "desenfunariam": "desenfunar",
    "desenfunarias": "desenfunar",
    "desenfunarmo": "desenfunar",
    "desenfunarmos": "desenfunar",
    "desenfunará": "desenfunar",
    "desenfunarás": "desenfunar",
    "desenfunarão": "desenfunar",
    "desenfunaríamos": "desenfunar",
    "desenfunaríeis": "desenfunar",
    "desenfunas": "desenfunar",
    "desenfunasse": "desenfunar",
    "desenfunassem": "desenfunar",
    "desenfunasses": "desenfunar",
    "desenfunaste": "desenfunar",
    "desenfunastes": "desenfunar",
    "desenfunava": "desenfunar",
    "desenfunavam": "desenfunar",
    "desenfunavas": "desenfunar",
    "desenfune": "desenfunar",
    "desenfunei": "desenfunar",
    "desenfuneis": "desenfunar",
    "desenfunem": "desenfunar",
    "desenfunemo": "desenfunar",
    "desenfunemos": "desenfunar",
    "desenfunes": "desenfunar",
    "desenfuno": "desenfunar",
    "desenfunou": "desenfunar",
    "desenfuná": "desenfunar",
    "desenfunámo": "desenfunar",
    "desenfunámos": "desenfunar",
    "desenfunáramo": "desenfunar",
    "desenfunáramos": "desenfunar",
    "desenfunárei": "desenfunar",
    "desenfunáreis": "desenfunar",
    "desenfunásseis": "desenfunar",
    "desenfunássemos": "desenfunar",
    "desenfunávamo": "desenfunar",
    "desenfunávamos": "desenfunar",
    "desenfunávei": "desenfunar",
    "desenfunáveis": "desenfunar",
    "desenfurece": "desenfurecer",
    "desenfurecei": "desenfurecer",
    "desenfureceis": "desenfurecer",
    "desenfurecem": "desenfurecer",
    "desenfurecemo": "desenfurecer",
    "desenfurecemos": "desenfurecer",
    "desenfurecendo": "desenfurecer",
    "desenfurecera": "desenfurecer",
    "desenfureceram": "desenfurecer",
    "desenfureceras": "desenfurecer",
    "desenfurecerde": "desenfurecer",
    "desenfurecerdes": "desenfurecer",
    "desenfurecere": "desenfurecer",
    "desenfurecerei": "desenfurecer",
    "desenfurecereis": "desenfurecer",
    "desenfurecerem": "desenfurecer",
    "desenfureceremos": "desenfurecer",
    "desenfureceres": "desenfurecer",
    "desenfureceria": "desenfurecer",
    "desenfureceriam": "desenfurecer",
    "desenfurecerias": "desenfurecer",
    "desenfurecermo": "desenfurecer",
    "desenfurecermos": "desenfurecer",
    "desenfurecerá": "desenfurecer",
    "desenfurecerás": "desenfurecer",
    "desenfurecerão": "desenfurecer",
    "desenfureceríamos": "desenfurecer",
    "desenfureceríeis": "desenfurecer",
    "desenfureces": "desenfurecer",
    "desenfurecesse": "desenfurecer",
    "desenfurecessem": "desenfurecer",
    "desenfurecesses": "desenfurecer",
    "desenfureceste": "desenfurecer",
    "desenfurecestes": "desenfurecer",
    "desenfureceu": "desenfurecer",
    "desenfureci": "desenfurecer",
    "desenfurecia": "desenfurecer",
    "desenfureciam": "desenfurecer",
    "desenfurecias": "desenfurecer",
    "desenfurecida": "desenfurecido",
    "desenfurecidas": "desenfurecido",
    "desenfurecido": "desenfurecer",
    "desenfurecidos": "desenfurecido",
    "desenfurecê": "desenfurecer",
    "desenfurecêramo": "desenfurecer",
    "desenfurecêramos": "desenfurecer",
    "desenfurecêrei": "desenfurecer",
    "desenfurecêreis": "desenfurecer",
    "desenfurecêsseis": "desenfurecer",
    "desenfurecêssemos": "desenfurecer",
    "desenfurecíamo": "desenfurecer",
    "desenfurecíamos": "desenfurecer",
    "desenfurecíei": "desenfurecer",
    "desenfurecíeis": "desenfurecer",
    "desenfureça": "desenfurecer",
    "desenfureçais": "desenfurecer",
    "desenfureçam": "desenfurecer",
    "desenfureçamo": "desenfurecer",
    "desenfureçamos": "desenfurecer",
    "desenfureças": "desenfurecer",
    "desenfureço": "desenfurecer",
    "desenfurna": "desenfurnar",
    "desenfurnada": "desenfurnar",
    "desenfurnadas": "desenfurnar",
    "desenfurnado": "desenfurnar",
    "desenfurnados": "desenfurnar",
    "desenfurnai": "desenfurnar",
    "desenfurnais": "desenfurnar",
    "desenfurnam": "desenfurnar",
    "desenfurnamo": "desenfurnar",
    "desenfurnamos": "desenfurnar",
    "desenfurnando": "desenfurnar",
    "desenfurnara": "desenfurnar",
    "desenfurnaram": "desenfurnar",
    "desenfurnaras": "desenfurnar",
    "desenfurnarde": "desenfurnar",
    "desenfurnardes": "desenfurnar",
    "desenfurnare": "desenfurnar",
    "desenfurnarei": "desenfurnar",
    "desenfurnareis": "desenfurnar",
    "desenfurnarem": "desenfurnar",
    "desenfurnaremos": "desenfurnar",
    "desenfurnares": "desenfurnar",
    "desenfurnaria": "desenfurnar",
    "desenfurnariam": "desenfurnar",
    "desenfurnarias": "desenfurnar",
    "desenfurnarmo": "desenfurnar",
    "desenfurnarmos": "desenfurnar",
    "desenfurnará": "desenfurnar",
    "desenfurnarás": "desenfurnar",
    "desenfurnarão": "desenfurnar",
    "desenfurnaríamos": "desenfurnar",
    "desenfurnaríeis": "desenfurnar",
    "desenfurnas": "desenfurnar",
    "desenfurnasse": "desenfurnar",
    "desenfurnassem": "desenfurnar",
    "desenfurnasses": "desenfurnar",
    "desenfurnaste": "desenfurnar",
    "desenfurnastes": "desenfurnar",
    "desenfurnava": "desenfurnar",
    "desenfurnavam": "desenfurnar",
    "desenfurnavas": "desenfurnar",
    "desenfurne": "desenfurnar",
    "desenfurnei": "desenfurnar",
    "desenfurneis": "desenfurnar",
    "desenfurnem": "desenfurnar",
    "desenfurnemo": "desenfurnar",
    "desenfurnemos": "desenfurnar",
    "desenfurnes": "desenfurnar",
    "desenfurno": "desenfurnar",
    "desenfurnou": "desenfurnar",
    "desenfurná": "desenfurnar",
    "desenfurnámo": "desenfurnar",
    "desenfurnámos": "desenfurnar",
    "desenfurnáramo": "desenfurnar",
    "desenfurnáramos": "desenfurnar",
    "desenfurnárei": "desenfurnar",
    "desenfurnáreis": "desenfurnar",
    "desenfurnásseis": "desenfurnar",
    "desenfurnássemos": "desenfurnar",
    "desenfurnávamo": "desenfurnar",
    "desenfurnávamos": "desenfurnar",
    "desenfurnávei": "desenfurnar",
    "desenfurnáveis": "desenfurnar",
    "desenfusca": "desenfuscar",
    "desenfuscada": "desenfuscar",
    "desenfuscadas": "desenfuscar",
    "desenfuscado": "desenfuscar",
    "desenfuscados": "desenfuscar",
    "desenfuscai": "desenfuscar",
    "desenfuscais": "desenfuscar",
    "desenfuscam": "desenfuscar",
    "desenfuscamo": "desenfuscar",
    "desenfuscamos": "desenfuscar",
    "desenfuscando": "desenfuscar",
    "desenfuscara": "desenfuscar",
    "desenfuscaram": "desenfuscar",
    "desenfuscaras": "desenfuscar",
    "desenfuscarde": "desenfuscar",
    "desenfuscardes": "desenfuscar",
    "desenfuscare": "desenfuscar",
    "desenfuscarei": "desenfuscar",
    "desenfuscareis": "desenfuscar",
    "desenfuscarem": "desenfuscar",
    "desenfuscaremos": "desenfuscar",
    "desenfuscares": "desenfuscar",
    "desenfuscaria": "desenfuscar",
    "desenfuscariam": "desenfuscar",
    "desenfuscarias": "desenfuscar",
    "desenfuscarmo": "desenfuscar",
    "desenfuscarmos": "desenfuscar",
    "desenfuscará": "desenfuscar",
    "desenfuscarás": "desenfuscar",
    "desenfuscarão": "desenfuscar",
    "desenfuscaríamos": "desenfuscar",
    "desenfuscaríeis": "desenfuscar",
    "desenfuscas": "desenfuscar",
    "desenfuscasse": "desenfuscar",
    "desenfuscassem": "desenfuscar",
    "desenfuscasses": "desenfuscar",
    "desenfuscaste": "desenfuscar",
    "desenfuscastes": "desenfuscar",
    "desenfuscava": "desenfuscar",
    "desenfuscavam": "desenfuscar",
    "desenfuscavas": "desenfuscar",
    "desenfusco": "desenfuscar",
    "desenfuscou": "desenfuscar",
    "desenfuscá": "desenfuscar",
    "desenfuscámo": "desenfuscar",
    "desenfuscámos": "desenfuscar",
    "desenfuscáramo": "desenfuscar",
    "desenfuscáramos": "desenfuscar",
    "desenfuscárei": "desenfuscar",
    "desenfuscáreis": "desenfuscar",
    "desenfuscásseis": "desenfuscar",
    "desenfuscássemos": "desenfuscar",
    "desenfuscávamo": "desenfuscar",
    "desenfuscávamos": "desenfuscar",
    "desenfuscávei": "desenfuscar",
    "desenfuscáveis": "desenfuscar",
    "desenfusque": "desenfuscar",
    "desenfusquei": "desenfuscar",
    "desenfusqueis": "desenfuscar",
    "desenfusquem": "desenfuscar",
    "desenfusquemo": "desenfuscar",
    "desenfusquemos": "desenfuscar",
    "desenfusques": "desenfuscar",
    "desengace": "desengaçar",
    "desengacei": "desengaçar",
    "desengaceis": "desengaçar",
    "desengacem": "desengaçar",
    "desengacemo": "desengaçar",
    "desengacemos": "desengaçar",
    "desengaces": "desengace",
    "desengaiola": "desengaiolar",
    "desengaiolada": "desengaiolar",
    "desengaioladas": "desengaiolar",
    "desengaiolado": "desengaiolar",
    "desengaiolados": "desengaiolar",
    "desengaiolai": "desengaiolar",
    "desengaiolais": "desengaiolar",
    "desengaiolam": "desengaiolar",
    "desengaiolamo": "desengaiolar",
    "desengaiolamos": "desengaiolar",
    "desengaiolando": "desengaiolar",
    "desengaiolara": "desengaiolar",
    "desengaiolaram": "desengaiolar",
    "desengaiolaras": "desengaiolar",
    "desengaiolarde": "desengaiolar",
    "desengaiolardes": "desengaiolar",
    "desengaiolare": "desengaiolar",
    "desengaiolarei": "desengaiolar",
    "desengaiolareis": "desengaiolar",
    "desengaiolarem": "desengaiolar",
    "desengaiolaremos": "desengaiolar",
    "desengaiolares": "desengaiolar",
    "desengaiolaria": "desengaiolar",
    "desengaiolariam": "desengaiolar",
    "desengaiolarias": "desengaiolar",
    "desengaiolarmo": "desengaiolar",
    "desengaiolarmos": "desengaiolar",
    "desengaiolará": "desengaiolar",
    "desengaiolarás": "desengaiolar",
    "desengaiolarão": "desengaiolar",
    "desengaiolaríamos": "desengaiolar",
    "desengaiolaríeis": "desengaiolar",
    "desengaiolas": "desengaiolar",
    "desengaiolasse": "desengaiolar",
    "desengaiolassem": "desengaiolar",
    "desengaiolasses": "desengaiolar",
    "desengaiolaste": "desengaiolar",
    "desengaiolastes": "desengaiolar",
    "desengaiolava": "desengaiolar",
    "desengaiolavam": "desengaiolar",
    "desengaiolavas": "desengaiolar",
    "desengaiole": "desengaiolar",
    "desengaiolei": "desengaiolar",
    "desengaioleis": "desengaiolar",
    "desengaiolem": "desengaiolar",
    "desengaiolemo": "desengaiolar",
    "desengaiolemos": "desengaiolar",
    "desengaioles": "desengaiolar",
    "desengaiolo": "desengaiolar",
    "desengaiolou": "desengaiolar",
    "desengaiolá": "desengaiolar",
    "desengaiolámo": "desengaiolar",
    "desengaiolámos": "desengaiolar",
    "desengaioláramo": "desengaiolar",
    "desengaioláramos": "desengaiolar",
    "desengaiolárei": "desengaiolar",
    "desengaioláreis": "desengaiolar",
    "desengaiolásseis": "desengaiolar",
    "desengaiolássemos": "desengaiolar",
    "desengaiolávamo": "desengaiolar",
    "desengaiolávamos": "desengaiolar",
    "desengaiolávei": "desengaiolar",
    "desengaioláveis": "desengaiolar",
    "desengajada": "desengajado",
    "desengajadas": "desengajado",
    "desengajados": "desengajado",
    "desengalfinha": "desengalfinhar",
    "desengalfinhada": "desengalfinhar",
    "desengalfinhadas": "desengalfinhar",
    "desengalfinhado": "desengalfinhar",
    "desengalfinhados": "desengalfinhar",
    "desengalfinhai": "desengalfinhar",
    "desengalfinhais": "desengalfinhar",
    "desengalfinham": "desengalfinhar",
    "desengalfinhamo": "desengalfinhar",
    "desengalfinhamos": "desengalfinhar",
    "desengalfinhando": "desengalfinhar",
    "desengalfinhara": "desengalfinhar",
    "desengalfinharam": "desengalfinhar",
    "desengalfinharas": "desengalfinhar",
    "desengalfinharde": "desengalfinhar",
    "desengalfinhardes": "desengalfinhar",
    "desengalfinhare": "desengalfinhar",
    "desengalfinharei": "desengalfinhar",
    "desengalfinhareis": "desengalfinhar",
    "desengalfinharem": "desengalfinhar",
    "desengalfinharemos": "desengalfinhar",
    "desengalfinhares": "desengalfinhar",
    "desengalfinharia": "desengalfinhar",
    "desengalfinhariam": "desengalfinhar",
    "desengalfinharias": "desengalfinhar",
    "desengalfinharmo": "desengalfinhar",
    "desengalfinharmos": "desengalfinhar",
    "desengalfinhará": "desengalfinhar",
    "desengalfinharás": "desengalfinhar",
    "desengalfinharão": "desengalfinhar",
    "desengalfinharíamos": "desengalfinhar",
    "desengalfinharíeis": "desengalfinhar",
    "desengalfinhas": "desengalfinhar",
    "desengalfinhasse": "desengalfinhar",
    "desengalfinhassem": "desengalfinhar",
    "desengalfinhasses": "desengalfinhar",
    "desengalfinhaste": "desengalfinhar",
    "desengalfinhastes": "desengalfinhar",
    "desengalfinhava": "desengalfinhar",
    "desengalfinhavam": "desengalfinhar",
    "desengalfinhavas": "desengalfinhar",
    "desengalfinhe": "desengalfinhar",
    "desengalfinhei": "desengalfinhar",
    "desengalfinheis": "desengalfinhar",
    "desengalfinhem": "desengalfinhar",
    "desengalfinhemo": "desengalfinhar",
    "desengalfinhemos": "desengalfinhar",
    "desengalfinhes": "desengalfinhar",
    "desengalfinho": "desengalfinhar",
    "desengalfinhou": "desengalfinhar",
    "desengalfinhá": "desengalfinhar",
    "desengalfinhámo": "desengalfinhar",
    "desengalfinhámos": "desengalfinhar",
    "desengalfinháramo": "desengalfinhar",
    "desengalfinháramos": "desengalfinhar",
    "desengalfinhárei": "desengalfinhar",
    "desengalfinháreis": "desengalfinhar",
    "desengalfinhásseis": "desengalfinhar",
    "desengalfinhássemos": "desengalfinhar",
    "desengalfinhávamo": "desengalfinhar",
    "desengalfinhávamos": "desengalfinhar",
    "desengalfinhávei": "desengalfinhar",
    "desengalfinháveis": "desengalfinhar",
    "desengana": "desenganar",
    "desenganada": "desenganar",
    "desenganadas": "desenganar",
    "desenganado": "desenganar",
    "desenganadora": "desenganador",
    "desenganadoras": "desenganador",
    "desenganadores": "desenganador",
    "desenganados": "desenganar",
    "desenganai": "desenganar",
    "desenganais": "desenganar",
    "desenganam": "desenganar",
    "desenganamo": "desenganar",
    "desenganamos": "desenganar",
    "desenganando": "desenganar",
    "desenganara": "desenganar",
    "desenganaram": "desenganar",
    "desenganaras": "desenganar",
    "desenganarde": "desenganar",
    "desenganardes": "desenganar",
    "desenganare": "desenganar",
    "desenganarei": "desenganar",
    "desenganareis": "desenganar",
    "desenganarem": "desenganar",
    "desenganaremos": "desenganar",
    "desenganares": "desenganar",
    "desenganaria": "desenganar",
    "desenganariam": "desenganar",
    "desenganarias": "desenganar",
    "desenganarmo": "desenganar",
    "desenganarmos": "desenganar",
    "desenganará": "desenganar",
    "desenganarás": "desenganar",
    "desenganarão": "desenganar",
    "desenganaríamos": "desenganar",
    "desenganaríeis": "desenganar",
    "desenganas": "desenganar",
    "desenganasse": "desenganar",
    "desenganassem": "desenganar",
    "desenganasses": "desenganar",
    "desenganaste": "desenganar",
    "desenganastes": "desenganar",
    "desenganava": "desenganar",
    "desenganavam": "desenganar",
    "desenganavas": "desenganar",
    "desengancha": "desenganchar",
    "desenganchada": "desenganchar",
    "desenganchadas": "desenganchar",
    "desenganchado": "desenganchar",
    "desenganchados": "desenganchar",
    "desenganchai": "desenganchar",
    "desenganchais": "desenganchar",
    "desengancham": "desenganchar",
    "desenganchamo": "desenganchar",
    "desenganchamos": "desenganchar",
    "desenganchando": "desenganchar",
    "desenganchara": "desenganchar",
    "desengancharam": "desenganchar",
    "desengancharas": "desenganchar",
    "desengancharde": "desenganchar",
    "desenganchardes": "desenganchar",
    "desenganchare": "desenganchar",
    "desengancharei": "desenganchar",
    "desenganchareis": "desenganchar",
    "desengancharem": "desenganchar",
    "desengancharemos": "desenganchar",
    "desenganchares": "desenganchar",
    "desengancharia": "desenganchar",
    "desenganchariam": "desenganchar",
    "desengancharias": "desenganchar",
    "desengancharmo": "desenganchar",
    "desengancharmos": "desenganchar",
    "desenganchará": "desenganchar",
    "desengancharás": "desenganchar",
    "desengancharão": "desenganchar",
    "desengancharíamos": "desenganchar",
    "desengancharíeis": "desenganchar",
    "desenganchas": "desenganchar",
    "desenganchasse": "desenganchar",
    "desenganchassem": "desenganchar",
    "desenganchasses": "desenganchar",
    "desenganchaste": "desenganchar",
    "desenganchastes": "desenganchar",
    "desenganchava": "desenganchar",
    "desenganchavam": "desenganchar",
    "desenganchavas": "desenganchar",
    "desenganche": "desenganchar",
    "desenganchei": "desenganchar",
    "desengancheis": "desenganchar",
    "desenganchem": "desenganchar",
    "desenganchemo": "desenganchar",
    "desenganchemos": "desenganchar",
    "desenganches": "desenganchar",
    "desengancho": "desenganchar",
    "desenganchou": "desenganchar",
    "desenganchá": "desenganchar",
    "desenganchámo": "desenganchar",
    "desenganchámos": "desenganchar",
    "desengancháramo": "desenganchar",
    "desengancháramos": "desenganchar",
    "desenganchárei": "desenganchar",
    "desengancháreis": "desenganchar",
    "desenganchásseis": "desenganchar",
    "desenganchássemos": "desenganchar",
    "desenganchávamo": "desenganchar",
    "desenganchávamos": "desenganchar",
    "desenganchávei": "desenganchar",
    "desengancháveis": "desenganchar",
    "desengane": "desenganar",
    "desenganei": "desenganar",
    "desenganeis": "desenganar",
    "desenganem": "desenganar",
    "desenganemo": "desenganar",
    "desenganemos": "desenganar",
    "desenganes": "desenganar",
    "desengano": "desenganar",
    "desenganos": "desengano",
    "desenganou": "desenganar",
    "desenganá": "desenganar",
    "desenganámo": "desenganar",
    "desenganámos": "desenganar",
    "desenganáramo": "desenganar",
    "desenganáramos": "desenganar",
    "desenganárei": "desenganar",
    "desenganáreis": "desenganar",
    "desenganásseis": "desenganar",
    "desenganássemos": "desenganar",
    "desenganávamo": "desenganar",
    "desenganávamos": "desenganar",
    "desenganávei": "desenganar",
    "desenganáveis": "desenganar",
    "desengarrafa": "desengarrafar",
    "desengarrafada": "desengarrafar",
    "desengarrafadas": "desengarrafar",
    "desengarrafado": "desengarrafar",
    "desengarrafados": "desengarrafar",
    "desengarrafai": "desengarrafar",
    "desengarrafais": "desengarrafar",
    "desengarrafam": "desengarrafar",
    "desengarrafamo": "desengarrafar",
    "desengarrafamos": "desengarrafar",
    "desengarrafando": "desengarrafar",
    "desengarrafara": "desengarrafar",
    "desengarrafaram": "desengarrafar",
    "desengarrafaras": "desengarrafar",
    "desengarrafarde": "desengarrafar",
    "desengarrafardes": "desengarrafar",
    "desengarrafare": "desengarrafar",
    "desengarrafarei": "desengarrafar",
    "desengarrafareis": "desengarrafar",
    "desengarrafarem": "desengarrafar",
    "desengarrafaremos": "desengarrafar",
    "desengarrafares": "desengarrafar",
    "desengarrafaria": "desengarrafar",
    "desengarrafariam": "desengarrafar",
    "desengarrafarias": "desengarrafar",
    "desengarrafarmo": "desengarrafar",
    "desengarrafarmos": "desengarrafar",
    "desengarrafará": "desengarrafar",
    "desengarrafarás": "desengarrafar",
    "desengarrafarão": "desengarrafar",
    "desengarrafaríamos": "desengarrafar",
    "desengarrafaríeis": "desengarrafar",
    "desengarrafas": "desengarrafar",
    "desengarrafasse": "desengarrafar",
    "desengarrafassem": "desengarrafar",
    "desengarrafasses": "desengarrafar",
    "desengarrafaste": "desengarrafar",
    "desengarrafastes": "desengarrafar",
    "desengarrafava": "desengarrafar",
    "desengarrafavam": "desengarrafar",
    "desengarrafavas": "desengarrafar",
    "desengarrafe": "desengarrafar",
    "desengarrafei": "desengarrafar",
    "desengarrafeis": "desengarrafar",
    "desengarrafem": "desengarrafar",
    "desengarrafemo": "desengarrafar",
    "desengarrafemos": "desengarrafar",
    "desengarrafes": "desengarrafar",
    "desengarrafo": "desengarrafar",
    "desengarrafou": "desengarrafar",
    "desengarrafá": "desengarrafar",
    "desengarrafámo": "desengarrafar",
    "desengarrafámos": "desengarrafar",
    "desengarrafáramo": "desengarrafar",
    "desengarrafáramos": "desengarrafar",
    "desengarrafárei": "desengarrafar",
    "desengarrafáreis": "desengarrafar",
    "desengarrafásseis": "desengarrafar",
    "desengarrafássemos": "desengarrafar",
    "desengarrafávamo": "desengarrafar",
    "desengarrafávamos": "desengarrafar",
    "desengarrafávei": "desengarrafar",
    "desengarrafáveis": "desengarrafar",
    "desengasga": "desengasgar",
    "desengasgada": "desengasgar",
    "desengasgadas": "desengasgar",
    "desengasgado": "desengasgar",
    "desengasgados": "desengasgar",
    "desengasgai": "desengasgar",
    "desengasgais": "desengasgar",
    "desengasgam": "desengasgar",
    "desengasgamo": "desengasgar",
    "desengasgamos": "desengasgar",
    "desengasgando": "desengasgar",
    "desengasgara": "desengasgar",
    "desengasgaram": "desengasgar",
    "desengasgaras": "desengasgar",
    "desengasgarde": "desengasgar",
    "desengasgardes": "desengasgar",
    "desengasgare": "desengasgar",
    "desengasgarei": "desengasgar",
    "desengasgareis": "desengasgar",
    "desengasgarem": "desengasgar",
    "desengasgaremos": "desengasgar",
    "desengasgares": "desengasgar",
    "desengasgaria": "desengasgar",
    "desengasgariam": "desengasgar",
    "desengasgarias": "desengasgar",
    "desengasgarmo": "desengasgar",
    "desengasgarmos": "desengasgar",
    "desengasgará": "desengasgar",
    "desengasgarás": "desengasgar",
    "desengasgarão": "desengasgar",
    "desengasgaríamos": "desengasgar",
    "desengasgaríeis": "desengasgar",
    "desengasgas": "desengasgar",
    "desengasgasse": "desengasgar",
    "desengasgassem": "desengasgar",
    "desengasgasses": "desengasgar",
    "desengasgaste": "desengasgar",
    "desengasgastes": "desengasgar",
    "desengasgava": "desengasgar",
    "desengasgavam": "desengasgar",
    "desengasgavas": "desengasgar",
    "desengasgo": "desengasgar",
    "desengasgou": "desengasgar",
    "desengasgue": "desengasgar",
    "desengasguei": "desengasgar",
    "desengasgueis": "desengasgar",
    "desengasguem": "desengasgar",
    "desengasguemo": "desengasgar",
    "desengasguemos": "desengasgar",
    "desengasgues": "desengasgar",
    "desengasgá": "desengasgar",
    "desengasgámo": "desengasgar",
    "desengasgámos": "desengasgar",
    "desengasgáramo": "desengasgar",
    "desengasgáramos": "desengasgar",
    "desengasgárei": "desengasgar",
    "desengasgáreis": "desengasgar",
    "desengasgásseis": "desengasgar",
    "desengasgássemos": "desengasgar",
    "desengasgávamo": "desengasgar",
    "desengasgávamos": "desengasgar",
    "desengasgávei": "desengasgar",
    "desengasgáveis": "desengasgar",
    "desengasta": "desengastar",
    "desengastada": "desengastar",
    "desengastadas": "desengastar",
    "desengastado": "desengastar",
    "desengastados": "desengastar",
    "desengastai": "desengastar",
    "desengastais": "desengastar",
    "desengastam": "desengastar",
    "desengastamo": "desengastar",
    "desengastamos": "desengastar",
    "desengastando": "desengastar",
    "desengastara": "desengastar",
    "desengastaram": "desengastar",
    "desengastaras": "desengastar",
    "desengastarde": "desengastar",
    "desengastardes": "desengastar",
    "desengastare": "desengastar",
    "desengastarei": "desengastar",
    "desengastareis": "desengastar",
    "desengastarem": "desengastar",
    "desengastaremos": "desengastar",
    "desengastares": "desengastar",
    "desengastaria": "desengastar",
    "desengastariam": "desengastar",
    "desengastarias": "desengastar",
    "desengastarmo": "desengastar",
    "desengastarmos": "desengastar",
    "desengastará": "desengastar",
    "desengastarás": "desengastar",
    "desengastarão": "desengastar",
    "desengastaríamos": "desengastar",
    "desengastaríeis": "desengastar",
    "desengastas": "desengastar",
    "desengastasse": "desengastar",
    "desengastassem": "desengastar",
    "desengastasses": "desengastar",
    "desengastaste": "desengastar",
    "desengastastes": "desengastar",
    "desengastava": "desengastar",
    "desengastavam": "desengastar",
    "desengastavas": "desengastar",
    "desengaste": "desengastar",
    "desengastei": "desengastar",
    "desengasteis": "desengastar",
    "desengastem": "desengastar",
    "desengastemo": "desengastar",
    "desengastemos": "desengastar",
    "desengastes": "desengastar",
    "desengasto": "desengastar",
    "desengastou": "desengastar",
    "desengastá": "desengastar",
    "desengastámo": "desengastar",
    "desengastámos": "desengastar",
    "desengastáramo": "desengastar",
    "desengastáramos": "desengastar",
    "desengastárei": "desengastar",
    "desengastáreis": "desengastar",
    "desengastásseis": "desengastar",
    "desengastássemos": "desengastar",
    "desengastávamo": "desengastar",
    "desengastávamos": "desengastar",
    "desengastávei": "desengastar",
    "desengastáveis": "desengastar",
    "desengata": "desengatar",
    "desengatada": "desengatar",
    "desengatadas": "desengatar",
    "desengatado": "desengatar",
    "desengatados": "desengatar",
    "desengatai": "desengatar",
    "desengatais": "desengatar",
    "desengatam": "desengatar",
    "desengatamo": "desengatar",
    "desengatamos": "desengatar",
    "desengatando": "desengatar",
    "desengatara": "desengatar",
    "desengataram": "desengatar",
    "desengataras": "desengatar",
    "desengatarde": "desengatar",
    "desengatardes": "desengatar",
    "desengatare": "desengatar",
    "desengatarei": "desengatar",
    "desengatareis": "desengatar",
    "desengatarem": "desengatar",
    "desengataremos": "desengatar",
    "desengatares": "desengatar",
    "desengataria": "desengatar",
    "desengatariam": "desengatar",
    "desengatarias": "desengatar",
    "desengatarmo": "desengatar",
    "desengatarmos": "desengatar",
    "desengatará": "desengatar",
    "desengatarás": "desengatar",
    "desengatarão": "desengatar",
    "desengataríamos": "desengatar",
    "desengataríeis": "desengatar",
    "desengatas": "desengatar",
    "desengatasse": "desengatar",
    "desengatassem": "desengatar",
    "desengatasses": "desengatar",
    "desengataste": "desengatar",
    "desengatastes": "desengatar",
    "desengatava": "desengatar",
    "desengatavam": "desengatar",
    "desengatavas": "desengatar",
    "desengate": "desengatar",
    "desengatei": "desengatar",
    "desengateis": "desengatar",
    "desengatem": "desengatar",
    "desengatemo": "desengatar",
    "desengatemos": "desengatar",
    "desengates": "desengate",
    "desengatilha": "desengatilhar",
    "desengatilhada": "desengatilhar",
    "desengatilhadas": "desengatilhar",
    "desengatilhado": "desengatilhar",
    "desengatilhados": "desengatilhar",
    "desengatilhai": "desengatilhar",
    "desengatilhais": "desengatilhar",
    "desengatilham": "desengatilhar",
    "desengatilhamo": "desengatilhar",
    "desengatilhamos": "desengatilhar",
    "desengatilhando": "desengatilhar",
    "desengatilhara": "desengatilhar",
    "desengatilharam": "desengatilhar",
    "desengatilharas": "desengatilhar",
    "desengatilharde": "desengatilhar",
    "desengatilhardes": "desengatilhar",
    "desengatilhare": "desengatilhar",
    "desengatilharei": "desengatilhar",
    "desengatilhareis": "desengatilhar",
    "desengatilharem": "desengatilhar",
    "desengatilharemos": "desengatilhar",
    "desengatilhares": "desengatilhar",
    "desengatilharia": "desengatilhar",
    "desengatilhariam": "desengatilhar",
    "desengatilharias": "desengatilhar",
    "desengatilharmo": "desengatilhar",
    "desengatilharmos": "desengatilhar",
    "desengatilhará": "desengatilhar",
    "desengatilharás": "desengatilhar",
    "desengatilharão": "desengatilhar",
    "desengatilharíamos": "desengatilhar",
    "desengatilharíeis": "desengatilhar",
    "desengatilhas": "desengatilhar",
    "desengatilhasse": "desengatilhar",
    "desengatilhassem": "desengatilhar",
    "desengatilhasses": "desengatilhar",
    "desengatilhaste": "desengatilhar",
    "desengatilhastes": "desengatilhar",
    "desengatilhava": "desengatilhar",
    "desengatilhavam": "desengatilhar",
    "desengatilhavas": "desengatilhar",
    "desengatilhe": "desengatilhar",
    "desengatilhei": "desengatilhar",
    "desengatilheis": "desengatilhar",
    "desengatilhem": "desengatilhar",
    "desengatilhemo": "desengatilhar",
    "desengatilhemos": "desengatilhar",
    "desengatilhes": "desengatilhar",
    "desengatilho": "desengatilhar",
    "desengatilhou": "desengatilhar",
    "desengatilhá": "desengatilhar",
    "desengatilhámo": "desengatilhar",
    "desengatilhámos": "desengatilhar",
    "desengatilháramo": "desengatilhar",
    "desengatilháramos": "desengatilhar",
    "desengatilhárei": "desengatilhar",
    "desengatilháreis": "desengatilhar",
    "desengatilhásseis": "desengatilhar",
    "desengatilhássemos": "desengatilhar",
    "desengatilhávamo": "desengatilhar",
    "desengatilhávamos": "desengatilhar",
    "desengatilhávei": "desengatilhar",
    "desengatilháveis": "desengatilhar",
    "desengato": "desengatar",
    "desengatou": "desengatar",
    "desengatá": "desengatar",
    "desengatámo": "desengatar",
    "desengatámos": "desengatar",
    "desengatáramo": "desengatar",
    "desengatáramos": "desengatar",
    "desengatárei": "desengatar",
    "desengatáreis": "desengatar",
    "desengatásseis": "desengatar",
    "desengatássemos": "desengatar",
    "desengatávamo": "desengatar",
    "desengatávamos": "desengatar",
    "desengatávei": "desengatar",
    "desengatáveis": "desengatar",
    "desengaveta": "desengavetar",
    "desengavetada": "desengavetar",
    "desengavetadas": "desengavetar",
    "desengavetado": "desengavetar",
    "desengavetados": "desengavetar",
    "desengavetai": "desengavetar",
    "desengavetais": "desengavetar",
    "desengavetam": "desengavetar",
    "desengavetamo": "desengavetar",
    "desengavetamos": "desengavetar",
    "desengavetando": "desengavetar",
    "desengavetara": "desengavetar",
    "desengavetaram": "desengavetar",
    "desengavetaras": "desengavetar",
    "desengavetarde": "desengavetar",
    "desengavetardes": "desengavetar",
    "desengavetare": "desengavetar",
    "desengavetarei": "desengavetar",
    "desengavetareis": "desengavetar",
    "desengavetarem": "desengavetar",
    "desengavetaremos": "desengavetar",
    "desengavetares": "desengavetar",
    "desengavetaria": "desengavetar",
    "desengavetariam": "desengavetar",
    "desengavetarias": "desengavetar",
    "desengavetarmo": "desengavetar",
    "desengavetarmos": "desengavetar",
    "desengavetará": "desengavetar",
    "desengavetarás": "desengavetar",
    "desengavetarão": "desengavetar",
    "desengavetaríamos": "desengavetar",
    "desengavetaríeis": "desengavetar",
    "desengavetas": "desengavetar",
    "desengavetasse": "desengavetar",
    "desengavetassem": "desengavetar",
    "desengavetasses": "desengavetar",
    "desengavetaste": "desengavetar",
    "desengavetastes": "desengavetar",
    "desengavetava": "desengavetar",
    "desengavetavam": "desengavetar",
    "desengavetavas": "desengavetar",
    "desengavete": "desengavetar",
    "desengavetei": "desengavetar",
    "desengaveteis": "desengavetar",
    "desengavetem": "desengavetar",
    "desengavetemo": "desengavetar",
    "desengavetemos": "desengavetar",
    "desengavetes": "desengavetar",
    "desengaveto": "desengavetar",
    "desengavetou": "desengavetar",
    "desengavetá": "desengavetar",
    "desengavetámo": "desengavetar",
    "desengavetámos": "desengavetar",
    "desengavetáramo": "desengavetar",
    "desengavetáramos": "desengavetar",
    "desengavetárei": "desengavetar",
    "desengavetáreis": "desengavetar",
    "desengavetásseis": "desengavetar",
    "desengavetássemos": "desengavetar",
    "desengavetávamo": "desengavetar",
    "desengavetávamos": "desengavetar",
    "desengavetávei": "desengavetar",
    "desengavetáveis": "desengavetar",
    "desengaça": "desengaçar",
    "desengaçada": "desengaçar",
    "desengaçadas": "desengaçar",
    "desengaçadeiras": "desengaçadeira",
    "desengaçado": "desengaçar",
    "desengaçadores": "desengaçador",
    "desengaçados": "desengaçar",
    "desengaçai": "desengaçar",
    "desengaçais": "desengaçar",
    "desengaçam": "desengaçar",
    "desengaçamo": "desengaçar",
    "desengaçamos": "desengaçar",
    "desengaçando": "desengaçar",
    "desengaçara": "desengaçar",
    "desengaçaram": "desengaçar",
    "desengaçaras": "desengaçar",
    "desengaçarde": "desengaçar",
    "desengaçardes": "desengaçar",
    "desengaçare": "desengaçar",
    "desengaçarei": "desengaçar",
    "desengaçareis": "desengaçar",
    "desengaçarem": "desengaçar",
    "desengaçaremos": "desengaçar",
    "desengaçares": "desengaçar",
    "desengaçaria": "desengaçar",
    "desengaçariam": "desengaçar",
    "desengaçarias": "desengaçar",
    "desengaçarmo": "desengaçar",
    "desengaçarmos": "desengaçar",
    "desengaçará": "desengaçar",
    "desengaçarás": "desengaçar",
    "desengaçarão": "desengaçar",
    "desengaçaríamos": "desengaçar",
    "desengaçaríeis": "desengaçar",
    "desengaças": "desengaçar",
    "desengaçasse": "desengaçar",
    "desengaçassem": "desengaçar",
    "desengaçasses": "desengaçar",
    "desengaçaste": "desengaçar",
    "desengaçastes": "desengaçar",
    "desengaçava": "desengaçar",
    "desengaçavam": "desengaçar",
    "desengaçavas": "desengaçar",
    "desengaço": "desengaçar",
    "desengaços": "desengaço",
    "desengaçou": "desengaçar",
    "desengaçá": "desengaçar",
    "desengaçámo": "desengaçar",
    "desengaçámos": "desengaçar",
    "desengaçáramo": "desengaçar",
    "desengaçáramos": "desengaçar",
    "desengaçárei": "desengaçar",
    "desengaçáreis": "desengaçar",
    "desengaçásseis": "desengaçar",
    "desengaçássemos": "desengaçar",
    "desengaçávamo": "desengaçar",
    "desengaçávamos": "desengaçar",
    "desengaçávei": "desengaçar",
    "desengaçáveis": "desengaçar",
    "desengelha": "desengelhar",
    "desengelhada": "desengelhar",
    "desengelhadas": "desengelhar",
    "desengelhado": "desengelhar",
    "desengelhados": "desengelhar",
    "desengelhai": "desengelhar",
    "desengelhais": "desengelhar",
    "desengelham": "desengelhar",
    "desengelhamo": "desengelhar",
    "desengelhamos": "desengelhar",
    "desengelhando": "desengelhar",
    "desengelhara": "desengelhar",
    "desengelharam": "desengelhar",
    "desengelharas": "desengelhar",
    "desengelharde": "desengelhar",
    "desengelhardes": "desengelhar",
    "desengelhare": "desengelhar",
    "desengelharei": "desengelhar",
    "desengelhareis": "desengelhar",
    "desengelharem": "desengelhar",
    "desengelharemos": "desengelhar",
    "desengelhares": "desengelhar",
    "desengelharia": "desengelhar",
    "desengelhariam": "desengelhar",
    "desengelharias": "desengelhar",
    "desengelharmo": "desengelhar",
    "desengelharmos": "desengelhar",
    "desengelhará": "desengelhar",
    "desengelharás": "desengelhar",
    "desengelharão": "desengelhar",
    "desengelharíamos": "desengelhar",
    "desengelharíeis": "desengelhar",
    "desengelhas": "desengelhar",
    "desengelhasse": "desengelhar",
    "desengelhassem": "desengelhar",
    "desengelhasses": "desengelhar",
    "desengelhaste": "desengelhar",
    "desengelhastes": "desengelhar",
    "desengelhava": "desengelhar",
    "desengelhavam": "desengelhar",
    "desengelhavas": "desengelhar",
    "desengelhe": "desengelhar",
    "desengelhei": "desengelhar",
    "desengelheis": "desengelhar",
    "desengelhem": "desengelhar",
    "desengelhemo": "desengelhar",
    "desengelhemos": "desengelhar",
    "desengelhes": "desengelhar",
    "desengelho": "desengelhar",
    "desengelhou": "desengelhar",
    "desengelhá": "desengelhar",
    "desengelhámo": "desengelhar",
    "desengelhámos": "desengelhar",
    "desengelháramo": "desengelhar",
    "desengelháramos": "desengelhar",
    "desengelhárei": "desengelhar",
    "desengelháreis": "desengelhar",
    "desengelhásseis": "desengelhar",
    "desengelhássemos": "desengelhar",
    "desengelhávamo": "desengelhar",
    "desengelhávamos": "desengelhar",
    "desengelhávei": "desengelhar",
    "desengelháveis": "desengelhar",
    "desengenhosa": "desengenhoso",
    "desengenhosas": "desengenhoso",
    "desengenhosos": "desengenhoso",
    "desengloba": "desenglobar",
    "desenglobada": "desenglobar",
    "desenglobadas": "desenglobar",
    "desenglobado": "desenglobar",
    "desenglobados": "desenglobar",
    "desenglobai": "desenglobar",
    "desenglobais": "desenglobar",
    "desenglobam": "desenglobar",
    "desenglobamo": "desenglobar",
    "desenglobamos": "desenglobar",
    "desenglobando": "desenglobar",
    "desenglobara": "desenglobar",
    "desenglobaram": "desenglobar",
    "desenglobaras": "desenglobar",
    "desenglobarde": "desenglobar",
    "desenglobardes": "desenglobar",
    "desenglobare": "desenglobar",
    "desenglobarei": "desenglobar",
    "desenglobareis": "desenglobar",
    "desenglobarem": "desenglobar",
    "desenglobaremos": "desenglobar",
    "desenglobares": "desenglobar",
    "desenglobaria": "desenglobar",
    "desenglobariam": "desenglobar",
    "desenglobarias": "desenglobar",
    "desenglobarmo": "desenglobar",
    "desenglobarmos": "desenglobar",
    "desenglobará": "desenglobar",
    "desenglobarás": "desenglobar",
    "desenglobarão": "desenglobar",
    "desenglobaríamos": "desenglobar",
    "desenglobaríeis": "desenglobar",
    "desenglobas": "desenglobar",
    "desenglobasse": "desenglobar",
    "desenglobassem": "desenglobar",
    "desenglobasses": "desenglobar",
    "desenglobaste": "desenglobar",
    "desenglobastes": "desenglobar",
    "desenglobava": "desenglobar",
    "desenglobavam": "desenglobar",
    "desenglobavas": "desenglobar",
    "desenglobe": "desenglobar",
    "desenglobei": "desenglobar",
    "desenglobeis": "desenglobar",
    "desenglobem": "desenglobar",
    "desenglobemo": "desenglobar",
    "desenglobemos": "desenglobar",
    "desenglobes": "desenglobar",
    "desenglobo": "desenglobar",
    "desenglobou": "desenglobar",
    "desenglobá": "desenglobar",
    "desenglobámo": "desenglobar",
    "desenglobámos": "desenglobar",
    "desenglobáramo": "desenglobar",
    "desenglobáramos": "desenglobar",
    "desenglobárei": "desenglobar",
    "desenglobáreis": "desenglobar",
    "desenglobásseis": "desenglobar",
    "desenglobássemos": "desenglobar",
    "desenglobávamo": "desenglobar",
    "desenglobávamos": "desenglobar",
    "desenglobávei": "desenglobar",
    "desenglobáveis": "desenglobar",
    "desengoda": "desengodar",
    "desengodada": "desengodar",
    "desengodadas": "desengodar",
    "desengodado": "desengodar",
    "desengodados": "desengodar",
    "desengodai": "desengodar",
    "desengodais": "desengodar",
    "desengodam": "desengodar",
    "desengodamo": "desengodar",
    "desengodamos": "desengodar",
    "desengodando": "desengodar",
    "desengodara": "desengodar",
    "desengodaram": "desengodar",
    "desengodaras": "desengodar",
    "desengodarde": "desengodar",
    "desengodardes": "desengodar",
    "desengodare": "desengodar",
    "desengodarei": "desengodar",
    "desengodareis": "desengodar",
    "desengodarem": "desengodar",
    "desengodaremos": "desengodar",
    "desengodares": "desengodar",
    "desengodaria": "desengodar",
    "desengodariam": "desengodar",
    "desengodarias": "desengodar",
    "desengodarmo": "desengodar",
    "desengodarmos": "desengodar",
    "desengodará": "desengodar",
    "desengodarás": "desengodar",
    "desengodarão": "desengodar",
    "desengodaríamos": "desengodar",
    "desengodaríeis": "desengodar",
    "desengodas": "desengodar",
    "desengodasse": "desengodar",
    "desengodassem": "desengodar",
    "desengodasses": "desengodar",
    "desengodaste": "desengodar",
    "desengodastes": "desengodar",
    "desengodava": "desengodar",
    "desengodavam": "desengodar",
    "desengodavas": "desengodar",
    "desengode": "desengodar",
    "desengodei": "desengodar",
    "desengodeis": "desengodar",
    "desengodem": "desengodar",
    "desengodemo": "desengodar",
    "desengodemos": "desengodar",
    "desengodes": "desengodar",
    "desengodo": "desengodar",
    "desengodou": "desengodar",
    "desengodá": "desengodar",
    "desengodámo": "desengodar",
    "desengodámos": "desengodar",
    "desengodáramo": "desengodar",
    "desengodáramos": "desengodar",
    "desengodárei": "desengodar",
    "desengodáreis": "desengodar",
    "desengodásseis": "desengodar",
    "desengodássemos": "desengodar",
    "desengodávamo": "desengodar",
    "desengodávamos": "desengodar",
    "desengodávei": "desengodar",
    "desengodáveis": "desengodar",
    "desengole": "desengolir",
    "desengolem": "desengolir",
    "desengoles": "desengolir",
    "desengolfa": "desengolfar",
    "desengolfada": "desengolfar",
    "desengolfadas": "desengolfar",
    "desengolfado": "desengolfar",
    "desengolfados": "desengolfar",
    "desengolfai": "desengolfar",
    "desengolfais": "desengolfar",
    "desengolfam": "desengolfar",
    "desengolfamo": "desengolfar",
    "desengolfamos": "desengolfar",
    "desengolfando": "desengolfar",
    "desengolfara": "desengolfar",
    "desengolfaram": "desengolfar",
    "desengolfaras": "desengolfar",
    "desengolfarde": "desengolfar",
    "desengolfardes": "desengolfar",
    "desengolfare": "desengolfar",
    "desengolfarei": "desengolfar",
    "desengolfareis": "desengolfar",
    "desengolfarem": "desengolfar",
    "desengolfaremos": "desengolfar",
    "desengolfares": "desengolfar",
    "desengolfaria": "desengolfar",
    "desengolfariam": "desengolfar",
    "desengolfarias": "desengolfar",
    "desengolfarmo": "desengolfar",
    "desengolfarmos": "desengolfar",
    "desengolfará": "desengolfar",
    "desengolfarás": "desengolfar",
    "desengolfarão": "desengolfar",
    "desengolfaríamos": "desengolfar",
    "desengolfaríeis": "desengolfar",
    "desengolfas": "desengolfar",
    "desengolfasse": "desengolfar",
    "desengolfassem": "desengolfar",
    "desengolfasses": "desengolfar",
    "desengolfaste": "desengolfar",
    "desengolfastes": "desengolfar",
    "desengolfava": "desengolfar",
    "desengolfavam": "desengolfar",
    "desengolfavas": "desengolfar",
    "desengolfe": "desengolfar",
    "desengolfei": "desengolfar",
    "desengolfeis": "desengolfar",
    "desengolfem": "desengolfar",
    "desengolfemo": "desengolfar",
    "desengolfemos": "desengolfar",
    "desengolfes": "desengolfar",
    "desengolfo": "desengolfar",
    "desengolfou": "desengolfar",
    "desengolfá": "desengolfar",
    "desengolfámo": "desengolfar",
    "desengolfámos": "desengolfar",
    "desengolfáramo": "desengolfar",
    "desengolfáramos": "desengolfar",
    "desengolfárei": "desengolfar",
    "desengolfáreis": "desengolfar",
    "desengolfásseis": "desengolfar",
    "desengolfássemos": "desengolfar",
    "desengolfávamo": "desengolfar",
    "desengolfávamos": "desengolfar",
    "desengolfávei": "desengolfar",
    "desengolfáveis": "desengolfar",
    "desengoli": "desengolir",
    "desengolia": "desengolir",
    "desengoliam": "desengolir",
    "desengolias": "desengolir",
    "desengolida": "desengolir",
    "desengolidas": "desengolir",
    "desengolido": "desengolir",
    "desengolidos": "desengolir",
    "desengolimo": "desengolir",
    "desengolimos": "desengolir",
    "desengolindo": "desengolir",
    "desengolira": "desengolir",
    "desengoliram": "desengolir",
    "desengoliras": "desengolir",
    "desengolirde": "desengolir",
    "desengolirdes": "desengolir",
    "desengolire": "desengolir",
    "desengolirei": "desengolir",
    "desengolireis": "desengolir",
    "desengolirem": "desengolir",
    "desengoliremos": "desengolir",
    "desengolires": "desengolir",
    "desengoliria": "desengolir",
    "desengoliriam": "desengolir",
    "desengolirias": "desengolir",
    "desengolirmo": "desengolir",
    "desengolirmos": "desengolir",
    "desengolirá": "desengolir",
    "desengolirás": "desengolir",
    "desengolirão": "desengolir",
    "desengoliríamos": "desengolir",
    "desengoliríeis": "desengolir",
    "desengolis": "desengolir",
    "desengolisse": "desengolir",
    "desengolissem": "desengolir",
    "desengolisses": "desengolir",
    "desengoliste": "desengolir",
    "desengolistes": "desengolir",
    "desengoliu": "desengolir",
    "desengolíamo": "desengolir",
    "desengolíamos": "desengolir",
    "desengolíei": "desengolir",
    "desengolíeis": "desengolir",
    "desengolíramo": "desengolir",
    "desengolíramos": "desengolir",
    "desengolírei": "desengolir",
    "desengolíreis": "desengolir",
    "desengolísseis": "desengolir",
    "desengolíssemos": "desengolir",
    "desengoma": "desengomar",
    "desengomada": "desengomar",
    "desengomadas": "desengomar",
    "desengomado": "desengomar",
    "desengomados": "desengomar",
    "desengomai": "desengomar",
    "desengomais": "desengomar",
    "desengomam": "desengomar",
    "desengomamo": "desengomar",
    "desengomamos": "desengomar",
    "desengomando": "desengomar",
    "desengomara": "desengomar",
    "desengomaram": "desengomar",
    "desengomaras": "desengomar",
    "desengomarde": "desengomar",
    "desengomardes": "desengomar",
    "desengomare": "desengomar",
    "desengomarei": "desengomar",
    "desengomareis": "desengomar",
    "desengomarem": "desengomar",
    "desengomaremos": "desengomar",
    "desengomares": "desengomar",
    "desengomaria": "desengomar",
    "desengomariam": "desengomar",
    "desengomarias": "desengomar",
    "desengomarmo": "desengomar",
    "desengomarmos": "desengomar",
    "desengomará": "desengomar",
    "desengomarás": "desengomar",
    "desengomarão": "desengomar",
    "desengomaríamos": "desengomar",
    "desengomaríeis": "desengomar",
    "desengomas": "desengomar",
    "desengomasse": "desengomar",
    "desengomassem": "desengomar",
    "desengomasses": "desengomar",
    "desengomaste": "desengomar",
    "desengomastes": "desengomar",
    "desengomava": "desengomar",
    "desengomavam": "desengomar",
    "desengomavas": "desengomar",
    "desengome": "desengomar",
    "desengomei": "desengomar",
    "desengomeis": "desengomar",
    "desengomem": "desengomar",
    "desengomemo": "desengomar",
    "desengomemos": "desengomar",
    "desengomes": "desengomar",
    "desengomo": "desengomar",
    "desengomou": "desengomar",
    "desengomá": "desengomar",
    "desengomámo": "desengomar",
    "desengomámos": "desengomar",
    "desengomáramo": "desengomar",
    "desengomáramos": "desengomar",
    "desengomárei": "desengomar",
    "desengomáreis": "desengomar",
    "desengomásseis": "desengomar",
    "desengomássemos": "desengomar",
    "desengomávamo": "desengomar",
    "desengomávamos": "desengomar",
    "desengomávei": "desengomar",
    "desengomáveis": "desengomar",
    "desengonce": "desengonçar",
    "desengoncei": "desengonçar",
    "desengonceis": "desengonçar",
    "desengoncem": "desengonçar",
    "desengoncemo": "desengonçar",
    "desengoncemos": "desengonçar",
    "desengonces": "desengonçar",
    "desengonça": "desengonçar",
    "desengonçada": "desengonçar",
    "desengonçadas": "desengonçar",
    "desengonçado": "desengonçar",
    "desengonçados": "desengonçar",
    "desengonçai": "desengonçar",
    "desengonçais": "desengonçar",
    "desengonçam": "desengonçar",
    "desengonçamo": "desengonçar",
    "desengonçamos": "desengonçar",
    "desengonçando": "desengonçar",
    "desengonçara": "desengonçar",
    "desengonçaram": "desengonçar",
    "desengonçaras": "desengonçar",
    "desengonçarde": "desengonçar",
    "desengonçardes": "desengonçar",
    "desengonçare": "desengonçar",
    "desengonçarei": "desengonçar",
    "desengonçareis": "desengonçar",
    "desengonçarem": "desengonçar",
    "desengonçaremos": "desengonçar",
    "desengonçares": "desengonçar",
    "desengonçaria": "desengonçar",
    "desengonçariam": "desengonçar",
    "desengonçarias": "desengonçar",
    "desengonçarmo": "desengonçar",
    "desengonçarmos": "desengonçar",
    "desengonçará": "desengonçar",
    "desengonçarás": "desengonçar",
    "desengonçarão": "desengonçar",
    "desengonçaríamos": "desengonçar",
    "desengonçaríeis": "desengonçar",
    "desengonças": "desengonçar",
    "desengonçasse": "desengonçar",
    "desengonçassem": "desengonçar",
    "desengonçasses": "desengonçar",
    "desengonçaste": "desengonçar",
    "desengonçastes": "desengonçar",
    "desengonçava": "desengonçar",
    "desengonçavam": "desengonçar",
    "desengonçavas": "desengonçar",
    "desengonço": "desengonçar",
    "desengonços": "desengonço",
    "desengonçou": "desengonçar",
    "desengonçá": "desengonçar",
    "desengonçámo": "desengonçar",
    "desengonçámos": "desengonçar",
    "desengonçáramo": "desengonçar",
    "desengonçáramos": "desengonçar",
    "desengonçárei": "desengonçar",
    "desengonçáreis": "desengonçar",
    "desengonçásseis": "desengonçar",
    "desengonçássemos": "desengonçar",
    "desengonçávamo": "desengonçar",
    "desengonçávamos": "desengonçar",
    "desengonçávei": "desengonçar",
    "desengonçáveis": "desengonçar",
    "desengorda": "desengordar",
    "desengordada": "desengordar",
    "desengordadas": "desengordar",
    "desengordado": "desengordar",
    "desengordados": "desengordar",
    "desengordai": "desengordar",
    "desengordais": "desengordar",
    "desengordam": "desengordar",
    "desengordamo": "desengordar",
    "desengordamos": "desengordar",
    "desengordando": "desengordar",
    "desengordara": "desengordar",
    "desengordaram": "desengordar",
    "desengordaras": "desengordar",
    "desengordarde": "desengordar",
    "desengordardes": "desengordar",
    "desengordare": "desengordar",
    "desengordarei": "desengordar",
    "desengordareis": "desengordar",
    "desengordarem": "desengordar",
    "desengordaremos": "desengordar",
    "desengordares": "desengordar",
    "desengordaria": "desengordar",
    "desengordariam": "desengordar",
    "desengordarias": "desengordar",
    "desengordarmo": "desengordar",
    "desengordarmos": "desengordar",
    "desengordará": "desengordar",
    "desengordarás": "desengordar",
    "desengordarão": "desengordar",
    "desengordaríamos": "desengordar",
    "desengordaríeis": "desengordar",
    "desengordas": "desengordar",
    "desengordasse": "desengordar",
    "desengordassem": "desengordar",
    "desengordasses": "desengordar",
    "desengordaste": "desengordar",
    "desengordastes": "desengordar",
    "desengordava": "desengordar",
    "desengordavam": "desengordar",
    "desengordavas": "desengordar",
    "desengorde": "desengordar",
    "desengordei": "desengordar",
    "desengordeis": "desengordar",
    "desengordem": "desengordar",
    "desengordemo": "desengordar",
    "desengordemos": "desengordar",
    "desengordes": "desengordar",
    "desengordo": "desengordar",
    "desengordou": "desengordar",
    "desengordura": "desengordurar",
    "desengordurada": "desengordurar",
    "desengorduradas": "desengordurar",
    "desengordurado": "desengordurar",
    "desengorduradora": "desengordurador",
    "desengorduradoras": "desengordurador",
    "desengorduradores": "desengordurador",
    "desengordurados": "desengordurar",
    "desengordurai": "desengordurar",
    "desengordurais": "desengordurar",
    "desengorduram": "desengordurar",
    "desengorduramo": "desengordurar",
    "desengorduramos": "desengordurar",
    "desengordurando": "desengordurar",
    "desengordurantes": "desengordurante",
    "desengordurara": "desengordurar",
    "desengorduraram": "desengordurar",
    "desengorduraras": "desengordurar",
    "desengordurarde": "desengordurar",
    "desengordurardes": "desengordurar",
    "desengordurare": "desengordurar",
    "desengordurarei": "desengordurar",
    "desengordurareis": "desengordurar",
    "desengordurarem": "desengordurar",
    "desengorduraremos": "desengordurar",
    "desengordurares": "desengordurar",
    "desengorduraria": "desengordurar",
    "desengordurariam": "desengordurar",
    "desengordurarias": "desengordurar",
    "desengordurarmo": "desengordurar",
    "desengordurarmos": "desengordurar",
    "desengordurará": "desengordurar",
    "desengordurarás": "desengordurar",
    "desengordurarão": "desengordurar",
    "desengorduraríamos": "desengordurar",
    "desengorduraríeis": "desengordurar",
    "desengorduras": "desengordurar",
    "desengordurasse": "desengordurar",
    "desengordurassem": "desengordurar",
    "desengordurasses": "desengordurar",
    "desengorduraste": "desengordurar",
    "desengordurastes": "desengordurar",
    "desengordurava": "desengordurar",
    "desengorduravam": "desengordurar",
    "desengorduravas": "desengordurar",
    "desengordure": "desengordurar",
    "desengordurei": "desengordurar",
    "desengordureis": "desengordurar",
    "desengordurem": "desengordurar",
    "desengorduremo": "desengordurar",
    "desengorduremos": "desengordurar",
    "desengordures": "desengordurar",
    "desengorduro": "desengordurar",
    "desengordurou": "desengordurar",
    "desengordurá": "desengordurar",
    "desengordurámo": "desengordurar",
    "desengordurámos": "desengordurar",
    "desengorduráramo": "desengordurar",
    "desengorduráramos": "desengordurar",
    "desengordurárei": "desengordurar",
    "desengorduráreis": "desengordurar",
    "desengordurásseis": "desengordurar",
    "desengordurássemos": "desengordurar",
    "desengordurávamo": "desengordurar",
    "desengordurávamos": "desengordurar",
    "desengordurávei": "desengordurar",
    "desengorduráveis": "desengordurar",
    "desengordá": "desengordar",
    "desengordámo": "desengordar",
    "desengordámos": "desengordar",
    "desengordáramo": "desengordar",
    "desengordáramos": "desengordar",
    "desengordárei": "desengordar",
    "desengordáreis": "desengordar",
    "desengordásseis": "desengordar",
    "desengordássemos": "desengordar",
    "desengordávamo": "desengordar",
    "desengordávamos": "desengordar",
    "desengordávei": "desengordar",
    "desengordáveis": "desengordar",
    "desengorgita": "desengorgitar",
    "desengorgitada": "desengorgitar",
    "desengorgitadas": "desengorgitar",
    "desengorgitado": "desengorgitar",
    "desengorgitados": "desengorgitar",
    "desengorgitai": "desengorgitar",
    "desengorgitais": "desengorgitar",
    "desengorgitam": "desengorgitar",
    "desengorgitamentos": "desengorgitamento",
    "desengorgitamo": "desengorgitar",
    "desengorgitamos": "desengorgitar",
    "desengorgitando": "desengorgitar",
    "desengorgitara": "desengorgitar",
    "desengorgitaram": "desengorgitar",
    "desengorgitaras": "desengorgitar",
    "desengorgitarde": "desengorgitar",
    "desengorgitardes": "desengorgitar",
    "desengorgitare": "desengorgitar",
    "desengorgitarei": "desengorgitar",
    "desengorgitareis": "desengorgitar",
    "desengorgitarem": "desengorgitar",
    "desengorgitaremos": "desengorgitar",
    "desengorgitares": "desengorgitar",
    "desengorgitaria": "desengorgitar",
    "desengorgitariam": "desengorgitar",
    "desengorgitarias": "desengorgitar",
    "desengorgitarmo": "desengorgitar",
    "desengorgitarmos": "desengorgitar",
    "desengorgitará": "desengorgitar",
    "desengorgitarás": "desengorgitar",
    "desengorgitarão": "desengorgitar",
    "desengorgitaríamos": "desengorgitar",
    "desengorgitaríeis": "desengorgitar",
    "desengorgitas": "desengorgitar",
    "desengorgitasse": "desengorgitar",
    "desengorgitassem": "desengorgitar",
    "desengorgitasses": "desengorgitar",
    "desengorgitaste": "desengorgitar",
    "desengorgitastes": "desengorgitar",
    "desengorgitava": "desengorgitar",
    "desengorgitavam": "desengorgitar",
    "desengorgitavas": "desengorgitar",
    "desengorgite": "desengorgitar",
    "desengorgitei": "desengorgitar",
    "desengorgiteis": "desengorgitar",
    "desengorgitem": "desengorgitar",
    "desengorgitemo": "desengorgitar",
    "desengorgitemos": "desengorgitar",
    "desengorgites": "desengorgitar",
    "desengorgito": "desengorgitar",
    "desengorgitou": "desengorgitar",
    "desengorgitá": "desengorgitar",
    "desengorgitámo": "desengorgitar",
    "desengorgitámos": "desengorgitar",
    "desengorgitáramo": "desengorgitar",
    "desengorgitáramos": "desengorgitar",
    "desengorgitárei": "desengorgitar",
    "desengorgitáreis": "desengorgitar",
    "desengorgitásseis": "desengorgitar",
    "desengorgitássemos": "desengorgitar",
    "desengorgitávamo": "desengorgitar",
    "desengorgitávamos": "desengorgitar",
    "desengorgitávei": "desengorgitar",
    "desengorgitáveis": "desengorgitar",
    "desengrace": "desengraçar",
    "desengracei": "desengraçar",
    "desengraceis": "desengraçar",
    "desengracem": "desengraçar",
    "desengracemo": "desengraçar",
    "desengracemos": "desengraçar",
    "desengraces": "desengraçar",
    "desengrainha": "desengrainhar",
    "desengrainhada": "desengrainhar",
    "desengrainhadas": "desengrainhar",
    "desengrainhado": "desengrainhar",
    "desengrainhados": "desengrainhar",
    "desengrainhai": "desengrainhar",
    "desengrainhais": "desengrainhar",
    "desengrainham": "desengrainhar",
    "desengrainhamo": "desengrainhar",
    "desengrainhamos": "desengrainhar",
    "desengrainhando": "desengrainhar",
    "desengrainhara": "desengrainhar",
    "desengrainharam": "desengrainhar",
    "desengrainharas": "desengrainhar",
    "desengrainharde": "desengrainhar",
    "desengrainhardes": "desengrainhar",
    "desengrainhare": "desengrainhar",
    "desengrainharei": "desengrainhar",
    "desengrainhareis": "desengrainhar",
    "desengrainharem": "desengrainhar",
    "desengrainharemos": "desengrainhar",
    "desengrainhares": "desengrainhar",
    "desengrainharia": "desengrainhar",
    "desengrainhariam": "desengrainhar",
    "desengrainharias": "desengrainhar",
    "desengrainharmo": "desengrainhar",
    "desengrainharmos": "desengrainhar",
    "desengrainhará": "desengrainhar",
    "desengrainharás": "desengrainhar",
    "desengrainharão": "desengrainhar",
    "desengrainharíamos": "desengrainhar",
    "desengrainharíeis": "desengrainhar",
    "desengrainhas": "desengrainhar",
    "desengrainhasse": "desengrainhar",
    "desengrainhassem": "desengrainhar",
    "desengrainhasses": "desengrainhar",
    "desengrainhaste": "desengrainhar",
    "desengrainhastes": "desengrainhar",
    "desengrainhava": "desengrainhar",
    "desengrainhavam": "desengrainhar",
    "desengrainhavas": "desengrainhar",
    "desengrainhe": "desengrainhar",
    "desengrainhei": "desengrainhar",
    "desengrainheis": "desengrainhar",
    "desengrainhem": "desengrainhar",
    "desengrainhemo": "desengrainhar",
    "desengrainhemos": "desengrainhar",
    "desengrainhes": "desengrainhar",
    "desengrainho": "desengrainhar",
    "desengrainhou": "desengrainhar",
    "desengrainhá": "desengrainhar",
    "desengrainhámo": "desengrainhar",
    "desengrainhámos": "desengrainhar",
    "desengrainháramo": "desengrainhar",
    "desengrainháramos": "desengrainhar",
    "desengrainhárei": "desengrainhar",
    "desengrainháreis": "desengrainhar",
    "desengrainhásseis": "desengrainhar",
    "desengrainhássemos": "desengrainhar",
    "desengrainhávamo": "desengrainhar",
    "desengrainhávamos": "desengrainhar",
    "desengrainhávei": "desengrainhar",
    "desengrainháveis": "desengrainhar",
    "desengrandece": "desengrandecer",
    "desengrandecei": "desengrandecer",
    "desengrandeceis": "desengrandecer",
    "desengrandecem": "desengrandecer",
    "desengrandecemo": "desengrandecer",
    "desengrandecemos": "desengrandecer",
    "desengrandecendo": "desengrandecer",
    "desengrandecera": "desengrandecer",
    "desengrandeceram": "desengrandecer",
    "desengrandeceras": "desengrandecer",
    "desengrandecerde": "desengrandecer",
    "desengrandecerdes": "desengrandecer",
    "desengrandecere": "desengrandecer",
    "desengrandecerei": "desengrandecer",
    "desengrandecereis": "desengrandecer",
    "desengrandecerem": "desengrandecer",
    "desengrandeceremos": "desengrandecer",
    "desengrandeceres": "desengrandecer",
    "desengrandeceria": "desengrandecer",
    "desengrandeceriam": "desengrandecer",
    "desengrandecerias": "desengrandecer",
    "desengrandecermo": "desengrandecer",
    "desengrandecermos": "desengrandecer",
    "desengrandecerá": "desengrandecer",
    "desengrandecerás": "desengrandecer",
    "desengrandecerão": "desengrandecer",
    "desengrandeceríamos": "desengrandecer",
    "desengrandeceríeis": "desengrandecer",
    "desengrandeces": "desengrandecer",
    "desengrandecesse": "desengrandecer",
    "desengrandecessem": "desengrandecer",
    "desengrandecesses": "desengrandecer",
    "desengrandeceste": "desengrandecer",
    "desengrandecestes": "desengrandecer",
    "desengrandeceu": "desengrandecer",
    "desengrandeci": "desengrandecer",
    "desengrandecia": "desengrandecer",
    "desengrandeciam": "desengrandecer",
    "desengrandecias": "desengrandecer",
    "desengrandecida": "desengrandecido",
    "desengrandecidas": "desengrandecido",
    "desengrandecido": "desengrandecer",
    "desengrandecidos": "desengrandecido",
    "desengrandecê": "desengrandecer",
    "desengrandecêramo": "desengrandecer",
    "desengrandecêramos": "desengrandecer",
    "desengrandecêrei": "desengrandecer",
    "desengrandecêreis": "desengrandecer",
    "desengrandecêsseis": "desengrandecer",
    "desengrandecêssemos": "desengrandecer",
    "desengrandecíamo": "desengrandecer",
    "desengrandecíamos": "desengrandecer",
    "desengrandecíei": "desengrandecer",
    "desengrandecíeis": "desengrandecer",
    "desengrandeça": "desengrandecer",
    "desengrandeçais": "desengrandecer",
    "desengrandeçam": "desengrandecer",
    "desengrandeçamo": "desengrandecer",
    "desengrandeçamos": "desengrandecer",
    "desengrandeças": "desengrandecer",
    "desengrandeço": "desengrandecer",
    "desengranza": "desengranzar",
    "desengranzada": "desengranzar",
    "desengranzadas": "desengranzar",
    "desengranzado": "desengranzar",
    "desengranzados": "desengranzar",
    "desengranzai": "desengranzar",
    "desengranzais": "desengranzar",
    "desengranzam": "desengranzar",
    "desengranzamo": "desengranzar",
    "desengranzamos": "desengranzar",
    "desengranzando": "desengranzar",
    "desengranzara": "desengranzar",
    "desengranzaram": "desengranzar",
    "desengranzaras": "desengranzar",
    "desengranzarde": "desengranzar",
    "desengranzardes": "desengranzar",
    "desengranzare": "desengranzar",
    "desengranzarei": "desengranzar",
    "desengranzareis": "desengranzar",
    "desengranzarem": "desengranzar",
    "desengranzaremos": "desengranzar",
    "desengranzares": "desengranzar",
    "desengranzaria": "desengranzar",
    "desengranzariam": "desengranzar",
    "desengranzarias": "desengranzar",
    "desengranzarmo": "desengranzar",
    "desengranzarmos": "desengranzar",
    "desengranzará": "desengranzar",
    "desengranzarás": "desengranzar",
    "desengranzarão": "desengranzar",
    "desengranzaríamos": "desengranzar",
    "desengranzaríeis": "desengranzar",
    "desengranzas": "desengranzar",
    "desengranzasse": "desengranzar",
    "desengranzassem": "desengranzar",
    "desengranzasses": "desengranzar",
    "desengranzaste": "desengranzar",
    "desengranzastes": "desengranzar",
    "desengranzava": "desengranzar",
    "desengranzavam": "desengranzar",
    "desengranzavas": "desengranzar",
    "desengranze": "desengranzar",
    "desengranzei": "desengranzar",
    "desengranzeis": "desengranzar",
    "desengranzem": "desengranzar",
    "desengranzemo": "desengranzar",
    "desengranzemos": "desengranzar",
    "desengranzes": "desengranzar",
    "desengranzo": "desengranzar",
    "desengranzou": "desengranzar",
    "desengranzá": "desengranzar",
    "desengranzámo": "desengranzar",
    "desengranzámos": "desengranzar",
    "desengranzáramo": "desengranzar",
    "desengranzáramos": "desengranzar",
    "desengranzárei": "desengranzar",
    "desengranzáreis": "desengranzar",
    "desengranzásseis": "desengranzar",
    "desengranzássemos": "desengranzar",
    "desengranzávamo": "desengranzar",
    "desengranzávamos": "desengranzar",
    "desengranzávei": "desengranzar",
    "desengranzáveis": "desengranzar",
    "desengravece": "desengravecer",
    "desengravecei": "desengravecer",
    "desengraveceis": "desengravecer",
    "desengravecem": "desengravecer",
    "desengravecemo": "desengravecer",
    "desengravecemos": "desengravecer",
    "desengravecendo": "desengravecer",
    "desengravecera": "desengravecer",
    "desengraveceram": "desengravecer",
    "desengraveceras": "desengravecer",
    "desengravecerde": "desengravecer",
    "desengravecerdes": "desengravecer",
    "desengravecere": "desengravecer",
    "desengravecerei": "desengravecer",
    "desengravecereis": "desengravecer",
    "desengravecerem": "desengravecer",
    "desengraveceremos": "desengravecer",
    "desengraveceres": "desengravecer",
    "desengraveceria": "desengravecer",
    "desengraveceriam": "desengravecer",
    "desengravecerias": "desengravecer",
    "desengravecermo": "desengravecer",
    "desengravecermos": "desengravecer",
    "desengravecerá": "desengravecer",
    "desengravecerás": "desengravecer",
    "desengravecerão": "desengravecer",
    "desengraveceríamos": "desengravecer",
    "desengraveceríeis": "desengravecer",
    "desengraveces": "desengravecer",
    "desengravecesse": "desengravecer",
    "desengravecessem": "desengravecer",
    "desengravecesses": "desengravecer",
    "desengraveceste": "desengravecer",
    "desengravecestes": "desengravecer",
    "desengraveceu": "desengravecer",
    "desengraveci": "desengravecer",
    "desengravecia": "desengravecer",
    "desengraveciam": "desengravecer",
    "desengravecias": "desengravecer",
    "desengravecida": "desengravecido",
    "desengravecidas": "desengravecido",
    "desengravecido": "desengravecer",
    "desengravecidos": "desengravecido",
    "desengravecê": "desengravecer",
    "desengravecêramo": "desengravecer",
    "desengravecêramos": "desengravecer",
    "desengravecêrei": "desengravecer",
    "desengravecêreis": "desengravecer",
    "desengravecêsseis": "desengravecer",
    "desengravecêssemos": "desengravecer",
    "desengravecíamo": "desengravecer",
    "desengravecíamos": "desengravecer",
    "desengravecíei": "desengravecer",
    "desengravecíeis": "desengravecer",
    "desengraveça": "desengravecer",
    "desengraveçais": "desengravecer",
    "desengraveçam": "desengravecer",
    "desengraveçamo": "desengravecer",
    "desengraveçamos": "desengravecer",
    "desengraveças": "desengravecer",
    "desengraveço": "desengravecer",
    "desengraxa": "desengraxar",
    "desengraxada": "desengraxar",
    "desengraxadas": "desengraxar",
    "desengraxado": "desengraxar",
    "desengraxados": "desengraxar",
    "desengraxai": "desengraxar",
    "desengraxais": "desengraxar",
    "desengraxam": "desengraxar",
    "desengraxamo": "desengraxar",
    "desengraxamos": "desengraxar",
    "desengraxando": "desengraxar",
    "desengraxara": "desengraxar",
    "desengraxaram": "desengraxar",
    "desengraxaras": "desengraxar",
    "desengraxarde": "desengraxar",
    "desengraxardes": "desengraxar",
    "desengraxare": "desengraxar",
    "desengraxarei": "desengraxar",
    "desengraxareis": "desengraxar",
    "desengraxarem": "desengraxar",
    "desengraxaremos": "desengraxar",
    "desengraxares": "desengraxar",
    "desengraxaria": "desengraxar",
    "desengraxariam": "desengraxar",
    "desengraxarias": "desengraxar",
    "desengraxarmo": "desengraxar",
    "desengraxarmos": "desengraxar",
    "desengraxará": "desengraxar",
    "desengraxarás": "desengraxar",
    "desengraxarão": "desengraxar",
    "desengraxaríamos": "desengraxar",
    "desengraxaríeis": "desengraxar",
    "desengraxas": "desengraxar",
    "desengraxasse": "desengraxar",
    "desengraxassem": "desengraxar",
    "desengraxasses": "desengraxar",
    "desengraxaste": "desengraxar",
    "desengraxastes": "desengraxar",
    "desengraxava": "desengraxar",
    "desengraxavam": "desengraxar",
    "desengraxavas": "desengraxar",
    "desengraxe": "desengraxar",
    "desengraxei": "desengraxar",
    "desengraxeis": "desengraxar",
    "desengraxem": "desengraxar",
    "desengraxemo": "desengraxar",
    "desengraxemos": "desengraxar",
    "desengraxes": "desengraxar",
    "desengraxo": "desengraxar",
    "desengraxou": "desengraxar",
    "desengraxá": "desengraxar",
    "desengraxámo": "desengraxar",
    "desengraxámos": "desengraxar",
    "desengraxáramo": "desengraxar",
    "desengraxáramos": "desengraxar",
    "desengraxárei": "desengraxar",
    "desengraxáreis": "desengraxar",
    "desengraxásseis": "desengraxar",
    "desengraxássemos": "desengraxar",
    "desengraxávamo": "desengraxar",
    "desengraxávamos": "desengraxar",
    "desengraxávei": "desengraxar",
    "desengraxáveis": "desengraxar",
    "desengraça": "desengraçar",
    "desengraçada": "desengraçar",
    "desengraçadas": "desengraçar",
    "desengraçado": "desengraçar",
    "desengraçados": "desengraçar",
    "desengraçai": "desengraçar",
    "desengraçais": "desengraçar",
    "desengraçam": "desengraçar",
    "desengraçamo": "desengraçar",
    "desengraçamos": "desengraçar",
    "desengraçando": "desengraçar",
    "desengraçara": "desengraçar",
    "desengraçaram": "desengraçar",
    "desengraçaras": "desengraçar",
    "desengraçarde": "desengraçar",
    "desengraçardes": "desengraçar",
    "desengraçare": "desengraçar",
    "desengraçarei": "desengraçar",
    "desengraçareis": "desengraçar",
    "desengraçarem": "desengraçar",
    "desengraçaremos": "desengraçar",
    "desengraçares": "desengraçar",
    "desengraçaria": "desengraçar",
    "desengraçariam": "desengraçar",
    "desengraçarias": "desengraçar",
    "desengraçarmo": "desengraçar",
    "desengraçarmos": "desengraçar",
    "desengraçará": "desengraçar",
    "desengraçarás": "desengraçar",
    "desengraçarão": "desengraçar",
    "desengraçaríamos": "desengraçar",
    "desengraçaríeis": "desengraçar",
    "desengraças": "desengraçar",
    "desengraçasse": "desengraçar",
    "desengraçassem": "desengraçar",
    "desengraçasses": "desengraçar",
    "desengraçaste": "desengraçar",
    "desengraçastes": "desengraçar",
    "desengraçava": "desengraçar",
    "desengraçavam": "desengraçar",
    "desengraçavas": "desengraçar",
    "desengraço": "desengraçar",
    "desengraçou": "desengraçar",
    "desengraçá": "desengraçar",
    "desengraçámo": "desengraçar",
    "desengraçámos": "desengraçar",
    "desengraçáramo": "desengraçar",
    "desengraçáramos": "desengraçar",
    "desengraçárei": "desengraçar",
    "desengraçáreis": "desengraçar",
    "desengraçásseis": "desengraçar",
    "desengraçássemos": "desengraçar",
    "desengraçávamo": "desengraçar",
    "desengraçávamos": "desengraçar",
    "desengraçávei": "desengraçar",
    "desengraçáveis": "desengraçar",
    "desengrenada": "desengrenado",
    "desengrenadas": "desengrenado",
    "desengrenados": "desengrenado",
    "desengrila": "desengrilar",
    "desengrilada": "desengrilar",
    "desengriladas": "desengrilar",
    "desengrilado": "desengrilar",
    "desengrilados": "desengrilar",
    "desengrilai": "desengrilar",
    "desengrilais": "desengrilar",
    "desengrilam": "desengrilar",
    "desengrilamo": "desengrilar",
    "desengrilamos": "desengrilar",
    "desengrilando": "desengrilar",
    "desengrilara": "desengrilar",
    "desengrilaram": "desengrilar",
    "desengrilaras": "desengrilar",
    "desengrilarde": "desengrilar",
    "desengrilardes": "desengrilar",
    "desengrilare": "desengrilar",
    "desengrilarei": "desengrilar",
    "desengrilareis": "desengrilar",
    "desengrilarem": "desengrilar",
    "desengrilaremos": "desengrilar",
    "desengrilares": "desengrilar",
    "desengrilaria": "desengrilar",
    "desengrilariam": "desengrilar",
    "desengrilarias": "desengrilar",
    "desengrilarmo": "desengrilar",
    "desengrilarmos": "desengrilar",
    "desengrilará": "desengrilar",
    "desengrilarás": "desengrilar",
    "desengrilarão": "desengrilar",
    "desengrilaríamos": "desengrilar",
    "desengrilaríeis": "desengrilar",
    "desengrilas": "desengrilar",
    "desengrilasse": "desengrilar",
    "desengrilassem": "desengrilar",
    "desengrilasses": "desengrilar",
    "desengrilaste": "desengrilar",
    "desengrilastes": "desengrilar",
    "desengrilava": "desengrilar",
    "desengrilavam": "desengrilar",
    "desengrilavas": "desengrilar",
    "desengrile": "desengrilar",
    "desengrilei": "desengrilar",
    "desengrileis": "desengrilar",
    "desengrilem": "desengrilar",
    "desengrilemo": "desengrilar",
    "desengrilemos": "desengrilar",
    "desengriles": "desengrilar",
    "desengrilo": "desengrilar",
    "desengrilou": "desengrilar",
    "desengrilá": "desengrilar",
    "desengrilámo": "desengrilar",
    "desengrilámos": "desengrilar",
    "desengriláramo": "desengrilar",
    "desengriláramos": "desengrilar",
    "desengrilárei": "desengrilar",
    "desengriláreis": "desengrilar",
    "desengrilásseis": "desengrilar",
    "desengrilássemos": "desengrilar",
    "desengrilávamo": "desengrilar",
    "desengrilávamos": "desengrilar",
    "desengrilávei": "desengrilar",
    "desengriláveis": "desengrilar",
    "desengrimpa": "desengrimpar",
    "desengrimpada": "desengrimpar",
    "desengrimpadas": "desengrimpar",
    "desengrimpado": "desengrimpar",
    "desengrimpados": "desengrimpar",
    "desengrimpai": "desengrimpar",
    "desengrimpais": "desengrimpar",
    "desengrimpam": "desengrimpar",
    "desengrimpamo": "desengrimpar",
    "desengrimpamos": "desengrimpar",
    "desengrimpando": "desengrimpar",
    "desengrimpara": "desengrimpar",
    "desengrimparam": "desengrimpar",
    "desengrimparas": "desengrimpar",
    "desengrimparde": "desengrimpar",
    "desengrimpardes": "desengrimpar",
    "desengrimpare": "desengrimpar",
    "desengrimparei": "desengrimpar",
    "desengrimpareis": "desengrimpar",
    "desengrimparem": "desengrimpar",
    "desengrimparemos": "desengrimpar",
    "desengrimpares": "desengrimpar",
    "desengrimparia": "desengrimpar",
    "desengrimpariam": "desengrimpar",
    "desengrimparias": "desengrimpar",
    "desengrimparmo": "desengrimpar",
    "desengrimparmos": "desengrimpar",
    "desengrimpará": "desengrimpar",
    "desengrimparás": "desengrimpar",
    "desengrimparão": "desengrimpar",
    "desengrimparíamos": "desengrimpar",
    "desengrimparíeis": "desengrimpar",
    "desengrimpas": "desengrimpar",
    "desengrimpasse": "desengrimpar",
    "desengrimpassem": "desengrimpar",
    "desengrimpasses": "desengrimpar",
    "desengrimpaste": "desengrimpar",
    "desengrimpastes": "desengrimpar",
    "desengrimpava": "desengrimpar",
    "desengrimpavam": "desengrimpar",
    "desengrimpavas": "desengrimpar",
    "desengrimpe": "desengrimpar",
    "desengrimpei": "desengrimpar",
    "desengrimpeis": "desengrimpar",
    "desengrimpem": "desengrimpar",
    "desengrimpemo": "desengrimpar",
    "desengrimpemos": "desengrimpar",
    "desengrimpes": "desengrimpar",
    "desengrimpo": "desengrimpar",
    "desengrimpou": "desengrimpar",
    "desengrimpá": "desengrimpar",
    "desengrimpámo": "desengrimpar",
    "desengrimpámos": "desengrimpar",
    "desengrimpáramo": "desengrimpar",
    "desengrimpáramos": "desengrimpar",
    "desengrimpárei": "desengrimpar",
    "desengrimpáreis": "desengrimpar",
    "desengrimpásseis": "desengrimpar",
    "desengrimpássemos": "desengrimpar",
    "desengrimpávamo": "desengrimpar",
    "desengrimpávamos": "desengrimpar",
    "desengrimpávei": "desengrimpar",
    "desengrimpáveis": "desengrimpar",
    "desengrinalda": "desengrinaldar",
    "desengrinaldada": "desengrinaldar",
    "desengrinaldadas": "desengrinaldar",
    "desengrinaldado": "desengrinaldar",
    "desengrinaldados": "desengrinaldar",
    "desengrinaldai": "desengrinaldar",
    "desengrinaldais": "desengrinaldar",
    "desengrinaldam": "desengrinaldar",
    "desengrinaldamo": "desengrinaldar",
    "desengrinaldamos": "desengrinaldar",
    "desengrinaldando": "desengrinaldar",
    "desengrinaldara": "desengrinaldar",
    "desengrinaldaram": "desengrinaldar",
    "desengrinaldaras": "desengrinaldar",
    "desengrinaldarde": "desengrinaldar",
    "desengrinaldardes": "desengrinaldar",
    "desengrinaldare": "desengrinaldar",
    "desengrinaldarei": "desengrinaldar",
    "desengrinaldareis": "desengrinaldar",
    "desengrinaldarem": "desengrinaldar",
    "desengrinaldaremos": "desengrinaldar",
    "desengrinaldares": "desengrinaldar",
    "desengrinaldaria": "desengrinaldar",
    "desengrinaldariam": "desengrinaldar",
    "desengrinaldarias": "desengrinaldar",
    "desengrinaldarmo": "desengrinaldar",
    "desengrinaldarmos": "desengrinaldar",
    "desengrinaldará": "desengrinaldar",
    "desengrinaldarás": "desengrinaldar",
    "desengrinaldarão": "desengrinaldar",
    "desengrinaldaríamos": "desengrinaldar",
    "desengrinaldaríeis": "desengrinaldar",
    "desengrinaldas": "desengrinaldar",
    "desengrinaldasse": "desengrinaldar",
    "desengrinaldassem": "desengrinaldar",
    "desengrinaldasses": "desengrinaldar",
    "desengrinaldaste": "desengrinaldar",
    "desengrinaldastes": "desengrinaldar",
    "desengrinaldava": "desengrinaldar",
    "desengrinaldavam": "desengrinaldar",
    "desengrinaldavas": "desengrinaldar",
    "desengrinalde": "desengrinaldar",
    "desengrinaldei": "desengrinaldar",
    "desengrinaldeis": "desengrinaldar",
    "desengrinaldem": "desengrinaldar",
    "desengrinaldemo": "desengrinaldar",
    "desengrinaldemos": "desengrinaldar",
    "desengrinaldes": "desengrinaldar",
    "desengrinaldo": "desengrinaldar",
    "desengrinaldou": "desengrinaldar",
    "desengrinaldá": "desengrinaldar",
    "desengrinaldámo": "desengrinaldar",
    "desengrinaldámos": "desengrinaldar",
    "desengrinaldáramo": "desengrinaldar",
    "desengrinaldáramos": "desengrinaldar",
    "desengrinaldárei": "desengrinaldar",
    "desengrinaldáreis": "desengrinaldar",
    "desengrinaldásseis": "desengrinaldar",
    "desengrinaldássemos": "desengrinaldar",
    "desengrinaldávamo": "desengrinaldar",
    "desengrinaldávamos": "desengrinaldar",
    "desengrinaldávei": "desengrinaldar",
    "desengrinaldáveis": "desengrinaldar",
    "desengrossa": "desengrossar",
    "desengrossada": "desengrossar",
    "desengrossadas": "desengrossar",
    "desengrossadeiras": "desengrossadeira",
    "desengrossado": "desengrossar",
    "desengrossados": "desengrossar",
    "desengrossai": "desengrossar",
    "desengrossais": "desengrossar",
    "desengrossam": "desengrossar",
    "desengrossamentos": "desengrossamento",
    "desengrossamo": "desengrossar",
    "desengrossamos": "desengrossar",
    "desengrossando": "desengrossar",
    "desengrossara": "desengrossar",
    "desengrossaram": "desengrossar",
    "desengrossaras": "desengrossar",
    "desengrossarde": "desengrossar",
    "desengrossardes": "desengrossar",
    "desengrossare": "desengrossar",
    "desengrossarei": "desengrossar",
    "desengrossareis": "desengrossar",
    "desengrossarem": "desengrossar",
    "desengrossaremos": "desengrossar",
    "desengrossares": "desengrossar",
    "desengrossaria": "desengrossar",
    "desengrossariam": "desengrossar",
    "desengrossarias": "desengrossar",
    "desengrossarmo": "desengrossar",
    "desengrossarmos": "desengrossar",
    "desengrossará": "desengrossar",
    "desengrossarás": "desengrossar",
    "desengrossarão": "desengrossar",
    "desengrossaríamos": "desengrossar",
    "desengrossaríeis": "desengrossar",
    "desengrossas": "desengrossar",
    "desengrossasse": "desengrossar",
    "desengrossassem": "desengrossar",
    "desengrossasses": "desengrossar",
    "desengrossaste": "desengrossar",
    "desengrossastes": "desengrossar",
    "desengrossava": "desengrossar",
    "desengrossavam": "desengrossar",
    "desengrossavas": "desengrossar",
    "desengrosse": "desengrossar",
    "desengrossei": "desengrossar",
    "desengrosseis": "desengrossar",
    "desengrossem": "desengrossar",
    "desengrossemo": "desengrossar",
    "desengrossemos": "desengrossar",
    "desengrosses": "desengrossar",
    "desengrosso": "desengrossar",
    "desengrossos": "desengrosso",
    "desengrossou": "desengrossar",
    "desengrossá": "desengrossar",
    "desengrossámo": "desengrossar",
    "desengrossámos": "desengrossar",
    "desengrossáramo": "desengrossar",
    "desengrossáramos": "desengrossar",
    "desengrossárei": "desengrossar",
    "desengrossáreis": "desengrossar",
    "desengrossásseis": "desengrossar",
    "desengrossássemos": "desengrossar",
    "desengrossávamo": "desengrossar",
    "desengrossávamos": "desengrossar",
    "desengrossávei": "desengrossar",
    "desengrossáveis": "desengrossar",
    "desengruma": "desengrumar",
    "desengrumada": "desengrumar",
    "desengrumadas": "desengrumar",
    "desengrumado": "desengrumar",
    "desengrumados": "desengrumar",
    "desengrumai": "desengrumar",
    "desengrumais": "desengrumar",
    "desengrumam": "desengrumar",
    "desengrumamo": "desengrumar",
    "desengrumamos": "desengrumar",
    "desengrumando": "desengrumar",
    "desengrumara": "desengrumar",
    "desengrumaram": "desengrumar",
    "desengrumaras": "desengrumar",
    "desengrumarde": "desengrumar",
    "desengrumardes": "desengrumar",
    "desengrumare": "desengrumar",
    "desengrumarei": "desengrumar",
    "desengrumareis": "desengrumar",
    "desengrumarem": "desengrumar",
    "desengrumaremos": "desengrumar",
    "desengrumares": "desengrumar",
    "desengrumaria": "desengrumar",
    "desengrumariam": "desengrumar",
    "desengrumarias": "desengrumar",
    "desengrumarmo": "desengrumar",
    "desengrumarmos": "desengrumar",
    "desengrumará": "desengrumar",
    "desengrumarás": "desengrumar",
    "desengrumarão": "desengrumar",
    "desengrumaríamos": "desengrumar",
    "desengrumaríeis": "desengrumar",
    "desengrumas": "desengrumar",
    "desengrumasse": "desengrumar",
    "desengrumassem": "desengrumar",
    "desengrumasses": "desengrumar",
    "desengrumaste": "desengrumar",
    "desengrumastes": "desengrumar",
    "desengrumava": "desengrumar",
    "desengrumavam": "desengrumar",
    "desengrumavas": "desengrumar",
    "desengrume": "desengrumar",
    "desengrumei": "desengrumar",
    "desengrumeis": "desengrumar",
    "desengrumem": "desengrumar",
    "desengrumemo": "desengrumar",
    "desengrumemos": "desengrumar",
    "desengrumes": "desengrumar",
    "desengrumo": "desengrumar",
    "desengrumou": "desengrumar",
    "desengrumá": "desengrumar",
    "desengrumámo": "desengrumar",
    "desengrumámos": "desengrumar",
    "desengrumáramo": "desengrumar",
    "desengrumáramos": "desengrumar",
    "desengrumárei": "desengrumar",
    "desengrumáreis": "desengrumar",
    "desengrumásseis": "desengrumar",
    "desengrumássemos": "desengrumar",
    "desengrumávamo": "desengrumar",
    "desengrumávamos": "desengrumar",
    "desengrumávei": "desengrumar",
    "desengrumáveis": "desengrumar",
    "desengrunha": "desengrunhir",
    "desengrunhais": "desengrunhir",
    "desengrunham": "desengrunhir",
    "desengrunhamo": "desengrunhir",
    "desengrunhamos": "desengrunhir",
    "desengrunhas": "desengrunhir",
    "desengrunhe": "desengrunhir",
    "desengrunhem": "desengrunhir",
    "desengrunhes": "desengrunhir",
    "desengrunhi": "desengrunhir",
    "desengrunhia": "desengrunhir",
    "desengrunhiam": "desengrunhir",
    "desengrunhias": "desengrunhir",
    "desengrunhida": "desengrunhir",
    "desengrunhidas": "desengrunhir",
    "desengrunhido": "desengrunhir",
    "desengrunhidos": "desengrunhir",
    "desengrunhimo": "desengrunhir",
    "desengrunhimos": "desengrunhir",
    "desengrunhindo": "desengrunhir",
    "desengrunhira": "desengrunhir",
    "desengrunhiram": "desengrunhir",
    "desengrunhiras": "desengrunhir",
    "desengrunhirdes": "desengrunhir",
    "desengrunhirei": "desengrunhir",
    "desengrunhireis": "desengrunhir",
    "desengrunhirem": "desengrunhir",
    "desengrunhiremos": "desengrunhir",
    "desengrunhires": "desengrunhir",
    "desengrunhiria": "desengrunhir",
    "desengrunhiriam": "desengrunhir",
    "desengrunhirias": "desengrunhir",
    "desengrunhirmo": "desengrunhir",
    "desengrunhirmos": "desengrunhir",
    "desengrunhirá": "desengrunhir",
    "desengrunhirás": "desengrunhir",
    "desengrunhirão": "desengrunhir",
    "desengrunhiríamos": "desengrunhir",
    "desengrunhiríeis": "desengrunhir",
    "desengrunhis": "desengrunhir",
    "desengrunhisse": "desengrunhir",
    "desengrunhissem": "desengrunhir",
    "desengrunhisses": "desengrunhir",
    "desengrunhiste": "desengrunhir",
    "desengrunhistes": "desengrunhir",
    "desengrunhiu": "desengrunhir",
    "desengrunho": "desengrunhir",
    "desengrunhíamo": "desengrunhir",
    "desengrunhíamos": "desengrunhir",
    "desengrunhíeis": "desengrunhir",
    "desengrunhíramo": "desengrunhir",
    "desengrunhíramos": "desengrunhir",
    "desengrunhíreis": "desengrunhir",
    "desengrunhísseis": "desengrunhir",
    "desengrunhíssemos": "desengrunhir",
    "desenguice": "desenguiçar",
    "desenguicei": "desenguiçar",
    "desenguiceis": "desenguiçar",
    "desenguicem": "desenguiçar",
    "desenguicemo": "desenguiçar",
    "desenguicemos": "desenguiçar",
    "desenguices": "desenguiçar",
    "desenguiça": "desenguiçar",
    "desenguiçada": "desenguiçar",
    "desenguiçadas": "desenguiçar",
    "desenguiçado": "desenguiçar",
    "desenguiçados": "desenguiçar",
    "desenguiçai": "desenguiçar",
    "desenguiçais": "desenguiçar",
    "desenguiçam": "desenguiçar",
    "desenguiçamo": "desenguiçar",
    "desenguiçamos": "desenguiçar",
    "desenguiçando": "desenguiçar",
    "desenguiçara": "desenguiçar",
    "desenguiçaram": "desenguiçar",
    "desenguiçaras": "desenguiçar",
    "desenguiçarde": "desenguiçar",
    "desenguiçardes": "desenguiçar",
    "desenguiçare": "desenguiçar",
    "desenguiçarei": "desenguiçar",
    "desenguiçareis": "desenguiçar",
    "desenguiçarem": "desenguiçar",
    "desenguiçaremos": "desenguiçar",
    "desenguiçares": "desenguiçar",
    "desenguiçaria": "desenguiçar",
    "desenguiçariam": "desenguiçar",
    "desenguiçarias": "desenguiçar",
    "desenguiçarmo": "desenguiçar",
    "desenguiçarmos": "desenguiçar",
    "desenguiçará": "desenguiçar",
    "desenguiçarás": "desenguiçar",
    "desenguiçarão": "desenguiçar",
    "desenguiçaríamos": "desenguiçar",
    "desenguiçaríeis": "desenguiçar",
    "desenguiças": "desenguiçar",
    "desenguiçasse": "desenguiçar",
    "desenguiçassem": "desenguiçar",
    "desenguiçasses": "desenguiçar",
    "desenguiçaste": "desenguiçar",
    "desenguiçastes": "desenguiçar",
    "desenguiçava": "desenguiçar",
    "desenguiçavam": "desenguiçar",
    "desenguiçavas": "desenguiçar",
    "desenguiço": "desenguiçar",
    "desenguiços": "desenguiço",
    "desenguiçou": "desenguiçar",
    "desenguiçá": "desenguiçar",
    "desenguiçámo": "desenguiçar",
    "desenguiçámos": "desenguiçar",
    "desenguiçáramo": "desenguiçar",
    "desenguiçáramos": "desenguiçar",
    "desenguiçárei": "desenguiçar",
    "desenguiçáreis": "desenguiçar",
    "desenguiçásseis": "desenguiçar",
    "desenguiçássemos": "desenguiçar",
    "desenguiçávamo": "desenguiçar",
    "desenguiçávamos": "desenguiçar",
    "desenguiçávei": "desenguiçar",
    "desenguiçáveis": "desenguiçar",
    "desengula": "desengolir",
    "desengulais": "desengolir",
    "desengulam": "desengolir",
    "desengulamo": "desengolir",
    "desengulamos": "desengolir",
    "desengulas": "desengolir",
    "desengulha": "desengulhar",
    "desengulhada": "desengulhar",
    "desengulhadas": "desengulhar",
    "desengulhado": "desengulhar",
    "desengulhados": "desengulhar",
    "desengulhai": "desengulhar",
    "desengulhais": "desengulhar",
    "desengulham": "desengulhar",
    "desengulhamo": "desengulhar",
    "desengulhamos": "desengulhar",
    "desengulhando": "desengulhar",
    "desengulhara": "desengulhar",
    "desengulharam": "desengulhar",
    "desengulharas": "desengulhar",
    "desengulharde": "desengulhar",
    "desengulhardes": "desengulhar",
    "desengulhare": "desengulhar",
    "desengulharei": "desengulhar",
    "desengulhareis": "desengulhar",
    "desengulharem": "desengulhar",
    "desengulharemos": "desengulhar",
    "desengulhares": "desengulhar",
    "desengulharia": "desengulhar",
    "desengulhariam": "desengulhar",
    "desengulharias": "desengulhar",
    "desengulharmo": "desengulhar",
    "desengulharmos": "desengulhar",
    "desengulhará": "desengulhar",
    "desengulharás": "desengulhar",
    "desengulharão": "desengulhar",
    "desengulharíamos": "desengulhar",
    "desengulharíeis": "desengulhar",
    "desengulhas": "desengulhar",
    "desengulhasse": "desengulhar",
    "desengulhassem": "desengulhar",
    "desengulhasses": "desengulhar",
    "desengulhaste": "desengulhar",
    "desengulhastes": "desengulhar",
    "desengulhava": "desengulhar",
    "desengulhavam": "desengulhar",
    "desengulhavas": "desengulhar",
    "desengulhe": "desengulhar",
    "desengulhei": "desengulhar",
    "desengulheis": "desengulhar",
    "desengulhem": "desengulhar",
    "desengulhemo": "desengulhar",
    "desengulhemos": "desengulhar",
    "desengulhes": "desengulhar",
    "desengulho": "desengulhar",
    "desengulhou": "desengulhar",
    "desengulhá": "desengulhar",
    "desengulhámo": "desengulhar",
    "desengulhámos": "desengulhar",
    "desengulháramo": "desengulhar",
    "desengulháramos": "desengulhar",
    "desengulhárei": "desengulhar",
    "desengulháreis": "desengulhar",
    "desengulhásseis": "desengulhar",
    "desengulhássemos": "desengulhar",
    "desengulhávamo": "desengulhar",
    "desengulhávamos": "desengulhar",
    "desengulhávei": "desengulhar",
    "desengulháveis": "desengulhar",
    "desenguli": "desengolir",
    "desengulo": "desengolir",
    "desenha": "desenhar",
    "desenhada": "desenhar",
    "desenhadas": "desenhar",
    "desenhado": "desenhar",
    "desenhadora": "desenhador",
    "desenhadoras": "desenhador",
    "desenhadores": "desenhador",
    "desenhados": "desenhar",
    "desenhai": "desenhar",
    "desenhais": "desenhar",
    "desenham": "desenhar",
    "desenhamo": "desenhar",
    "desenhamos": "desenhar",
    "desenhando": "desenhar",
    "desenhara": "desenhar",
    "desenharam": "desenhar",
    "desenharas": "desenhar",
    "desenharde": "desenhar",
    "desenhardes": "desenhar",
    "desenhare": "desenhar",
    "desenharei": "desenhar",
    "desenhareis": "desenhar",
    "desenharem": "desenhar",
    "desenharemos": "desenhar",
    "desenhares": "desenhar",
    "desenharia": "desenhar",
    "desenhariam": "desenhar",
    "desenharias": "desenhar",
    "desenharmo": "desenhar",
    "desenharmos": "desenhar",
    "desenhará": "desenhar",
    "desenharás": "desenhar",
    "desenharão": "desenhar",
    "desenharíamos": "desenhar",
    "desenharíeis": "desenhar",
    "desenhas": "desenhar",
    "desenhasse": "desenhar",
    "desenhassem": "desenhar",
    "desenhasses": "desenhar",
    "desenhaste": "desenhar",
    "desenhastes": "desenhar",
    "desenhava": "desenhar",
    "desenhavam": "desenhar",
    "desenhavas": "desenhar",
    "desenhe": "desenhar",
    "desenhei": "desenhar",
    "desenheis": "desenhar",
    "desenhem": "desenhar",
    "desenhemo": "desenhar",
    "desenhemos": "desenhar",
    "desenhes": "desenhar",
    "desenhistas": "desenhista",
    "desenho": "desenhar",
    "desenhos": "desenho",
    "desenhou": "desenhar",
    "desenhá": "desenhar",
    "desenhámo": "desenhar",
    "desenhámos": "desenhar",
    "desenháramo": "desenhar",
    "desenháramos": "desenhar",
    "desenhárei": "desenhar",
    "desenháreis": "desenhar",
    "desenhásseis": "desenhar",
    "desenhássemos": "desenhar",
    "desenhávamo": "desenhar",
    "desenhávamos": "desenhar",
    "desenhávei": "desenhar",
    "desenháveis": "desenhar",
    "desenjaula": "desenjaular",
    "desenjaulada": "desenjaular",
    "desenjauladas": "desenjaular",
    "desenjaulado": "desenjaular",
    "desenjaulados": "desenjaular",
    "desenjaulai": "desenjaular",
    "desenjaulais": "desenjaular",
    "desenjaulam": "desenjaular",
    "desenjaulamo": "desenjaular",
    "desenjaulamos": "desenjaular",
    "desenjaulando": "desenjaular",
    "desenjaulara": "desenjaular",
    "desenjaularam": "desenjaular",
    "desenjaularas": "desenjaular",
    "desenjaularde": "desenjaular",
    "desenjaulardes": "desenjaular",
    "desenjaulare": "desenjaular",
    "desenjaularei": "desenjaular",
    "desenjaulareis": "desenjaular",
    "desenjaularem": "desenjaular",
    "desenjaularemos": "desenjaular",
    "desenjaulares": "desenjaular",
    "desenjaularia": "desenjaular",
    "desenjaulariam": "desenjaular",
    "desenjaularias": "desenjaular",
    "desenjaularmo": "desenjaular",
    "desenjaularmos": "desenjaular",
    "desenjaulará": "desenjaular",
    "desenjaularás": "desenjaular",
    "desenjaularão": "desenjaular",
    "desenjaularíamos": "desenjaular",
    "desenjaularíeis": "desenjaular",
    "desenjaulas": "desenjaular",
    "desenjaulasse": "desenjaular",
    "desenjaulassem": "desenjaular",
    "desenjaulasses": "desenjaular",
    "desenjaulaste": "desenjaular",
    "desenjaulastes": "desenjaular",
    "desenjaulava": "desenjaular",
    "desenjaulavam": "desenjaular",
    "desenjaulavas": "desenjaular",
    "desenjaule": "desenjaular",
    "desenjaulei": "desenjaular",
    "desenjauleis": "desenjaular",
    "desenjaulem": "desenjaular",
    "desenjaulemo": "desenjaular",
    "desenjaulemos": "desenjaular",
    "desenjaules": "desenjaular",
    "desenjaulo": "desenjaular",
    "desenjaulou": "desenjaular",
    "desenjaulá": "desenjaular",
    "desenjaulámo": "desenjaular",
    "desenjaulámos": "desenjaular",
    "desenjauláramo": "desenjaular",
    "desenjauláramos": "desenjaular",
    "desenjaulárei": "desenjaular",
    "desenjauláreis": "desenjaular",
    "desenjaulásseis": "desenjaular",
    "desenjaulássemos": "desenjaular",
    "desenjaulávamo": "desenjaular",
    "desenjaulávamos": "desenjaular",
    "desenjaulávei": "desenjaular",
    "desenjauláveis": "desenjaular",
    "desenjoa": "desenjoar",
    "desenjoada": "desenjoar",
    "desenjoadas": "desenjoar",
    "desenjoado": "desenjoar",
    "desenjoados": "desenjoar",
    "desenjoai": "desenjoar",
    "desenjoais": "desenjoar",
    "desenjoam": "desenjoar",
    "desenjoamo": "desenjoar",
    "desenjoamos": "desenjoar",
    "desenjoando": "desenjoar",
    "desenjoara": "desenjoar",
    "desenjoaram": "desenjoar",
    "desenjoaras": "desenjoar",
    "desenjoardes": "desenjoar",
    "desenjoarei": "desenjoar",
    "desenjoareis": "desenjoar",
    "desenjoarem": "desenjoar",
    "desenjoaremos": "desenjoar",
    "desenjoares": "desenjoar",
    "desenjoaria": "desenjoar",
    "desenjoariam": "desenjoar",
    "desenjoarias": "desenjoar",
    "desenjoarmo": "desenjoar",
    "desenjoarmos": "desenjoar",
    "desenjoará": "desenjoar",
    "desenjoarás": "desenjoar",
    "desenjoarão": "desenjoar",
    "desenjoaríamos": "desenjoar",
    "desenjoaríeis": "desenjoar",
    "desenjoas": "desenjoar",
    "desenjoasse": "desenjoar",
    "desenjoassem": "desenjoar",
    "desenjoasses": "desenjoar",
    "desenjoaste": "desenjoar",
    "desenjoastes": "desenjoar",
    "desenjoativa": "desenjoativo",
    "desenjoativas": "desenjoativo",
    "desenjoativos": "desenjoativo",
    "desenjoava": "desenjoar",
    "desenjoavam": "desenjoar",
    "desenjoavas": "desenjoar",
    "desenjoe": "desenjoar",
    "desenjoei": "desenjoar",
    "desenjoeis": "desenjoar",
    "desenjoem": "desenjoar",
    "desenjoemo": "desenjoar",
    "desenjoemos": "desenjoar",
    "desenjoes": "desenjoar",
    "desenjoo": "desenjoar",
    "desenjoos": "desenjoo",
    "desenjoou": "desenjoar",
    "desenjoámo": "desenjoar",
    "desenjoámos": "desenjoar",
    "desenjoáramo": "desenjoar",
    "desenjoáramos": "desenjoar",
    "desenjoáreis": "desenjoar",
    "desenjoásseis": "desenjoar",
    "desenjoássemos": "desenjoar",
    "desenjoávamo": "desenjoar",
    "desenjoávamos": "desenjoar",
    "desenjoáveis": "desenjoar",
    "desenlace": "desenlaçar",
    "desenlacei": "desenlaçar",
    "desenlaceis": "desenlaçar",
    "desenlacem": "desenlaçar",
    "desenlacemo": "desenlaçar",
    "desenlacemos": "desenlaçar",
    "desenlaces": "desenlace",
    "desenlameada": "desenlamear",
    "desenlameadas": "desenlamear",
    "desenlameado": "desenlamear",
    "desenlameados": "desenlamear",
    "desenlameai": "desenlamear",
    "desenlameais": "desenlamear",
    "desenlameamo": "desenlamear",
    "desenlameamos": "desenlamear",
    "desenlameando": "desenlamear",
    "desenlameara": "desenlamear",
    "desenlamearam": "desenlamear",
    "desenlamearas": "desenlamear",
    "desenlamearde": "desenlamear",
    "desenlameardes": "desenlamear",
    "desenlameare": "desenlamear",
    "desenlamearei": "desenlamear",
    "desenlameareis": "desenlamear",
    "desenlamearem": "desenlamear",
    "desenlamearemos": "desenlamear",
    "desenlameares": "desenlamear",
    "desenlamearia": "desenlamear",
    "desenlameariam": "desenlamear",
    "desenlamearias": "desenlamear",
    "desenlamearmo": "desenlamear",
    "desenlamearmos": "desenlamear",
    "desenlameará": "desenlamear",
    "desenlamearás": "desenlamear",
    "desenlamearão": "desenlamear",
    "desenlamearíamos": "desenlamear",
    "desenlamearíeis": "desenlamear",
    "desenlameasse": "desenlamear",
    "desenlameassem": "desenlamear",
    "desenlameasses": "desenlamear",
    "desenlameaste": "desenlamear",
    "desenlameastes": "desenlamear",
    "desenlameava": "desenlamear",
    "desenlameavam": "desenlamear",
    "desenlameavas": "desenlamear",
    "desenlameei": "desenlamear",
    "desenlameeis": "desenlamear",
    "desenlameemo": "desenlamear",
    "desenlameemos": "desenlamear",
    "desenlameia": "desenlamear",
    "desenlameiam": "desenlamear",
    "desenlameias": "desenlamear",
    "desenlameie": "desenlamear",
    "desenlameiem": "desenlamear",
    "desenlameies": "desenlamear",
    "desenlameio": "desenlamear",
    "desenlameou": "desenlamear",
    "desenlameá": "desenlamear",
    "desenlameámo": "desenlamear",
    "desenlameámos": "desenlamear",
    "desenlameáramo": "desenlamear",
    "desenlameáramos": "desenlamear",
    "desenlameárei": "desenlamear",
    "desenlameáreis": "desenlamear",
    "desenlameásseis": "desenlamear",
    "desenlameássemos": "desenlamear",
    "desenlameávamo": "desenlamear",
    "desenlameávamos": "desenlamear",
    "desenlameávei": "desenlamear",
    "desenlameáveis": "desenlamear",
    "desenlapa": "desenlapar",
    "desenlapada": "desenlapar",
    "desenlapadas": "desenlapar",
    "desenlapado": "desenlapar",
    "desenlapados": "desenlapar",
    "desenlapai": "desenlapar",
    "desenlapais": "desenlapar",
    "desenlapam": "desenlapar",
    "desenlapamo": "desenlapar",
    "desenlapamos": "desenlapar",
    "desenlapando": "desenlapar",
    "desenlapara": "desenlapar",
    "desenlaparam": "desenlapar",
    "desenlaparas": "desenlapar",
    "desenlaparde": "desenlapar",
    "desenlapardes": "desenlapar",
    "desenlapare": "desenlapar",
    "desenlaparei": "desenlapar",
    "desenlapareis": "desenlapar",
    "desenlaparem": "desenlapar",
    "desenlaparemos": "desenlapar",
    "desenlapares": "desenlapar",
    "desenlaparia": "desenlapar",
    "desenlapariam": "desenlapar",
    "desenlaparias": "desenlapar",
    "desenlaparmo": "desenlapar",
    "desenlaparmos": "desenlapar",
    "desenlapará": "desenlapar",
    "desenlaparás": "desenlapar",
    "desenlaparão": "desenlapar",
    "desenlaparíamos": "desenlapar",
    "desenlaparíeis": "desenlapar",
    "desenlapas": "desenlapar",
    "desenlapasse": "desenlapar",
    "desenlapassem": "desenlapar",
    "desenlapasses": "desenlapar",
    "desenlapaste": "desenlapar",
    "desenlapastes": "desenlapar",
    "desenlapava": "desenlapar",
    "desenlapavam": "desenlapar",
    "desenlapavas": "desenlapar",
    "desenlape": "desenlapar",
    "desenlapei": "desenlapar",
    "desenlapeis": "desenlapar",
    "desenlapem": "desenlapar",
    "desenlapemo": "desenlapar",
    "desenlapemos": "desenlapar",
    "desenlapes": "desenlapar",
    "desenlapo": "desenlapar",
    "desenlapou": "desenlapar",
    "desenlapá": "desenlapar",
    "desenlapámo": "desenlapar",
    "desenlapámos": "desenlapar",
    "desenlapáramo": "desenlapar",
    "desenlapáramos": "desenlapar",
    "desenlapárei": "desenlapar",
    "desenlapáreis": "desenlapar",
    "desenlapásseis": "desenlapar",
    "desenlapássemos": "desenlapar",
    "desenlapávamo": "desenlapar",
    "desenlapávamos": "desenlapar",
    "desenlapávei": "desenlapar",
    "desenlapáveis": "desenlapar",
    "desenlaça": "desenlaçar",
    "desenlaçada": "desenlaçar",
    "desenlaçadas": "desenlaçar",
    "desenlaçado": "desenlaçar",
    "desenlaçados": "desenlaçar",
    "desenlaçai": "desenlaçar",
    "desenlaçais": "desenlaçar",
    "desenlaçam": "desenlaçar",
    "desenlaçamentos": "desenlaçamento",
    "desenlaçamo": "desenlaçar",
    "desenlaçamos": "desenlaçar",
    "desenlaçando": "desenlaçar",
    "desenlaçara": "desenlaçar",
    "desenlaçaram": "desenlaçar",
    "desenlaçaras": "desenlaçar",
    "desenlaçarde": "desenlaçar",
    "desenlaçardes": "desenlaçar",
    "desenlaçare": "desenlaçar",
    "desenlaçarei": "desenlaçar",
    "desenlaçareis": "desenlaçar",
    "desenlaçarem": "desenlaçar",
    "desenlaçaremos": "desenlaçar",
    "desenlaçares": "desenlaçar",
    "desenlaçaria": "desenlaçar",
    "desenlaçariam": "desenlaçar",
    "desenlaçarias": "desenlaçar",
    "desenlaçarmo": "desenlaçar",
    "desenlaçarmos": "desenlaçar",
    "desenlaçará": "desenlaçar",
    "desenlaçarás": "desenlaçar",
    "desenlaçarão": "desenlaçar",
    "desenlaçaríamos": "desenlaçar",
    "desenlaçaríeis": "desenlaçar",
    "desenlaças": "desenlaçar",
    "desenlaçasse": "desenlaçar",
    "desenlaçassem": "desenlaçar",
    "desenlaçasses": "desenlaçar",
    "desenlaçaste": "desenlaçar",
    "desenlaçastes": "desenlaçar",
    "desenlaçava": "desenlaçar",
    "desenlaçavam": "desenlaçar",
    "desenlaçavas": "desenlaçar",
    "desenlaço": "desenlaçar",
    "desenlaçou": "desenlaçar",
    "desenlaçá": "desenlaçar",
    "desenlaçámo": "desenlaçar",
    "desenlaçámos": "desenlaçar",
    "desenlaçáramo": "desenlaçar",
    "desenlaçáramos": "desenlaçar",
    "desenlaçárei": "desenlaçar",
    "desenlaçáreis": "desenlaçar",
    "desenlaçásseis": "desenlaçar",
    "desenlaçássemos": "desenlaçar",
    "desenlaçávamo": "desenlaçar",
    "desenlaçávamos": "desenlaçar",
    "desenlaçávei": "desenlaçar",
    "desenlaçáveis": "desenlaçar",
    "desenleada": "desenlear",
    "desenleadas": "desenlear",
    "desenleado": "desenlear",
    "desenleados": "desenlear",
    "desenleai": "desenlear",
    "desenleais": "desenlear",
    "desenleamo": "desenlear",
    "desenleamos": "desenlear",
    "desenleando": "desenlear",
    "desenleara": "desenlear",
    "desenlearam": "desenlear",
    "desenlearas": "desenlear",
    "desenlearde": "desenlear",
    "desenleardes": "desenlear",
    "desenleare": "desenlear",
    "desenlearei": "desenlear",
    "desenleareis": "desenlear",
    "desenlearem": "desenlear",
    "desenlearemos": "desenlear",
    "desenleares": "desenlear",
    "desenlearia": "desenlear",
    "desenleariam": "desenlear",
    "desenlearias": "desenlear",
    "desenlearmo": "desenlear",
    "desenlearmos": "desenlear",
    "desenleará": "desenlear",
    "desenlearás": "desenlear",
    "desenlearão": "desenlear",
    "desenlearíamos": "desenlear",
    "desenlearíeis": "desenlear",
    "desenleasse": "desenlear",
    "desenleassem": "desenlear",
    "desenleasses": "desenlear",
    "desenleaste": "desenlear",
    "desenleastes": "desenlear",
    "desenleava": "desenlear",
    "desenleavam": "desenlear",
    "desenleavas": "desenlear",
    "desenleei": "desenlear",
    "desenleeis": "desenlear",
    "desenleemo": "desenlear",
    "desenleemos": "desenlear",
    "desenleia": "desenlear",
    "desenleiam": "desenlear",
    "desenleias": "desenlear",
    "desenleie": "desenlear",
    "desenleiem": "desenlear",
    "desenleies": "desenlear",
    "desenleio": "desenlear",
    "desenleios": "desenleio",
    "desenleou": "desenlear",
    "desenleva": "desenlevar",
    "desenlevada": "desenlevar",
    "desenlevadas": "desenlevar",
    "desenlevado": "desenlevar",
    "desenlevados": "desenlevar",
    "desenlevai": "desenlevar",
    "desenlevais": "desenlevar",
    "desenlevam": "desenlevar",
    "desenlevamo": "desenlevar",
    "desenlevamos": "desenlevar",
    "desenlevando": "desenlevar",
    "desenlevara": "desenlevar",
    "desenlevaram": "desenlevar",
    "desenlevaras": "desenlevar",
    "desenlevarde": "desenlevar",
    "desenlevardes": "desenlevar",
    "desenlevare": "desenlevar",
    "desenlevarei": "desenlevar",
    "desenlevareis": "desenlevar",
    "desenlevarem": "desenlevar",
    "desenlevaremos": "desenlevar",
    "desenlevares": "desenlevar",
    "desenlevaria": "desenlevar",
    "desenlevariam": "desenlevar",
    "desenlevarias": "desenlevar",
    "desenlevarmo": "desenlevar",
    "desenlevarmos": "desenlevar",
    "desenlevará": "desenlevar",
    "desenlevarás": "desenlevar",
    "desenlevarão": "desenlevar",
    "desenlevaríamos": "desenlevar",
    "desenlevaríeis": "desenlevar",
    "desenlevas": "desenlevar",
    "desenlevasse": "desenlevar",
    "desenlevassem": "desenlevar",
    "desenlevasses": "desenlevar",
    "desenlevaste": "desenlevar",
    "desenlevastes": "desenlevar",
    "desenlevava": "desenlevar",
    "desenlevavam": "desenlevar",
    "desenlevavas": "desenlevar",
    "desenleve": "desenlevar",
    "desenlevei": "desenlevar",
    "desenleveis": "desenlevar",
    "desenlevem": "desenlevar",
    "desenlevemo": "desenlevar",
    "desenlevemos": "desenlevar",
    "desenleves": "desenlevar",
    "desenlevo": "desenlevar",
    "desenlevou": "desenlevar",
    "desenlevá": "desenlevar",
    "desenlevámo": "desenlevar",
    "desenlevámos": "desenlevar",
    "desenleváramo": "desenlevar",
    "desenleváramos": "desenlevar",
    "desenlevárei": "desenlevar",
    "desenleváreis": "desenlevar",
    "desenlevásseis": "desenlevar",
    "desenlevássemos": "desenlevar",
    "desenlevávamo": "desenlevar",
    "desenlevávamos": "desenlevar",
    "desenlevávei": "desenlevar",
    "desenleváveis": "desenlevar",
    "desenleá": "desenlear",
    "desenleámo": "desenlear",
    "desenleámos": "desenlear",
    "desenleáramo": "desenlear",
    "desenleáramos": "desenlear",
    "desenleárei": "desenlear",
    "desenleáreis": "desenlear",
    "desenleásseis": "desenlear",
    "desenleássemos": "desenlear",
    "desenleávamo": "desenlear",
    "desenleávamos": "desenlear",
    "desenleávei": "desenlear",
    "desenleáveis": "desenlear",
    "desenlice": "desenliçar",
    "desenlicei": "desenliçar",
    "desenliceis": "desenliçar",
    "desenlicem": "desenliçar",
    "desenlicemo": "desenliçar",
    "desenlicemos": "desenliçar",
    "desenlices": "desenliçar",
    "desenliça": "desenliçar",
    "desenliçada": "desenliçar",
    "desenliçadas": "desenliçar",
    "desenliçado": "desenliçar",
    "desenliçados": "desenliçar",
    "desenliçai": "desenliçar",
    "desenliçais": "desenliçar",
    "desenliçam": "desenliçar",
    "desenliçamo": "desenliçar",
    "desenliçamos": "desenliçar",
    "desenliçando": "desenliçar",
    "desenliçara": "desenliçar",
    "desenliçaram": "desenliçar",
    "desenliçaras": "desenliçar",
    "desenliçarde": "desenliçar",
    "desenliçardes": "desenliçar",
    "desenliçare": "desenliçar",
    "desenliçarei": "desenliçar",
    "desenliçareis": "desenliçar",
    "desenliçarem": "desenliçar",
    "desenliçaremos": "desenliçar",
    "desenliçares": "desenliçar",
    "desenliçaria": "desenliçar",
    "desenliçariam": "desenliçar",
    "desenliçarias": "desenliçar",
    "desenliçarmo": "desenliçar",
    "desenliçarmos": "desenliçar",
    "desenliçará": "desenliçar",
    "desenliçarás": "desenliçar",
    "desenliçarão": "desenliçar",
    "desenliçaríamos": "desenliçar",
    "desenliçaríeis": "desenliçar",
    "desenliças": "desenliçar",
    "desenliçasse": "desenliçar",
    "desenliçassem": "desenliçar",
    "desenliçasses": "desenliçar",
    "desenliçaste": "desenliçar",
    "desenliçastes": "desenliçar",
    "desenliçava": "desenliçar",
    "desenliçavam": "desenliçar",
    "desenliçavas": "desenliçar",
    "desenliço": "desenliçar",
    "desenliçou": "desenliçar",
    "desenliçá": "desenliçar",
    "desenliçámo": "desenliçar",
    "desenliçámos": "desenliçar",
    "desenliçáramo": "desenliçar",
    "desenliçáramos": "desenliçar",
    "desenliçárei": "desenliçar",
    "desenliçáreis": "desenliçar",
    "desenliçásseis": "desenliçar",
    "desenliçássemos": "desenliçar",
    "desenliçávamo": "desenliçar",
    "desenliçávamos": "desenliçar",
    "desenliçávei": "desenliçar",
    "desenliçáveis": "desenliçar",
    "desenloda": "desenlodar",
    "desenlodada": "desenlodar",
    "desenlodadas": "desenlodar",
    "desenlodado": "desenlodar",
    "desenlodados": "desenlodar",
    "desenlodai": "desenlodar",
    "desenlodais": "desenlodar",
    "desenlodam": "desenlodar",
    "desenlodamo": "desenlodar",
    "desenlodamos": "desenlodar",
    "desenlodando": "desenlodar",
    "desenlodara": "desenlodar",
    "desenlodaram": "desenlodar",
    "desenlodaras": "desenlodar",
    "desenlodarde": "desenlodar",
    "desenlodardes": "desenlodar",
    "desenlodare": "desenlodar",
    "desenlodarei": "desenlodar",
    "desenlodareis": "desenlodar",
    "desenlodarem": "desenlodar",
    "desenlodaremos": "desenlodar",
    "desenlodares": "desenlodar",
    "desenlodaria": "desenlodar",
    "desenlodariam": "desenlodar",
    "desenlodarias": "desenlodar",
    "desenlodarmo": "desenlodar",
    "desenlodarmos": "desenlodar",
    "desenlodará": "desenlodar",
    "desenlodarás": "desenlodar",
    "desenlodarão": "desenlodar",
    "desenlodaríamos": "desenlodar",
    "desenlodaríeis": "desenlodar",
    "desenlodas": "desenlodar",
    "desenlodasse": "desenlodar",
    "desenlodassem": "desenlodar",
    "desenlodasses": "desenlodar",
    "desenlodaste": "desenlodar",
    "desenlodastes": "desenlodar",
    "desenlodava": "desenlodar",
    "desenlodavam": "desenlodar",
    "desenlodavas": "desenlodar",
    "desenlode": "desenlodar",
    "desenlodei": "desenlodar",
    "desenlodeis": "desenlodar",
    "desenlodem": "desenlodar",
    "desenlodemo": "desenlodar",
    "desenlodemos": "desenlodar",
    "desenlodes": "desenlodar",
    "desenlodo": "desenlodar",
    "desenlodou": "desenlodar",
    "desenlodá": "desenlodar",
    "desenlodámo": "desenlodar",
    "desenlodámos": "desenlodar",
    "desenlodáramo": "desenlodar",
    "desenlodáramos": "desenlodar",
    "desenlodárei": "desenlodar",
    "desenlodáreis": "desenlodar",
    "desenlodásseis": "desenlodar",
    "desenlodássemos": "desenlodar",
    "desenlodávamo": "desenlodar",
    "desenlodávamos": "desenlodar",
    "desenlodávei": "desenlodar",
    "desenlodáveis": "desenlodar",
    "desenlouquece": "desenlouquecer",
    "desenlouquecei": "desenlouquecer",
    "desenlouqueceis": "desenlouquecer",
    "desenlouquecem": "desenlouquecer",
    "desenlouquecemo": "desenlouquecer",
    "desenlouquecemos": "desenlouquecer",
    "desenlouquecendo": "desenlouquecer",
    "desenlouquecera": "desenlouquecer",
    "desenlouqueceram": "desenlouquecer",
    "desenlouqueceras": "desenlouquecer",
    "desenlouquecerdes": "desenlouquecer",
    "desenlouquecerei": "desenlouquecer",
    "desenlouquecereis": "desenlouquecer",
    "desenlouquecerem": "desenlouquecer",
    "desenlouqueceremos": "desenlouquecer",
    "desenlouqueceres": "desenlouquecer",
    "desenlouqueceria": "desenlouquecer",
    "desenlouqueceriam": "desenlouquecer",
    "desenlouquecerias": "desenlouquecer",
    "desenlouquecermo": "desenlouquecer",
    "desenlouquecermos": "desenlouquecer",
    "desenlouquecerá": "desenlouquecer",
    "desenlouquecerás": "desenlouquecer",
    "desenlouquecerão": "desenlouquecer",
    "desenlouqueceríamos": "desenlouquecer",
    "desenlouqueceríeis": "desenlouquecer",
    "desenlouqueces": "desenlouquecer",
    "desenlouquecesse": "desenlouquecer",
    "desenlouquecessem": "desenlouquecer",
    "desenlouquecesses": "desenlouquecer",
    "desenlouqueceste": "desenlouquecer",
    "desenlouquecestes": "desenlouquecer",
    "desenlouqueceu": "desenlouquecer",
    "desenlouqueci": "desenlouquecer",
    "desenlouquecia": "desenlouquecer",
    "desenlouqueciam": "desenlouquecer",
    "desenlouquecias": "desenlouquecer",
    "desenlouquecida": "desenlouquecido",
    "desenlouquecidas": "desenlouquecido",
    "desenlouquecido": "desenlouquecer",
    "desenlouquecidos": "desenlouquecido",
    "desenlouquecêramo": "desenlouquecer",
    "desenlouquecêramos": "desenlouquecer",
    "desenlouquecêreis": "desenlouquecer",
    "desenlouquecêsseis": "desenlouquecer",
    "desenlouquecêssemos": "desenlouquecer",
    "desenlouquecíamo": "desenlouquecer",
    "desenlouquecíamos": "desenlouquecer",
    "desenlouquecíeis": "desenlouquecer",
    "desenlouqueça": "desenlouquecer",
    "desenlouqueçais": "desenlouquecer",
    "desenlouqueçam": "desenlouquecer",
    "desenlouqueçamo": "desenlouquecer",
    "desenlouqueçamos": "desenlouquecer",
    "desenlouqueças": "desenlouquecer",
    "desenlouqueço": "desenlouquecer",
    "desenluta": "desenlutar",
    "desenlutada": "desenlutar",
    "desenlutadas": "desenlutar",
    "desenlutado": "desenlutar",
    "desenlutados": "desenlutar",
    "desenlutai": "desenlutar",
    "desenlutais": "desenlutar",
    "desenlutam": "desenlutar",
    "desenlutamo": "desenlutar",
    "desenlutamos": "desenlutar",
    "desenlutando": "desenlutar",
    "desenlutara": "desenlutar",
    "desenlutaram": "desenlutar",
    "desenlutaras": "desenlutar",
    "desenlutardes": "desenlutar",
    "desenlutarei": "desenlutar",
    "desenlutareis": "desenlutar",
    "desenlutarem": "desenlutar",
    "desenlutaremos": "desenlutar",
    "desenlutares": "desenlutar",
    "desenlutaria": "desenlutar",
    "desenlutariam": "desenlutar",
    "desenlutarias": "desenlutar",
    "desenlutarmo": "desenlutar",
    "desenlutarmos": "desenlutar",
    "desenlutará": "desenlutar",
    "desenlutarás": "desenlutar",
    "desenlutarão": "desenlutar",
    "desenlutaríamos": "desenlutar",
    "desenlutaríeis": "desenlutar",
    "desenlutas": "desenlutar",
    "desenlutasse": "desenlutar",
    "desenlutassem": "desenlutar",
    "desenlutasses": "desenlutar",
    "desenlutaste": "desenlutar",
    "desenlutastes": "desenlutar",
    "desenlutava": "desenlutar",
    "desenlutavam": "desenlutar",
    "desenlutavas": "desenlutar",
    "desenlute": "desenlutar",
    "desenlutei": "desenlutar",
    "desenluteis": "desenlutar",
    "desenlutem": "desenlutar",
    "desenlutemo": "desenlutar",
    "desenlutemos": "desenlutar",
    "desenlutes": "desenlutar",
    "desenluto": "desenlutar",
    "desenlutou": "desenlutar",
    "desenlutámo": "desenlutar",
    "desenlutámos": "desenlutar",
    "desenlutáramo": "desenlutar",
    "desenlutáramos": "desenlutar",
    "desenlutáreis": "desenlutar",
    "desenlutásseis": "desenlutar",
    "desenlutássemos": "desenlutar",
    "desenlutávamo": "desenlutar",
    "desenlutávamos": "desenlutar",
    "desenlutáveis": "desenlutar",
    "desenobrece": "desenobrecer",
    "desenobrecei": "desenobrecer",
    "desenobreceis": "desenobrecer",
    "desenobrecem": "desenobrecer",
    "desenobrecemo": "desenobrecer",
    "desenobrecemos": "desenobrecer",
    "desenobrecendo": "desenobrecer",
    "desenobrecera": "desenobrecer",
    "desenobreceram": "desenobrecer",
    "desenobreceras": "desenobrecer",
    "desenobrecerde": "desenobrecer",
    "desenobrecerdes": "desenobrecer",
    "desenobrecere": "desenobrecer",
    "desenobrecerei": "desenobrecer",
    "desenobrecereis": "desenobrecer",
    "desenobrecerem": "desenobrecer",
    "desenobreceremos": "desenobrecer",
    "desenobreceres": "desenobrecer",
    "desenobreceria": "desenobrecer",
    "desenobreceriam": "desenobrecer",
    "desenobrecerias": "desenobrecer",
    "desenobrecermo": "desenobrecer",
    "desenobrecermos": "desenobrecer",
    "desenobrecerá": "desenobrecer",
    "desenobrecerás": "desenobrecer",
    "desenobrecerão": "desenobrecer",
    "desenobreceríamos": "desenobrecer",
    "desenobreceríeis": "desenobrecer",
    "desenobreces": "desenobrecer",
    "desenobrecesse": "desenobrecer",
    "desenobrecessem": "desenobrecer",
    "desenobrecesses": "desenobrecer",
    "desenobreceste": "desenobrecer",
    "desenobrecestes": "desenobrecer",
    "desenobreceu": "desenobrecer",
    "desenobreci": "desenobrecer",
    "desenobrecia": "desenobrecer",
    "desenobreciam": "desenobrecer",
    "desenobrecias": "desenobrecer",
    "desenobrecida": "desenobrecido",
    "desenobrecidas": "desenobrecido",
    "desenobrecido": "desenobrecer",
    "desenobrecidos": "desenobrecido",
    "desenobrecê": "desenobrecer",
    "desenobrecêramo": "desenobrecer",
    "desenobrecêramos": "desenobrecer",
    "desenobrecêrei": "desenobrecer",
    "desenobrecêreis": "desenobrecer",
    "desenobrecêsseis": "desenobrecer",
    "desenobrecêssemos": "desenobrecer",
    "desenobrecíamo": "desenobrecer",
    "desenobrecíamos": "desenobrecer",
    "desenobrecíei": "desenobrecer",
    "desenobrecíeis": "desenobrecer",
    "desenobreça": "desenobrecer",
    "desenobreçais": "desenobrecer",
    "desenobreçam": "desenobrecer",
    "desenobreçamo": "desenobrecer",
    "desenobreçamos": "desenobrecer",
    "desenobreças": "desenobrecer",
    "desenobreço": "desenobrecer",
    "desenodeada": "desenodeado",
    "desenodeadas": "desenodeado",
    "desenodeados": "desenodeado",
    "desenodoa": "desenodoar",
    "desenodoada": "desenodoar",
    "desenodoadas": "desenodoar",
    "desenodoado": "desenodoar",
    "desenodoados": "desenodoar",
    "desenodoai": "desenodoar",
    "desenodoais": "desenodoar",
    "desenodoam": "desenodoar",
    "desenodoamo": "desenodoar",
    "desenodoamos": "desenodoar",
    "desenodoando": "desenodoar",
    "desenodoara": "desenodoar",
    "desenodoaram": "desenodoar",
    "desenodoaras": "desenodoar",
    "desenodoarde": "desenodoar",
    "desenodoardes": "desenodoar",
    "desenodoare": "desenodoar",
    "desenodoarei": "desenodoar",
    "desenodoareis": "desenodoar",
    "desenodoarem": "desenodoar",
    "desenodoaremos": "desenodoar",
    "desenodoares": "desenodoar",
    "desenodoaria": "desenodoar",
    "desenodoariam": "desenodoar",
    "desenodoarias": "desenodoar",
    "desenodoarmo": "desenodoar",
    "desenodoarmos": "desenodoar",
    "desenodoará": "desenodoar",
    "desenodoarás": "desenodoar",
    "desenodoarão": "desenodoar",
    "desenodoaríamos": "desenodoar",
    "desenodoaríeis": "desenodoar",
    "desenodoas": "desenodoar",
    "desenodoasse": "desenodoar",
    "desenodoassem": "desenodoar",
    "desenodoasses": "desenodoar",
    "desenodoaste": "desenodoar",
    "desenodoastes": "desenodoar",
    "desenodoava": "desenodoar",
    "desenodoavam": "desenodoar",
    "desenodoavas": "desenodoar",
    "desenodoe": "desenodoar",
    "desenodoei": "desenodoar",
    "desenodoeis": "desenodoar",
    "desenodoem": "desenodoar",
    "desenodoemo": "desenodoar",
    "desenodoemos": "desenodoar",
    "desenodoes": "desenodoar",
    "desenodoo": "desenodoar",
    "desenodoou": "desenodoar",
    "desenodoá": "desenodoar",
    "desenodoámo": "desenodoar",
    "desenodoámos": "desenodoar",
    "desenodoáramo": "desenodoar",
    "desenodoáramos": "desenodoar",
    "desenodoárei": "desenodoar",
    "desenodoáreis": "desenodoar",
    "desenodoásseis": "desenodoar",
    "desenodoássemos": "desenodoar",
    "desenodoávamo": "desenodoar",
    "desenodoávamos": "desenodoar",
    "desenodoávei": "desenodoar",
    "desenodoáveis": "desenodoar",
    "desenojada": "desenojado",
    "desenojadas": "desenojado",
    "desenojados": "desenojado",
    "desenovela": "desenovelar",
    "desenovelada": "desenovelar",
    "desenoveladas": "desenovelar",
    "desenovelado": "desenovelar",
    "desenovelados": "desenovelar",
    "desenovelai": "desenovelar",
    "desenovelais": "desenovelar",
    "desenovelam": "desenovelar",
    "desenovelamo": "desenovelar",
    "desenovelamos": "desenovelar",
    "desenovelando": "desenovelar",
    "desenovelara": "desenovelar",
    "desenovelaram": "desenovelar",
    "desenovelaras": "desenovelar",
    "desenovelarde": "desenovelar",
    "desenovelardes": "desenovelar",
    "desenovelare": "desenovelar",
    "desenovelarei": "desenovelar",
    "desenovelareis": "desenovelar",
    "desenovelarem": "desenovelar",
    "desenovelaremos": "desenovelar",
    "desenovelares": "desenovelar",
    "desenovelaria": "desenovelar",
    "desenovelariam": "desenovelar",
    "desenovelarias": "desenovelar",
    "desenovelarmo": "desenovelar",
    "desenovelarmos": "desenovelar",
    "desenovelará": "desenovelar",
    "desenovelarás": "desenovelar",
    "desenovelarão": "desenovelar",
    "desenovelaríamos": "desenovelar",
    "desenovelaríeis": "desenovelar",
    "desenovelas": "desenovelar",
    "desenovelasse": "desenovelar",
    "desenovelassem": "desenovelar",
    "desenovelasses": "desenovelar",
    "desenovelaste": "desenovelar",
    "desenovelastes": "desenovelar",
    "desenovelava": "desenovelar",
    "desenovelavam": "desenovelar",
    "desenovelavas": "desenovelar",
    "desenovele": "desenovelar",
    "desenovelei": "desenovelar",
    "desenoveleis": "desenovelar",
    "desenovelem": "desenovelar",
    "desenovelemo": "desenovelar",
    "desenovelemos": "desenovelar",
    "desenoveles": "desenovelar",
    "desenovelo": "desenovelar",
    "desenovelou": "desenovelar",
    "desenovelá": "desenovelar",
    "desenovelámo": "desenovelar",
    "desenovelámos": "desenovelar",
    "desenoveláramo": "desenovelar",
    "desenoveláramos": "desenovelar",
    "desenovelárei": "desenovelar",
    "desenoveláreis": "desenovelar",
    "desenovelásseis": "desenovelar",
    "desenovelássemos": "desenovelar",
    "desenovelávamo": "desenovelar",
    "desenovelávamos": "desenovelar",
    "desenovelávei": "desenovelar",
    "desenoveláveis": "desenovelar",
    "desenquadra": "desenquadrar",
    "desenquadrada": "desenquadrar",
    "desenquadradas": "desenquadrar",
    "desenquadrado": "desenquadrar",
    "desenquadrados": "desenquadrar",
    "desenquadrai": "desenquadrar",
    "desenquadrais": "desenquadrar",
    "desenquadram": "desenquadrar",
    "desenquadramentos": "desenquadramento",
    "desenquadramo": "desenquadrar",
    "desenquadramos": "desenquadrar",
    "desenquadrando": "desenquadrar",
    "desenquadrara": "desenquadrar",
    "desenquadraram": "desenquadrar",
    "desenquadraras": "desenquadrar",
    "desenquadrarde": "desenquadrar",
    "desenquadrardes": "desenquadrar",
    "desenquadrare": "desenquadrar",
    "desenquadrarei": "desenquadrar",
    "desenquadrareis": "desenquadrar",
    "desenquadrarem": "desenquadrar",
    "desenquadraremos": "desenquadrar",
    "desenquadrares": "desenquadrar",
    "desenquadraria": "desenquadrar",
    "desenquadrariam": "desenquadrar",
    "desenquadrarias": "desenquadrar",
    "desenquadrarmo": "desenquadrar",
    "desenquadrarmos": "desenquadrar",
    "desenquadrará": "desenquadrar",
    "desenquadrarás": "desenquadrar",
    "desenquadrarão": "desenquadrar",
    "desenquadraríamos": "desenquadrar",
    "desenquadraríeis": "desenquadrar",
    "desenquadras": "desenquadrar",
    "desenquadrasse": "desenquadrar",
    "desenquadrassem": "desenquadrar",
    "desenquadrasses": "desenquadrar",
    "desenquadraste": "desenquadrar",
    "desenquadrastes": "desenquadrar",
    "desenquadrava": "desenquadrar",
    "desenquadravam": "desenquadrar",
    "desenquadravas": "desenquadrar",
    "desenquadre": "desenquadrar",
    "desenquadrei": "desenquadrar",
    "desenquadreis": "desenquadrar",
    "desenquadrem": "desenquadrar",
    "desenquadremo": "desenquadrar",
    "desenquadremos": "desenquadrar",
    "desenquadres": "desenquadrar",
    "desenquadro": "desenquadrar",
    "desenquadrou": "desenquadrar",
    "desenquadrá": "desenquadrar",
    "desenquadrámo": "desenquadrar",
    "desenquadrámos": "desenquadrar",
    "desenquadráramo": "desenquadrar",
    "desenquadráramos": "desenquadrar",
    "desenquadrárei": "desenquadrar",
    "desenquadráreis": "desenquadrar",
    "desenquadrásseis": "desenquadrar",
    "desenquadrássemos": "desenquadrar",
    "desenquadrávamo": "desenquadrar",
    "desenquadrávamos": "desenquadrar",
    "desenquadrávei": "desenquadrar",
    "desenquadráveis": "desenquadrar",
    "desenraia": "desenraiar",
    "desenraiada": "desenraiar",
    "desenraiadas": "desenraiar",
    "desenraiado": "desenraiar",
    "desenraiados": "desenraiar",
    "desenraiai": "desenraiar",
    "desenraiais": "desenraiar",
    "desenraiam": "desenraiar",
    "desenraiamo": "desenraiar",
    "desenraiamos": "desenraiar",
    "desenraiando": "desenraiar",
    "desenraiara": "desenraiar",
    "desenraiaram": "desenraiar",
    "desenraiaras": "desenraiar",
    "desenraiarde": "desenraiar",
    "desenraiardes": "desenraiar",
    "desenraiare": "desenraiar",
    "desenraiarei": "desenraiar",
    "desenraiareis": "desenraiar",
    "desenraiarem": "desenraiar",
    "desenraiaremos": "desenraiar",
    "desenraiares": "desenraiar",
    "desenraiaria": "desenraiar",
    "desenraiariam": "desenraiar",
    "desenraiarias": "desenraiar",
    "desenraiarmo": "desenraiar",
    "desenraiarmos": "desenraiar",
    "desenraiará": "desenraiar",
    "desenraiarás": "desenraiar",
    "desenraiarão": "desenraiar",
    "desenraiaríamos": "desenraiar",
    "desenraiaríeis": "desenraiar",
    "desenraias": "desenraiar",
    "desenraiasse": "desenraiar",
    "desenraiassem": "desenraiar",
    "desenraiasses": "desenraiar",
    "desenraiaste": "desenraiar",
    "desenraiastes": "desenraiar",
    "desenraiava": "desenraiar",
    "desenraiavam": "desenraiar",
    "desenraiavas": "desenraiar",
    "desenraie": "desenraiar",
    "desenraiei": "desenraiar",
    "desenraieis": "desenraiar",
    "desenraiem": "desenraiar",
    "desenraiemo": "desenraiar",
    "desenraiemos": "desenraiar",
    "desenraies": "desenraiar",
    "desenraio": "desenraiar",
    "desenraiou": "desenraiar",
    "desenraiva": "desenraivar",
    "desenraivada": "desenraivar",
    "desenraivadas": "desenraivar",
    "desenraivado": "desenraivar",
    "desenraivados": "desenraivar",
    "desenraivai": "desenraivar",
    "desenraivais": "desenraivar",
    "desenraivam": "desenraivar",
    "desenraivamo": "desenraivar",
    "desenraivamos": "desenraivar",
    "desenraivando": "desenraivar",
    "desenraivara": "desenraivar",
    "desenraivaram": "desenraivar",
    "desenraivaras": "desenraivar",
    "desenraivarde": "desenraivar",
    "desenraivardes": "desenraivar",
    "desenraivare": "desenraivar",
    "desenraivarei": "desenraivar",
    "desenraivareis": "desenraivar",
    "desenraivarem": "desenraivar",
    "desenraivaremos": "desenraivar",
    "desenraivares": "desenraivar",
    "desenraivaria": "desenraivar",
    "desenraivariam": "desenraivar",
    "desenraivarias": "desenraivar",
    "desenraivarmo": "desenraivar",
    "desenraivarmos": "desenraivar",
    "desenraivará": "desenraivar",
    "desenraivarás": "desenraivar",
    "desenraivarão": "desenraivar",
    "desenraivaríamos": "desenraivar",
    "desenraivaríeis": "desenraivar",
    "desenraivas": "desenraivar",
    "desenraivasse": "desenraivar",
    "desenraivassem": "desenraivar",
    "desenraivasses": "desenraivar",
    "desenraivaste": "desenraivar",
    "desenraivastes": "desenraivar",
    "desenraivava": "desenraivar",
    "desenraivavam": "desenraivar",
    "desenraivavas": "desenraivar",
    "desenraive": "desenraivar",
    "desenraivece": "desenraivecer",
    "desenraivecei": "desenraivecer",
    "desenraiveceis": "desenraivecer",
    "desenraivecem": "desenraivecer",
    "desenraivecemo": "desenraivecer",
    "desenraivecemos": "desenraivecer",
    "desenraivecendo": "desenraivecer",
    "desenraivecera": "desenraivecer",
    "desenraiveceram": "desenraivecer",
    "desenraiveceras": "desenraivecer",
    "desenraivecerde": "desenraivecer",
    "desenraivecerdes": "desenraivecer",
    "desenraivecere": "desenraivecer",
    "desenraivecerei": "desenraivecer",
    "desenraivecereis": "desenraivecer",
    "desenraivecerem": "desenraivecer",
    "desenraiveceremos": "desenraivecer",
    "desenraiveceres": "desenraivecer",
    "desenraiveceria": "desenraivecer",
    "desenraiveceriam": "desenraivecer",
    "desenraivecerias": "desenraivecer",
    "desenraivecermo": "desenraivecer",
    "desenraivecermos": "desenraivecer",
    "desenraivecerá": "desenraivecer",
    "desenraivecerás": "desenraivecer",
    "desenraivecerão": "desenraivecer",
    "desenraiveceríamos": "desenraivecer",
    "desenraiveceríeis": "desenraivecer",
    "desenraiveces": "desenraivecer",
    "desenraivecesse": "desenraivecer",
    "desenraivecessem": "desenraivecer",
    "desenraivecesses": "desenraivecer",
    "desenraiveceste": "desenraivecer",
    "desenraivecestes": "desenraivecer",
    "desenraiveceu": "desenraivecer",
    "desenraiveci": "desenraivecer",
    "desenraivecia": "desenraivecer",
    "desenraiveciam": "desenraivecer",
    "desenraivecias": "desenraivecer",
    "desenraivecida": "desenraivecido",
    "desenraivecidas": "desenraivecido",
    "desenraivecido": "desenraivecer",
    "desenraivecidos": "desenraivecido",
    "desenraivecê": "desenraivecer",
    "desenraivecêramo": "desenraivecer",
    "desenraivecêramos": "desenraivecer",
    "desenraivecêrei": "desenraivecer",
    "desenraivecêreis": "desenraivecer",
    "desenraivecêsseis": "desenraivecer",
    "desenraivecêssemos": "desenraivecer",
    "desenraivecíamo": "desenraivecer",
    "desenraivecíamos": "desenraivecer",
    "desenraivecíei": "desenraivecer",
    "desenraivecíeis": "desenraivecer",
    "desenraivei": "desenraivar",
    "desenraiveis": "desenraivar",
    "desenraivem": "desenraivar",
    "desenraivemo": "desenraivar",
    "desenraivemos": "desenraivar",
    "desenraives": "desenraivar",
    "desenraiveça": "desenraivecer",
    "desenraiveçais": "desenraivecer",
    "desenraiveçam": "desenraivecer",
    "desenraiveçamo": "desenraivecer",
    "desenraiveçamos": "desenraivecer",
    "desenraiveças": "desenraivecer",
    "desenraiveço": "desenraivecer",
    "desenraivo": "desenraivar",
    "desenraivou": "desenraivar",
    "desenraivá": "desenraivar",
    "desenraivámo": "desenraivar",
    "desenraivámos": "desenraivar",
    "desenraiváramo": "desenraivar",
    "desenraiváramos": "desenraivar",
    "desenraivárei": "desenraivar",
    "desenraiváreis": "desenraivar",
    "desenraivásseis": "desenraivar",
    "desenraivássemos": "desenraivar",
    "desenraivávamo": "desenraivar",
    "desenraivávamos": "desenraivar",
    "desenraivávei": "desenraivar",
    "desenraiváveis": "desenraivar",
    "desenraizada": "desenraizar",
    "desenraizadas": "desenraizar",
    "desenraizado": "desenraizar",
    "desenraizados": "desenraizar",
    "desenraizai": "desenraizar",
    "desenraizais": "desenraizar",
    "desenraizamentos": "desenraizamento",
    "desenraizamo": "desenraizar",
    "desenraizamos": "desenraizar",
    "desenraizando": "desenraizar",
    "desenraizara": "desenraizar",
    "desenraizaram": "desenraizar",
    "desenraizaras": "desenraizar",
    "desenraizarde": "desenraizar",
    "desenraizardes": "desenraizar",
    "desenraizare": "desenraizar",
    "desenraizarei": "desenraizar",
    "desenraizareis": "desenraizar",
    "desenraizarem": "desenraizar",
    "desenraizaremos": "desenraizar",
    "desenraizares": "desenraizar",
    "desenraizaria": "desenraizar",
    "desenraizariam": "desenraizar",
    "desenraizarias": "desenraizar",
    "desenraizarmo": "desenraizar",
    "desenraizarmos": "desenraizar",
    "desenraizará": "desenraizar",
    "desenraizarás": "desenraizar",
    "desenraizarão": "desenraizar",
    "desenraizaríamos": "desenraizar",
    "desenraizaríeis": "desenraizar",
    "desenraizasse": "desenraizar",
    "desenraizassem": "desenraizar",
    "desenraizasses": "desenraizar",
    "desenraizaste": "desenraizar",
    "desenraizastes": "desenraizar",
    "desenraizava": "desenraizar",
    "desenraizavam": "desenraizar",
    "desenraizavas": "desenraizar",
    "desenraizei": "desenraizar",
    "desenraizeis": "desenraizar",
    "desenraizemo": "desenraizar",
    "desenraizemos": "desenraizar",
    "desenraizou": "desenraizar",
    "desenraizá": "desenraizar",
    "desenraizámo": "desenraizar",
    "desenraizámos": "desenraizar",
    "desenraizáramo": "desenraizar",
    "desenraizáramos": "desenraizar",
    "desenraizárei": "desenraizar",
    "desenraizáreis": "desenraizar",
    "desenraizásseis": "desenraizar",
    "desenraizássemos": "desenraizar",
    "desenraizávamo": "desenraizar",
    "desenraizávamos": "desenraizar",
    "desenraizávei": "desenraizar",
    "desenraizáveis": "desenraizável",
    "desenraiá": "desenraiar",
    "desenraiámo": "desenraiar",
    "desenraiámos": "desenraiar",
    "desenraiáramo": "desenraiar",
    "desenraiáramos": "desenraiar",
    "desenraiárei": "desenraiar",
    "desenraiáreis": "desenraiar",
    "desenraiásseis": "desenraiar",
    "desenraiássemos": "desenraiar",
    "desenraiávamo": "desenraiar",
    "desenraiávamos": "desenraiar",
    "desenraiávei": "desenraiar",
    "desenraiáveis": "desenraiar",
    "desenrama": "desenramar",
    "desenramada": "desenramar",
    "desenramadas": "desenramar",
    "desenramado": "desenramar",
    "desenramados": "desenramar",
    "desenramai": "desenramar",
    "desenramais": "desenramar",
    "desenramam": "desenramar",
    "desenramamo": "desenramar",
    "desenramamos": "desenramar",
    "desenramando": "desenramar",
    "desenramara": "desenramar",
    "desenramaram": "desenramar",
    "desenramaras": "desenramar",
    "desenramarde": "desenramar",
    "desenramardes": "desenramar",
    "desenramare": "desenramar",
    "desenramarei": "desenramar",
    "desenramareis": "desenramar",
    "desenramarem": "desenramar",
    "desenramaremos": "desenramar",
    "desenramares": "desenramar",
    "desenramaria": "desenramar",
    "desenramariam": "desenramar",
    "desenramarias": "desenramar",
    "desenramarmo": "desenramar",
    "desenramarmos": "desenramar",
    "desenramará": "desenramar",
    "desenramarás": "desenramar",
    "desenramarão": "desenramar",
    "desenramaríamos": "desenramar",
    "desenramaríeis": "desenramar",
    "desenramas": "desenramar",
    "desenramasse": "desenramar",
    "desenramassem": "desenramar",
    "desenramasses": "desenramar",
    "desenramaste": "desenramar",
    "desenramastes": "desenramar",
    "desenramava": "desenramar",
    "desenramavam": "desenramar",
    "desenramavas": "desenramar",
    "desenrame": "desenramar",
    "desenramei": "desenramar",
    "desenrameis": "desenramar",
    "desenramem": "desenramar",
    "desenramemo": "desenramar",
    "desenramemos": "desenramar",
    "desenrames": "desenramar",
    "desenramo": "desenramar",
    "desenramou": "desenramar",
    "desenramá": "desenramar",
    "desenramámo": "desenramar",
    "desenramámos": "desenramar",
    "desenramáramo": "desenramar",
    "desenramáramos": "desenramar",
    "desenramárei": "desenramar",
    "desenramáreis": "desenramar",
    "desenramásseis": "desenramar",
    "desenramássemos": "desenramar",
    "desenramávamo": "desenramar",
    "desenramávamos": "desenramar",
    "desenramávei": "desenramar",
    "desenramáveis": "desenramar",
    "desenrasca": "desenrascar",
    "desenrascada": "desenrascar",
    "desenrascadas": "desenrascar",
    "desenrascado": "desenrascar",
    "desenrascados": "desenrascar",
    "desenrascai": "desenrascar",
    "desenrascais": "desenrascar",
    "desenrascam": "desenrascar",
    "desenrascamo": "desenrascar",
    "desenrascamos": "desenrascar",
    "desenrascando": "desenrascar",
    "desenrascara": "desenrascar",
    "desenrascaram": "desenrascar",
    "desenrascaras": "desenrascar",
    "desenrascarde": "desenrascar",
    "desenrascardes": "desenrascar",
    "desenrascare": "desenrascar",
    "desenrascarei": "desenrascar",
    "desenrascareis": "desenrascar",
    "desenrascarem": "desenrascar",
    "desenrascaremos": "desenrascar",
    "desenrascares": "desenrascar",
    "desenrascaria": "desenrascar",
    "desenrascariam": "desenrascar",
    "desenrascarias": "desenrascar",
    "desenrascarmo": "desenrascar",
    "desenrascarmos": "desenrascar",
    "desenrascará": "desenrascar",
    "desenrascarás": "desenrascar",
    "desenrascarão": "desenrascar",
    "desenrascaríamos": "desenrascar",
    "desenrascaríeis": "desenrascar",
    "desenrascas": "desenrascar",
    "desenrascasse": "desenrascar",
    "desenrascassem": "desenrascar",
    "desenrascasses": "desenrascar",
    "desenrascaste": "desenrascar",
    "desenrascastes": "desenrascar",
    "desenrascava": "desenrascar",
    "desenrascavam": "desenrascar",
    "desenrascavas": "desenrascar",
    "desenrasco": "desenrascar",
    "desenrascou": "desenrascar",
    "desenrascá": "desenrascar",
    "desenrascámo": "desenrascar",
    "desenrascámos": "desenrascar",
    "desenrascáramo": "desenrascar",
    "desenrascáramos": "desenrascar",
    "desenrascárei": "desenrascar",
    "desenrascáreis": "desenrascar",
    "desenrascásseis": "desenrascar",
    "desenrascássemos": "desenrascar",
    "desenrascávamo": "desenrascar",
    "desenrascávamos": "desenrascar",
    "desenrascávei": "desenrascar",
    "desenrascáveis": "desenrascar",
    "desenrasque": "desenrascar",
    "desenrasquei": "desenrascar",
    "desenrasqueis": "desenrascar",
    "desenrasquem": "desenrascar",
    "desenrasquemo": "desenrascar",
    "desenrasquemos": "desenrascar",
    "desenrasques": "desenrascar",
    "desenraíza": "desenraizar",
    "desenraízam": "desenraizar",
    "desenraízas": "desenraizar",
    "desenraíze": "desenraizar",
    "desenraízem": "desenraizar",
    "desenraízes": "desenraizar",
    "desenraízo": "desenraizar",
    "desenreda": "desenredar",
    "desenredada": "desenredar",
    "desenredadas": "desenredar",
    "desenredado": "desenredar",
    "desenredadora": "desenredador",
    "desenredadoras": "desenredador",
    "desenredadores": "desenredador",
    "desenredados": "desenredar",
    "desenredai": "desenredar",
    "desenredais": "desenredar",
    "desenredam": "desenredar",
    "desenredamo": "desenredar",
    "desenredamos": "desenredar",
    "desenredando": "desenredar",
    "desenredara": "desenredar",
    "desenredaram": "desenredar",
    "desenredaras": "desenredar",
    "desenredarde": "desenredar",
    "desenredardes": "desenredar",
    "desenredare": "desenredar",
    "desenredarei": "desenredar",
    "desenredareis": "desenredar",
    "desenredarem": "desenredar",
    "desenredaremos": "desenredar",
    "desenredares": "desenredar",
    "desenredaria": "desenredar",
    "desenredariam": "desenredar",
    "desenredarias": "desenredar",
    "desenredarmo": "desenredar",
    "desenredarmos": "desenredar",
    "desenredará": "desenredar",
    "desenredarás": "desenredar",
    "desenredarão": "desenredar",
    "desenredaríamos": "desenredar",
    "desenredaríeis": "desenredar",
    "desenredas": "desenredar",
    "desenredasse": "desenredar",
    "desenredassem": "desenredar",
    "desenredasses": "desenredar",
    "desenredaste": "desenredar",
    "desenredastes": "desenredar",
    "desenredava": "desenredar",
    "desenredavam": "desenredar",
    "desenredavas": "desenredar",
    "desenrede": "desenredar",
    "desenredei": "desenredar",
    "desenredeis": "desenredar",
    "desenredem": "desenredar",
    "desenredemo": "desenredar",
    "desenredemos": "desenredar",
    "desenredes": "desenredar",
    "desenredo": "desenredar",
    "desenredos": "desenredo",
    "desenredou": "desenredar",
    "desenredá": "desenredar",
    "desenredámo": "desenredar",
    "desenredámos": "desenredar",
    "desenredáramo": "desenredar",
    "desenredáramos": "desenredar",
    "desenredárei": "desenredar",
    "desenredáreis": "desenredar",
    "desenredásseis": "desenredar",
    "desenredássemos": "desenredar",
    "desenredávamo": "desenredar",
    "desenredávamos": "desenredar",
    "desenredávei": "desenredar",
    "desenredáveis": "desenredar",
    "desenregela": "desenregelar",
    "desenregelada": "desenregelar",
    "desenregeladas": "desenregelar",
    "desenregelado": "desenregelar",
    "desenregelados": "desenregelar",
    "desenregelai": "desenregelar",
    "desenregelais": "desenregelar",
    "desenregelam": "desenregelar",
    "desenregelamentos": "desenregelamento",
    "desenregelamo": "desenregelar",
    "desenregelamos": "desenregelar",
    "desenregelando": "desenregelar",
    "desenregelara": "desenregelar",
    "desenregelaram": "desenregelar",
    "desenregelaras": "desenregelar",
    "desenregelardes": "desenregelar",
    "desenregelarei": "desenregelar",
    "desenregelareis": "desenregelar",
    "desenregelarem": "desenregelar",
    "desenregelaremos": "desenregelar",
    "desenregelares": "desenregelar",
    "desenregelaria": "desenregelar",
    "desenregelariam": "desenregelar",
    "desenregelarias": "desenregelar",
    "desenregelarmo": "desenregelar",
    "desenregelarmos": "desenregelar",
    "desenregelará": "desenregelar",
    "desenregelarás": "desenregelar",
    "desenregelarão": "desenregelar",
    "desenregelaríamos": "desenregelar",
    "desenregelaríeis": "desenregelar",
    "desenregelas": "desenregelar",
    "desenregelasse": "desenregelar",
    "desenregelassem": "desenregelar",
    "desenregelasses": "desenregelar",
    "desenregelaste": "desenregelar",
    "desenregelastes": "desenregelar",
    "desenregelava": "desenregelar",
    "desenregelavam": "desenregelar",
    "desenregelavas": "desenregelar",
    "desenregele": "desenregelar",
    "desenregelei": "desenregelar",
    "desenregeleis": "desenregelar",
    "desenregelem": "desenregelar",
    "desenregelemo": "desenregelar",
    "desenregelemos": "desenregelar",
    "desenregeles": "desenregelar",
    "desenregelo": "desenregelar",
    "desenregelou": "desenregelar",
    "desenregelámo": "desenregelar",
    "desenregelámos": "desenregelar",
    "desenregeláramo": "desenregelar",
    "desenregeláramos": "desenregelar",
    "desenregeláreis": "desenregelar",
    "desenregelásseis": "desenregelar",
    "desenregelássemos": "desenregelar",
    "desenregelávamo": "desenregelar",
    "desenregelávamos": "desenregelar",
    "desenregeláveis": "desenregelar",
    "desenrice": "desenriçar",
    "desenricei": "desenriçar",
    "desenriceis": "desenriçar",
    "desenricem": "desenriçar",
    "desenricemo": "desenriçar",
    "desenricemos": "desenriçar",
    "desenrices": "desenriçar",
    "desenrija": "desenrijar",
    "desenrijada": "desenrijar",
    "desenrijadas": "desenrijar",
    "desenrijado": "desenrijar",
    "desenrijados": "desenrijar",
    "desenrijai": "desenrijar",
    "desenrijais": "desenrijar",
    "desenrijam": "desenrijar",
    "desenrijamo": "desenrijar",
    "desenrijamos": "desenrijar",
    "desenrijando": "desenrijar",
    "desenrijara": "desenrijar",
    "desenrijaram": "desenrijar",
    "desenrijaras": "desenrijar",
    "desenrijarde": "desenrijar",
    "desenrijardes": "desenrijar",
    "desenrijare": "desenrijar",
    "desenrijarei": "desenrijar",
    "desenrijareis": "desenrijar",
    "desenrijarem": "desenrijar",
    "desenrijaremos": "desenrijar",
    "desenrijares": "desenrijar",
    "desenrijaria": "desenrijar",
    "desenrijariam": "desenrijar",
    "desenrijarias": "desenrijar",
    "desenrijarmo": "desenrijar",
    "desenrijarmos": "desenrijar",
    "desenrijará": "desenrijar",
    "desenrijarás": "desenrijar",
    "desenrijarão": "desenrijar",
    "desenrijaríamos": "desenrijar",
    "desenrijaríeis": "desenrijar",
    "desenrijas": "desenrijar",
    "desenrijasse": "desenrijar",
    "desenrijassem": "desenrijar",
    "desenrijasses": "desenrijar",
    "desenrijaste": "desenrijar",
    "desenrijastes": "desenrijar",
    "desenrijava": "desenrijar",
    "desenrijavam": "desenrijar",
    "desenrijavas": "desenrijar",
    "desenrije": "desenrijar",
    "desenrijei": "desenrijar",
    "desenrijeis": "desenrijar",
    "desenrijem": "desenrijar",
    "desenrijemo": "desenrijar",
    "desenrijemos": "desenrijar",
    "desenrijes": "desenrijar",
    "desenrijo": "desenrijar",
    "desenrijou": "desenrijar",
    "desenrijá": "desenrijar",
    "desenrijámo": "desenrijar",
    "desenrijámos": "desenrijar",
    "desenrijáramo": "desenrijar",
    "desenrijáramos": "desenrijar",
    "desenrijárei": "desenrijar",
    "desenrijáreis": "desenrijar",
    "desenrijásseis": "desenrijar",
    "desenrijássemos": "desenrijar",
    "desenrijávamo": "desenrijar",
    "desenrijávamos": "desenrijar",
    "desenrijávei": "desenrijar",
    "desenrijáveis": "desenrijar",
    "desenriquece": "desenriquecer",
    "desenriquecei": "desenriquecer",
    "desenriqueceis": "desenriquecer",
    "desenriquecem": "desenriquecer",
    "desenriquecemo": "desenriquecer",
    "desenriquecemos": "desenriquecer",
    "desenriquecendo": "desenriquecer",
    "desenriquecera": "desenriquecer",
    "desenriqueceram": "desenriquecer",
    "desenriqueceras": "desenriquecer",
    "desenriquecerdes": "desenriquecer",
    "desenriquecerei": "desenriquecer",
    "desenriquecereis": "desenriquecer",
    "desenriquecerem": "desenriquecer",
    "desenriqueceremos": "desenriquecer",
    "desenriqueceres": "desenriquecer",
    "desenriqueceria": "desenriquecer",
    "desenriqueceriam": "desenriquecer",
    "desenriquecerias": "desenriquecer",
    "desenriquecermo": "desenriquecer",
    "desenriquecermos": "desenriquecer",
    "desenriquecerá": "desenriquecer",
    "desenriquecerás": "desenriquecer",
    "desenriquecerão": "desenriquecer",
    "desenriqueceríamos": "desenriquecer",
    "desenriqueceríeis": "desenriquecer",
    "desenriqueces": "desenriquecer",
    "desenriquecesse": "desenriquecer",
    "desenriquecessem": "desenriquecer",
    "desenriquecesses": "desenriquecer",
    "desenriqueceste": "desenriquecer",
    "desenriquecestes": "desenriquecer",
    "desenriqueceu": "desenriquecer",
    "desenriqueci": "desenriquecer",
    "desenriquecia": "desenriquecer",
    "desenriqueciam": "desenriquecer",
    "desenriquecias": "desenriquecer",
    "desenriquecida": "desenriquecido",
    "desenriquecidas": "desenriquecido",
    "desenriquecido": "desenriquecer",
    "desenriquecidos": "desenriquecido",
    "desenriquecêramo": "desenriquecer",
    "desenriquecêramos": "desenriquecer",
    "desenriquecêreis": "desenriquecer",
    "desenriquecêsseis": "desenriquecer",
    "desenriquecêssemos": "desenriquecer",
    "desenriquecíamo": "desenriquecer",
    "desenriquecíamos": "desenriquecer",
    "desenriquecíeis": "desenriquecer",
    "desenriqueça": "desenriquecer",
    "desenriqueçais": "desenriquecer",
    "desenriqueçam": "desenriquecer",
    "desenriqueçamo": "desenriquecer",
    "desenriqueçamos": "desenriquecer",
    "desenriqueças": "desenriquecer",
    "desenriqueço": "desenriquecer",
    "desenrista": "desenristar",
    "desenristada": "desenristar",
    "desenristadas": "desenristar",
    "desenristado": "desenristar",
    "desenristados": "desenristar",
    "desenristai": "desenristar",
    "desenristais": "desenristar",
    "desenristam": "desenristar",
    "desenristamo": "desenristar",
    "desenristamos": "desenristar",
    "desenristando": "desenristar",
    "desenristara": "desenristar",
    "desenristaram": "desenristar",
    "desenristaras": "desenristar",
    "desenristarde": "desenristar",
    "desenristardes": "desenristar",
    "desenristare": "desenristar",
    "desenristarei": "desenristar",
    "desenristareis": "desenristar",
    "desenristarem": "desenristar",
    "desenristaremos": "desenristar",
    "desenristares": "desenristar",
    "desenristaria": "desenristar",
    "desenristariam": "desenristar",
    "desenristarias": "desenristar",
    "desenristarmo": "desenristar",
    "desenristarmos": "desenristar",
    "desenristará": "desenristar",
    "desenristarás": "desenristar",
    "desenristarão": "desenristar",
    "desenristaríamos": "desenristar",
    "desenristaríeis": "desenristar",
    "desenristas": "desenristar",
    "desenristasse": "desenristar",
    "desenristassem": "desenristar",
    "desenristasses": "desenristar",
    "desenristaste": "desenristar",
    "desenristastes": "desenristar",
    "desenristava": "desenristar",
    "desenristavam": "desenristar",
    "desenristavas": "desenristar",
    "desenriste": "desenristar",
    "desenristei": "desenristar",
    "desenristeis": "desenristar",
    "desenristem": "desenristar",
    "desenristemo": "desenristar",
    "desenristemos": "desenristar",
    "desenristes": "desenristar",
    "desenristo": "desenristar",
    "desenristou": "desenristar",
    "desenristá": "desenristar",
    "desenristámo": "desenristar",
    "desenristámos": "desenristar",
    "desenristáramo": "desenristar",
    "desenristáramos": "desenristar",
    "desenristárei": "desenristar",
    "desenristáreis": "desenristar",
    "desenristásseis": "desenristar",
    "desenristássemos": "desenristar",
    "desenristávamo": "desenristar",
    "desenristávamos": "desenristar",
    "desenristávei": "desenristar",
    "desenristáveis": "desenristar",
    "desenriza": "desenrizar",
    "desenrizada": "desenrizar",
    "desenrizadas": "desenrizar",
    "desenrizado": "desenrizar",
    "desenrizados": "desenrizar",
    "desenrizai": "desenrizar",
    "desenrizais": "desenrizar",
    "desenrizam": "desenrizar",
    "desenrizamo": "desenrizar",
    "desenrizamos": "desenrizar",
    "desenrizando": "desenrizar",
    "desenrizara": "desenrizar",
    "desenrizaram": "desenrizar",
    "desenrizaras": "desenrizar",
    "desenrizarde": "desenrizar",
    "desenrizardes": "desenrizar",
    "desenrizare": "desenrizar",
    "desenrizarei": "desenrizar",
    "desenrizareis": "desenrizar",
    "desenrizarem": "desenrizar",
    "desenrizaremos": "desenrizar",
    "desenrizares": "desenrizar",
    "desenrizaria": "desenrizar",
    "desenrizariam": "desenrizar",
    "desenrizarias": "desenrizar",
    "desenrizarmo": "desenrizar",
    "desenrizarmos": "desenrizar",
    "desenrizará": "desenrizar",
    "desenrizarás": "desenrizar",
    "desenrizarão": "desenrizar",
    "desenrizaríamos": "desenrizar",
    "desenrizaríeis": "desenrizar",
    "desenrizas": "desenrizar",
    "desenrizasse": "desenrizar",
    "desenrizassem": "desenrizar",
    "desenrizasses": "desenrizar",
    "desenrizaste": "desenrizar",
    "desenrizastes": "desenrizar",
    "desenrizava": "desenrizar",
    "desenrizavam": "desenrizar",
    "desenrizavas": "desenrizar",
    "desenrize": "desenrizar",
    "desenrizei": "desenrizar",
    "desenrizeis": "desenrizar",
    "desenrizem": "desenrizar",
    "desenrizemo": "desenrizar",
    "desenrizemos": "desenrizar",
    "desenrizes": "desenrizar",
    "desenrizo": "desenrizar",
    "desenrizou": "desenrizar",
    "desenrizá": "desenrizar",
    "desenrizámo": "desenrizar",
    "desenrizámos": "desenrizar",
    "desenrizáramo": "desenrizar",
    "desenrizáramos": "desenrizar",
    "desenrizárei": "desenrizar",
    "desenrizáreis": "desenrizar",
    "desenrizásseis": "desenrizar",
    "desenrizássemos": "desenrizar",
    "desenrizávamo": "desenrizar",
    "desenrizávamos": "desenrizar",
    "desenrizávei": "desenrizar",
    "desenrizáveis": "desenrizar",
    "desenriça": "desenriçar",
    "desenriçada": "desenriçar",
    "desenriçadas": "desenriçar",
    "desenriçado": "desenriçar",
    "desenriçados": "desenriçar",
    "desenriçai": "desenriçar",
    "desenriçais": "desenriçar",
    "desenriçam": "desenriçar",
    "desenriçamo": "desenriçar",
    "desenriçamos": "desenriçar",
    "desenriçando": "desenriçar",
    "desenriçara": "desenriçar",
    "desenriçaram": "desenriçar",
    "desenriçaras": "desenriçar",
    "desenriçarde": "desenriçar",
    "desenriçardes": "desenriçar",
    "desenriçare": "desenriçar",
    "desenriçarei": "desenriçar",
    "desenriçareis": "desenriçar",
    "desenriçarem": "desenriçar",
    "desenriçaremos": "desenriçar",
    "desenriçares": "desenriçar",
    "desenriçaria": "desenriçar",
    "desenriçariam": "desenriçar",
    "desenriçarias": "desenriçar",
    "desenriçarmo": "desenriçar",
    "desenriçarmos": "desenriçar",
    "desenriçará": "desenriçar",
    "desenriçarás": "desenriçar",
    "desenriçarão": "desenriçar",
    "desenriçaríamos": "desenriçar",
    "desenriçaríeis": "desenriçar",
    "desenriças": "desenriçar",
    "desenriçasse": "desenriçar",
    "desenriçassem": "desenriçar",
    "desenriçasses": "desenriçar",
    "desenriçaste": "desenriçar",
    "desenriçastes": "desenriçar",
    "desenriçava": "desenriçar",
    "desenriçavam": "desenriçar",
    "desenriçavas": "desenriçar",
    "desenriço": "desenriçar",
    "desenriçou": "desenriçar",
    "desenriçá": "desenriçar",
    "desenriçámo": "desenriçar",
    "desenriçámos": "desenriçar",
    "desenriçáramo": "desenriçar",
    "desenriçáramos": "desenriçar",
    "desenriçárei": "desenriçar",
    "desenriçáreis": "desenriçar",
    "desenriçásseis": "desenriçar",
    "desenriçássemos": "desenriçar",
    "desenriçávamo": "desenriçar",
    "desenriçávamos": "desenriçar",
    "desenriçávei": "desenriçar",
    "desenriçáveis": "desenriçar",
    "desenrodilha": "desenrodilhar",
    "desenrodilhada": "desenrodilhar",
    "desenrodilhadas": "desenrodilhar",
    "desenrodilhado": "desenrodilhar",
    "desenrodilhados": "desenrodilhar",
    "desenrodilhai": "desenrodilhar",
    "desenrodilhais": "desenrodilhar",
    "desenrodilham": "desenrodilhar",
    "desenrodilhamo": "desenrodilhar",
    "desenrodilhamos": "desenrodilhar",
    "desenrodilhando": "desenrodilhar",
    "desenrodilhara": "desenrodilhar",
    "desenrodilharam": "desenrodilhar",
    "desenrodilharas": "desenrodilhar",
    "desenrodilharde": "desenrodilhar",
    "desenrodilhardes": "desenrodilhar",
    "desenrodilhare": "desenrodilhar",
    "desenrodilharei": "desenrodilhar",
    "desenrodilhareis": "desenrodilhar",
    "desenrodilharem": "desenrodilhar",
    "desenrodilharemos": "desenrodilhar",
    "desenrodilhares": "desenrodilhar",
    "desenrodilharia": "desenrodilhar",
    "desenrodilhariam": "desenrodilhar",
    "desenrodilharias": "desenrodilhar",
    "desenrodilharmo": "desenrodilhar",
    "desenrodilharmos": "desenrodilhar",
    "desenrodilhará": "desenrodilhar",
    "desenrodilharás": "desenrodilhar",
    "desenrodilharão": "desenrodilhar",
    "desenrodilharíamos": "desenrodilhar",
    "desenrodilharíeis": "desenrodilhar",
    "desenrodilhas": "desenrodilhar",
    "desenrodilhasse": "desenrodilhar",
    "desenrodilhassem": "desenrodilhar",
    "desenrodilhasses": "desenrodilhar",
    "desenrodilhaste": "desenrodilhar",
    "desenrodilhastes": "desenrodilhar",
    "desenrodilhava": "desenrodilhar",
    "desenrodilhavam": "desenrodilhar",
    "desenrodilhavas": "desenrodilhar",
    "desenrodilhe": "desenrodilhar",
    "desenrodilhei": "desenrodilhar",
    "desenrodilheis": "desenrodilhar",
    "desenrodilhem": "desenrodilhar",
    "desenrodilhemo": "desenrodilhar",
    "desenrodilhemos": "desenrodilhar",
    "desenrodilhes": "desenrodilhar",
    "desenrodilho": "desenrodilhar",
    "desenrodilhou": "desenrodilhar",
    "desenrodilhá": "desenrodilhar",
    "desenrodilhámo": "desenrodilhar",
    "desenrodilhámos": "desenrodilhar",
    "desenrodilháramo": "desenrodilhar",
    "desenrodilháramos": "desenrodilhar",
    "desenrodilhárei": "desenrodilhar",
    "desenrodilháreis": "desenrodilhar",
    "desenrodilhásseis": "desenrodilhar",
    "desenrodilhássemos": "desenrodilhar",
    "desenrodilhávamo": "desenrodilhar",
    "desenrodilhávamos": "desenrodilhar",
    "desenrodilhávei": "desenrodilhar",
    "desenrodilháveis": "desenrodilhar",
    "desenrola": "desenrolar",
    "desenrolada": "desenrolar",
    "desenroladas": "desenrolar",
    "desenrolado": "desenrolar",
    "desenrolados": "desenrolar",
    "desenrolai": "desenrolar",
    "desenrolais": "desenrolar",
    "desenrolam": "desenrolar",
    "desenrolamentos": "desenrolamento",
    "desenrolamo": "desenrolar",
    "desenrolamos": "desenrolar",
    "desenrolando": "desenrolar",
    "desenrolara": "desenrolar",
    "desenrolaram": "desenrolar",
    "desenrolaras": "desenrolar",
    "desenrolarde": "desenrolar",
    "desenrolardes": "desenrolar",
    "desenrolare": "desenrolar",
    "desenrolarei": "desenrolar",
    "desenrolareis": "desenrolar",
    "desenrolarem": "desenrolar",
    "desenrolaremos": "desenrolar",
    "desenrolares": "desenrolar",
    "desenrolaria": "desenrolar",
    "desenrolariam": "desenrolar",
    "desenrolarias": "desenrolar",
    "desenrolarmo": "desenrolar",
    "desenrolarmos": "desenrolar",
    "desenrolará": "desenrolar",
    "desenrolarás": "desenrolar",
    "desenrolarão": "desenrolar",
    "desenrolaríamos": "desenrolar",
    "desenrolaríeis": "desenrolar",
    "desenrolas": "desenrolar",
    "desenrolasse": "desenrolar",
    "desenrolassem": "desenrolar",
    "desenrolasses": "desenrolar",
    "desenrolaste": "desenrolar",
    "desenrolastes": "desenrolar",
    "desenrolava": "desenrolar",
    "desenrolavam": "desenrolar",
    "desenrolavas": "desenrolar",
    "desenrole": "desenrolar",
    "desenrolei": "desenrolar",
    "desenroleis": "desenrolar",
    "desenrolem": "desenrolar",
    "desenrolemo": "desenrolar",
    "desenrolemos": "desenrolar",
    "desenroles": "desenrolar",
    "desenrolha": "desenrolhar",
    "desenrolhada": "desenrolhar",
    "desenrolhadas": "desenrolhar",
    "desenrolhado": "desenrolhar",
    "desenrolhados": "desenrolhar",
    "desenrolhai": "desenrolhar",
    "desenrolhais": "desenrolhar",
    "desenrolham": "desenrolhar",
    "desenrolhamo": "desenrolhar",
    "desenrolhamos": "desenrolhar",
    "desenrolhando": "desenrolhar",
    "desenrolhara": "desenrolhar",
    "desenrolharam": "desenrolhar",
    "desenrolharas": "desenrolhar",
    "desenrolharde": "desenrolhar",
    "desenrolhardes": "desenrolhar",
    "desenrolhare": "desenrolhar",
    "desenrolharei": "desenrolhar",
    "desenrolhareis": "desenrolhar",
    "desenrolharem": "desenrolhar",
    "desenrolharemos": "desenrolhar",
    "desenrolhares": "desenrolhar",
    "desenrolharia": "desenrolhar",
    "desenrolhariam": "desenrolhar",
    "desenrolharias": "desenrolhar",
    "desenrolharmo": "desenrolhar",
    "desenrolharmos": "desenrolhar",
    "desenrolhará": "desenrolhar",
    "desenrolharás": "desenrolhar",
    "desenrolharão": "desenrolhar",
    "desenrolharíamos": "desenrolhar",
    "desenrolharíeis": "desenrolhar",
    "desenrolhas": "desenrolhar",
    "desenrolhasse": "desenrolhar",
    "desenrolhassem": "desenrolhar",
    "desenrolhasses": "desenrolhar",
    "desenrolhaste": "desenrolhar",
    "desenrolhastes": "desenrolhar",
    "desenrolhava": "desenrolhar",
    "desenrolhavam": "desenrolhar",
    "desenrolhavas": "desenrolhar",
    "desenrolhe": "desenrolhar",
    "desenrolhei": "desenrolhar",
    "desenrolheis": "desenrolhar",
    "desenrolhem": "desenrolhar",
    "desenrolhemo": "desenrolhar",
    "desenrolhemos": "desenrolhar",
    "desenrolhes": "desenrolhar",
    "desenrolho": "desenrolhar",
    "desenrolhou": "desenrolhar",
    "desenrolhá": "desenrolhar",
    "desenrolhámo": "desenrolhar",
    "desenrolhámos": "desenrolhar",
    "desenrolháramo": "desenrolhar",
    "desenrolháramos": "desenrolhar",
    "desenrolhárei": "desenrolhar",
    "desenrolháreis": "desenrolhar",
    "desenrolhásseis": "desenrolhar",
    "desenrolhássemos": "desenrolhar",
    "desenrolhávamo": "desenrolhar",
    "desenrolhávamos": "desenrolhar",
    "desenrolhávei": "desenrolhar",
    "desenrolháveis": "desenrolhar",
    "desenrolo": "desenrolar",
    "desenrolos": "desenrolo",
    "desenrolou": "desenrolar",
    "desenrolá": "desenrolar",
    "desenrolámo": "desenrolar",
    "desenrolámos": "desenrolar",
    "desenroláramo": "desenrolar",
    "desenroláramos": "desenrolar",
    "desenrolárei": "desenrolar",
    "desenroláreis": "desenrolar",
    "desenrolásseis": "desenrolar",
    "desenrolássemos": "desenrolar",
    "desenrolávamo": "desenrolar",
    "desenrolávamos": "desenrolar",
    "desenrolávei": "desenrolar",
    "desenroláveis": "desenrolável",
    "desenrosca": "desenroscar",
    "desenroscada": "desenroscar",
    "desenroscadas": "desenroscar",
    "desenroscado": "desenroscar",
    "desenroscados": "desenroscar",
    "desenroscai": "desenroscar",
    "desenroscais": "desenroscar",
    "desenroscam": "desenroscar",
    "desenroscamo": "desenroscar",
    "desenroscamos": "desenroscar",
    "desenroscando": "desenroscar",
    "desenroscara": "desenroscar",
    "desenroscaram": "desenroscar",
    "desenroscaras": "desenroscar",
    "desenroscarde": "desenroscar",
    "desenroscardes": "desenroscar",
    "desenroscare": "desenroscar",
    "desenroscarei": "desenroscar",
    "desenroscareis": "desenroscar",
    "desenroscarem": "desenroscar",
    "desenroscaremos": "desenroscar",
    "desenroscares": "desenroscar",
    "desenroscaria": "desenroscar",
    "desenroscariam": "desenroscar",
    "desenroscarias": "desenroscar",
    "desenroscarmo": "desenroscar",
    "desenroscarmos": "desenroscar",
    "desenroscará": "desenroscar",
    "desenroscarás": "desenroscar",
    "desenroscarão": "desenroscar",
    "desenroscaríamos": "desenroscar",
    "desenroscaríeis": "desenroscar",
    "desenroscas": "desenroscar",
    "desenroscasse": "desenroscar",
    "desenroscassem": "desenroscar",
    "desenroscasses": "desenroscar",
    "desenroscaste": "desenroscar",
    "desenroscastes": "desenroscar",
    "desenroscava": "desenroscar",
    "desenroscavam": "desenroscar",
    "desenroscavas": "desenroscar",
    "desenrosco": "desenroscar",
    "desenroscou": "desenroscar",
    "desenroscá": "desenroscar",
    "desenroscámo": "desenroscar",
    "desenroscámos": "desenroscar",
    "desenroscáramo": "desenroscar",
    "desenroscáramos": "desenroscar",
    "desenroscárei": "desenroscar",
    "desenroscáreis": "desenroscar",
    "desenroscásseis": "desenroscar",
    "desenroscássemos": "desenroscar",
    "desenroscávamo": "desenroscar",
    "desenroscávamos": "desenroscar",
    "desenroscávei": "desenroscar",
    "desenroscáveis": "desenroscável",
    "desenrosque": "desenroscar",
    "desenrosquei": "desenroscar",
    "desenrosqueis": "desenroscar",
    "desenrosquem": "desenroscar",
    "desenrosquemo": "desenroscar",
    "desenrosquemos": "desenroscar",
    "desenrosques": "desenroscar",
    "desenroupa": "desenroupar",
    "desenroupada": "desenroupar",
    "desenroupadas": "desenroupar",
    "desenroupado": "desenroupar",
    "desenroupados": "desenroupar",
    "desenroupai": "desenroupar",
    "desenroupais": "desenroupar",
    "desenroupam": "desenroupar",
    "desenroupamo": "desenroupar",
    "desenroupamos": "desenroupar",
    "desenroupando": "desenroupar",
    "desenroupara": "desenroupar",
    "desenrouparam": "desenroupar",
    "desenrouparas": "desenroupar",
    "desenrouparde": "desenroupar",
    "desenroupardes": "desenroupar",
    "desenroupare": "desenroupar",
    "desenrouparei": "desenroupar",
    "desenroupareis": "desenroupar",
    "desenrouparem": "desenroupar",
    "desenrouparemos": "desenroupar",
    "desenroupares": "desenroupar",
    "desenrouparia": "desenroupar",
    "desenroupariam": "desenroupar",
    "desenrouparias": "desenroupar",
    "desenrouparmo": "desenroupar",
    "desenrouparmos": "desenroupar",
    "desenroupará": "desenroupar",
    "desenrouparás": "desenroupar",
    "desenrouparão": "desenroupar",
    "desenrouparíamos": "desenroupar",
    "desenrouparíeis": "desenroupar",
    "desenroupas": "desenroupar",
    "desenroupasse": "desenroupar",
    "desenroupassem": "desenroupar",
    "desenroupasses": "desenroupar",
    "desenroupaste": "desenroupar",
    "desenroupastes": "desenroupar",
    "desenroupava": "desenroupar",
    "desenroupavam": "desenroupar",
    "desenroupavas": "desenroupar",
    "desenroupe": "desenroupar",
    "desenroupei": "desenroupar",
    "desenroupeis": "desenroupar",
    "desenroupem": "desenroupar",
    "desenroupemo": "desenroupar",
    "desenroupemos": "desenroupar",
    "desenroupes": "desenroupar",
    "desenroupo": "desenroupar",
    "desenroupou": "desenroupar",
    "desenroupá": "desenroupar",
    "desenroupámo": "desenroupar",
    "desenroupámos": "desenroupar",
    "desenroupáramo": "desenroupar",
    "desenroupáramos": "desenroupar",
    "desenroupárei": "desenroupar",
    "desenroupáreis": "desenroupar",
    "desenroupásseis": "desenroupar",
    "desenroupássemos": "desenroupar",
    "desenroupávamo": "desenroupar",
    "desenroupávamos": "desenroupar",
    "desenroupávei": "desenroupar",
    "desenroupáveis": "desenroupar",
    "desenrouquece": "desenrouquecer",
    "desenrouquecei": "desenrouquecer",
    "desenrouqueceis": "desenrouquecer",
    "desenrouquecem": "desenrouquecer",
    "desenrouquecemo": "desenrouquecer",
    "desenrouquecemos": "desenrouquecer",
    "desenrouquecendo": "desenrouquecer",
    "desenrouquecera": "desenrouquecer",
    "desenrouqueceram": "desenrouquecer",
    "desenrouqueceras": "desenrouquecer",
    "desenrouquecerdes": "desenrouquecer",
    "desenrouquecerei": "desenrouquecer",
    "desenrouquecereis": "desenrouquecer",
    "desenrouquecerem": "desenrouquecer",
    "desenrouqueceremos": "desenrouquecer",
    "desenrouqueceres": "desenrouquecer",
    "desenrouqueceria": "desenrouquecer",
    "desenrouqueceriam": "desenrouquecer",
    "desenrouquecerias": "desenrouquecer",
    "desenrouquecermo": "desenrouquecer",
    "desenrouquecermos": "desenrouquecer",
    "desenrouquecerá": "desenrouquecer",
    "desenrouquecerás": "desenrouquecer",
    "desenrouquecerão": "desenrouquecer",
    "desenrouqueceríamos": "desenrouquecer",
    "desenrouqueceríeis": "desenrouquecer",
    "desenrouqueces": "desenrouquecer",
    "desenrouquecesse": "desenrouquecer",
    "desenrouquecessem": "desenrouquecer",
    "desenrouquecesses": "desenrouquecer",
    "desenrouqueceste": "desenrouquecer",
    "desenrouquecestes": "desenrouquecer",
    "desenrouqueceu": "desenrouquecer",
    "desenrouqueci": "desenrouquecer",
    "desenrouquecia": "desenrouquecer",
    "desenrouqueciam": "desenrouquecer",
    "desenrouquecias": "desenrouquecer",
    "desenrouquecida": "desenrouquecido",
    "desenrouquecidas": "desenrouquecido",
    "desenrouquecido": "desenrouquecer",
    "desenrouquecidos": "desenrouquecido",
    "desenrouquecêramo": "desenrouquecer",
    "desenrouquecêramos": "desenrouquecer",
    "desenrouquecêreis": "desenrouquecer",
    "desenrouquecêsseis": "desenrouquecer",
    "desenrouquecêssemos": "desenrouquecer",
    "desenrouquecíamo": "desenrouquecer",
    "desenrouquecíamos": "desenrouquecer",
    "desenrouquecíeis": "desenrouquecer",
    "desenrouqueça": "desenrouquecer",
    "desenrouqueçais": "desenrouquecer",
    "desenrouqueçam": "desenrouquecer",
    "desenrouqueçamo": "desenrouquecer",
    "desenrouqueçamos": "desenrouquecer",
    "desenrouqueças": "desenrouquecer",
    "desenrouqueço": "desenrouquecer",
    "desenrubesce": "desenrubescer",
    "desenrubescei": "desenrubescer",
    "desenrubesceis": "desenrubescer",
    "desenrubescem": "desenrubescer",
    "desenrubescemo": "desenrubescer",
    "desenrubescemos": "desenrubescer",
    "desenrubescendo": "desenrubescer",
    "desenrubescera": "desenrubescer",
    "desenrubesceram": "desenrubescer",
    "desenrubesceras": "desenrubescer",
    "desenrubescerdes": "desenrubescer",
    "desenrubescerei": "desenrubescer",
    "desenrubescereis": "desenrubescer",
    "desenrubescerem": "desenrubescer",
    "desenrubesceremos": "desenrubescer",
    "desenrubesceres": "desenrubescer",
    "desenrubesceria": "desenrubescer",
    "desenrubesceriam": "desenrubescer",
    "desenrubescerias": "desenrubescer",
    "desenrubescermo": "desenrubescer",
    "desenrubescermos": "desenrubescer",
    "desenrubescerá": "desenrubescer",
    "desenrubescerás": "desenrubescer",
    "desenrubescerão": "desenrubescer",
    "desenrubesceríamos": "desenrubescer",
    "desenrubesceríeis": "desenrubescer",
    "desenrubesces": "desenrubescer",
    "desenrubescesse": "desenrubescer",
    "desenrubescessem": "desenrubescer",
    "desenrubescesses": "desenrubescer",
    "desenrubesceste": "desenrubescer",
    "desenrubescestes": "desenrubescer",
    "desenrubesceu": "desenrubescer",
    "desenrubesci": "desenrubescer",
    "desenrubescia": "desenrubescer",
    "desenrubesciam": "desenrubescer",
    "desenrubescias": "desenrubescer",
    "desenrubescida": "desenrubescido",
    "desenrubescidas": "desenrubescido",
    "desenrubescido": "desenrubescer",
    "desenrubescidos": "desenrubescido",
    "desenrubescêramo": "desenrubescer",
    "desenrubescêramos": "desenrubescer",
    "desenrubescêreis": "desenrubescer",
    "desenrubescêsseis": "desenrubescer",
    "desenrubescêssemos": "desenrubescer",
    "desenrubescíamo": "desenrubescer",
    "desenrubescíamos": "desenrubescer",
    "desenrubescíeis": "desenrubescer",
    "desenrubesça": "desenrubescer",
    "desenrubesçais": "desenrubescer",
    "desenrubesçam": "desenrubescer",
    "desenrubesçamo": "desenrubescer",
    "desenrubesçamos": "desenrubescer",
    "desenrubesças": "desenrubescer",
    "desenrubesço": "desenrubescer",
    "desenruga": "desenrugar",
    "desenrugada": "desenrugar",
    "desenrugadas": "desenrugar",
    "desenrugado": "desenrugar",
    "desenrugados": "desenrugar",
    "desenrugai": "desenrugar",
    "desenrugais": "desenrugar",
    "desenrugam": "desenrugar",
    "desenrugamo": "desenrugar",
    "desenrugamos": "desenrugar",
    "desenrugando": "desenrugar",
    "desenrugara": "desenrugar",
    "desenrugaram": "desenrugar",
    "desenrugaras": "desenrugar",
    "desenrugarde": "desenrugar",
    "desenrugardes": "desenrugar",
    "desenrugare": "desenrugar",
    "desenrugarei": "desenrugar",
    "desenrugareis": "desenrugar",
    "desenrugarem": "desenrugar",
    "desenrugaremos": "desenrugar",
    "desenrugares": "desenrugar",
    "desenrugaria": "desenrugar",
    "desenrugariam": "desenrugar",
    "desenrugarias": "desenrugar",
    "desenrugarmo": "desenrugar",
    "desenrugarmos": "desenrugar",
    "desenrugará": "desenrugar",
    "desenrugarás": "desenrugar",
    "desenrugarão": "desenrugar",
    "desenrugaríamos": "desenrugar",
    "desenrugaríeis": "desenrugar",
    "desenrugas": "desenrugar",
    "desenrugasse": "desenrugar",
    "desenrugassem": "desenrugar",
    "desenrugasses": "desenrugar",
    "desenrugaste": "desenrugar",
    "desenrugastes": "desenrugar",
    "desenrugava": "desenrugar",
    "desenrugavam": "desenrugar",
    "desenrugavas": "desenrugar",
    "desenrugo": "desenrugar",
    "desenrugou": "desenrugar",
    "desenrugue": "desenrugar",
    "desenruguei": "desenrugar",
    "desenrugueis": "desenrugar",
    "desenruguem": "desenrugar",
    "desenruguemo": "desenrugar",
    "desenruguemos": "desenrugar",
    "desenrugues": "desenrugar",
    "desenrugá": "desenrugar",
    "desenrugámo": "desenrugar",
    "desenrugámos": "desenrugar",
    "desenrugáramo": "desenrugar",
    "desenrugáramos": "desenrugar",
    "desenrugárei": "desenrugar",
    "desenrugáreis": "desenrugar",
    "desenrugásseis": "desenrugar",
    "desenrugássemos": "desenrugar",
    "desenrugávamo": "desenrugar",
    "desenrugávamos": "desenrugar",
    "desenrugávei": "desenrugar",
    "desenrugáveis": "desenrugar",
    "desensaboa": "desensaboar",
    "desensaboada": "desensaboar",
    "desensaboadas": "desensaboar",
    "desensaboado": "desensaboar",
    "desensaboados": "desensaboar",
    "desensaboai": "desensaboar",
    "desensaboais": "desensaboar",
    "desensaboam": "desensaboar",
    "desensaboamo": "desensaboar",
    "desensaboamos": "desensaboar",
    "desensaboando": "desensaboar",
    "desensaboara": "desensaboar",
    "desensaboaram": "desensaboar",
    "desensaboaras": "desensaboar",
    "desensaboarde": "desensaboar",
    "desensaboardes": "desensaboar",
    "desensaboare": "desensaboar",
    "desensaboarei": "desensaboar",
    "desensaboareis": "desensaboar",
    "desensaboarem": "desensaboar",
    "desensaboaremos": "desensaboar",
    "desensaboares": "desensaboar",
    "desensaboaria": "desensaboar",
    "desensaboariam": "desensaboar",
    "desensaboarias": "desensaboar",
    "desensaboarmo": "desensaboar",
    "desensaboarmos": "desensaboar",
    "desensaboará": "desensaboar",
    "desensaboarás": "desensaboar",
    "desensaboarão": "desensaboar",
    "desensaboaríamos": "desensaboar",
    "desensaboaríeis": "desensaboar",
    "desensaboas": "desensaboar",
    "desensaboasse": "desensaboar",
    "desensaboassem": "desensaboar",
    "desensaboasses": "desensaboar",
    "desensaboaste": "desensaboar",
    "desensaboastes": "desensaboar",
    "desensaboava": "desensaboar",
    "desensaboavam": "desensaboar",
    "desensaboavas": "desensaboar",
    "desensaboe": "desensaboar",
    "desensaboei": "desensaboar",
    "desensaboeis": "desensaboar",
    "desensaboem": "desensaboar",
    "desensaboemo": "desensaboar",
    "desensaboemos": "desensaboar",
    "desensaboes": "desensaboar",
    "desensaboo": "desensaboar",
    "desensaboou": "desensaboar",
    "desensaboá": "desensaboar",
    "desensaboámo": "desensaboar",
    "desensaboámos": "desensaboar",
    "desensaboáramo": "desensaboar",
    "desensaboáramos": "desensaboar",
    "desensaboárei": "desensaboar",
    "desensaboáreis": "desensaboar",
    "desensaboásseis": "desensaboar",
    "desensaboássemos": "desensaboar",
    "desensaboávamo": "desensaboar",
    "desensaboávamos": "desensaboar",
    "desensaboávei": "desensaboar",
    "desensaboáveis": "desensaboar",
    "desensaburra": "desensaburrar",
    "desensaburrada": "desensaburrar",
    "desensaburradas": "desensaburrar",
    "desensaburrado": "desensaburrar",
    "desensaburrados": "desensaburrar",
    "desensaburrai": "desensaburrar",
    "desensaburrais": "desensaburrar",
    "desensaburram": "desensaburrar",
    "desensaburramo": "desensaburrar",
    "desensaburramos": "desensaburrar",
    "desensaburrando": "desensaburrar",
    "desensaburrara": "desensaburrar",
    "desensaburraram": "desensaburrar",
    "desensaburraras": "desensaburrar",
    "desensaburrarde": "desensaburrar",
    "desensaburrardes": "desensaburrar",
    "desensaburrare": "desensaburrar",
    "desensaburrarei": "desensaburrar",
    "desensaburrareis": "desensaburrar",
    "desensaburrarem": "desensaburrar",
    "desensaburraremos": "desensaburrar",
    "desensaburrares": "desensaburrar",
    "desensaburraria": "desensaburrar",
    "desensaburrariam": "desensaburrar",
    "desensaburrarias": "desensaburrar",
    "desensaburrarmo": "desensaburrar",
    "desensaburrarmos": "desensaburrar",
    "desensaburrará": "desensaburrar",
    "desensaburrarás": "desensaburrar",
    "desensaburrarão": "desensaburrar",
    "desensaburraríamos": "desensaburrar",
    "desensaburraríeis": "desensaburrar",
    "desensaburras": "desensaburrar",
    "desensaburrasse": "desensaburrar",
    "desensaburrassem": "desensaburrar",
    "desensaburrasses": "desensaburrar",
    "desensaburraste": "desensaburrar",
    "desensaburrastes": "desensaburrar",
    "desensaburrava": "desensaburrar",
    "desensaburravam": "desensaburrar",
    "desensaburravas": "desensaburrar",
    "desensaburre": "desensaburrar",
    "desensaburrei": "desensaburrar",
    "desensaburreis": "desensaburrar",
    "desensaburrem": "desensaburrar",
    "desensaburremo": "desensaburrar",
    "desensaburremos": "desensaburrar",
    "desensaburres": "desensaburrar",
    "desensaburro": "desensaburrar",
    "desensaburrou": "desensaburrar",
    "desensaburrá": "desensaburrar",
    "desensaburrámo": "desensaburrar",
    "desensaburrámos": "desensaburrar",
    "desensaburráramo": "desensaburrar",
    "desensaburráramos": "desensaburrar",
    "desensaburrárei": "desensaburrar",
    "desensaburráreis": "desensaburrar",
    "desensaburrásseis": "desensaburrar",
    "desensaburrássemos": "desensaburrar",
    "desensaburrávamo": "desensaburrar",
    "desensaburrávamos": "desensaburrar",
    "desensaburrávei": "desensaburrar",
    "desensaburráveis": "desensaburrar",
    "desensaca": "desensacar",
    "desensacada": "desensacar",
    "desensacadas": "desensacar",
    "desensacado": "desensacar",
    "desensacados": "desensacar",
    "desensacai": "desensacar",
    "desensacais": "desensacar",
    "desensacam": "desensacar",
    "desensacamo": "desensacar",
    "desensacamos": "desensacar",
    "desensacando": "desensacar",
    "desensacara": "desensacar",
    "desensacaram": "desensacar",
    "desensacaras": "desensacar",
    "desensacarde": "desensacar",
    "desensacardes": "desensacar",
    "desensacare": "desensacar",
    "desensacarei": "desensacar",
    "desensacareis": "desensacar",
    "desensacarem": "desensacar",
    "desensacaremos": "desensacar",
    "desensacares": "desensacar",
    "desensacaria": "desensacar",
    "desensacariam": "desensacar",
    "desensacarias": "desensacar",
    "desensacarmo": "desensacar",
    "desensacarmos": "desensacar",
    "desensacará": "desensacar",
    "desensacarás": "desensacar",
    "desensacarão": "desensacar",
    "desensacaríamos": "desensacar",
    "desensacaríeis": "desensacar",
    "desensacas": "desensacar",
    "desensacasse": "desensacar",
    "desensacassem": "desensacar",
    "desensacasses": "desensacar",
    "desensacaste": "desensacar",
    "desensacastes": "desensacar",
    "desensacava": "desensacar",
    "desensacavam": "desensacar",
    "desensacavas": "desensacar",
    "desensaco": "desensacar",
    "desensacou": "desensacar",
    "desensacá": "desensacar",
    "desensacámo": "desensacar",
    "desensacámos": "desensacar",
    "desensacáramo": "desensacar",
    "desensacáramos": "desensacar",
    "desensacárei": "desensacar",
    "desensacáreis": "desensacar",
    "desensacásseis": "desensacar",
    "desensacássemos": "desensacar",
    "desensacávamo": "desensacar",
    "desensacávamos": "desensacar",
    "desensacávei": "desensacar",
    "desensacáveis": "desensacar",
    "desensandece": "desensandecer",
    "desensandecei": "desensandecer",
    "desensandeceis": "desensandecer",
    "desensandecem": "desensandecer",
    "desensandecemo": "desensandecer",
    "desensandecemos": "desensandecer",
    "desensandecendo": "desensandecer",
    "desensandecera": "desensandecer",
    "desensandeceram": "desensandecer",
    "desensandeceras": "desensandecer",
    "desensandecerdes": "desensandecer",
    "desensandecerei": "desensandecer",
    "desensandecereis": "desensandecer",
    "desensandecerem": "desensandecer",
    "desensandeceremos": "desensandecer",
    "desensandeceres": "desensandecer",
    "desensandeceria": "desensandecer",
    "desensandeceriam": "desensandecer",
    "desensandecerias": "desensandecer",
    "desensandecermo": "desensandecer",
    "desensandecermos": "desensandecer",
    "desensandecerá": "desensandecer",
    "desensandecerás": "desensandecer",
    "desensandecerão": "desensandecer",
    "desensandeceríamos": "desensandecer",
    "desensandeceríeis": "desensandecer",
    "desensandeces": "desensandecer",
    "desensandecesse": "desensandecer",
    "desensandecessem": "desensandecer",
    "desensandecesses": "desensandecer",
    "desensandeceste": "desensandecer",
    "desensandecestes": "desensandecer",
    "desensandeceu": "desensandecer",
    "desensandeci": "desensandecer",
    "desensandecia": "desensandecer",
    "desensandeciam": "desensandecer",
    "desensandecias": "desensandecer",
    "desensandecida": "desensandecido",
    "desensandecidas": "desensandecido",
    "desensandecido": "desensandecer",
    "desensandecidos": "desensandecido",
    "desensandecêramo": "desensandecer",
    "desensandecêramos": "desensandecer",
    "desensandecêreis": "desensandecer",
    "desensandecêsseis": "desensandecer",
    "desensandecêssemos": "desensandecer",
    "desensandecíamo": "desensandecer",
    "desensandecíamos": "desensandecer",
    "desensandecíeis": "desensandecer",
    "desensandeça": "desensandecer",
    "desensandeçais": "desensandecer",
    "desensandeçam": "desensandecer",
    "desensandeçamo": "desensandecer",
    "desensandeçamos": "desensandecer",
    "desensandeças": "desensandecer",
    "desensandeço": "desensandecer",
    "desensanguenta": "desensanguentar",
    "desensanguentada": "desensanguentar",
    "desensanguentadas": "desensanguentar",
    "desensanguentado": "desensanguentar",
    "desensanguentados": "desensanguentar",
    "desensanguentai": "desensanguentar",
    "desensanguentais": "desensanguentar",
    "desensanguentam": "desensanguentar",
    "desensanguentamo": "desensanguentar",
    "desensanguentamos": "desensanguentar",
    "desensanguentando": "desensanguentar",
    "desensanguentara": "desensanguentar",
    "desensanguentaram": "desensanguentar",
    "desensanguentaras": "desensanguentar",
    "desensanguentardes": "desensanguentar",
    "desensanguentarei": "desensanguentar",
    "desensanguentareis": "desensanguentar",
    "desensanguentarem": "desensanguentar",
    "desensanguentaremos": "desensanguentar",
    "desensanguentares": "desensanguentar",
    "desensanguentaria": "desensanguentar",
    "desensanguentariam": "desensanguentar",
    "desensanguentarias": "desensanguentar",
    "desensanguentarmo": "desensanguentar",
    "desensanguentarmos": "desensanguentar",
    "desensanguentará": "desensanguentar",
    "desensanguentarás": "desensanguentar",
    "desensanguentarão": "desensanguentar",
    "desensanguentaríamos": "desensanguentar",
    "desensanguentaríeis": "desensanguentar",
    "desensanguentas": "desensanguentar",
    "desensanguentasse": "desensanguentar",
    "desensanguentassem": "desensanguentar",
    "desensanguentasses": "desensanguentar",
    "desensanguentaste": "desensanguentar",
    "desensanguentastes": "desensanguentar",
    "desensanguentava": "desensanguentar",
    "desensanguentavam": "desensanguentar",
    "desensanguentavas": "desensanguentar",
    "desensanguente": "desensanguentar",
    "desensanguentei": "desensanguentar",
    "desensanguenteis": "desensanguentar",
    "desensanguentem": "desensanguentar",
    "desensanguentemo": "desensanguentar",
    "desensanguentemos": "desensanguentar",
    "desensanguentes": "desensanguentar",
    "desensanguento": "desensanguentar",
    "desensanguentou": "desensanguentar",
    "desensanguentámo": "desensanguentar",
    "desensanguentámos": "desensanguentar",
    "desensanguentáramo": "desensanguentar",
    "desensanguentáramos": "desensanguentar",
    "desensanguentáreis": "desensanguentar",
    "desensanguentásseis": "desensanguentar",
    "desensanguentássemos": "desensanguentar",
    "desensanguentávamo": "desensanguentar",
    "desensanguentávamos": "desensanguentar",
    "desensanguentáveis": "desensanguentar",
    "desensaque": "desensacar",
    "desensaquei": "desensacar",
    "desensaqueis": "desensacar",
    "desensaquem": "desensacar",
    "desensaquemo": "desensacar",
    "desensaquemos": "desensacar",
    "desensaques": "desensacar",
    "desensarilha": "desensarilhar",
    "desensarilhada": "desensarilhar",
    "desensarilhadas": "desensarilhar",
    "desensarilhado": "desensarilhar",
    "desensarilhados": "desensarilhar",
    "desensarilhai": "desensarilhar",
    "desensarilhais": "desensarilhar",
    "desensarilham": "desensarilhar",
    "desensarilhamo": "desensarilhar",
    "desensarilhamos": "desensarilhar",
    "desensarilhando": "desensarilhar",
    "desensarilhara": "desensarilhar",
    "desensarilharam": "desensarilhar",
    "desensarilharas": "desensarilhar",
    "desensarilharde": "desensarilhar",
    "desensarilhardes": "desensarilhar",
    "desensarilhare": "desensarilhar",
    "desensarilharei": "desensarilhar",
    "desensarilhareis": "desensarilhar",
    "desensarilharem": "desensarilhar",
    "desensarilharemos": "desensarilhar",
    "desensarilhares": "desensarilhar",
    "desensarilharia": "desensarilhar",
    "desensarilhariam": "desensarilhar",
    "desensarilharias": "desensarilhar",
    "desensarilharmo": "desensarilhar",
    "desensarilharmos": "desensarilhar",
    "desensarilhará": "desensarilhar",
    "desensarilharás": "desensarilhar",
    "desensarilharão": "desensarilhar",
    "desensarilharíamos": "desensarilhar",
    "desensarilharíeis": "desensarilhar",
    "desensarilhas": "desensarilhar",
    "desensarilhasse": "desensarilhar",
    "desensarilhassem": "desensarilhar",
    "desensarilhasses": "desensarilhar",
    "desensarilhaste": "desensarilhar",
    "desensarilhastes": "desensarilhar",
    "desensarilhava": "desensarilhar",
    "desensarilhavam": "desensarilhar",
    "desensarilhavas": "desensarilhar",
    "desensarilhe": "desensarilhar",
    "desensarilhei": "desensarilhar",
    "desensarilheis": "desensarilhar",
    "desensarilhem": "desensarilhar",
    "desensarilhemo": "desensarilhar",
    "desensarilhemos": "desensarilhar",
    "desensarilhes": "desensarilhar",
    "desensarilho": "desensarilhar",
    "desensarilhou": "desensarilhar",
    "desensarilhá": "desensarilhar",
    "desensarilhámo": "desensarilhar",
    "desensarilhámos": "desensarilhar",
    "desensarilháramo": "desensarilhar",
    "desensarilháramos": "desensarilhar",
    "desensarilhárei": "desensarilhar",
    "desensarilháreis": "desensarilhar",
    "desensarilhásseis": "desensarilhar",
    "desensarilhássemos": "desensarilhar",
    "desensarilhávamo": "desensarilhar",
    "desensarilhávamos": "desensarilhar",
    "desensarilhávei": "desensarilhar",
    "desensarilháveis": "desensarilhar",
    "desenseba": "desensebar",
    "desensebada": "desensebar",
    "desensebadas": "desensebar",
    "desensebado": "desensebar",
    "desensebados": "desensebar",
    "desensebai": "desensebar",
    "desensebais": "desensebar",
    "desensebam": "desensebar",
    "desensebamo": "desensebar",
    "desensebamos": "desensebar",
    "desensebando": "desensebar",
    "desensebara": "desensebar",
    "desensebaram": "desensebar",
    "desensebaras": "desensebar",
    "desensebarde": "desensebar",
    "desensebardes": "desensebar",
    "desensebare": "desensebar",
    "desensebarei": "desensebar",
    "desensebareis": "desensebar",
    "desensebarem": "desensebar",
    "desensebaremos": "desensebar",
    "desensebares": "desensebar",
    "desensebaria": "desensebar",
    "desensebariam": "desensebar",
    "desensebarias": "desensebar",
    "desensebarmo": "desensebar",
    "desensebarmos": "desensebar",
    "desensebará": "desensebar",
    "desensebarás": "desensebar",
    "desensebarão": "desensebar",
    "desensebaríamos": "desensebar",
    "desensebaríeis": "desensebar",
    "desensebas": "desensebar",
    "desensebasse": "desensebar",
    "desensebassem": "desensebar",
    "desensebasses": "desensebar",
    "desensebaste": "desensebar",
    "desensebastes": "desensebar",
    "desensebava": "desensebar",
    "desensebavam": "desensebar",
    "desensebavas": "desensebar",
    "desensebe": "desensebar",
    "desensebei": "desensebar",
    "desensebeis": "desensebar",
    "desensebem": "desensebar",
    "desensebemo": "desensebar",
    "desensebemos": "desensebar",
    "desensebes": "desensebar",
    "desensebo": "desensebar",
    "desensebou": "desensebar",
    "desensebá": "desensebar",
    "desensebámo": "desensebar",
    "desensebámos": "desensebar",
    "desensebáramo": "desensebar",
    "desensebáramos": "desensebar",
    "desensebárei": "desensebar",
    "desensebáreis": "desensebar",
    "desensebásseis": "desensebar",
    "desensebássemos": "desensebar",
    "desensebávamo": "desensebar",
    "desensebávamos": "desensebar",
    "desensebávei": "desensebar",
    "desensebáveis": "desensebar",
    "desensina": "desensinar",
    "desensinada": "desensinar",
    "desensinadas": "desensinar",
    "desensinado": "desensinar",
    "desensinadora": "desensinador",
    "desensinadoras": "desensinador",
    "desensinadores": "desensinador",
    "desensinados": "desensinar",
    "desensinai": "desensinar",
    "desensinais": "desensinar",
    "desensinam": "desensinar",
    "desensinamo": "desensinar",
    "desensinamos": "desensinar",
    "desensinando": "desensinar",
    "desensinara": "desensinar",
    "desensinaram": "desensinar",
    "desensinaras": "desensinar",
    "desensinarde": "desensinar",
    "desensinardes": "desensinar",
    "desensinare": "desensinar",
    "desensinarei": "desensinar",
    "desensinareis": "desensinar",
    "desensinarem": "desensinar",
    "desensinaremos": "desensinar",
    "desensinares": "desensinar",
    "desensinaria": "desensinar",
    "desensinariam": "desensinar",
    "desensinarias": "desensinar",
    "desensinarmo": "desensinar",
    "desensinarmos": "desensinar",
    "desensinará": "desensinar",
    "desensinarás": "desensinar",
    "desensinarão": "desensinar",
    "desensinaríamos": "desensinar",
    "desensinaríeis": "desensinar",
    "desensinas": "desensinar",
    "desensinasse": "desensinar",
    "desensinassem": "desensinar",
    "desensinasses": "desensinar",
    "desensinaste": "desensinar",
    "desensinastes": "desensinar",
    "desensinava": "desensinar",
    "desensinavam": "desensinar",
    "desensinavas": "desensinar",
    "desensine": "desensinar",
    "desensinei": "desensinar",
    "desensineis": "desensinar",
    "desensinem": "desensinar",
    "desensinemo": "desensinar",
    "desensinemos": "desensinar",
    "desensines": "desensinar",
    "desensino": "desensinar",
    "desensinos": "desensino",
    "desensinou": "desensinar",
    "desensiná": "desensinar",
    "desensinámo": "desensinar",
    "desensinámos": "desensinar",
    "desensináramo": "desensinar",
    "desensináramos": "desensinar",
    "desensinárei": "desensinar",
    "desensináreis": "desensinar",
    "desensinásseis": "desensinar",
    "desensinássemos": "desensinar",
    "desensinávamo": "desensinar",
    "desensinávamos": "desensinar",
    "desensinávei": "desensinar",
    "desensináveis": "desensinar",
    "desensoberbece": "desensoberbecer",
    "desensoberbecei": "desensoberbecer",
    "desensoberbeceis": "desensoberbecer",
    "desensoberbecem": "desensoberbecer",
    "desensoberbecemo": "desensoberbecer",
    "desensoberbecemos": "desensoberbecer",
    "desensoberbecendo": "desensoberbecer",
    "desensoberbecera": "desensoberbecer",
    "desensoberbeceram": "desensoberbecer",
    "desensoberbeceras": "desensoberbecer",
    "desensoberbecerde": "desensoberbecer",
    "desensoberbecerdes": "desensoberbecer",
    "desensoberbecere": "desensoberbecer",
    "desensoberbecerei": "desensoberbecer",
    "desensoberbecereis": "desensoberbecer",
    "desensoberbecerem": "desensoberbecer",
    "desensoberbeceremos": "desensoberbecer",
    "desensoberbeceres": "desensoberbecer",
    "desensoberbeceria": "desensoberbecer",
    "desensoberbeceriam": "desensoberbecer",
    "desensoberbecerias": "desensoberbecer",
    "desensoberbecermo": "desensoberbecer",
    "desensoberbecermos": "desensoberbecer",
    "desensoberbecerá": "desensoberbecer",
    "desensoberbecerás": "desensoberbecer",
    "desensoberbecerão": "desensoberbecer",
    "desensoberbeceríamos": "desensoberbecer",
    "desensoberbeceríeis": "desensoberbecer",
    "desensoberbeces": "desensoberbecer",
    "desensoberbecesse": "desensoberbecer",
    "desensoberbecessem": "desensoberbecer",
    "desensoberbecesses": "desensoberbecer",
    "desensoberbeceste": "desensoberbecer",
    "desensoberbecestes": "desensoberbecer",
    "desensoberbeceu": "desensoberbecer",
    "desensoberbeci": "desensoberbecer",
    "desensoberbecia": "desensoberbecer",
    "desensoberbeciam": "desensoberbecer",
    "desensoberbecias": "desensoberbecer",
    "desensoberbecida": "desensoberbecido",
    "desensoberbecidas": "desensoberbecido",
    "desensoberbecido": "desensoberbecer",
    "desensoberbecidos": "desensoberbecido",
    "desensoberbecê": "desensoberbecer",
    "desensoberbecêramo": "desensoberbecer",
    "desensoberbecêramos": "desensoberbecer",
    "desensoberbecêrei": "desensoberbecer",
    "desensoberbecêreis": "desensoberbecer",
    "desensoberbecêsseis": "desensoberbecer",
    "desensoberbecêssemos": "desensoberbecer",
    "desensoberbecíamo": "desensoberbecer",
    "desensoberbecíamos": "desensoberbecer",
    "desensoberbecíei": "desensoberbecer",
    "desensoberbecíeis": "desensoberbecer",
    "desensoberbeça": "desensoberbecer",
    "desensoberbeçais": "desensoberbecer",
    "desensoberbeçam": "desensoberbecer",
    "desensoberbeçamo": "desensoberbecer",
    "desensoberbeçamos": "desensoberbecer",
    "desensoberbeças": "desensoberbecer",
    "desensoberbeço": "desensoberbecer",
    "desensombra": "desensombrar",
    "desensombrada": "desensombrar",
    "desensombradas": "desensombrar",
    "desensombrado": "desensombrar",
    "desensombrados": "desensombrar",
    "desensombrai": "desensombrar",
    "desensombrais": "desensombrar",
    "desensombram": "desensombrar",
    "desensombramo": "desensombrar",
    "desensombramos": "desensombrar",
    "desensombrando": "desensombrar",
    "desensombrara": "desensombrar",
    "desensombraram": "desensombrar",
    "desensombraras": "desensombrar",
    "desensombrarde": "desensombrar",
    "desensombrardes": "desensombrar",
    "desensombrare": "desensombrar",
    "desensombrarei": "desensombrar",
    "desensombrareis": "desensombrar",
    "desensombrarem": "desensombrar",
    "desensombraremos": "desensombrar",
    "desensombrares": "desensombrar",
    "desensombraria": "desensombrar",
    "desensombrariam": "desensombrar",
    "desensombrarias": "desensombrar",
    "desensombrarmo": "desensombrar",
    "desensombrarmos": "desensombrar",
    "desensombrará": "desensombrar",
    "desensombrarás": "desensombrar",
    "desensombrarão": "desensombrar",
    "desensombraríamos": "desensombrar",
    "desensombraríeis": "desensombrar",
    "desensombras": "desensombrar",
    "desensombrasse": "desensombrar",
    "desensombrassem": "desensombrar",
    "desensombrasses": "desensombrar",
    "desensombraste": "desensombrar",
    "desensombrastes": "desensombrar",
    "desensombrava": "desensombrar",
    "desensombravam": "desensombrar",
    "desensombravas": "desensombrar",
    "desensombre": "desensombrar",
    "desensombrei": "desensombrar",
    "desensombreis": "desensombrar",
    "desensombrem": "desensombrar",
    "desensombremo": "desensombrar",
    "desensombremos": "desensombrar",
    "desensombres": "desensombrar",
    "desensombro": "desensombrar",
    "desensombrou": "desensombrar",
    "desensombrá": "desensombrar",
    "desensombrámo": "desensombrar",
    "desensombrámos": "desensombrar",
    "desensombráramo": "desensombrar",
    "desensombráramos": "desensombrar",
    "desensombrárei": "desensombrar",
    "desensombráreis": "desensombrar",
    "desensombrásseis": "desensombrar",
    "desensombrássemos": "desensombrar",
    "desensombrávamo": "desensombrar",
    "desensombrávamos": "desensombrar",
    "desensombrávei": "desensombrar",
    "desensombráveis": "desensombrar",
    "desensopa": "desensopar",
    "desensopada": "desensopar",
    "desensopadas": "desensopar",
    "desensopado": "desensopar",
    "desensopados": "desensopar",
    "desensopai": "desensopar",
    "desensopais": "desensopar",
    "desensopam": "desensopar",
    "desensopamo": "desensopar",
    "desensopamos": "desensopar",
    "desensopando": "desensopar",
    "desensopara": "desensopar",
    "desensoparam": "desensopar",
    "desensoparas": "desensopar",
    "desensoparde": "desensopar",
    "desensopardes": "desensopar",
    "desensopare": "desensopar",
    "desensoparei": "desensopar",
    "desensopareis": "desensopar",
    "desensoparem": "desensopar",
    "desensoparemos": "desensopar",
    "desensopares": "desensopar",
    "desensoparia": "desensopar",
    "desensopariam": "desensopar",
    "desensoparias": "desensopar",
    "desensoparmo": "desensopar",
    "desensoparmos": "desensopar",
    "desensopará": "desensopar",
    "desensoparás": "desensopar",
    "desensoparão": "desensopar",
    "desensoparíamos": "desensopar",
    "desensoparíeis": "desensopar",
    "desensopas": "desensopar",
    "desensopasse": "desensopar",
    "desensopassem": "desensopar",
    "desensopasses": "desensopar",
    "desensopaste": "desensopar",
    "desensopastes": "desensopar",
    "desensopava": "desensopar",
    "desensopavam": "desensopar",
    "desensopavas": "desensopar",
    "desensope": "desensopar",
    "desensopei": "desensopar",
    "desensopeis": "desensopar",
    "desensopem": "desensopar",
    "desensopemo": "desensopar",
    "desensopemos": "desensopar",
    "desensopes": "desensopar",
    "desensopo": "desensopar",
    "desensopou": "desensopar",
    "desensopá": "desensopar",
    "desensopámo": "desensopar",
    "desensopámos": "desensopar",
    "desensopáramo": "desensopar",
    "desensopáramos": "desensopar",
    "desensopárei": "desensopar",
    "desensopáreis": "desensopar",
    "desensopásseis": "desensopar",
    "desensopássemos": "desensopar",
    "desensopávamo": "desensopar",
    "desensopávamos": "desensopar",
    "desensopávei": "desensopar",
    "desensopáveis": "desensopar",
    "desensurdece": "desensurdecer",
    "desensurdecei": "desensurdecer",
    "desensurdeceis": "desensurdecer",
    "desensurdecem": "desensurdecer",
    "desensurdecemo": "desensurdecer",
    "desensurdecemos": "desensurdecer",
    "desensurdecendo": "desensurdecer",
    "desensurdecera": "desensurdecer",
    "desensurdeceram": "desensurdecer",
    "desensurdeceras": "desensurdecer",
    "desensurdecerdes": "desensurdecer",
    "desensurdecerei": "desensurdecer",
    "desensurdecereis": "desensurdecer",
    "desensurdecerem": "desensurdecer",
    "desensurdeceremos": "desensurdecer",
    "desensurdeceres": "desensurdecer",
    "desensurdeceria": "desensurdecer",
    "desensurdeceriam": "desensurdecer",
    "desensurdecerias": "desensurdecer",
    "desensurdecermo": "desensurdecer",
    "desensurdecermos": "desensurdecer",
    "desensurdecerá": "desensurdecer",
    "desensurdecerás": "desensurdecer",
    "desensurdecerão": "desensurdecer",
    "desensurdeceríamos": "desensurdecer",
    "desensurdeceríeis": "desensurdecer",
    "desensurdeces": "desensurdecer",
    "desensurdecesse": "desensurdecer",
    "desensurdecessem": "desensurdecer",
    "desensurdecesses": "desensurdecer",
    "desensurdeceste": "desensurdecer",
    "desensurdecestes": "desensurdecer",
    "desensurdeceu": "desensurdecer",
    "desensurdeci": "desensurdecer",
    "desensurdecia": "desensurdecer",
    "desensurdeciam": "desensurdecer",
    "desensurdecias": "desensurdecer",
    "desensurdecida": "desensurdecido",
    "desensurdecidas": "desensurdecido",
    "desensurdecido": "desensurdecer",
    "desensurdecidos": "desensurdecido",
    "desensurdecêramo": "desensurdecer",
    "desensurdecêramos": "desensurdecer",
    "desensurdecêreis": "desensurdecer",
    "desensurdecêsseis": "desensurdecer",
    "desensurdecêssemos": "desensurdecer",
    "desensurdecíamo": "desensurdecer",
    "desensurdecíamos": "desensurdecer",
    "desensurdecíeis": "desensurdecer",
    "desensurdeça": "desensurdecer",
    "desensurdeçais": "desensurdecer",
    "desensurdeçam": "desensurdecer",
    "desensurdeçamo": "desensurdecer",
    "desensurdeçamos": "desensurdecer",
    "desensurdeças": "desensurdecer",
    "desensurdeço": "desensurdecer",
    "desensurra": "desensurrar",
    "desensurrada": "desensurrar",
    "desensurradas": "desensurrar",
    "desensurrado": "desensurrar",
    "desensurrados": "desensurrar",
    "desensurrai": "desensurrar",
    "desensurrais": "desensurrar",
    "desensurram": "desensurrar",
    "desensurramo": "desensurrar",
    "desensurramos": "desensurrar",
    "desensurrando": "desensurrar",
    "desensurrara": "desensurrar",
    "desensurraram": "desensurrar",
    "desensurraras": "desensurrar",
    "desensurrarde": "desensurrar",
    "desensurrardes": "desensurrar",
    "desensurrare": "desensurrar",
    "desensurrarei": "desensurrar",
    "desensurrareis": "desensurrar",
    "desensurrarem": "desensurrar",
    "desensurraremos": "desensurrar",
    "desensurrares": "desensurrar",
    "desensurraria": "desensurrar",
    "desensurrariam": "desensurrar",
    "desensurrarias": "desensurrar",
    "desensurrarmo": "desensurrar",
    "desensurrarmos": "desensurrar",
    "desensurrará": "desensurrar",
    "desensurrarás": "desensurrar",
    "desensurrarão": "desensurrar",
    "desensurraríamos": "desensurrar",
    "desensurraríeis": "desensurrar",
    "desensurras": "desensurrar",
    "desensurrasse": "desensurrar",
    "desensurrassem": "desensurrar",
    "desensurrasses": "desensurrar",
    "desensurraste": "desensurrar",
    "desensurrastes": "desensurrar",
    "desensurrava": "desensurrar",
    "desensurravam": "desensurrar",
    "desensurravas": "desensurrar",
    "desensurre": "desensurrar",
    "desensurrei": "desensurrar",
    "desensurreis": "desensurrar",
    "desensurrem": "desensurrar",
    "desensurremo": "desensurrar",
    "desensurremos": "desensurrar",
    "desensurres": "desensurrar",
    "desensurro": "desensurrar",
    "desensurrou": "desensurrar",
    "desensurrá": "desensurrar",
    "desensurrámo": "desensurrar",
    "desensurrámos": "desensurrar",
    "desensurráramo": "desensurrar",
    "desensurráramos": "desensurrar",
    "desensurrárei": "desensurrar",
    "desensurráreis": "desensurrar",
    "desensurrásseis": "desensurrar",
    "desensurrássemos": "desensurrar",
    "desensurrávamo": "desensurrar",
    "desensurrávamos": "desensurrar",
    "desensurrávei": "desensurrar",
    "desensurráveis": "desensurrar",
    "desentabua": "desentabuar",
    "desentabuada": "desentabuar",
    "desentabuadas": "desentabuar",
    "desentabuado": "desentabuar",
    "desentabuados": "desentabuar",
    "desentabuai": "desentabuar",
    "desentabuais": "desentabuar",
    "desentabuam": "desentabuar",
    "desentabuamo": "desentabuar",
    "desentabuamos": "desentabuar",
    "desentabuando": "desentabuar",
    "desentabuara": "desentabuar",
    "desentabuaram": "desentabuar",
    "desentabuaras": "desentabuar",
    "desentabuarde": "desentabuar",
    "desentabuardes": "desentabuar",
    "desentabuare": "desentabuar",
    "desentabuarei": "desentabuar",
    "desentabuareis": "desentabuar",
    "desentabuarem": "desentabuar",
    "desentabuaremos": "desentabuar",
    "desentabuares": "desentabuar",
    "desentabuaria": "desentabuar",
    "desentabuariam": "desentabuar",
    "desentabuarias": "desentabuar",
    "desentabuarmo": "desentabuar",
    "desentabuarmos": "desentabuar",
    "desentabuará": "desentabuar",
    "desentabuarás": "desentabuar",
    "desentabuarão": "desentabuar",
    "desentabuaríamos": "desentabuar",
    "desentabuaríeis": "desentabuar",
    "desentabuas": "desentabuar",
    "desentabuasse": "desentabuar",
    "desentabuassem": "desentabuar",
    "desentabuasses": "desentabuar",
    "desentabuaste": "desentabuar",
    "desentabuastes": "desentabuar",
    "desentabuava": "desentabuar",
    "desentabuavam": "desentabuar",
    "desentabuavas": "desentabuar",
    "desentabue": "desentabuar",
    "desentabuei": "desentabuar",
    "desentabueis": "desentabuar",
    "desentabuem": "desentabuar",
    "desentabuemo": "desentabuar",
    "desentabuemos": "desentabuar",
    "desentabues": "desentabuar",
    "desentabula": "desentabular",
    "desentabulada": "desentabular",
    "desentabuladas": "desentabular",
    "desentabulado": "desentabular",
    "desentabulados": "desentabular",
    "desentabulai": "desentabular",
    "desentabulais": "desentabular",
    "desentabulam": "desentabular",
    "desentabulamo": "desentabular",
    "desentabulamos": "desentabular",
    "desentabulando": "desentabular",
    "desentabulara": "desentabular",
    "desentabularam": "desentabular",
    "desentabularas": "desentabular",
    "desentabularde": "desentabular",
    "desentabulardes": "desentabular",
    "desentabulare": "desentabular",
    "desentabularei": "desentabular",
    "desentabulareis": "desentabular",
    "desentabularem": "desentabular",
    "desentabularemos": "desentabular",
    "desentabulares": "desentabular",
    "desentabularia": "desentabular",
    "desentabulariam": "desentabular",
    "desentabularias": "desentabular",
    "desentabularmo": "desentabular",
    "desentabularmos": "desentabular",
    "desentabulará": "desentabular",
    "desentabularás": "desentabular",
    "desentabularão": "desentabular",
    "desentabularíamos": "desentabular",
    "desentabularíeis": "desentabular",
    "desentabulas": "desentabular",
    "desentabulasse": "desentabular",
    "desentabulassem": "desentabular",
    "desentabulasses": "desentabular",
    "desentabulaste": "desentabular",
    "desentabulastes": "desentabular",
    "desentabulava": "desentabular",
    "desentabulavam": "desentabular",
    "desentabulavas": "desentabular",
    "desentabule": "desentabular",
    "desentabulei": "desentabular",
    "desentabuleis": "desentabular",
    "desentabulem": "desentabular",
    "desentabulemo": "desentabular",
    "desentabulemos": "desentabular",
    "desentabules": "desentabular",
    "desentabulo": "desentabular",
    "desentabulou": "desentabular",
    "desentabulá": "desentabular",
    "desentabulámo": "desentabular",
    "desentabulámos": "desentabular",
    "desentabuláramo": "desentabular",
    "desentabuláramos": "desentabular",
    "desentabulárei": "desentabular",
    "desentabuláreis": "desentabular",
    "desentabulásseis": "desentabular",
    "desentabulássemos": "desentabular",
    "desentabulávamo": "desentabular",
    "desentabulávamos": "desentabular",
    "desentabulávei": "desentabular",
    "desentabuláveis": "desentabular",
    "desentabuo": "desentabuar",
    "desentabuou": "desentabuar",
    "desentabuá": "desentabuar",
    "desentabuámo": "desentabuar",
    "desentabuámos": "desentabuar",
    "desentabuáramo": "desentabuar",
    "desentabuáramos": "desentabuar",
    "desentabuárei": "desentabuar",
    "desentabuáreis": "desentabuar",
    "desentabuásseis": "desentabuar",
    "desentabuássemos": "desentabuar",
    "desentabuávamo": "desentabuar",
    "desentabuávamos": "desentabuar",
    "desentabuávei": "desentabuar",
    "desentabuáveis": "desentabuar",
    "desentaipa": "desentaipar",
    "desentaipada": "desentaipar",
    "desentaipadas": "desentaipar",
    "desentaipado": "desentaipar",
    "desentaipados": "desentaipar",
    "desentaipai": "desentaipar",
    "desentaipais": "desentaipar",
    "desentaipam": "desentaipar",
    "desentaipamo": "desentaipar",
    "desentaipamos": "desentaipar",
    "desentaipando": "desentaipar",
    "desentaipara": "desentaipar",
    "desentaiparam": "desentaipar",
    "desentaiparas": "desentaipar",
    "desentaiparde": "desentaipar",
    "desentaipardes": "desentaipar",
    "desentaipare": "desentaipar",
    "desentaiparei": "desentaipar",
    "desentaipareis": "desentaipar",
    "desentaiparem": "desentaipar",
    "desentaiparemos": "desentaipar",
    "desentaipares": "desentaipar",
    "desentaiparia": "desentaipar",
    "desentaipariam": "desentaipar",
    "desentaiparias": "desentaipar",
    "desentaiparmo": "desentaipar",
    "desentaiparmos": "desentaipar",
    "desentaipará": "desentaipar",
    "desentaiparás": "desentaipar",
    "desentaiparão": "desentaipar",
    "desentaiparíamos": "desentaipar",
    "desentaiparíeis": "desentaipar",
    "desentaipas": "desentaipar",
    "desentaipasse": "desentaipar",
    "desentaipassem": "desentaipar",
    "desentaipasses": "desentaipar",
    "desentaipaste": "desentaipar",
    "desentaipastes": "desentaipar",
    "desentaipava": "desentaipar",
    "desentaipavam": "desentaipar",
    "desentaipavas": "desentaipar",
    "desentaipe": "desentaipar",
    "desentaipei": "desentaipar",
    "desentaipeis": "desentaipar",
    "desentaipem": "desentaipar",
    "desentaipemo": "desentaipar",
    "desentaipemos": "desentaipar",
    "desentaipes": "desentaipar",
    "desentaipo": "desentaipar",
    "desentaipou": "desentaipar",
    "desentaipá": "desentaipar",
    "desentaipámo": "desentaipar",
    "desentaipámos": "desentaipar",
    "desentaipáramo": "desentaipar",
    "desentaipáramos": "desentaipar",
    "desentaipárei": "desentaipar",
    "desentaipáreis": "desentaipar",
    "desentaipásseis": "desentaipar",
    "desentaipássemos": "desentaipar",
    "desentaipávamo": "desentaipar",
    "desentaipávamos": "desentaipar",
    "desentaipávei": "desentaipar",
    "desentaipáveis": "desentaipar",
    "desentala": "desentalar",
    "desentalada": "desentalar",
    "desentaladas": "desentalar",
    "desentalado": "desentalar",
    "desentalados": "desentalar",
    "desentalai": "desentalar",
    "desentalais": "desentalar",
    "desentalam": "desentalar",
    "desentalamo": "desentalar",
    "desentalamos": "desentalar",
    "desentalando": "desentalar",
    "desentalara": "desentalar",
    "desentalaram": "desentalar",
    "desentalaras": "desentalar",
    "desentalarde": "desentalar",
    "desentalardes": "desentalar",
    "desentalare": "desentalar",
    "desentalarei": "desentalar",
    "desentalareis": "desentalar",
    "desentalarem": "desentalar",
    "desentalaremos": "desentalar",
    "desentalares": "desentalar",
    "desentalaria": "desentalar",
    "desentalariam": "desentalar",
    "desentalarias": "desentalar",
    "desentalarmo": "desentalar",
    "desentalarmos": "desentalar",
    "desentalará": "desentalar",
    "desentalarás": "desentalar",
    "desentalarão": "desentalar",
    "desentalaríamos": "desentalar",
    "desentalaríeis": "desentalar",
    "desentalas": "desentalar",
    "desentalasse": "desentalar",
    "desentalassem": "desentalar",
    "desentalasses": "desentalar",
    "desentalaste": "desentalar",
    "desentalastes": "desentalar",
    "desentalava": "desentalar",
    "desentalavam": "desentalar",
    "desentalavas": "desentalar",
    "desentale": "desentalar",
    "desentalei": "desentalar",
    "desentaleis": "desentalar",
    "desentalem": "desentalar",
    "desentalemo": "desentalar",
    "desentalemos": "desentalar",
    "desentales": "desentalar",
    "desentalisca": "desentaliscar",
    "desentaliscada": "desentaliscar",
    "desentaliscadas": "desentaliscar",
    "desentaliscado": "desentaliscar",
    "desentaliscados": "desentaliscar",
    "desentaliscai": "desentaliscar",
    "desentaliscais": "desentaliscar",
    "desentaliscam": "desentaliscar",
    "desentaliscamo": "desentaliscar",
    "desentaliscamos": "desentaliscar",
    "desentaliscando": "desentaliscar",
    "desentaliscara": "desentaliscar",
    "desentaliscaram": "desentaliscar",
    "desentaliscaras": "desentaliscar",
    "desentaliscarde": "desentaliscar",
    "desentaliscardes": "desentaliscar",
    "desentaliscare": "desentaliscar",
    "desentaliscarei": "desentaliscar",
    "desentaliscareis": "desentaliscar",
    "desentaliscarem": "desentaliscar",
    "desentaliscaremos": "desentaliscar",
    "desentaliscares": "desentaliscar",
    "desentaliscaria": "desentaliscar",
    "desentaliscariam": "desentaliscar",
    "desentaliscarias": "desentaliscar",
    "desentaliscarmo": "desentaliscar",
    "desentaliscarmos": "desentaliscar",
    "desentaliscará": "desentaliscar",
    "desentaliscarás": "desentaliscar",
    "desentaliscarão": "desentaliscar",
    "desentaliscaríamos": "desentaliscar",
    "desentaliscaríeis": "desentaliscar",
    "desentaliscas": "desentaliscar",
    "desentaliscasse": "desentaliscar",
    "desentaliscassem": "desentaliscar",
    "desentaliscasses": "desentaliscar",
    "desentaliscaste": "desentaliscar",
    "desentaliscastes": "desentaliscar",
    "desentaliscava": "desentaliscar",
    "desentaliscavam": "desentaliscar",
    "desentaliscavas": "desentaliscar",
    "desentalisco": "desentaliscar",
    "desentaliscou": "desentaliscar",
    "desentaliscá": "desentaliscar",
    "desentaliscámo": "desentaliscar",
    "desentaliscámos": "desentaliscar",
    "desentaliscáramo": "desentaliscar",
    "desentaliscáramos": "desentaliscar",
    "desentaliscárei": "desentaliscar",
    "desentaliscáreis": "desentaliscar",
    "desentaliscásseis": "desentaliscar",
    "desentaliscássemos": "desentaliscar",
    "desentaliscávamo": "desentaliscar",
    "desentaliscávamos": "desentaliscar",
    "desentaliscávei": "desentaliscar",
    "desentaliscáveis": "desentaliscar",
    "desentalisque": "desentaliscar",
    "desentalisquei": "desentaliscar",
    "desentalisqueis": "desentaliscar",
    "desentalisquem": "desentaliscar",
    "desentalisquemo": "desentaliscar",
    "desentalisquemos": "desentaliscar",
    "desentalisques": "desentaliscar",
    "desentalo": "desentalar",
    "desentalou": "desentalar",
    "desentalá": "desentalar",
    "desentalámo": "desentalar",
    "desentalámos": "desentalar",
    "desentaláramo": "desentalar",
    "desentaláramos": "desentalar",
    "desentalárei": "desentalar",
    "desentaláreis": "desentalar",
    "desentalásseis": "desentalar",
    "desentalássemos": "desentalar",
    "desentalávamo": "desentalar",
    "desentalávamos": "desentalar",
    "desentalávei": "desentalar",
    "desentaláveis": "desentalar",
    "desentaramela": "desentaramelar",
    "desentaramelada": "desentaramelar",
    "desentarameladas": "desentaramelar",
    "desentaramelado": "desentaramelar",
    "desentaramelados": "desentaramelar",
    "desentaramelai": "desentaramelar",
    "desentaramelais": "desentaramelar",
    "desentaramelam": "desentaramelar",
    "desentaramelamo": "desentaramelar",
    "desentaramelamos": "desentaramelar",
    "desentaramelando": "desentaramelar",
    "desentaramelara": "desentaramelar",
    "desentaramelaram": "desentaramelar",
    "desentaramelaras": "desentaramelar",
    "desentaramelarde": "desentaramelar",
    "desentaramelardes": "desentaramelar",
    "desentaramelare": "desentaramelar",
    "desentaramelarei": "desentaramelar",
    "desentaramelareis": "desentaramelar",
    "desentaramelarem": "desentaramelar",
    "desentaramelaremos": "desentaramelar",
    "desentaramelares": "desentaramelar",
    "desentaramelaria": "desentaramelar",
    "desentaramelariam": "desentaramelar",
    "desentaramelarias": "desentaramelar",
    "desentaramelarmo": "desentaramelar",
    "desentaramelarmos": "desentaramelar",
    "desentaramelará": "desentaramelar",
    "desentaramelarás": "desentaramelar",
    "desentaramelarão": "desentaramelar",
    "desentaramelaríamos": "desentaramelar",
    "desentaramelaríeis": "desentaramelar",
    "desentaramelas": "desentaramelar",
    "desentaramelasse": "desentaramelar",
    "desentaramelassem": "desentaramelar",
    "desentaramelasses": "desentaramelar",
    "desentaramelaste": "desentaramelar",
    "desentaramelastes": "desentaramelar",
    "desentaramelava": "desentaramelar",
    "desentaramelavam": "desentaramelar",
    "desentaramelavas": "desentaramelar",
    "desentaramele": "desentaramelar",
    "desentaramelei": "desentaramelar",
    "desentarameleis": "desentaramelar",
    "desentaramelem": "desentaramelar",
    "desentaramelemo": "desentaramelar",
    "desentaramelemos": "desentaramelar",
    "desentarameles": "desentaramelar",
    "desentaramelo": "desentaramelar",
    "desentaramelou": "desentaramelar",
    "desentaramelá": "desentaramelar",
    "desentaramelámo": "desentaramelar",
    "desentaramelámos": "desentaramelar",
    "desentarameláramo": "desentaramelar",
    "desentarameláramos": "desentaramelar",
    "desentaramelárei": "desentaramelar",
    "desentarameláreis": "desentaramelar",
    "desentaramelásseis": "desentaramelar",
    "desentaramelássemos": "desentaramelar",
    "desentaramelávamo": "desentaramelar",
    "desentaramelávamos": "desentaramelar",
    "desentaramelávei": "desentaramelar",
    "desentarameláveis": "desentaramelar",
    "desentarraxa": "desentarraxar",
    "desentarraxada": "desentarraxar",
    "desentarraxadas": "desentarraxar",
    "desentarraxado": "desentarraxar",
    "desentarraxados": "desentarraxar",
    "desentarraxai": "desentarraxar",
    "desentarraxais": "desentarraxar",
    "desentarraxam": "desentarraxar",
    "desentarraxamo": "desentarraxar",
    "desentarraxamos": "desentarraxar",
    "desentarraxando": "desentarraxar",
    "desentarraxara": "desentarraxar",
    "desentarraxaram": "desentarraxar",
    "desentarraxaras": "desentarraxar",
    "desentarraxarde": "desentarraxar",
    "desentarraxardes": "desentarraxar",
    "desentarraxare": "desentarraxar",
    "desentarraxarei": "desentarraxar",
    "desentarraxareis": "desentarraxar",
    "desentarraxarem": "desentarraxar",
    "desentarraxaremos": "desentarraxar",
    "desentarraxares": "desentarraxar",
    "desentarraxaria": "desentarraxar",
    "desentarraxariam": "desentarraxar",
    "desentarraxarias": "desentarraxar",
    "desentarraxarmo": "desentarraxar",
    "desentarraxarmos": "desentarraxar",
    "desentarraxará": "desentarraxar",
    "desentarraxarás": "desentarraxar",
    "desentarraxarão": "desentarraxar",
    "desentarraxaríamos": "desentarraxar",
    "desentarraxaríeis": "desentarraxar",
    "desentarraxas": "desentarraxar",
    "desentarraxasse": "desentarraxar",
    "desentarraxassem": "desentarraxar",
    "desentarraxasses": "desentarraxar",
    "desentarraxaste": "desentarraxar",
    "desentarraxastes": "desentarraxar",
    "desentarraxava": "desentarraxar",
    "desentarraxavam": "desentarraxar",
    "desentarraxavas": "desentarraxar",
    "desentarraxe": "desentarraxar",
    "desentarraxei": "desentarraxar",
    "desentarraxeis": "desentarraxar",
    "desentarraxem": "desentarraxar",
    "desentarraxemo": "desentarraxar",
    "desentarraxemos": "desentarraxar",
    "desentarraxes": "desentarraxar",
    "desentarraxo": "desentarraxar",
    "desentarraxou": "desentarraxar",
    "desentarraxá": "desentarraxar",
    "desentarraxámo": "desentarraxar",
    "desentarraxámos": "desentarraxar",
    "desentarraxáramo": "desentarraxar",
    "desentarraxáramos": "desentarraxar",
    "desentarraxárei": "desentarraxar",
    "desentarraxáreis": "desentarraxar",
    "desentarraxásseis": "desentarraxar",
    "desentarraxássemos": "desentarraxar",
    "desentarraxávamo": "desentarraxar",
    "desentarraxávamos": "desentarraxar",
    "desentarraxávei": "desentarraxar",
    "desentarraxáveis": "desentarraxar",
    "desentedia": "desentediar",
    "desentediada": "desentediar",
    "desentediadas": "desentediar",
    "desentediado": "desentediar",
    "desentediados": "desentediar",
    "desentediai": "desentediar",
    "desentediais": "desentediar",
    "desentediam": "desentediar",
    "desentediamo": "desentediar",
    "desentediamos": "desentediar",
    "desentediando": "desentediar",
    "desentediara": "desentediar",
    "desentediaram": "desentediar",
    "desentediaras": "desentediar",
    "desentediarde": "desentediar",
    "desentediardes": "desentediar",
    "desentediare": "desentediar",
    "desentediarei": "desentediar",
    "desentediareis": "desentediar",
    "desentediarem": "desentediar",
    "desentediaremos": "desentediar",
    "desentediares": "desentediar",
    "desentediaria": "desentediar",
    "desentediariam": "desentediar",
    "desentediarias": "desentediar",
    "desentediarmo": "desentediar",
    "desentediarmos": "desentediar",
    "desentediará": "desentediar",
    "desentediarás": "desentediar",
    "desentediarão": "desentediar",
    "desentediaríamos": "desentediar",
    "desentediaríeis": "desentediar",
    "desentedias": "desentediar",
    "desentediasse": "desentediar",
    "desentediassem": "desentediar",
    "desentediasses": "desentediar",
    "desentediaste": "desentediar",
    "desentediastes": "desentediar",
    "desentediava": "desentediar",
    "desentediavam": "desentediar",
    "desentediavas": "desentediar",
    "desentedie": "desentediar",
    "desentediei": "desentediar",
    "desentedieis": "desentediar",
    "desentediem": "desentediar",
    "desentediemo": "desentediar",
    "desentediemos": "desentediar",
    "desentedies": "desentediar",
    "desentedio": "desentediar",
    "desentediou": "desentediar",
    "desentediá": "desentediar",
    "desentediámo": "desentediar",
    "desentediámos": "desentediar",
    "desentediáramo": "desentediar",
    "desentediáramos": "desentediar",
    "desentediárei": "desentediar",
    "desentediáreis": "desentediar",
    "desentediásseis": "desentediar",
    "desentediássemos": "desentediar",
    "desentediávamo": "desentediar",
    "desentediávamos": "desentediar",
    "desentediávei": "desentediar",
    "desentediáveis": "desentediar",
    "desentenda": "desentender",
    "desentendais": "desentender",
    "desentendam": "desentender",
    "desentendamo": "desentender",
    "desentendamos": "desentender",
    "desentendas": "desentender",
    "desentende": "desentender",
    "desentendei": "desentender",
    "desentendeis": "desentender",
    "desentendem": "desentender",
    "desentendemo": "desentender",
    "desentendemos": "desentender",
    "desentendendo": "desentender",
    "desentendera": "desentender",
    "desentenderam": "desentender",
    "desentenderas": "desentender",
    "desentenderdes": "desentender",
    "desentenderei": "desentender",
    "desentendereis": "desentender",
    "desentenderem": "desentender",
    "desentenderemos": "desentender",
    "desentenderes": "desentender",
    "desentenderia": "desentender",
    "desentenderiam": "desentender",
    "desentenderias": "desentender",
    "desentendermo": "desentender",
    "desentendermos": "desentender",
    "desentenderá": "desentender",
    "desentenderás": "desentender",
    "desentenderão": "desentender",
    "desentenderíamos": "desentender",
    "desentenderíeis": "desentender",
    "desentendes": "desentender",
    "desentendesse": "desentender",
    "desentendessem": "desentender",
    "desentendesses": "desentender",
    "desentendeste": "desentender",
    "desentendestes": "desentender",
    "desentendeu": "desentender",
    "desentendi": "desentender",
    "desentendia": "desentender",
    "desentendiam": "desentender",
    "desentendias": "desentender",
    "desentendida": "desentendido",
    "desentendidas": "desentendido",
    "desentendido": "desentender",
    "desentendidos": "desentendido",
    "desentendimentos": "desentendimento",
    "desentendo": "desentender",
    "desentendêramo": "desentender",
    "desentendêramos": "desentender",
    "desentendêreis": "desentender",
    "desentendêsseis": "desentender",
    "desentendêssemos": "desentender",
    "desentendíamo": "desentender",
    "desentendíamos": "desentender",
    "desentendíeis": "desentender",
    "desentenebrece": "desentenebrecer",
    "desentenebrecei": "desentenebrecer",
    "desentenebreceis": "desentenebrecer",
    "desentenebrecem": "desentenebrecer",
    "desentenebrecemo": "desentenebrecer",
    "desentenebrecemos": "desentenebrecer",
    "desentenebrecendo": "desentenebrecer",
    "desentenebrecera": "desentenebrecer",
    "desentenebreceram": "desentenebrecer",
    "desentenebreceras": "desentenebrecer",
    "desentenebrecerdes": "desentenebrecer",
    "desentenebrecerei": "desentenebrecer",
    "desentenebrecereis": "desentenebrecer",
    "desentenebrecerem": "desentenebrecer",
    "desentenebreceremos": "desentenebrecer",
    "desentenebreceres": "desentenebrecer",
    "desentenebreceria": "desentenebrecer",
    "desentenebreceriam": "desentenebrecer",
    "desentenebrecerias": "desentenebrecer",
    "desentenebrecermo": "desentenebrecer",
    "desentenebrecermos": "desentenebrecer",
    "desentenebrecerá": "desentenebrecer",
    "desentenebrecerás": "desentenebrecer",
    "desentenebrecerão": "desentenebrecer",
    "desentenebreceríamos": "desentenebrecer",
    "desentenebreceríeis": "desentenebrecer",
    "desentenebreces": "desentenebrecer",
    "desentenebrecesse": "desentenebrecer",
    "desentenebrecessem": "desentenebrecer",
    "desentenebrecesses": "desentenebrecer",
    "desentenebreceste": "desentenebrecer",
    "desentenebrecestes": "desentenebrecer",
    "desentenebreceu": "desentenebrecer",
    "desentenebreci": "desentenebrecer",
    "desentenebrecia": "desentenebrecer",
    "desentenebreciam": "desentenebrecer",
    "desentenebrecias": "desentenebrecer",
    "desentenebrecida": "desentenebrecido",
    "desentenebrecidas": "desentenebrecido",
    "desentenebrecido": "desentenebrecer",
    "desentenebrecidos": "desentenebrecido",
    "desentenebrecêramo": "desentenebrecer",
    "desentenebrecêramos": "desentenebrecer",
    "desentenebrecêreis": "desentenebrecer",
    "desentenebrecêsseis": "desentenebrecer",
    "desentenebrecêssemos": "desentenebrecer",
    "desentenebrecíamo": "desentenebrecer",
    "desentenebrecíamos": "desentenebrecer",
    "desentenebrecíeis": "desentenebrecer",
    "desentenebreça": "desentenebrecer",
    "desentenebreçais": "desentenebrecer",
    "desentenebreçam": "desentenebrecer",
    "desentenebreçamo": "desentenebrecer",
    "desentenebreçamos": "desentenebrecer",
    "desentenebreças": "desentenebrecer",
    "desentenebreço": "desentenebrecer",
    "desenternece": "desenternecer",
    "desenternecei": "desenternecer",
    "desenterneceis": "desenternecer",
    "desenternecem": "desenternecer",
    "desenternecemo": "desenternecer",
    "desenternecemos": "desenternecer",
    "desenternecendo": "desenternecer",
    "desenternecera": "desenternecer",
    "desenterneceram": "desenternecer",
    "desenterneceras": "desenternecer",
    "desenternecerde": "desenternecer",
    "desenternecerdes": "desenternecer",
    "desenternecere": "desenternecer",
    "desenternecerei": "desenternecer",
    "desenternecereis": "desenternecer",
    "desenternecerem": "desenternecer",
    "desenterneceremos": "desenternecer",
    "desenterneceres": "desenternecer",
    "desenterneceria": "desenternecer",
    "desenterneceriam": "desenternecer",
    "desenternecerias": "desenternecer",
    "desenternecermo": "desenternecer",
    "desenternecermos": "desenternecer",
    "desenternecerá": "desenternecer",
    "desenternecerás": "desenternecer",
    "desenternecerão": "desenternecer",
    "desenterneceríamos": "desenternecer",
    "desenterneceríeis": "desenternecer",
    "desenterneces": "desenternecer",
    "desenternecesse": "desenternecer",
    "desenternecessem": "desenternecer",
    "desenternecesses": "desenternecer",
    "desenterneceste": "desenternecer",
    "desenternecestes": "desenternecer",
    "desenterneceu": "desenternecer",
    "desenterneci": "desenternecer",
    "desenternecia": "desenternecer",
    "desenterneciam": "desenternecer",
    "desenternecias": "desenternecer",
    "desenternecida": "desenternecido",
    "desenternecidas": "desenternecido",
    "desenternecido": "desenternecer",
    "desenternecidos": "desenternecido",
    "desenternecê": "desenternecer",
    "desenternecêramo": "desenternecer",
    "desenternecêramos": "desenternecer",
    "desenternecêrei": "desenternecer",
    "desenternecêreis": "desenternecer",
    "desenternecêsseis": "desenternecer",
    "desenternecêssemos": "desenternecer",
    "desenternecíamo": "desenternecer",
    "desenternecíamos": "desenternecer",
    "desenternecíei": "desenternecer",
    "desenternecíeis": "desenternecer",
    "desenterneça": "desenternecer",
    "desenterneçais": "desenternecer",
    "desenterneçam": "desenternecer",
    "desenterneçamo": "desenternecer",
    "desenterneçamos": "desenternecer",
    "desenterneças": "desenternecer",
    "desenterneço": "desenternecer",
    "desenterra": "desenterrar",
    "desenterrada": "desenterrar",
    "desenterradas": "desenterrar",
    "desenterrado": "desenterrar",
    "desenterradora": "desenterrador",
    "desenterradoras": "desenterrador",
    "desenterradores": "desenterrador",
    "desenterrados": "desenterrar",
    "desenterrai": "desenterrar",
    "desenterrais": "desenterrar",
    "desenterram": "desenterrar",
    "desenterramentos": "desenterramento",
    "desenterramo": "desenterrar",
    "desenterramos": "desenterrar",
    "desenterrando": "desenterrar",
    "desenterrara": "desenterrar",
    "desenterraram": "desenterrar",
    "desenterraras": "desenterrar",
    "desenterrarde": "desenterrar",
    "desenterrardes": "desenterrar",
    "desenterrare": "desenterrar",
    "desenterrarei": "desenterrar",
    "desenterrareis": "desenterrar",
    "desenterrarem": "desenterrar",
    "desenterraremos": "desenterrar",
    "desenterrares": "desenterrar",
    "desenterraria": "desenterrar",
    "desenterrariam": "desenterrar",
    "desenterrarias": "desenterrar",
    "desenterrarmo": "desenterrar",
    "desenterrarmos": "desenterrar",
    "desenterrará": "desenterrar",
    "desenterrarás": "desenterrar",
    "desenterrarão": "desenterrar",
    "desenterraríamos": "desenterrar",
    "desenterraríeis": "desenterrar",
    "desenterras": "desenterrar",
    "desenterrasse": "desenterrar",
    "desenterrassem": "desenterrar",
    "desenterrasses": "desenterrar",
    "desenterraste": "desenterrar",
    "desenterrastes": "desenterrar",
    "desenterrava": "desenterrar",
    "desenterravam": "desenterrar",
    "desenterravas": "desenterrar",
    "desenterre": "desenterrar",
    "desenterrei": "desenterrar",
    "desenterreis": "desenterrar",
    "desenterrem": "desenterrar",
    "desenterremo": "desenterrar",
    "desenterremos": "desenterrar",
    "desenterres": "desenterrar",
    "desenterro": "desenterrar",
    "desenterroa": "desenterroar",
    "desenterroada": "desenterroar",
    "desenterroadas": "desenterroar",
    "desenterroado": "desenterroar",
    "desenterroados": "desenterroar",
    "desenterroai": "desenterroar",
    "desenterroais": "desenterroar",
    "desenterroam": "desenterroar",
    "desenterroamo": "desenterroar",
    "desenterroamos": "desenterroar",
    "desenterroando": "desenterroar",
    "desenterroara": "desenterroar",
    "desenterroaram": "desenterroar",
    "desenterroaras": "desenterroar",
    "desenterroarde": "desenterroar",
    "desenterroardes": "desenterroar",
    "desenterroare": "desenterroar",
    "desenterroarei": "desenterroar",
    "desenterroareis": "desenterroar",
    "desenterroarem": "desenterroar",
    "desenterroaremos": "desenterroar",
    "desenterroares": "desenterroar",
    "desenterroaria": "desenterroar",
    "desenterroariam": "desenterroar",
    "desenterroarias": "desenterroar",
    "desenterroarmo": "desenterroar",
    "desenterroarmos": "desenterroar",
    "desenterroará": "desenterroar",
    "desenterroarás": "desenterroar",
    "desenterroarão": "desenterroar",
    "desenterroaríamos": "desenterroar",
    "desenterroaríeis": "desenterroar",
    "desenterroas": "desenterroar",
    "desenterroasse": "desenterroar",
    "desenterroassem": "desenterroar",
    "desenterroasses": "desenterroar",
    "desenterroaste": "desenterroar",
    "desenterroastes": "desenterroar",
    "desenterroava": "desenterroar",
    "desenterroavam": "desenterroar",
    "desenterroavas": "desenterroar",
    "desenterroe": "desenterroar",
    "desenterroei": "desenterroar",
    "desenterroeis": "desenterroar",
    "desenterroem": "desenterroar",
    "desenterroemo": "desenterroar",
    "desenterroemos": "desenterroar",
    "desenterroes": "desenterroar",
    "desenterroo": "desenterroar",
    "desenterroou": "desenterroar",
    "desenterros": "desenterro",
    "desenterrou": "desenterrar",
    "desenterroá": "desenterroar",
    "desenterroámo": "desenterroar",
    "desenterroámos": "desenterroar",
    "desenterroáramo": "desenterroar",
    "desenterroáramos": "desenterroar",
    "desenterroárei": "desenterroar",
    "desenterroáreis": "desenterroar",
    "desenterroásseis": "desenterroar",
    "desenterroássemos": "desenterroar",
    "desenterroávamo": "desenterroar",
    "desenterroávamos": "desenterroar",
    "desenterroávei": "desenterroar",
    "desenterroáveis": "desenterroar",
    "desenterrá": "desenterrar",
    "desenterrámo": "desenterrar",
    "desenterrámos": "desenterrar",
    "desenterráramo": "desenterrar",
    "desenterráramos": "desenterrar",
    "desenterrárei": "desenterrar",
    "desenterráreis": "desenterrar",
    "desenterrásseis": "desenterrar",
    "desenterrássemos": "desenterrar",
    "desenterrávamo": "desenterrar",
    "desenterrávamos": "desenterrar",
    "desenterrávei": "desenterrar",
    "desenterráveis": "desenterrar",
    "desentesa": "desentesar",
    "desentesada": "desentesar",
    "desentesadas": "desentesar",
    "desentesado": "desentesar",
    "desentesados": "desentesar",
    "desentesai": "desentesar",
    "desentesais": "desentesar",
    "desentesam": "desentesar",
    "desentesamo": "desentesar",
    "desentesamos": "desentesar",
    "desentesando": "desentesar",
    "desentesara": "desentesar",
    "desentesaram": "desentesar",
    "desentesaras": "desentesar",
    "desentesarde": "desentesar",
    "desentesardes": "desentesar",
    "desentesare": "desentesar",
    "desentesarei": "desentesar",
    "desentesareis": "desentesar",
    "desentesarem": "desentesar",
    "desentesaremos": "desentesar",
    "desentesares": "desentesar",
    "desentesaria": "desentesar",
    "desentesariam": "desentesar",
    "desentesarias": "desentesar",
    "desentesarmo": "desentesar",
    "desentesarmos": "desentesar",
    "desentesará": "desentesar",
    "desentesarás": "desentesar",
    "desentesarão": "desentesar",
    "desentesaríamos": "desentesar",
    "desentesaríeis": "desentesar",
    "desentesas": "desentesar",
    "desentesasse": "desentesar",
    "desentesassem": "desentesar",
    "desentesasses": "desentesar",
    "desentesaste": "desentesar",
    "desentesastes": "desentesar",
    "desentesava": "desentesar",
    "desentesavam": "desentesar",
    "desentesavas": "desentesar",
    "desentese": "desentesar",
    "desentesei": "desentesar",
    "desenteseis": "desentesar",
    "desentesem": "desentesar",
    "desentesemo": "desentesar",
    "desentesemos": "desentesar",
    "desenteses": "desentesar",
    "desenteso": "desentesar",
    "desentesoira": "desentesoirar",
    "desentesoirada": "desentesoirar",
    "desentesoiradas": "desentesoirar",
    "desentesoirado": "desentesoirar",
    "desentesoirados": "desentesoirar",
    "desentesoirai": "desentesoirar",
    "desentesoirais": "desentesoirar",
    "desentesoiram": "desentesoirar",
    "desentesoiramo": "desentesoirar",
    "desentesoiramos": "desentesoirar",
    "desentesoirando": "desentesoirar",
    "desentesoirara": "desentesoirar",
    "desentesoiraram": "desentesoirar",
    "desentesoiraras": "desentesoirar",
    "desentesoirarde": "desentesoirar",
    "desentesoirardes": "desentesoirar",
    "desentesoirare": "desentesoirar",
    "desentesoirarei": "desentesoirar",
    "desentesoirareis": "desentesoirar",
    "desentesoirarem": "desentesoirar",
    "desentesoiraremos": "desentesoirar",
    "desentesoirares": "desentesoirar",
    "desentesoiraria": "desentesoirar",
    "desentesoirariam": "desentesoirar",
    "desentesoirarias": "desentesoirar",
    "desentesoirarmo": "desentesoirar",
    "desentesoirarmos": "desentesoirar",
    "desentesoirará": "desentesoirar",
    "desentesoirarás": "desentesoirar",
    "desentesoirarão": "desentesoirar",
    "desentesoiraríamos": "desentesoirar",
    "desentesoiraríeis": "desentesoirar",
    "desentesoiras": "desentesoirar",
    "desentesoirasse": "desentesoirar",
    "desentesoirassem": "desentesoirar",
    "desentesoirasses": "desentesoirar",
    "desentesoiraste": "desentesoirar",
    "desentesoirastes": "desentesoirar",
    "desentesoirava": "desentesoirar",
    "desentesoiravam": "desentesoirar",
    "desentesoiravas": "desentesoirar",
    "desentesoire": "desentesoirar",
    "desentesoirei": "desentesoirar",
    "desentesoireis": "desentesoirar",
    "desentesoirem": "desentesoirar",
    "desentesoiremo": "desentesoirar",
    "desentesoiremos": "desentesoirar",
    "desentesoires": "desentesoirar",
    "desentesoiro": "desentesoirar",
    "desentesoirou": "desentesoirar",
    "desentesoirá": "desentesoirar",
    "desentesoirámo": "desentesoirar",
    "desentesoirámos": "desentesoirar",
    "desentesoiráramo": "desentesoirar",
    "desentesoiráramos": "desentesoirar",
    "desentesoirárei": "desentesoirar",
    "desentesoiráreis": "desentesoirar",
    "desentesoirásseis": "desentesoirar",
    "desentesoirássemos": "desentesoirar",
    "desentesoirávamo": "desentesoirar",
    "desentesoirávamos": "desentesoirar",
    "desentesoirávei": "desentesoirar",
    "desentesoiráveis": "desentesoirar",
    "desentesou": "desentesar",
    "desentesoura": "desentesourar",
    "desentesourada": "desentesourar",
    "desentesouradas": "desentesourar",
    "desentesourado": "desentesourar",
    "desentesourados": "desentesourar",
    "desentesourai": "desentesourar",
    "desentesourais": "desentesourar",
    "desentesouram": "desentesourar",
    "desentesouramo": "desentesourar",
    "desentesouramos": "desentesourar",
    "desentesourando": "desentesourar",
    "desentesourara": "desentesourar",
    "desentesouraram": "desentesourar",
    "desentesouraras": "desentesourar",
    "desentesourarde": "desentesourar",
    "desentesourardes": "desentesourar",
    "desentesourare": "desentesourar",
    "desentesourarei": "desentesourar",
    "desentesourareis": "desentesourar",
    "desentesourarem": "desentesourar",
    "desentesouraremos": "desentesourar",
    "desentesourares": "desentesourar",
    "desentesouraria": "desentesourar",
    "desentesourariam": "desentesourar",
    "desentesourarias": "desentesourar",
    "desentesourarmo": "desentesourar",
    "desentesourarmos": "desentesourar",
    "desentesourará": "desentesourar",
    "desentesourarás": "desentesourar",
    "desentesourarão": "desentesourar",
    "desentesouraríamos": "desentesourar",
    "desentesouraríeis": "desentesourar",
    "desentesouras": "desentesourar",
    "desentesourasse": "desentesourar",
    "desentesourassem": "desentesourar",
    "desentesourasses": "desentesourar",
    "desentesouraste": "desentesourar",
    "desentesourastes": "desentesourar",
    "desentesourava": "desentesourar",
    "desentesouravam": "desentesourar",
    "desentesouravas": "desentesourar",
    "desentesoure": "desentesourar",
    "desentesourei": "desentesourar",
    "desentesoureis": "desentesourar",
    "desentesourem": "desentesourar",
    "desentesouremo": "desentesourar",
    "desentesouremos": "desentesourar",
    "desentesoures": "desentesourar",
    "desentesouro": "desentesourar",
    "desentesourou": "desentesourar",
    "desentesourá": "desentesourar",
    "desentesourámo": "desentesourar",
    "desentesourámos": "desentesourar",
    "desentesouráramo": "desentesourar",
    "desentesouráramos": "desentesourar",
    "desentesourárei": "desentesourar",
    "desentesouráreis": "desentesourar",
    "desentesourásseis": "desentesourar",
    "desentesourássemos": "desentesourar",
    "desentesourávamo": "desentesourar",
    "desentesourávamos": "desentesourar",
    "desentesourávei": "desentesourar",
    "desentesouráveis": "desentesourar",
    "desentesá": "desentesar",
    "desentesámo": "desentesar",
    "desentesámos": "desentesar",
    "desentesáramo": "desentesar",
    "desentesáramos": "desentesar",
    "desentesárei": "desentesar",
    "desentesáreis": "desentesar",
    "desentesásseis": "desentesar",
    "desentesássemos": "desentesar",
    "desentesávamo": "desentesar",
    "desentesávamos": "desentesar",
    "desentesávei": "desentesar",
    "desentesáveis": "desentesar",
    "desentibia": "desentibiar",
    "desentibiada": "desentibiar",
    "desentibiadas": "desentibiar",
    "desentibiado": "desentibiar",
    "desentibiados": "desentibiar",
    "desentibiai": "desentibiar",
    "desentibiais": "desentibiar",
    "desentibiam": "desentibiar",
    "desentibiamo": "desentibiar",
    "desentibiamos": "desentibiar",
    "desentibiando": "desentibiar",
    "desentibiara": "desentibiar",
    "desentibiaram": "desentibiar",
    "desentibiaras": "desentibiar",
    "desentibiarde": "desentibiar",
    "desentibiardes": "desentibiar",
    "desentibiare": "desentibiar",
    "desentibiarei": "desentibiar",
    "desentibiareis": "desentibiar",
    "desentibiarem": "desentibiar",
    "desentibiaremos": "desentibiar",
    "desentibiares": "desentibiar",
    "desentibiaria": "desentibiar",
    "desentibiariam": "desentibiar",
    "desentibiarias": "desentibiar",
    "desentibiarmo": "desentibiar",
    "desentibiarmos": "desentibiar",
    "desentibiará": "desentibiar",
    "desentibiarás": "desentibiar",
    "desentibiarão": "desentibiar",
    "desentibiaríamos": "desentibiar",
    "desentibiaríeis": "desentibiar",
    "desentibias": "desentibiar",
    "desentibiasse": "desentibiar",
    "desentibiassem": "desentibiar",
    "desentibiasses": "desentibiar",
    "desentibiaste": "desentibiar",
    "desentibiastes": "desentibiar",
    "desentibiava": "desentibiar",
    "desentibiavam": "desentibiar",
    "desentibiavas": "desentibiar",
    "desentibie": "desentibiar",
    "desentibiei": "desentibiar",
    "desentibieis": "desentibiar",
    "desentibiem": "desentibiar",
    "desentibiemo": "desentibiar",
    "desentibiemos": "desentibiar",
    "desentibies": "desentibiar",
    "desentibio": "desentibiar",
    "desentibiou": "desentibiar",
    "desentibiá": "desentibiar",
    "desentibiámo": "desentibiar",
    "desentibiámos": "desentibiar",
    "desentibiáramo": "desentibiar",
    "desentibiáramos": "desentibiar",
    "desentibiárei": "desentibiar",
    "desentibiáreis": "desentibiar",
    "desentibiásseis": "desentibiar",
    "desentibiássemos": "desentibiar",
    "desentibiávamo": "desentibiar",
    "desentibiávamos": "desentibiar",
    "desentibiávei": "desentibiar",
    "desentibiáveis": "desentibiar",
    "desentoa": "desentoar",
    "desentoada": "desentoar",
    "desentoadas": "desentoar",
    "desentoado": "desentoar",
    "desentoados": "desentoar",
    "desentoai": "desentoar",
    "desentoais": "desentoar",
    "desentoam": "desentoar",
    "desentoamentos": "desentoamento",
    "desentoamo": "desentoar",
    "desentoamos": "desentoar",
    "desentoando": "desentoar",
    "desentoara": "desentoar",
    "desentoaram": "desentoar",
    "desentoaras": "desentoar",
    "desentoarde": "desentoar",
    "desentoardes": "desentoar",
    "desentoare": "desentoar",
    "desentoarei": "desentoar",
    "desentoareis": "desentoar",
    "desentoarem": "desentoar",
    "desentoaremos": "desentoar",
    "desentoares": "desentoar",
    "desentoaria": "desentoar",
    "desentoariam": "desentoar",
    "desentoarias": "desentoar",
    "desentoarmo": "desentoar",
    "desentoarmos": "desentoar",
    "desentoará": "desentoar",
    "desentoarás": "desentoar",
    "desentoarão": "desentoar",
    "desentoaríamos": "desentoar",
    "desentoaríeis": "desentoar",
    "desentoas": "desentoar",
    "desentoasse": "desentoar",
    "desentoassem": "desentoar",
    "desentoasses": "desentoar",
    "desentoaste": "desentoar",
    "desentoastes": "desentoar",
    "desentoava": "desentoar",
    "desentoavam": "desentoar",
    "desentoavas": "desentoar",
    "desentoações": "desentoação",
    "desentoca": "desentocar",
    "desentocada": "desentocar",
    "desentocadas": "desentocar",
    "desentocado": "desentocar",
    "desentocados": "desentocar",
    "desentocai": "desentocar",
    "desentocais": "desentocar",
    "desentocam": "desentocar",
    "desentocamo": "desentocar",
    "desentocamos": "desentocar",
    "desentocando": "desentocar",
    "desentocara": "desentocar",
    "desentocaram": "desentocar",
    "desentocaras": "desentocar",
    "desentocarde": "desentocar",
    "desentocardes": "desentocar",
    "desentocare": "desentocar",
    "desentocarei": "desentocar",
    "desentocareis": "desentocar",
    "desentocarem": "desentocar",
    "desentocaremos": "desentocar",
    "desentocares": "desentocar",
    "desentocaria": "desentocar",
    "desentocariam": "desentocar",
    "desentocarias": "desentocar",
    "desentocarmo": "desentocar",
    "desentocarmos": "desentocar",
    "desentocará": "desentocar",
    "desentocarás": "desentocar",
    "desentocarão": "desentocar",
    "desentocaríamos": "desentocar",
    "desentocaríeis": "desentocar",
    "desentocas": "desentocar",
    "desentocasse": "desentocar",
    "desentocassem": "desentocar",
    "desentocasses": "desentocar",
    "desentocaste": "desentocar",
    "desentocastes": "desentocar",
    "desentocava": "desentocar",
    "desentocavam": "desentocar",
    "desentocavas": "desentocar",
    "desentoco": "desentocar",
    "desentocou": "desentocar",
    "desentocá": "desentocar",
    "desentocámo": "desentocar",
    "desentocámos": "desentocar",
    "desentocáramo": "desentocar",
    "desentocáramos": "desentocar",
    "desentocárei": "desentocar",
    "desentocáreis": "desentocar",
    "desentocásseis": "desentocar",
    "desentocássemos": "desentocar",
    "desentocávamo": "desentocar",
    "desentocávamos": "desentocar",
    "desentocávei": "desentocar",
    "desentocáveis": "desentocar",
    "desentoe": "desentoar",
    "desentoei": "desentoar",
    "desentoeis": "desentoar",
    "desentoem": "desentoar",
    "desentoemo": "desentoar",
    "desentoemos": "desentoar",
    "desentoes": "desentoar",
    "desentolha": "desentolher",
    "desentolhais": "desentolher",
    "desentolham": "desentolher",
    "desentolhamo": "desentolher",
    "desentolhamos": "desentolher",
    "desentolhas": "desentolher",
    "desentolhe": "desentolher",
    "desentolhei": "desentolher",
    "desentolheis": "desentolher",
    "desentolhem": "desentolher",
    "desentolhemo": "desentolher",
    "desentolhemos": "desentolher",
    "desentolhendo": "desentolher",
    "desentolhera": "desentolher",
    "desentolheram": "desentolher",
    "desentolheras": "desentolher",
    "desentolherde": "desentolher",
    "desentolherdes": "desentolher",
    "desentolhere": "desentolher",
    "desentolherei": "desentolher",
    "desentolhereis": "desentolher",
    "desentolherem": "desentolher",
    "desentolheremos": "desentolher",
    "desentolheres": "desentolher",
    "desentolheria": "desentolher",
    "desentolheriam": "desentolher",
    "desentolherias": "desentolher",
    "desentolhermo": "desentolher",
    "desentolhermos": "desentolher",
    "desentolherá": "desentolher",
    "desentolherás": "desentolher",
    "desentolherão": "desentolher",
    "desentolheríamos": "desentolher",
    "desentolheríeis": "desentolher",
    "desentolhes": "desentolher",
    "desentolhesse": "desentolher",
    "desentolhessem": "desentolher",
    "desentolhesses": "desentolher",
    "desentolheste": "desentolher",
    "desentolhestes": "desentolher",
    "desentolheu": "desentolher",
    "desentolhi": "desentolher",
    "desentolhia": "desentolher",
    "desentolhiam": "desentolher",
    "desentolhias": "desentolher",
    "desentolhida": "desentolhido",
    "desentolhidas": "desentolhido",
    "desentolhido": "desentolher",
    "desentolhidos": "desentolhido",
    "desentolho": "desentolher",
    "desentolhê": "desentolher",
    "desentolhêramo": "desentolher",
    "desentolhêramos": "desentolher",
    "desentolhêrei": "desentolher",
    "desentolhêreis": "desentolher",
    "desentolhêsseis": "desentolher",
    "desentolhêssemos": "desentolher",
    "desentolhíamo": "desentolher",
    "desentolhíamos": "desentolher",
    "desentolhíei": "desentolher",
    "desentolhíeis": "desentolher",
    "desentona": "desentonar",
    "desentonada": "desentonar",
    "desentonadas": "desentonar",
    "desentonado": "desentonar",
    "desentonados": "desentonar",
    "desentonai": "desentonar",
    "desentonais": "desentonar",
    "desentonam": "desentonar",
    "desentonamo": "desentonar",
    "desentonamos": "desentonar",
    "desentonando": "desentonar",
    "desentonara": "desentonar",
    "desentonaram": "desentonar",
    "desentonaras": "desentonar",
    "desentonarde": "desentonar",
    "desentonardes": "desentonar",
    "desentonare": "desentonar",
    "desentonarei": "desentonar",
    "desentonareis": "desentonar",
    "desentonarem": "desentonar",
    "desentonaremos": "desentonar",
    "desentonares": "desentonar",
    "desentonaria": "desentonar",
    "desentonariam": "desentonar",
    "desentonarias": "desentonar",
    "desentonarmo": "desentonar",
    "desentonarmos": "desentonar",
    "desentonará": "desentonar",
    "desentonarás": "desentonar",
    "desentonarão": "desentonar",
    "desentonaríamos": "desentonar",
    "desentonaríeis": "desentonar",
    "desentonas": "desentonar",
    "desentonasse": "desentonar",
    "desentonassem": "desentonar",
    "desentonasses": "desentonar",
    "desentonaste": "desentonar",
    "desentonastes": "desentonar",
    "desentonava": "desentonar",
    "desentonavam": "desentonar",
    "desentonavas": "desentonar",
    "desentone": "desentonar",
    "desentonei": "desentonar",
    "desentoneis": "desentonar",
    "desentonem": "desentonar",
    "desentonemo": "desentonar",
    "desentonemos": "desentonar",
    "desentones": "desentonar",
    "desentono": "desentonar",
    "desentonou": "desentonar",
    "desentoná": "desentonar",
    "desentonámo": "desentonar",
    "desentonámos": "desentonar",
    "desentonáramo": "desentonar",
    "desentonáramos": "desentonar",
    "desentonárei": "desentonar",
    "desentonáreis": "desentonar",
    "desentonásseis": "desentonar",
    "desentonássemos": "desentonar",
    "desentonávamo": "desentonar",
    "desentonávamos": "desentonar",
    "desentonávei": "desentonar",
    "desentonáveis": "desentonar",
    "desentoo": "desentoar",
    "desentoou": "desentoar",
    "desentope": "desentupir",
    "desentopem": "desentupir",
    "desentopes": "desentupir",
    "desentoque": "desentocar",
    "desentoquei": "desentocar",
    "desentoqueis": "desentocar",
    "desentoquem": "desentocar",
    "desentoquemo": "desentocar",
    "desentoquemos": "desentocar",
    "desentoques": "desentocar",
    "desentorna": "desentornar",
    "desentornada": "desentornar",
    "desentornadas": "desentornar",
    "desentornado": "desentornar",
    "desentornados": "desentornar",
    "desentornai": "desentornar",
    "desentornais": "desentornar",
    "desentornam": "desentornar",
    "desentornamo": "desentornar",
    "desentornamos": "desentornar",
    "desentornando": "desentornar",
    "desentornara": "desentornar",
    "desentornaram": "desentornar",
    "desentornaras": "desentornar",
    "desentornarde": "desentornar",
    "desentornardes": "desentornar",
    "desentornare": "desentornar",
    "desentornarei": "desentornar",
    "desentornareis": "desentornar",
    "desentornarem": "desentornar",
    "desentornaremos": "desentornar",
    "desentornares": "desentornar",
    "desentornaria": "desentornar",
    "desentornariam": "desentornar",
    "desentornarias": "desentornar",
    "desentornarmo": "desentornar",
    "desentornarmos": "desentornar",
    "desentornará": "desentornar",
    "desentornarás": "desentornar",
    "desentornarão": "desentornar",
    "desentornaríamos": "desentornar",
    "desentornaríeis": "desentornar",
    "desentornas": "desentornar",
    "desentornasse": "desentornar",
    "desentornassem": "desentornar",
    "desentornasses": "desentornar",
    "desentornaste": "desentornar",
    "desentornastes": "desentornar",
    "desentornava": "desentornar",
    "desentornavam": "desentornar",
    "desentornavas": "desentornar",
    "desentorne": "desentornar",
    "desentornei": "desentornar",
    "desentorneis": "desentornar",
    "desentornem": "desentornar",
    "desentornemo": "desentornar",
    "desentornemos": "desentornar",
    "desentornes": "desentornar",
    "desentorno": "desentornar",
    "desentornou": "desentornar",
    "desentorná": "desentornar",
    "desentornámo": "desentornar",
    "desentornámos": "desentornar",
    "desentornáramo": "desentornar",
    "desentornáramos": "desentornar",
    "desentornárei": "desentornar",
    "desentornáreis": "desentornar",
    "desentornásseis": "desentornar",
    "desentornássemos": "desentornar",
    "desentornávamo": "desentornar",
    "desentornávamos": "desentornar",
    "desentornávei": "desentornar",
    "desentornáveis": "desentornar",
    "desentorpece": "desentorpecer",
    "desentorpecei": "desentorpecer",
    "desentorpeceis": "desentorpecer",
    "desentorpecem": "desentorpecer",
    "desentorpecemo": "desentorpecer",
    "desentorpecemos": "desentorpecer",
    "desentorpecendo": "desentorpecer",
    "desentorpecera": "desentorpecer",
    "desentorpeceram": "desentorpecer",
    "desentorpeceras": "desentorpecer",
    "desentorpecerde": "desentorpecer",
    "desentorpecerdes": "desentorpecer",
    "desentorpecere": "desentorpecer",
    "desentorpecerei": "desentorpecer",
    "desentorpecereis": "desentorpecer",
    "desentorpecerem": "desentorpecer",
    "desentorpeceremos": "desentorpecer",
    "desentorpeceres": "desentorpecer",
    "desentorpeceria": "desentorpecer",
    "desentorpeceriam": "desentorpecer",
    "desentorpecerias": "desentorpecer",
    "desentorpecermo": "desentorpecer",
    "desentorpecermos": "desentorpecer",
    "desentorpecerá": "desentorpecer",
    "desentorpecerás": "desentorpecer",
    "desentorpecerão": "desentorpecer",
    "desentorpeceríamos": "desentorpecer",
    "desentorpeceríeis": "desentorpecer",
    "desentorpeces": "desentorpecer",
    "desentorpecesse": "desentorpecer",
    "desentorpecessem": "desentorpecer",
    "desentorpecesses": "desentorpecer",
    "desentorpeceste": "desentorpecer",
    "desentorpecestes": "desentorpecer",
    "desentorpeceu": "desentorpecer",
    "desentorpeci": "desentorpecer",
    "desentorpecia": "desentorpecer",
    "desentorpeciam": "desentorpecer",
    "desentorpecias": "desentorpecer",
    "desentorpecida": "desentorpecido",
    "desentorpecidas": "desentorpecido",
    "desentorpecido": "desentorpecer",
    "desentorpecidos": "desentorpecido",
    "desentorpecimentos": "desentorpecimento",
    "desentorpecê": "desentorpecer",
    "desentorpecêramo": "desentorpecer",
    "desentorpecêramos": "desentorpecer",
    "desentorpecêrei": "desentorpecer",
    "desentorpecêreis": "desentorpecer",
    "desentorpecêsseis": "desentorpecer",
    "desentorpecêssemos": "desentorpecer",
    "desentorpecíamo": "desentorpecer",
    "desentorpecíamos": "desentorpecer",
    "desentorpecíei": "desentorpecer",
    "desentorpecíeis": "desentorpecer",
    "desentorpeça": "desentorpecer",
    "desentorpeçais": "desentorpecer",
    "desentorpeçam": "desentorpecer",
    "desentorpeçamo": "desentorpecer",
    "desentorpeçamos": "desentorpecer",
    "desentorpeças": "desentorpecer",
    "desentorpeço": "desentorpecer",
    "desentortada": "desentortado",
    "desentortadas": "desentortado",
    "desentortados": "desentortado",
    "desentoá": "desentoar",
    "desentoámo": "desentoar",
    "desentoámos": "desentoar",
    "desentoáramo": "desentoar",
    "desentoáramos": "desentoar",
    "desentoárei": "desentoar",
    "desentoáreis": "desentoar",
    "desentoásseis": "desentoar",
    "desentoássemos": "desentoar",
    "desentoávamo": "desentoar",
    "desentoávamos": "desentoar",
    "desentoávei": "desentoar",
    "desentoáveis": "desentoar",
    "desentralha": "desentralhar",
    "desentralhada": "desentralhar",
    "desentralhadas": "desentralhar",
    "desentralhado": "desentralhar",
    "desentralhados": "desentralhar",
    "desentralhai": "desentralhar",
    "desentralhais": "desentralhar",
    "desentralham": "desentralhar",
    "desentralhamo": "desentralhar",
    "desentralhamos": "desentralhar",
    "desentralhando": "desentralhar",
    "desentralhara": "desentralhar",
    "desentralharam": "desentralhar",
    "desentralharas": "desentralhar",
    "desentralharde": "desentralhar",
    "desentralhardes": "desentralhar",
    "desentralhare": "desentralhar",
    "desentralharei": "desentralhar",
    "desentralhareis": "desentralhar",
    "desentralharem": "desentralhar",
    "desentralharemos": "desentralhar",
    "desentralhares": "desentralhar",
    "desentralharia": "desentralhar",
    "desentralhariam": "desentralhar",
    "desentralharias": "desentralhar",
    "desentralharmo": "desentralhar",
    "desentralharmos": "desentralhar",
    "desentralhará": "desentralhar",
    "desentralharás": "desentralhar",
    "desentralharão": "desentralhar",
    "desentralharíamos": "desentralhar",
    "desentralharíeis": "desentralhar",
    "desentralhas": "desentralhar",
    "desentralhasse": "desentralhar",
    "desentralhassem": "desentralhar",
    "desentralhasses": "desentralhar",
    "desentralhaste": "desentralhar",
    "desentralhastes": "desentralhar",
    "desentralhava": "desentralhar",
    "desentralhavam": "desentralhar",
    "desentralhavas": "desentralhar",
    "desentralhe": "desentralhar",
    "desentralhei": "desentralhar",
    "desentralheis": "desentralhar",
    "desentralhem": "desentralhar",
    "desentralhemo": "desentralhar",
    "desentralhemos": "desentralhar",
    "desentralhes": "desentralhar",
    "desentralho": "desentralhar",
    "desentralhou": "desentralhar",
    "desentralhá": "desentralhar",
    "desentralhámo": "desentralhar",
    "desentralhámos": "desentralhar",
    "desentralháramo": "desentralhar",
    "desentralháramos": "desentralhar",
    "desentralhárei": "desentralhar",
    "desentralháreis": "desentralhar",
    "desentralhásseis": "desentralhar",
    "desentralhássemos": "desentralhar",
    "desentralhávamo": "desentralhar",
    "desentralhávamos": "desentralhar",
    "desentralhávei": "desentralhar",
    "desentralháveis": "desentralhar",
    "desentrance": "desentrançar",
    "desentrancei": "desentrançar",
    "desentranceis": "desentrançar",
    "desentrancem": "desentrançar",
    "desentrancemo": "desentrançar",
    "desentrancemos": "desentrançar",
    "desentrances": "desentrançar",
    "desentranha": "desentranhar",
    "desentranhada": "desentranhar",
    "desentranhadas": "desentranhar",
    "desentranhado": "desentranhar",
    "desentranhados": "desentranhar",
    "desentranhai": "desentranhar",
    "desentranhais": "desentranhar",
    "desentranham": "desentranhar",
    "desentranhamo": "desentranhar",
    "desentranhamos": "desentranhar",
    "desentranhando": "desentranhar",
    "desentranhara": "desentranhar",
    "desentranharam": "desentranhar",
    "desentranharas": "desentranhar",
    "desentranharde": "desentranhar",
    "desentranhardes": "desentranhar",
    "desentranhare": "desentranhar",
    "desentranharei": "desentranhar",
    "desentranhareis": "desentranhar",
    "desentranharem": "desentranhar",
    "desentranharemos": "desentranhar",
    "desentranhares": "desentranhar",
    "desentranharia": "desentranhar",
    "desentranhariam": "desentranhar",
    "desentranharias": "desentranhar",
    "desentranharmo": "desentranhar",
    "desentranharmos": "desentranhar",
    "desentranhará": "desentranhar",
    "desentranharás": "desentranhar",
    "desentranharão": "desentranhar",
    "desentranharíamos": "desentranhar",
    "desentranharíeis": "desentranhar",
    "desentranhas": "desentranhar",
    "desentranhasse": "desentranhar",
    "desentranhassem": "desentranhar",
    "desentranhasses": "desentranhar",
    "desentranhaste": "desentranhar",
    "desentranhastes": "desentranhar",
    "desentranhava": "desentranhar",
    "desentranhavam": "desentranhar",
    "desentranhavas": "desentranhar",
    "desentranhe": "desentranhar",
    "desentranhei": "desentranhar",
    "desentranheis": "desentranhar",
    "desentranhem": "desentranhar",
    "desentranhemo": "desentranhar",
    "desentranhemos": "desentranhar",
    "desentranhes": "desentranhar",
    "desentranho": "desentranhar",
    "desentranhou": "desentranhar",
    "desentranhá": "desentranhar",
    "desentranhámo": "desentranhar",
    "desentranhámos": "desentranhar",
    "desentranháramo": "desentranhar",
    "desentranháramos": "desentranhar",
    "desentranhárei": "desentranhar",
    "desentranháreis": "desentranhar",
    "desentranhásseis": "desentranhar",
    "desentranhássemos": "desentranhar",
    "desentranhávamo": "desentranhar",
    "desentranhávamos": "desentranhar",
    "desentranhávei": "desentranhar",
    "desentranháveis": "desentranhar",
    "desentrança": "desentrançar",
    "desentrançada": "desentrançar",
    "desentrançadas": "desentrançar",
    "desentrançado": "desentrançar",
    "desentrançados": "desentrançar",
    "desentrançai": "desentrançar",
    "desentrançais": "desentrançar",
    "desentrançam": "desentrançar",
    "desentrançamo": "desentrançar",
    "desentrançamos": "desentrançar",
    "desentrançando": "desentrançar",
    "desentrançara": "desentrançar",
    "desentrançaram": "desentrançar",
    "desentrançaras": "desentrançar",
    "desentrançarde": "desentrançar",
    "desentrançardes": "desentrançar",
    "desentrançare": "desentrançar",
    "desentrançarei": "desentrançar",
    "desentrançareis": "desentrançar",
    "desentrançarem": "desentrançar",
    "desentrançaremos": "desentrançar",
    "desentrançares": "desentrançar",
    "desentrançaria": "desentrançar",
    "desentrançariam": "desentrançar",
    "desentrançarias": "desentrançar",
    "desentrançarmo": "desentrançar",
    "desentrançarmos": "desentrançar",
    "desentrançará": "desentrançar",
    "desentrançarás": "desentrançar",
    "desentrançarão": "desentrançar",
    "desentrançaríamos": "desentrançar",
    "desentrançaríeis": "desentrançar",
    "desentranças": "desentrançar",
    "desentrançasse": "desentrançar",
    "desentrançassem": "desentrançar",
    "desentrançasses": "desentrançar",
    "desentrançaste": "desentrançar",
    "desentrançastes": "desentrançar",
    "desentrançava": "desentrançar",
    "desentrançavam": "desentrançar",
    "desentrançavas": "desentrançar",
    "desentranço": "desentrançar",
    "desentrançou": "desentrançar",
    "desentrançá": "desentrançar",
    "desentrançámo": "desentrançar",
    "desentrançámos": "desentrançar",
    "desentrançáramo": "desentrançar",
    "desentrançáramos": "desentrançar",
    "desentrançárei": "desentrançar",
    "desentrançáreis": "desentrançar",
    "desentrançásseis": "desentrançar",
    "desentrançássemos": "desentrançar",
    "desentrançávamo": "desentrançar",
    "desentrançávamos": "desentrançar",
    "desentrançávei": "desentrançar",
    "desentrançáveis": "desentrançar",
    "desentrapa": "desentrapar",
    "desentrapada": "desentrapar",
    "desentrapadas": "desentrapar",
    "desentrapado": "desentrapar",
    "desentrapados": "desentrapar",
    "desentrapai": "desentrapar",
    "desentrapais": "desentrapar",
    "desentrapam": "desentrapar",
    "desentrapamo": "desentrapar",
    "desentrapamos": "desentrapar",
    "desentrapando": "desentrapar",
    "desentrapara": "desentrapar",
    "desentraparam": "desentrapar",
    "desentraparas": "desentrapar",
    "desentraparde": "desentrapar",
    "desentrapardes": "desentrapar",
    "desentrapare": "desentrapar",
    "desentraparei": "desentrapar",
    "desentrapareis": "desentrapar",
    "desentraparem": "desentrapar",
    "desentraparemos": "desentrapar",
    "desentrapares": "desentrapar",
    "desentraparia": "desentrapar",
    "desentrapariam": "desentrapar",
    "desentraparias": "desentrapar",
    "desentraparmo": "desentrapar",
    "desentraparmos": "desentrapar",
    "desentrapará": "desentrapar",
    "desentraparás": "desentrapar",
    "desentraparão": "desentrapar",
    "desentraparíamos": "desentrapar",
    "desentraparíeis": "desentrapar",
    "desentrapas": "desentrapar",
    "desentrapasse": "desentrapar",
    "desentrapassem": "desentrapar",
    "desentrapasses": "desentrapar",
    "desentrapaste": "desentrapar",
    "desentrapastes": "desentrapar",
    "desentrapava": "desentrapar",
    "desentrapavam": "desentrapar",
    "desentrapavas": "desentrapar",
    "desentrape": "desentrapar",
    "desentrapei": "desentrapar",
    "desentrapeis": "desentrapar",
    "desentrapem": "desentrapar",
    "desentrapemo": "desentrapar",
    "desentrapemos": "desentrapar",
    "desentrapes": "desentrapar",
    "desentrapo": "desentrapar",
    "desentrapou": "desentrapar",
    "desentrapá": "desentrapar",
    "desentrapámo": "desentrapar",
    "desentrapámos": "desentrapar",
    "desentrapáramo": "desentrapar",
    "desentrapáramos": "desentrapar",
    "desentrapárei": "desentrapar",
    "desentrapáreis": "desentrapar",
    "desentrapásseis": "desentrapar",
    "desentrapássemos": "desentrapar",
    "desentrapávamo": "desentrapar",
    "desentrapávamos": "desentrapar",
    "desentrapávei": "desentrapar",
    "desentrapáveis": "desentrapar",
    "desentrava": "desentravar",
    "desentravada": "desentravar",
    "desentravadas": "desentravar",
    "desentravado": "desentravar",
    "desentravados": "desentravar",
    "desentravai": "desentravar",
    "desentravais": "desentravar",
    "desentravam": "desentravar",
    "desentravamo": "desentravar",
    "desentravamos": "desentravar",
    "desentravando": "desentravar",
    "desentravara": "desentravar",
    "desentravaram": "desentravar",
    "desentravaras": "desentravar",
    "desentravarde": "desentravar",
    "desentravardes": "desentravar",
    "desentravare": "desentravar",
    "desentravarei": "desentravar",
    "desentravareis": "desentravar",
    "desentravarem": "desentravar",
    "desentravaremos": "desentravar",
    "desentravares": "desentravar",
    "desentravaria": "desentravar",
    "desentravariam": "desentravar",
    "desentravarias": "desentravar",
    "desentravarmo": "desentravar",
    "desentravarmos": "desentravar",
    "desentravará": "desentravar",
    "desentravarás": "desentravar",
    "desentravarão": "desentravar",
    "desentravaríamos": "desentravar",
    "desentravaríeis": "desentravar",
    "desentravas": "desentravar",
    "desentravasse": "desentravar",
    "desentravassem": "desentravar",
    "desentravasses": "desentravar",
    "desentravaste": "desentravar",
    "desentravastes": "desentravar",
    "desentravava": "desentravar",
    "desentravavam": "desentravar",
    "desentravavas": "desentravar",
    "desentrave": "desentravar",
    "desentravei": "desentravar",
    "desentraveis": "desentravar",
    "desentravem": "desentravar",
    "desentravemo": "desentravar",
    "desentravemos": "desentravar",
    "desentraves": "desentravar",
    "desentravo": "desentravar",
    "desentravou": "desentravar",
    "desentravá": "desentravar",
    "desentravámo": "desentravar",
    "desentravámos": "desentravar",
    "desentraváramo": "desentravar",
    "desentraváramos": "desentravar",
    "desentravárei": "desentravar",
    "desentraváreis": "desentravar",
    "desentravásseis": "desentravar",
    "desentravássemos": "desentravar",
    "desentravávamo": "desentravar",
    "desentravávamos": "desentravar",
    "desentravávei": "desentravar",
    "desentraváveis": "desentravar",
    "desentrechos": "desentrecho",
    "desentrelace": "desentrelaçar",
    "desentrelacei": "desentrelaçar",
    "desentrelaceis": "desentrelaçar",
    "desentrelacem": "desentrelaçar",
    "desentrelacemo": "desentrelaçar",
    "desentrelacemos": "desentrelaçar",
    "desentrelaces": "desentrelaçar",
    "desentrelaça": "desentrelaçar",
    "desentrelaçada": "desentrelaçar",
    "desentrelaçadas": "desentrelaçar",
    "desentrelaçado": "desentrelaçar",
    "desentrelaçados": "desentrelaçar",
    "desentrelaçai": "desentrelaçar",
    "desentrelaçais": "desentrelaçar",
    "desentrelaçam": "desentrelaçar",
    "desentrelaçamo": "desentrelaçar",
    "desentrelaçamos": "desentrelaçar",
    "desentrelaçando": "desentrelaçar",
    "desentrelaçara": "desentrelaçar",
    "desentrelaçaram": "desentrelaçar",
    "desentrelaçaras": "desentrelaçar",
    "desentrelaçarde": "desentrelaçar",
    "desentrelaçardes": "desentrelaçar",
    "desentrelaçare": "desentrelaçar",
    "desentrelaçarei": "desentrelaçar",
    "desentrelaçareis": "desentrelaçar",
    "desentrelaçarem": "desentrelaçar",
    "desentrelaçaremos": "desentrelaçar",
    "desentrelaçares": "desentrelaçar",
    "desentrelaçaria": "desentrelaçar",
    "desentrelaçariam": "desentrelaçar",
    "desentrelaçarias": "desentrelaçar",
    "desentrelaçarmo": "desentrelaçar",
    "desentrelaçarmos": "desentrelaçar",
    "desentrelaçará": "desentrelaçar",
    "desentrelaçarás": "desentrelaçar",
    "desentrelaçarão": "desentrelaçar",
    "desentrelaçaríamos": "desentrelaçar",
    "desentrelaçaríeis": "desentrelaçar",
    "desentrelaças": "desentrelaçar",
    "desentrelaçasse": "desentrelaçar",
    "desentrelaçassem": "desentrelaçar",
    "desentrelaçasses": "desentrelaçar",
    "desentrelaçaste": "desentrelaçar",
    "desentrelaçastes": "desentrelaçar",
    "desentrelaçava": "desentrelaçar",
    "desentrelaçavam": "desentrelaçar",
    "desentrelaçavas": "desentrelaçar",
    "desentrelaço": "desentrelaçar",
    "desentrelaçou": "desentrelaçar",
    "desentrelaçá": "desentrelaçar",
    "desentrelaçámo": "desentrelaçar",
    "desentrelaçámos": "desentrelaçar",
    "desentrelaçáramo": "desentrelaçar",
    "desentrelaçáramos": "desentrelaçar",
    "desentrelaçárei": "desentrelaçar",
    "desentrelaçáreis": "desentrelaçar",
    "desentrelaçásseis": "desentrelaçar",
    "desentrelaçássemos": "desentrelaçar",
    "desentrelaçávamo": "desentrelaçar",
    "desentrelaçávamos": "desentrelaçar",
    "desentrelaçávei": "desentrelaçar",
    "desentrelaçáveis": "desentrelaçar",
    "desentrelinha": "desentrelinhar",
    "desentrelinhada": "desentrelinhar",
    "desentrelinhadas": "desentrelinhar",
    "desentrelinhado": "desentrelinhar",
    "desentrelinhados": "desentrelinhar",
    "desentrelinhai": "desentrelinhar",
    "desentrelinhais": "desentrelinhar",
    "desentrelinham": "desentrelinhar",
    "desentrelinhamentos": "desentrelinhamento",
    "desentrelinhamo": "desentrelinhar",
    "desentrelinhamos": "desentrelinhar",
    "desentrelinhando": "desentrelinhar",
    "desentrelinhara": "desentrelinhar",
    "desentrelinharam": "desentrelinhar",
    "desentrelinharas": "desentrelinhar",
    "desentrelinharde": "desentrelinhar",
    "desentrelinhardes": "desentrelinhar",
    "desentrelinhare": "desentrelinhar",
    "desentrelinharei": "desentrelinhar",
    "desentrelinhareis": "desentrelinhar",
    "desentrelinharem": "desentrelinhar",
    "desentrelinharemos": "desentrelinhar",
    "desentrelinhares": "desentrelinhar",
    "desentrelinharia": "desentrelinhar",
    "desentrelinhariam": "desentrelinhar",
    "desentrelinharias": "desentrelinhar",
    "desentrelinharmo": "desentrelinhar",
    "desentrelinharmos": "desentrelinhar",
    "desentrelinhará": "desentrelinhar",
    "desentrelinharás": "desentrelinhar",
    "desentrelinharão": "desentrelinhar",
    "desentrelinharíamos": "desentrelinhar",
    "desentrelinharíeis": "desentrelinhar",
    "desentrelinhas": "desentrelinhar",
    "desentrelinhasse": "desentrelinhar",
    "desentrelinhassem": "desentrelinhar",
    "desentrelinhasses": "desentrelinhar",
    "desentrelinhaste": "desentrelinhar",
    "desentrelinhastes": "desentrelinhar",
    "desentrelinhava": "desentrelinhar",
    "desentrelinhavam": "desentrelinhar",
    "desentrelinhavas": "desentrelinhar",
    "desentrelinhe": "desentrelinhar",
    "desentrelinhei": "desentrelinhar",
    "desentrelinheis": "desentrelinhar",
    "desentrelinhem": "desentrelinhar",
    "desentrelinhemo": "desentrelinhar",
    "desentrelinhemos": "desentrelinhar",
    "desentrelinhes": "desentrelinhar",
    "desentrelinho": "desentrelinhar",
    "desentrelinhou": "desentrelinhar",
    "desentrelinhá": "desentrelinhar",
    "desentrelinhámo": "desentrelinhar",
    "desentrelinhámos": "desentrelinhar",
    "desentrelinháramo": "desentrelinhar",
    "desentrelinháramos": "desentrelinhar",
    "desentrelinhárei": "desentrelinhar",
    "desentrelinháreis": "desentrelinhar",
    "desentrelinhásseis": "desentrelinhar",
    "desentrelinhássemos": "desentrelinhar",
    "desentrelinhávamo": "desentrelinhar",
    "desentrelinhávamos": "desentrelinhar",
    "desentrelinhávei": "desentrelinhar",
    "desentrelinháveis": "desentrelinhar",
    "desentreva": "desentrevar",
    "desentrevada": "desentrevar",
    "desentrevadas": "desentrevar",
    "desentrevado": "desentrevar",
    "desentrevados": "desentrevar",
    "desentrevai": "desentrevar",
    "desentrevais": "desentrevar",
    "desentrevam": "desentrevar",
    "desentrevamo": "desentrevar",
    "desentrevamos": "desentrevar",
    "desentrevando": "desentrevar",
    "desentrevara": "desentrevar",
    "desentrevaram": "desentrevar",
    "desentrevaras": "desentrevar",
    "desentrevardes": "desentrevar",
    "desentrevarei": "desentrevar",
    "desentrevareis": "desentrevar",
    "desentrevarem": "desentrevar",
    "desentrevaremos": "desentrevar",
    "desentrevares": "desentrevar",
    "desentrevaria": "desentrevar",
    "desentrevariam": "desentrevar",
    "desentrevarias": "desentrevar",
    "desentrevarmo": "desentrevar",
    "desentrevarmos": "desentrevar",
    "desentrevará": "desentrevar",
    "desentrevarás": "desentrevar",
    "desentrevarão": "desentrevar",
    "desentrevaríamos": "desentrevar",
    "desentrevaríeis": "desentrevar",
    "desentrevas": "desentrevar",
    "desentrevasse": "desentrevar",
    "desentrevassem": "desentrevar",
    "desentrevasses": "desentrevar",
    "desentrevaste": "desentrevar",
    "desentrevastes": "desentrevar",
    "desentrevava": "desentrevar",
    "desentrevavam": "desentrevar",
    "desentrevavas": "desentrevar",
    "desentreve": "desentrevar",
    "desentrevei": "desentrevar",
    "desentreveis": "desentrevar",
    "desentrevem": "desentrevar",
    "desentrevemo": "desentrevar",
    "desentrevemos": "desentrevar",
    "desentreves": "desentrevar",
    "desentrevo": "desentrevar",
    "desentrevou": "desentrevar",
    "desentrevámo": "desentrevar",
    "desentrevámos": "desentrevar",
    "desentreváramo": "desentrevar",
    "desentreváramos": "desentrevar",
    "desentreváreis": "desentrevar",
    "desentrevásseis": "desentrevar",
    "desentrevássemos": "desentrevar",
    "desentrevávamo": "desentrevar",
    "desentrevávamos": "desentrevar",
    "desentreváveis": "desentrevar",
    "desentrincheira": "desentrincheirar",
    "desentrincheirada": "desentrincheirar",
    "desentrincheiradas": "desentrincheirar",
    "desentrincheirado": "desentrincheirar",
    "desentrincheirados": "desentrincheirar",
    "desentrincheirai": "desentrincheirar",
    "desentrincheirais": "desentrincheirar",
    "desentrincheiram": "desentrincheirar",
    "desentrincheiramo": "desentrincheirar",
    "desentrincheiramos": "desentrincheirar",
    "desentrincheirando": "desentrincheirar",
    "desentrincheirara": "desentrincheirar",
    "desentrincheiraram": "desentrincheirar",
    "desentrincheiraras": "desentrincheirar",
    "desentrincheirarde": "desentrincheirar",
    "desentrincheirardes": "desentrincheirar",
    "desentrincheirare": "desentrincheirar",
    "desentrincheirarei": "desentrincheirar",
    "desentrincheirareis": "desentrincheirar",
    "desentrincheirarem": "desentrincheirar",
    "desentrincheiraremos": "desentrincheirar",
    "desentrincheirares": "desentrincheirar",
    "desentrincheiraria": "desentrincheirar",
    "desentrincheirariam": "desentrincheirar",
    "desentrincheirarias": "desentrincheirar",
    "desentrincheirarmo": "desentrincheirar",
    "desentrincheirarmos": "desentrincheirar",
    "desentrincheirará": "desentrincheirar",
    "desentrincheirarás": "desentrincheirar",
    "desentrincheirarão": "desentrincheirar",
    "desentrincheiraríamos": "desentrincheirar",
    "desentrincheiraríeis": "desentrincheirar",
    "desentrincheiras": "desentrincheirar",
    "desentrincheirasse": "desentrincheirar",
    "desentrincheirassem": "desentrincheirar",
    "desentrincheirasses": "desentrincheirar",
    "desentrincheiraste": "desentrincheirar",
    "desentrincheirastes": "desentrincheirar",
    "desentrincheirava": "desentrincheirar",
    "desentrincheiravam": "desentrincheirar",
    "desentrincheiravas": "desentrincheirar",
    "desentrincheire": "desentrincheirar",
    "desentrincheirei": "desentrincheirar",
    "desentrincheireis": "desentrincheirar",
    "desentrincheirem": "desentrincheirar",
    "desentrincheiremo": "desentrincheirar",
    "desentrincheiremos": "desentrincheirar",
    "desentrincheires": "desentrincheirar",
    "desentrincheiro": "desentrincheirar",
    "desentrincheirou": "desentrincheirar",
    "desentrincheirá": "desentrincheirar",
    "desentrincheirámo": "desentrincheirar",
    "desentrincheirámos": "desentrincheirar",
    "desentrincheiráramo": "desentrincheirar",
    "desentrincheiráramos": "desentrincheirar",
    "desentrincheirárei": "desentrincheirar",
    "desentrincheiráreis": "desentrincheirar",
    "desentrincheirásseis": "desentrincheirar",
    "desentrincheirássemos": "desentrincheirar",
    "desentrincheirávamo": "desentrincheirar",
    "desentrincheirávamos": "desentrincheirar",
    "desentrincheirávei": "desentrincheirar",
    "desentrincheiráveis": "desentrincheirar",
    "desentristece": "desentristecer",
    "desentristecei": "desentristecer",
    "desentristeceis": "desentristecer",
    "desentristecem": "desentristecer",
    "desentristecemo": "desentristecer",
    "desentristecemos": "desentristecer",
    "desentristecendo": "desentristecer",
    "desentristecera": "desentristecer",
    "desentristeceram": "desentristecer",
    "desentristeceras": "desentristecer",
    "desentristecerdes": "desentristecer",
    "desentristecerei": "desentristecer",
    "desentristecereis": "desentristecer",
    "desentristecerem": "desentristecer",
    "desentristeceremos": "desentristecer",
    "desentristeceres": "desentristecer",
    "desentristeceria": "desentristecer",
    "desentristeceriam": "desentristecer",
    "desentristecerias": "desentristecer",
    "desentristecermo": "desentristecer",
    "desentristecermos": "desentristecer",
    "desentristecerá": "desentristecer",
    "desentristecerás": "desentristecer",
    "desentristecerão": "desentristecer",
    "desentristeceríamos": "desentristecer",
    "desentristeceríeis": "desentristecer",
    "desentristeces": "desentristecer",
    "desentristecesse": "desentristecer",
    "desentristecessem": "desentristecer",
    "desentristecesses": "desentristecer",
    "desentristeceste": "desentristecer",
    "desentristecestes": "desentristecer",
    "desentristeceu": "desentristecer",
    "desentristeci": "desentristecer",
    "desentristecia": "desentristecer",
    "desentristeciam": "desentristecer",
    "desentristecias": "desentristecer",
    "desentristecida": "desentristecido",
    "desentristecidas": "desentristecido",
    "desentristecido": "desentristecer",
    "desentristecidos": "desentristecido",
    "desentristecêramo": "desentristecer",
    "desentristecêramos": "desentristecer",
    "desentristecêreis": "desentristecer",
    "desentristecêsseis": "desentristecer",
    "desentristecêssemos": "desentristecer",
    "desentristecíamo": "desentristecer",
    "desentristecíamos": "desentristecer",
    "desentristecíeis": "desentristecer",
    "desentristeça": "desentristecer",
    "desentristeçais": "desentristecer",
    "desentristeçam": "desentristecer",
    "desentristeçamo": "desentristecer",
    "desentristeçamos": "desentristecer",
    "desentristeças": "desentristecer",
    "desentristeço": "desentristecer",
    "desentroixa": "desentroixar",
    "desentroixada": "desentroixar",
    "desentroixadas": "desentroixar",
    "desentroixado": "desentroixar",
    "desentroixados": "desentroixar",
    "desentroixai": "desentroixar",
    "desentroixais": "desentroixar",
    "desentroixam": "desentroixar",
    "desentroixamo": "desentroixar",
    "desentroixamos": "desentroixar",
    "desentroixando": "desentroixar",
    "desentroixara": "desentroixar",
    "desentroixaram": "desentroixar",
    "desentroixaras": "desentroixar",
    "desentroixarde": "desentroixar",
    "desentroixardes": "desentroixar",
    "desentroixare": "desentroixar",
    "desentroixarei": "desentroixar",
    "desentroixareis": "desentroixar",
    "desentroixarem": "desentroixar",
    "desentroixaremos": "desentroixar",
    "desentroixares": "desentroixar",
    "desentroixaria": "desentroixar",
    "desentroixariam": "desentroixar",
    "desentroixarias": "desentroixar",
    "desentroixarmo": "desentroixar",
    "desentroixarmos": "desentroixar",
    "desentroixará": "desentroixar",
    "desentroixarás": "desentroixar",
    "desentroixarão": "desentroixar",
    "desentroixaríamos": "desentroixar",
    "desentroixaríeis": "desentroixar",
    "desentroixas": "desentroixar",
    "desentroixasse": "desentroixar",
    "desentroixassem": "desentroixar",
    "desentroixasses": "desentroixar",
    "desentroixaste": "desentroixar",
    "desentroixastes": "desentroixar",
    "desentroixava": "desentroixar",
    "desentroixavam": "desentroixar",
    "desentroixavas": "desentroixar",
    "desentroixe": "desentroixar",
    "desentroixei": "desentroixar",
    "desentroixeis": "desentroixar",
    "desentroixem": "desentroixar",
    "desentroixemo": "desentroixar",
    "desentroixemos": "desentroixar",
    "desentroixes": "desentroixar",
    "desentroixo": "desentroixar",
    "desentroixou": "desentroixar",
    "desentroixá": "desentroixar",
    "desentroixámo": "desentroixar",
    "desentroixámos": "desentroixar",
    "desentroixáramo": "desentroixar",
    "desentroixáramos": "desentroixar",
    "desentroixárei": "desentroixar",
    "desentroixáreis": "desentroixar",
    "desentroixásseis": "desentroixar",
    "desentroixássemos": "desentroixar",
    "desentroixávamo": "desentroixar",
    "desentroixávamos": "desentroixar",
    "desentroixávei": "desentroixar",
    "desentroixáveis": "desentroixar",
    "desentroniza": "desentronizar",
    "desentronizada": "desentronizar",
    "desentronizadas": "desentronizar",
    "desentronizado": "desentronizar",
    "desentronizados": "desentronizar",
    "desentronizai": "desentronizar",
    "desentronizais": "desentronizar",
    "desentronizam": "desentronizar",
    "desentronizamo": "desentronizar",
    "desentronizamos": "desentronizar",
    "desentronizando": "desentronizar",
    "desentronizara": "desentronizar",
    "desentronizaram": "desentronizar",
    "desentronizaras": "desentronizar",
    "desentronizarde": "desentronizar",
    "desentronizardes": "desentronizar",
    "desentronizare": "desentronizar",
    "desentronizarei": "desentronizar",
    "desentronizareis": "desentronizar",
    "desentronizarem": "desentronizar",
    "desentronizaremos": "desentronizar",
    "desentronizares": "desentronizar",
    "desentronizaria": "desentronizar",
    "desentronizariam": "desentronizar",
    "desentronizarias": "desentronizar",
    "desentronizarmo": "desentronizar",
    "desentronizarmos": "desentronizar",
    "desentronizará": "desentronizar",
    "desentronizarás": "desentronizar",
    "desentronizarão": "desentronizar",
    "desentronizaríamos": "desentronizar",
    "desentronizaríeis": "desentronizar",
    "desentronizas": "desentronizar",
    "desentronizasse": "desentronizar",
    "desentronizassem": "desentronizar",
    "desentronizasses": "desentronizar",
    "desentronizaste": "desentronizar",
    "desentronizastes": "desentronizar",
    "desentronizava": "desentronizar",
    "desentronizavam": "desentronizar",
    "desentronizavas": "desentronizar",
    "desentronize": "desentronizar",
    "desentronizei": "desentronizar",
    "desentronizeis": "desentronizar",
    "desentronizem": "desentronizar",
    "desentronizemo": "desentronizar",
    "desentronizemos": "desentronizar",
    "desentronizes": "desentronizar",
    "desentronizo": "desentronizar",
    "desentronizou": "desentronizar",
    "desentronizá": "desentronizar",
    "desentronizámo": "desentronizar",
    "desentronizámos": "desentronizar",
    "desentronizáramo": "desentronizar",
    "desentronizáramos": "desentronizar",
    "desentronizárei": "desentronizar",
    "desentronizáreis": "desentronizar",
    "desentronizásseis": "desentronizar",
    "desentronizássemos": "desentronizar",
    "desentronizávamo": "desentronizar",
    "desentronizávamos": "desentronizar",
    "desentronizávei": "desentronizar",
    "desentronizáveis": "desentronizar",
    "desentrosamentos": "desentrosamento",
    "desentrouxa": "desentrouxar",
    "desentrouxada": "desentrouxar",
    "desentrouxadas": "desentrouxar",
    "desentrouxado": "desentrouxar",
    "desentrouxados": "desentrouxar",
    "desentrouxai": "desentrouxar",
    "desentrouxais": "desentrouxar",
    "desentrouxam": "desentrouxar",
    "desentrouxamo": "desentrouxar",
    "desentrouxamos": "desentrouxar",
    "desentrouxando": "desentrouxar",
    "desentrouxara": "desentrouxar",
    "desentrouxaram": "desentrouxar",
    "desentrouxaras": "desentrouxar",
    "desentrouxarde": "desentrouxar",
    "desentrouxardes": "desentrouxar",
    "desentrouxare": "desentrouxar",
    "desentrouxarei": "desentrouxar",
    "desentrouxareis": "desentrouxar",
    "desentrouxarem": "desentrouxar",
    "desentrouxaremos": "desentrouxar",
    "desentrouxares": "desentrouxar",
    "desentrouxaria": "desentrouxar",
    "desentrouxariam": "desentrouxar",
    "desentrouxarias": "desentrouxar",
    "desentrouxarmo": "desentrouxar",
    "desentrouxarmos": "desentrouxar",
    "desentrouxará": "desentrouxar",
    "desentrouxarás": "desentrouxar",
    "desentrouxarão": "desentrouxar",
    "desentrouxaríamos": "desentrouxar",
    "desentrouxaríeis": "desentrouxar",
    "desentrouxas": "desentrouxar",
    "desentrouxasse": "desentrouxar",
    "desentrouxassem": "desentrouxar",
    "desentrouxasses": "desentrouxar",
    "desentrouxaste": "desentrouxar",
    "desentrouxastes": "desentrouxar",
    "desentrouxava": "desentrouxar",
    "desentrouxavam": "desentrouxar",
    "desentrouxavas": "desentrouxar",
    "desentrouxe": "desentrouxar",
    "desentrouxei": "desentrouxar",
    "desentrouxeis": "desentrouxar",
    "desentrouxem": "desentrouxar",
    "desentrouxemo": "desentrouxar",
    "desentrouxemos": "desentrouxar",
    "desentrouxes": "desentrouxar",
    "desentrouxo": "desentrouxar",
    "desentrouxou": "desentrouxar",
    "desentrouxá": "desentrouxar",
    "desentrouxámo": "desentrouxar",
    "desentrouxámos": "desentrouxar",
    "desentrouxáramo": "desentrouxar",
    "desentrouxáramos": "desentrouxar",
    "desentrouxárei": "desentrouxar",
    "desentrouxáreis": "desentrouxar",
    "desentrouxásseis": "desentrouxar",
    "desentrouxássemos": "desentrouxar",
    "desentrouxávamo": "desentrouxar",
    "desentrouxávamos": "desentrouxar",
    "desentrouxávei": "desentrouxar",
    "desentrouxáveis": "desentrouxar",
    "desentrulhada": "desentrulhado",
    "desentrulhadas": "desentrulhado",
    "desentrulhadora": "desentrulhador",
    "desentrulhadoras": "desentrulhador",
    "desentrulhadores": "desentrulhador",
    "desentrulhados": "desentrulhado",
    "desentulha": "desentulhar",
    "desentulhada": "desentulhar",
    "desentulhadas": "desentulhar",
    "desentulhado": "desentulhar",
    "desentulhadores": "desentulhador",
    "desentulhados": "desentulhar",
    "desentulhai": "desentulhar",
    "desentulhais": "desentulhar",
    "desentulham": "desentulhar",
    "desentulhamo": "desentulhar",
    "desentulhamos": "desentulhar",
    "desentulhando": "desentulhar",
    "desentulhara": "desentulhar",
    "desentulharam": "desentulhar",
    "desentulharas": "desentulhar",
    "desentulharde": "desentulhar",
    "desentulhardes": "desentulhar",
    "desentulhare": "desentulhar",
    "desentulharei": "desentulhar",
    "desentulhareis": "desentulhar",
    "desentulharem": "desentulhar",
    "desentulharemos": "desentulhar",
    "desentulhares": "desentulhar",
    "desentulharia": "desentulhar",
    "desentulhariam": "desentulhar",
    "desentulharias": "desentulhar",
    "desentulharmo": "desentulhar",
    "desentulharmos": "desentulhar",
    "desentulhará": "desentulhar",
    "desentulharás": "desentulhar",
    "desentulharão": "desentulhar",
    "desentulharíamos": "desentulhar",
    "desentulharíeis": "desentulhar",
    "desentulhas": "desentulhar",
    "desentulhasse": "desentulhar",
    "desentulhassem": "desentulhar",
    "desentulhasses": "desentulhar",
    "desentulhaste": "desentulhar",
    "desentulhastes": "desentulhar",
    "desentulhava": "desentulhar",
    "desentulhavam": "desentulhar",
    "desentulhavas": "desentulhar",
    "desentulhe": "desentulhar",
    "desentulhei": "desentulhar",
    "desentulheis": "desentulhar",
    "desentulhem": "desentulhar",
    "desentulhemo": "desentulhar",
    "desentulhemos": "desentulhar",
    "desentulhes": "desentulhar",
    "desentulho": "desentulhar",
    "desentulhos": "desentulho",
    "desentulhou": "desentulhar",
    "desentulhá": "desentulhar",
    "desentulhámo": "desentulhar",
    "desentulhámos": "desentulhar",
    "desentulháramo": "desentulhar",
    "desentulháramos": "desentulhar",
    "desentulhárei": "desentulhar",
    "desentulháreis": "desentulhar",
    "desentulhásseis": "desentulhar",
    "desentulhássemos": "desentulhar",
    "desentulhávamo": "desentulhar",
    "desentulhávamos": "desentulhar",
    "desentulhávei": "desentulhar",
    "desentulháveis": "desentulhar",
    "desentumece": "desentumecer",
    "desentumecei": "desentumecer",
    "desentumeceis": "desentumecer",
    "desentumecem": "desentumecer",
    "desentumecemo": "desentumecer",
    "desentumecemos": "desentumecer",
    "desentumecendo": "desentumecer",
    "desentumecera": "desentumecer",
    "desentumeceram": "desentumecer",
    "desentumeceras": "desentumecer",
    "desentumecerde": "desentumecer",
    "desentumecerdes": "desentumecer",
    "desentumecere": "desentumecer",
    "desentumecerei": "desentumecer",
    "desentumecereis": "desentumecer",
    "desentumecerem": "desentumecer",
    "desentumeceremos": "desentumecer",
    "desentumeceres": "desentumecer",
    "desentumeceria": "desentumecer",
    "desentumeceriam": "desentumecer",
    "desentumecerias": "desentumecer",
    "desentumecermo": "desentumecer",
    "desentumecermos": "desentumecer",
    "desentumecerá": "desentumecer",
    "desentumecerás": "desentumecer",
    "desentumecerão": "desentumecer",
    "desentumeceríamos": "desentumecer",
    "desentumeceríeis": "desentumecer",
    "desentumeces": "desentumecer",
    "desentumecesse": "desentumecer",
    "desentumecessem": "desentumecer",
    "desentumecesses": "desentumecer",
    "desentumeceste": "desentumecer",
    "desentumecestes": "desentumecer",
    "desentumeceu": "desentumecer",
    "desentumeci": "desentumecer",
    "desentumecia": "desentumecer",
    "desentumeciam": "desentumecer",
    "desentumecias": "desentumecer",
    "desentumecida": "desentumecido",
    "desentumecidas": "desentumecido",
    "desentumecido": "desentumecer",
    "desentumecidos": "desentumecido",
    "desentumecê": "desentumecer",
    "desentumecêramo": "desentumecer",
    "desentumecêramos": "desentumecer",
    "desentumecêrei": "desentumecer",
    "desentumecêreis": "desentumecer",
    "desentumecêsseis": "desentumecer",
    "desentumecêssemos": "desentumecer",
    "desentumecíamo": "desentumecer",
    "desentumecíamos": "desentumecer",
    "desentumecíei": "desentumecer",
    "desentumecíeis": "desentumecer",
    "desentumeça": "desentumecer",
    "desentumeçais": "desentumecer",
    "desentumeçam": "desentumecer",
    "desentumeçamo": "desentumecer",
    "desentumeçamos": "desentumecer",
    "desentumeças": "desentumecer",
    "desentumeço": "desentumecer",
    "desentupa": "desentupir",
    "desentupais": "desentupir",
    "desentupam": "desentupir",
    "desentupamo": "desentupir",
    "desentupamos": "desentupir",
    "desentupas": "desentupir",
    "desentupe": "desentupir",
    "desentupem": "desentupir",
    "desentupes": "desentupir",
    "desentupi": "desentupir",
    "desentupia": "desentupir",
    "desentupiam": "desentupir",
    "desentupias": "desentupir",
    "desentupida": "desentupir",
    "desentupidas": "desentupir",
    "desentupido": "desentupir",
    "desentupidos": "desentupir",
    "desentupimentos": "desentupimento",
    "desentupimo": "desentupir",
    "desentupimos": "desentupir",
    "desentupindo": "desentupir",
    "desentupira": "desentupir",
    "desentupiram": "desentupir",
    "desentupiras": "desentupir",
    "desentupirde": "desentupir",
    "desentupirdes": "desentupir",
    "desentupire": "desentupir",
    "desentupirei": "desentupir",
    "desentupireis": "desentupir",
    "desentupirem": "desentupir",
    "desentupiremos": "desentupir",
    "desentupires": "desentupir",
    "desentupiria": "desentupir",
    "desentupiriam": "desentupir",
    "desentupirias": "desentupir",
    "desentupirmo": "desentupir",
    "desentupirmos": "desentupir",
    "desentupirá": "desentupir",
    "desentupirás": "desentupir",
    "desentupirão": "desentupir",
    "desentupiríamos": "desentupir",
    "desentupiríeis": "desentupir",
    "desentupis": "desentupir",
    "desentupisse": "desentupir",
    "desentupissem": "desentupir",
    "desentupisses": "desentupir",
    "desentupiste": "desentupir",
    "desentupistes": "desentupir",
    "desentupiu": "desentupir",
    "desentupo": "desentupir",
    "desentupíamo": "desentupir",
    "desentupíamos": "desentupir",
    "desentupíei": "desentupir",
    "desentupíeis": "desentupir",
    "desentupíramo": "desentupir",
    "desentupíramos": "desentupir",
    "desentupírei": "desentupir",
    "desentupíreis": "desentupir",
    "desentupísseis": "desentupir",
    "desentupíssemos": "desentupir",
    "desenturva": "desenturvar",
    "desenturvada": "desenturvar",
    "desenturvadas": "desenturvar",
    "desenturvado": "desenturvar",
    "desenturvados": "desenturvar",
    "desenturvai": "desenturvar",
    "desenturvais": "desenturvar",
    "desenturvam": "desenturvar",
    "desenturvamo": "desenturvar",
    "desenturvamos": "desenturvar",
    "desenturvando": "desenturvar",
    "desenturvara": "desenturvar",
    "desenturvaram": "desenturvar",
    "desenturvaras": "desenturvar",
    "desenturvarde": "desenturvar",
    "desenturvardes": "desenturvar",
    "desenturvare": "desenturvar",
    "desenturvarei": "desenturvar",
    "desenturvareis": "desenturvar",
    "desenturvarem": "desenturvar",
    "desenturvaremos": "desenturvar",
    "desenturvares": "desenturvar",
    "desenturvaria": "desenturvar",
    "desenturvariam": "desenturvar",
    "desenturvarias": "desenturvar",
    "desenturvarmo": "desenturvar",
    "desenturvarmos": "desenturvar",
    "desenturvará": "desenturvar",
    "desenturvarás": "desenturvar",
    "desenturvarão": "desenturvar",
    "desenturvaríamos": "desenturvar",
    "desenturvaríeis": "desenturvar",
    "desenturvas": "desenturvar",
    "desenturvasse": "desenturvar",
    "desenturvassem": "desenturvar",
    "desenturvasses": "desenturvar",
    "desenturvaste": "desenturvar",
    "desenturvastes": "desenturvar",
    "desenturvava": "desenturvar",
    "desenturvavam": "desenturvar",
    "desenturvavas": "desenturvar",
    "desenturve": "desenturvar",
    "desenturvei": "desenturvar",
    "desenturveis": "desenturvar",
    "desenturvem": "desenturvar",
    "desenturvemo": "desenturvar",
    "desenturvemos": "desenturvar",
    "desenturves": "desenturvar",
    "desenturvo": "desenturvar",
    "desenturvou": "desenturvar",
    "desenturvá": "desenturvar",
    "desenturvámo": "desenturvar",
    "desenturvámos": "desenturvar",
    "desenturváramo": "desenturvar",
    "desenturváramos": "desenturvar",
    "desenturvárei": "desenturvar",
    "desenturváreis": "desenturvar",
    "desenturvásseis": "desenturvar",
    "desenturvássemos": "desenturvar",
    "desenturvávamo": "desenturvar",
    "desenturvávamos": "desenturvar",
    "desenturvávei": "desenturvar",
    "desenturváveis": "desenturvar",
    "desenubla": "desenublar",
    "desenublada": "desenublar",
    "desenubladas": "desenublar",
    "desenublado": "desenublar",
    "desenublados": "desenublar",
    "desenublai": "desenublar",
    "desenublais": "desenublar",
    "desenublam": "desenublar",
    "desenublamo": "desenublar",
    "desenublamos": "desenublar",
    "desenublando": "desenublar",
    "desenublara": "desenublar",
    "desenublaram": "desenublar",
    "desenublaras": "desenublar",
    "desenublardes": "desenublar",
    "desenublarei": "desenublar",
    "desenublareis": "desenublar",
    "desenublarem": "desenublar",
    "desenublaremos": "desenublar",
    "desenublares": "desenublar",
    "desenublaria": "desenublar",
    "desenublariam": "desenublar",
    "desenublarias": "desenublar",
    "desenublarmo": "desenublar",
    "desenublarmos": "desenublar",
    "desenublará": "desenublar",
    "desenublarás": "desenublar",
    "desenublarão": "desenublar",
    "desenublaríamos": "desenublar",
    "desenublaríeis": "desenublar",
    "desenublas": "desenublar",
    "desenublasse": "desenublar",
    "desenublassem": "desenublar",
    "desenublasses": "desenublar",
    "desenublaste": "desenublar",
    "desenublastes": "desenublar",
    "desenublava": "desenublar",
    "desenublavam": "desenublar",
    "desenublavas": "desenublar",
    "desenuble": "desenublar",
    "desenublei": "desenublar",
    "desenubleis": "desenublar",
    "desenublem": "desenublar",
    "desenublemo": "desenublar",
    "desenublemos": "desenublar",
    "desenubles": "desenublar",
    "desenublo": "desenublar",
    "desenublou": "desenublar",
    "desenublámo": "desenublar",
    "desenublámos": "desenublar",
    "desenubláramo": "desenublar",
    "desenubláramos": "desenublar",
    "desenubláreis": "desenublar",
    "desenublásseis": "desenublar",
    "desenublássemos": "desenublar",
    "desenublávamo": "desenublar",
    "desenublávamos": "desenublar",
    "desenubláveis": "desenublar",
    "desenvasa": "desenvasar",
    "desenvasada": "desenvasar",
    "desenvasadas": "desenvasar",
    "desenvasado": "desenvasar",
    "desenvasados": "desenvasar",
    "desenvasai": "desenvasar",
    "desenvasais": "desenvasar",
    "desenvasam": "desenvasar",
    "desenvasamo": "desenvasar",
    "desenvasamos": "desenvasar",
    "desenvasando": "desenvasar",
    "desenvasara": "desenvasar",
    "desenvasaram": "desenvasar",
    "desenvasaras": "desenvasar",
    "desenvasarde": "desenvasar",
    "desenvasardes": "desenvasar",
    "desenvasare": "desenvasar",
    "desenvasarei": "desenvasar",
    "desenvasareis": "desenvasar",
    "desenvasarem": "desenvasar",
    "desenvasaremos": "desenvasar",
    "desenvasares": "desenvasar",
    "desenvasaria": "desenvasar",
    "desenvasariam": "desenvasar",
    "desenvasarias": "desenvasar",
    "desenvasarmo": "desenvasar",
    "desenvasarmos": "desenvasar",
    "desenvasará": "desenvasar",
    "desenvasarás": "desenvasar",
    "desenvasarão": "desenvasar",
    "desenvasaríamos": "desenvasar",
    "desenvasaríeis": "desenvasar",
    "desenvasas": "desenvasar",
    "desenvasasse": "desenvasar",
    "desenvasassem": "desenvasar",
    "desenvasasses": "desenvasar",
    "desenvasaste": "desenvasar",
    "desenvasastes": "desenvasar",
    "desenvasava": "desenvasar",
    "desenvasavam": "desenvasar",
    "desenvasavas": "desenvasar",
    "desenvase": "desenvasar",
    "desenvasei": "desenvasar",
    "desenvaseis": "desenvasar",
    "desenvasem": "desenvasar",
    "desenvasemo": "desenvasar",
    "desenvasemos": "desenvasar",
    "desenvases": "desenvasar",
    "desenvasilha": "desenvasilhar",
    "desenvasilhada": "desenvasilhar",
    "desenvasilhadas": "desenvasilhar",
    "desenvasilhado": "desenvasilhar",
    "desenvasilhados": "desenvasilhar",
    "desenvasilhai": "desenvasilhar",
    "desenvasilhais": "desenvasilhar",
    "desenvasilham": "desenvasilhar",
    "desenvasilhamo": "desenvasilhar",
    "desenvasilhamos": "desenvasilhar",
    "desenvasilhando": "desenvasilhar",
    "desenvasilhara": "desenvasilhar",
    "desenvasilharam": "desenvasilhar",
    "desenvasilharas": "desenvasilhar",
    "desenvasilharde": "desenvasilhar",
    "desenvasilhardes": "desenvasilhar",
    "desenvasilhare": "desenvasilhar",
    "desenvasilharei": "desenvasilhar",
    "desenvasilhareis": "desenvasilhar",
    "desenvasilharem": "desenvasilhar",
    "desenvasilharemos": "desenvasilhar",
    "desenvasilhares": "desenvasilhar",
    "desenvasilharia": "desenvasilhar",
    "desenvasilhariam": "desenvasilhar",
    "desenvasilharias": "desenvasilhar",
    "desenvasilharmo": "desenvasilhar",
    "desenvasilharmos": "desenvasilhar",
    "desenvasilhará": "desenvasilhar",
    "desenvasilharás": "desenvasilhar",
    "desenvasilharão": "desenvasilhar",
    "desenvasilharíamos": "desenvasilhar",
    "desenvasilharíeis": "desenvasilhar",
    "desenvasilhas": "desenvasilhar",
    "desenvasilhasse": "desenvasilhar",
    "desenvasilhassem": "desenvasilhar",
    "desenvasilhasses": "desenvasilhar",
    "desenvasilhaste": "desenvasilhar",
    "desenvasilhastes": "desenvasilhar",
    "desenvasilhava": "desenvasilhar",
    "desenvasilhavam": "desenvasilhar",
    "desenvasilhavas": "desenvasilhar",
    "desenvasilhe": "desenvasilhar",
    "desenvasilhei": "desenvasilhar",
    "desenvasilheis": "desenvasilhar",
    "desenvasilhem": "desenvasilhar",
    "desenvasilhemo": "desenvasilhar",
    "desenvasilhemos": "desenvasilhar",
    "desenvasilhes": "desenvasilhar",
    "desenvasilho": "desenvasilhar",
    "desenvasilhou": "desenvasilhar",
    "desenvasilhá": "desenvasilhar",
    "desenvasilhámo": "desenvasilhar",
    "desenvasilhámos": "desenvasilhar",
    "desenvasilháramo": "desenvasilhar",
    "desenvasilháramos": "desenvasilhar",
    "desenvasilhárei": "desenvasilhar",
    "desenvasilháreis": "desenvasilhar",
    "desenvasilhásseis": "desenvasilhar",
    "desenvasilhássemos": "desenvasilhar",
    "desenvasilhávamo": "desenvasilhar",
    "desenvasilhávamos": "desenvasilhar",
    "desenvasilhávei": "desenvasilhar",
    "desenvasilháveis": "desenvasilhar",
    "desenvaso": "desenvasar",
    "desenvasou": "desenvasar",
    "desenvasá": "desenvasar",
    "desenvasámo": "desenvasar",
    "desenvasámos": "desenvasar",
    "desenvasáramo": "desenvasar",
    "desenvasáramos": "desenvasar",
    "desenvasárei": "desenvasar",
    "desenvasáreis": "desenvasar",
    "desenvasásseis": "desenvasar",
    "desenvasássemos": "desenvasar",
    "desenvasávamo": "desenvasar",
    "desenvasávamos": "desenvasar",
    "desenvasávei": "desenvasar",
    "desenvasáveis": "desenvasar",
    "desenvencilha": "desenvencilhar",
    "desenvencilhada": "desenvencilhar",
    "desenvencilhadas": "desenvencilhar",
    "desenvencilhado": "desenvencilhar",
    "desenvencilhados": "desenvencilhar",
    "desenvencilhai": "desenvencilhar",
    "desenvencilhais": "desenvencilhar",
    "desenvencilham": "desenvencilhar",
    "desenvencilhamo": "desenvencilhar",
    "desenvencilhamos": "desenvencilhar",
    "desenvencilhando": "desenvencilhar",
    "desenvencilhara": "desenvencilhar",
    "desenvencilharam": "desenvencilhar",
    "desenvencilharas": "desenvencilhar",
    "desenvencilharde": "desenvencilhar",
    "desenvencilhardes": "desenvencilhar",
    "desenvencilhare": "desenvencilhar",
    "desenvencilharei": "desenvencilhar",
    "desenvencilhareis": "desenvencilhar",
    "desenvencilharem": "desenvencilhar",
    "desenvencilharemos": "desenvencilhar",
    "desenvencilhares": "desenvencilhar",
    "desenvencilharia": "desenvencilhar",
    "desenvencilhariam": "desenvencilhar",
    "desenvencilharias": "desenvencilhar",
    "desenvencilharmo": "desenvencilhar",
    "desenvencilharmos": "desenvencilhar",
    "desenvencilhará": "desenvencilhar",
    "desenvencilharás": "desenvencilhar",
    "desenvencilharão": "desenvencilhar",
    "desenvencilharíamos": "desenvencilhar",
    "desenvencilharíeis": "desenvencilhar",
    "desenvencilhas": "desenvencilhar",
    "desenvencilhasse": "desenvencilhar",
    "desenvencilhassem": "desenvencilhar",
    "desenvencilhasses": "desenvencilhar",
    "desenvencilhaste": "desenvencilhar",
    "desenvencilhastes": "desenvencilhar",
    "desenvencilhava": "desenvencilhar",
    "desenvencilhavam": "desenvencilhar",
    "desenvencilhavas": "desenvencilhar",
    "desenvencilhe": "desenvencilhar",
    "desenvencilhei": "desenvencilhar",
    "desenvencilheis": "desenvencilhar",
    "desenvencilhem": "desenvencilhar",
    "desenvencilhemo": "desenvencilhar",
    "desenvencilhemos": "desenvencilhar",
    "desenvencilhes": "desenvencilhar",
    "desenvencilho": "desenvencilhar",
    "desenvencilhou": "desenvencilhar",
    "desenvencilhá": "desenvencilhar",
    "desenvencilhámo": "desenvencilhar",
    "desenvencilhámos": "desenvencilhar",
    "desenvencilháramo": "desenvencilhar",
    "desenvencilháramos": "desenvencilhar",
    "desenvencilhárei": "desenvencilhar",
    "desenvencilháreis": "desenvencilhar",
    "desenvencilhásseis": "desenvencilhar",
    "desenvencilhássemos": "desenvencilhar",
    "desenvencilhávamo": "desenvencilhar",
    "desenvencilhávamos": "desenvencilhar",
    "desenvencilhávei": "desenvencilhar",
    "desenvencilháveis": "desenvencilhar",
    "desenvenena": "desenvenenar",
    "desenvenenada": "desenvenenar",
    "desenvenenadas": "desenvenenar",
    "desenvenenado": "desenvenenar",
    "desenvenenados": "desenvenenar",
    "desenvenenai": "desenvenenar",
    "desenvenenais": "desenvenenar",
    "desenvenenam": "desenvenenar",
    "desenvenenamo": "desenvenenar",
    "desenvenenamos": "desenvenenar",
    "desenvenenando": "desenvenenar",
    "desenvenenara": "desenvenenar",
    "desenvenenaram": "desenvenenar",
    "desenvenenaras": "desenvenenar",
    "desenvenenarde": "desenvenenar",
    "desenvenenardes": "desenvenenar",
    "desenvenenare": "desenvenenar",
    "desenvenenarei": "desenvenenar",
    "desenvenenareis": "desenvenenar",
    "desenvenenarem": "desenvenenar",
    "desenvenenaremos": "desenvenenar",
    "desenvenenares": "desenvenenar",
    "desenvenenaria": "desenvenenar",
    "desenvenenariam": "desenvenenar",
    "desenvenenarias": "desenvenenar",
    "desenvenenarmo": "desenvenenar",
    "desenvenenarmos": "desenvenenar",
    "desenvenenará": "desenvenenar",
    "desenvenenarás": "desenvenenar",
    "desenvenenarão": "desenvenenar",
    "desenvenenaríamos": "desenvenenar",
    "desenvenenaríeis": "desenvenenar",
    "desenvenenas": "desenvenenar",
    "desenvenenasse": "desenvenenar",
    "desenvenenassem": "desenvenenar",
    "desenvenenasses": "desenvenenar",
    "desenvenenaste": "desenvenenar",
    "desenvenenastes": "desenvenenar",
    "desenvenenava": "desenvenenar",
    "desenvenenavam": "desenvenenar",
    "desenvenenavas": "desenvenenar",
    "desenvenene": "desenvenenar",
    "desenvenenei": "desenvenenar",
    "desenveneneis": "desenvenenar",
    "desenvenenem": "desenvenenar",
    "desenvenenemo": "desenvenenar",
    "desenvenenemos": "desenvenenar",
    "desenvenenes": "desenvenenar",
    "desenveneno": "desenvenenar",
    "desenvenenou": "desenvenenar",
    "desenvenená": "desenvenenar",
    "desenvenenámo": "desenvenenar",
    "desenvenenámos": "desenvenenar",
    "desenvenenáramo": "desenvenenar",
    "desenvenenáramos": "desenvenenar",
    "desenvenenárei": "desenvenenar",
    "desenvenenáreis": "desenvenenar",
    "desenvenenásseis": "desenvenenar",
    "desenvenenássemos": "desenvenenar",
    "desenvenenávamo": "desenvenenar",
    "desenvenenávamos": "desenvenenar",
    "desenvenenávei": "desenvenenar",
    "desenvenenáveis": "desenvenenar",
    "desenvereda": "desenveredar",
    "desenveredada": "desenveredar",
    "desenveredadas": "desenveredar",
    "desenveredado": "desenveredar",
    "desenveredados": "desenveredar",
    "desenveredai": "desenveredar",
    "desenveredais": "desenveredar",
    "desenveredam": "desenveredar",
    "desenveredamo": "desenveredar",
    "desenveredamos": "desenveredar",
    "desenveredando": "desenveredar",
    "desenveredara": "desenveredar",
    "desenveredaram": "desenveredar",
    "desenveredaras": "desenveredar",
    "desenveredardes": "desenveredar",
    "desenveredarei": "desenveredar",
    "desenveredareis": "desenveredar",
    "desenveredarem": "desenveredar",
    "desenveredaremos": "desenveredar",
    "desenveredares": "desenveredar",
    "desenveredaria": "desenveredar",
    "desenveredariam": "desenveredar",
    "desenveredarias": "desenveredar",
    "desenveredarmo": "desenveredar",
    "desenveredarmos": "desenveredar",
    "desenveredará": "desenveredar",
    "desenveredarás": "desenveredar",
    "desenveredarão": "desenveredar",
    "desenveredaríamos": "desenveredar",
    "desenveredaríeis": "desenveredar",
    "desenveredas": "desenveredar",
    "desenveredasse": "desenveredar",
    "desenveredassem": "desenveredar",
    "desenveredasses": "desenveredar",
    "desenveredaste": "desenveredar",
    "desenveredastes": "desenveredar",
    "desenveredava": "desenveredar",
    "desenveredavam": "desenveredar",
    "desenveredavas": "desenveredar",
    "desenverede": "desenveredar",
    "desenveredei": "desenveredar",
    "desenveredeis": "desenveredar",
    "desenveredem": "desenveredar",
    "desenveredemo": "desenveredar",
    "desenveredemos": "desenveredar",
    "desenveredes": "desenveredar",
    "desenveredo": "desenveredar",
    "desenveredou": "desenveredar",
    "desenveredámo": "desenveredar",
    "desenveredámos": "desenveredar",
    "desenveredáramo": "desenveredar",
    "desenveredáramos": "desenveredar",
    "desenveredáreis": "desenveredar",
    "desenveredásseis": "desenveredar",
    "desenveredássemos": "desenveredar",
    "desenveredávamo": "desenveredar",
    "desenveredávamos": "desenveredar",
    "desenveredáveis": "desenveredar",
    "desenverga": "desenvergar",
    "desenvergada": "desenvergar",
    "desenvergadas": "desenvergar",
    "desenvergado": "desenvergar",
    "desenvergados": "desenvergar",
    "desenvergai": "desenvergar",
    "desenvergais": "desenvergar",
    "desenvergam": "desenvergar",
    "desenvergamo": "desenvergar",
    "desenvergamos": "desenvergar",
    "desenvergando": "desenvergar",
    "desenvergara": "desenvergar",
    "desenvergaram": "desenvergar",
    "desenvergaras": "desenvergar",
    "desenvergarde": "desenvergar",
    "desenvergardes": "desenvergar",
    "desenvergare": "desenvergar",
    "desenvergarei": "desenvergar",
    "desenvergareis": "desenvergar",
    "desenvergarem": "desenvergar",
    "desenvergaremos": "desenvergar",
    "desenvergares": "desenvergar",
    "desenvergaria": "desenvergar",
    "desenvergariam": "desenvergar",
    "desenvergarias": "desenvergar",
    "desenvergarmo": "desenvergar",
    "desenvergarmos": "desenvergar",
    "desenvergará": "desenvergar",
    "desenvergarás": "desenvergar",
    "desenvergarão": "desenvergar",
    "desenvergaríamos": "desenvergar",
    "desenvergaríeis": "desenvergar",
    "desenvergas": "desenvergar",
    "desenvergasse": "desenvergar",
    "desenvergassem": "desenvergar",
    "desenvergasses": "desenvergar",
    "desenvergaste": "desenvergar",
    "desenvergastes": "desenvergar",
    "desenvergava": "desenvergar",
    "desenvergavam": "desenvergar",
    "desenvergavas": "desenvergar",
    "desenvergo": "desenvergar",
    "desenvergonhada": "desenvergonhado",
    "desenvergonhadas": "desenvergonhado",
    "desenvergonhados": "desenvergonhado",
    "desenvergou": "desenvergar",
    "desenvergue": "desenvergar",
    "desenverguei": "desenvergar",
    "desenvergueis": "desenvergar",
    "desenverguem": "desenvergar",
    "desenverguemo": "desenvergar",
    "desenverguemos": "desenvergar",
    "desenvergues": "desenvergar",
    "desenvergá": "desenvergar",
    "desenvergámo": "desenvergar",
    "desenvergámos": "desenvergar",
    "desenvergáramo": "desenvergar",
    "desenvergáramos": "desenvergar",
    "desenvergárei": "desenvergar",
    "desenvergáreis": "desenvergar",
    "desenvergásseis": "desenvergar",
    "desenvergássemos": "desenvergar",
    "desenvergávamo": "desenvergar",
    "desenvergávamos": "desenvergar",
    "desenvergávei": "desenvergar",
    "desenvergáveis": "desenvergar",
    "desenverniza": "desenvernizar",
    "desenvernizada": "desenvernizar",
    "desenvernizadas": "desenvernizar",
    "desenvernizado": "desenvernizar",
    "desenvernizados": "desenvernizar",
    "desenvernizai": "desenvernizar",
    "desenvernizais": "desenvernizar",
    "desenvernizam": "desenvernizar",
    "desenvernizamo": "desenvernizar",
    "desenvernizamos": "desenvernizar",
    "desenvernizando": "desenvernizar",
    "desenvernizara": "desenvernizar",
    "desenvernizaram": "desenvernizar",
    "desenvernizaras": "desenvernizar",
    "desenvernizarde": "desenvernizar",
    "desenvernizardes": "desenvernizar",
    "desenvernizare": "desenvernizar",
    "desenvernizarei": "desenvernizar",
    "desenvernizareis": "desenvernizar",
    "desenvernizarem": "desenvernizar",
    "desenvernizaremos": "desenvernizar",
    "desenvernizares": "desenvernizar",
    "desenvernizaria": "desenvernizar",
    "desenvernizariam": "desenvernizar",
    "desenvernizarias": "desenvernizar",
    "desenvernizarmo": "desenvernizar",
    "desenvernizarmos": "desenvernizar",
    "desenvernizará": "desenvernizar",
    "desenvernizarás": "desenvernizar",
    "desenvernizarão": "desenvernizar",
    "desenvernizaríamos": "desenvernizar",
    "desenvernizaríeis": "desenvernizar",
    "desenvernizas": "desenvernizar",
    "desenvernizasse": "desenvernizar",
    "desenvernizassem": "desenvernizar",
    "desenvernizasses": "desenvernizar",
    "desenvernizaste": "desenvernizar",
    "desenvernizastes": "desenvernizar",
    "desenvernizava": "desenvernizar",
    "desenvernizavam": "desenvernizar",
    "desenvernizavas": "desenvernizar",
    "desenvernize": "desenvernizar",
    "desenvernizei": "desenvernizar",
    "desenvernizeis": "desenvernizar",
    "desenvernizem": "desenvernizar",
    "desenvernizemo": "desenvernizar",
    "desenvernizemos": "desenvernizar",
    "desenvernizes": "desenvernizar",
    "desenvernizo": "desenvernizar",
    "desenvernizou": "desenvernizar",
    "desenvernizá": "desenvernizar",
    "desenvernizámo": "desenvernizar",
    "desenvernizámos": "desenvernizar",
    "desenvernizáramo": "desenvernizar",
    "desenvernizáramos": "desenvernizar",
    "desenvernizárei": "desenvernizar",
    "desenvernizáreis": "desenvernizar",
    "desenvernizásseis": "desenvernizar",
    "desenvernizássemos": "desenvernizar",
    "desenvernizávamo": "desenvernizar",
    "desenvernizávamos": "desenvernizar",
    "desenvernizávei": "desenvernizar",
    "desenvernizáveis": "desenvernizar",
    "desenviesa": "desenviesar",
    "desenviesada": "desenviesar",
    "desenviesadas": "desenviesar",
    "desenviesado": "desenviesar",
    "desenviesados": "desenviesar",
    "desenviesai": "desenviesar",
    "desenviesais": "desenviesar",
    "desenviesam": "desenviesar",
    "desenviesamo": "desenviesar",
    "desenviesamos": "desenviesar",
    "desenviesando": "desenviesar",
    "desenviesara": "desenviesar",
    "desenviesaram": "desenviesar",
    "desenviesaras": "desenviesar",
    "desenviesarde": "desenviesar",
    "desenviesardes": "desenviesar",
    "desenviesare": "desenviesar",
    "desenviesarei": "desenviesar",
    "desenviesareis": "desenviesar",
    "desenviesarem": "desenviesar",
    "desenviesaremos": "desenviesar",
    "desenviesares": "desenviesar",
    "desenviesaria": "desenviesar",
    "desenviesariam": "desenviesar",
    "desenviesarias": "desenviesar",
    "desenviesarmo": "desenviesar",
    "desenviesarmos": "desenviesar",
    "desenviesará": "desenviesar",
    "desenviesarás": "desenviesar",
    "desenviesarão": "desenviesar",
    "desenviesaríamos": "desenviesar",
    "desenviesaríeis": "desenviesar",
    "desenviesas": "desenviesar",
    "desenviesasse": "desenviesar",
    "desenviesassem": "desenviesar",
    "desenviesasses": "desenviesar",
    "desenviesaste": "desenviesar",
    "desenviesastes": "desenviesar",
    "desenviesava": "desenviesar",
    "desenviesavam": "desenviesar",
    "desenviesavas": "desenviesar",
    "desenviese": "desenviesar",
    "desenviesei": "desenviesar",
    "desenvieseis": "desenviesar",
    "desenviesem": "desenviesar",
    "desenviesemo": "desenviesar",
    "desenviesemos": "desenviesar",
    "desenvieses": "desenviesar",
    "desenvieso": "desenviesar",
    "desenviesou": "desenviesar",
    "desenviesá": "desenviesar",
    "desenviesámo": "desenviesar",
    "desenviesámos": "desenviesar",
    "desenviesáramo": "desenviesar",
    "desenviesáramos": "desenviesar",
    "desenviesárei": "desenviesar",
    "desenviesáreis": "desenviesar",
    "desenviesásseis": "desenviesar",
    "desenviesássemos": "desenviesar",
    "desenviesávamo": "desenviesar",
    "desenviesávamos": "desenviesar",
    "desenviesávei": "desenviesar",
    "desenviesáveis": "desenviesar",
    "desenviola": "desenviolar",
    "desenviolada": "desenviolar",
    "desenvioladas": "desenviolar",
    "desenviolado": "desenviolar",
    "desenviolados": "desenviolar",
    "desenviolai": "desenviolar",
    "desenviolais": "desenviolar",
    "desenviolam": "desenviolar",
    "desenviolamo": "desenviolar",
    "desenviolamos": "desenviolar",
    "desenviolando": "desenviolar",
    "desenviolara": "desenviolar",
    "desenviolaram": "desenviolar",
    "desenviolaras": "desenviolar",
    "desenviolarde": "desenviolar",
    "desenviolardes": "desenviolar",
    "desenviolare": "desenviolar",
    "desenviolarei": "desenviolar",
    "desenviolareis": "desenviolar",
    "desenviolarem": "desenviolar",
    "desenviolaremos": "desenviolar",
    "desenviolares": "desenviolar",
    "desenviolaria": "desenviolar",
    "desenviolariam": "desenviolar",
    "desenviolarias": "desenviolar",
    "desenviolarmo": "desenviolar",
    "desenviolarmos": "desenviolar",
    "desenviolará": "desenviolar",
    "desenviolarás": "desenviolar",
    "desenviolarão": "desenviolar",
    "desenviolaríamos": "desenviolar",
    "desenviolaríeis": "desenviolar",
    "desenviolas": "desenviolar",
    "desenviolasse": "desenviolar",
    "desenviolassem": "desenviolar",
    "desenviolasses": "desenviolar",
    "desenviolaste": "desenviolar",
    "desenviolastes": "desenviolar",
    "desenviolava": "desenviolar",
    "desenviolavam": "desenviolar",
    "desenviolavas": "desenviolar",
    "desenviole": "desenviolar",
    "desenviolei": "desenviolar",
    "desenvioleis": "desenviolar",
    "desenviolem": "desenviolar",
    "desenviolemo": "desenviolar",
    "desenviolemos": "desenviolar",
    "desenvioles": "desenviolar",
    "desenviolo": "desenviolar",
    "desenviolou": "desenviolar",
    "desenviolá": "desenviolar",
    "desenviolámo": "desenviolar",
    "desenviolámos": "desenviolar",
    "desenvioláramo": "desenviolar",
    "desenvioláramos": "desenviolar",
    "desenviolárei": "desenviolar",
    "desenvioláreis": "desenviolar",
    "desenviolásseis": "desenviolar",
    "desenviolássemos": "desenviolar",
    "desenviolávamo": "desenviolar",
    "desenviolávamos": "desenviolar",
    "desenviolávei": "desenviolar",
    "desenvioláveis": "desenviolar",
    "desenvisca": "desenviscar",
    "desenviscada": "desenviscar",
    "desenviscadas": "desenviscar",
    "desenviscado": "desenviscar",
    "desenviscados": "desenviscar",
    "desenviscai": "desenviscar",
    "desenviscais": "desenviscar",
    "desenviscam": "desenviscar",
    "desenviscamo": "desenviscar",
    "desenviscamos": "desenviscar",
    "desenviscando": "desenviscar",
    "desenviscara": "desenviscar",
    "desenviscaram": "desenviscar",
    "desenviscaras": "desenviscar",
    "desenviscarde": "desenviscar",
    "desenviscardes": "desenviscar",
    "desenviscare": "desenviscar",
    "desenviscarei": "desenviscar",
    "desenviscareis": "desenviscar",
    "desenviscarem": "desenviscar",
    "desenviscaremos": "desenviscar",
    "desenviscares": "desenviscar",
    "desenviscaria": "desenviscar",
    "desenviscariam": "desenviscar",
    "desenviscarias": "desenviscar",
    "desenviscarmo": "desenviscar",
    "desenviscarmos": "desenviscar",
    "desenviscará": "desenviscar",
    "desenviscarás": "desenviscar",
    "desenviscarão": "desenviscar",
    "desenviscaríamos": "desenviscar",
    "desenviscaríeis": "desenviscar",
    "desenviscas": "desenviscar",
    "desenviscasse": "desenviscar",
    "desenviscassem": "desenviscar",
    "desenviscasses": "desenviscar",
    "desenviscaste": "desenviscar",
    "desenviscastes": "desenviscar",
    "desenviscava": "desenviscar",
    "desenviscavam": "desenviscar",
    "desenviscavas": "desenviscar",
    "desenvisco": "desenviscar",
    "desenviscou": "desenviscar",
    "desenviscá": "desenviscar",
    "desenviscámo": "desenviscar",
    "desenviscámos": "desenviscar",
    "desenviscáramo": "desenviscar",
    "desenviscáramos": "desenviscar",
    "desenviscárei": "desenviscar",
    "desenviscáreis": "desenviscar",
    "desenviscásseis": "desenviscar",
    "desenviscássemos": "desenviscar",
    "desenviscávamo": "desenviscar",
    "desenviscávamos": "desenviscar",
    "desenviscávei": "desenviscar",
    "desenviscáveis": "desenviscar",
    "desenvisque": "desenviscar",
    "desenvisquei": "desenviscar",
    "desenvisqueis": "desenviscar",
    "desenvisquem": "desenviscar",
    "desenvisquemo": "desenviscar",
    "desenvisquemos": "desenviscar",
    "desenvisques": "desenviscar",
    "desenvolta": "desenvolto",
    "desenvoltas": "desenvolto",
    "desenvoltos": "desenvolto",
    "desenvolturas": "desenvoltura",
    "desenvoluções": "desenvolução",
    "desenvolva": "desenvolver",
    "desenvolvais": "desenvolver",
    "desenvolvam": "desenvolver",
    "desenvolvamo": "desenvolver",
    "desenvolvamos": "desenvolver",
    "desenvolvas": "desenvolver",
    "desenvolve": "desenvolver",
    "desenvolvei": "desenvolver",
    "desenvolveis": "desenvolver",
    "desenvolvem": "desenvolver",
    "desenvolvemo": "desenvolver",
    "desenvolvemos": "desenvolver",
    "desenvolvendo": "desenvolver",
    "desenvolventes": "desenvolvente",
    "desenvolvera": "desenvolver",
    "desenvolveram": "desenvolver",
    "desenvolveras": "desenvolver",
    "desenvolverde": "desenvolver",
    "desenvolverdes": "desenvolver",
    "desenvolvere": "desenvolver",
    "desenvolverei": "desenvolver",
    "desenvolvereis": "desenvolver",
    "desenvolverem": "desenvolver",
    "desenvolveremos": "desenvolver",
    "desenvolveres": "desenvolver",
    "desenvolveria": "desenvolver",
    "desenvolveriam": "desenvolver",
    "desenvolverias": "desenvolver",
    "desenvolvermo": "desenvolver",
    "desenvolvermos": "desenvolver",
    "desenvolverá": "desenvolver",
    "desenvolverás": "desenvolver",
    "desenvolverão": "desenvolver",
    "desenvolveríamos": "desenvolver",
    "desenvolveríeis": "desenvolver",
    "desenvolves": "desenvolver",
    "desenvolvesse": "desenvolver",
    "desenvolvessem": "desenvolver",
    "desenvolvesses": "desenvolver",
    "desenvolveste": "desenvolver",
    "desenvolvestes": "desenvolver",
    "desenvolveu": "desenvolver",
    "desenvolvi": "desenvolver",
    "desenvolvia": "desenvolver",
    "desenvolviam": "desenvolver",
    "desenvolvias": "desenvolver",
    "desenvolvida": "desenvolvido",
    "desenvolvidas": "desenvolvido",
    "desenvolvido": "desenvolver",
    "desenvolvidos": "desenvolvido",
    "desenvolvimentos": "desenvolvimento",
    "desenvolvo": "desenvolver",
    "desenvolvê": "desenvolver",
    "desenvolvêramo": "desenvolver",
    "desenvolvêramos": "desenvolver",
    "desenvolvêrei": "desenvolver",
    "desenvolvêreis": "desenvolver",
    "desenvolvêsseis": "desenvolver",
    "desenvolvêssemos": "desenvolver",
    "desenvolvíamo": "desenvolver",
    "desenvolvíamos": "desenvolver",
    "desenvolvíei": "desenvolver",
    "desenvolvíeis": "desenvolver",
    "desenxaba": "desenxabir",
    "desenxabais": "desenxabir",
    "desenxabam": "desenxabir",
    "desenxabamo": "desenxabir",
    "desenxabamos": "desenxabir",
    "desenxabas": "desenxabir",
    "desenxabe": "desenxabir",
    "desenxabem": "desenxabir",
    "desenxabes": "desenxabir",
    "desenxabi": "desenxabir",
    "desenxabia": "desenxabir",
    "desenxabiam": "desenxabir",
    "desenxabias": "desenxabir",
    "desenxabida": "desenxabir",
    "desenxabidas": "desenxabir",
    "desenxabidezes": "desenxabidez",
    "desenxabido": "desenxabir",
    "desenxabidos": "desenxabir",
    "desenxabimentos": "desenxabimento",
    "desenxabimo": "desenxabir",
    "desenxabimos": "desenxabir",
    "desenxabindo": "desenxabir",
    "desenxabira": "desenxabir",
    "desenxabiram": "desenxabir",
    "desenxabiras": "desenxabir",
    "desenxabirde": "desenxabir",
    "desenxabirdes": "desenxabir",
    "desenxabire": "desenxabir",
    "desenxabirei": "desenxabir",
    "desenxabireis": "desenxabir",
    "desenxabirem": "desenxabir",
    "desenxabiremos": "desenxabir",
    "desenxabires": "desenxabir",
    "desenxabiria": "desenxabir",
    "desenxabiriam": "desenxabir",
    "desenxabirias": "desenxabir",
    "desenxabirmo": "desenxabir",
    "desenxabirmos": "desenxabir",
    "desenxabirá": "desenxabir",
    "desenxabirás": "desenxabir",
    "desenxabirão": "desenxabir",
    "desenxabiríamos": "desenxabir",
    "desenxabiríeis": "desenxabir",
    "desenxabis": "desenxabir",
    "desenxabisse": "desenxabir",
    "desenxabissem": "desenxabir",
    "desenxabisses": "desenxabir",
    "desenxabiste": "desenxabir",
    "desenxabistes": "desenxabir",
    "desenxabiu": "desenxabir",
    "desenxabo": "desenxabir",
    "desenxabíamo": "desenxabir",
    "desenxabíamos": "desenxabir",
    "desenxabíei": "desenxabir",
    "desenxabíeis": "desenxabir",
    "desenxabíramo": "desenxabir",
    "desenxabíramos": "desenxabir",
    "desenxabírei": "desenxabir",
    "desenxabíreis": "desenxabir",
    "desenxabísseis": "desenxabir",
    "desenxabíssemos": "desenxabir",
    "desenxaibida": "desenxaibido",
    "desenxaibidas": "desenxaibido",
    "desenxaibidos": "desenxaibido",
    "desenxameada": "desenxamear",
    "desenxameadas": "desenxamear",
    "desenxameado": "desenxamear",
    "desenxameados": "desenxamear",
    "desenxameai": "desenxamear",
    "desenxameais": "desenxamear",
    "desenxameamo": "desenxamear",
    "desenxameamos": "desenxamear",
    "desenxameando": "desenxamear",
    "desenxameara": "desenxamear",
    "desenxamearam": "desenxamear",
    "desenxamearas": "desenxamear",
    "desenxamearde": "desenxamear",
    "desenxameardes": "desenxamear",
    "desenxameare": "desenxamear",
    "desenxamearei": "desenxamear",
    "desenxameareis": "desenxamear",
    "desenxamearem": "desenxamear",
    "desenxamearemos": "desenxamear",
    "desenxameares": "desenxamear",
    "desenxamearia": "desenxamear",
    "desenxameariam": "desenxamear",
    "desenxamearias": "desenxamear",
    "desenxamearmo": "desenxamear",
    "desenxamearmos": "desenxamear",
    "desenxameará": "desenxamear",
    "desenxamearás": "desenxamear",
    "desenxamearão": "desenxamear",
    "desenxamearíamos": "desenxamear",
    "desenxamearíeis": "desenxamear",
    "desenxameasse": "desenxamear",
    "desenxameassem": "desenxamear",
    "desenxameasses": "desenxamear",
    "desenxameaste": "desenxamear",
    "desenxameastes": "desenxamear",
    "desenxameava": "desenxamear",
    "desenxameavam": "desenxamear",
    "desenxameavas": "desenxamear",
    "desenxameei": "desenxamear",
    "desenxameeis": "desenxamear",
    "desenxameemo": "desenxamear",
    "desenxameemos": "desenxamear",
    "desenxameia": "desenxamear",
    "desenxameiam": "desenxamear",
    "desenxameias": "desenxamear",
    "desenxameie": "desenxamear",
    "desenxameiem": "desenxamear",
    "desenxameies": "desenxamear",
    "desenxameio": "desenxamear",
    "desenxameou": "desenxamear",
    "desenxameá": "desenxamear",
    "desenxameámo": "desenxamear",
    "desenxameámos": "desenxamear",
    "desenxameáramo": "desenxamear",
    "desenxameáramos": "desenxamear",
    "desenxameárei": "desenxamear",
    "desenxameáreis": "desenxamear",
    "desenxameásseis": "desenxamear",
    "desenxameássemos": "desenxamear",
    "desenxameávamo": "desenxamear",
    "desenxameávamos": "desenxamear",
    "desenxameávei": "desenxamear",
    "desenxameáveis": "desenxamear",
    "desenxofra": "desenxofrar",
    "desenxofrada": "desenxofrar",
    "desenxofradas": "desenxofrar",
    "desenxofrado": "desenxofrar",
    "desenxofrados": "desenxofrar",
    "desenxofrai": "desenxofrar",
    "desenxofrais": "desenxofrar",
    "desenxofram": "desenxofrar",
    "desenxoframo": "desenxofrar",
    "desenxoframos": "desenxofrar",
    "desenxofrando": "desenxofrar",
    "desenxofrara": "desenxofrar",
    "desenxofraram": "desenxofrar",
    "desenxofraras": "desenxofrar",
    "desenxofrarde": "desenxofrar",
    "desenxofrardes": "desenxofrar",
    "desenxofrare": "desenxofrar",
    "desenxofrarei": "desenxofrar",
    "desenxofrareis": "desenxofrar",
    "desenxofrarem": "desenxofrar",
    "desenxofraremos": "desenxofrar",
    "desenxofrares": "desenxofrar",
    "desenxofraria": "desenxofrar",
    "desenxofrariam": "desenxofrar",
    "desenxofrarias": "desenxofrar",
    "desenxofrarmo": "desenxofrar",
    "desenxofrarmos": "desenxofrar",
    "desenxofrará": "desenxofrar",
    "desenxofrarás": "desenxofrar",
    "desenxofrarão": "desenxofrar",
    "desenxofraríamos": "desenxofrar",
    "desenxofraríeis": "desenxofrar",
    "desenxofras": "desenxofrar",
    "desenxofrasse": "desenxofrar",
    "desenxofrassem": "desenxofrar",
    "desenxofrasses": "desenxofrar",
    "desenxofraste": "desenxofrar",
    "desenxofrastes": "desenxofrar",
    "desenxofrava": "desenxofrar",
    "desenxofravam": "desenxofrar",
    "desenxofravas": "desenxofrar",
    "desenxofre": "desenxofrar",
    "desenxofrei": "desenxofrar",
    "desenxofreis": "desenxofrar",
    "desenxofrem": "desenxofrar",
    "desenxofremo": "desenxofrar",
    "desenxofremos": "desenxofrar",
    "desenxofres": "desenxofrar",
    "desenxofro": "desenxofrar",
    "desenxofrou": "desenxofrar",
    "desenxofrá": "desenxofrar",
    "desenxofrámo": "desenxofrar",
    "desenxofrámos": "desenxofrar",
    "desenxofráramo": "desenxofrar",
    "desenxofráramos": "desenxofrar",
    "desenxofrárei": "desenxofrar",
    "desenxofráreis": "desenxofrar",
    "desenxofrásseis": "desenxofrar",
    "desenxofrássemos": "desenxofrar",
    "desenxofrávamo": "desenxofrar",
    "desenxofrávamos": "desenxofrar",
    "desenxofrávei": "desenxofrar",
    "desenxofráveis": "desenxofrar",
    "desenxova": "desenxovar",
    "desenxovada": "desenxovar",
    "desenxovadas": "desenxovar",
    "desenxovado": "desenxovar",
    "desenxovados": "desenxovar",
    "desenxovai": "desenxovar",
    "desenxovais": "desenxovar",
    "desenxovalha": "desenxovalhar",
    "desenxovalhada": "desenxovalhar",
    "desenxovalhadas": "desenxovalhar",
    "desenxovalhado": "desenxovalhar",
    "desenxovalhados": "desenxovalhar",
    "desenxovalhai": "desenxovalhar",
    "desenxovalhais": "desenxovalhar",
    "desenxovalham": "desenxovalhar",
    "desenxovalhamo": "desenxovalhar",
    "desenxovalhamos": "desenxovalhar",
    "desenxovalhando": "desenxovalhar",
    "desenxovalhara": "desenxovalhar",
    "desenxovalharam": "desenxovalhar",
    "desenxovalharas": "desenxovalhar",
    "desenxovalharde": "desenxovalhar",
    "desenxovalhardes": "desenxovalhar",
    "desenxovalhare": "desenxovalhar",
    "desenxovalharei": "desenxovalhar",
    "desenxovalhareis": "desenxovalhar",
    "desenxovalharem": "desenxovalhar",
    "desenxovalharemos": "desenxovalhar",
    "desenxovalhares": "desenxovalhar",
    "desenxovalharia": "desenxovalhar",
    "desenxovalhariam": "desenxovalhar",
    "desenxovalharias": "desenxovalhar",
    "desenxovalharmo": "desenxovalhar",
    "desenxovalharmos": "desenxovalhar",
    "desenxovalhará": "desenxovalhar",
    "desenxovalharás": "desenxovalhar",
    "desenxovalharão": "desenxovalhar",
    "desenxovalharíamos": "desenxovalhar",
    "desenxovalharíeis": "desenxovalhar",
    "desenxovalhas": "desenxovalhar",
    "desenxovalhasse": "desenxovalhar",
    "desenxovalhassem": "desenxovalhar",
    "desenxovalhasses": "desenxovalhar",
    "desenxovalhaste": "desenxovalhar",
    "desenxovalhastes": "desenxovalhar",
    "desenxovalhava": "desenxovalhar",
    "desenxovalhavam": "desenxovalhar",
    "desenxovalhavas": "desenxovalhar",
    "desenxovalhe": "desenxovalhar",
    "desenxovalhei": "desenxovalhar",
    "desenxovalheis": "desenxovalhar",
    "desenxovalhem": "desenxovalhar",
    "desenxovalhemo": "desenxovalhar",
    "desenxovalhemos": "desenxovalhar",
    "desenxovalhes": "desenxovalhar",
    "desenxovalho": "desenxovalhar",
    "desenxovalhos": "desenxovalho",
    "desenxovalhou": "desenxovalhar",
    "desenxovalhá": "desenxovalhar",
    "desenxovalhámo": "desenxovalhar",
    "desenxovalhámos": "desenxovalhar",
    "desenxovalháramo": "desenxovalhar",
    "desenxovalháramos": "desenxovalhar",
    "desenxovalhárei": "desenxovalhar",
    "desenxovalháreis": "desenxovalhar",
    "desenxovalhásseis": "desenxovalhar",
    "desenxovalhássemos": "desenxovalhar",
    "desenxovalhávamo": "desenxovalhar",
    "desenxovalhávamos": "desenxovalhar",
    "desenxovalhávei": "desenxovalhar",
    "desenxovalháveis": "desenxovalhar",
    "desenxovam": "desenxovar",
    "desenxovamo": "desenxovar",
    "desenxovamos": "desenxovar",
    "desenxovando": "desenxovar",
    "desenxovara": "desenxovar",
    "desenxovaram": "desenxovar",
    "desenxovaras": "desenxovar",
    "desenxovarde": "desenxovar",
    "desenxovardes": "desenxovar",
    "desenxovare": "desenxovar",
    "desenxovarei": "desenxovar",
    "desenxovareis": "desenxovar",
    "desenxovarem": "desenxovar",
    "desenxovaremos": "desenxovar",
    "desenxovares": "desenxovar",
    "desenxovaria": "desenxovar",
    "desenxovariam": "desenxovar",
    "desenxovarias": "desenxovar",
    "desenxovarmo": "desenxovar",
    "desenxovarmos": "desenxovar",
    "desenxovará": "desenxovar",
    "desenxovarás": "desenxovar",
    "desenxovarão": "desenxovar",
    "desenxovaríamos": "desenxovar",
    "desenxovaríeis": "desenxovar",
    "desenxovas": "desenxovar",
    "desenxovasse": "desenxovar",
    "desenxovassem": "desenxovar",
    "desenxovasses": "desenxovar",
    "desenxovaste": "desenxovar",
    "desenxovastes": "desenxovar",
    "desenxovava": "desenxovar",
    "desenxovavam": "desenxovar",
    "desenxovavas": "desenxovar",
    "desenxove": "desenxovar",
    "desenxovei": "desenxovar",
    "desenxoveis": "desenxovar",
    "desenxovem": "desenxovar",
    "desenxovemo": "desenxovar",
    "desenxovemos": "desenxovar",
    "desenxoves": "desenxovar",
    "desenxovo": "desenxovar",
    "desenxovou": "desenxovar",
    "desenxová": "desenxovar",
    "desenxovámo": "desenxovar",
    "desenxovámos": "desenxovar",
    "desenxováramo": "desenxovar",
    "desenxováramos": "desenxovar",
    "desenxovárei": "desenxovar",
    "desenxováreis": "desenxovar",
    "desenxovásseis": "desenxovar",
    "desenxovássemos": "desenxovar",
    "desenxovávamo": "desenxovar",
    "desenxovávamos": "desenxovar",
    "desenxovávei": "desenxovar",
    "desenxováveis": "desenxovar",
    "desequilibra": "desequilibrar",
    "desequilibrada": "desequilibrar",
    "desequilibradas": "desequilibrar",
    "desequilibrado": "desequilibrar",
    "desequilibrados": "desequilibrar",
    "desequilibrai": "desequilibrar",
    "desequilibrais": "desequilibrar",
    "desequilibram": "desequilibrar",
    "desequilibramo": "desequilibrar",
    "desequilibramos": "desequilibrar",
    "desequilibrando": "desequilibrar",
    "desequilibrara": "desequilibrar",
    "desequilibraram": "desequilibrar",
    "desequilibraras": "desequilibrar",
    "desequilibrarde": "desequilibrar",
    "desequilibrardes": "desequilibrar",
    "desequilibrare": "desequilibrar",
    "desequilibrarei": "desequilibrar",
    "desequilibrareis": "desequilibrar",
    "desequilibrarem": "desequilibrar",
    "desequilibraremos": "desequilibrar",
    "desequilibrares": "desequilibrar",
    "desequilibraria": "desequilibrar",
    "desequilibrariam": "desequilibrar",
    "desequilibrarias": "desequilibrar",
    "desequilibrarmo": "desequilibrar",
    "desequilibrarmos": "desequilibrar",
    "desequilibrará": "desequilibrar",
    "desequilibrarás": "desequilibrar",
    "desequilibrarão": "desequilibrar",
    "desequilibraríamos": "desequilibrar",
    "desequilibraríeis": "desequilibrar",
    "desequilibras": "desequilibrar",
    "desequilibrasse": "desequilibrar",
    "desequilibrassem": "desequilibrar",
    "desequilibrasses": "desequilibrar",
    "desequilibraste": "desequilibrar",
    "desequilibrastes": "desequilibrar",
    "desequilibrava": "desequilibrar",
    "desequilibravam": "desequilibrar",
    "desequilibravas": "desequilibrar",
    "desequilibre": "desequilibrar",
    "desequilibrei": "desequilibrar",
    "desequilibreis": "desequilibrar",
    "desequilibrem": "desequilibrar",
    "desequilibremo": "desequilibrar",
    "desequilibremos": "desequilibrar",
    "desequilibres": "desequilibrar",
    "desequilibro": "desequilibrar",
    "desequilibrou": "desequilibrar",
    "desequilibrá": "desequilibrar",
    "desequilibrámo": "desequilibrar",
    "desequilibrámos": "desequilibrar",
    "desequilibráramo": "desequilibrar",
    "desequilibráramos": "desequilibrar",
    "desequilibrárei": "desequilibrar",
    "desequilibráreis": "desequilibrar",
    "desequilibrásseis": "desequilibrar",
    "desequilibrássemos": "desequilibrar",
    "desequilibrávamo": "desequilibrar",
    "desequilibrávamos": "desequilibrar",
    "desequilibrávei": "desequilibrar",
    "desequilibráveis": "desequilibrável",
    "desequilíbrios": "desequilíbrio",
    "desequipa": "desequipar",
    "desequipada": "desequipar",
    "desequipadas": "desequipar",
    "desequipado": "desequipar",
    "desequipados": "desequipar",
    "desequipai": "desequipar",
    "desequipais": "desequipar",
    "desequipam": "desequipar",
    "desequipamo": "desequipar",
    "desequipamos": "desequipar",
    "desequipando": "desequipar",
    "desequipara": "desequipar",
    "desequiparam": "desequipar",
    "desequiparas": "desequipar",
    "desequiparde": "desequipar",
    "desequipardes": "desequipar",
    "desequipare": "desequipar",
    "desequiparei": "desequipar",
    "desequipareis": "desequipar",
    "desequiparem": "desequipar",
    "desequiparemos": "desequipar",
    "desequipares": "desequipar",
    "desequiparia": "desequipar",
    "desequipariam": "desequipar",
    "desequiparias": "desequipar",
    "desequiparmo": "desequipar",
    "desequiparmos": "desequipar",
    "desequipará": "desequipar",
    "desequiparás": "desequipar",
    "desequiparão": "desequipar",
    "desequiparíamos": "desequipar",
    "desequiparíeis": "desequipar",
    "desequipas": "desequipar",
    "desequipasse": "desequipar",
    "desequipassem": "desequipar",
    "desequipasses": "desequipar",
    "desequipaste": "desequipar",
    "desequipastes": "desequipar",
    "desequipava": "desequipar",
    "desequipavam": "desequipar",
    "desequipavas": "desequipar",
    "desequipe": "desequipar",
    "desequipei": "desequipar",
    "desequipeis": "desequipar",
    "desequipem": "desequipar",
    "desequipemo": "desequipar",
    "desequipemos": "desequipar",
    "desequipes": "desequipar",
    "desequipo": "desequipar",
    "desequipou": "desequipar",
    "desequipá": "desequipar",
    "desequipámo": "desequipar",
    "desequipámos": "desequipar",
    "desequipáramo": "desequipar",
    "desequipáramos": "desequipar",
    "desequipárei": "desequipar",
    "desequipáreis": "desequipar",
    "desequipásseis": "desequipar",
    "desequipássemos": "desequipar",
    "desequipávamo": "desequipar",
    "desequipávamos": "desequipar",
    "desequipávei": "desequipar",
    "desequipáveis": "desequipar",
    "desequivoca": "desequivocar",
    "desequivocada": "desequivocar",
    "desequivocadas": "desequivocar",
    "desequivocado": "desequivocar",
    "desequivocados": "desequivocar",
    "desequivocai": "desequivocar",
    "desequivocais": "desequivocar",
    "desequivocam": "desequivocar",
    "desequivocamo": "desequivocar",
    "desequivocamos": "desequivocar",
    "desequivocando": "desequivocar",
    "desequivocara": "desequivocar",
    "desequivocaram": "desequivocar",
    "desequivocaras": "desequivocar",
    "desequivocarde": "desequivocar",
    "desequivocardes": "desequivocar",
    "desequivocare": "desequivocar",
    "desequivocarei": "desequivocar",
    "desequivocareis": "desequivocar",
    "desequivocarem": "desequivocar",
    "desequivocaremos": "desequivocar",
    "desequivocares": "desequivocar",
    "desequivocaria": "desequivocar",
    "desequivocariam": "desequivocar",
    "desequivocarias": "desequivocar",
    "desequivocarmo": "desequivocar",
    "desequivocarmos": "desequivocar",
    "desequivocará": "desequivocar",
    "desequivocarás": "desequivocar",
    "desequivocarão": "desequivocar",
    "desequivocaríamos": "desequivocar",
    "desequivocaríeis": "desequivocar",
    "desequivocas": "desequivocar",
    "desequivocasse": "desequivocar",
    "desequivocassem": "desequivocar",
    "desequivocasses": "desequivocar",
    "desequivocaste": "desequivocar",
    "desequivocastes": "desequivocar",
    "desequivocava": "desequivocar",
    "desequivocavam": "desequivocar",
    "desequivocavas": "desequivocar",
    "desequivoco": "desequivocar",
    "desequivocou": "desequivocar",
    "desequivocá": "desequivocar",
    "desequivocámo": "desequivocar",
    "desequivocámos": "desequivocar",
    "desequivocáramo": "desequivocar",
    "desequivocáramos": "desequivocar",
    "desequivocárei": "desequivocar",
    "desequivocáreis": "desequivocar",
    "desequivocásseis": "desequivocar",
    "desequivocássemos": "desequivocar",
    "desequivocávamo": "desequivocar",
    "desequivocávamos": "desequivocar",
    "desequivocávei": "desequivocar",
    "desequivocáveis": "desequivocar",
    "desequivoque": "desequivocar",
    "desequivoquei": "desequivocar",
    "desequivoqueis": "desequivocar",
    "desequivoquem": "desequivocar",
    "desequivoquemo": "desequivocar",
    "desequivoquemos": "desequivocar",
    "desequivoques": "desequivocar",
    "deserda": "deserdar",
    "deserdada": "deserdar",
    "deserdadas": "deserdar",
    "deserdado": "deserdar",
    "deserdados": "deserdar",
    "deserdai": "deserdar",
    "deserdais": "deserdar",
    "deserdam": "deserdar",
    "deserdamo": "deserdar",
    "deserdamos": "deserdar",
    "deserdando": "deserdar",
    "deserdara": "deserdar",
    "deserdaram": "deserdar",
    "deserdaras": "deserdar",
    "deserdarde": "deserdar",
    "deserdardes": "deserdar",
    "deserdare": "deserdar",
    "deserdarei": "deserdar",
    "deserdareis": "deserdar",
    "deserdarem": "deserdar",
    "deserdaremos": "deserdar",
    "deserdares": "deserdar",
    "deserdaria": "deserdar",
    "deserdariam": "deserdar",
    "deserdarias": "deserdar",
    "deserdarmo": "deserdar",
    "deserdarmos": "deserdar",
    "deserdará": "deserdar",
    "deserdarás": "deserdar",
    "deserdarão": "deserdar",
    "deserdaríamos": "deserdar",
    "deserdaríeis": "deserdar",
    "deserdas": "deserdar",
    "deserdasse": "deserdar",
    "deserdassem": "deserdar",
    "deserdasses": "deserdar",
    "deserdaste": "deserdar",
    "deserdastes": "deserdar",
    "deserdava": "deserdar",
    "deserdavam": "deserdar",
    "deserdavas": "deserdar",
    "deserdações": "deserdação",
    "deserde": "deserdar",
    "deserdei": "deserdar",
    "deserdeis": "deserdar",
    "deserdem": "deserdar",
    "deserdemo": "deserdar",
    "deserdemos": "deserdar",
    "deserdes": "deserdar",
    "deserdo": "deserdar",
    "deserdou": "deserdar",
    "deserdá": "deserdar",
    "deserdámo": "deserdar",
    "deserdámos": "deserdar",
    "deserdáramo": "deserdar",
    "deserdáramos": "deserdar",
    "deserdárei": "deserdar",
    "deserdáreis": "deserdar",
    "deserdásseis": "deserdar",
    "deserdássemos": "deserdar",
    "deserdávamo": "deserdar",
    "deserdávamos": "deserdar",
    "deserdávei": "deserdar",
    "deserdáveis": "deserdável",
    "deserta": "desertar",
    "desertada": "desertar",
    "desertadas": "desertar",
    "desertado": "desertar",
    "desertados": "desertar",
    "desertai": "desertar",
    "desertais": "desertar",
    "desertam": "desertar",
    "desertamo": "desertar",
    "desertamos": "desertar",
    "desertando": "desertar",
    "desertara": "desertar",
    "desertaram": "desertar",
    "desertaras": "desertar",
    "desertardes": "desertar",
    "desertarei": "desertar",
    "desertareis": "desertar",
    "desertarem": "desertar",
    "desertaremos": "desertar",
    "desertares": "desertar",
    "desertaria": "desertar",
    "desertariam": "desertar",
    "desertarias": "desertar",
    "desertarmo": "desertar",
    "desertarmos": "desertar",
    "desertará": "desertar",
    "desertarás": "desertar",
    "desertarão": "desertar",
    "desertaríamos": "desertar",
    "desertaríeis": "desertar",
    "desertas": "desertar",
    "desertasse": "desertar",
    "desertassem": "desertar",
    "desertasses": "desertar",
    "desertaste": "desertar",
    "desertastes": "desertar",
    "desertava": "desertar",
    "desertavam": "desertar",
    "desertavas": "desertar",
    "deserte": "desertar",
    "desertei": "desertar",
    "deserteis": "desertar",
    "desertem": "desertar",
    "desertemo": "desertar",
    "desertemos": "desertar",
    "desertes": "desertar",
    "desertifica": "desertificar",
    "desertificada": "desertificar",
    "desertificadas": "desertificar",
    "desertificado": "desertificar",
    "desertificados": "desertificar",
    "desertificai": "desertificar",
    "desertificais": "desertificar",
    "desertificam": "desertificar",
    "desertificamo": "desertificar",
    "desertificamos": "desertificar",
    "desertificando": "desertificar",
    "desertificara": "desertificar",
    "desertificaram": "desertificar",
    "desertificaras": "desertificar",
    "desertificarde": "desertificar",
    "desertificardes": "desertificar",
    "desertificare": "desertificar",
    "desertificarei": "desertificar",
    "desertificareis": "desertificar",
    "desertificarem": "desertificar",
    "desertificaremos": "desertificar",
    "desertificares": "desertificar",
    "desertificaria": "desertificar",
    "desertificariam": "desertificar",
    "desertificarias": "desertificar",
    "desertificarmo": "desertificar",
    "desertificarmos": "desertificar",
    "desertificará": "desertificar",
    "desertificarás": "desertificar",
    "desertificarão": "desertificar",
    "desertificaríamos": "desertificar",
    "desertificaríeis": "desertificar",
    "desertificas": "desertificar",
    "desertificasse": "desertificar",
    "desertificassem": "desertificar",
    "desertificasses": "desertificar",
    "desertificaste": "desertificar",
    "desertificastes": "desertificar",
    "desertificava": "desertificar",
    "desertificavam": "desertificar",
    "desertificavas": "desertificar",
    "desertificações": "desertificação",
    "desertifico": "desertificar",
    "desertificou": "desertificar",
    "desertificá": "desertificar",
    "desertificámo": "desertificar",
    "desertificámos": "desertificar",
    "desertificáramo": "desertificar",
    "desertificáramos": "desertificar",
    "desertificárei": "desertificar",
    "desertificáreis": "desertificar",
    "desertificásseis": "desertificar",
    "desertificássemos": "desertificar",
    "desertificávamo": "desertificar",
    "desertificávamos": "desertificar",
    "desertificávei": "desertificar",
    "desertificáveis": "desertificar",
    "desertifique": "desertificar",
    "desertifiquei": "desertificar",
    "desertifiqueis": "desertificar",
    "desertifiquem": "desertificar",
    "desertifiquemo": "desertificar",
    "desertifiquemos": "desertificar",
    "desertifiques": "desertificar",
    "deserto": "desertar",
    "desertora": "desertor",
    "desertoras": "desertor",
    "desertores": "desertor",
    "desertos": "deserto",
    "desertou": "desertar",
    "desertámo": "desertar",
    "desertámos": "desertar",
    "desertáramo": "desertar",
    "desertáramos": "desertar",
    "desertáreis": "desertar",
    "desertásseis": "desertar",
    "desertássemos": "desertar",
    "desertávamo": "desertar",
    "desertávamos": "desertar",
    "desertáveis": "desertar",
    "desertícolas": "desertícola",
    "deserções": "deserção",
    "desespanholizáveis": "desespanholizável",
    "desespartilha": "desespartilhar",
    "desespartilhada": "desespartilhar",
    "desespartilhadas": "desespartilhar",
    "desespartilhado": "desespartilhar",
    "desespartilhados": "desespartilhar",
    "desespartilhai": "desespartilhar",
    "desespartilhais": "desespartilhar",
    "desespartilham": "desespartilhar",
    "desespartilhamo": "desespartilhar",
    "desespartilhamos": "desespartilhar",
    "desespartilhando": "desespartilhar",
    "desespartilhara": "desespartilhar",
    "desespartilharam": "desespartilhar",
    "desespartilharas": "desespartilhar",
    "desespartilharde": "desespartilhar",
    "desespartilhardes": "desespartilhar",
    "desespartilhare": "desespartilhar",
    "desespartilharei": "desespartilhar",
    "desespartilhareis": "desespartilhar",
    "desespartilharem": "desespartilhar",
    "desespartilharemos": "desespartilhar",
    "desespartilhares": "desespartilhar",
    "desespartilharia": "desespartilhar",
    "desespartilhariam": "desespartilhar",
    "desespartilharias": "desespartilhar",
    "desespartilharmo": "desespartilhar",
    "desespartilharmos": "desespartilhar",
    "desespartilhará": "desespartilhar",
    "desespartilharás": "desespartilhar",
    "desespartilharão": "desespartilhar",
    "desespartilharíamos": "desespartilhar",
    "desespartilharíeis": "desespartilhar",
    "desespartilhas": "desespartilhar",
    "desespartilhasse": "desespartilhar",
    "desespartilhassem": "desespartilhar",
    "desespartilhasses": "desespartilhar",
    "desespartilhaste": "desespartilhar",
    "desespartilhastes": "desespartilhar",
    "desespartilhava": "desespartilhar",
    "desespartilhavam": "desespartilhar",
    "desespartilhavas": "desespartilhar",
    "desespartilhe": "desespartilhar",
    "desespartilhei": "desespartilhar",
    "desespartilheis": "desespartilhar",
    "desespartilhem": "desespartilhar",
    "desespartilhemo": "desespartilhar",
    "desespartilhemos": "desespartilhar",
    "desespartilhes": "desespartilhar",
    "desespartilho": "desespartilhar",
    "desespartilhou": "desespartilhar",
    "desespartilhá": "desespartilhar",
    "desespartilhámo": "desespartilhar",
    "desespartilhámos": "desespartilhar",
    "desespartilháramo": "desespartilhar",
    "desespartilháramos": "desespartilhar",
    "desespartilhárei": "desespartilhar",
    "desespartilháreis": "desespartilhar",
    "desespartilhásseis": "desespartilhar",
    "desespartilhássemos": "desespartilhar",
    "desespartilhávamo": "desespartilhar",
    "desespartilhávamos": "desespartilhar",
    "desespartilhávei": "desespartilhar",
    "desespartilháveis": "desespartilhar",
    "desespera": "desesperar",
    "desesperada": "desesperar",
    "desesperadas": "desesperar",
    "desesperado": "desesperar",
    "desesperadora": "desesperador",
    "desesperadoras": "desesperador",
    "desesperadores": "desesperador",
    "desesperados": "desesperar",
    "desesperadíssima": "desesperado",
    "desesperadíssimas": "desesperado",
    "desesperadíssimo": "desesperado",
    "desesperadíssimos": "desesperado",
    "desesperai": "desesperar",
    "desesperais": "desesperar",
    "desesperam": "desesperar",
    "desesperamo": "desesperar",
    "desesperamos": "desesperar",
    "desesperando": "desesperar",
    "desesperantes": "desesperante",
    "desesperançada": "desesperançado",
    "desesperançadas": "desesperançado",
    "desesperançados": "desesperançado",
    "desesperanças": "desesperança",
    "desesperara": "desesperar",
    "desesperaram": "desesperar",
    "desesperaras": "desesperar",
    "desesperarde": "desesperar",
    "desesperardes": "desesperar",
    "desesperare": "desesperar",
    "desesperarei": "desesperar",
    "desesperareis": "desesperar",
    "desesperarem": "desesperar",
    "desesperaremos": "desesperar",
    "desesperares": "desesperar",
    "desesperaria": "desesperar",
    "desesperariam": "desesperar",
    "desesperarias": "desesperar",
    "desesperarmo": "desesperar",
    "desesperarmos": "desesperar",
    "desesperará": "desesperar",
    "desesperarás": "desesperar",
    "desesperarão": "desesperar",
    "desesperaríamos": "desesperar",
    "desesperaríeis": "desesperar",
    "desesperas": "desesperar",
    "desesperasse": "desesperar",
    "desesperassem": "desesperar",
    "desesperasses": "desesperar",
    "desesperaste": "desesperar",
    "desesperastes": "desesperar",
    "desesperativa": "desesperativo",
    "desesperativas": "desesperativo",
    "desesperativos": "desesperativo",
    "desesperava": "desesperar",
    "desesperavam": "desesperar",
    "desesperavas": "desesperar",
    "desesperações": "desesperação",
    "desespere": "desesperar",
    "desesperei": "desesperar",
    "desespereis": "desesperar",
    "desesperem": "desesperar",
    "desesperemo": "desesperar",
    "desesperemos": "desesperar",
    "desesperes": "desesperar",
    "desespero": "desesperar",
    "desesperos": "desespero",
    "desesperou": "desesperar",
    "desesperá": "desesperar",
    "desesperámo": "desesperar",
    "desesperámos": "desesperar",
    "desesperáramo": "desesperar",
    "desesperáramos": "desesperar",
    "desesperárei": "desesperar",
    "desesperáreis": "desesperar",
    "desesperásseis": "desesperar",
    "desesperássemos": "desesperar",
    "desesperávamo": "desesperar",
    "desesperávamos": "desesperar",
    "desesperávei": "desesperar",
    "desesperáveis": "desesperar",
    "desespinha": "desespinhar",
    "desespinhada": "desespinhar",
    "desespinhadas": "desespinhar",
    "desespinhado": "desespinhar",
    "desespinhados": "desespinhar",
    "desespinhai": "desespinhar",
    "desespinhais": "desespinhar",
    "desespinham": "desespinhar",
    "desespinhamo": "desespinhar",
    "desespinhamos": "desespinhar",
    "desespinhando": "desespinhar",
    "desespinhara": "desespinhar",
    "desespinharam": "desespinhar",
    "desespinharas": "desespinhar",
    "desespinharde": "desespinhar",
    "desespinhardes": "desespinhar",
    "desespinhare": "desespinhar",
    "desespinharei": "desespinhar",
    "desespinhareis": "desespinhar",
    "desespinharem": "desespinhar",
    "desespinharemos": "desespinhar",
    "desespinhares": "desespinhar",
    "desespinharia": "desespinhar",
    "desespinhariam": "desespinhar",
    "desespinharias": "desespinhar",
    "desespinharmo": "desespinhar",
    "desespinharmos": "desespinhar",
    "desespinhará": "desespinhar",
    "desespinharás": "desespinhar",
    "desespinharão": "desespinhar",
    "desespinharíamos": "desespinhar",
    "desespinharíeis": "desespinhar",
    "desespinhas": "desespinhar",
    "desespinhasse": "desespinhar",
    "desespinhassem": "desespinhar",
    "desespinhasses": "desespinhar",
    "desespinhaste": "desespinhar",
    "desespinhastes": "desespinhar",
    "desespinhava": "desespinhar",
    "desespinhavam": "desespinhar",
    "desespinhavas": "desespinhar",
    "desespinhe": "desespinhar",
    "desespinhei": "desespinhar",
    "desespinheis": "desespinhar",
    "desespinhem": "desespinhar",
    "desespinhemo": "desespinhar",
    "desespinhemos": "desespinhar",
    "desespinhes": "desespinhar",
    "desespinho": "desespinhar",
    "desespinhou": "desespinhar",
    "desespinhá": "desespinhar",
    "desespinhámo": "desespinhar",
    "desespinhámos": "desespinhar",
    "desespinháramo": "desespinhar",
    "desespinháramos": "desespinhar",
    "desespinhárei": "desespinhar",
    "desespinháreis": "desespinhar",
    "desespinhásseis": "desespinhar",
    "desespinhássemos": "desespinhar",
    "desespinhávamo": "desespinhar",
    "desespinhávamos": "desespinhar",
    "desespinhávei": "desespinhar",
    "desespinháveis": "desespinhar",
    "desestabiliza": "desestabilizar",
    "desestabilizada": "desestabilizar",
    "desestabilizadas": "desestabilizar",
    "desestabilizado": "desestabilizar",
    "desestabilizadora": "desestabilizador",
    "desestabilizadoras": "desestabilizador",
    "desestabilizadores": "desestabilizador",
    "desestabilizados": "desestabilizar",
    "desestabilizai": "desestabilizar",
    "desestabilizais": "desestabilizar",
    "desestabilizam": "desestabilizar",
    "desestabilizamo": "desestabilizar",
    "desestabilizamos": "desestabilizar",
    "desestabilizando": "desestabilizar",
    "desestabilizara": "desestabilizar",
    "desestabilizaram": "desestabilizar",
    "desestabilizaras": "desestabilizar",
    "desestabilizarde": "desestabilizar",
    "desestabilizardes": "desestabilizar",
    "desestabilizare": "desestabilizar",
    "desestabilizarei": "desestabilizar",
    "desestabilizareis": "desestabilizar",
    "desestabilizarem": "desestabilizar",
    "desestabilizaremos": "desestabilizar",
    "desestabilizares": "desestabilizar",
    "desestabilizaria": "desestabilizar",
    "desestabilizariam": "desestabilizar",
    "desestabilizarias": "desestabilizar",
    "desestabilizarmo": "desestabilizar",
    "desestabilizarmos": "desestabilizar",
    "desestabilizará": "desestabilizar",
    "desestabilizarás": "desestabilizar",
    "desestabilizarão": "desestabilizar",
    "desestabilizaríamos": "desestabilizar",
    "desestabilizaríeis": "desestabilizar",
    "desestabilizas": "desestabilizar",
    "desestabilizasse": "desestabilizar",
    "desestabilizassem": "desestabilizar",
    "desestabilizasses": "desestabilizar",
    "desestabilizaste": "desestabilizar",
    "desestabilizastes": "desestabilizar",
    "desestabilizava": "desestabilizar",
    "desestabilizavam": "desestabilizar",
    "desestabilizavas": "desestabilizar",
    "desestabilizações": "desestabilização",
    "desestabilize": "desestabilizar",
    "desestabilizei": "desestabilizar",
    "desestabilizeis": "desestabilizar",
    "desestabilizem": "desestabilizar",
    "desestabilizemo": "desestabilizar",
    "desestabilizemos": "desestabilizar",
    "desestabilizes": "desestabilizar",
    "desestabilizo": "desestabilizar",
    "desestabilizou": "desestabilizar",
    "desestabilizá": "desestabilizar",
    "desestabilizámo": "desestabilizar",
    "desestabilizámos": "desestabilizar",
    "desestabilizáramo": "desestabilizar",
    "desestabilizáramos": "desestabilizar",
    "desestabilizárei": "desestabilizar",
    "desestabilizáreis": "desestabilizar",
    "desestabilizásseis": "desestabilizar",
    "desestabilizássemos": "desestabilizar",
    "desestabilizávamo": "desestabilizar",
    "desestabilizávamos": "desestabilizar",
    "desestabilizávei": "desestabilizar",
    "desestabilizáveis": "desestabilizável",
    "desestagna": "desestagnar",
    "desestagnada": "desestagnar",
    "desestagnadas": "desestagnar",
    "desestagnado": "desestagnar",
    "desestagnados": "desestagnar",
    "desestagnai": "desestagnar",
    "desestagnais": "desestagnar",
    "desestagnam": "desestagnar",
    "desestagnamo": "desestagnar",
    "desestagnamos": "desestagnar",
    "desestagnando": "desestagnar",
    "desestagnara": "desestagnar",
    "desestagnaram": "desestagnar",
    "desestagnaras": "desestagnar",
    "desestagnardes": "desestagnar",
    "desestagnarei": "desestagnar",
    "desestagnareis": "desestagnar",
    "desestagnarem": "desestagnar",
    "desestagnaremos": "desestagnar",
    "desestagnares": "desestagnar",
    "desestagnaria": "desestagnar",
    "desestagnariam": "desestagnar",
    "desestagnarias": "desestagnar",
    "desestagnarmo": "desestagnar",
    "desestagnarmos": "desestagnar",
    "desestagnará": "desestagnar",
    "desestagnarás": "desestagnar",
    "desestagnarão": "desestagnar",
    "desestagnaríamos": "desestagnar",
    "desestagnaríeis": "desestagnar",
    "desestagnas": "desestagnar",
    "desestagnasse": "desestagnar",
    "desestagnassem": "desestagnar",
    "desestagnasses": "desestagnar",
    "desestagnaste": "desestagnar",
    "desestagnastes": "desestagnar",
    "desestagnava": "desestagnar",
    "desestagnavam": "desestagnar",
    "desestagnavas": "desestagnar",
    "desestagnações": "desestagnação",
    "desestagne": "desestagnar",
    "desestagnei": "desestagnar",
    "desestagneis": "desestagnar",
    "desestagnem": "desestagnar",
    "desestagnemo": "desestagnar",
    "desestagnemos": "desestagnar",
    "desestagnes": "desestagnar",
    "desestagno": "desestagnar",
    "desestagnou": "desestagnar",
    "desestagnámo": "desestagnar",
    "desestagnámos": "desestagnar",
    "desestagnáramo": "desestagnar",
    "desestagnáramos": "desestagnar",
    "desestagnáreis": "desestagnar",
    "desestagnásseis": "desestagnar",
    "desestagnássemos": "desestagnar",
    "desestagnávamo": "desestagnar",
    "desestagnávamos": "desestagnar",
    "desestagnáveis": "desestagnar",
    "desestalinizações": "desestalinização",
    "desestatizações": "desestatização",
    "desesteira": "desesteirar",
    "desesteirada": "desesteirar",
    "desesteiradas": "desesteirar",
    "desesteirado": "desesteirar",
    "desesteirados": "desesteirar",
    "desesteirai": "desesteirar",
    "desesteirais": "desesteirar",
    "desesteiram": "desesteirar",
    "desesteiramo": "desesteirar",
    "desesteiramos": "desesteirar",
    "desesteirando": "desesteirar",
    "desesteirara": "desesteirar",
    "desesteiraram": "desesteirar",
    "desesteiraras": "desesteirar",
    "desesteirarde": "desesteirar",
    "desesteirardes": "desesteirar",
    "desesteirare": "desesteirar",
    "desesteirarei": "desesteirar",
    "desesteirareis": "desesteirar",
    "desesteirarem": "desesteirar",
    "desesteiraremos": "desesteirar",
    "desesteirares": "desesteirar",
    "desesteiraria": "desesteirar",
    "desesteirariam": "desesteirar",
    "desesteirarias": "desesteirar",
    "desesteirarmo": "desesteirar",
    "desesteirarmos": "desesteirar",
    "desesteirará": "desesteirar",
    "desesteirarás": "desesteirar",
    "desesteirarão": "desesteirar",
    "desesteiraríamos": "desesteirar",
    "desesteiraríeis": "desesteirar",
    "desesteiras": "desesteirar",
    "desesteirasse": "desesteirar",
    "desesteirassem": "desesteirar",
    "desesteirasses": "desesteirar",
    "desesteiraste": "desesteirar",
    "desesteirastes": "desesteirar",
    "desesteirava": "desesteirar",
    "desesteiravam": "desesteirar",
    "desesteiravas": "desesteirar",
    "desesteire": "desesteirar",
    "desesteirei": "desesteirar",
    "desesteireis": "desesteirar",
    "desesteirem": "desesteirar",
    "desesteiremo": "desesteirar",
    "desesteiremos": "desesteirar",
    "desesteires": "desesteirar",
    "desesteiro": "desesteirar",
    "desesteirou": "desesteirar",
    "desesteirá": "desesteirar",
    "desesteirámo": "desesteirar",
    "desesteirámos": "desesteirar",
    "desesteiráramo": "desesteirar",
    "desesteiráramos": "desesteirar",
    "desesteirárei": "desesteirar",
    "desesteiráreis": "desesteirar",
    "desesteirásseis": "desesteirar",
    "desesteirássemos": "desesteirar",
    "desesteirávamo": "desesteirar",
    "desesteirávamos": "desesteirar",
    "desesteirávei": "desesteirar",
    "desesteiráveis": "desesteirar",
    "desestima": "desestimar",
    "desestimada": "desestimar",
    "desestimadas": "desestimar",
    "desestimado": "desestimar",
    "desestimadora": "desestimador",
    "desestimadoras": "desestimador",
    "desestimadores": "desestimador",
    "desestimados": "desestimar",
    "desestimai": "desestimar",
    "desestimais": "desestimar",
    "desestimam": "desestimar",
    "desestimamo": "desestimar",
    "desestimamos": "desestimar",
    "desestimando": "desestimar",
    "desestimara": "desestimar",
    "desestimaram": "desestimar",
    "desestimaras": "desestimar",
    "desestimarde": "desestimar",
    "desestimardes": "desestimar",
    "desestimare": "desestimar",
    "desestimarei": "desestimar",
    "desestimareis": "desestimar",
    "desestimarem": "desestimar",
    "desestimaremos": "desestimar",
    "desestimares": "desestimar",
    "desestimaria": "desestimar",
    "desestimariam": "desestimar",
    "desestimarias": "desestimar",
    "desestimarmo": "desestimar",
    "desestimarmos": "desestimar",
    "desestimará": "desestimar",
    "desestimarás": "desestimar",
    "desestimarão": "desestimar",
    "desestimaríamos": "desestimar",
    "desestimaríeis": "desestimar",
    "desestimas": "desestimar",
    "desestimasse": "desestimar",
    "desestimassem": "desestimar",
    "desestimasses": "desestimar",
    "desestimaste": "desestimar",
    "desestimastes": "desestimar",
    "desestimava": "desestimar",
    "desestimavam": "desestimar",
    "desestimavas": "desestimar",
    "desestimações": "desestimação",
    "desestime": "desestimar",
    "desestimei": "desestimar",
    "desestimeis": "desestimar",
    "desestimem": "desestimar",
    "desestimemo": "desestimar",
    "desestimemos": "desestimar",
    "desestimes": "desestimar",
    "desestimo": "desestimar",
    "desestimou": "desestimar",
    "desestimulos": "desestimulo",
    "desestimá": "desestimar",
    "desestimámo": "desestimar",
    "desestimámos": "desestimar",
    "desestimáramo": "desestimar",
    "desestimáramos": "desestimar",
    "desestimárei": "desestimar",
    "desestimáreis": "desestimar",
    "desestimásseis": "desestimar",
    "desestimássemos": "desestimar",
    "desestimávamo": "desestimar",
    "desestimávamos": "desestimar",
    "desestimávei": "desestimar",
    "desestimáveis": "desestimável",
    "desestorva": "desestorvar",
    "desestorvada": "desestorvar",
    "desestorvadas": "desestorvar",
    "desestorvado": "desestorvar",
    "desestorvados": "desestorvar",
    "desestorvai": "desestorvar",
    "desestorvais": "desestorvar",
    "desestorvam": "desestorvar",
    "desestorvamo": "desestorvar",
    "desestorvamos": "desestorvar",
    "desestorvando": "desestorvar",
    "desestorvara": "desestorvar",
    "desestorvaram": "desestorvar",
    "desestorvaras": "desestorvar",
    "desestorvardes": "desestorvar",
    "desestorvarei": "desestorvar",
    "desestorvareis": "desestorvar",
    "desestorvarem": "desestorvar",
    "desestorvaremos": "desestorvar",
    "desestorvares": "desestorvar",
    "desestorvaria": "desestorvar",
    "desestorvariam": "desestorvar",
    "desestorvarias": "desestorvar",
    "desestorvarmo": "desestorvar",
    "desestorvarmos": "desestorvar",
    "desestorvará": "desestorvar",
    "desestorvarás": "desestorvar",
    "desestorvarão": "desestorvar",
    "desestorvaríamos": "desestorvar",
    "desestorvaríeis": "desestorvar",
    "desestorvas": "desestorvar",
    "desestorvasse": "desestorvar",
    "desestorvassem": "desestorvar",
    "desestorvasses": "desestorvar",
    "desestorvaste": "desestorvar",
    "desestorvastes": "desestorvar",
    "desestorvava": "desestorvar",
    "desestorvavam": "desestorvar",
    "desestorvavas": "desestorvar",
    "desestorve": "desestorvar",
    "desestorvei": "desestorvar",
    "desestorveis": "desestorvar",
    "desestorvem": "desestorvar",
    "desestorvemo": "desestorvar",
    "desestorvemos": "desestorvar",
    "desestorves": "desestorvar",
    "desestorvo": "desestorvar",
    "desestorvos": "desestorvo",
    "desestorvou": "desestorvar",
    "desestorvámo": "desestorvar",
    "desestorvámos": "desestorvar",
    "desestorváramo": "desestorvar",
    "desestorváramos": "desestorvar",
    "desestorváreis": "desestorvar",
    "desestorvásseis": "desestorvar",
    "desestorvássemos": "desestorvar",
    "desestorvávamo": "desestorvar",
    "desestorvávamos": "desestorvar",
    "desestorváveis": "desestorvar",
    "desestriba": "desestribar",
    "desestribada": "desestribar",
    "desestribadas": "desestribar",
    "desestribado": "desestribar",
    "desestribados": "desestribar",
    "desestribai": "desestribar",
    "desestribais": "desestribar",
    "desestribam": "desestribar",
    "desestribamo": "desestribar",
    "desestribamos": "desestribar",
    "desestribando": "desestribar",
    "desestribara": "desestribar",
    "desestribaram": "desestribar",
    "desestribaras": "desestribar",
    "desestribarde": "desestribar",
    "desestribardes": "desestribar",
    "desestribare": "desestribar",
    "desestribarei": "desestribar",
    "desestribareis": "desestribar",
    "desestribarem": "desestribar",
    "desestribaremos": "desestribar",
    "desestribares": "desestribar",
    "desestribaria": "desestribar",
    "desestribariam": "desestribar",
    "desestribarias": "desestribar",
    "desestribarmo": "desestribar",
    "desestribarmos": "desestribar",
    "desestribará": "desestribar",
    "desestribarás": "desestribar",
    "desestribarão": "desestribar",
    "desestribaríamos": "desestribar",
    "desestribaríeis": "desestribar",
    "desestribas": "desestribar",
    "desestribasse": "desestribar",
    "desestribassem": "desestribar",
    "desestribasses": "desestribar",
    "desestribaste": "desestribar",
    "desestribastes": "desestribar",
    "desestribava": "desestribar",
    "desestribavam": "desestribar",
    "desestribavas": "desestribar",
    "desestribe": "desestribar",
    "desestribei": "desestribar",
    "desestribeis": "desestribar",
    "desestribem": "desestribar",
    "desestribemo": "desestribar",
    "desestribemos": "desestribar",
    "desestribes": "desestribar",
    "desestribo": "desestribar",
    "desestribou": "desestribar",
    "desestribá": "desestribar",
    "desestribámo": "desestribar",
    "desestribámos": "desestribar",
    "desestribáramo": "desestribar",
    "desestribáramos": "desestribar",
    "desestribárei": "desestribar",
    "desestribáreis": "desestribar",
    "desestribásseis": "desestribar",
    "desestribássemos": "desestribar",
    "desestribávamo": "desestribar",
    "desestribávamos": "desestribar",
    "desestribávei": "desestribar",
    "desestribáveis": "desestribar",
    "desestrutura": "desestruturar",
    "desestruturada": "desestruturar",
    "desestruturadas": "desestruturar",
    "desestruturado": "desestruturar",
    "desestruturados": "desestruturar",
    "desestruturai": "desestruturar",
    "desestruturais": "desestruturar",
    "desestruturam": "desestruturar",
    "desestruturamo": "desestruturar",
    "desestruturamos": "desestruturar",
    "desestruturando": "desestruturar",
    "desestruturara": "desestruturar",
    "desestruturaram": "desestruturar",
    "desestruturaras": "desestruturar",
    "desestruturarde": "desestruturar",
    "desestruturardes": "desestruturar",
    "desestruturare": "desestruturar",
    "desestruturarei": "desestruturar",
    "desestruturareis": "desestruturar",
    "desestruturarem": "desestruturar",
    "desestruturaremos": "desestruturar",
    "desestruturares": "desestruturar",
    "desestruturaria": "desestruturar",
    "desestruturariam": "desestruturar",
    "desestruturarias": "desestruturar",
    "desestruturarmo": "desestruturar",
    "desestruturarmos": "desestruturar",
    "desestruturará": "desestruturar",
    "desestruturarás": "desestruturar",
    "desestruturarão": "desestruturar",
    "desestruturaríamos": "desestruturar",
    "desestruturaríeis": "desestruturar",
    "desestruturas": "desestruturar",
    "desestruturasse": "desestruturar",
    "desestruturassem": "desestruturar",
    "desestruturasses": "desestruturar",
    "desestruturaste": "desestruturar",
    "desestruturastes": "desestruturar",
    "desestruturava": "desestruturar",
    "desestruturavam": "desestruturar",
    "desestruturavas": "desestruturar",
    "desestruturações": "desestruturação",
    "desestruture": "desestruturar",
    "desestruturei": "desestruturar",
    "desestrutureis": "desestruturar",
    "desestruturem": "desestruturar",
    "desestruturemo": "desestruturar",
    "desestruturemos": "desestruturar",
    "desestrutures": "desestruturar",
    "desestruturo": "desestruturar",
    "desestruturou": "desestruturar",
    "desestruturá": "desestruturar",
    "desestruturámo": "desestruturar",
    "desestruturámos": "desestruturar",
    "desestruturáramo": "desestruturar",
    "desestruturáramos": "desestruturar",
    "desestruturárei": "desestruturar",
    "desestruturáreis": "desestruturar",
    "desestruturásseis": "desestruturar",
    "desestruturássemos": "desestruturar",
    "desestruturávamo": "desestruturar",
    "desestruturávamos": "desestruturar",
    "desestruturávei": "desestruturar",
    "desestruturáveis": "desestruturar",
    "desestuda": "desestudar",
    "desestudada": "desestudar",
    "desestudadas": "desestudar",
    "desestudado": "desestudar",
    "desestudados": "desestudar",
    "desestudai": "desestudar",
    "desestudais": "desestudar",
    "desestudam": "desestudar",
    "desestudamo": "desestudar",
    "desestudamos": "desestudar",
    "desestudando": "desestudar",
    "desestudara": "desestudar",
    "desestudaram": "desestudar",
    "desestudaras": "desestudar",
    "desestudarde": "desestudar",
    "desestudardes": "desestudar",
    "desestudare": "desestudar",
    "desestudarei": "desestudar",
    "desestudareis": "desestudar",
    "desestudarem": "desestudar",
    "desestudaremos": "desestudar",
    "desestudares": "desestudar",
    "desestudaria": "desestudar",
    "desestudariam": "desestudar",
    "desestudarias": "desestudar",
    "desestudarmo": "desestudar",
    "desestudarmos": "desestudar",
    "desestudará": "desestudar",
    "desestudarás": "desestudar",
    "desestudarão": "desestudar",
    "desestudaríamos": "desestudar",
    "desestudaríeis": "desestudar",
    "desestudas": "desestudar",
    "desestudasse": "desestudar",
    "desestudassem": "desestudar",
    "desestudasses": "desestudar",
    "desestudaste": "desestudar",
    "desestudastes": "desestudar",
    "desestudava": "desestudar",
    "desestudavam": "desestudar",
    "desestudavas": "desestudar",
    "desestude": "desestudar",
    "desestudei": "desestudar",
    "desestudeis": "desestudar",
    "desestudem": "desestudar",
    "desestudemo": "desestudar",
    "desestudemos": "desestudar",
    "desestudes": "desestudar",
    "desestudo": "desestudar",
    "desestudou": "desestudar",
    "desestudá": "desestudar",
    "desestudámo": "desestudar",
    "desestudámos": "desestudar",
    "desestudáramo": "desestudar",
    "desestudáramos": "desestudar",
    "desestudárei": "desestudar",
    "desestudáreis": "desestudar",
    "desestudásseis": "desestudar",
    "desestudássemos": "desestudar",
    "desestudávamo": "desestudar",
    "desestudávamos": "desestudar",
    "desestudávei": "desestudar",
    "desestudáveis": "desestudar",
    "desevangeliza": "desevangelizar",
    "desevangelizada": "desevangelizar",
    "desevangelizadas": "desevangelizar",
    "desevangelizado": "desevangelizar",
    "desevangelizadora": "desevangelizador",
    "desevangelizadoras": "desevangelizador",
    "desevangelizadores": "desevangelizador",
    "desevangelizados": "desevangelizar",
    "desevangelizai": "desevangelizar",
    "desevangelizais": "desevangelizar",
    "desevangelizam": "desevangelizar",
    "desevangelizamo": "desevangelizar",
    "desevangelizamos": "desevangelizar",
    "desevangelizando": "desevangelizar",
    "desevangelizara": "desevangelizar",
    "desevangelizaram": "desevangelizar",
    "desevangelizaras": "desevangelizar",
    "desevangelizarde": "desevangelizar",
    "desevangelizardes": "desevangelizar",
    "desevangelizare": "desevangelizar",
    "desevangelizarei": "desevangelizar",
    "desevangelizareis": "desevangelizar",
    "desevangelizarem": "desevangelizar",
    "desevangelizaremos": "desevangelizar",
    "desevangelizares": "desevangelizar",
    "desevangelizaria": "desevangelizar",
    "desevangelizariam": "desevangelizar",
    "desevangelizarias": "desevangelizar",
    "desevangelizarmo": "desevangelizar",
    "desevangelizarmos": "desevangelizar",
    "desevangelizará": "desevangelizar",
    "desevangelizarás": "desevangelizar",
    "desevangelizarão": "desevangelizar",
    "desevangelizaríamos": "desevangelizar",
    "desevangelizaríeis": "desevangelizar",
    "desevangelizas": "desevangelizar",
    "desevangelizasse": "desevangelizar",
    "desevangelizassem": "desevangelizar",
    "desevangelizasses": "desevangelizar",
    "desevangelizaste": "desevangelizar",
    "desevangelizastes": "desevangelizar",
    "desevangelizava": "desevangelizar",
    "desevangelizavam": "desevangelizar",
    "desevangelizavas": "desevangelizar",
    "desevangelize": "desevangelizar",
    "desevangelizei": "desevangelizar",
    "desevangelizeis": "desevangelizar",
    "desevangelizem": "desevangelizar",
    "desevangelizemo": "desevangelizar",
    "desevangelizemos": "desevangelizar",
    "desevangelizes": "desevangelizar",
    "desevangelizo": "desevangelizar",
    "desevangelizou": "desevangelizar",
    "desevangelizá": "desevangelizar",
    "desevangelizámo": "desevangelizar",
    "desevangelizámos": "desevangelizar",
    "desevangelizáramo": "desevangelizar",
    "desevangelizáramos": "desevangelizar",
    "desevangelizárei": "desevangelizar",
    "desevangelizáreis": "desevangelizar",
    "desevangelizásseis": "desevangelizar",
    "desevangelizássemos": "desevangelizar",
    "desevangelizávamo": "desevangelizar",
    "desevangelizávamos": "desevangelizar",
    "desevangelizávei": "desevangelizar",
    "desevangelizáveis": "desevangelizar",
    "desexcomunga": "desexcomungar",
    "desexcomungada": "desexcomungar",
    "desexcomungadas": "desexcomungar",
    "desexcomungado": "desexcomungar",
    "desexcomungados": "desexcomungar",
    "desexcomungai": "desexcomungar",
    "desexcomungais": "desexcomungar",
    "desexcomungam": "desexcomungar",
    "desexcomungamo": "desexcomungar",
    "desexcomungamos": "desexcomungar",
    "desexcomungando": "desexcomungar",
    "desexcomungara": "desexcomungar",
    "desexcomungaram": "desexcomungar",
    "desexcomungaras": "desexcomungar",
    "desexcomungarde": "desexcomungar",
    "desexcomungardes": "desexcomungar",
    "desexcomungare": "desexcomungar",
    "desexcomungarei": "desexcomungar",
    "desexcomungareis": "desexcomungar",
    "desexcomungarem": "desexcomungar",
    "desexcomungaremos": "desexcomungar",
    "desexcomungares": "desexcomungar",
    "desexcomungaria": "desexcomungar",
    "desexcomungariam": "desexcomungar",
    "desexcomungarias": "desexcomungar",
    "desexcomungarmo": "desexcomungar",
    "desexcomungarmos": "desexcomungar",
    "desexcomungará": "desexcomungar",
    "desexcomungarás": "desexcomungar",
    "desexcomungarão": "desexcomungar",
    "desexcomungaríamos": "desexcomungar",
    "desexcomungaríeis": "desexcomungar",
    "desexcomungas": "desexcomungar",
    "desexcomungasse": "desexcomungar",
    "desexcomungassem": "desexcomungar",
    "desexcomungasses": "desexcomungar",
    "desexcomungaste": "desexcomungar",
    "desexcomungastes": "desexcomungar",
    "desexcomungava": "desexcomungar",
    "desexcomungavam": "desexcomungar",
    "desexcomungavas": "desexcomungar",
    "desexcomungo": "desexcomungar",
    "desexcomungou": "desexcomungar",
    "desexcomungue": "desexcomungar",
    "desexcomunguei": "desexcomungar",
    "desexcomungueis": "desexcomungar",
    "desexcomunguem": "desexcomungar",
    "desexcomunguemo": "desexcomungar",
    "desexcomunguemos": "desexcomungar",
    "desexcomungues": "desexcomungar",
    "desexcomungá": "desexcomungar",
    "desexcomungámo": "desexcomungar",
    "desexcomungámos": "desexcomungar",
    "desexcomungáramo": "desexcomungar",
    "desexcomungáramos": "desexcomungar",
    "desexcomungárei": "desexcomungar",
    "desexcomungáreis": "desexcomungar",
    "desexcomungásseis": "desexcomungar",
    "desexcomungássemos": "desexcomungar",
    "desexcomungávamo": "desexcomungar",
    "desexcomungávamos": "desexcomungar",
    "desexcomungávei": "desexcomungar",
    "desexcomungáveis": "desexcomungar",
    "desexcomunhões": "desexcomunhão",
    "desfabrica": "desfabricar",
    "desfabricada": "desfabricar",
    "desfabricadas": "desfabricar",
    "desfabricado": "desfabricar",
    "desfabricados": "desfabricar",
    "desfabricai": "desfabricar",
    "desfabricais": "desfabricar",
    "desfabricam": "desfabricar",
    "desfabricamo": "desfabricar",
    "desfabricamos": "desfabricar",
    "desfabricando": "desfabricar",
    "desfabricara": "desfabricar",
    "desfabricaram": "desfabricar",
    "desfabricaras": "desfabricar",
    "desfabricarde": "desfabricar",
    "desfabricardes": "desfabricar",
    "desfabricare": "desfabricar",
    "desfabricarei": "desfabricar",
    "desfabricareis": "desfabricar",
    "desfabricarem": "desfabricar",
    "desfabricaremos": "desfabricar",
    "desfabricares": "desfabricar",
    "desfabricaria": "desfabricar",
    "desfabricariam": "desfabricar",
    "desfabricarias": "desfabricar",
    "desfabricarmo": "desfabricar",
    "desfabricarmos": "desfabricar",
    "desfabricará": "desfabricar",
    "desfabricarás": "desfabricar",
    "desfabricarão": "desfabricar",
    "desfabricaríamos": "desfabricar",
    "desfabricaríeis": "desfabricar",
    "desfabricas": "desfabricar",
    "desfabricasse": "desfabricar",
    "desfabricassem": "desfabricar",
    "desfabricasses": "desfabricar",
    "desfabricaste": "desfabricar",
    "desfabricastes": "desfabricar",
    "desfabricava": "desfabricar",
    "desfabricavam": "desfabricar",
    "desfabricavas": "desfabricar",
    "desfabrico": "desfabricar",
    "desfabricou": "desfabricar",
    "desfabricá": "desfabricar",
    "desfabricámo": "desfabricar",
    "desfabricámos": "desfabricar",
    "desfabricáramo": "desfabricar",
    "desfabricáramos": "desfabricar",
    "desfabricárei": "desfabricar",
    "desfabricáreis": "desfabricar",
    "desfabricásseis": "desfabricar",
    "desfabricássemos": "desfabricar",
    "desfabricávamo": "desfabricar",
    "desfabricávamos": "desfabricar",
    "desfabricávei": "desfabricar",
    "desfabricáveis": "desfabricar",
    "desfabrique": "desfabricar",
    "desfabriquei": "desfabricar",
    "desfabriqueis": "desfabricar",
    "desfabriquem": "desfabricar",
    "desfabriquemo": "desfabricar",
    "desfabriquemos": "desfabricar",
    "desfabriques": "desfabricar",
    "desfabula": "desfabular",
    "desfabulada": "desfabular",
    "desfabuladas": "desfabular",
    "desfabulado": "desfabular",
    "desfabulados": "desfabular",
    "desfabulai": "desfabular",
    "desfabulais": "desfabular",
    "desfabulam": "desfabular",
    "desfabulamo": "desfabular",
    "desfabulamos": "desfabular",
    "desfabulando": "desfabular",
    "desfabulara": "desfabular",
    "desfabularam": "desfabular",
    "desfabularas": "desfabular",
    "desfabularde": "desfabular",
    "desfabulardes": "desfabular",
    "desfabulare": "desfabular",
    "desfabularei": "desfabular",
    "desfabulareis": "desfabular",
    "desfabularem": "desfabular",
    "desfabularemos": "desfabular",
    "desfabulares": "desfabular",
    "desfabularia": "desfabular",
    "desfabulariam": "desfabular",
    "desfabularias": "desfabular",
    "desfabularmo": "desfabular",
    "desfabularmos": "desfabular",
    "desfabulará": "desfabular",
    "desfabularás": "desfabular",
    "desfabularão": "desfabular",
    "desfabularíamos": "desfabular",
    "desfabularíeis": "desfabular",
    "desfabulas": "desfabular",
    "desfabulasse": "desfabular",
    "desfabulassem": "desfabular",
    "desfabulasses": "desfabular",
    "desfabulaste": "desfabular",
    "desfabulastes": "desfabular",
    "desfabulava": "desfabular",
    "desfabulavam": "desfabular",
    "desfabulavas": "desfabular",
    "desfabule": "desfabular",
    "desfabulei": "desfabular",
    "desfabuleis": "desfabular",
    "desfabulem": "desfabular",
    "desfabulemo": "desfabular",
    "desfabulemos": "desfabular",
    "desfabules": "desfabular",
    "desfabulo": "desfabular",
    "desfabulou": "desfabular",
    "desfabulá": "desfabular",
    "desfabulámo": "desfabular",
    "desfabulámos": "desfabular",
    "desfabuláramo": "desfabular",
    "desfabuláramos": "desfabular",
    "desfabulárei": "desfabular",
    "desfabuláreis": "desfabular",
    "desfabulásseis": "desfabular",
    "desfabulássemos": "desfabular",
    "desfabulávamo": "desfabular",
    "desfabulávamos": "desfabular",
    "desfabulávei": "desfabular",
    "desfabuláveis": "desfabular",
    "desface": "desfaçar",
    "desfacei": "desfaçar",
    "desfaceis": "desfaçar",
    "desfacem": "desfaçar",
    "desfacemo": "desfaçar",
    "desfacemos": "desfaçar",
    "desfaces": "desfaçar",
    "desfadiga": "desfadigar",
    "desfadigada": "desfadigar",
    "desfadigadas": "desfadigar",
    "desfadigado": "desfadigar",
    "desfadigados": "desfadigar",
    "desfadigai": "desfadigar",
    "desfadigais": "desfadigar",
    "desfadigam": "desfadigar",
    "desfadigamo": "desfadigar",
    "desfadigamos": "desfadigar",
    "desfadigando": "desfadigar",
    "desfadigara": "desfadigar",
    "desfadigaram": "desfadigar",
    "desfadigaras": "desfadigar",
    "desfadigarde": "desfadigar",
    "desfadigardes": "desfadigar",
    "desfadigare": "desfadigar",
    "desfadigarei": "desfadigar",
    "desfadigareis": "desfadigar",
    "desfadigarem": "desfadigar",
    "desfadigaremos": "desfadigar",
    "desfadigares": "desfadigar",
    "desfadigaria": "desfadigar",
    "desfadigariam": "desfadigar",
    "desfadigarias": "desfadigar",
    "desfadigarmo": "desfadigar",
    "desfadigarmos": "desfadigar",
    "desfadigará": "desfadigar",
    "desfadigarás": "desfadigar",
    "desfadigarão": "desfadigar",
    "desfadigaríamos": "desfadigar",
    "desfadigaríeis": "desfadigar",
    "desfadigas": "desfadigar",
    "desfadigasse": "desfadigar",
    "desfadigassem": "desfadigar",
    "desfadigasses": "desfadigar",
    "desfadigaste": "desfadigar",
    "desfadigastes": "desfadigar",
    "desfadigava": "desfadigar",
    "desfadigavam": "desfadigar",
    "desfadigavas": "desfadigar",
    "desfadigo": "desfadigar",
    "desfadigou": "desfadigar",
    "desfadigue": "desfadigar",
    "desfadiguei": "desfadigar",
    "desfadigueis": "desfadigar",
    "desfadiguem": "desfadigar",
    "desfadiguemo": "desfadigar",
    "desfadiguemos": "desfadigar",
    "desfadigues": "desfadigar",
    "desfadigá": "desfadigar",
    "desfadigámo": "desfadigar",
    "desfadigámos": "desfadigar",
    "desfadigáramo": "desfadigar",
    "desfadigáramos": "desfadigar",
    "desfadigárei": "desfadigar",
    "desfadigáreis": "desfadigar",
    "desfadigásseis": "desfadigar",
    "desfadigássemos": "desfadigar",
    "desfadigávamo": "desfadigar",
    "desfadigávamos": "desfadigar",
    "desfadigávei": "desfadigar",
    "desfadigáveis": "desfadigar",
    "desfaia": "desfaiar",
    "desfaiada": "desfaiar",
    "desfaiadas": "desfaiar",
    "desfaiado": "desfaiar",
    "desfaiados": "desfaiar",
    "desfaiai": "desfaiar",
    "desfaiais": "desfaiar",
    "desfaiam": "desfaiar",
    "desfaiamo": "desfaiar",
    "desfaiamos": "desfaiar",
    "desfaiando": "desfaiar",
    "desfaiara": "desfaiar",
    "desfaiaram": "desfaiar",
    "desfaiaras": "desfaiar",
    "desfaiarde": "desfaiar",
    "desfaiardes": "desfaiar",
    "desfaiare": "desfaiar",
    "desfaiarei": "desfaiar",
    "desfaiareis": "desfaiar",
    "desfaiarem": "desfaiar",
    "desfaiaremos": "desfaiar",
    "desfaiares": "desfaiar",
    "desfaiaria": "desfaiar",
    "desfaiariam": "desfaiar",
    "desfaiarias": "desfaiar",
    "desfaiarmo": "desfaiar",
    "desfaiarmos": "desfaiar",
    "desfaiará": "desfaiar",
    "desfaiarás": "desfaiar",
    "desfaiarão": "desfaiar",
    "desfaiaríamos": "desfaiar",
    "desfaiaríeis": "desfaiar",
    "desfaias": "desfaiar",
    "desfaiasse": "desfaiar",
    "desfaiassem": "desfaiar",
    "desfaiasses": "desfaiar",
    "desfaiaste": "desfaiar",
    "desfaiastes": "desfaiar",
    "desfaiava": "desfaiar",
    "desfaiavam": "desfaiar",
    "desfaiavas": "desfaiar",
    "desfaie": "desfaiar",
    "desfaiei": "desfaiar",
    "desfaieis": "desfaiar",
    "desfaiem": "desfaiar",
    "desfaiemo": "desfaiar",
    "desfaiemos": "desfaiar",
    "desfaies": "desfaiar",
    "desfaio": "desfaiar",
    "desfaiou": "desfaiar",
    "desfaiá": "desfaiar",
    "desfaiámo": "desfaiar",
    "desfaiámos": "desfaiar",
    "desfaiáramo": "desfaiar",
    "desfaiáramos": "desfaiar",
    "desfaiárei": "desfaiar",
    "desfaiáreis": "desfaiar",
    "desfaiásseis": "desfaiar",
    "desfaiássemos": "desfaiar",
    "desfaiávamo": "desfaiar",
    "desfaiávamos": "desfaiar",
    "desfaiávei": "desfaiar",
    "desfaiáveis": "desfaiar",
    "desfalca": "desfalcar",
    "desfalcace": "desfalcaçar",
    "desfalcacei": "desfalcaçar",
    "desfalcaceis": "desfalcaçar",
    "desfalcacem": "desfalcaçar",
    "desfalcacemo": "desfalcaçar",
    "desfalcacemos": "desfalcaçar",
    "desfalcaces": "desfalcaçar",
    "desfalcada": "desfalcar",
    "desfalcadas": "desfalcar",
    "desfalcado": "desfalcar",
    "desfalcados": "desfalcar",
    "desfalcai": "desfalcar",
    "desfalcais": "desfalcar",
    "desfalcam": "desfalcar",
    "desfalcamentos": "desfalcamento",
    "desfalcamo": "desfalcar",
    "desfalcamos": "desfalcar",
    "desfalcando": "desfalcar",
    "desfalcara": "desfalcar",
    "desfalcaram": "desfalcar",
    "desfalcaras": "desfalcar",
    "desfalcarde": "desfalcar",
    "desfalcardes": "desfalcar",
    "desfalcare": "desfalcar",
    "desfalcarei": "desfalcar",
    "desfalcareis": "desfalcar",
    "desfalcarem": "desfalcar",
    "desfalcaremos": "desfalcar",
    "desfalcares": "desfalcar",
    "desfalcaria": "desfalcar",
    "desfalcariam": "desfalcar",
    "desfalcarias": "desfalcar",
    "desfalcarmo": "desfalcar",
    "desfalcarmos": "desfalcar",
    "desfalcará": "desfalcar",
    "desfalcarás": "desfalcar",
    "desfalcarão": "desfalcar",
    "desfalcaríamos": "desfalcar",
    "desfalcaríeis": "desfalcar",
    "desfalcas": "desfalcar",
    "desfalcasse": "desfalcar",
    "desfalcassem": "desfalcar",
    "desfalcasses": "desfalcar",
    "desfalcaste": "desfalcar",
    "desfalcastes": "desfalcar",
    "desfalcava": "desfalcar",
    "desfalcavam": "desfalcar",
    "desfalcavas": "desfalcar",
    "desfalcaça": "desfalcaçar",
    "desfalcaçada": "desfalcaçar",
    "desfalcaçadas": "desfalcaçar",
    "desfalcaçado": "desfalcaçar",
    "desfalcaçados": "desfalcaçar",
    "desfalcaçai": "desfalcaçar",
    "desfalcaçais": "desfalcaçar",
    "desfalcaçam": "desfalcaçar",
    "desfalcaçamo": "desfalcaçar",
    "desfalcaçamos": "desfalcaçar",
    "desfalcaçando": "desfalcaçar",
    "desfalcaçara": "desfalcaçar",
    "desfalcaçaram": "desfalcaçar",
    "desfalcaçaras": "desfalcaçar",
    "desfalcaçarde": "desfalcaçar",
    "desfalcaçardes": "desfalcaçar",
    "desfalcaçare": "desfalcaçar",
    "desfalcaçarei": "desfalcaçar",
    "desfalcaçareis": "desfalcaçar",
    "desfalcaçarem": "desfalcaçar",
    "desfalcaçaremos": "desfalcaçar",
    "desfalcaçares": "desfalcaçar",
    "desfalcaçaria": "desfalcaçar",
    "desfalcaçariam": "desfalcaçar",
    "desfalcaçarias": "desfalcaçar",
    "desfalcaçarmo": "desfalcaçar",
    "desfalcaçarmos": "desfalcaçar",
    "desfalcaçará": "desfalcaçar",
    "desfalcaçarás": "desfalcaçar",
    "desfalcaçarão": "desfalcaçar",
    "desfalcaçaríamos": "desfalcaçar",
    "desfalcaçaríeis": "desfalcaçar",
    "desfalcaças": "desfalcaçar",
    "desfalcaçasse": "desfalcaçar",
    "desfalcaçassem": "desfalcaçar",
    "desfalcaçasses": "desfalcaçar",
    "desfalcaçaste": "desfalcaçar",
    "desfalcaçastes": "desfalcaçar",
    "desfalcaçava": "desfalcaçar",
    "desfalcaçavam": "desfalcaçar",
    "desfalcaçavas": "desfalcaçar",
    "desfalcaço": "desfalcaçar",
    "desfalcaçou": "desfalcaçar",
    "desfalcaçá": "desfalcaçar",
    "desfalcaçámo": "desfalcaçar",
    "desfalcaçámos": "desfalcaçar",
    "desfalcaçáramo": "desfalcaçar",
    "desfalcaçáramos": "desfalcaçar",
    "desfalcaçárei": "desfalcaçar",
    "desfalcaçáreis": "desfalcaçar",
    "desfalcaçásseis": "desfalcaçar",
    "desfalcaçássemos": "desfalcaçar",
    "desfalcaçávamo": "desfalcaçar",
    "desfalcaçávamos": "desfalcaçar",
    "desfalcaçávei": "desfalcaçar",
    "desfalcaçáveis": "desfalcaçar",
    "desfalco": "desfalcar",
    "desfalcou": "desfalcar",
    "desfalcá": "desfalcar",
    "desfalcámo": "desfalcar",
    "desfalcámos": "desfalcar",
    "desfalcáramo": "desfalcar",
    "desfalcáramos": "desfalcar",
    "desfalcárei": "desfalcar",
    "desfalcáreis": "desfalcar",
    "desfalcásseis": "desfalcar",
    "desfalcássemos": "desfalcar",
    "desfalcávamo": "desfalcar",
    "desfalcávamos": "desfalcar",
    "desfalcávei": "desfalcar",
    "desfalcáveis": "desfalcável",
    "desfalece": "desfalecer",
    "desfalecei": "desfalecer",
    "desfaleceis": "desfalecer",
    "desfalecem": "desfalecer",
    "desfalecemo": "desfalecer",
    "desfalecemos": "desfalecer",
    "desfalecendo": "desfalecer",
    "desfalecentes": "desfalecente",
    "desfalecera": "desfalecer",
    "desfaleceram": "desfalecer",
    "desfaleceras": "desfalecer",
    "desfalecerdes": "desfalecer",
    "desfalecerei": "desfalecer",
    "desfalecereis": "desfalecer",
    "desfalecerem": "desfalecer",
    "desfaleceremos": "desfalecer",
    "desfaleceres": "desfalecer",
    "desfaleceria": "desfalecer",
    "desfaleceriam": "desfalecer",
    "desfalecerias": "desfalecer",
    "desfalecermo": "desfalecer",
    "desfalecermos": "desfalecer",
    "desfalecerá": "desfalecer",
    "desfalecerás": "desfalecer",
    "desfalecerão": "desfalecer",
    "desfaleceríamos": "desfalecer",
    "desfaleceríeis": "desfalecer",
    "desfaleces": "desfalecer",
    "desfalecesse": "desfalecer",
    "desfalecessem": "desfalecer",
    "desfalecesses": "desfalecer",
    "desfaleceste": "desfalecer",
    "desfalecestes": "desfalecer",
    "desfaleceu": "desfalecer",
    "desfaleci": "desfalecer",
    "desfalecia": "desfalecer",
    "desfaleciam": "desfalecer",
    "desfalecias": "desfalecer",
    "desfalecida": "desfalecido",
    "desfalecidas": "desfalecido",
    "desfalecido": "desfalecer",
    "desfalecidos": "desfalecido",
    "desfalecimentos": "desfalecimento",
    "desfalecências": "desfalecência",
    "desfalecêramo": "desfalecer",
    "desfalecêramos": "desfalecer",
    "desfalecêreis": "desfalecer",
    "desfalecêsseis": "desfalecer",
    "desfalecêssemos": "desfalecer",
    "desfalecíamo": "desfalecer",
    "desfalecíamos": "desfalecer",
    "desfalecíeis": "desfalecer",
    "desfaleça": "desfalecer",
    "desfaleçais": "desfalecer",
    "desfaleçam": "desfalecer",
    "desfaleçamo": "desfalecer",
    "desfaleçamos": "desfalecer",
    "desfaleças": "desfalecer",
    "desfaleço": "desfalecer",
    "desfalque": "desfalcar",
    "desfalquei": "desfalcar",
    "desfalqueis": "desfalcar",
    "desfalquem": "desfalcar",
    "desfalquemo": "desfalcar",
    "desfalquemos": "desfalcar",
    "desfalques": "desfalque",
    "desfanatiza": "desfanatizar",
    "desfanatizada": "desfanatizar",
    "desfanatizadas": "desfanatizar",
    "desfanatizado": "desfanatizar",
    "desfanatizados": "desfanatizar",
    "desfanatizai": "desfanatizar",
    "desfanatizais": "desfanatizar",
    "desfanatizam": "desfanatizar",
    "desfanatizamo": "desfanatizar",
    "desfanatizamos": "desfanatizar",
    "desfanatizando": "desfanatizar",
    "desfanatizara": "desfanatizar",
    "desfanatizaram": "desfanatizar",
    "desfanatizaras": "desfanatizar",
    "desfanatizarde": "desfanatizar",
    "desfanatizardes": "desfanatizar",
    "desfanatizare": "desfanatizar",
    "desfanatizarei": "desfanatizar",
    "desfanatizareis": "desfanatizar",
    "desfanatizarem": "desfanatizar",
    "desfanatizaremos": "desfanatizar",
    "desfanatizares": "desfanatizar",
    "desfanatizaria": "desfanatizar",
    "desfanatizariam": "desfanatizar",
    "desfanatizarias": "desfanatizar",
    "desfanatizarmo": "desfanatizar",
    "desfanatizarmos": "desfanatizar",
    "desfanatizará": "desfanatizar",
    "desfanatizarás": "desfanatizar",
    "desfanatizarão": "desfanatizar",
    "desfanatizaríamos": "desfanatizar",
    "desfanatizaríeis": "desfanatizar",
    "desfanatizas": "desfanatizar",
    "desfanatizasse": "desfanatizar",
    "desfanatizassem": "desfanatizar",
    "desfanatizasses": "desfanatizar",
    "desfanatizaste": "desfanatizar",
    "desfanatizastes": "desfanatizar",
    "desfanatizava": "desfanatizar",
    "desfanatizavam": "desfanatizar",
    "desfanatizavas": "desfanatizar",
    "desfanatize": "desfanatizar",
    "desfanatizei": "desfanatizar",
    "desfanatizeis": "desfanatizar",
    "desfanatizem": "desfanatizar",
    "desfanatizemo": "desfanatizar",
    "desfanatizemos": "desfanatizar",
    "desfanatizes": "desfanatizar",
    "desfanatizo": "desfanatizar",
    "desfanatizou": "desfanatizar",
    "desfanatizá": "desfanatizar",
    "desfanatizámo": "desfanatizar",
    "desfanatizámos": "desfanatizar",
    "desfanatizáramo": "desfanatizar",
    "desfanatizáramos": "desfanatizar",
    "desfanatizárei": "desfanatizar",
    "desfanatizáreis": "desfanatizar",
    "desfanatizásseis": "desfanatizar",
    "desfanatizássemos": "desfanatizar",
    "desfanatizávamo": "desfanatizar",
    "desfanatizávamos": "desfanatizar",
    "desfanatizávei": "desfanatizar",
    "desfanatizáveis": "desfanatizar",
    "desfantansia": "desfantansiar",
    "desfantansiada": "desfantansiar",
    "desfantansiadas": "desfantansiar",
    "desfantansiado": "desfantansiar",
    "desfantansiados": "desfantansiar",
    "desfantansiai": "desfantansiar",
    "desfantansiais": "desfantansiar",
    "desfantansiam": "desfantansiar",
    "desfantansiamo": "desfantansiar",
    "desfantansiamos": "desfantansiar",
    "desfantansiando": "desfantansiar",
    "desfantansiara": "desfantansiar",
    "desfantansiaram": "desfantansiar",
    "desfantansiaras": "desfantansiar",
    "desfantansiarde": "desfantansiar",
    "desfantansiardes": "desfantansiar",
    "desfantansiare": "desfantansiar",
    "desfantansiarei": "desfantansiar",
    "desfantansiareis": "desfantansiar",
    "desfantansiarem": "desfantansiar",
    "desfantansiaremos": "desfantansiar",
    "desfantansiares": "desfantansiar",
    "desfantansiaria": "desfantansiar",
    "desfantansiariam": "desfantansiar",
    "desfantansiarias": "desfantansiar",
    "desfantansiarmo": "desfantansiar",
    "desfantansiarmos": "desfantansiar",
    "desfantansiará": "desfantansiar",
    "desfantansiarás": "desfantansiar",
    "desfantansiarão": "desfantansiar",
    "desfantansiaríamos": "desfantansiar",
    "desfantansiaríeis": "desfantansiar",
    "desfantansias": "desfantansiar",
    "desfantansiasse": "desfantansiar",
    "desfantansiassem": "desfantansiar",
    "desfantansiasses": "desfantansiar",
    "desfantansiaste": "desfantansiar",
    "desfantansiastes": "desfantansiar",
    "desfantansiava": "desfantansiar",
    "desfantansiavam": "desfantansiar",
    "desfantansiavas": "desfantansiar",
    "desfantansie": "desfantansiar",
    "desfantansiei": "desfantansiar",
    "desfantansieis": "desfantansiar",
    "desfantansiem": "desfantansiar",
    "desfantansiemo": "desfantansiar",
    "desfantansiemos": "desfantansiar",
    "desfantansies": "desfantansiar",
    "desfantansio": "desfantansiar",
    "desfantansiou": "desfantansiar",
    "desfantansiá": "desfantansiar",
    "desfantansiámo": "desfantansiar",
    "desfantansiámos": "desfantansiar",
    "desfantansiáramo": "desfantansiar",
    "desfantansiáramos": "desfantansiar",
    "desfantansiárei": "desfantansiar",
    "desfantansiáreis": "desfantansiar",
    "desfantansiásseis": "desfantansiar",
    "desfantansiássemos": "desfantansiar",
    "desfantansiávamo": "desfantansiar",
    "desfantansiávamos": "desfantansiar",
    "desfantansiávei": "desfantansiar",
    "desfantansiáveis": "desfantansiar",
    "desfantasiada": "desfantasiado",
    "desfantasiadas": "desfantasiado",
    "desfantasiados": "desfantasiado",
    "desfarda": "desfardar",
    "desfardada": "desfardar",
    "desfardadas": "desfardar",
    "desfardado": "desfardar",
    "desfardados": "desfardar",
    "desfardai": "desfardar",
    "desfardais": "desfardar",
    "desfardam": "desfardar",
    "desfardamo": "desfardar",
    "desfardamos": "desfardar",
    "desfardando": "desfardar",
    "desfardara": "desfardar",
    "desfardaram": "desfardar",
    "desfardaras": "desfardar",
    "desfardarde": "desfardar",
    "desfardardes": "desfardar",
    "desfardare": "desfardar",
    "desfardarei": "desfardar",
    "desfardareis": "desfardar",
    "desfardarem": "desfardar",
    "desfardaremos": "desfardar",
    "desfardares": "desfardar",
    "desfardaria": "desfardar",
    "desfardariam": "desfardar",
    "desfardarias": "desfardar",
    "desfardarmo": "desfardar",
    "desfardarmos": "desfardar",
    "desfardará": "desfardar",
    "desfardarás": "desfardar",
    "desfardarão": "desfardar",
    "desfardaríamos": "desfardar",
    "desfardaríeis": "desfardar",
    "desfardas": "desfardar",
    "desfardasse": "desfardar",
    "desfardassem": "desfardar",
    "desfardasses": "desfardar",
    "desfardaste": "desfardar",
    "desfardastes": "desfardar",
    "desfardava": "desfardar",
    "desfardavam": "desfardar",
    "desfardavas": "desfardar",
    "desfarde": "desfardar",
    "desfardei": "desfardar",
    "desfardeis": "desfardar",
    "desfardem": "desfardar",
    "desfardemo": "desfardar",
    "desfardemos": "desfardar",
    "desfardes": "desfardar",
    "desfardo": "desfardar",
    "desfardou": "desfardar",
    "desfardá": "desfardar",
    "desfardámo": "desfardar",
    "desfardámos": "desfardar",
    "desfardáramo": "desfardar",
    "desfardáramos": "desfardar",
    "desfardárei": "desfardar",
    "desfardáreis": "desfardar",
    "desfardásseis": "desfardar",
    "desfardássemos": "desfardar",
    "desfardávamo": "desfardar",
    "desfardávamos": "desfardar",
    "desfardávei": "desfardar",
    "desfardáveis": "desfardar",
    "desfarei": "desfazer",
    "desfareis": "desfazer",
    "desfarela": "desfarelar",
    "desfarelada": "desfarelar",
    "desfareladas": "desfarelar",
    "desfarelado": "desfarelar",
    "desfarelados": "desfarelar",
    "desfarelai": "desfarelar",
    "desfarelais": "desfarelar",
    "desfarelam": "desfarelar",
    "desfarelamo": "desfarelar",
    "desfarelamos": "desfarelar",
    "desfarelando": "desfarelar",
    "desfarelara": "desfarelar",
    "desfarelaram": "desfarelar",
    "desfarelaras": "desfarelar",
    "desfarelarde": "desfarelar",
    "desfarelardes": "desfarelar",
    "desfarelare": "desfarelar",
    "desfarelarei": "desfarelar",
    "desfarelareis": "desfarelar",
    "desfarelarem": "desfarelar",
    "desfarelaremos": "desfarelar",
    "desfarelares": "desfarelar",
    "desfarelaria": "desfarelar",
    "desfarelariam": "desfarelar",
    "desfarelarias": "desfarelar",
    "desfarelarmo": "desfarelar",
    "desfarelarmos": "desfarelar",
    "desfarelará": "desfarelar",
    "desfarelarás": "desfarelar",
    "desfarelarão": "desfarelar",
    "desfarelaríamos": "desfarelar",
    "desfarelaríeis": "desfarelar",
    "desfarelas": "desfarelar",
    "desfarelasse": "desfarelar",
    "desfarelassem": "desfarelar",
    "desfarelasses": "desfarelar",
    "desfarelaste": "desfarelar",
    "desfarelastes": "desfarelar",
    "desfarelava": "desfarelar",
    "desfarelavam": "desfarelar",
    "desfarelavas": "desfarelar",
    "desfarele": "desfarelar",
    "desfarelei": "desfarelar",
    "desfareleis": "desfarelar",
    "desfarelem": "desfarelar",
    "desfarelemo": "desfarelar",
    "desfarelemos": "desfarelar",
    "desfareles": "desfarelar",
    "desfarelo": "desfarelar",
    "desfarelou": "desfarelar",
    "desfarelá": "desfarelar",
    "desfarelámo": "desfarelar",
    "desfarelámos": "desfarelar",
    "desfareláramo": "desfarelar",
    "desfareláramos": "desfarelar",
    "desfarelárei": "desfarelar",
    "desfareláreis": "desfarelar",
    "desfarelásseis": "desfarelar",
    "desfarelássemos": "desfarelar",
    "desfarelávamo": "desfarelar",
    "desfarelávamos": "desfarelar",
    "desfarelávei": "desfarelar",
    "desfareláveis": "desfarelar",
    "desfaremos": "desfazer",
    "desfaria": "desfazer",
    "desfariam": "desfazer",
    "desfarias": "desfazer",
    "desfará": "desfazer",
    "desfarás": "desfazer",
    "desfarão": "desfazer",
    "desfaríamos": "desfazer",
    "desfaríeis": "desfazer",
    "desfasa": "desfasar",
    "desfasada": "desfasar",
    "desfasadas": "desfasar",
    "desfasado": "desfasar",
    "desfasados": "desfasar",
    "desfasadíssima": "desfasado",
    "desfasadíssimas": "desfasado",
    "desfasadíssimo": "desfasado",
    "desfasadíssimos": "desfasado",
    "desfasagens": "desfasagem",
    "desfasai": "desfasar",
    "desfasais": "desfasar",
    "desfasam": "desfasar",
    "desfasamentos": "desfasamento",
    "desfasamo": "desfasar",
    "desfasamos": "desfasar",
    "desfasando": "desfasar",
    "desfasara": "desfasar",
    "desfasaram": "desfasar",
    "desfasaras": "desfasar",
    "desfasarde": "desfasar",
    "desfasardes": "desfasar",
    "desfasare": "desfasar",
    "desfasarei": "desfasar",
    "desfasareis": "desfasar",
    "desfasarem": "desfasar",
    "desfasaremos": "desfasar",
    "desfasares": "desfasar",
    "desfasaria": "desfasar",
    "desfasariam": "desfasar",
    "desfasarias": "desfasar",
    "desfasarmo": "desfasar",
    "desfasarmos": "desfasar",
    "desfasará": "desfasar",
    "desfasarás": "desfasar",
    "desfasarão": "desfasar",
    "desfasaríamos": "desfasar",
    "desfasaríeis": "desfasar",
    "desfasas": "desfasar",
    "desfasasse": "desfasar",
    "desfasassem": "desfasar",
    "desfasasses": "desfasar",
    "desfasaste": "desfasar",
    "desfasastes": "desfasar",
    "desfasava": "desfasar",
    "desfasavam": "desfasar",
    "desfasavas": "desfasar",
    "desfase": "desfasar",
    "desfasei": "desfasar",
    "desfaseis": "desfasar",
    "desfasem": "desfasar",
    "desfasemo": "desfasar",
    "desfasemos": "desfasar",
    "desfases": "desfasar",
    "desfaso": "desfasar",
    "desfasou": "desfasar",
    "desfastios": "desfastio",
    "desfasá": "desfasar",
    "desfasámo": "desfasar",
    "desfasámos": "desfasar",
    "desfasáramo": "desfasar",
    "desfasáramos": "desfasar",
    "desfasárei": "desfasar",
    "desfasáreis": "desfasar",
    "desfasásseis": "desfasar",
    "desfasássemos": "desfasar",
    "desfasávamo": "desfasar",
    "desfasávamos": "desfasar",
    "desfasávei": "desfasar",
    "desfasáveis": "desfasar",
    "desfavorece": "desfavorecer",
    "desfavorecedora": "desfavorecedor",
    "desfavorecedoras": "desfavorecedor",
    "desfavorecedores": "desfavorecedor",
    "desfavorecei": "desfavorecer",
    "desfavoreceis": "desfavorecer",
    "desfavorecem": "desfavorecer",
    "desfavorecemo": "desfavorecer",
    "desfavorecemos": "desfavorecer",
    "desfavorecendo": "desfavorecer",
    "desfavorecera": "desfavorecer",
    "desfavoreceram": "desfavorecer",
    "desfavoreceras": "desfavorecer",
    "desfavorecerde": "desfavorecer",
    "desfavorecerdes": "desfavorecer",
    "desfavorecere": "desfavorecer",
    "desfavorecerei": "desfavorecer",
    "desfavorecereis": "desfavorecer",
    "desfavorecerem": "desfavorecer",
    "desfavoreceremos": "desfavorecer",
    "desfavoreceres": "desfavorecer",
    "desfavoreceria": "desfavorecer",
    "desfavoreceriam": "desfavorecer",
    "desfavorecerias": "desfavorecer",
    "desfavorecermo": "desfavorecer",
    "desfavorecermos": "desfavorecer",
    "desfavorecerá": "desfavorecer",
    "desfavorecerás": "desfavorecer",
    "desfavorecerão": "desfavorecer",
    "desfavoreceríamos": "desfavorecer",
    "desfavoreceríeis": "desfavorecer",
    "desfavoreces": "desfavorecer",
    "desfavorecesse": "desfavorecer",
    "desfavorecessem": "desfavorecer",
    "desfavorecesses": "desfavorecer",
    "desfavoreceste": "desfavorecer",
    "desfavorecestes": "desfavorecer",
    "desfavoreceu": "desfavorecer",
    "desfavoreci": "desfavorecer",
    "desfavorecia": "desfavorecer",
    "desfavoreciam": "desfavorecer",
    "desfavorecias": "desfavorecer",
    "desfavorecida": "desfavorecido",
    "desfavorecidas": "desfavorecido",
    "desfavorecido": "desfavorecer",
    "desfavorecidos": "desfavorecido",
    "desfavorecê": "desfavorecer",
    "desfavorecêramo": "desfavorecer",
    "desfavorecêramos": "desfavorecer",
    "desfavorecêrei": "desfavorecer",
    "desfavorecêreis": "desfavorecer",
    "desfavorecêsseis": "desfavorecer",
    "desfavorecêssemos": "desfavorecer",
    "desfavorecíamo": "desfavorecer",
    "desfavorecíamos": "desfavorecer",
    "desfavorecíei": "desfavorecer",
    "desfavorecíeis": "desfavorecer",
    "desfavores": "desfavor",
    "desfavoreça": "desfavorecer",
    "desfavoreçais": "desfavorecer",
    "desfavoreçam": "desfavorecer",
    "desfavoreçamo": "desfavorecer",
    "desfavoreçamos": "desfavorecer",
    "desfavoreças": "desfavorecer",
    "desfavoreço": "desfavorecer",
    "desfavoráveis": "desfavorável",
    "desfaz": "desfazer",
    "desfaze": "desfazer",
    "desfazedora": "desfazedor",
    "desfazedoras": "desfazedor",
    "desfazedores": "desfazedor",
    "desfazei": "desfazer",
    "desfazeis": "desfazer",
    "desfazem": "desfazer",
    "desfazemo": "desfazer",
    "desfazemos": "desfazer",
    "desfazendo": "desfazer",
    "desfazerde": "desfazer",
    "desfazerdes": "desfazer",
    "desfazere": "desfazer",
    "desfazerem": "desfazer",
    "desfazeres": "desfazer",
    "desfazermo": "desfazer",
    "desfazermos": "desfazer",
    "desfazes": "desfazer",
    "desfazia": "desfazer",
    "desfaziam": "desfazer",
    "desfazias": "desfazer",
    "desfazê": "desfazer",
    "desfazíamo": "desfazer",
    "desfazíamos": "desfazer",
    "desfazíei": "desfazer",
    "desfazíeis": "desfazer",
    "desfaça": "desfazer",
    "desfaçada": "desfaçar",
    "desfaçadas": "desfaçar",
    "desfaçado": "desfaçar",
    "desfaçados": "desfaçar",
    "desfaçai": "desfaçar",
    "desfaçais": "desfazer",
    "desfaçam": "desfazer",
    "desfaçamentos": "desfaçamento",
    "desfaçamo": "desfazer",
    "desfaçamos": "desfazer",
    "desfaçando": "desfaçar",
    "desfaçara": "desfaçar",
    "desfaçaram": "desfaçar",
    "desfaçaras": "desfaçar",
    "desfaçarde": "desfaçar",
    "desfaçardes": "desfaçar",
    "desfaçare": "desfaçar",
    "desfaçarei": "desfaçar",
    "desfaçareis": "desfaçar",
    "desfaçarem": "desfaçar",
    "desfaçaremos": "desfaçar",
    "desfaçares": "desfaçar",
    "desfaçaria": "desfaçar",
    "desfaçariam": "desfaçar",
    "desfaçarias": "desfaçar",
    "desfaçarmo": "desfaçar",
    "desfaçarmos": "desfaçar",
    "desfaçará": "desfaçar",
    "desfaçarás": "desfaçar",
    "desfaçarão": "desfaçar",
    "desfaçaríamos": "desfaçar",
    "desfaçaríeis": "desfaçar",
    "desfaças": "desfazer",
    "desfaçasse": "desfaçar",
    "desfaçassem": "desfaçar",
    "desfaçasses": "desfaçar",
    "desfaçaste": "desfaçar",
    "desfaçastes": "desfaçar",
    "desfaçatezes": "desfaçatez",
    "desfaçava": "desfaçar",
    "desfaçavam": "desfaçar",
    "desfaçavas": "desfaçar",
    "desfaço": "desfazer",
    "desfaçou": "desfaçar",
    "desfaçá": "desfaçar",
    "desfaçámo": "desfaçar",
    "desfaçámos": "desfaçar",
    "desfaçáramo": "desfaçar",
    "desfaçáramos": "desfaçar",
    "desfaçárei": "desfaçar",
    "desfaçáreis": "desfaçar",
    "desfaçásseis": "desfaçar",
    "desfaçássemos": "desfaçar",
    "desfaçávamo": "desfaçar",
    "desfaçávamos": "desfaçar",
    "desfaçávei": "desfaçar",
    "desfaçáveis": "desfaçar",
    "desfeada": "desfear",
    "desfeadas": "desfear",
    "desfeado": "desfear",
    "desfeados": "desfear",
    "desfeai": "desfear",
    "desfeais": "desfear",
    "desfeamo": "desfear",
    "desfeamos": "desfear",
    "desfeando": "desfear",
    "desfeara": "desfear",
    "desfearam": "desfear",
    "desfearas": "desfear",
    "desfearde": "desfear",
    "desfeardes": "desfear",
    "desfeare": "desfear",
    "desfearei": "desfear",
    "desfeareis": "desfear",
    "desfearem": "desfear",
    "desfearemos": "desfear",
    "desfeares": "desfear",
    "desfearia": "desfear",
    "desfeariam": "desfear",
    "desfearias": "desfear",
    "desfearmo": "desfear",
    "desfearmos": "desfear",
    "desfeará": "desfear",
    "desfearás": "desfear",
    "desfearão": "desfear",
    "desfearíamos": "desfear",
    "desfearíeis": "desfear",
    "desfeasse": "desfear",
    "desfeassem": "desfear",
    "desfeasses": "desfear",
    "desfeaste": "desfear",
    "desfeastes": "desfear",
    "desfeava": "desfear",
    "desfeavam": "desfear",
    "desfeavas": "desfear",
    "desfecha": "desfechar",
    "desfechada": "desfechar",
    "desfechadas": "desfechar",
    "desfechado": "desfechar",
    "desfechados": "desfechar",
    "desfechai": "desfechar",
    "desfechais": "desfechar",
    "desfecham": "desfechar",
    "desfechamo": "desfechar",
    "desfechamos": "desfechar",
    "desfechando": "desfechar",
    "desfechara": "desfechar",
    "desfecharam": "desfechar",
    "desfecharas": "desfechar",
    "desfecharde": "desfechar",
    "desfechardes": "desfechar",
    "desfechare": "desfechar",
    "desfecharei": "desfechar",
    "desfechareis": "desfechar",
    "desfecharem": "desfechar",
    "desfecharemos": "desfechar",
    "desfechares": "desfechar",
    "desfecharia": "desfechar",
    "desfechariam": "desfechar",
    "desfecharias": "desfechar",
    "desfecharmo": "desfechar",
    "desfecharmos": "desfechar",
    "desfechará": "desfechar",
    "desfecharás": "desfechar",
    "desfecharão": "desfechar",
    "desfecharíamos": "desfechar",
    "desfecharíeis": "desfechar",
    "desfechas": "desfechar",
    "desfechasse": "desfechar",
    "desfechassem": "desfechar",
    "desfechasses": "desfechar",
    "desfechaste": "desfechar",
    "desfechastes": "desfechar",
    "desfechava": "desfechar",
    "desfechavam": "desfechar",
    "desfechavas": "desfechar",
    "desfeche": "desfechar",
    "desfechei": "desfechar",
    "desfecheis": "desfechar",
    "desfechem": "desfechar",
    "desfechemo": "desfechar",
    "desfechemos": "desfechar",
    "desfeches": "desfechar",
    "desfecho": "desfechar",
    "desfechos": "desfecho",
    "desfechou": "desfechar",
    "desfechá": "desfechar",
    "desfechámo": "desfechar",
    "desfechámos": "desfechar",
    "desfecháramo": "desfechar",
    "desfecháramos": "desfechar",
    "desfechárei": "desfechar",
    "desfecháreis": "desfechar",
    "desfechásseis": "desfechar",
    "desfechássemos": "desfechar",
    "desfechávamo": "desfechar",
    "desfechávamos": "desfechar",
    "desfechávei": "desfechar",
    "desfecháveis": "desfechar",
    "desfeei": "desfear",
    "desfeeis": "desfear",
    "desfeemo": "desfear",
    "desfeemos": "desfear",
    "desfeia": "desfear",
    "desfeiam": "desfear",
    "desfeias": "desfear",
    "desfeie": "desfear",
    "desfeiem": "desfear",
    "desfeies": "desfear",
    "desfeio": "desfear",
    "desfeita": "desfeito",
    "desfeitas": "desfeito",
    "desfeiteada": "desfeitear",
    "desfeiteadas": "desfeitear",
    "desfeiteado": "desfeitear",
    "desfeiteadora": "desfeiteador",
    "desfeiteadoras": "desfeiteador",
    "desfeiteadores": "desfeiteador",
    "desfeiteados": "desfeitear",
    "desfeiteai": "desfeitear",
    "desfeiteais": "desfeitear",
    "desfeiteamo": "desfeitear",
    "desfeiteamos": "desfeitear",
    "desfeiteando": "desfeitear",
    "desfeiteara": "desfeitear",
    "desfeitearam": "desfeitear",
    "desfeitearas": "desfeitear",
    "desfeitearde": "desfeitear",
    "desfeiteardes": "desfeitear",
    "desfeiteare": "desfeitear",
    "desfeitearei": "desfeitear",
    "desfeiteareis": "desfeitear",
    "desfeitearem": "desfeitear",
    "desfeitearemos": "desfeitear",
    "desfeiteares": "desfeitear",
    "desfeitearia": "desfeitear",
    "desfeiteariam": "desfeitear",
    "desfeitearias": "desfeitear",
    "desfeitearmo": "desfeitear",
    "desfeitearmos": "desfeitear",
    "desfeiteará": "desfeitear",
    "desfeitearás": "desfeitear",
    "desfeitearão": "desfeitear",
    "desfeitearíamos": "desfeitear",
    "desfeitearíeis": "desfeitear",
    "desfeiteasse": "desfeitear",
    "desfeiteassem": "desfeitear",
    "desfeiteasses": "desfeitear",
    "desfeiteaste": "desfeitear",
    "desfeiteastes": "desfeitear",
    "desfeiteava": "desfeitear",
    "desfeiteavam": "desfeitear",
    "desfeiteavas": "desfeitear",
    "desfeiteei": "desfeitear",
    "desfeiteeis": "desfeitear",
    "desfeiteemo": "desfeitear",
    "desfeiteemos": "desfeitear",
    "desfeiteia": "desfeitear",
    "desfeiteiam": "desfeitear",
    "desfeiteias": "desfeitear",
    "desfeiteie": "desfeitear",
    "desfeiteiem": "desfeitear",
    "desfeiteies": "desfeitear",
    "desfeiteio": "desfeitear",
    "desfeiteou": "desfeitear",
    "desfeiteá": "desfeitear",
    "desfeiteámo": "desfeitear",
    "desfeiteámos": "desfeitear",
    "desfeiteáramo": "desfeitear",
    "desfeiteáramos": "desfeitear",
    "desfeiteárei": "desfeitear",
    "desfeiteáreis": "desfeitear",
    "desfeiteásseis": "desfeitear",
    "desfeiteássemos": "desfeitear",
    "desfeiteávamo": "desfeitear",
    "desfeiteávamos": "desfeitear",
    "desfeiteávei": "desfeitear",
    "desfeiteáveis": "desfeitear",
    "desfeito": "desfazer",
    "desfeitos": "desfeito",
    "desfeou": "desfear",
    "desfere": "desferir",
    "desferem": "desferir",
    "desferes": "desferir",
    "desferi": "desferir",
    "desferia": "desferir",
    "desferiam": "desferir",
    "desferias": "desferir",
    "desferida": "desferir",
    "desferidas": "desferir",
    "desferido": "desferir",
    "desferidos": "desferir",
    "desferimentos": "desferimento",
    "desferimo": "desferir",
    "desferimos": "desferir",
    "desferindo": "desferir",
    "desferira": "desferir",
    "desferiram": "desferir",
    "desferiras": "desferir",
    "desferirde": "desferir",
    "desferirdes": "desferir",
    "desferire": "desferir",
    "desferirei": "desferir",
    "desferireis": "desferir",
    "desferirem": "desferir",
    "desferiremos": "desferir",
    "desferires": "desferir",
    "desferiria": "desferir",
    "desfeririam": "desferir",
    "desferirias": "desferir",
    "desferirmo": "desferir",
    "desferirmos": "desferir",
    "desferirá": "desferir",
    "desferirás": "desferir",
    "desferirão": "desferir",
    "desferiríamos": "desferir",
    "desferiríeis": "desferir",
    "desferis": "desferir",
    "desferisse": "desferir",
    "desferissem": "desferir",
    "desferisses": "desferir",
    "desferiste": "desferir",
    "desferistes": "desferir",
    "desferiu": "desferir",
    "desferra": "desferrar",
    "desferrada": "desferrar",
    "desferradas": "desferrar",
    "desferrado": "desferrar",
    "desferrados": "desferrar",
    "desferrai": "desferrar",
    "desferrais": "desferrar",
    "desferram": "desferrar",
    "desferramo": "desferrar",
    "desferramos": "desferrar",
    "desferrando": "desferrar",
    "desferrara": "desferrar",
    "desferraram": "desferrar",
    "desferraras": "desferrar",
    "desferrarde": "desferrar",
    "desferrardes": "desferrar",
    "desferrare": "desferrar",
    "desferrarei": "desferrar",
    "desferrareis": "desferrar",
    "desferrarem": "desferrar",
    "desferraremos": "desferrar",
    "desferrares": "desferrar",
    "desferraria": "desferrar",
    "desferrariam": "desferrar",
    "desferrarias": "desferrar",
    "desferrarmo": "desferrar",
    "desferrarmos": "desferrar",
    "desferrará": "desferrar",
    "desferrarás": "desferrar",
    "desferrarão": "desferrar",
    "desferraríamos": "desferrar",
    "desferraríeis": "desferrar",
    "desferras": "desferrar",
    "desferrasse": "desferrar",
    "desferrassem": "desferrar",
    "desferrasses": "desferrar",
    "desferraste": "desferrar",
    "desferrastes": "desferrar",
    "desferrava": "desferrar",
    "desferravam": "desferrar",
    "desferravas": "desferrar",
    "desferre": "desferrar",
    "desferrei": "desferrar",
    "desferreis": "desferrar",
    "desferrem": "desferrar",
    "desferremo": "desferrar",
    "desferremos": "desferrar",
    "desferres": "desferrar",
    "desferro": "desferrar",
    "desferrolha": "desferrolhar",
    "desferrolhada": "desferrolhar",
    "desferrolhadas": "desferrolhar",
    "desferrolhado": "desferrolhar",
    "desferrolhados": "desferrolhar",
    "desferrolhai": "desferrolhar",
    "desferrolhais": "desferrolhar",
    "desferrolham": "desferrolhar",
    "desferrolhamo": "desferrolhar",
    "desferrolhamos": "desferrolhar",
    "desferrolhando": "desferrolhar",
    "desferrolhara": "desferrolhar",
    "desferrolharam": "desferrolhar",
    "desferrolharas": "desferrolhar",
    "desferrolharde": "desferrolhar",
    "desferrolhardes": "desferrolhar",
    "desferrolhare": "desferrolhar",
    "desferrolharei": "desferrolhar",
    "desferrolhareis": "desferrolhar",
    "desferrolharem": "desferrolhar",
    "desferrolharemos": "desferrolhar",
    "desferrolhares": "desferrolhar",
    "desferrolharia": "desferrolhar",
    "desferrolhariam": "desferrolhar",
    "desferrolharias": "desferrolhar",
    "desferrolharmo": "desferrolhar",
    "desferrolharmos": "desferrolhar",
    "desferrolhará": "desferrolhar",
    "desferrolharás": "desferrolhar",
    "desferrolharão": "desferrolhar",
    "desferrolharíamos": "desferrolhar",
    "desferrolharíeis": "desferrolhar",
    "desferrolhas": "desferrolhar",
    "desferrolhasse": "desferrolhar",
    "desferrolhassem": "desferrolhar",
    "desferrolhasses": "desferrolhar",
    "desferrolhaste": "desferrolhar",
    "desferrolhastes": "desferrolhar",
    "desferrolhava": "desferrolhar",
    "desferrolhavam": "desferrolhar",
    "desferrolhavas": "desferrolhar",
    "desferrolhe": "desferrolhar",
    "desferrolhei": "desferrolhar",
    "desferrolheis": "desferrolhar",
    "desferrolhem": "desferrolhar",
    "desferrolhemo": "desferrolhar",
    "desferrolhemos": "desferrolhar",
    "desferrolhes": "desferrolhar",
    "desferrolho": "desferrolhar",
    "desferrolhou": "desferrolhar",
    "desferrolhá": "desferrolhar",
    "desferrolhámo": "desferrolhar",
    "desferrolhámos": "desferrolhar",
    "desferrolháramo": "desferrolhar",
    "desferrolháramos": "desferrolhar",
    "desferrolhárei": "desferrolhar",
    "desferrolháreis": "desferrolhar",
    "desferrolhásseis": "desferrolhar",
    "desferrolhássemos": "desferrolhar",
    "desferrolhávamo": "desferrolhar",
    "desferrolhávamos": "desferrolhar",
    "desferrolhávei": "desferrolhar",
    "desferrolháveis": "desferrolhar",
    "desferrou": "desferrar",
    "desferrá": "desferrar",
    "desferrámo": "desferrar",
    "desferrámos": "desferrar",
    "desferráramo": "desferrar",
    "desferráramos": "desferrar",
    "desferrárei": "desferrar",
    "desferráreis": "desferrar",
    "desferrásseis": "desferrar",
    "desferrássemos": "desferrar",
    "desferrávamo": "desferrar",
    "desferrávamos": "desferrar",
    "desferrávei": "desferrar",
    "desferráveis": "desferrar",
    "desfertiliza": "desfertilizar",
    "desfertilizada": "desfertilizar",
    "desfertilizadas": "desfertilizar",
    "desfertilizado": "desfertilizar",
    "desfertilizados": "desfertilizar",
    "desfertilizai": "desfertilizar",
    "desfertilizais": "desfertilizar",
    "desfertilizam": "desfertilizar",
    "desfertilizamo": "desfertilizar",
    "desfertilizamos": "desfertilizar",
    "desfertilizando": "desfertilizar",
    "desfertilizara": "desfertilizar",
    "desfertilizaram": "desfertilizar",
    "desfertilizaras": "desfertilizar",
    "desfertilizarde": "desfertilizar",
    "desfertilizardes": "desfertilizar",
    "desfertilizare": "desfertilizar",
    "desfertilizarei": "desfertilizar",
    "desfertilizareis": "desfertilizar",
    "desfertilizarem": "desfertilizar",
    "desfertilizaremos": "desfertilizar",
    "desfertilizares": "desfertilizar",
    "desfertilizaria": "desfertilizar",
    "desfertilizariam": "desfertilizar",
    "desfertilizarias": "desfertilizar",
    "desfertilizarmo": "desfertilizar",
    "desfertilizarmos": "desfertilizar",
    "desfertilizará": "desfertilizar",
    "desfertilizarás": "desfertilizar",
    "desfertilizarão": "desfertilizar",
    "desfertilizaríamos": "desfertilizar",
    "desfertilizaríeis": "desfertilizar",
    "desfertilizas": "desfertilizar",
    "desfertilizasse": "desfertilizar",
    "desfertilizassem": "desfertilizar",
    "desfertilizasses": "desfertilizar",
    "desfertilizaste": "desfertilizar",
    "desfertilizastes": "desfertilizar",
    "desfertilizava": "desfertilizar",
    "desfertilizavam": "desfertilizar",
    "desfertilizavas": "desfertilizar",
    "desfertilize": "desfertilizar",
    "desfertilizei": "desfertilizar",
    "desfertilizeis": "desfertilizar",
    "desfertilizem": "desfertilizar",
    "desfertilizemo": "desfertilizar",
    "desfertilizemos": "desfertilizar",
    "desfertilizes": "desfertilizar",
    "desfertilizo": "desfertilizar",
    "desfertilizou": "desfertilizar",
    "desfertilizá": "desfertilizar",
    "desfertilizámo": "desfertilizar",
    "desfertilizámos": "desfertilizar",
    "desfertilizáramo": "desfertilizar",
    "desfertilizáramos": "desfertilizar",
    "desfertilizárei": "desfertilizar",
    "desfertilizáreis": "desfertilizar",
    "desfertilizásseis": "desfertilizar",
    "desfertilizássemos": "desfertilizar",
    "desfertilizávamo": "desfertilizar",
    "desfertilizávamos": "desfertilizar",
    "desfertilizávei": "desfertilizar",
    "desfertilizáveis": "desfertilizar",
    "desfervorosa": "desfervoroso",
    "desfervorosas": "desfervoroso",
    "desfervorosos": "desfervoroso",
    "desferíamo": "desferir",
    "desferíamos": "desferir",
    "desferíei": "desferir",
    "desferíeis": "desferir",
    "desferíramo": "desferir",
    "desferíramos": "desferir",
    "desferírei": "desferir",
    "desferíreis": "desferir",
    "desferísseis": "desferir",
    "desferíssemos": "desferir",
    "desferíveis": "desferível",
    "desfez": "desfazer",
    "desfeá": "desfear",
    "desfeámo": "desfear",
    "desfeámos": "desfear",
    "desfeáramo": "desfear",
    "desfeáramos": "desfear",
    "desfeárei": "desfear",
    "desfeáreis": "desfear",
    "desfeásseis": "desfear",
    "desfeássemos": "desfear",
    "desfeávamo": "desfear",
    "desfeávamos": "desfear",
    "desfeávei": "desfear",
    "desfeáveis": "desfear",
    "desfi": "desfazer",
    "desfia": "desfiar",
    "desfiada": "desfiar",
    "desfiadas": "desfiar",
    "desfiado": "desfiar",
    "desfiados": "desfiar",
    "desfiaduras": "desfiadura",
    "desfiai": "desfiar",
    "desfiais": "desfiar",
    "desfiam": "desfiar",
    "desfiamo": "desfiar",
    "desfiamos": "desfiar",
    "desfiando": "desfiar",
    "desfiara": "desfiar",
    "desfiaram": "desfiar",
    "desfiaras": "desfiar",
    "desfiarde": "desfiar",
    "desfiardes": "desfiar",
    "desfiare": "desfiar",
    "desfiarei": "desfiar",
    "desfiareis": "desfiar",
    "desfiarem": "desfiar",
    "desfiaremos": "desfiar",
    "desfiares": "desfiar",
    "desfiaria": "desfiar",
    "desfiariam": "desfiar",
    "desfiarias": "desfiar",
    "desfiarmo": "desfiar",
    "desfiarmos": "desfiar",
    "desfiará": "desfiar",
    "desfiarás": "desfiar",
    "desfiarão": "desfiar",
    "desfiaríamos": "desfiar",
    "desfiaríeis": "desfiar",
    "desfias": "desfiar",
    "desfiasse": "desfiar",
    "desfiassem": "desfiar",
    "desfiasses": "desfiar",
    "desfiaste": "desfiar",
    "desfiastes": "desfiar",
    "desfiava": "desfiar",
    "desfiavam": "desfiar",
    "desfiavas": "desfiar",
    "desfibra": "desfibrar",
    "desfibrada": "desfibrar",
    "desfibradas": "desfibrar",
    "desfibrado": "desfibrar",
    "desfibradora": "desfibrador",
    "desfibradoras": "desfibrador",
    "desfibradores": "desfibrador",
    "desfibrados": "desfibrar",
    "desfibrai": "desfibrar",
    "desfibrais": "desfibrar",
    "desfibram": "desfibrar",
    "desfibramentos": "desfibramento",
    "desfibramo": "desfibrar",
    "desfibramos": "desfibrar",
    "desfibrando": "desfibrar",
    "desfibrantes": "desfibrante",
    "desfibrara": "desfibrar",
    "desfibraram": "desfibrar",
    "desfibraras": "desfibrar",
    "desfibrarde": "desfibrar",
    "desfibrardes": "desfibrar",
    "desfibrare": "desfibrar",
    "desfibrarei": "desfibrar",
    "desfibrareis": "desfibrar",
    "desfibrarem": "desfibrar",
    "desfibraremos": "desfibrar",
    "desfibrares": "desfibrar",
    "desfibraria": "desfibrar",
    "desfibrariam": "desfibrar",
    "desfibrarias": "desfibrar",
    "desfibrarmo": "desfibrar",
    "desfibrarmos": "desfibrar",
    "desfibrará": "desfibrar",
    "desfibrarás": "desfibrar",
    "desfibrarão": "desfibrar",
    "desfibraríamos": "desfibrar",
    "desfibraríeis": "desfibrar",
    "desfibras": "desfibrar",
    "desfibrasse": "desfibrar",
    "desfibrassem": "desfibrar",
    "desfibrasses": "desfibrar",
    "desfibraste": "desfibrar",
    "desfibrastes": "desfibrar",
    "desfibrava": "desfibrar",
    "desfibravam": "desfibrar",
    "desfibravas": "desfibrar",
    "desfibre": "desfibrar",
    "desfibrei": "desfibrar",
    "desfibreis": "desfibrar",
    "desfibrem": "desfibrar",
    "desfibremo": "desfibrar",
    "desfibremos": "desfibrar",
    "desfibres": "desfibrar",
    "desfibriladores": "desfibrilador",
    "desfibrilhada": "desfibrilhado",
    "desfibrilhadas": "desfibrilhado",
    "desfibrilhados": "desfibrilhado",
    "desfibrina": "desfibrinar",
    "desfibrinada": "desfibrinar",
    "desfibrinadas": "desfibrinar",
    "desfibrinado": "desfibrinar",
    "desfibrinados": "desfibrinar",
    "desfibrinai": "desfibrinar",
    "desfibrinais": "desfibrinar",
    "desfibrinam": "desfibrinar",
    "desfibrinamo": "desfibrinar",
    "desfibrinamos": "desfibrinar",
    "desfibrinando": "desfibrinar",
    "desfibrinara": "desfibrinar",
    "desfibrinaram": "desfibrinar",
    "desfibrinaras": "desfibrinar",
    "desfibrinarde": "desfibrinar",
    "desfibrinardes": "desfibrinar",
    "desfibrinare": "desfibrinar",
    "desfibrinarei": "desfibrinar",
    "desfibrinareis": "desfibrinar",
    "desfibrinarem": "desfibrinar",
    "desfibrinaremos": "desfibrinar",
    "desfibrinares": "desfibrinar",
    "desfibrinaria": "desfibrinar",
    "desfibrinariam": "desfibrinar",
    "desfibrinarias": "desfibrinar",
    "desfibrinarmo": "desfibrinar",
    "desfibrinarmos": "desfibrinar",
    "desfibrinará": "desfibrinar",
    "desfibrinarás": "desfibrinar",
    "desfibrinarão": "desfibrinar",
    "desfibrinaríamos": "desfibrinar",
    "desfibrinaríeis": "desfibrinar",
    "desfibrinas": "desfibrinar",
    "desfibrinasse": "desfibrinar",
    "desfibrinassem": "desfibrinar",
    "desfibrinasses": "desfibrinar",
    "desfibrinaste": "desfibrinar",
    "desfibrinastes": "desfibrinar",
    "desfibrinava": "desfibrinar",
    "desfibrinavam": "desfibrinar",
    "desfibrinavas": "desfibrinar",
    "desfibrine": "desfibrinar",
    "desfibrinei": "desfibrinar",
    "desfibrineis": "desfibrinar",
    "desfibrinem": "desfibrinar",
    "desfibrinemo": "desfibrinar",
    "desfibrinemos": "desfibrinar",
    "desfibrines": "desfibrinar",
    "desfibrino": "desfibrinar",
    "desfibrinou": "desfibrinar",
    "desfibriná": "desfibrinar",
    "desfibrinámo": "desfibrinar",
    "desfibrinámos": "desfibrinar",
    "desfibrináramo": "desfibrinar",
    "desfibrináramos": "desfibrinar",
    "desfibrinárei": "desfibrinar",
    "desfibrináreis": "desfibrinar",
    "desfibrinásseis": "desfibrinar",
    "desfibrinássemos": "desfibrinar",
    "desfibrinávamo": "desfibrinar",
    "desfibrinávamos": "desfibrinar",
    "desfibrinávei": "desfibrinar",
    "desfibrináveis": "desfibrinar",
    "desfibro": "desfibrar",
    "desfibrou": "desfibrar",
    "desfibrá": "desfibrar",
    "desfibrámo": "desfibrar",
    "desfibrámos": "desfibrar",
    "desfibráramo": "desfibrar",
    "desfibráramos": "desfibrar",
    "desfibrárei": "desfibrar",
    "desfibráreis": "desfibrar",
    "desfibrásseis": "desfibrar",
    "desfibrássemos": "desfibrar",
    "desfibrávamo": "desfibrar",
    "desfibrávamos": "desfibrar",
    "desfibrávei": "desfibrar",
    "desfibráveis": "desfibrar",
    "desfie": "desfiar",
    "desfiei": "desfiar",
    "desfieis": "desfiar",
    "desfiem": "desfiar",
    "desfiemo": "desfiar",
    "desfiemos": "desfiar",
    "desfies": "desfiar",
    "desfigura": "desfigurar",
    "desfigurada": "desfigurar",
    "desfiguradas": "desfigurar",
    "desfigurado": "desfigurar",
    "desfiguradora": "desfigurador",
    "desfiguradoras": "desfigurador",
    "desfiguradores": "desfigurador",
    "desfigurados": "desfigurar",
    "desfigurai": "desfigurar",
    "desfigurais": "desfigurar",
    "desfiguram": "desfigurar",
    "desfiguramo": "desfigurar",
    "desfiguramos": "desfigurar",
    "desfigurando": "desfigurar",
    "desfigurara": "desfigurar",
    "desfiguraram": "desfigurar",
    "desfiguraras": "desfigurar",
    "desfigurarde": "desfigurar",
    "desfigurardes": "desfigurar",
    "desfigurare": "desfigurar",
    "desfigurarei": "desfigurar",
    "desfigurareis": "desfigurar",
    "desfigurarem": "desfigurar",
    "desfiguraremos": "desfigurar",
    "desfigurares": "desfigurar",
    "desfiguraria": "desfigurar",
    "desfigurariam": "desfigurar",
    "desfigurarias": "desfigurar",
    "desfigurarmo": "desfigurar",
    "desfigurarmos": "desfigurar",
    "desfigurará": "desfigurar",
    "desfigurarás": "desfigurar",
    "desfigurarão": "desfigurar",
    "desfiguraríamos": "desfigurar",
    "desfiguraríeis": "desfigurar",
    "desfiguras": "desfigurar",
    "desfigurasse": "desfigurar",
    "desfigurassem": "desfigurar",
    "desfigurasses": "desfigurar",
    "desfiguraste": "desfigurar",
    "desfigurastes": "desfigurar",
    "desfigurava": "desfigurar",
    "desfiguravam": "desfigurar",
    "desfiguravas": "desfigurar",
    "desfigurações": "desfiguração",
    "desfigure": "desfigurar",
    "desfigurei": "desfigurar",
    "desfigureis": "desfigurar",
    "desfigurem": "desfigurar",
    "desfiguremo": "desfigurar",
    "desfiguremos": "desfigurar",
    "desfigures": "desfigurar",
    "desfiguro": "desfigurar",
    "desfigurou": "desfigurar",
    "desfigurá": "desfigurar",
    "desfigurámo": "desfigurar",
    "desfigurámos": "desfigurar",
    "desfiguráramo": "desfigurar",
    "desfiguráramos": "desfigurar",
    "desfigurárei": "desfigurar",
    "desfiguráreis": "desfigurar",
    "desfigurásseis": "desfigurar",
    "desfigurássemos": "desfigurar",
    "desfigurávamo": "desfigurar",
    "desfigurávamos": "desfigurar",
    "desfigurávei": "desfigurar",
    "desfiguráveis": "desfigurável",
    "desfila": "desfilar",
    "desfilada": "desfilar",
    "desfiladas": "desfilar",
    "desfiladeiros": "desfiladeiro",
    "desfilado": "desfilar",
    "desfiladoras": "desfiladora",
    "desfilados": "desfilar",
    "desfilai": "desfilar",
    "desfilais": "desfilar",
    "desfilam": "desfilar",
    "desfilamentos": "desfilamento",
    "desfilamo": "desfilar",
    "desfilamos": "desfilar",
    "desfilando": "desfilar",
    "desfilara": "desfilar",
    "desfilaram": "desfilar",
    "desfilaras": "desfilar",
    "desfilardes": "desfilar",
    "desfilarei": "desfilar",
    "desfilareis": "desfilar",
    "desfilarem": "desfilar",
    "desfilaremos": "desfilar",
    "desfilares": "desfilar",
    "desfilaria": "desfilar",
    "desfilariam": "desfilar",
    "desfilarias": "desfilar",
    "desfilarmo": "desfilar",
    "desfilarmos": "desfilar",
    "desfilará": "desfilar",
    "desfilarás": "desfilar",
    "desfilarão": "desfilar",
    "desfilaríamos": "desfilar",
    "desfilaríeis": "desfilar",
    "desfilas": "desfilar",
    "desfilasse": "desfilar",
    "desfilassem": "desfilar",
    "desfilasses": "desfilar",
    "desfilaste": "desfilar",
    "desfilastes": "desfilar",
    "desfilava": "desfilar",
    "desfilavam": "desfilar",
    "desfilavas": "desfilar",
    "desfile": "desfilar",
    "desfilei": "desfilar",
    "desfileis": "desfilar",
    "desfilem": "desfilar",
    "desfilemo": "desfilar",
    "desfilemos": "desfilar",
    "desfiles": "desfile",
    "desfilha": "desfilhar",
    "desfilhada": "desfilhar",
    "desfilhadas": "desfilhar",
    "desfilhado": "desfilhar",
    "desfilhados": "desfilhar",
    "desfilhai": "desfilhar",
    "desfilhais": "desfilhar",
    "desfilham": "desfilhar",
    "desfilhamo": "desfilhar",
    "desfilhamos": "desfilhar",
    "desfilhando": "desfilhar",
    "desfilhara": "desfilhar",
    "desfilharam": "desfilhar",
    "desfilharas": "desfilhar",
    "desfilharde": "desfilhar",
    "desfilhardes": "desfilhar",
    "desfilhare": "desfilhar",
    "desfilharei": "desfilhar",
    "desfilhareis": "desfilhar",
    "desfilharem": "desfilhar",
    "desfilharemos": "desfilhar",
    "desfilhares": "desfilhar",
    "desfilharia": "desfilhar",
    "desfilhariam": "desfilhar",
    "desfilharias": "desfilhar",
    "desfilharmo": "desfilhar",
    "desfilharmos": "desfilhar",
    "desfilhará": "desfilhar",
    "desfilharás": "desfilhar",
    "desfilharão": "desfilhar",
    "desfilharíamos": "desfilhar",
    "desfilharíeis": "desfilhar",
    "desfilhas": "desfilhar",
    "desfilhasse": "desfilhar",
    "desfilhassem": "desfilhar",
    "desfilhasses": "desfilhar",
    "desfilhaste": "desfilhar",
    "desfilhastes": "desfilhar",
    "desfilhava": "desfilhar",
    "desfilhavam": "desfilhar",
    "desfilhavas": "desfilhar",
    "desfilhe": "desfilhar",
    "desfilhei": "desfilhar",
    "desfilheis": "desfilhar",
    "desfilhem": "desfilhar",
    "desfilhemo": "desfilhar",
    "desfilhemos": "desfilhar",
    "desfilhes": "desfilhar",
    "desfilho": "desfilhar",
    "desfilhou": "desfilhar",
    "desfilhá": "desfilhar",
    "desfilhámo": "desfilhar",
    "desfilhámos": "desfilhar",
    "desfilháramo": "desfilhar",
    "desfilháramos": "desfilhar",
    "desfilhárei": "desfilhar",
    "desfilháreis": "desfilhar",
    "desfilhásseis": "desfilhar",
    "desfilhássemos": "desfilhar",
    "desfilhávamo": "desfilhar",
    "desfilhávamos": "desfilhar",
    "desfilhávei": "desfilhar",
    "desfilháveis": "desfilhar",
    "desfilia": "desfiliar",
    "desfiliada": "desfiliar",
    "desfiliadas": "desfiliar",
    "desfiliado": "desfiliar",
    "desfiliados": "desfiliar",
    "desfiliai": "desfiliar",
    "desfiliais": "desfiliar",
    "desfiliam": "desfiliar",
    "desfiliamo": "desfiliar",
    "desfiliamos": "desfiliar",
    "desfiliando": "desfiliar",
    "desfiliara": "desfiliar",
    "desfiliaram": "desfiliar",
    "desfiliaras": "desfiliar",
    "desfiliarde": "desfiliar",
    "desfiliardes": "desfiliar",
    "desfiliare": "desfiliar",
    "desfiliarei": "desfiliar",
    "desfiliareis": "desfiliar",
    "desfiliarem": "desfiliar",
    "desfiliaremos": "desfiliar",
    "desfiliares": "desfiliar",
    "desfiliaria": "desfiliar",
    "desfiliariam": "desfiliar",
    "desfiliarias": "desfiliar",
    "desfiliarmo": "desfiliar",
    "desfiliarmos": "desfiliar",
    "desfiliará": "desfiliar",
    "desfiliarás": "desfiliar",
    "desfiliarão": "desfiliar",
    "desfiliaríamos": "desfiliar",
    "desfiliaríeis": "desfiliar",
    "desfilias": "desfiliar",
    "desfiliasse": "desfiliar",
    "desfiliassem": "desfiliar",
    "desfiliasses": "desfiliar",
    "desfiliaste": "desfiliar",
    "desfiliastes": "desfiliar",
    "desfiliava": "desfiliar",
    "desfiliavam": "desfiliar",
    "desfiliavas": "desfiliar",
    "desfiliações": "desfiliação",
    "desfilie": "desfiliar",
    "desfiliei": "desfiliar",
    "desfilieis": "desfiliar",
    "desfiliem": "desfiliar",
    "desfiliemo": "desfiliar",
    "desfiliemos": "desfiliar",
    "desfilies": "desfiliar",
    "desfilio": "desfiliar",
    "desfiliou": "desfiliar",
    "desfiliá": "desfiliar",
    "desfiliámo": "desfiliar",
    "desfiliámos": "desfiliar",
    "desfiliáramo": "desfiliar",
    "desfiliáramos": "desfiliar",
    "desfiliárei": "desfiliar",
    "desfiliáreis": "desfiliar",
    "desfiliásseis": "desfiliar",
    "desfiliássemos": "desfiliar",
    "desfiliávamo": "desfiliar",
    "desfiliávamos": "desfiliar",
    "desfiliávei": "desfiliar",
    "desfiliáveis": "desfiliar",
    "desfilo": "desfilar",
    "desfilou": "desfilar",
    "desfilámo": "desfilar",
    "desfilámos": "desfilar",
    "desfiláramo": "desfilar",
    "desfiláramos": "desfilar",
    "desfiláreis": "desfilar",
    "desfilásseis": "desfilar",
    "desfilássemos": "desfilar",
    "desfilávamo": "desfilar",
    "desfilávamos": "desfilar",
    "desfiláveis": "desfilar",
    "desfio": "desfiar",
    "desfiou": "desfiar",
    "desfira": "desferir",
    "desfirais": "desferir",
    "desfiram": "desferir",
    "desfiramo": "desferir",
    "desfiramos": "desferir",
    "desfiras": "desferir",
    "desfiro": "desferir",
    "desfita": "desfitar",
    "desfitada": "desfitar",
    "desfitadas": "desfitar",
    "desfitado": "desfitar",
    "desfitados": "desfitar",
    "desfitai": "desfitar",
    "desfitais": "desfitar",
    "desfitam": "desfitar",
    "desfitamo": "desfitar",
    "desfitamos": "desfitar",
    "desfitando": "desfitar",
    "desfitara": "desfitar",
    "desfitaram": "desfitar",
    "desfitaras": "desfitar",
    "desfitarde": "desfitar",
    "desfitardes": "desfitar",
    "desfitare": "desfitar",
    "desfitarei": "desfitar",
    "desfitareis": "desfitar",
    "desfitarem": "desfitar",
    "desfitaremos": "desfitar",
    "desfitares": "desfitar",
    "desfitaria": "desfitar",
    "desfitariam": "desfitar",
    "desfitarias": "desfitar",
    "desfitarmo": "desfitar",
    "desfitarmos": "desfitar",
    "desfitará": "desfitar",
    "desfitarás": "desfitar",
    "desfitarão": "desfitar",
    "desfitaríamos": "desfitar",
    "desfitaríeis": "desfitar",
    "desfitas": "desfitar",
    "desfitasse": "desfitar",
    "desfitassem": "desfitar",
    "desfitasses": "desfitar",
    "desfitaste": "desfitar",
    "desfitastes": "desfitar",
    "desfitava": "desfitar",
    "desfitavam": "desfitar",
    "desfitavas": "desfitar",
    "desfite": "desfitar",
    "desfitei": "desfitar",
    "desfiteis": "desfitar",
    "desfitem": "desfitar",
    "desfitemo": "desfitar",
    "desfitemos": "desfitar",
    "desfites": "desfitar",
    "desfito": "desfitar",
    "desfitou": "desfitar",
    "desfitá": "desfitar",
    "desfitámo": "desfitar",
    "desfitámos": "desfitar",
    "desfitáramo": "desfitar",
    "desfitáramos": "desfitar",
    "desfitárei": "desfitar",
    "desfitáreis": "desfitar",
    "desfitásseis": "desfitar",
    "desfitássemos": "desfitar",
    "desfitávamo": "desfitar",
    "desfitávamos": "desfitar",
    "desfitávei": "desfitar",
    "desfitáveis": "desfitar",
    "desfivela": "desfivelar",
    "desfivelada": "desfivelar",
    "desfiveladas": "desfivelar",
    "desfivelado": "desfivelar",
    "desfivelados": "desfivelar",
    "desfivelai": "desfivelar",
    "desfivelais": "desfivelar",
    "desfivelam": "desfivelar",
    "desfivelamo": "desfivelar",
    "desfivelamos": "desfivelar",
    "desfivelando": "desfivelar",
    "desfivelara": "desfivelar",
    "desfivelaram": "desfivelar",
    "desfivelaras": "desfivelar",
    "desfivelarde": "desfivelar",
    "desfivelardes": "desfivelar",
    "desfivelare": "desfivelar",
    "desfivelarei": "desfivelar",
    "desfivelareis": "desfivelar",
    "desfivelarem": "desfivelar",
    "desfivelaremos": "desfivelar",
    "desfivelares": "desfivelar",
    "desfivelaria": "desfivelar",
    "desfivelariam": "desfivelar",
    "desfivelarias": "desfivelar",
    "desfivelarmo": "desfivelar",
    "desfivelarmos": "desfivelar",
    "desfivelará": "desfivelar",
    "desfivelarás": "desfivelar",
    "desfivelarão": "desfivelar",
    "desfivelaríamos": "desfivelar",
    "desfivelaríeis": "desfivelar",
    "desfivelas": "desfivelar",
    "desfivelasse": "desfivelar",
    "desfivelassem": "desfivelar",
    "desfivelasses": "desfivelar",
    "desfivelaste": "desfivelar",
    "desfivelastes": "desfivelar",
    "desfivelava": "desfivelar",
    "desfivelavam": "desfivelar",
    "desfivelavas": "desfivelar",
    "desfivele": "desfivelar",
    "desfivelei": "desfivelar",
    "desfiveleis": "desfivelar",
    "desfivelem": "desfivelar",
    "desfivelemo": "desfivelar",
    "desfivelemos": "desfivelar",
    "desfiveles": "desfivelar",
    "desfivelo": "desfivelar",
    "desfivelou": "desfivelar",
    "desfivelá": "desfivelar",
    "desfivelámo": "desfivelar",
    "desfivelámos": "desfivelar",
    "desfiveláramo": "desfivelar",
    "desfiveláramos": "desfivelar",
    "desfivelárei": "desfivelar",
    "desfiveláreis": "desfivelar",
    "desfivelásseis": "desfivelar",
    "desfivelássemos": "desfivelar",
    "desfivelávamo": "desfivelar",
    "desfivelávamos": "desfivelar",
    "desfivelávei": "desfivelar",
    "desfiveláveis": "desfivelar",
    "desfiz": "desfazer",
    "desfizemo": "desfazer",
    "desfizemos": "desfazer",
    "desfizer": "desfazer",
    "desfizera": "desfazer",
    "desfizeram": "desfazer",
    "desfizeras": "desfazer",
    "desfizerdes": "desfazer",
    "desfizerem": "desfazer",
    "desfizeres": "desfazer",
    "desfizermos": "desfazer",
    "desfizesse": "desfazer",
    "desfizessem": "desfazer",
    "desfizesses": "desfazer",
    "desfizeste": "desfazer",
    "desfizestes": "desfazer",
    "desfizéramo": "desfazer",
    "desfizéramos": "desfazer",
    "desfizérei": "desfazer",
    "desfizéreis": "desfazer",
    "desfizésseis": "desfazer",
    "desfizéssemos": "desfazer",
    "desfiá": "desfiar",
    "desfiámo": "desfiar",
    "desfiámos": "desfiar",
    "desfiáramo": "desfiar",
    "desfiáramos": "desfiar",
    "desfiárei": "desfiar",
    "desfiáreis": "desfiar",
    "desfiásseis": "desfiar",
    "desfiássemos": "desfiar",
    "desfiávamo": "desfiar",
    "desfiávamos": "desfiar",
    "desfiávei": "desfiar",
    "desfiáveis": "desfiar",
    "desflora": "desflorir",
    "desflorada": "desflorar",
    "desfloradas": "desflorar",
    "desflorado": "desflorar",
    "desfloradora": "desflorador",
    "desfloradoras": "desflorador",
    "desfloradores": "desflorador",
    "desflorados": "desflorar",
    "desflorai": "desflorar",
    "desflorais": "desflorir",
    "desfloram": "desflorir",
    "desfloramentos": "desfloramento",
    "desfloramo": "desflorir",
    "desfloramos": "desflorir",
    "desflorando": "desflorar",
    "desflorara": "desflorar",
    "desfloraram": "desflorar",
    "desfloraras": "desflorar",
    "desflorarde": "desflorar",
    "desflorardes": "desflorar",
    "desflorare": "desflorar",
    "desflorarei": "desflorar",
    "desflorareis": "desflorar",
    "desflorarem": "desflorar",
    "desfloraremos": "desflorar",
    "desflorares": "desflorar",
    "desfloraria": "desflorar",
    "desflorariam": "desflorar",
    "desflorarias": "desflorar",
    "desflorarmo": "desflorar",
    "desflorarmos": "desflorar",
    "desflorará": "desflorar",
    "desflorarás": "desflorar",
    "desflorarão": "desflorar",
    "desfloraríamos": "desflorar",
    "desfloraríeis": "desflorar",
    "desfloras": "desflorir",
    "desflorasse": "desflorar",
    "desflorassem": "desflorar",
    "desflorasses": "desflorar",
    "desfloraste": "desflorar",
    "desflorastes": "desflorar",
    "desflorava": "desflorar",
    "desfloravam": "desflorar",
    "desfloravas": "desflorar",
    "desflorações": "desfloração",
    "desflore": "desflorir",
    "desflorei": "desflorar",
    "desfloreis": "desflorar",
    "desflorem": "desflorir",
    "desfloremo": "desflorar",
    "desfloremos": "desflorar",
    "desflores": "desflorir",
    "desfloresce": "desflorescer",
    "desflorescei": "desflorescer",
    "desfloresceis": "desflorescer",
    "desflorescem": "desflorescer",
    "desflorescemo": "desflorescer",
    "desflorescemos": "desflorescer",
    "desflorescendo": "desflorescer",
    "desflorescera": "desflorescer",
    "desfloresceram": "desflorescer",
    "desfloresceras": "desflorescer",
    "desflorescerdes": "desflorescer",
    "desflorescerei": "desflorescer",
    "desflorescereis": "desflorescer",
    "desflorescerem": "desflorescer",
    "desfloresceremos": "desflorescer",
    "desfloresceres": "desflorescer",
    "desfloresceria": "desflorescer",
    "desfloresceriam": "desflorescer",
    "desflorescerias": "desflorescer",
    "desflorescermo": "desflorescer",
    "desflorescermos": "desflorescer",
    "desflorescerá": "desflorescer",
    "desflorescerás": "desflorescer",
    "desflorescerão": "desflorescer",
    "desfloresceríamos": "desflorescer",
    "desfloresceríeis": "desflorescer",
    "desfloresces": "desflorescer",
    "desflorescesse": "desflorescer",
    "desflorescessem": "desflorescer",
    "desflorescesses": "desflorescer",
    "desfloresceste": "desflorescer",
    "desflorescestes": "desflorescer",
    "desfloresceu": "desflorescer",
    "desfloresci": "desflorescer",
    "desflorescia": "desflorescer",
    "desfloresciam": "desflorescer",
    "desflorescias": "desflorescer",
    "desflorescida": "desflorescer",
    "desflorescidas": "desflorescer",
    "desflorescido": "desflorescer",
    "desflorescidos": "desflorescer",
    "desflorescimentos": "desflorescimento",
    "desflorescêramo": "desflorescer",
    "desflorescêramos": "desflorescer",
    "desflorescêreis": "desflorescer",
    "desflorescêsseis": "desflorescer",
    "desflorescêssemos": "desflorescer",
    "desflorescíamo": "desflorescer",
    "desflorescíamos": "desflorescer",
    "desflorescíeis": "desflorescer",
    "desfloresta": "desflorestar",
    "desflorestada": "desflorestar",
    "desflorestadas": "desflorestar",
    "desflorestado": "desflorestar",
    "desflorestados": "desflorestar",
    "desflorestai": "desflorestar",
    "desflorestais": "desflorestar",
    "desflorestam": "desflorestar",
    "desflorestamentos": "desflorestamento",
    "desflorestamo": "desflorestar",
    "desflorestamos": "desflorestar",
    "desflorestando": "desflorestar",
    "desflorestara": "desflorestar",
    "desflorestaram": "desflorestar",
    "desflorestaras": "desflorestar",
    "desflorestarde": "desflorestar",
    "desflorestardes": "desflorestar",
    "desflorestare": "desflorestar",
    "desflorestarei": "desflorestar",
    "desflorestareis": "desflorestar",
    "desflorestarem": "desflorestar",
    "desflorestaremos": "desflorestar",
    "desflorestares": "desflorestar",
    "desflorestaria": "desflorestar",
    "desflorestariam": "desflorestar",
    "desflorestarias": "desflorestar",
    "desflorestarmo": "desflorestar",
    "desflorestarmos": "desflorestar",
    "desflorestará": "desflorestar",
    "desflorestarás": "desflorestar",
    "desflorestarão": "desflorestar",
    "desflorestaríamos": "desflorestar",
    "desflorestaríeis": "desflorestar",
    "desflorestas": "desflorestar",
    "desflorestasse": "desflorestar",
    "desflorestassem": "desflorestar",
    "desflorestasses": "desflorestar",
    "desflorestaste": "desflorestar",
    "desflorestastes": "desflorestar",
    "desflorestava": "desflorestar",
    "desflorestavam": "desflorestar",
    "desflorestavas": "desflorestar",
    "desflorestações": "desflorestação",
    "desfloreste": "desflorestar",
    "desflorestei": "desflorestar",
    "desfloresteis": "desflorestar",
    "desflorestem": "desflorestar",
    "desflorestemo": "desflorestar",
    "desflorestemos": "desflorestar",
    "desflorestes": "desflorestar",
    "desfloresto": "desflorestar",
    "desflorestou": "desflorestar",
    "desflorestá": "desflorestar",
    "desflorestámo": "desflorestar",
    "desflorestámos": "desflorestar",
    "desflorestáramo": "desflorestar",
    "desflorestáramos": "desflorestar",
    "desflorestárei": "desflorestar",
    "desflorestáreis": "desflorestar",
    "desflorestásseis": "desflorestar",
    "desflorestássemos": "desflorestar",
    "desflorestávamo": "desflorestar",
    "desflorestávamos": "desflorestar",
    "desflorestávei": "desflorestar",
    "desflorestáveis": "desflorestar",
    "desfloresça": "desflorescer",
    "desfloresçais": "desflorescer",
    "desfloresçam": "desflorescer",
    "desfloresçamo": "desflorescer",
    "desfloresçamos": "desflorescer",
    "desfloresças": "desflorescer",
    "desfloresço": "desflorescer",
    "desflori": "desflorir",
    "desfloria": "desflorir",
    "desfloriam": "desflorir",
    "desflorias": "desflorir",
    "desflorida": "desflorir",
    "desfloridas": "desflorir",
    "desflorido": "desflorir",
    "desfloridos": "desflorir",
    "desflorimo": "desflorir",
    "desflorimos": "desflorir",
    "desflorindo": "desflorir",
    "desflorira": "desflorir",
    "desfloriram": "desflorir",
    "desfloriras": "desflorir",
    "desflorirdes": "desflorir",
    "desflorirei": "desflorir",
    "desflorireis": "desflorir",
    "desflorirem": "desflorir",
    "desfloriremos": "desflorir",
    "desflorires": "desflorir",
    "desfloriria": "desflorir",
    "desfloririam": "desflorir",
    "desfloririas": "desflorir",
    "desflorirmo": "desflorir",
    "desflorirmos": "desflorir",
    "desflorirá": "desflorir",
    "desflorirás": "desflorir",
    "desflorirão": "desflorir",
    "desfloriríamos": "desflorir",
    "desfloriríeis": "desflorir",
    "desfloris": "desflorir",
    "desflorisse": "desflorir",
    "desflorissem": "desflorir",
    "desflorisses": "desflorir",
    "desfloriste": "desflorir",
    "desfloristes": "desflorir",
    "desfloriu": "desflorir",
    "desfloro": "desflorir",
    "desflorou": "desflorar",
    "desflorá": "desflorar",
    "desflorámo": "desflorar",
    "desflorámos": "desflorar",
    "desfloráramo": "desflorar",
    "desfloráramos": "desflorar",
    "desflorárei": "desflorar",
    "desfloráreis": "desflorar",
    "desflorásseis": "desflorar",
    "desflorássemos": "desflorar",
    "desflorávamo": "desflorar",
    "desflorávamos": "desflorar",
    "desflorávei": "desflorar",
    "desfloráveis": "desflorar",
    "desfloríamo": "desflorir",
    "desfloríamos": "desflorir",
    "desfloríeis": "desflorir",
    "desfloríramo": "desflorir",
    "desfloríramos": "desflorir",
    "desfloríreis": "desflorir",
    "desflorísseis": "desflorir",
    "desfloríssemos": "desflorir",
    "desfoca": "desfocar",
    "desfocada": "desfocar",
    "desfocadas": "desfocar",
    "desfocado": "desfocar",
    "desfocados": "desfocar",
    "desfocai": "desfocar",
    "desfocais": "desfocar",
    "desfocam": "desfocar",
    "desfocamo": "desfocar",
    "desfocamos": "desfocar",
    "desfocando": "desfocar",
    "desfocara": "desfocar",
    "desfocaram": "desfocar",
    "desfocaras": "desfocar",
    "desfocarde": "desfocar",
    "desfocardes": "desfocar",
    "desfocare": "desfocar",
    "desfocarei": "desfocar",
    "desfocareis": "desfocar",
    "desfocarem": "desfocar",
    "desfocaremos": "desfocar",
    "desfocares": "desfocar",
    "desfocaria": "desfocar",
    "desfocariam": "desfocar",
    "desfocarias": "desfocar",
    "desfocarmo": "desfocar",
    "desfocarmos": "desfocar",
    "desfocará": "desfocar",
    "desfocarás": "desfocar",
    "desfocarão": "desfocar",
    "desfocaríamos": "desfocar",
    "desfocaríeis": "desfocar",
    "desfocas": "desfocar",
    "desfocasse": "desfocar",
    "desfocassem": "desfocar",
    "desfocasses": "desfocar",
    "desfocaste": "desfocar",
    "desfocastes": "desfocar",
    "desfocava": "desfocar",
    "desfocavam": "desfocar",
    "desfocavas": "desfocar",
    "desfoco": "desfocar",
    "desfocou": "desfocar",
    "desfocá": "desfocar",
    "desfocámo": "desfocar",
    "desfocámos": "desfocar",
    "desfocáramo": "desfocar",
    "desfocáramos": "desfocar",
    "desfocárei": "desfocar",
    "desfocáreis": "desfocar",
    "desfocásseis": "desfocar",
    "desfocássemos": "desfocar",
    "desfocávamo": "desfocar",
    "desfocávamos": "desfocar",
    "desfocávei": "desfocar",
    "desfocáveis": "desfocar",
    "desfolha": "desfolhar",
    "desfolhada": "desfolhar",
    "desfolhadas": "desfolhar",
    "desfolhado": "desfolhar",
    "desfolhadora": "desfolhador",
    "desfolhadoras": "desfolhador",
    "desfolhadores": "desfolhador",
    "desfolhados": "desfolhar",
    "desfolhadouros": "desfolhadouro",
    "desfolhaduras": "desfolhadura",
    "desfolhai": "desfolhar",
    "desfolhais": "desfolhar",
    "desfolham": "desfolhar",
    "desfolhamentos": "desfolhamento",
    "desfolhamo": "desfolhar",
    "desfolhamos": "desfolhar",
    "desfolhando": "desfolhar",
    "desfolhara": "desfolhar",
    "desfolharam": "desfolhar",
    "desfolharas": "desfolhar",
    "desfolharde": "desfolhar",
    "desfolhardes": "desfolhar",
    "desfolhare": "desfolhar",
    "desfolharei": "desfolhar",
    "desfolhareis": "desfolhar",
    "desfolharem": "desfolhar",
    "desfolharemos": "desfolhar",
    "desfolhares": "desfolhar",
    "desfolharia": "desfolhar",
    "desfolhariam": "desfolhar",
    "desfolharias": "desfolhar",
    "desfolharmo": "desfolhar",
    "desfolharmos": "desfolhar",
    "desfolhará": "desfolhar",
    "desfolharás": "desfolhar",
    "desfolharão": "desfolhar",
    "desfolharíamos": "desfolhar",
    "desfolharíeis": "desfolhar",
    "desfolhas": "desfolhar",
    "desfolhasse": "desfolhar",
    "desfolhassem": "desfolhar",
    "desfolhasses": "desfolhar",
    "desfolhaste": "desfolhar",
    "desfolhastes": "desfolhar",
    "desfolhava": "desfolhar",
    "desfolhavam": "desfolhar",
    "desfolhavas": "desfolhar",
    "desfolhações": "desfolhação",
    "desfolhe": "desfolhar",
    "desfolhei": "desfolhar",
    "desfolheis": "desfolhar",
    "desfolhem": "desfolhar",
    "desfolhemo": "desfolhar",
    "desfolhemos": "desfolhar",
    "desfolhes": "desfolhar",
    "desfolho": "desfolhar",
    "desfolhos": "desfolho",
    "desfolhou": "desfolhar",
    "desfolhá": "desfolhar",
    "desfolhámo": "desfolhar",
    "desfolhámos": "desfolhar",
    "desfolháramo": "desfolhar",
    "desfolháramos": "desfolhar",
    "desfolhárei": "desfolhar",
    "desfolháreis": "desfolhar",
    "desfolhásseis": "desfolhar",
    "desfolhássemos": "desfolhar",
    "desfolhávamo": "desfolhar",
    "desfolhávamos": "desfolhar",
    "desfolhávei": "desfolhar",
    "desfolháveis": "desfolhável",
    "desfoliada": "desfoliado",
    "desfoliadas": "desfoliado",
    "desfoliados": "desfoliado",
    "desfoliantes": "desfoliante",
    "desfoliações": "desfoliação",
    "desfoque": "desfocar",
    "desfoquei": "desfocar",
    "desfoqueis": "desfocar",
    "desfoquem": "desfocar",
    "desfoquemo": "desfocar",
    "desfoquemos": "desfocar",
    "desfoques": "desfocar",
    "desforce": "desforçar",
    "desforcei": "desforçar",
    "desforceis": "desforçar",
    "desforcem": "desforçar",
    "desforcemo": "desforçar",
    "desforcemos": "desforçar",
    "desforces": "desforçar",
    "desforma": "desformar",
    "desformada": "desformar",
    "desformadas": "desformar",
    "desformado": "desformar",
    "desformados": "desformar",
    "desformai": "desformar",
    "desformais": "desformar",
    "desformam": "desformar",
    "desformamo": "desformar",
    "desformamos": "desformar",
    "desformando": "desformar",
    "desformara": "desformar",
    "desformaram": "desformar",
    "desformaras": "desformar",
    "desformarde": "desformar",
    "desformardes": "desformar",
    "desformare": "desformar",
    "desformarei": "desformar",
    "desformareis": "desformar",
    "desformarem": "desformar",
    "desformaremos": "desformar",
    "desformares": "desformar",
    "desformaria": "desformar",
    "desformariam": "desformar",
    "desformarias": "desformar",
    "desformarmo": "desformar",
    "desformarmos": "desformar",
    "desformará": "desformar",
    "desformarás": "desformar",
    "desformarão": "desformar",
    "desformaríamos": "desformar",
    "desformaríeis": "desformar",
    "desformas": "desformar",
    "desformasse": "desformar",
    "desformassem": "desformar",
    "desformasses": "desformar",
    "desformaste": "desformar",
    "desformastes": "desformar",
    "desformava": "desformar",
    "desformavam": "desformar",
    "desformavas": "desformar",
    "desforme": "desformar",
    "desformei": "desformar",
    "desformeis": "desformar",
    "desformem": "desformar",
    "desformemo": "desformar",
    "desformemos": "desformar",
    "desformes": "desformar",
    "desformo": "desformar",
    "desformoseada": "desformosear",
    "desformoseadas": "desformosear",
    "desformoseado": "desformosear",
    "desformoseados": "desformosear",
    "desformoseai": "desformosear",
    "desformoseais": "desformosear",
    "desformoseamo": "desformosear",
    "desformoseamos": "desformosear",
    "desformoseando": "desformosear",
    "desformoseara": "desformosear",
    "desformosearam": "desformosear",
    "desformosearas": "desformosear",
    "desformosearde": "desformosear",
    "desformoseardes": "desformosear",
    "desformoseare": "desformosear",
    "desformosearei": "desformosear",
    "desformoseareis": "desformosear",
    "desformosearem": "desformosear",
    "desformosearemos": "desformosear",
    "desformoseares": "desformosear",
    "desformosearia": "desformosear",
    "desformoseariam": "desformosear",
    "desformosearias": "desformosear",
    "desformosearmo": "desformosear",
    "desformosearmos": "desformosear",
    "desformoseará": "desformosear",
    "desformosearás": "desformosear",
    "desformosearão": "desformosear",
    "desformosearíamos": "desformosear",
    "desformosearíeis": "desformosear",
    "desformoseasse": "desformosear",
    "desformoseassem": "desformosear",
    "desformoseasses": "desformosear",
    "desformoseaste": "desformosear",
    "desformoseastes": "desformosear",
    "desformoseava": "desformosear",
    "desformoseavam": "desformosear",
    "desformoseavas": "desformosear",
    "desformoseei": "desformosear",
    "desformoseeis": "desformosear",
    "desformoseemo": "desformosear",
    "desformoseemos": "desformosear",
    "desformoseia": "desformosear",
    "desformoseiam": "desformosear",
    "desformoseias": "desformosear",
    "desformoseie": "desformosear",
    "desformoseiem": "desformosear",
    "desformoseies": "desformosear",
    "desformoseio": "desformosear",
    "desformoseou": "desformosear",
    "desformoseá": "desformosear",
    "desformoseámo": "desformosear",
    "desformoseámos": "desformosear",
    "desformoseáramo": "desformosear",
    "desformoseáramos": "desformosear",
    "desformoseárei": "desformosear",
    "desformoseáreis": "desformosear",
    "desformoseásseis": "desformosear",
    "desformoseássemos": "desformosear",
    "desformoseávamo": "desformosear",
    "desformoseávamos": "desformosear",
    "desformoseávei": "desformosear",
    "desformoseáveis": "desformosear",
    "desformou": "desformar",
    "desformá": "desformar",
    "desformámo": "desformar",
    "desformámos": "desformar",
    "desformáramo": "desformar",
    "desformáramos": "desformar",
    "desformárei": "desformar",
    "desformáreis": "desformar",
    "desformásseis": "desformar",
    "desformássemos": "desformar",
    "desformávamo": "desformar",
    "desformávamos": "desformar",
    "desformávei": "desformar",
    "desformáveis": "desformar",
    "desforra": "desforrar",
    "desforrada": "desforrar",
    "desforradas": "desforrar",
    "desforrado": "desforrar",
    "desforrados": "desforrar",
    "desforrai": "desforrar",
    "desforrais": "desforrar",
    "desforram": "desforrar",
    "desforramo": "desforrar",
    "desforramos": "desforrar",
    "desforrando": "desforrar",
    "desforrara": "desforrar",
    "desforraram": "desforrar",
    "desforraras": "desforrar",
    "desforrarde": "desforrar",
    "desforrardes": "desforrar",
    "desforrare": "desforrar",
    "desforrarei": "desforrar",
    "desforrareis": "desforrar",
    "desforrarem": "desforrar",
    "desforraremos": "desforrar",
    "desforrares": "desforrar",
    "desforraria": "desforrar",
    "desforrariam": "desforrar",
    "desforrarias": "desforrar",
    "desforrarmo": "desforrar",
    "desforrarmos": "desforrar",
    "desforrará": "desforrar",
    "desforrarás": "desforrar",
    "desforrarão": "desforrar",
    "desforraríamos": "desforrar",
    "desforraríeis": "desforrar",
    "desforras": "desforrar",
    "desforrasse": "desforrar",
    "desforrassem": "desforrar",
    "desforrasses": "desforrar",
    "desforraste": "desforrar",
    "desforrastes": "desforrar",
    "desforrava": "desforrar",
    "desforravam": "desforrar",
    "desforravas": "desforrar",
    "desforre": "desforrar",
    "desforrei": "desforrar",
    "desforreis": "desforrar",
    "desforrem": "desforrar",
    "desforremo": "desforrar",
    "desforremos": "desforrar",
    "desforres": "desforrar",
    "desforro": "desforrar",
    "desforros": "desforro",
    "desforrou": "desforrar",
    "desforrá": "desforrar",
    "desforrámo": "desforrar",
    "desforrámos": "desforrar",
    "desforráramo": "desforrar",
    "desforráramos": "desforrar",
    "desforrárei": "desforrar",
    "desforráreis": "desforrar",
    "desforrásseis": "desforrar",
    "desforrássemos": "desforrar",
    "desforrávamo": "desforrar",
    "desforrávamos": "desforrar",
    "desforrávei": "desforrar",
    "desforráveis": "desforrar",
    "desfortalece": "desfortalecer",
    "desfortalecei": "desfortalecer",
    "desfortaleceis": "desfortalecer",
    "desfortalecem": "desfortalecer",
    "desfortalecemo": "desfortalecer",
    "desfortalecemos": "desfortalecer",
    "desfortalecendo": "desfortalecer",
    "desfortalecera": "desfortalecer",
    "desfortaleceram": "desfortalecer",
    "desfortaleceras": "desfortalecer",
    "desfortalecerde": "desfortalecer",
    "desfortalecerdes": "desfortalecer",
    "desfortalecere": "desfortalecer",
    "desfortalecerei": "desfortalecer",
    "desfortalecereis": "desfortalecer",
    "desfortalecerem": "desfortalecer",
    "desfortaleceremos": "desfortalecer",
    "desfortaleceres": "desfortalecer",
    "desfortaleceria": "desfortalecer",
    "desfortaleceriam": "desfortalecer",
    "desfortalecerias": "desfortalecer",
    "desfortalecermo": "desfortalecer",
    "desfortalecermos": "desfortalecer",
    "desfortalecerá": "desfortalecer",
    "desfortalecerás": "desfortalecer",
    "desfortalecerão": "desfortalecer",
    "desfortaleceríamos": "desfortalecer",
    "desfortaleceríeis": "desfortalecer",
    "desfortaleces": "desfortalecer",
    "desfortalecesse": "desfortalecer",
    "desfortalecessem": "desfortalecer",
    "desfortalecesses": "desfortalecer",
    "desfortaleceste": "desfortalecer",
    "desfortalecestes": "desfortalecer",
    "desfortaleceu": "desfortalecer",
    "desfortaleci": "desfortalecer",
    "desfortalecia": "desfortalecer",
    "desfortaleciam": "desfortalecer",
    "desfortalecias": "desfortalecer",
    "desfortalecida": "desfortalecido",
    "desfortalecidas": "desfortalecido",
    "desfortalecido": "desfortalecer",
    "desfortalecidos": "desfortalecido",
    "desfortalecê": "desfortalecer",
    "desfortalecêramo": "desfortalecer",
    "desfortalecêramos": "desfortalecer",
    "desfortalecêrei": "desfortalecer",
    "desfortalecêreis": "desfortalecer",
    "desfortalecêsseis": "desfortalecer",
    "desfortalecêssemos": "desfortalecer",
    "desfortalecíamo": "desfortalecer",
    "desfortalecíamos": "desfortalecer",
    "desfortalecíei": "desfortalecer",
    "desfortalecíeis": "desfortalecer",
    "desfortaleça": "desfortalecer",
    "desfortaleçais": "desfortalecer",
    "desfortaleçam": "desfortalecer",
    "desfortaleçamo": "desfortalecer",
    "desfortaleçamos": "desfortalecer",
    "desfortaleças": "desfortalecer",
    "desfortaleço": "desfortalecer",
    "desfortifica": "desfortificar",
    "desfortificada": "desfortificar",
    "desfortificadas": "desfortificar",
    "desfortificado": "desfortificar",
    "desfortificados": "desfortificar",
    "desfortificai": "desfortificar",
    "desfortificais": "desfortificar",
    "desfortificam": "desfortificar",
    "desfortificamo": "desfortificar",
    "desfortificamos": "desfortificar",
    "desfortificando": "desfortificar",
    "desfortificara": "desfortificar",
    "desfortificaram": "desfortificar",
    "desfortificaras": "desfortificar",
    "desfortificarde": "desfortificar",
    "desfortificardes": "desfortificar",
    "desfortificare": "desfortificar",
    "desfortificarei": "desfortificar",
    "desfortificareis": "desfortificar",
    "desfortificarem": "desfortificar",
    "desfortificaremos": "desfortificar",
    "desfortificares": "desfortificar",
    "desfortificaria": "desfortificar",
    "desfortificariam": "desfortificar",
    "desfortificarias": "desfortificar",
    "desfortificarmo": "desfortificar",
    "desfortificarmos": "desfortificar",
    "desfortificará": "desfortificar",
    "desfortificarás": "desfortificar",
    "desfortificarão": "desfortificar",
    "desfortificaríamos": "desfortificar",
    "desfortificaríeis": "desfortificar",
    "desfortificas": "desfortificar",
    "desfortificasse": "desfortificar",
    "desfortificassem": "desfortificar",
    "desfortificasses": "desfortificar",
    "desfortificaste": "desfortificar",
    "desfortificastes": "desfortificar",
    "desfortificava": "desfortificar",
    "desfortificavam": "desfortificar",
    "desfortificavas": "desfortificar",
    "desfortifico": "desfortificar",
    "desfortificou": "desfortificar",
    "desfortificá": "desfortificar",
    "desfortificámo": "desfortificar",
    "desfortificámos": "desfortificar",
    "desfortificáramo": "desfortificar",
    "desfortificáramos": "desfortificar",
    "desfortificárei": "desfortificar",
    "desfortificáreis": "desfortificar",
    "desfortificásseis": "desfortificar",
    "desfortificássemos": "desfortificar",
    "desfortificávamo": "desfortificar",
    "desfortificávamos": "desfortificar",
    "desfortificávei": "desfortificar",
    "desfortificáveis": "desfortificar",
    "desfortifique": "desfortificar",
    "desfortifiquei": "desfortificar",
    "desfortifiqueis": "desfortificar",
    "desfortifiquem": "desfortificar",
    "desfortifiquemo": "desfortificar",
    "desfortifiquemos": "desfortificar",
    "desfortifiques": "desfortificar",
    "desfortunada": "desfortunado",
    "desfortunadas": "desfortunado",
    "desfortunados": "desfortunado",
    "desfortunas": "desfortuna",
    "desfortúnios": "desfortúnio",
    "desforça": "desforçar",
    "desforçada": "desforçar",
    "desforçadas": "desforçar",
    "desforçado": "desforçar",
    "desforçadora": "desforçador",
    "desforçadoras": "desforçador",
    "desforçadores": "desforçador",
    "desforçados": "desforçar",
    "desforçai": "desforçar",
    "desforçais": "desforçar",
    "desforçam": "desforçar",
    "desforçamentos": "desforçamento",
    "desforçamo": "desforçar",
    "desforçamos": "desforçar",
    "desforçando": "desforçar",
    "desforçara": "desforçar",
    "desforçaram": "desforçar",
    "desforçaras": "desforçar",
    "desforçarde": "desforçar",
    "desforçardes": "desforçar",
    "desforçare": "desforçar",
    "desforçarei": "desforçar",
    "desforçareis": "desforçar",
    "desforçarem": "desforçar",
    "desforçaremos": "desforçar",
    "desforçares": "desforçar",
    "desforçaria": "desforçar",
    "desforçariam": "desforçar",
    "desforçarias": "desforçar",
    "desforçarmo": "desforçar",
    "desforçarmos": "desforçar",
    "desforçará": "desforçar",
    "desforçarás": "desforçar",
    "desforçarão": "desforçar",
    "desforçaríamos": "desforçar",
    "desforçaríeis": "desforçar",
    "desforças": "desforçar",
    "desforçasse": "desforçar",
    "desforçassem": "desforçar",
    "desforçasses": "desforçar",
    "desforçaste": "desforçar",
    "desforçastes": "desforçar",
    "desforçava": "desforçar",
    "desforçavam": "desforçar",
    "desforçavas": "desforçar",
    "desforço": "desforçar",
    "desforços": "desforço",
    "desforçou": "desforçar",
    "desforçá": "desforçar",
    "desforçámo": "desforçar",
    "desforçámos": "desforçar",
    "desforçáramo": "desforçar",
    "desforçáramos": "desforçar",
    "desforçárei": "desforçar",
    "desforçáreis": "desforçar",
    "desforçásseis": "desforçar",
    "desforçássemos": "desforçar",
    "desforçávamo": "desforçar",
    "desforçávamos": "desforçar",
    "desforçávei": "desforçar",
    "desforçáveis": "desforçar",
    "desfrada": "desfradar",
    "desfradada": "desfradar",
    "desfradadas": "desfradar",
    "desfradado": "desfradar",
    "desfradados": "desfradar",
    "desfradai": "desfradar",
    "desfradais": "desfradar",
    "desfradam": "desfradar",
    "desfradamo": "desfradar",
    "desfradamos": "desfradar",
    "desfradando": "desfradar",
    "desfradara": "desfradar",
    "desfradaram": "desfradar",
    "desfradaras": "desfradar",
    "desfradarde": "desfradar",
    "desfradardes": "desfradar",
    "desfradare": "desfradar",
    "desfradarei": "desfradar",
    "desfradareis": "desfradar",
    "desfradarem": "desfradar",
    "desfradaremos": "desfradar",
    "desfradares": "desfradar",
    "desfradaria": "desfradar",
    "desfradariam": "desfradar",
    "desfradarias": "desfradar",
    "desfradarmo": "desfradar",
    "desfradarmos": "desfradar",
    "desfradará": "desfradar",
    "desfradarás": "desfradar",
    "desfradarão": "desfradar",
    "desfradaríamos": "desfradar",
    "desfradaríeis": "desfradar",
    "desfradas": "desfradar",
    "desfradasse": "desfradar",
    "desfradassem": "desfradar",
    "desfradasses": "desfradar",
    "desfradaste": "desfradar",
    "desfradastes": "desfradar",
    "desfradava": "desfradar",
    "desfradavam": "desfradar",
    "desfradavas": "desfradar",
    "desfrade": "desfradar",
    "desfradei": "desfradar",
    "desfradeis": "desfradar",
    "desfradem": "desfradar",
    "desfrademo": "desfradar",
    "desfrademos": "desfradar",
    "desfrades": "desfradar",
    "desfrado": "desfradar",
    "desfradou": "desfradar",
    "desfradá": "desfradar",
    "desfradámo": "desfradar",
    "desfradámos": "desfradar",
    "desfradáramo": "desfradar",
    "desfradáramos": "desfradar",
    "desfradárei": "desfradar",
    "desfradáreis": "desfradar",
    "desfradásseis": "desfradar",
    "desfradássemos": "desfradar",
    "desfradávamo": "desfradar",
    "desfradávamos": "desfradar",
    "desfradávei": "desfradar",
    "desfradáveis": "desfradar",
    "desfralda": "desfraldar",
    "desfraldada": "desfraldar",
    "desfraldadas": "desfraldar",
    "desfraldado": "desfraldar",
    "desfraldados": "desfraldar",
    "desfraldai": "desfraldar",
    "desfraldais": "desfraldar",
    "desfraldam": "desfraldar",
    "desfraldamo": "desfraldar",
    "desfraldamos": "desfraldar",
    "desfraldando": "desfraldar",
    "desfraldara": "desfraldar",
    "desfraldaram": "desfraldar",
    "desfraldaras": "desfraldar",
    "desfraldarde": "desfraldar",
    "desfraldardes": "desfraldar",
    "desfraldare": "desfraldar",
    "desfraldarei": "desfraldar",
    "desfraldareis": "desfraldar",
    "desfraldarem": "desfraldar",
    "desfraldaremos": "desfraldar",
    "desfraldares": "desfraldar",
    "desfraldaria": "desfraldar",
    "desfraldariam": "desfraldar",
    "desfraldarias": "desfraldar",
    "desfraldarmo": "desfraldar",
    "desfraldarmos": "desfraldar",
    "desfraldará": "desfraldar",
    "desfraldarás": "desfraldar",
    "desfraldarão": "desfraldar",
    "desfraldaríamos": "desfraldar",
    "desfraldaríeis": "desfraldar",
    "desfraldas": "desfraldar",
    "desfraldasse": "desfraldar",
    "desfraldassem": "desfraldar",
    "desfraldasses": "desfraldar",
    "desfraldaste": "desfraldar",
    "desfraldastes": "desfraldar",
    "desfraldava": "desfraldar",
    "desfraldavam": "desfraldar",
    "desfraldavas": "desfraldar",
    "desfralde": "desfraldar",
    "desfraldei": "desfraldar",
    "desfraldeis": "desfraldar",
    "desfraldem": "desfraldar",
    "desfraldemo": "desfraldar",
    "desfraldemos": "desfraldar",
    "desfraldes": "desfraldar",
    "desfraldo": "desfraldar",
    "desfraldou": "desfraldar",
    "desfraldá": "desfraldar",
    "desfraldámo": "desfraldar",
    "desfraldámos": "desfraldar",
    "desfraldáramo": "desfraldar",
    "desfraldáramos": "desfraldar",
    "desfraldárei": "desfraldar",
    "desfraldáreis": "desfraldar",
    "desfraldásseis": "desfraldar",
    "desfraldássemos": "desfraldar",
    "desfraldávamo": "desfraldar",
    "desfraldávamos": "desfraldar",
    "desfraldávei": "desfraldar",
    "desfraldáveis": "desfraldar",
    "desfranja": "desfranjar",
    "desfranjada": "desfranjar",
    "desfranjadas": "desfranjar",
    "desfranjado": "desfranjar",
    "desfranjados": "desfranjar",
    "desfranjai": "desfranjar",
    "desfranjais": "desfranjar",
    "desfranjam": "desfranjar",
    "desfranjamo": "desfranjar",
    "desfranjamos": "desfranjar",
    "desfranjando": "desfranjar",
    "desfranjara": "desfranjar",
    "desfranjaram": "desfranjar",
    "desfranjaras": "desfranjar",
    "desfranjarde": "desfranjar",
    "desfranjardes": "desfranjar",
    "desfranjare": "desfranjar",
    "desfranjarei": "desfranjar",
    "desfranjareis": "desfranjar",
    "desfranjarem": "desfranjar",
    "desfranjaremos": "desfranjar",
    "desfranjares": "desfranjar",
    "desfranjaria": "desfranjar",
    "desfranjariam": "desfranjar",
    "desfranjarias": "desfranjar",
    "desfranjarmo": "desfranjar",
    "desfranjarmos": "desfranjar",
    "desfranjará": "desfranjar",
    "desfranjarás": "desfranjar",
    "desfranjarão": "desfranjar",
    "desfranjaríamos": "desfranjar",
    "desfranjaríeis": "desfranjar",
    "desfranjas": "desfranjar",
    "desfranjasse": "desfranjar",
    "desfranjassem": "desfranjar",
    "desfranjasses": "desfranjar",
    "desfranjaste": "desfranjar",
    "desfranjastes": "desfranjar",
    "desfranjava": "desfranjar",
    "desfranjavam": "desfranjar",
    "desfranjavas": "desfranjar",
    "desfranje": "desfranjar",
    "desfranjei": "desfranjar",
    "desfranjeis": "desfranjar",
    "desfranjem": "desfranjar",
    "desfranjemo": "desfranjar",
    "desfranjemos": "desfranjar",
    "desfranjes": "desfranjar",
    "desfranjo": "desfranjar",
    "desfranjou": "desfranjar",
    "desfranjá": "desfranjar",
    "desfranjámo": "desfranjar",
    "desfranjámos": "desfranjar",
    "desfranjáramo": "desfranjar",
    "desfranjáramos": "desfranjar",
    "desfranjárei": "desfranjar",
    "desfranjáreis": "desfranjar",
    "desfranjásseis": "desfranjar",
    "desfranjássemos": "desfranjar",
    "desfranjávamo": "desfranjar",
    "desfranjávamos": "desfranjar",
    "desfranjávei": "desfranjar",
    "desfranjáveis": "desfranjar",
    "desfranza": "desfranzir",
    "desfranzais": "desfranzir",
    "desfranzam": "desfranzir",
    "desfranzamo": "desfranzir",
    "desfranzamos": "desfranzir",
    "desfranzas": "desfranzir",
    "desfranze": "desfranzir",
    "desfranzem": "desfranzir",
    "desfranzes": "desfranzir",
    "desfranzi": "desfranzir",
    "desfranzia": "desfranzir",
    "desfranziam": "desfranzir",
    "desfranzias": "desfranzir",
    "desfranzida": "desfranzir",
    "desfranzidas": "desfranzir",
    "desfranzido": "desfranzir",
    "desfranzidos": "desfranzir",
    "desfranzimo": "desfranzir",
    "desfranzimos": "desfranzir",
    "desfranzindo": "desfranzir",
    "desfranzira": "desfranzir",
    "desfranziram": "desfranzir",
    "desfranziras": "desfranzir",
    "desfranzirde": "desfranzir",
    "desfranzirdes": "desfranzir",
    "desfranzire": "desfranzir",
    "desfranzirei": "desfranzir",
    "desfranzireis": "desfranzir",
    "desfranzirem": "desfranzir",
    "desfranziremos": "desfranzir",
    "desfranzires": "desfranzir",
    "desfranziria": "desfranzir",
    "desfranziriam": "desfranzir",
    "desfranzirias": "desfranzir",
    "desfranzirmo": "desfranzir",
    "desfranzirmos": "desfranzir",
    "desfranzirá": "desfranzir",
    "desfranzirás": "desfranzir",
    "desfranzirão": "desfranzir",
    "desfranziríamos": "desfranzir",
    "desfranziríeis": "desfranzir",
    "desfranzis": "desfranzir",
    "desfranzisse": "desfranzir",
    "desfranzissem": "desfranzir",
    "desfranzisses": "desfranzir",
    "desfranziste": "desfranzir",
    "desfranzistes": "desfranzir",
    "desfranziu": "desfranzir",
    "desfranzo": "desfranzir",
    "desfranzíamo": "desfranzir",
    "desfranzíamos": "desfranzir",
    "desfranzíei": "desfranzir",
    "desfranzíeis": "desfranzir",
    "desfranzíramo": "desfranzir",
    "desfranzíramos": "desfranzir",
    "desfranzírei": "desfranzir",
    "desfranzíreis": "desfranzir",
    "desfranzísseis": "desfranzir",
    "desfranzíssemos": "desfranzir",
    "desfreada": "desfrear",
    "desfreadas": "desfrear",
    "desfreado": "desfrear",
    "desfreados": "desfrear",
    "desfreai": "desfrear",
    "desfreais": "desfrear",
    "desfreamo": "desfrear",
    "desfreamos": "desfrear",
    "desfreando": "desfrear",
    "desfreara": "desfrear",
    "desfrearam": "desfrear",
    "desfrearas": "desfrear",
    "desfrearde": "desfrear",
    "desfreardes": "desfrear",
    "desfreare": "desfrear",
    "desfrearei": "desfrear",
    "desfreareis": "desfrear",
    "desfrearem": "desfrear",
    "desfrearemos": "desfrear",
    "desfreares": "desfrear",
    "desfrearia": "desfrear",
    "desfreariam": "desfrear",
    "desfrearias": "desfrear",
    "desfrearmo": "desfrear",
    "desfrearmos": "desfrear",
    "desfreará": "desfrear",
    "desfrearás": "desfrear",
    "desfrearão": "desfrear",
    "desfrearíamos": "desfrear",
    "desfrearíeis": "desfrear",
    "desfreasse": "desfrear",
    "desfreassem": "desfrear",
    "desfreasses": "desfrear",
    "desfreaste": "desfrear",
    "desfreastes": "desfrear",
    "desfreava": "desfrear",
    "desfreavam": "desfrear",
    "desfreavas": "desfrear",
    "desfrecha": "desfrechar",
    "desfrechada": "desfrechar",
    "desfrechadas": "desfrechar",
    "desfrechado": "desfrechar",
    "desfrechados": "desfrechar",
    "desfrechai": "desfrechar",
    "desfrechais": "desfrechar",
    "desfrecham": "desfrechar",
    "desfrechamo": "desfrechar",
    "desfrechamos": "desfrechar",
    "desfrechando": "desfrechar",
    "desfrechara": "desfrechar",
    "desfrecharam": "desfrechar",
    "desfrecharas": "desfrechar",
    "desfrecharde": "desfrechar",
    "desfrechardes": "desfrechar",
    "desfrechare": "desfrechar",
    "desfrecharei": "desfrechar",
    "desfrechareis": "desfrechar",
    "desfrecharem": "desfrechar",
    "desfrecharemos": "desfrechar",
    "desfrechares": "desfrechar",
    "desfrecharia": "desfrechar",
    "desfrechariam": "desfrechar",
    "desfrecharias": "desfrechar",
    "desfrecharmo": "desfrechar",
    "desfrecharmos": "desfrechar",
    "desfrechará": "desfrechar",
    "desfrecharás": "desfrechar",
    "desfrecharão": "desfrechar",
    "desfrecharíamos": "desfrechar",
    "desfrecharíeis": "desfrechar",
    "desfrechas": "desfrechar",
    "desfrechasse": "desfrechar",
    "desfrechassem": "desfrechar",
    "desfrechasses": "desfrechar",
    "desfrechaste": "desfrechar",
    "desfrechastes": "desfrechar",
    "desfrechava": "desfrechar",
    "desfrechavam": "desfrechar",
    "desfrechavas": "desfrechar",
    "desfreche": "desfrechar",
    "desfrechei": "desfrechar",
    "desfrecheis": "desfrechar",
    "desfrechem": "desfrechar",
    "desfrechemo": "desfrechar",
    "desfrechemos": "desfrechar",
    "desfreches": "desfrechar",
    "desfrecho": "desfrechar",
    "desfrechou": "desfrechar",
    "desfrechá": "desfrechar",
    "desfrechámo": "desfrechar",
    "desfrechámos": "desfrechar",
    "desfrecháramo": "desfrechar",
    "desfrecháramos": "desfrechar",
    "desfrechárei": "desfrechar",
    "desfrecháreis": "desfrechar",
    "desfrechásseis": "desfrechar",
    "desfrechássemos": "desfrechar",
    "desfrechávamo": "desfrechar",
    "desfrechávamos": "desfrechar",
    "desfrechávei": "desfrechar",
    "desfrecháveis": "desfrechar",
    "desfreei": "desfrear",
    "desfreeis": "desfrear",
    "desfreemo": "desfrear",
    "desfreemos": "desfrear",
    "desfreia": "desfrear",
    "desfreiam": "desfrear",
    "desfreias": "desfrear",
    "desfreie": "desfrear",
    "desfreiem": "desfrear",
    "desfreies": "desfrear",
    "desfreio": "desfrear",
    "desfreou": "desfrear",
    "desfrequenta": "desfrequentar",
    "desfrequentada": "desfrequentar",
    "desfrequentadas": "desfrequentar",
    "desfrequentado": "desfrequentar",
    "desfrequentados": "desfrequentar",
    "desfrequentai": "desfrequentar",
    "desfrequentais": "desfrequentar",
    "desfrequentam": "desfrequentar",
    "desfrequentamo": "desfrequentar",
    "desfrequentamos": "desfrequentar",
    "desfrequentando": "desfrequentar",
    "desfrequentara": "desfrequentar",
    "desfrequentaram": "desfrequentar",
    "desfrequentaras": "desfrequentar",
    "desfrequentarde": "desfrequentar",
    "desfrequentardes": "desfrequentar",
    "desfrequentare": "desfrequentar",
    "desfrequentarei": "desfrequentar",
    "desfrequentareis": "desfrequentar",
    "desfrequentarem": "desfrequentar",
    "desfrequentaremos": "desfrequentar",
    "desfrequentares": "desfrequentar",
    "desfrequentaria": "desfrequentar",
    "desfrequentariam": "desfrequentar",
    "desfrequentarias": "desfrequentar",
    "desfrequentarmo": "desfrequentar",
    "desfrequentarmos": "desfrequentar",
    "desfrequentará": "desfrequentar",
    "desfrequentarás": "desfrequentar",
    "desfrequentarão": "desfrequentar",
    "desfrequentaríamos": "desfrequentar",
    "desfrequentaríeis": "desfrequentar",
    "desfrequentas": "desfrequentar",
    "desfrequentasse": "desfrequentar",
    "desfrequentassem": "desfrequentar",
    "desfrequentasses": "desfrequentar",
    "desfrequentaste": "desfrequentar",
    "desfrequentastes": "desfrequentar",
    "desfrequentava": "desfrequentar",
    "desfrequentavam": "desfrequentar",
    "desfrequentavas": "desfrequentar",
    "desfrequente": "desfrequentar",
    "desfrequentei": "desfrequentar",
    "desfrequenteis": "desfrequentar",
    "desfrequentem": "desfrequentar",
    "desfrequentemo": "desfrequentar",
    "desfrequentemos": "desfrequentar",
    "desfrequentes": "desfrequentar",
    "desfrequento": "desfrequentar",
    "desfrequentou": "desfrequentar",
    "desfrequentá": "desfrequentar",
    "desfrequentámo": "desfrequentar",
    "desfrequentámos": "desfrequentar",
    "desfrequentáramo": "desfrequentar",
    "desfrequentáramos": "desfrequentar",
    "desfrequentárei": "desfrequentar",
    "desfrequentáreis": "desfrequentar",
    "desfrequentásseis": "desfrequentar",
    "desfrequentássemos": "desfrequentar",
    "desfrequentávamo": "desfrequentar",
    "desfrequentávamos": "desfrequentar",
    "desfrequentávei": "desfrequentar",
    "desfrequentáveis": "desfrequentar",
    "desfreá": "desfrear",
    "desfreámo": "desfrear",
    "desfreámos": "desfrear",
    "desfreáramo": "desfrear",
    "desfreáramos": "desfrear",
    "desfreárei": "desfrear",
    "desfreáreis": "desfrear",
    "desfreásseis": "desfrear",
    "desfreássemos": "desfrear",
    "desfreávamo": "desfrear",
    "desfreávamos": "desfrear",
    "desfreávei": "desfrear",
    "desfreáveis": "desfrear",
    "desfrisa": "desfrisar",
    "desfrisada": "desfrisar",
    "desfrisadas": "desfrisar",
    "desfrisado": "desfrisar",
    "desfrisados": "desfrisar",
    "desfrisai": "desfrisar",
    "desfrisais": "desfrisar",
    "desfrisam": "desfrisar",
    "desfrisamo": "desfrisar",
    "desfrisamos": "desfrisar",
    "desfrisando": "desfrisar",
    "desfrisantes": "desfrisante",
    "desfrisara": "desfrisar",
    "desfrisaram": "desfrisar",
    "desfrisaras": "desfrisar",
    "desfrisarde": "desfrisar",
    "desfrisardes": "desfrisar",
    "desfrisare": "desfrisar",
    "desfrisarei": "desfrisar",
    "desfrisareis": "desfrisar",
    "desfrisarem": "desfrisar",
    "desfrisaremos": "desfrisar",
    "desfrisares": "desfrisar",
    "desfrisaria": "desfrisar",
    "desfrisariam": "desfrisar",
    "desfrisarias": "desfrisar",
    "desfrisarmo": "desfrisar",
    "desfrisarmos": "desfrisar",
    "desfrisará": "desfrisar",
    "desfrisarás": "desfrisar",
    "desfrisarão": "desfrisar",
    "desfrisaríamos": "desfrisar",
    "desfrisaríeis": "desfrisar",
    "desfrisas": "desfrisar",
    "desfrisasse": "desfrisar",
    "desfrisassem": "desfrisar",
    "desfrisasses": "desfrisar",
    "desfrisaste": "desfrisar",
    "desfrisastes": "desfrisar",
    "desfrisava": "desfrisar",
    "desfrisavam": "desfrisar",
    "desfrisavas": "desfrisar",
    "desfrise": "desfrisar",
    "desfrisei": "desfrisar",
    "desfriseis": "desfrisar",
    "desfrisem": "desfrisar",
    "desfrisemo": "desfrisar",
    "desfrisemos": "desfrisar",
    "desfrises": "desfrisar",
    "desfriso": "desfrisar",
    "desfrisou": "desfrisar",
    "desfrisá": "desfrisar",
    "desfrisámo": "desfrisar",
    "desfrisámos": "desfrisar",
    "desfrisáramo": "desfrisar",
    "desfrisáramos": "desfrisar",
    "desfrisárei": "desfrisar",
    "desfrisáreis": "desfrisar",
    "desfrisásseis": "desfrisar",
    "desfrisássemos": "desfrisar",
    "desfrisávamo": "desfrisar",
    "desfrisávamos": "desfrisar",
    "desfrisávei": "desfrisar",
    "desfrisáveis": "desfrisar",
    "desfrua": "desfruir",
    "desfruais": "desfruir",
    "desfruam": "desfruir",
    "desfruamo": "desfruir",
    "desfruamos": "desfruir",
    "desfruas": "desfruir",
    "desfruem": "desfruir",
    "desfrui": "desfruir",
    "desfruida": "desfruido",
    "desfruidas": "desfruido",
    "desfruidos": "desfruido",
    "desfruindo": "desfruir",
    "desfruirde": "desfruir",
    "desfruirdes": "desfruir",
    "desfruirei": "desfruir",
    "desfruireis": "desfruir",
    "desfruiremos": "desfruir",
    "desfruiria": "desfruir",
    "desfruiriam": "desfruir",
    "desfruirias": "desfruir",
    "desfruirmo": "desfruir",
    "desfruirmos": "desfruir",
    "desfruirá": "desfruir",
    "desfruirás": "desfruir",
    "desfruirão": "desfruir",
    "desfruiríamos": "desfruir",
    "desfruiríeis": "desfruir",
    "desfruis": "desfruir",
    "desfruiu": "desfruir",
    "desfruo": "desfruir",
    "desfruta": "desfrutar",
    "desfrutada": "desfrutar",
    "desfrutadas": "desfrutar",
    "desfrutado": "desfrutar",
    "desfrutadora": "desfrutador",
    "desfrutadoras": "desfrutador",
    "desfrutadores": "desfrutador",
    "desfrutados": "desfrutar",
    "desfrutai": "desfrutar",
    "desfrutais": "desfrutar",
    "desfrutam": "desfrutar",
    "desfrutamo": "desfrutar",
    "desfrutamos": "desfrutar",
    "desfrutando": "desfrutar",
    "desfrutara": "desfrutar",
    "desfrutaram": "desfrutar",
    "desfrutaras": "desfrutar",
    "desfrutarde": "desfrutar",
    "desfrutardes": "desfrutar",
    "desfrutare": "desfrutar",
    "desfrutarei": "desfrutar",
    "desfrutareis": "desfrutar",
    "desfrutarem": "desfrutar",
    "desfrutaremos": "desfrutar",
    "desfrutares": "desfrutar",
    "desfrutaria": "desfrutar",
    "desfrutariam": "desfrutar",
    "desfrutarias": "desfrutar",
    "desfrutarmo": "desfrutar",
    "desfrutarmos": "desfrutar",
    "desfrutará": "desfrutar",
    "desfrutarás": "desfrutar",
    "desfrutarão": "desfrutar",
    "desfrutaríamos": "desfrutar",
    "desfrutaríeis": "desfrutar",
    "desfrutas": "desfrutar",
    "desfrutasse": "desfrutar",
    "desfrutassem": "desfrutar",
    "desfrutasses": "desfrutar",
    "desfrutaste": "desfrutar",
    "desfrutastes": "desfrutar",
    "desfrutava": "desfrutar",
    "desfrutavam": "desfrutar",
    "desfrutavas": "desfrutar",
    "desfrutações": "desfrutação",
    "desfrute": "desfrutar",
    "desfrutece": "desfrutecer",
    "desfrutecei": "desfrutecer",
    "desfruteceis": "desfrutecer",
    "desfrutecem": "desfrutecer",
    "desfrutecemo": "desfrutecer",
    "desfrutecemos": "desfrutecer",
    "desfrutecendo": "desfrutecer",
    "desfrutecera": "desfrutecer",
    "desfruteceram": "desfrutecer",
    "desfruteceras": "desfrutecer",
    "desfrutecerdes": "desfrutecer",
    "desfrutecerei": "desfrutecer",
    "desfrutecereis": "desfrutecer",
    "desfrutecerem": "desfrutecer",
    "desfruteceremos": "desfrutecer",
    "desfruteceres": "desfrutecer",
    "desfruteceria": "desfrutecer",
    "desfruteceriam": "desfrutecer",
    "desfrutecerias": "desfrutecer",
    "desfrutecermo": "desfrutecer",
    "desfrutecermos": "desfrutecer",
    "desfrutecerá": "desfrutecer",
    "desfrutecerás": "desfrutecer",
    "desfrutecerão": "desfrutecer",
    "desfruteceríamos": "desfrutecer",
    "desfruteceríeis": "desfrutecer",
    "desfruteces": "desfrutecer",
    "desfrutecesse": "desfrutecer",
    "desfrutecessem": "desfrutecer",
    "desfrutecesses": "desfrutecer",
    "desfruteceste": "desfrutecer",
    "desfrutecestes": "desfrutecer",
    "desfruteceu": "desfrutecer",
    "desfruteci": "desfrutecer",
    "desfrutecia": "desfrutecer",
    "desfruteciam": "desfrutecer",
    "desfrutecias": "desfrutecer",
    "desfrutecida": "desfrutecer",
    "desfrutecidas": "desfrutecer",
    "desfrutecido": "desfrutecer",
    "desfrutecidos": "desfrutecer",
    "desfrutecêramo": "desfrutecer",
    "desfrutecêramos": "desfrutecer",
    "desfrutecêreis": "desfrutecer",
    "desfrutecêsseis": "desfrutecer",
    "desfrutecêssemos": "desfrutecer",
    "desfrutecíamo": "desfrutecer",
    "desfrutecíamos": "desfrutecer",
    "desfrutecíeis": "desfrutecer",
    "desfrutei": "desfrutar",
    "desfruteis": "desfrutar",
    "desfrutem": "desfrutar",
    "desfrutemo": "desfrutar",
    "desfrutemos": "desfrutar",
    "desfrutes": "desfrute",
    "desfruteça": "desfrutecer",
    "desfruteçais": "desfrutecer",
    "desfruteçam": "desfrutecer",
    "desfruteçamo": "desfrutecer",
    "desfruteçamos": "desfrutecer",
    "desfruteças": "desfrutecer",
    "desfruteço": "desfrutecer",
    "desfruto": "desfrutar",
    "desfrutou": "desfrutar",
    "desfrutá": "desfrutar",
    "desfrutámo": "desfrutar",
    "desfrutámos": "desfrutar",
    "desfrutáramo": "desfrutar",
    "desfrutáramos": "desfrutar",
    "desfrutárei": "desfrutar",
    "desfrutáreis": "desfrutar",
    "desfrutásseis": "desfrutar",
    "desfrutássemos": "desfrutar",
    "desfrutávamo": "desfrutar",
    "desfrutávamos": "desfrutar",
    "desfrutávei": "desfrutar",
    "desfrutáveis": "desfrutável",
    "desfruí": "desfruir",
    "desfruía": "desfruir",
    "desfruíam": "desfruir",
    "desfruíamo": "desfruir",
    "desfruíamos": "desfruir",
    "desfruías": "desfruir",
    "desfruída": "desfruir",
    "desfruídas": "desfruir",
    "desfruído": "desfruir",
    "desfruídos": "desfruir",
    "desfruíei": "desfruir",
    "desfruíeis": "desfruir",
    "desfruímo": "desfruir",
    "desfruímos": "desfruir",
    "desfruíra": "desfruir",
    "desfruíram": "desfruir",
    "desfruíramo": "desfruir",
    "desfruíramos": "desfruir",
    "desfruíras": "desfruir",
    "desfruíre": "desfruir",
    "desfruírei": "desfruir",
    "desfruíreis": "desfruir",
    "desfruírem": "desfruir",
    "desfruíres": "desfruir",
    "desfruís": "desfruir",
    "desfruísse": "desfruir",
    "desfruísseis": "desfruir",
    "desfruíssem": "desfruir",
    "desfruíssemos": "desfruir",
    "desfruísses": "desfruir",
    "desfruíste": "desfruir",
    "desfruístes": "desfruir",
    "desfunda": "desfundar",
    "desfundada": "desfundar",
    "desfundadas": "desfundar",
    "desfundado": "desfundar",
    "desfundados": "desfundar",
    "desfundai": "desfundar",
    "desfundais": "desfundar",
    "desfundam": "desfundar",
    "desfundamo": "desfundar",
    "desfundamos": "desfundar",
    "desfundando": "desfundar",
    "desfundara": "desfundar",
    "desfundaram": "desfundar",
    "desfundaras": "desfundar",
    "desfundarde": "desfundar",
    "desfundardes": "desfundar",
    "desfundare": "desfundar",
    "desfundarei": "desfundar",
    "desfundareis": "desfundar",
    "desfundarem": "desfundar",
    "desfundaremos": "desfundar",
    "desfundares": "desfundar",
    "desfundaria": "desfundar",
    "desfundariam": "desfundar",
    "desfundarias": "desfundar",
    "desfundarmo": "desfundar",
    "desfundarmos": "desfundar",
    "desfundará": "desfundar",
    "desfundarás": "desfundar",
    "desfundarão": "desfundar",
    "desfundaríamos": "desfundar",
    "desfundaríeis": "desfundar",
    "desfundas": "desfundar",
    "desfundasse": "desfundar",
    "desfundassem": "desfundar",
    "desfundasses": "desfundar",
    "desfundaste": "desfundar",
    "desfundastes": "desfundar",
    "desfundava": "desfundar",
    "desfundavam": "desfundar",
    "desfundavas": "desfundar",
    "desfunde": "desfundar",
    "desfundei": "desfundar",
    "desfundeis": "desfundar",
    "desfundem": "desfundar",
    "desfundemo": "desfundar",
    "desfundemos": "desfundar",
    "desfundes": "desfundar",
    "desfundo": "desfundar",
    "desfundou": "desfundar",
    "desfundá": "desfundar",
    "desfundámo": "desfundar",
    "desfundámos": "desfundar",
    "desfundáramo": "desfundar",
    "desfundáramos": "desfundar",
    "desfundárei": "desfundar",
    "desfundáreis": "desfundar",
    "desfundásseis": "desfundar",
    "desfundássemos": "desfundar",
    "desfundávamo": "desfundar",
    "desfundávamos": "desfundar",
    "desfundávei": "desfundar",
    "desfundáveis": "desfundar",
    "desfá": "desfazer",
    "desfê": "desfazer",
    "desgaba": "desgabar",
    "desgabada": "desgabar",
    "desgabadas": "desgabar",
    "desgabado": "desgabar",
    "desgabadora": "desgabador",
    "desgabadoras": "desgabador",
    "desgabadores": "desgabador",
    "desgabados": "desgabar",
    "desgabai": "desgabar",
    "desgabais": "desgabar",
    "desgabam": "desgabar",
    "desgabamo": "desgabar",
    "desgabamos": "desgabar",
    "desgabando": "desgabar",
    "desgabara": "desgabar",
    "desgabaram": "desgabar",
    "desgabaras": "desgabar",
    "desgabarde": "desgabar",
    "desgabardes": "desgabar",
    "desgabare": "desgabar",
    "desgabarei": "desgabar",
    "desgabareis": "desgabar",
    "desgabarem": "desgabar",
    "desgabaremos": "desgabar",
    "desgabares": "desgabar",
    "desgabaria": "desgabar",
    "desgabariam": "desgabar",
    "desgabarias": "desgabar",
    "desgabarmo": "desgabar",
    "desgabarmos": "desgabar",
    "desgabará": "desgabar",
    "desgabarás": "desgabar",
    "desgabarão": "desgabar",
    "desgabaríamos": "desgabar",
    "desgabaríeis": "desgabar",
    "desgabas": "desgabar",
    "desgabasse": "desgabar",
    "desgabassem": "desgabar",
    "desgabasses": "desgabar",
    "desgabaste": "desgabar",
    "desgabastes": "desgabar",
    "desgabava": "desgabar",
    "desgabavam": "desgabar",
    "desgabavas": "desgabar",
    "desgabe": "desgabar",
    "desgabei": "desgabar",
    "desgabeis": "desgabar",
    "desgabem": "desgabar",
    "desgabemo": "desgabar",
    "desgabemos": "desgabar",
    "desgabes": "desgabar",
    "desgabo": "desgabar",
    "desgabos": "desgabo",
    "desgabou": "desgabar",
    "desgabá": "desgabar",
    "desgabámo": "desgabar",
    "desgabámos": "desgabar",
    "desgabáramo": "desgabar",
    "desgabáramos": "desgabar",
    "desgabárei": "desgabar",
    "desgabáreis": "desgabar",
    "desgabásseis": "desgabar",
    "desgabássemos": "desgabar",
    "desgabávamo": "desgabar",
    "desgabávamos": "desgabar",
    "desgabávei": "desgabar",
    "desgabáveis": "desgabar",
    "desgadelha": "desgadelhar",
    "desgadelhada": "desgadelhar",
    "desgadelhadas": "desgadelhar",
    "desgadelhado": "desgadelhar",
    "desgadelhados": "desgadelhar",
    "desgadelhai": "desgadelhar",
    "desgadelhais": "desgadelhar",
    "desgadelham": "desgadelhar",
    "desgadelhamo": "desgadelhar",
    "desgadelhamos": "desgadelhar",
    "desgadelhando": "desgadelhar",
    "desgadelhara": "desgadelhar",
    "desgadelharam": "desgadelhar",
    "desgadelharas": "desgadelhar",
    "desgadelharde": "desgadelhar",
    "desgadelhardes": "desgadelhar",
    "desgadelhare": "desgadelhar",
    "desgadelharei": "desgadelhar",
    "desgadelhareis": "desgadelhar",
    "desgadelharem": "desgadelhar",
    "desgadelharemos": "desgadelhar",
    "desgadelhares": "desgadelhar",
    "desgadelharia": "desgadelhar",
    "desgadelhariam": "desgadelhar",
    "desgadelharias": "desgadelhar",
    "desgadelharmo": "desgadelhar",
    "desgadelharmos": "desgadelhar",
    "desgadelhará": "desgadelhar",
    "desgadelharás": "desgadelhar",
    "desgadelharão": "desgadelhar",
    "desgadelharíamos": "desgadelhar",
    "desgadelharíeis": "desgadelhar",
    "desgadelhas": "desgadelhar",
    "desgadelhasse": "desgadelhar",
    "desgadelhassem": "desgadelhar",
    "desgadelhasses": "desgadelhar",
    "desgadelhaste": "desgadelhar",
    "desgadelhastes": "desgadelhar",
    "desgadelhava": "desgadelhar",
    "desgadelhavam": "desgadelhar",
    "desgadelhavas": "desgadelhar",
    "desgadelhe": "desgadelhar",
    "desgadelhei": "desgadelhar",
    "desgadelheis": "desgadelhar",
    "desgadelhem": "desgadelhar",
    "desgadelhemo": "desgadelhar",
    "desgadelhemos": "desgadelhar",
    "desgadelhes": "desgadelhar",
    "desgadelho": "desgadelhar",
    "desgadelhou": "desgadelhar",
    "desgadelhá": "desgadelhar",
    "desgadelhámo": "desgadelhar",
    "desgadelhámos": "desgadelhar",
    "desgadelháramo": "desgadelhar",
    "desgadelháramos": "desgadelhar",
    "desgadelhárei": "desgadelhar",
    "desgadelháreis": "desgadelhar",
    "desgadelhásseis": "desgadelhar",
    "desgadelhássemos": "desgadelhar",
    "desgadelhávamo": "desgadelhar",
    "desgadelhávamos": "desgadelhar",
    "desgadelhávei": "desgadelhar",
    "desgadelháveis": "desgadelhar",
    "desgalantes": "desgalante",
    "desgalga": "desgalgar",
    "desgalgada": "desgalgar",
    "desgalgadas": "desgalgar",
    "desgalgado": "desgalgar",
    "desgalgados": "desgalgar",
    "desgalgai": "desgalgar",
    "desgalgais": "desgalgar",
    "desgalgam": "desgalgar",
    "desgalgamo": "desgalgar",
    "desgalgamos": "desgalgar",
    "desgalgando": "desgalgar",
    "desgalgara": "desgalgar",
    "desgalgaram": "desgalgar",
    "desgalgaras": "desgalgar",
    "desgalgarde": "desgalgar",
    "desgalgardes": "desgalgar",
    "desgalgare": "desgalgar",
    "desgalgarei": "desgalgar",
    "desgalgareis": "desgalgar",
    "desgalgarem": "desgalgar",
    "desgalgaremos": "desgalgar",
    "desgalgares": "desgalgar",
    "desgalgaria": "desgalgar",
    "desgalgariam": "desgalgar",
    "desgalgarias": "desgalgar",
    "desgalgarmo": "desgalgar",
    "desgalgarmos": "desgalgar",
    "desgalgará": "desgalgar",
    "desgalgarás": "desgalgar",
    "desgalgarão": "desgalgar",
    "desgalgaríamos": "desgalgar",
    "desgalgaríeis": "desgalgar",
    "desgalgas": "desgalgar",
    "desgalgasse": "desgalgar",
    "desgalgassem": "desgalgar",
    "desgalgasses": "desgalgar",
    "desgalgaste": "desgalgar",
    "desgalgastes": "desgalgar",
    "desgalgava": "desgalgar",
    "desgalgavam": "desgalgar",
    "desgalgavas": "desgalgar",
    "desgalgo": "desgalgar",
    "desgalgou": "desgalgar",
    "desgalgue": "desgalgar",
    "desgalguei": "desgalgar",
    "desgalgueis": "desgalgar",
    "desgalguem": "desgalgar",
    "desgalguemo": "desgalgar",
    "desgalguemos": "desgalgar",
    "desgalgues": "desgalgar",
    "desgalgá": "desgalgar",
    "desgalgámo": "desgalgar",
    "desgalgámos": "desgalgar",
    "desgalgáramo": "desgalgar",
    "desgalgáramos": "desgalgar",
    "desgalgárei": "desgalgar",
    "desgalgáreis": "desgalgar",
    "desgalgásseis": "desgalgar",
    "desgalgássemos": "desgalgar",
    "desgalgávamo": "desgalgar",
    "desgalgávamos": "desgalgar",
    "desgalgávei": "desgalgar",
    "desgalgáveis": "desgalgar",
    "desgalha": "desgalhar",
    "desgalhada": "desgalhar",
    "desgalhadas": "desgalhar",
    "desgalhado": "desgalhar",
    "desgalhados": "desgalhar",
    "desgalhai": "desgalhar",
    "desgalhais": "desgalhar",
    "desgalham": "desgalhar",
    "desgalhamo": "desgalhar",
    "desgalhamos": "desgalhar",
    "desgalhando": "desgalhar",
    "desgalhara": "desgalhar",
    "desgalharam": "desgalhar",
    "desgalharas": "desgalhar",
    "desgalharde": "desgalhar",
    "desgalhardes": "desgalhar",
    "desgalhare": "desgalhar",
    "desgalharei": "desgalhar",
    "desgalhareis": "desgalhar",
    "desgalharem": "desgalhar",
    "desgalharemos": "desgalhar",
    "desgalhares": "desgalhar",
    "desgalharia": "desgalhar",
    "desgalhariam": "desgalhar",
    "desgalharias": "desgalhar",
    "desgalharmo": "desgalhar",
    "desgalharmos": "desgalhar",
    "desgalhará": "desgalhar",
    "desgalharás": "desgalhar",
    "desgalharão": "desgalhar",
    "desgalharíamos": "desgalhar",
    "desgalharíeis": "desgalhar",
    "desgalhas": "desgalhar",
    "desgalhasse": "desgalhar",
    "desgalhassem": "desgalhar",
    "desgalhasses": "desgalhar",
    "desgalhaste": "desgalhar",
    "desgalhastes": "desgalhar",
    "desgalhava": "desgalhar",
    "desgalhavam": "desgalhar",
    "desgalhavas": "desgalhar",
    "desgalhe": "desgalhar",
    "desgalhei": "desgalhar",
    "desgalheis": "desgalhar",
    "desgalhem": "desgalhar",
    "desgalhemo": "desgalhar",
    "desgalhemos": "desgalhar",
    "desgalhes": "desgalhar",
    "desgalho": "desgalhar",
    "desgalhou": "desgalhar",
    "desgalhá": "desgalhar",
    "desgalhámo": "desgalhar",
    "desgalhámos": "desgalhar",
    "desgalháramo": "desgalhar",
    "desgalháramos": "desgalhar",
    "desgalhárei": "desgalhar",
    "desgalháreis": "desgalhar",
    "desgalhásseis": "desgalhar",
    "desgalhássemos": "desgalhar",
    "desgalhávamo": "desgalhar",
    "desgalhávamos": "desgalhar",
    "desgalhávei": "desgalhar",
    "desgalháveis": "desgalhar",
    "desgalvaniza": "desgalvanizar",
    "desgalvanizada": "desgalvanizar",
    "desgalvanizadas": "desgalvanizar",
    "desgalvanizado": "desgalvanizar",
    "desgalvanizados": "desgalvanizar",
    "desgalvanizai": "desgalvanizar",
    "desgalvanizais": "desgalvanizar",
    "desgalvanizam": "desgalvanizar",
    "desgalvanizamo": "desgalvanizar",
    "desgalvanizamos": "desgalvanizar",
    "desgalvanizando": "desgalvanizar",
    "desgalvanizara": "desgalvanizar",
    "desgalvanizaram": "desgalvanizar",
    "desgalvanizaras": "desgalvanizar",
    "desgalvanizarde": "desgalvanizar",
    "desgalvanizardes": "desgalvanizar",
    "desgalvanizare": "desgalvanizar",
    "desgalvanizarei": "desgalvanizar",
    "desgalvanizareis": "desgalvanizar",
    "desgalvanizarem": "desgalvanizar",
    "desgalvanizaremos": "desgalvanizar",
    "desgalvanizares": "desgalvanizar",
    "desgalvanizaria": "desgalvanizar",
    "desgalvanizariam": "desgalvanizar",
    "desgalvanizarias": "desgalvanizar",
    "desgalvanizarmo": "desgalvanizar",
    "desgalvanizarmos": "desgalvanizar",
    "desgalvanizará": "desgalvanizar",
    "desgalvanizarás": "desgalvanizar",
    "desgalvanizarão": "desgalvanizar",
    "desgalvanizaríamos": "desgalvanizar",
    "desgalvanizaríeis": "desgalvanizar",
    "desgalvanizas": "desgalvanizar",
    "desgalvanizasse": "desgalvanizar",
    "desgalvanizassem": "desgalvanizar",
    "desgalvanizasses": "desgalvanizar",
    "desgalvanizaste": "desgalvanizar",
    "desgalvanizastes": "desgalvanizar",
    "desgalvanizava": "desgalvanizar",
    "desgalvanizavam": "desgalvanizar",
    "desgalvanizavas": "desgalvanizar",
    "desgalvanizações": "desgalvanização",
    "desgalvanize": "desgalvanizar",
    "desgalvanizei": "desgalvanizar",
    "desgalvanizeis": "desgalvanizar",
    "desgalvanizem": "desgalvanizar",
    "desgalvanizemo": "desgalvanizar",
    "desgalvanizemos": "desgalvanizar",
    "desgalvanizes": "desgalvanizar",
    "desgalvanizo": "desgalvanizar",
    "desgalvanizou": "desgalvanizar",
    "desgalvanizá": "desgalvanizar",
    "desgalvanizámo": "desgalvanizar",
    "desgalvanizámos": "desgalvanizar",
    "desgalvanizáramo": "desgalvanizar",
    "desgalvanizáramos": "desgalvanizar",
    "desgalvanizárei": "desgalvanizar",
    "desgalvanizáreis": "desgalvanizar",
    "desgalvanizásseis": "desgalvanizar",
    "desgalvanizássemos": "desgalvanizar",
    "desgalvanizávamo": "desgalvanizar",
    "desgalvanizávamos": "desgalvanizar",
    "desgalvanizávei": "desgalvanizar",
    "desgalvanizáveis": "desgalvanizar",
    "desgaranta": "desgarantir",
    "desgarantais": "desgarantir",
    "desgarantam": "desgarantir",
    "desgarantamo": "desgarantir",
    "desgarantamos": "desgarantir",
    "desgarantas": "desgarantir",
    "desgarante": "desgarantir",
    "desgarantem": "desgarantir",
    "desgarantes": "desgarantir",
    "desgaranti": "desgarantir",
    "desgarantia": "desgarantir",
    "desgarantiam": "desgarantir",
    "desgarantias": "desgarantir",
    "desgarantida": "desgarantir",
    "desgarantidas": "desgarantir",
    "desgarantido": "desgarantir",
    "desgarantidos": "desgarantir",
    "desgarantimo": "desgarantir",
    "desgarantimos": "desgarantir",
    "desgarantindo": "desgarantir",
    "desgarantira": "desgarantir",
    "desgarantiram": "desgarantir",
    "desgarantiras": "desgarantir",
    "desgarantirde": "desgarantir",
    "desgarantirdes": "desgarantir",
    "desgarantire": "desgarantir",
    "desgarantirei": "desgarantir",
    "desgarantireis": "desgarantir",
    "desgarantirem": "desgarantir",
    "desgarantiremos": "desgarantir",
    "desgarantires": "desgarantir",
    "desgarantiria": "desgarantir",
    "desgarantiriam": "desgarantir",
    "desgarantirias": "desgarantir",
    "desgarantirmo": "desgarantir",
    "desgarantirmos": "desgarantir",
    "desgarantirá": "desgarantir",
    "desgarantirás": "desgarantir",
    "desgarantirão": "desgarantir",
    "desgarantiríamos": "desgarantir",
    "desgarantiríeis": "desgarantir",
    "desgarantis": "desgarantir",
    "desgarantisse": "desgarantir",
    "desgarantissem": "desgarantir",
    "desgarantisses": "desgarantir",
    "desgarantiste": "desgarantir",
    "desgarantistes": "desgarantir",
    "desgarantiu": "desgarantir",
    "desgaranto": "desgarantir",
    "desgarantíamo": "desgarantir",
    "desgarantíamos": "desgarantir",
    "desgarantíei": "desgarantir",
    "desgarantíeis": "desgarantir",
    "desgarantíramo": "desgarantir",
    "desgarantíramos": "desgarantir",
    "desgarantírei": "desgarantir",
    "desgarantíreis": "desgarantir",
    "desgarantísseis": "desgarantir",
    "desgarantíssemos": "desgarantir",
    "desgargala": "desgargalar",
    "desgargalada": "desgargalar",
    "desgargaladas": "desgargalar",
    "desgargalado": "desgargalar",
    "desgargalados": "desgargalar",
    "desgargalai": "desgargalar",
    "desgargalais": "desgargalar",
    "desgargalam": "desgargalar",
    "desgargalamo": "desgargalar",
    "desgargalamos": "desgargalar",
    "desgargalando": "desgargalar",
    "desgargalara": "desgargalar",
    "desgargalaram": "desgargalar",
    "desgargalaras": "desgargalar",
    "desgargalarde": "desgargalar",
    "desgargalardes": "desgargalar",
    "desgargalare": "desgargalar",
    "desgargalarei": "desgargalar",
    "desgargalareis": "desgargalar",
    "desgargalarem": "desgargalar",
    "desgargalaremos": "desgargalar",
    "desgargalares": "desgargalar",
    "desgargalaria": "desgargalar",
    "desgargalariam": "desgargalar",
    "desgargalarias": "desgargalar",
    "desgargalarmo": "desgargalar",
    "desgargalarmos": "desgargalar",
    "desgargalará": "desgargalar",
    "desgargalarás": "desgargalar",
    "desgargalarão": "desgargalar",
    "desgargalaríamos": "desgargalar",
    "desgargalaríeis": "desgargalar",
    "desgargalas": "desgargalar",
    "desgargalasse": "desgargalar",
    "desgargalassem": "desgargalar",
    "desgargalasses": "desgargalar",
    "desgargalaste": "desgargalar",
    "desgargalastes": "desgargalar",
    "desgargalava": "desgargalar",
    "desgargalavam": "desgargalar",
    "desgargalavas": "desgargalar",
    "desgargale": "desgargalar",
    "desgargalei": "desgargalar",
    "desgargaleis": "desgargalar",
    "desgargalem": "desgargalar",
    "desgargalemo": "desgargalar",
    "desgargalemos": "desgargalar",
    "desgargales": "desgargalar",
    "desgargalo": "desgargalar",
    "desgargalou": "desgargalar",
    "desgargalá": "desgargalar",
    "desgargalámo": "desgargalar",
    "desgargalámos": "desgargalar",
    "desgargaláramo": "desgargalar",
    "desgargaláramos": "desgargalar",
    "desgargalárei": "desgargalar",
    "desgargaláreis": "desgargalar",
    "desgargalásseis": "desgargalar",
    "desgargalássemos": "desgargalar",
    "desgargalávamo": "desgargalar",
    "desgargalávamos": "desgargalar",
    "desgargalávei": "desgargalar",
    "desgargaláveis": "desgargalar",
    "desgarra": "desgarrar",
    "desgarrada": "desgarrar",
    "desgarradas": "desgarrar",
    "desgarrado": "desgarrar",
    "desgarrados": "desgarrar",
    "desgarrai": "desgarrar",
    "desgarrais": "desgarrar",
    "desgarram": "desgarrar",
    "desgarramentos": "desgarramento",
    "desgarramo": "desgarrar",
    "desgarramos": "desgarrar",
    "desgarrando": "desgarrar",
    "desgarrara": "desgarrar",
    "desgarraram": "desgarrar",
    "desgarraras": "desgarrar",
    "desgarrarde": "desgarrar",
    "desgarrardes": "desgarrar",
    "desgarrare": "desgarrar",
    "desgarrarei": "desgarrar",
    "desgarrareis": "desgarrar",
    "desgarrarem": "desgarrar",
    "desgarraremos": "desgarrar",
    "desgarrares": "desgarrar",
    "desgarraria": "desgarrar",
    "desgarrariam": "desgarrar",
    "desgarrarias": "desgarrar",
    "desgarrarmo": "desgarrar",
    "desgarrarmos": "desgarrar",
    "desgarrará": "desgarrar",
    "desgarrarás": "desgarrar",
    "desgarrarão": "desgarrar",
    "desgarraríamos": "desgarrar",
    "desgarraríeis": "desgarrar",
    "desgarras": "desgarrar",
    "desgarrasse": "desgarrar",
    "desgarrassem": "desgarrar",
    "desgarrasses": "desgarrar",
    "desgarraste": "desgarrar",
    "desgarrastes": "desgarrar",
    "desgarrava": "desgarrar",
    "desgarravam": "desgarrar",
    "desgarravas": "desgarrar",
    "desgarre": "desgarrar",
    "desgarrei": "desgarrar",
    "desgarreis": "desgarrar",
    "desgarrem": "desgarrar",
    "desgarremo": "desgarrar",
    "desgarremos": "desgarrar",
    "desgarres": "desgarre",
    "desgarro": "desgarrar",
    "desgarrona": "desgarrão",
    "desgarronas": "desgarrão",
    "desgarrou": "desgarrar",
    "desgarrá": "desgarrar",
    "desgarrámo": "desgarrar",
    "desgarrámos": "desgarrar",
    "desgarráramo": "desgarrar",
    "desgarráramos": "desgarrar",
    "desgarrárei": "desgarrar",
    "desgarráreis": "desgarrar",
    "desgarrásseis": "desgarrar",
    "desgarrássemos": "desgarrar",
    "desgarrávamo": "desgarrar",
    "desgarrávamos": "desgarrar",
    "desgarrávei": "desgarrar",
    "desgarráveis": "desgarrar",
    "desgarrões": "desgarrão",
    "desgasta": "desgasto",
    "desgastada": "desgastar",
    "desgastadas": "desgastar",
    "desgastado": "desgastar",
    "desgastados": "desgastar",
    "desgastai": "desgastar",
    "desgastais": "desgastar",
    "desgastam": "desgastar",
    "desgastamo": "desgastar",
    "desgastamos": "desgastar",
    "desgastando": "desgastar",
    "desgastantes": "desgastante",
    "desgastara": "desgastar",
    "desgastaram": "desgastar",
    "desgastaras": "desgastar",
    "desgastarde": "desgastar",
    "desgastardes": "desgastar",
    "desgastare": "desgastar",
    "desgastarei": "desgastar",
    "desgastareis": "desgastar",
    "desgastarem": "desgastar",
    "desgastaremos": "desgastar",
    "desgastares": "desgastar",
    "desgastaria": "desgastar",
    "desgastariam": "desgastar",
    "desgastarias": "desgastar",
    "desgastarmo": "desgastar",
    "desgastarmos": "desgastar",
    "desgastará": "desgastar",
    "desgastarás": "desgastar",
    "desgastarão": "desgastar",
    "desgastaríamos": "desgastar",
    "desgastaríeis": "desgastar",
    "desgastas": "desgasto",
    "desgastasse": "desgastar",
    "desgastassem": "desgastar",
    "desgastasses": "desgastar",
    "desgastaste": "desgastar",
    "desgastastes": "desgastar",
    "desgastava": "desgastar",
    "desgastavam": "desgastar",
    "desgastavas": "desgastar",
    "desgaste": "desgastar",
    "desgastei": "desgastar",
    "desgasteis": "desgastar",
    "desgastem": "desgastar",
    "desgastemo": "desgastar",
    "desgastemos": "desgastar",
    "desgastes": "desgaste",
    "desgasto": "desgastar",
    "desgastos": "desgasto",
    "desgastou": "desgastar",
    "desgastá": "desgastar",
    "desgastámo": "desgastar",
    "desgastámos": "desgastar",
    "desgastáramo": "desgastar",
    "desgastáramos": "desgastar",
    "desgastárei": "desgastar",
    "desgastáreis": "desgastar",
    "desgastásseis": "desgastar",
    "desgastássemos": "desgastar",
    "desgastávamo": "desgastar",
    "desgastávamos": "desgastar",
    "desgastávei": "desgastar",
    "desgastáveis": "desgastável",
    "desgelada": "desgelado",
    "desgeladas": "desgelado",
    "desgelados": "desgelado",
    "desgelos": "desgelo",
    "desglabra": "desglabrar",
    "desglabrada": "desglabrar",
    "desglabradas": "desglabrar",
    "desglabrado": "desglabrar",
    "desglabrados": "desglabrar",
    "desglabrai": "desglabrar",
    "desglabrais": "desglabrar",
    "desglabram": "desglabrar",
    "desglabramo": "desglabrar",
    "desglabramos": "desglabrar",
    "desglabrando": "desglabrar",
    "desglabrara": "desglabrar",
    "desglabraram": "desglabrar",
    "desglabraras": "desglabrar",
    "desglabrarde": "desglabrar",
    "desglabrardes": "desglabrar",
    "desglabrare": "desglabrar",
    "desglabrarei": "desglabrar",
    "desglabrareis": "desglabrar",
    "desglabrarem": "desglabrar",
    "desglabraremos": "desglabrar",
    "desglabrares": "desglabrar",
    "desglabraria": "desglabrar",
    "desglabrariam": "desglabrar",
    "desglabrarias": "desglabrar",
    "desglabrarmo": "desglabrar",
    "desglabrarmos": "desglabrar",
    "desglabrará": "desglabrar",
    "desglabrarás": "desglabrar",
    "desglabrarão": "desglabrar",
    "desglabraríamos": "desglabrar",
    "desglabraríeis": "desglabrar",
    "desglabras": "desglabrar",
    "desglabrasse": "desglabrar",
    "desglabrassem": "desglabrar",
    "desglabrasses": "desglabrar",
    "desglabraste": "desglabrar",
    "desglabrastes": "desglabrar",
    "desglabrava": "desglabrar",
    "desglabravam": "desglabrar",
    "desglabravas": "desglabrar",
    "desglabrações": "desglabração",
    "desglabre": "desglabrar",
    "desglabrei": "desglabrar",
    "desglabreis": "desglabrar",
    "desglabrem": "desglabrar",
    "desglabremo": "desglabrar",
    "desglabremos": "desglabrar",
    "desglabres": "desglabrar",
    "desglabro": "desglabrar",
    "desglabrou": "desglabrar",
    "desglabrá": "desglabrar",
    "desglabrámo": "desglabrar",
    "desglabrámos": "desglabrar",
    "desglabráramo": "desglabrar",
    "desglabráramos": "desglabrar",
    "desglabrárei": "desglabrar",
    "desglabráreis": "desglabrar",
    "desglabrásseis": "desglabrar",
    "desglabrássemos": "desglabrar",
    "desglabrávamo": "desglabrar",
    "desglabrávamos": "desglabrar",
    "desglabrávei": "desglabrar",
    "desglabráveis": "desglabrar",
    "desglobuliza": "desglobulizar",
    "desglobulizada": "desglobulizar",
    "desglobulizadas": "desglobulizar",
    "desglobulizado": "desglobulizar",
    "desglobulizados": "desglobulizar",
    "desglobulizai": "desglobulizar",
    "desglobulizais": "desglobulizar",
    "desglobulizam": "desglobulizar",
    "desglobulizamo": "desglobulizar",
    "desglobulizamos": "desglobulizar",
    "desglobulizando": "desglobulizar",
    "desglobulizara": "desglobulizar",
    "desglobulizaram": "desglobulizar",
    "desglobulizaras": "desglobulizar",
    "desglobulizarde": "desglobulizar",
    "desglobulizardes": "desglobulizar",
    "desglobulizare": "desglobulizar",
    "desglobulizarei": "desglobulizar",
    "desglobulizareis": "desglobulizar",
    "desglobulizarem": "desglobulizar",
    "desglobulizaremos": "desglobulizar",
    "desglobulizares": "desglobulizar",
    "desglobulizaria": "desglobulizar",
    "desglobulizariam": "desglobulizar",
    "desglobulizarias": "desglobulizar",
    "desglobulizarmo": "desglobulizar",
    "desglobulizarmos": "desglobulizar",
    "desglobulizará": "desglobulizar",
    "desglobulizarás": "desglobulizar",
    "desglobulizarão": "desglobulizar",
    "desglobulizaríamos": "desglobulizar",
    "desglobulizaríeis": "desglobulizar",
    "desglobulizas": "desglobulizar",
    "desglobulizasse": "desglobulizar",
    "desglobulizassem": "desglobulizar",
    "desglobulizasses": "desglobulizar",
    "desglobulizaste": "desglobulizar",
    "desglobulizastes": "desglobulizar",
    "desglobulizava": "desglobulizar",
    "desglobulizavam": "desglobulizar",
    "desglobulizavas": "desglobulizar",
    "desglobulize": "desglobulizar",
    "desglobulizei": "desglobulizar",
    "desglobulizeis": "desglobulizar",
    "desglobulizem": "desglobulizar",
    "desglobulizemo": "desglobulizar",
    "desglobulizemos": "desglobulizar",
    "desglobulizes": "desglobulizar",
    "desglobulizo": "desglobulizar",
    "desglobulizou": "desglobulizar",
    "desglobulizá": "desglobulizar",
    "desglobulizámo": "desglobulizar",
    "desglobulizámos": "desglobulizar",
    "desglobulizáramo": "desglobulizar",
    "desglobulizáramos": "desglobulizar",
    "desglobulizárei": "desglobulizar",
    "desglobulizáreis": "desglobulizar",
    "desglobulizásseis": "desglobulizar",
    "desglobulizássemos": "desglobulizar",
    "desglobulizávamo": "desglobulizar",
    "desglobulizávamos": "desglobulizar",
    "desglobulizávei": "desglobulizar",
    "desglobulizáveis": "desglobulizar",
    "desgoela": "desgoelar",
    "desgoelada": "desgoelar",
    "desgoeladas": "desgoelar",
    "desgoelado": "desgoelar",
    "desgoelados": "desgoelar",
    "desgoelai": "desgoelar",
    "desgoelais": "desgoelar",
    "desgoelam": "desgoelar",
    "desgoelamo": "desgoelar",
    "desgoelamos": "desgoelar",
    "desgoelando": "desgoelar",
    "desgoelara": "desgoelar",
    "desgoelaram": "desgoelar",
    "desgoelaras": "desgoelar",
    "desgoelarde": "desgoelar",
    "desgoelardes": "desgoelar",
    "desgoelare": "desgoelar",
    "desgoelarei": "desgoelar",
    "desgoelareis": "desgoelar",
    "desgoelarem": "desgoelar",
    "desgoelaremos": "desgoelar",
    "desgoelares": "desgoelar",
    "desgoelaria": "desgoelar",
    "desgoelariam": "desgoelar",
    "desgoelarias": "desgoelar",
    "desgoelarmo": "desgoelar",
    "desgoelarmos": "desgoelar",
    "desgoelará": "desgoelar",
    "desgoelarás": "desgoelar",
    "desgoelarão": "desgoelar",
    "desgoelaríamos": "desgoelar",
    "desgoelaríeis": "desgoelar",
    "desgoelas": "desgoelar",
    "desgoelasse": "desgoelar",
    "desgoelassem": "desgoelar",
    "desgoelasses": "desgoelar",
    "desgoelaste": "desgoelar",
    "desgoelastes": "desgoelar",
    "desgoelava": "desgoelar",
    "desgoelavam": "desgoelar",
    "desgoelavas": "desgoelar",
    "desgoele": "desgoelar",
    "desgoelei": "desgoelar",
    "desgoeleis": "desgoelar",
    "desgoelem": "desgoelar",
    "desgoelemo": "desgoelar",
    "desgoelemos": "desgoelar",
    "desgoeles": "desgoelar",
    "desgoelo": "desgoelar",
    "desgoelou": "desgoelar",
    "desgoelá": "desgoelar",
    "desgoelámo": "desgoelar",
    "desgoelámos": "desgoelar",
    "desgoeláramo": "desgoelar",
    "desgoeláramos": "desgoelar",
    "desgoelárei": "desgoelar",
    "desgoeláreis": "desgoelar",
    "desgoelásseis": "desgoelar",
    "desgoelássemos": "desgoelar",
    "desgoelávamo": "desgoelar",
    "desgoelávamos": "desgoelar",
    "desgoelávei": "desgoelar",
    "desgoeláveis": "desgoelar",
    "desgorgomilada": "desgorgomilado",
    "desgorgomiladas": "desgorgomilado",
    "desgorgomilados": "desgorgomilado",
    "desgorjada": "desgorjado",
    "desgorjadas": "desgorjado",
    "desgorjados": "desgorjado",
    "desgorna": "desgornir",
    "desgornais": "desgornir",
    "desgornam": "desgornir",
    "desgornamo": "desgornir",
    "desgornamos": "desgornir",
    "desgornas": "desgornir",
    "desgorne": "desgornir",
    "desgornem": "desgornir",
    "desgornes": "desgornir",
    "desgorni": "desgornir",
    "desgornia": "desgornir",
    "desgorniam": "desgornir",
    "desgornias": "desgornir",
    "desgornida": "desgornir",
    "desgornidas": "desgornir",
    "desgornido": "desgornir",
    "desgornidos": "desgornir",
    "desgornimo": "desgornir",
    "desgornimos": "desgornir",
    "desgornindo": "desgornir",
    "desgornira": "desgornir",
    "desgorniram": "desgornir",
    "desgorniras": "desgornir",
    "desgornirde": "desgornir",
    "desgornirdes": "desgornir",
    "desgornire": "desgornir",
    "desgornirei": "desgornir",
    "desgornireis": "desgornir",
    "desgornirem": "desgornir",
    "desgorniremos": "desgornir",
    "desgornires": "desgornir",
    "desgorniria": "desgornir",
    "desgorniriam": "desgornir",
    "desgornirias": "desgornir",
    "desgornirmo": "desgornir",
    "desgornirmos": "desgornir",
    "desgornirá": "desgornir",
    "desgornirás": "desgornir",
    "desgornirão": "desgornir",
    "desgorniríamos": "desgornir",
    "desgorniríeis": "desgornir",
    "desgornis": "desgornir",
    "desgornisse": "desgornir",
    "desgornissem": "desgornir",
    "desgornisses": "desgornir",
    "desgorniste": "desgornir",
    "desgornistes": "desgornir",
    "desgorniu": "desgornir",
    "desgorno": "desgornir",
    "desgorníamo": "desgornir",
    "desgorníamos": "desgornir",
    "desgorníei": "desgornir",
    "desgorníeis": "desgornir",
    "desgorníramo": "desgornir",
    "desgorníramos": "desgornir",
    "desgornírei": "desgornir",
    "desgorníreis": "desgornir",
    "desgornísseis": "desgornir",
    "desgorníssemos": "desgornir",
    "desgosta": "desgostar",
    "desgostada": "desgostar",
    "desgostadas": "desgostar",
    "desgostado": "desgostar",
    "desgostados": "desgostar",
    "desgostai": "desgostar",
    "desgostais": "desgostar",
    "desgostam": "desgostar",
    "desgostamo": "desgostar",
    "desgostamos": "desgostar",
    "desgostando": "desgostar",
    "desgostara": "desgostar",
    "desgostaram": "desgostar",
    "desgostaras": "desgostar",
    "desgostarde": "desgostar",
    "desgostardes": "desgostar",
    "desgostare": "desgostar",
    "desgostarei": "desgostar",
    "desgostareis": "desgostar",
    "desgostarem": "desgostar",
    "desgostaremos": "desgostar",
    "desgostares": "desgostar",
    "desgostaria": "desgostar",
    "desgostariam": "desgostar",
    "desgostarias": "desgostar",
    "desgostarmo": "desgostar",
    "desgostarmos": "desgostar",
    "desgostará": "desgostar",
    "desgostarás": "desgostar",
    "desgostarão": "desgostar",
    "desgostaríamos": "desgostar",
    "desgostaríeis": "desgostar",
    "desgostas": "desgostar",
    "desgostasse": "desgostar",
    "desgostassem": "desgostar",
    "desgostasses": "desgostar",
    "desgostaste": "desgostar",
    "desgostastes": "desgostar",
    "desgostava": "desgostar",
    "desgostavam": "desgostar",
    "desgostavas": "desgostar",
    "desgoste": "desgostar",
    "desgostei": "desgostar",
    "desgosteis": "desgostar",
    "desgostem": "desgostar",
    "desgostemo": "desgostar",
    "desgostemos": "desgostar",
    "desgostes": "desgostar",
    "desgosto": "desgostar",
    "desgostos": "desgosto",
    "desgostosa": "desgostoso",
    "desgostosas": "desgostoso",
    "desgostosos": "desgostoso",
    "desgostou": "desgostar",
    "desgostá": "desgostar",
    "desgostámo": "desgostar",
    "desgostámos": "desgostar",
    "desgostáramo": "desgostar",
    "desgostáramos": "desgostar",
    "desgostárei": "desgostar",
    "desgostáreis": "desgostar",
    "desgostásseis": "desgostar",
    "desgostássemos": "desgostar",
    "desgostávamo": "desgostar",
    "desgostávamos": "desgostar",
    "desgostávei": "desgostar",
    "desgostáveis": "desgostar",
    "desgoverna": "desgovernar",
    "desgovernada": "desgovernar",
    "desgovernadas": "desgovernar",
    "desgovernado": "desgovernar",
    "desgovernados": "desgovernar",
    "desgovernai": "desgovernar",
    "desgovernais": "desgovernar",
    "desgovernam": "desgovernar",
    "desgovernamentações": "desgovernamentação",
    "desgovernamo": "desgovernar",
    "desgovernamos": "desgovernar",
    "desgovernando": "desgovernar",
    "desgovernara": "desgovernar",
    "desgovernaram": "desgovernar",
    "desgovernaras": "desgovernar",
    "desgovernarde": "desgovernar",
    "desgovernardes": "desgovernar",
    "desgovernare": "desgovernar",
    "desgovernarei": "desgovernar",
    "desgovernareis": "desgovernar",
    "desgovernarem": "desgovernar",
    "desgovernaremos": "desgovernar",
    "desgovernares": "desgovernar",
    "desgovernaria": "desgovernar",
    "desgovernariam": "desgovernar",
    "desgovernarias": "desgovernar",
    "desgovernarmo": "desgovernar",
    "desgovernarmos": "desgovernar",
    "desgovernará": "desgovernar",
    "desgovernarás": "desgovernar",
    "desgovernarão": "desgovernar",
    "desgovernaríamos": "desgovernar",
    "desgovernaríeis": "desgovernar",
    "desgovernas": "desgovernar",
    "desgovernasse": "desgovernar",
    "desgovernassem": "desgovernar",
    "desgovernasses": "desgovernar",
    "desgovernaste": "desgovernar",
    "desgovernastes": "desgovernar",
    "desgovernava": "desgovernar",
    "desgovernavam": "desgovernar",
    "desgovernavas": "desgovernar",
    "desgoverne": "desgovernar",
    "desgovernei": "desgovernar",
    "desgoverneis": "desgovernar",
    "desgovernem": "desgovernar",
    "desgovernemo": "desgovernar",
    "desgovernemos": "desgovernar",
    "desgovernes": "desgovernar",
    "desgoverno": "desgovernar",
    "desgovernos": "desgoverno",
    "desgovernou": "desgovernar",
    "desgoverná": "desgovernar",
    "desgovernámo": "desgovernar",
    "desgovernámos": "desgovernar",
    "desgovernáramo": "desgovernar",
    "desgovernáramos": "desgovernar",
    "desgovernárei": "desgovernar",
    "desgovernáreis": "desgovernar",
    "desgovernásseis": "desgovernar",
    "desgovernássemos": "desgovernar",
    "desgovernávamo": "desgovernar",
    "desgovernávamos": "desgovernar",
    "desgovernávei": "desgovernar",
    "desgovernáveis": "desgovernar",
    "desgrace": "desgraçar",
    "desgracei": "desgraçar",
    "desgraceiras": "desgraceira",
    "desgraceis": "desgraçar",
    "desgracem": "desgraçar",
    "desgracemo": "desgraçar",
    "desgracemos": "desgraçar",
    "desgraces": "desgraçar",
    "desgracia": "desgraciar",
    "desgraciada": "desgraciar",
    "desgraciadas": "desgraciar",
    "desgraciado": "desgraciar",
    "desgraciados": "desgraciar",
    "desgraciai": "desgraciar",
    "desgraciais": "desgraciar",
    "desgraciam": "desgraciar",
    "desgraciamo": "desgraciar",
    "desgraciamos": "desgraciar",
    "desgraciando": "desgraciar",
    "desgraciara": "desgraciar",
    "desgraciaram": "desgraciar",
    "desgraciaras": "desgraciar",
    "desgraciarde": "desgraciar",
    "desgraciardes": "desgraciar",
    "desgraciare": "desgraciar",
    "desgraciarei": "desgraciar",
    "desgraciareis": "desgraciar",
    "desgraciarem": "desgraciar",
    "desgraciaremos": "desgraciar",
    "desgraciares": "desgraciar",
    "desgraciaria": "desgraciar",
    "desgraciariam": "desgraciar",
    "desgraciarias": "desgraciar",
    "desgraciarmo": "desgraciar",
    "desgraciarmos": "desgraciar",
    "desgraciará": "desgraciar",
    "desgraciarás": "desgraciar",
    "desgraciarão": "desgraciar",
    "desgraciaríamos": "desgraciar",
    "desgraciaríeis": "desgraciar",
    "desgracias": "desgraciar",
    "desgraciasse": "desgraciar",
    "desgraciassem": "desgraciar",
    "desgraciasses": "desgraciar",
    "desgraciaste": "desgraciar",
    "desgraciastes": "desgraciar",
    "desgraciava": "desgraciar",
    "desgraciavam": "desgraciar",
    "desgraciavas": "desgraciar",
    "desgracie": "desgraciar",
    "desgraciei": "desgraciar",
    "desgracieis": "desgraciar",
    "desgraciem": "desgraciar",
    "desgraciemo": "desgraciar",
    "desgraciemos": "desgraciar",
    "desgracies": "desgraciar",
    "desgracio": "desgraciar",
    "desgraciosa": "desgracioso",
    "desgraciosas": "desgracioso",
    "desgraciosos": "desgracioso",
    "desgraciou": "desgraciar",
    "desgraciá": "desgraciar",
    "desgraciámo": "desgraciar",
    "desgraciámos": "desgraciar",
    "desgraciáramo": "desgraciar",
    "desgraciáramos": "desgraciar",
    "desgraciárei": "desgraciar",
    "desgraciáreis": "desgraciar",
    "desgraciásseis": "desgraciar",
    "desgraciássemos": "desgraciar",
    "desgraciávamo": "desgraciar",
    "desgraciávamos": "desgraciar",
    "desgraciávei": "desgraciar",
    "desgraciáveis": "desgraciar",
    "desgradeada": "desgradear",
    "desgradeadas": "desgradear",
    "desgradeado": "desgradear",
    "desgradeados": "desgradear",
    "desgradeai": "desgradear",
    "desgradeais": "desgradear",
    "desgradeamo": "desgradear",
    "desgradeamos": "desgradear",
    "desgradeando": "desgradear",
    "desgradeara": "desgradear",
    "desgradearam": "desgradear",
    "desgradearas": "desgradear",
    "desgradearde": "desgradear",
    "desgradeardes": "desgradear",
    "desgradeare": "desgradear",
    "desgradearei": "desgradear",
    "desgradeareis": "desgradear",
    "desgradearem": "desgradear",
    "desgradearemos": "desgradear",
    "desgradeares": "desgradear",
    "desgradearia": "desgradear",
    "desgradeariam": "desgradear",
    "desgradearias": "desgradear",
    "desgradearmo": "desgradear",
    "desgradearmos": "desgradear",
    "desgradeará": "desgradear",
    "desgradearás": "desgradear",
    "desgradearão": "desgradear",
    "desgradearíamos": "desgradear",
    "desgradearíeis": "desgradear",
    "desgradeasse": "desgradear",
    "desgradeassem": "desgradear",
    "desgradeasses": "desgradear",
    "desgradeaste": "desgradear",
    "desgradeastes": "desgradear",
    "desgradeava": "desgradear",
    "desgradeavam": "desgradear",
    "desgradeavas": "desgradear",
    "desgradeei": "desgradear",
    "desgradeeis": "desgradear",
    "desgradeemo": "desgradear",
    "desgradeemos": "desgradear",
    "desgradeia": "desgradear",
    "desgradeiam": "desgradear",
    "desgradeias": "desgradear",
    "desgradeie": "desgradear",
    "desgradeiem": "desgradear",
    "desgradeies": "desgradear",
    "desgradeio": "desgradear",
    "desgradeou": "desgradear",
    "desgradeá": "desgradear",
    "desgradeámo": "desgradear",
    "desgradeámos": "desgradear",
    "desgradeáramo": "desgradear",
    "desgradeáramos": "desgradear",
    "desgradeárei": "desgradear",
    "desgradeáreis": "desgradear",
    "desgradeásseis": "desgradear",
    "desgradeássemos": "desgradear",
    "desgradeávamo": "desgradear",
    "desgradeávamos": "desgradear",
    "desgradeávei": "desgradear",
    "desgradeáveis": "desgradear",
    "desgradua": "desgraduar",
    "desgraduada": "desgraduar",
    "desgraduadas": "desgraduar",
    "desgraduado": "desgraduar",
    "desgraduados": "desgraduar",
    "desgraduai": "desgraduar",
    "desgraduais": "desgraduar",
    "desgraduam": "desgraduar",
    "desgraduamo": "desgraduar",
    "desgraduamos": "desgraduar",
    "desgraduando": "desgraduar",
    "desgraduara": "desgraduar",
    "desgraduaram": "desgraduar",
    "desgraduaras": "desgraduar",
    "desgraduarde": "desgraduar",
    "desgraduardes": "desgraduar",
    "desgraduare": "desgraduar",
    "desgraduarei": "desgraduar",
    "desgraduareis": "desgraduar",
    "desgraduarem": "desgraduar",
    "desgraduaremos": "desgraduar",
    "desgraduares": "desgraduar",
    "desgraduaria": "desgraduar",
    "desgraduariam": "desgraduar",
    "desgraduarias": "desgraduar",
    "desgraduarmo": "desgraduar",
    "desgraduarmos": "desgraduar",
    "desgraduará": "desgraduar",
    "desgraduarás": "desgraduar",
    "desgraduarão": "desgraduar",
    "desgraduaríamos": "desgraduar",
    "desgraduaríeis": "desgraduar",
    "desgraduas": "desgraduar",
    "desgraduasse": "desgraduar",
    "desgraduassem": "desgraduar",
    "desgraduasses": "desgraduar",
    "desgraduaste": "desgraduar",
    "desgraduastes": "desgraduar",
    "desgraduava": "desgraduar",
    "desgraduavam": "desgraduar",
    "desgraduavas": "desgraduar",
    "desgradue": "desgraduar",
    "desgraduei": "desgraduar",
    "desgradueis": "desgraduar",
    "desgraduem": "desgraduar",
    "desgraduemo": "desgraduar",
    "desgraduemos": "desgraduar",
    "desgradues": "desgraduar",
    "desgraduo": "desgraduar",
    "desgraduou": "desgraduar",
    "desgraduá": "desgraduar",
    "desgraduámo": "desgraduar",
    "desgraduámos": "desgraduar",
    "desgraduáramo": "desgraduar",
    "desgraduáramos": "desgraduar",
    "desgraduárei": "desgraduar",
    "desgraduáreis": "desgraduar",
    "desgraduásseis": "desgraduar",
    "desgraduássemos": "desgraduar",
    "desgraduávamo": "desgraduar",
    "desgraduávamos": "desgraduar",
    "desgraduávei": "desgraduar",
    "desgraduáveis": "desgraduar",
    "desgrana": "desgranar",
    "desgranada": "desgranar",
    "desgranadas": "desgranar",
    "desgranado": "desgranar",
    "desgranados": "desgranar",
    "desgranai": "desgranar",
    "desgranais": "desgranar",
    "desgranam": "desgranar",
    "desgranamo": "desgranar",
    "desgranamos": "desgranar",
    "desgranando": "desgranar",
    "desgranara": "desgranar",
    "desgranaram": "desgranar",
    "desgranaras": "desgranar",
    "desgranarde": "desgranar",
    "desgranardes": "desgranar",
    "desgranare": "desgranar",
    "desgranarei": "desgranar",
    "desgranareis": "desgranar",
    "desgranarem": "desgranar",
    "desgranaremos": "desgranar",
    "desgranares": "desgranar",
    "desgranaria": "desgranar",
    "desgranariam": "desgranar",
    "desgranarias": "desgranar",
    "desgranarmo": "desgranar",
    "desgranarmos": "desgranar",
    "desgranará": "desgranar",
    "desgranarás": "desgranar",
    "desgranarão": "desgranar",
    "desgranaríamos": "desgranar",
    "desgranaríeis": "desgranar",
    "desgranas": "desgranar",
    "desgranasse": "desgranar",
    "desgranassem": "desgranar",
    "desgranasses": "desgranar",
    "desgranaste": "desgranar",
    "desgranastes": "desgranar",
    "desgranava": "desgranar",
    "desgranavam": "desgranar",
    "desgranavas": "desgranar",
    "desgrane": "desgranar",
    "desgranei": "desgranar",
    "desgraneis": "desgranar",
    "desgranem": "desgranar",
    "desgranemo": "desgranar",
    "desgranemos": "desgranar",
    "desgranes": "desgranar",
    "desgrano": "desgranar",
    "desgranou": "desgranar",
    "desgraná": "desgranar",
    "desgranámo": "desgranar",
    "desgranámos": "desgranar",
    "desgranáramo": "desgranar",
    "desgranáramos": "desgranar",
    "desgranárei": "desgranar",
    "desgranáreis": "desgranar",
    "desgranásseis": "desgranar",
    "desgranássemos": "desgranar",
    "desgranávamo": "desgranar",
    "desgranávamos": "desgranar",
    "desgranávei": "desgranar",
    "desgranáveis": "desgranar",
    "desgravações": "desgravação",
    "desgravida": "desgravidar",
    "desgravidada": "desgravidar",
    "desgravidadas": "desgravidar",
    "desgravidado": "desgravidar",
    "desgravidados": "desgravidar",
    "desgravidai": "desgravidar",
    "desgravidais": "desgravidar",
    "desgravidam": "desgravidar",
    "desgravidamo": "desgravidar",
    "desgravidamos": "desgravidar",
    "desgravidando": "desgravidar",
    "desgravidara": "desgravidar",
    "desgravidaram": "desgravidar",
    "desgravidaras": "desgravidar",
    "desgravidarde": "desgravidar",
    "desgravidardes": "desgravidar",
    "desgravidare": "desgravidar",
    "desgravidarei": "desgravidar",
    "desgravidareis": "desgravidar",
    "desgravidarem": "desgravidar",
    "desgravidaremos": "desgravidar",
    "desgravidares": "desgravidar",
    "desgravidaria": "desgravidar",
    "desgravidariam": "desgravidar",
    "desgravidarias": "desgravidar",
    "desgravidarmo": "desgravidar",
    "desgravidarmos": "desgravidar",
    "desgravidará": "desgravidar",
    "desgravidarás": "desgravidar",
    "desgravidarão": "desgravidar",
    "desgravidaríamos": "desgravidar",
    "desgravidaríeis": "desgravidar",
    "desgravidas": "desgravidar",
    "desgravidasse": "desgravidar",
    "desgravidassem": "desgravidar",
    "desgravidasses": "desgravidar",
    "desgravidaste": "desgravidar",
    "desgravidastes": "desgravidar",
    "desgravidava": "desgravidar",
    "desgravidavam": "desgravidar",
    "desgravidavas": "desgravidar",
    "desgravidações": "desgravidação",
    "desgravide": "desgravidar",
    "desgravidei": "desgravidar",
    "desgravideis": "desgravidar",
    "desgravidem": "desgravidar",
    "desgravidemo": "desgravidar",
    "desgravidemos": "desgravidar",
    "desgravides": "desgravidar",
    "desgravido": "desgravidar",
    "desgravidou": "desgravidar",
    "desgravidá": "desgravidar",
    "desgravidámo": "desgravidar",
    "desgravidámos": "desgravidar",
    "desgravidáramo": "desgravidar",
    "desgravidáramos": "desgravidar",
    "desgravidárei": "desgravidar",
    "desgravidáreis": "desgravidar",
    "desgravidásseis": "desgravidar",
    "desgravidássemos": "desgravidar",
    "desgravidávamo": "desgravidar",
    "desgravidávamos": "desgravidar",
    "desgravidávei": "desgravidar",
    "desgravidáveis": "desgravidar",
    "desgravitada": "desgravitado",
    "desgravitadas": "desgravitado",
    "desgravitados": "desgravitado",
    "desgraváveis": "desgravável",
    "desgraxa": "desgraxar",
    "desgraxada": "desgraxar",
    "desgraxadas": "desgraxar",
    "desgraxado": "desgraxar",
    "desgraxados": "desgraxar",
    "desgraxai": "desgraxar",
    "desgraxais": "desgraxar",
    "desgraxam": "desgraxar",
    "desgraxamo": "desgraxar",
    "desgraxamos": "desgraxar",
    "desgraxando": "desgraxar",
    "desgraxara": "desgraxar",
    "desgraxaram": "desgraxar",
    "desgraxaras": "desgraxar",
    "desgraxarde": "desgraxar",
    "desgraxardes": "desgraxar",
    "desgraxare": "desgraxar",
    "desgraxarei": "desgraxar",
    "desgraxareis": "desgraxar",
    "desgraxarem": "desgraxar",
    "desgraxaremos": "desgraxar",
    "desgraxares": "desgraxar",
    "desgraxaria": "desgraxar",
    "desgraxariam": "desgraxar",
    "desgraxarias": "desgraxar",
    "desgraxarmo": "desgraxar",
    "desgraxarmos": "desgraxar",
    "desgraxará": "desgraxar",
    "desgraxarás": "desgraxar",
    "desgraxarão": "desgraxar",
    "desgraxaríamos": "desgraxar",
    "desgraxaríeis": "desgraxar",
    "desgraxas": "desgraxar",
    "desgraxasse": "desgraxar",
    "desgraxassem": "desgraxar",
    "desgraxasses": "desgraxar",
    "desgraxaste": "desgraxar",
    "desgraxastes": "desgraxar",
    "desgraxava": "desgraxar",
    "desgraxavam": "desgraxar",
    "desgraxavas": "desgraxar",
    "desgraxe": "desgraxar",
    "desgraxei": "desgraxar",
    "desgraxeis": "desgraxar",
    "desgraxem": "desgraxar",
    "desgraxemo": "desgraxar",
    "desgraxemos": "desgraxar",
    "desgraxes": "desgraxar",
    "desgraxo": "desgraxar",
    "desgraxou": "desgraxar",
    "desgraxá": "desgraxar",
    "desgraxámo": "desgraxar",
    "desgraxámos": "desgraxar",
    "desgraxáramo": "desgraxar",
    "desgraxáramos": "desgraxar",
    "desgraxárei": "desgraxar",
    "desgraxáreis": "desgraxar",
    "desgraxásseis": "desgraxar",
    "desgraxássemos": "desgraxar",
    "desgraxávamo": "desgraxar",
    "desgraxávamos": "desgraxar",
    "desgraxávei": "desgraxar",
    "desgraxáveis": "desgraxar",
    "desgraça": "desgraçar",
    "desgraçada": "desgraçar",
    "desgraçadas": "desgraçar",
    "desgraçado": "desgraçar",
    "desgraçados": "desgraçar",
    "desgraçai": "desgraçar",
    "desgraçais": "desgraçar",
    "desgraçam": "desgraçar",
    "desgraçamo": "desgraçar",
    "desgraçamos": "desgraçar",
    "desgraçando": "desgraçar",
    "desgraçara": "desgraçar",
    "desgraçaram": "desgraçar",
    "desgraçaras": "desgraçar",
    "desgraçarde": "desgraçar",
    "desgraçardes": "desgraçar",
    "desgraçare": "desgraçar",
    "desgraçarei": "desgraçar",
    "desgraçareis": "desgraçar",
    "desgraçarem": "desgraçar",
    "desgraçaremos": "desgraçar",
    "desgraçares": "desgraçar",
    "desgraçaria": "desgraçar",
    "desgraçariam": "desgraçar",
    "desgraçarias": "desgraçar",
    "desgraçarmo": "desgraçar",
    "desgraçarmos": "desgraçar",
    "desgraçará": "desgraçar",
    "desgraçarás": "desgraçar",
    "desgraçarão": "desgraçar",
    "desgraçaríamos": "desgraçar",
    "desgraçaríeis": "desgraçar",
    "desgraças": "desgraçar",
    "desgraçasse": "desgraçar",
    "desgraçassem": "desgraçar",
    "desgraçasses": "desgraçar",
    "desgraçaste": "desgraçar",
    "desgraçastes": "desgraçar",
    "desgraçava": "desgraçar",
    "desgraçavam": "desgraçar",
    "desgraçavas": "desgraçar",
    "desgraço": "desgraçar",
    "desgraçou": "desgraçar",
    "desgraçá": "desgraçar",
    "desgraçámo": "desgraçar",
    "desgraçámos": "desgraçar",
    "desgraçáramo": "desgraçar",
    "desgraçáramos": "desgraçar",
    "desgraçárei": "desgraçar",
    "desgraçáreis": "desgraçar",
    "desgraçásseis": "desgraçar",
    "desgraçássemos": "desgraçar",
    "desgraçávamo": "desgraçar",
    "desgraçávamos": "desgraçar",
    "desgraçávei": "desgraçar",
    "desgraçáveis": "desgraçar",
    "desgrenha": "desgrenhar",
    "desgrenhada": "desgrenhar",
    "desgrenhadas": "desgrenhar",
    "desgrenhado": "desgrenhar",
    "desgrenhados": "desgrenhar",
    "desgrenhai": "desgrenhar",
    "desgrenhais": "desgrenhar",
    "desgrenham": "desgrenhar",
    "desgrenhamentos": "desgrenhamento",
    "desgrenhamo": "desgrenhar",
    "desgrenhamos": "desgrenhar",
    "desgrenhando": "desgrenhar",
    "desgrenhara": "desgrenhar",
    "desgrenharam": "desgrenhar",
    "desgrenharas": "desgrenhar",
    "desgrenharde": "desgrenhar",
    "desgrenhardes": "desgrenhar",
    "desgrenhare": "desgrenhar",
    "desgrenharei": "desgrenhar",
    "desgrenhareis": "desgrenhar",
    "desgrenharem": "desgrenhar",
    "desgrenharemos": "desgrenhar",
    "desgrenhares": "desgrenhar",
    "desgrenharia": "desgrenhar",
    "desgrenhariam": "desgrenhar",
    "desgrenharias": "desgrenhar",
    "desgrenharmo": "desgrenhar",
    "desgrenharmos": "desgrenhar",
    "desgrenhará": "desgrenhar",
    "desgrenharás": "desgrenhar",
    "desgrenharão": "desgrenhar",
    "desgrenharíamos": "desgrenhar",
    "desgrenharíeis": "desgrenhar",
    "desgrenhas": "desgrenhar",
    "desgrenhasse": "desgrenhar",
    "desgrenhassem": "desgrenhar",
    "desgrenhasses": "desgrenhar",
    "desgrenhaste": "desgrenhar",
    "desgrenhastes": "desgrenhar",
    "desgrenhava": "desgrenhar",
    "desgrenhavam": "desgrenhar",
    "desgrenhavas": "desgrenhar",
    "desgrenhe": "desgrenhar",
    "desgrenhei": "desgrenhar",
    "desgrenheis": "desgrenhar",
    "desgrenhem": "desgrenhar",
    "desgrenhemo": "desgrenhar",
    "desgrenhemos": "desgrenhar",
    "desgrenhes": "desgrenhar",
    "desgrenho": "desgrenhar",
    "desgrenhou": "desgrenhar",
    "desgrenhá": "desgrenhar",
    "desgrenhámo": "desgrenhar",
    "desgrenhámos": "desgrenhar",
    "desgrenháramo": "desgrenhar",
    "desgrenháramos": "desgrenhar",
    "desgrenhárei": "desgrenhar",
    "desgrenháreis": "desgrenhar",
    "desgrenhásseis": "desgrenhar",
    "desgrenhássemos": "desgrenhar",
    "desgrenhávamo": "desgrenhar",
    "desgrenhávamos": "desgrenhar",
    "desgrenhávei": "desgrenhar",
    "desgrenháveis": "desgrenhar",
    "desgrilhoa": "desgrilhoar",
    "desgrilhoada": "desgrilhoar",
    "desgrilhoadas": "desgrilhoar",
    "desgrilhoado": "desgrilhoar",
    "desgrilhoados": "desgrilhoar",
    "desgrilhoai": "desgrilhoar",
    "desgrilhoais": "desgrilhoar",
    "desgrilhoam": "desgrilhoar",
    "desgrilhoamo": "desgrilhoar",
    "desgrilhoamos": "desgrilhoar",
    "desgrilhoando": "desgrilhoar",
    "desgrilhoara": "desgrilhoar",
    "desgrilhoaram": "desgrilhoar",
    "desgrilhoaras": "desgrilhoar",
    "desgrilhoarde": "desgrilhoar",
    "desgrilhoardes": "desgrilhoar",
    "desgrilhoare": "desgrilhoar",
    "desgrilhoarei": "desgrilhoar",
    "desgrilhoareis": "desgrilhoar",
    "desgrilhoarem": "desgrilhoar",
    "desgrilhoaremos": "desgrilhoar",
    "desgrilhoares": "desgrilhoar",
    "desgrilhoaria": "desgrilhoar",
    "desgrilhoariam": "desgrilhoar",
    "desgrilhoarias": "desgrilhoar",
    "desgrilhoarmo": "desgrilhoar",
    "desgrilhoarmos": "desgrilhoar",
    "desgrilhoará": "desgrilhoar",
    "desgrilhoarás": "desgrilhoar",
    "desgrilhoarão": "desgrilhoar",
    "desgrilhoaríamos": "desgrilhoar",
    "desgrilhoaríeis": "desgrilhoar",
    "desgrilhoas": "desgrilhoar",
    "desgrilhoasse": "desgrilhoar",
    "desgrilhoassem": "desgrilhoar",
    "desgrilhoasses": "desgrilhoar",
    "desgrilhoaste": "desgrilhoar",
    "desgrilhoastes": "desgrilhoar",
    "desgrilhoava": "desgrilhoar",
    "desgrilhoavam": "desgrilhoar",
    "desgrilhoavas": "desgrilhoar",
    "desgrilhoda": "desgrilhodo",
    "desgrilhodas": "desgrilhodo",
    "desgrilhodos": "desgrilhodo",
    "desgrilhoe": "desgrilhoar",
    "desgrilhoei": "desgrilhoar",
    "desgrilhoeis": "desgrilhoar",
    "desgrilhoem": "desgrilhoar",
    "desgrilhoemo": "desgrilhoar",
    "desgrilhoemos": "desgrilhoar",
    "desgrilhoes": "desgrilhoar",
    "desgrilhoo": "desgrilhoar",
    "desgrilhoou": "desgrilhoar",
    "desgrilhoá": "desgrilhoar",
    "desgrilhoámo": "desgrilhoar",
    "desgrilhoámos": "desgrilhoar",
    "desgrilhoáramo": "desgrilhoar",
    "desgrilhoáramos": "desgrilhoar",
    "desgrilhoárei": "desgrilhoar",
    "desgrilhoáreis": "desgrilhoar",
    "desgrilhoásseis": "desgrilhoar",
    "desgrilhoássemos": "desgrilhoar",
    "desgrilhoávamo": "desgrilhoar",
    "desgrilhoávamos": "desgrilhoar",
    "desgrilhoávei": "desgrilhoar",
    "desgrilhoáveis": "desgrilhoar",
    "desgrinalda": "desgrinaldar",
    "desgrinaldada": "desgrinaldar",
    "desgrinaldadas": "desgrinaldar",
    "desgrinaldado": "desgrinaldar",
    "desgrinaldados": "desgrinaldar",
    "desgrinaldai": "desgrinaldar",
    "desgrinaldais": "desgrinaldar",
    "desgrinaldam": "desgrinaldar",
    "desgrinaldamo": "desgrinaldar",
    "desgrinaldamos": "desgrinaldar",
    "desgrinaldando": "desgrinaldar",
    "desgrinaldara": "desgrinaldar",
    "desgrinaldaram": "desgrinaldar",
    "desgrinaldaras": "desgrinaldar",
    "desgrinaldarde": "desgrinaldar",
    "desgrinaldardes": "desgrinaldar",
    "desgrinaldare": "desgrinaldar",
    "desgrinaldarei": "desgrinaldar",
    "desgrinaldareis": "desgrinaldar",
    "desgrinaldarem": "desgrinaldar",
    "desgrinaldaremos": "desgrinaldar",
    "desgrinaldares": "desgrinaldar",
    "desgrinaldaria": "desgrinaldar",
    "desgrinaldariam": "desgrinaldar",
    "desgrinaldarias": "desgrinaldar",
    "desgrinaldarmo": "desgrinaldar",
    "desgrinaldarmos": "desgrinaldar",
    "desgrinaldará": "desgrinaldar",
    "desgrinaldarás": "desgrinaldar",
    "desgrinaldarão": "desgrinaldar",
    "desgrinaldaríamos": "desgrinaldar",
    "desgrinaldaríeis": "desgrinaldar",
    "desgrinaldas": "desgrinaldar",
    "desgrinaldasse": "desgrinaldar",
    "desgrinaldassem": "desgrinaldar",
    "desgrinaldasses": "desgrinaldar",
    "desgrinaldaste": "desgrinaldar",
    "desgrinaldastes": "desgrinaldar",
    "desgrinaldava": "desgrinaldar",
    "desgrinaldavam": "desgrinaldar",
    "desgrinaldavas": "desgrinaldar",
    "desgrinalde": "desgrinaldar",
    "desgrinaldei": "desgrinaldar",
    "desgrinaldeis": "desgrinaldar",
    "desgrinaldem": "desgrinaldar",
    "desgrinaldemo": "desgrinaldar",
    "desgrinaldemos": "desgrinaldar",
    "desgrinaldes": "desgrinaldar",
    "desgrinaldo": "desgrinaldar",
    "desgrinaldou": "desgrinaldar",
    "desgrinaldá": "desgrinaldar",
    "desgrinaldámo": "desgrinaldar",
    "desgrinaldámos": "desgrinaldar",
    "desgrinaldáramo": "desgrinaldar",
    "desgrinaldáramos": "desgrinaldar",
    "desgrinaldárei": "desgrinaldar",
    "desgrinaldáreis": "desgrinaldar",
    "desgrinaldásseis": "desgrinaldar",
    "desgrinaldássemos": "desgrinaldar",
    "desgrinaldávamo": "desgrinaldar",
    "desgrinaldávamos": "desgrinaldar",
    "desgrinaldávei": "desgrinaldar",
    "desgrinaldáveis": "desgrinaldar",
    "desgruda": "desgrudar",
    "desgrudada": "desgrudar",
    "desgrudadas": "desgrudar",
    "desgrudado": "desgrudar",
    "desgrudados": "desgrudar",
    "desgrudai": "desgrudar",
    "desgrudais": "desgrudar",
    "desgrudam": "desgrudar",
    "desgrudamo": "desgrudar",
    "desgrudamos": "desgrudar",
    "desgrudando": "desgrudar",
    "desgrudara": "desgrudar",
    "desgrudaram": "desgrudar",
    "desgrudaras": "desgrudar",
    "desgrudarde": "desgrudar",
    "desgrudardes": "desgrudar",
    "desgrudare": "desgrudar",
    "desgrudarei": "desgrudar",
    "desgrudareis": "desgrudar",
    "desgrudarem": "desgrudar",
    "desgrudaremos": "desgrudar",
    "desgrudares": "desgrudar",
    "desgrudaria": "desgrudar",
    "desgrudariam": "desgrudar",
    "desgrudarias": "desgrudar",
    "desgrudarmo": "desgrudar",
    "desgrudarmos": "desgrudar",
    "desgrudará": "desgrudar",
    "desgrudarás": "desgrudar",
    "desgrudarão": "desgrudar",
    "desgrudaríamos": "desgrudar",
    "desgrudaríeis": "desgrudar",
    "desgrudas": "desgrudar",
    "desgrudasse": "desgrudar",
    "desgrudassem": "desgrudar",
    "desgrudasses": "desgrudar",
    "desgrudaste": "desgrudar",
    "desgrudastes": "desgrudar",
    "desgrudava": "desgrudar",
    "desgrudavam": "desgrudar",
    "desgrudavas": "desgrudar",
    "desgrude": "desgrudar",
    "desgrudei": "desgrudar",
    "desgrudeis": "desgrudar",
    "desgrudem": "desgrudar",
    "desgrudemo": "desgrudar",
    "desgrudemos": "desgrudar",
    "desgrudes": "desgrudar",
    "desgrudo": "desgrudar",
    "desgrudou": "desgrudar",
    "desgrudá": "desgrudar",
    "desgrudámo": "desgrudar",
    "desgrudámos": "desgrudar",
    "desgrudáramo": "desgrudar",
    "desgrudáramos": "desgrudar",
    "desgrudárei": "desgrudar",
    "desgrudáreis": "desgrudar",
    "desgrudásseis": "desgrudar",
    "desgrudássemos": "desgrudar",
    "desgrudávamo": "desgrudar",
    "desgrudávamos": "desgrudar",
    "desgrudávei": "desgrudar",
    "desgrudáveis": "desgrudar",
    "desgruma": "desgrumar",
    "desgrumada": "desgrumar",
    "desgrumadas": "desgrumar",
    "desgrumado": "desgrumar",
    "desgrumados": "desgrumar",
    "desgrumai": "desgrumar",
    "desgrumais": "desgrumar",
    "desgrumam": "desgrumar",
    "desgrumamo": "desgrumar",
    "desgrumamos": "desgrumar",
    "desgrumando": "desgrumar",
    "desgrumara": "desgrumar",
    "desgrumaram": "desgrumar",
    "desgrumaras": "desgrumar",
    "desgrumarde": "desgrumar",
    "desgrumardes": "desgrumar",
    "desgrumare": "desgrumar",
    "desgrumarei": "desgrumar",
    "desgrumareis": "desgrumar",
    "desgrumarem": "desgrumar",
    "desgrumaremos": "desgrumar",
    "desgrumares": "desgrumar",
    "desgrumaria": "desgrumar",
    "desgrumariam": "desgrumar",
    "desgrumarias": "desgrumar",
    "desgrumarmo": "desgrumar",
    "desgrumarmos": "desgrumar",
    "desgrumará": "desgrumar",
    "desgrumarás": "desgrumar",
    "desgrumarão": "desgrumar",
    "desgrumaríamos": "desgrumar",
    "desgrumaríeis": "desgrumar",
    "desgrumas": "desgrumar",
    "desgrumasse": "desgrumar",
    "desgrumassem": "desgrumar",
    "desgrumasses": "desgrumar",
    "desgrumaste": "desgrumar",
    "desgrumastes": "desgrumar",
    "desgrumava": "desgrumar",
    "desgrumavam": "desgrumar",
    "desgrumavas": "desgrumar",
    "desgrume": "desgrumar",
    "desgrumei": "desgrumar",
    "desgrumeis": "desgrumar",
    "desgrumem": "desgrumar",
    "desgrumemo": "desgrumar",
    "desgrumemos": "desgrumar",
    "desgrumes": "desgrumar",
    "desgrumo": "desgrumar",
    "desgrumou": "desgrumar",
    "desgrumá": "desgrumar",
    "desgrumámo": "desgrumar",
    "desgrumámos": "desgrumar",
    "desgrumáramo": "desgrumar",
    "desgrumáramos": "desgrumar",
    "desgrumárei": "desgrumar",
    "desgrumáreis": "desgrumar",
    "desgrumásseis": "desgrumar",
    "desgrumássemos": "desgrumar",
    "desgrumávamo": "desgrumar",
    "desgrumávamos": "desgrumar",
    "desgrumávei": "desgrumar",
    "desgrumáveis": "desgrumar",
    "desguarda": "desguardar",
    "desguardada": "desguardar",
    "desguardadas": "desguardar",
    "desguardado": "desguardar",
    "desguardados": "desguardar",
    "desguardai": "desguardar",
    "desguardais": "desguardar",
    "desguardam": "desguardar",
    "desguardamo": "desguardar",
    "desguardamos": "desguardar",
    "desguardando": "desguardar",
    "desguardara": "desguardar",
    "desguardaram": "desguardar",
    "desguardaras": "desguardar",
    "desguardarde": "desguardar",
    "desguardardes": "desguardar",
    "desguardare": "desguardar",
    "desguardarei": "desguardar",
    "desguardareis": "desguardar",
    "desguardarem": "desguardar",
    "desguardaremos": "desguardar",
    "desguardares": "desguardar",
    "desguardaria": "desguardar",
    "desguardariam": "desguardar",
    "desguardarias": "desguardar",
    "desguardarmo": "desguardar",
    "desguardarmos": "desguardar",
    "desguardará": "desguardar",
    "desguardarás": "desguardar",
    "desguardarão": "desguardar",
    "desguardaríamos": "desguardar",
    "desguardaríeis": "desguardar",
    "desguardas": "desguardar",
    "desguardasse": "desguardar",
    "desguardassem": "desguardar",
    "desguardasses": "desguardar",
    "desguardaste": "desguardar",
    "desguardastes": "desguardar",
    "desguardava": "desguardar",
    "desguardavam": "desguardar",
    "desguardavas": "desguardar",
    "desguarde": "desguardar",
    "desguardei": "desguardar",
    "desguardeis": "desguardar",
    "desguardem": "desguardar",
    "desguardemo": "desguardar",
    "desguardemos": "desguardar",
    "desguardes": "desguardar",
    "desguardo": "desguardar",
    "desguardou": "desguardar",
    "desguardá": "desguardar",
    "desguardámo": "desguardar",
    "desguardámos": "desguardar",
    "desguardáramo": "desguardar",
    "desguardáramos": "desguardar",
    "desguardárei": "desguardar",
    "desguardáreis": "desguardar",
    "desguardásseis": "desguardar",
    "desguardássemos": "desguardar",
    "desguardávamo": "desguardar",
    "desguardávamos": "desguardar",
    "desguardávei": "desguardar",
    "desguardáveis": "desguardar",
    "desguarnece": "desguarnecer",
    "desguarnecei": "desguarnecer",
    "desguarneceis": "desguarnecer",
    "desguarnecem": "desguarnecer",
    "desguarnecemo": "desguarnecer",
    "desguarnecemos": "desguarnecer",
    "desguarnecendo": "desguarnecer",
    "desguarnecera": "desguarnecer",
    "desguarneceram": "desguarnecer",
    "desguarneceras": "desguarnecer",
    "desguarnecerde": "desguarnecer",
    "desguarnecerdes": "desguarnecer",
    "desguarnecere": "desguarnecer",
    "desguarnecerei": "desguarnecer",
    "desguarnecereis": "desguarnecer",
    "desguarnecerem": "desguarnecer",
    "desguarneceremos": "desguarnecer",
    "desguarneceres": "desguarnecer",
    "desguarneceria": "desguarnecer",
    "desguarneceriam": "desguarnecer",
    "desguarnecerias": "desguarnecer",
    "desguarnecermo": "desguarnecer",
    "desguarnecermos": "desguarnecer",
    "desguarnecerá": "desguarnecer",
    "desguarnecerás": "desguarnecer",
    "desguarnecerão": "desguarnecer",
    "desguarneceríamos": "desguarnecer",
    "desguarneceríeis": "desguarnecer",
    "desguarneces": "desguarnecer",
    "desguarnecesse": "desguarnecer",
    "desguarnecessem": "desguarnecer",
    "desguarnecesses": "desguarnecer",
    "desguarneceste": "desguarnecer",
    "desguarnecestes": "desguarnecer",
    "desguarneceu": "desguarnecer",
    "desguarneci": "desguarnecer",
    "desguarnecia": "desguarnecer",
    "desguarneciam": "desguarnecer",
    "desguarnecias": "desguarnecer",
    "desguarnecida": "desguarnecido",
    "desguarnecidas": "desguarnecido",
    "desguarnecido": "desguarnecer",
    "desguarnecidos": "desguarnecido",
    "desguarnecê": "desguarnecer",
    "desguarnecêramo": "desguarnecer",
    "desguarnecêramos": "desguarnecer",
    "desguarnecêrei": "desguarnecer",
    "desguarnecêreis": "desguarnecer",
    "desguarnecêsseis": "desguarnecer",
    "desguarnecêssemos": "desguarnecer",
    "desguarnecíamo": "desguarnecer",
    "desguarnecíamos": "desguarnecer",
    "desguarnecíei": "desguarnecer",
    "desguarnecíeis": "desguarnecer",
    "desguarneça": "desguarnecer",
    "desguarneçais": "desguarnecer",
    "desguarneçam": "desguarnecer",
    "desguarneçamo": "desguarnecer",
    "desguarneçamos": "desguarnecer",
    "desguarneças": "desguarnecer",
    "desguarneço": "desguarnecer",
    "desguedelha": "desguedelhar",
    "desguedelhada": "desguedelhar",
    "desguedelhadas": "desguedelhar",
    "desguedelhado": "desguedelhar",
    "desguedelhados": "desguedelhar",
    "desguedelhai": "desguedelhar",
    "desguedelhais": "desguedelhar",
    "desguedelham": "desguedelhar",
    "desguedelhamo": "desguedelhar",
    "desguedelhamos": "desguedelhar",
    "desguedelhando": "desguedelhar",
    "desguedelhara": "desguedelhar",
    "desguedelharam": "desguedelhar",
    "desguedelharas": "desguedelhar",
    "desguedelharde": "desguedelhar",
    "desguedelhardes": "desguedelhar",
    "desguedelhare": "desguedelhar",
    "desguedelharei": "desguedelhar",
    "desguedelhareis": "desguedelhar",
    "desguedelharem": "desguedelhar",
    "desguedelharemos": "desguedelhar",
    "desguedelhares": "desguedelhar",
    "desguedelharia": "desguedelhar",
    "desguedelhariam": "desguedelhar",
    "desguedelharias": "desguedelhar",
    "desguedelharmo": "desguedelhar",
    "desguedelharmos": "desguedelhar",
    "desguedelhará": "desguedelhar",
    "desguedelharás": "desguedelhar",
    "desguedelharão": "desguedelhar",
    "desguedelharíamos": "desguedelhar",
    "desguedelharíeis": "desguedelhar",
    "desguedelhas": "desguedelhar",
    "desguedelhasse": "desguedelhar",
    "desguedelhassem": "desguedelhar",
    "desguedelhasses": "desguedelhar",
    "desguedelhaste": "desguedelhar",
    "desguedelhastes": "desguedelhar",
    "desguedelhava": "desguedelhar",
    "desguedelhavam": "desguedelhar",
    "desguedelhavas": "desguedelhar",
    "desguedelhe": "desguedelhar",
    "desguedelhei": "desguedelhar",
    "desguedelheis": "desguedelhar",
    "desguedelhem": "desguedelhar",
    "desguedelhemo": "desguedelhar",
    "desguedelhemos": "desguedelhar",
    "desguedelhes": "desguedelhar",
    "desguedelho": "desguedelhar",
    "desguedelhou": "desguedelhar",
    "desguedelhá": "desguedelhar",
    "desguedelhámo": "desguedelhar",
    "desguedelhámos": "desguedelhar",
    "desguedelháramo": "desguedelhar",
    "desguedelháramos": "desguedelhar",
    "desguedelhárei": "desguedelhar",
    "desguedelháreis": "desguedelhar",
    "desguedelhásseis": "desguedelhar",
    "desguedelhássemos": "desguedelhar",
    "desguedelhávamo": "desguedelhar",
    "desguedelhávamos": "desguedelhar",
    "desguedelhávei": "desguedelhar",
    "desguedelháveis": "desguedelhar",
    "desiderandos": "desiderando",
    "desiderativa": "desiderativo",
    "desiderativas": "desiderativo",
    "desiderativos": "desiderativo",
    "desideratos": "desiderato",
    "desidiosa": "desidioso",
    "desidiosas": "desidioso",
    "desidiosos": "desidioso",
    "desidrata": "desidratar",
    "desidratada": "desidratar",
    "desidratadas": "desidratar",
    "desidratado": "desidratar",
    "desidratados": "desidratar",
    "desidratai": "desidratar",
    "desidratais": "desidratar",
    "desidratam": "desidratar",
    "desidratamo": "desidratar",
    "desidratamos": "desidratar",
    "desidratando": "desidratar",
    "desidratara": "desidratar",
    "desidrataram": "desidratar",
    "desidrataras": "desidratar",
    "desidratarde": "desidratar",
    "desidratardes": "desidratar",
    "desidratare": "desidratar",
    "desidratarei": "desidratar",
    "desidratareis": "desidratar",
    "desidratarem": "desidratar",
    "desidrataremos": "desidratar",
    "desidratares": "desidratar",
    "desidrataria": "desidratar",
    "desidratariam": "desidratar",
    "desidratarias": "desidratar",
    "desidratarmo": "desidratar",
    "desidratarmos": "desidratar",
    "desidratará": "desidratar",
    "desidratarás": "desidratar",
    "desidratarão": "desidratar",
    "desidrataríamos": "desidratar",
    "desidrataríeis": "desidratar",
    "desidratas": "desidratar",
    "desidratasse": "desidratar",
    "desidratassem": "desidratar",
    "desidratasses": "desidratar",
    "desidrataste": "desidratar",
    "desidratastes": "desidratar",
    "desidratava": "desidratar",
    "desidratavam": "desidratar",
    "desidratavas": "desidratar",
    "desidratações": "desidratação",
    "desidrate": "desidratar",
    "desidratei": "desidratar",
    "desidrateis": "desidratar",
    "desidratem": "desidratar",
    "desidratemo": "desidratar",
    "desidratemos": "desidratar",
    "desidrates": "desidratar",
    "desidrato": "desidratar",
    "desidratou": "desidratar",
    "desidratá": "desidratar",
    "desidratámo": "desidratar",
    "desidratámos": "desidratar",
    "desidratáramo": "desidratar",
    "desidratáramos": "desidratar",
    "desidratárei": "desidratar",
    "desidratáreis": "desidratar",
    "desidratásseis": "desidratar",
    "desidratássemos": "desidratar",
    "desidratávamo": "desidratar",
    "desidratávamos": "desidratar",
    "desidratávei": "desidratar",
    "desidratáveis": "desidratável",
    "desidrogena": "desidrogenar",
    "desidrogenada": "desidrogenar",
    "desidrogenadas": "desidrogenar",
    "desidrogenado": "desidrogenar",
    "desidrogenados": "desidrogenar",
    "desidrogenai": "desidrogenar",
    "desidrogenais": "desidrogenar",
    "desidrogenam": "desidrogenar",
    "desidrogenamo": "desidrogenar",
    "desidrogenamos": "desidrogenar",
    "desidrogenando": "desidrogenar",
    "desidrogenara": "desidrogenar",
    "desidrogenaram": "desidrogenar",
    "desidrogenaras": "desidrogenar",
    "desidrogenarde": "desidrogenar",
    "desidrogenardes": "desidrogenar",
    "desidrogenare": "desidrogenar",
    "desidrogenarei": "desidrogenar",
    "desidrogenareis": "desidrogenar",
    "desidrogenarem": "desidrogenar",
    "desidrogenaremos": "desidrogenar",
    "desidrogenares": "desidrogenar",
    "desidrogenaria": "desidrogenar",
    "desidrogenariam": "desidrogenar",
    "desidrogenarias": "desidrogenar",
    "desidrogenarmo": "desidrogenar",
    "desidrogenarmos": "desidrogenar",
    "desidrogenará": "desidrogenar",
    "desidrogenarás": "desidrogenar",
    "desidrogenarão": "desidrogenar",
    "desidrogenaríamos": "desidrogenar",
    "desidrogenaríeis": "desidrogenar",
    "desidrogenas": "desidrogenar",
    "desidrogenasse": "desidrogenar",
    "desidrogenassem": "desidrogenar",
    "desidrogenasses": "desidrogenar",
    "desidrogenaste": "desidrogenar",
    "desidrogenastes": "desidrogenar",
    "desidrogenava": "desidrogenar",
    "desidrogenavam": "desidrogenar",
    "desidrogenavas": "desidrogenar",
    "desidrogenações": "desidrogenação",
    "desidrogene": "desidrogenar",
    "desidrogenei": "desidrogenar",
    "desidrogeneis": "desidrogenar",
    "desidrogenem": "desidrogenar",
    "desidrogenemo": "desidrogenar",
    "desidrogenemos": "desidrogenar",
    "desidrogenes": "desidrogenar",
    "desidrogeno": "desidrogenar",
    "desidrogenou": "desidrogenar",
    "desidrogená": "desidrogenar",
    "desidrogenámo": "desidrogenar",
    "desidrogenámos": "desidrogenar",
    "desidrogenáramo": "desidrogenar",
    "desidrogenáramos": "desidrogenar",
    "desidrogenárei": "desidrogenar",
    "desidrogenáreis": "desidrogenar",
    "desidrogenásseis": "desidrogenar",
    "desidrogenássemos": "desidrogenar",
    "desidrogenávamo": "desidrogenar",
    "desidrogenávamos": "desidrogenar",
    "desidrogenávei": "desidrogenar",
    "desidrogenáveis": "desidrogenar",
    "designa": "designar",
    "designada": "designar",
    "designadas": "designar",
    "designado": "designar",
    "designadora": "designador",
    "designadoras": "designador",
    "designadores": "designador",
    "designados": "designar",
    "designai": "designar",
    "designais": "designar",
    "designam": "designar",
    "designamo": "designar",
    "designamos": "designar",
    "designando": "designar",
    "designara": "designar",
    "designaram": "designar",
    "designaras": "designar",
    "designarde": "designar",
    "designardes": "designar",
    "designare": "designar",
    "designarei": "designar",
    "designareis": "designar",
    "designarem": "designar",
    "designaremos": "designar",
    "designares": "designar",
    "designaria": "designar",
    "designariam": "designar",
    "designarias": "designar",
    "designarmo": "designar",
    "designarmos": "designar",
    "designará": "designar",
    "designarás": "designar",
    "designarão": "designar",
    "designaríamos": "designar",
    "designaríeis": "designar",
    "designas": "designar",
    "designasse": "designar",
    "designassem": "designar",
    "designasses": "designar",
    "designaste": "designar",
    "designastes": "designar",
    "designativa": "designativo",
    "designativas": "designativo",
    "designativos": "designativo",
    "designava": "designar",
    "designavam": "designar",
    "designavas": "designar",
    "designações": "designação",
    "designe": "designar",
    "designei": "designar",
    "designeis": "designar",
    "designem": "designar",
    "designemo": "designar",
    "designemos": "designar",
    "designeres": "designer",
    "designes": "designar",
    "designo": "designar",
    "designou": "designar",
    "designá": "designar",
    "designámo": "designar",
    "designámos": "designar",
    "designáramo": "designar",
    "designáramos": "designar",
    "designárei": "designar",
    "designáreis": "designar",
    "designásseis": "designar",
    "designássemos": "designar",
    "designávamo": "designar",
    "designávamos": "designar",
    "designávei": "designar",
    "designáveis": "designável",
    "desiguais": "desigual",
    "desiguala": "desigualar",
    "desigualada": "desigualar",
    "desigualadas": "desigualar",
    "desigualado": "desigualar",
    "desigualados": "desigualar",
    "desigualai": "desigualar",
    "desigualais": "desigualar",
    "desigualam": "desigualar",
    "desigualamo": "desigualar",
    "desigualamos": "desigualar",
    "desigualando": "desigualar",
    "desigualara": "desigualar",
    "desigualaram": "desigualar",
    "desigualaras": "desigualar",
    "desigualarde": "desigualar",
    "desigualardes": "desigualar",
    "desigualare": "desigualar",
    "desigualarei": "desigualar",
    "desigualareis": "desigualar",
    "desigualarem": "desigualar",
    "desigualaremos": "desigualar",
    "desigualares": "desigualar",
    "desigualaria": "desigualar",
    "desigualariam": "desigualar",
    "desigualarias": "desigualar",
    "desigualarmo": "desigualar",
    "desigualarmos": "desigualar",
    "desigualará": "desigualar",
    "desigualarás": "desigualar",
    "desigualarão": "desigualar",
    "desigualaríamos": "desigualar",
    "desigualaríeis": "desigualar",
    "desigualas": "desigualar",
    "desigualasse": "desigualar",
    "desigualassem": "desigualar",
    "desigualasses": "desigualar",
    "desigualaste": "desigualar",
    "desigualastes": "desigualar",
    "desigualava": "desigualar",
    "desigualavam": "desigualar",
    "desigualavas": "desigualar",
    "desigualdades": "desigualdade",
    "desiguale": "desigualar",
    "desigualei": "desigualar",
    "desigualeis": "desigualar",
    "desigualem": "desigualar",
    "desigualemo": "desigualar",
    "desigualemos": "desigualar",
    "desiguales": "desigualar",
    "desigualo": "desigualar",
    "desigualou": "desigualar",
    "desigualá": "desigualar",
    "desigualámo": "desigualar",
    "desigualámos": "desigualar",
    "desigualáramo": "desigualar",
    "desigualáramos": "desigualar",
    "desigualárei": "desigualar",
    "desigualáreis": "desigualar",
    "desigualásseis": "desigualar",
    "desigualássemos": "desigualar",
    "desigualávamo": "desigualar",
    "desigualávamos": "desigualar",
    "desigualávei": "desigualar",
    "desigualáveis": "desigualar",
    "desiluda": "desiludir",
    "desiludais": "desiludir",
    "desiludam": "desiludir",
    "desiludamo": "desiludir",
    "desiludamos": "desiludir",
    "desiludas": "desiludir",
    "desilude": "desiludir",
    "desiludem": "desiludir",
    "desiludes": "desiludir",
    "desiludi": "desiludir",
    "desiludia": "desiludir",
    "desiludiam": "desiludir",
    "desiludias": "desiludir",
    "desiludida": "desiludir",
    "desiludidas": "desiludir",
    "desiludido": "desiludir",
    "desiludidos": "desiludir",
    "desiludimo": "desiludir",
    "desiludimos": "desiludir",
    "desiludindo": "desiludir",
    "desiludira": "desiludir",
    "desiludiram": "desiludir",
    "desiludiras": "desiludir",
    "desiludirde": "desiludir",
    "desiludirdes": "desiludir",
    "desiludire": "desiludir",
    "desiludirei": "desiludir",
    "desiludireis": "desiludir",
    "desiludirem": "desiludir",
    "desiludiremos": "desiludir",
    "desiludires": "desiludir",
    "desiludiria": "desiludir",
    "desiludiriam": "desiludir",
    "desiludirias": "desiludir",
    "desiludirmo": "desiludir",
    "desiludirmos": "desiludir",
    "desiludirá": "desiludir",
    "desiludirás": "desiludir",
    "desiludirão": "desiludir",
    "desiludiríamos": "desiludir",
    "desiludiríeis": "desiludir",
    "desiludis": "desiludir",
    "desiludisse": "desiludir",
    "desiludissem": "desiludir",
    "desiludisses": "desiludir",
    "desiludiste": "desiludir",
    "desiludistes": "desiludir",
    "desiludiu": "desiludir",
    "desiludo": "desiludir",
    "desiludíamo": "desiludir",
    "desiludíamos": "desiludir",
    "desiludíei": "desiludir",
    "desiludíeis": "desiludir",
    "desiludíramo": "desiludir",
    "desiludíramos": "desiludir",
    "desiludírei": "desiludir",
    "desiludíreis": "desiludir",
    "desiludísseis": "desiludir",
    "desiludíssemos": "desiludir",
    "desiludíveis": "desiludível",
    "desiluminada": "desiluminado",
    "desiluminadas": "desiluminado",
    "desiluminados": "desiluminado",
    "desilusa": "desiluso",
    "desilusas": "desiluso",
    "desilusiva": "desilusivo",
    "desilusivas": "desilusivo",
    "desilusivos": "desilusivo",
    "desilusos": "desiluso",
    "desilustra": "desilustrar",
    "desilustrada": "desilustrar",
    "desilustradas": "desilustrar",
    "desilustrado": "desilustrar",
    "desilustrados": "desilustrar",
    "desilustrai": "desilustrar",
    "desilustrais": "desilustrar",
    "desilustram": "desilustrar",
    "desilustramo": "desilustrar",
    "desilustramos": "desilustrar",
    "desilustrando": "desilustrar",
    "desilustrara": "desilustrar",
    "desilustraram": "desilustrar",
    "desilustraras": "desilustrar",
    "desilustrarde": "desilustrar",
    "desilustrardes": "desilustrar",
    "desilustrare": "desilustrar",
    "desilustrarei": "desilustrar",
    "desilustrareis": "desilustrar",
    "desilustrarem": "desilustrar",
    "desilustraremos": "desilustrar",
    "desilustrares": "desilustrar",
    "desilustraria": "desilustrar",
    "desilustrariam": "desilustrar",
    "desilustrarias": "desilustrar",
    "desilustrarmo": "desilustrar",
    "desilustrarmos": "desilustrar",
    "desilustrará": "desilustrar",
    "desilustrarás": "desilustrar",
    "desilustrarão": "desilustrar",
    "desilustraríamos": "desilustrar",
    "desilustraríeis": "desilustrar",
    "desilustras": "desilustrar",
    "desilustrasse": "desilustrar",
    "desilustrassem": "desilustrar",
    "desilustrasses": "desilustrar",
    "desilustraste": "desilustrar",
    "desilustrastes": "desilustrar",
    "desilustrava": "desilustrar",
    "desilustravam": "desilustrar",
    "desilustravas": "desilustrar",
    "desilustre": "desilustrar",
    "desilustrei": "desilustrar",
    "desilustreis": "desilustrar",
    "desilustrem": "desilustrar",
    "desilustremo": "desilustrar",
    "desilustremos": "desilustrar",
    "desilustres": "desilustrar",
    "desilustro": "desilustrar",
    "desilustrou": "desilustrar",
    "desilustrá": "desilustrar",
    "desilustrámo": "desilustrar",
    "desilustrámos": "desilustrar",
    "desilustráramo": "desilustrar",
    "desilustráramos": "desilustrar",
    "desilustrárei": "desilustrar",
    "desilustráreis": "desilustrar",
    "desilustrásseis": "desilustrar",
    "desilustrássemos": "desilustrar",
    "desilustrávamo": "desilustrar",
    "desilustrávamos": "desilustrar",
    "desilustrávei": "desilustrar",
    "desilustráveis": "desilustrar",
    "desilusões": "desilusão",
    "desimagina": "desimaginar",
    "desimaginada": "desimaginar",
    "desimaginadas": "desimaginar",
    "desimaginado": "desimaginar",
    "desimaginados": "desimaginar",
    "desimaginai": "desimaginar",
    "desimaginais": "desimaginar",
    "desimaginam": "desimaginar",
    "desimaginamo": "desimaginar",
    "desimaginamos": "desimaginar",
    "desimaginando": "desimaginar",
    "desimaginara": "desimaginar",
    "desimaginaram": "desimaginar",
    "desimaginaras": "desimaginar",
    "desimaginarde": "desimaginar",
    "desimaginardes": "desimaginar",
    "desimaginare": "desimaginar",
    "desimaginarei": "desimaginar",
    "desimaginareis": "desimaginar",
    "desimaginarem": "desimaginar",
    "desimaginaremos": "desimaginar",
    "desimaginares": "desimaginar",
    "desimaginaria": "desimaginar",
    "desimaginariam": "desimaginar",
    "desimaginarias": "desimaginar",
    "desimaginarmo": "desimaginar",
    "desimaginarmos": "desimaginar",
    "desimaginará": "desimaginar",
    "desimaginarás": "desimaginar",
    "desimaginarão": "desimaginar",
    "desimaginaríamos": "desimaginar",
    "desimaginaríeis": "desimaginar",
    "desimaginas": "desimaginar",
    "desimaginasse": "desimaginar",
    "desimaginassem": "desimaginar",
    "desimaginasses": "desimaginar",
    "desimaginaste": "desimaginar",
    "desimaginastes": "desimaginar",
    "desimaginava": "desimaginar",
    "desimaginavam": "desimaginar",
    "desimaginavas": "desimaginar",
    "desimagine": "desimaginar",
    "desimaginei": "desimaginar",
    "desimagineis": "desimaginar",
    "desimaginem": "desimaginar",
    "desimaginemo": "desimaginar",
    "desimaginemos": "desimaginar",
    "desimagines": "desimaginar",
    "desimagino": "desimaginar",
    "desimaginosa": "desimaginoso",
    "desimaginosas": "desimaginoso",
    "desimaginosos": "desimaginoso",
    "desimaginou": "desimaginar",
    "desimaginá": "desimaginar",
    "desimaginámo": "desimaginar",
    "desimaginámos": "desimaginar",
    "desimagináramo": "desimaginar",
    "desimagináramos": "desimaginar",
    "desimaginárei": "desimaginar",
    "desimagináreis": "desimaginar",
    "desimaginásseis": "desimaginar",
    "desimaginássemos": "desimaginar",
    "desimaginávamo": "desimaginar",
    "desimaginávamos": "desimaginar",
    "desimaginávei": "desimaginar",
    "desimagináveis": "desimaginar",
    "desimana": "desimanar",
    "desimanada": "desimanar",
    "desimanadas": "desimanar",
    "desimanado": "desimanar",
    "desimanados": "desimanar",
    "desimanai": "desimanar",
    "desimanais": "desimanar",
    "desimanam": "desimanar",
    "desimanamo": "desimanar",
    "desimanamos": "desimanar",
    "desimanando": "desimanar",
    "desimanara": "desimanar",
    "desimanaram": "desimanar",
    "desimanaras": "desimanar",
    "desimanarde": "desimanar",
    "desimanardes": "desimanar",
    "desimanare": "desimanar",
    "desimanarei": "desimanar",
    "desimanareis": "desimanar",
    "desimanarem": "desimanar",
    "desimanaremos": "desimanar",
    "desimanares": "desimanar",
    "desimanaria": "desimanar",
    "desimanariam": "desimanar",
    "desimanarias": "desimanar",
    "desimanarmo": "desimanar",
    "desimanarmos": "desimanar",
    "desimanará": "desimanar",
    "desimanarás": "desimanar",
    "desimanarão": "desimanar",
    "desimanaríamos": "desimanar",
    "desimanaríeis": "desimanar",
    "desimanas": "desimanar",
    "desimanasse": "desimanar",
    "desimanassem": "desimanar",
    "desimanasses": "desimanar",
    "desimanaste": "desimanar",
    "desimanastes": "desimanar",
    "desimanava": "desimanar",
    "desimanavam": "desimanar",
    "desimanavas": "desimanar",
    "desimanações": "desimanação",
    "desimane": "desimanar",
    "desimanei": "desimanar",
    "desimaneis": "desimanar",
    "desimanem": "desimanar",
    "desimanemo": "desimanar",
    "desimanemos": "desimanar",
    "desimanes": "desimanar",
    "desimano": "desimanar",
    "desimanou": "desimanar",
    "desimaná": "desimanar",
    "desimanámo": "desimanar",
    "desimanámos": "desimanar",
    "desimanáramo": "desimanar",
    "desimanáramos": "desimanar",
    "desimanárei": "desimanar",
    "desimanáreis": "desimanar",
    "desimanásseis": "desimanar",
    "desimanássemos": "desimanar",
    "desimanávamo": "desimanar",
    "desimanávamos": "desimanar",
    "desimanávei": "desimanar",
    "desimanáveis": "desimanar",
    "desimbua": "desimbuir",
    "desimbuais": "desimbuir",
    "desimbuam": "desimbuir",
    "desimbuamo": "desimbuir",
    "desimbuamos": "desimbuir",
    "desimbuas": "desimbuir",
    "desimbuem": "desimbuir",
    "desimbui": "desimbuir",
    "desimbuida": "desimbuido",
    "desimbuidas": "desimbuido",
    "desimbuidos": "desimbuido",
    "desimbuindo": "desimbuir",
    "desimbuirde": "desimbuir",
    "desimbuirdes": "desimbuir",
    "desimbuirei": "desimbuir",
    "desimbuireis": "desimbuir",
    "desimbuiremos": "desimbuir",
    "desimbuiria": "desimbuir",
    "desimbuiriam": "desimbuir",
    "desimbuirias": "desimbuir",
    "desimbuirmo": "desimbuir",
    "desimbuirmos": "desimbuir",
    "desimbuirá": "desimbuir",
    "desimbuirás": "desimbuir",
    "desimbuirão": "desimbuir",
    "desimbuiríamos": "desimbuir",
    "desimbuiríeis": "desimbuir",
    "desimbuis": "desimbuir",
    "desimbuiu": "desimbuir",
    "desimbuo": "desimbuir",
    "desimbuí": "desimbuir",
    "desimbuía": "desimbuir",
    "desimbuíam": "desimbuir",
    "desimbuíamo": "desimbuir",
    "desimbuíamos": "desimbuir",
    "desimbuías": "desimbuir",
    "desimbuída": "desimbuir",
    "desimbuídas": "desimbuir",
    "desimbuído": "desimbuir",
    "desimbuídos": "desimbuir",
    "desimbuíei": "desimbuir",
    "desimbuíeis": "desimbuir",
    "desimbuímo": "desimbuir",
    "desimbuímos": "desimbuir",
    "desimbuíra": "desimbuir",
    "desimbuíram": "desimbuir",
    "desimbuíramo": "desimbuir",
    "desimbuíramos": "desimbuir",
    "desimbuíras": "desimbuir",
    "desimbuíre": "desimbuir",
    "desimbuírei": "desimbuir",
    "desimbuíreis": "desimbuir",
    "desimbuírem": "desimbuir",
    "desimbuíres": "desimbuir",
    "desimbuís": "desimbuir",
    "desimbuísse": "desimbuir",
    "desimbuísseis": "desimbuir",
    "desimbuíssem": "desimbuir",
    "desimbuíssemos": "desimbuir",
    "desimbuísses": "desimbuir",
    "desimbuíste": "desimbuir",
    "desimbuístes": "desimbuir",
    "desimpede": "desimpedir",
    "desimpedem": "desimpedir",
    "desimpedes": "desimpedir",
    "desimpedi": "desimpedir",
    "desimpedia": "desimpedir",
    "desimpediam": "desimpedir",
    "desimpedias": "desimpedir",
    "desimpedida": "desimpedir",
    "desimpedidas": "desimpedir",
    "desimpedido": "desimpedir",
    "desimpedidos": "desimpedir",
    "desimpedimentos": "desimpedimento",
    "desimpedimo": "desimpedir",
    "desimpedimos": "desimpedir",
    "desimpedindo": "desimpedir",
    "desimpedira": "desimpedir",
    "desimpediram": "desimpedir",
    "desimpediras": "desimpedir",
    "desimpedirde": "desimpedir",
    "desimpedirdes": "desimpedir",
    "desimpedire": "desimpedir",
    "desimpedirei": "desimpedir",
    "desimpedireis": "desimpedir",
    "desimpedirem": "desimpedir",
    "desimpediremos": "desimpedir",
    "desimpedires": "desimpedir",
    "desimpediria": "desimpedir",
    "desimpediriam": "desimpedir",
    "desimpedirias": "desimpedir",
    "desimpedirmo": "desimpedir",
    "desimpedirmos": "desimpedir",
    "desimpedirá": "desimpedir",
    "desimpedirás": "desimpedir",
    "desimpedirão": "desimpedir",
    "desimpediríamos": "desimpedir",
    "desimpediríeis": "desimpedir",
    "desimpedis": "desimpedir",
    "desimpedisse": "desimpedir",
    "desimpedissem": "desimpedir",
    "desimpedisses": "desimpedir",
    "desimpediste": "desimpedir",
    "desimpedistes": "desimpedir",
    "desimpediu": "desimpedir",
    "desimpedíamo": "desimpedir",
    "desimpedíamos": "desimpedir",
    "desimpedíei": "desimpedir",
    "desimpedíeis": "desimpedir",
    "desimpedíramo": "desimpedir",
    "desimpedíramos": "desimpedir",
    "desimpedírei": "desimpedir",
    "desimpedíreis": "desimpedir",
    "desimpedísseis": "desimpedir",
    "desimpedíssemos": "desimpedir",
    "desimpeça": "desimpedir",
    "desimpeçais": "desimpedir",
    "desimpeçam": "desimpedir",
    "desimpeçamo": "desimpedir",
    "desimpeçamos": "desimpedir",
    "desimpeças": "desimpedir",
    "desimpeço": "desimpedir",
    "desimplica": "desimplicar",
    "desimplicada": "desimplicar",
    "desimplicadas": "desimplicar",
    "desimplicado": "desimplicar",
    "desimplicados": "desimplicar",
    "desimplicai": "desimplicar",
    "desimplicais": "desimplicar",
    "desimplicam": "desimplicar",
    "desimplicamo": "desimplicar",
    "desimplicamos": "desimplicar",
    "desimplicando": "desimplicar",
    "desimplicara": "desimplicar",
    "desimplicaram": "desimplicar",
    "desimplicaras": "desimplicar",
    "desimplicarde": "desimplicar",
    "desimplicardes": "desimplicar",
    "desimplicare": "desimplicar",
    "desimplicarei": "desimplicar",
    "desimplicareis": "desimplicar",
    "desimplicarem": "desimplicar",
    "desimplicaremos": "desimplicar",
    "desimplicares": "desimplicar",
    "desimplicaria": "desimplicar",
    "desimplicariam": "desimplicar",
    "desimplicarias": "desimplicar",
    "desimplicarmo": "desimplicar",
    "desimplicarmos": "desimplicar",
    "desimplicará": "desimplicar",
    "desimplicarás": "desimplicar",
    "desimplicarão": "desimplicar",
    "desimplicaríamos": "desimplicar",
    "desimplicaríeis": "desimplicar",
    "desimplicas": "desimplicar",
    "desimplicasse": "desimplicar",
    "desimplicassem": "desimplicar",
    "desimplicasses": "desimplicar",
    "desimplicaste": "desimplicar",
    "desimplicastes": "desimplicar",
    "desimplicava": "desimplicar",
    "desimplicavam": "desimplicar",
    "desimplicavas": "desimplicar",
    "desimplico": "desimplicar",
    "desimplicou": "desimplicar",
    "desimplicá": "desimplicar",
    "desimplicámo": "desimplicar",
    "desimplicámos": "desimplicar",
    "desimplicáramo": "desimplicar",
    "desimplicáramos": "desimplicar",
    "desimplicárei": "desimplicar",
    "desimplicáreis": "desimplicar",
    "desimplicásseis": "desimplicar",
    "desimplicássemos": "desimplicar",
    "desimplicávamo": "desimplicar",
    "desimplicávamos": "desimplicar",
    "desimplicávei": "desimplicar",
    "desimplicáveis": "desimplicar",
    "desimplique": "desimplicar",
    "desimpliquei": "desimplicar",
    "desimpliqueis": "desimplicar",
    "desimpliquem": "desimplicar",
    "desimpliquemo": "desimplicar",
    "desimpliquemos": "desimplicar",
    "desimpliques": "desimplicar",
    "desimpregna": "desimpregnar",
    "desimpregnada": "desimpregnar",
    "desimpregnadas": "desimpregnar",
    "desimpregnado": "desimpregnar",
    "desimpregnados": "desimpregnar",
    "desimpregnai": "desimpregnar",
    "desimpregnais": "desimpregnar",
    "desimpregnam": "desimpregnar",
    "desimpregnamo": "desimpregnar",
    "desimpregnamos": "desimpregnar",
    "desimpregnando": "desimpregnar",
    "desimpregnara": "desimpregnar",
    "desimpregnaram": "desimpregnar",
    "desimpregnaras": "desimpregnar",
    "desimpregnarde": "desimpregnar",
    "desimpregnardes": "desimpregnar",
    "desimpregnare": "desimpregnar",
    "desimpregnarei": "desimpregnar",
    "desimpregnareis": "desimpregnar",
    "desimpregnarem": "desimpregnar",
    "desimpregnaremos": "desimpregnar",
    "desimpregnares": "desimpregnar",
    "desimpregnaria": "desimpregnar",
    "desimpregnariam": "desimpregnar",
    "desimpregnarias": "desimpregnar",
    "desimpregnarmo": "desimpregnar",
    "desimpregnarmos": "desimpregnar",
    "desimpregnará": "desimpregnar",
    "desimpregnarás": "desimpregnar",
    "desimpregnarão": "desimpregnar",
    "desimpregnaríamos": "desimpregnar",
    "desimpregnaríeis": "desimpregnar",
    "desimpregnas": "desimpregnar",
    "desimpregnasse": "desimpregnar",
    "desimpregnassem": "desimpregnar",
    "desimpregnasses": "desimpregnar",
    "desimpregnaste": "desimpregnar",
    "desimpregnastes": "desimpregnar",
    "desimpregnava": "desimpregnar",
    "desimpregnavam": "desimpregnar",
    "desimpregnavas": "desimpregnar",
    "desimpregne": "desimpregnar",
    "desimpregnei": "desimpregnar",
    "desimpregneis": "desimpregnar",
    "desimpregnem": "desimpregnar",
    "desimpregnemo": "desimpregnar",
    "desimpregnemos": "desimpregnar",
    "desimpregnes": "desimpregnar",
    "desimpregno": "desimpregnar",
    "desimpregnou": "desimpregnar",
    "desimpregná": "desimpregnar",
    "desimpregnámo": "desimpregnar",
    "desimpregnámos": "desimpregnar",
    "desimpregnáramo": "desimpregnar",
    "desimpregnáramos": "desimpregnar",
    "desimpregnárei": "desimpregnar",
    "desimpregnáreis": "desimpregnar",
    "desimpregnásseis": "desimpregnar",
    "desimpregnássemos": "desimpregnar",
    "desimpregnávamo": "desimpregnar",
    "desimpregnávamos": "desimpregnar",
    "desimpregnávei": "desimpregnar",
    "desimpregnáveis": "desimpregnar",
    "desimprensa": "desimprensar",
    "desimprensada": "desimprensar",
    "desimprensadas": "desimprensar",
    "desimprensado": "desimprensar",
    "desimprensados": "desimprensar",
    "desimprensai": "desimprensar",
    "desimprensais": "desimprensar",
    "desimprensam": "desimprensar",
    "desimprensamo": "desimprensar",
    "desimprensamos": "desimprensar",
    "desimprensando": "desimprensar",
    "desimprensara": "desimprensar",
    "desimprensaram": "desimprensar",
    "desimprensaras": "desimprensar",
    "desimprensarde": "desimprensar",
    "desimprensardes": "desimprensar",
    "desimprensare": "desimprensar",
    "desimprensarei": "desimprensar",
    "desimprensareis": "desimprensar",
    "desimprensarem": "desimprensar",
    "desimprensaremos": "desimprensar",
    "desimprensares": "desimprensar",
    "desimprensaria": "desimprensar",
    "desimprensariam": "desimprensar",
    "desimprensarias": "desimprensar",
    "desimprensarmo": "desimprensar",
    "desimprensarmos": "desimprensar",
    "desimprensará": "desimprensar",
    "desimprensarás": "desimprensar",
    "desimprensarão": "desimprensar",
    "desimprensaríamos": "desimprensar",
    "desimprensaríeis": "desimprensar",
    "desimprensas": "desimprensar",
    "desimprensasse": "desimprensar",
    "desimprensassem": "desimprensar",
    "desimprensasses": "desimprensar",
    "desimprensaste": "desimprensar",
    "desimprensastes": "desimprensar",
    "desimprensava": "desimprensar",
    "desimprensavam": "desimprensar",
    "desimprensavas": "desimprensar",
    "desimprense": "desimprensar",
    "desimprensei": "desimprensar",
    "desimprenseis": "desimprensar",
    "desimprensem": "desimprensar",
    "desimprensemo": "desimprensar",
    "desimprensemos": "desimprensar",
    "desimprenses": "desimprensar",
    "desimprenso": "desimprensar",
    "desimprensou": "desimprensar",
    "desimprensá": "desimprensar",
    "desimprensámo": "desimprensar",
    "desimprensámos": "desimprensar",
    "desimprensáramo": "desimprensar",
    "desimprensáramos": "desimprensar",
    "desimprensárei": "desimprensar",
    "desimprensáreis": "desimprensar",
    "desimprensásseis": "desimprensar",
    "desimprensássemos": "desimprensar",
    "desimprensávamo": "desimprensar",
    "desimprensávamos": "desimprensar",
    "desimprensávei": "desimprensar",
    "desimprensáveis": "desimprensar",
    "desimpressiona": "desimpressionar",
    "desimpressionada": "desimpressionar",
    "desimpressionadas": "desimpressionar",
    "desimpressionado": "desimpressionar",
    "desimpressionados": "desimpressionar",
    "desimpressionai": "desimpressionar",
    "desimpressionais": "desimpressionar",
    "desimpressionam": "desimpressionar",
    "desimpressionamo": "desimpressionar",
    "desimpressionamos": "desimpressionar",
    "desimpressionando": "desimpressionar",
    "desimpressionara": "desimpressionar",
    "desimpressionaram": "desimpressionar",
    "desimpressionaras": "desimpressionar",
    "desimpressionarde": "desimpressionar",
    "desimpressionardes": "desimpressionar",
    "desimpressionare": "desimpressionar",
    "desimpressionarei": "desimpressionar",
    "desimpressionareis": "desimpressionar",
    "desimpressionarem": "desimpressionar",
    "desimpressionaremos": "desimpressionar",
    "desimpressionares": "desimpressionar",
    "desimpressionaria": "desimpressionar",
    "desimpressionariam": "desimpressionar",
    "desimpressionarias": "desimpressionar",
    "desimpressionarmo": "desimpressionar",
    "desimpressionarmos": "desimpressionar",
    "desimpressionará": "desimpressionar",
    "desimpressionarás": "desimpressionar",
    "desimpressionarão": "desimpressionar",
    "desimpressionaríamos": "desimpressionar",
    "desimpressionaríeis": "desimpressionar",
    "desimpressionas": "desimpressionar",
    "desimpressionasse": "desimpressionar",
    "desimpressionassem": "desimpressionar",
    "desimpressionasses": "desimpressionar",
    "desimpressionaste": "desimpressionar",
    "desimpressionastes": "desimpressionar",
    "desimpressionava": "desimpressionar",
    "desimpressionavam": "desimpressionar",
    "desimpressionavas": "desimpressionar",
    "desimpressione": "desimpressionar",
    "desimpressionei": "desimpressionar",
    "desimpressioneis": "desimpressionar",
    "desimpressionem": "desimpressionar",
    "desimpressionemo": "desimpressionar",
    "desimpressionemos": "desimpressionar",
    "desimpressiones": "desimpressionar",
    "desimpressiono": "desimpressionar",
    "desimpressionou": "desimpressionar",
    "desimpressioná": "desimpressionar",
    "desimpressionámo": "desimpressionar",
    "desimpressionámos": "desimpressionar",
    "desimpressionáramo": "desimpressionar",
    "desimpressionáramos": "desimpressionar",
    "desimpressionárei": "desimpressionar",
    "desimpressionáreis": "desimpressionar",
    "desimpressionásseis": "desimpressionar",
    "desimpressionássemos": "desimpressionar",
    "desimpressionávamo": "desimpressionar",
    "desimpressionávamos": "desimpressionar",
    "desimpressionávei": "desimpressionar",
    "desimpressionáveis": "desimpressionar",
    "desince": "desinçar",
    "desincei": "desinçar",
    "desinceis": "desinçar",
    "desincem": "desinçar",
    "desincemo": "desinçar",
    "desincemos": "desinçar",
    "desincentiva": "desincentivar",
    "desincentivada": "desincentivar",
    "desincentivadas": "desincentivar",
    "desincentivado": "desincentivar",
    "desincentivadora": "desincentivador",
    "desincentivadoras": "desincentivador",
    "desincentivadores": "desincentivador",
    "desincentivados": "desincentivar",
    "desincentivai": "desincentivar",
    "desincentivais": "desincentivar",
    "desincentivam": "desincentivar",
    "desincentivamo": "desincentivar",
    "desincentivamos": "desincentivar",
    "desincentivando": "desincentivar",
    "desincentivara": "desincentivar",
    "desincentivaram": "desincentivar",
    "desincentivaras": "desincentivar",
    "desincentivarde": "desincentivar",
    "desincentivardes": "desincentivar",
    "desincentivare": "desincentivar",
    "desincentivarei": "desincentivar",
    "desincentivareis": "desincentivar",
    "desincentivarem": "desincentivar",
    "desincentivaremos": "desincentivar",
    "desincentivares": "desincentivar",
    "desincentivaria": "desincentivar",
    "desincentivariam": "desincentivar",
    "desincentivarias": "desincentivar",
    "desincentivarmo": "desincentivar",
    "desincentivarmos": "desincentivar",
    "desincentivará": "desincentivar",
    "desincentivarás": "desincentivar",
    "desincentivarão": "desincentivar",
    "desincentivaríamos": "desincentivar",
    "desincentivaríeis": "desincentivar",
    "desincentivas": "desincentivar",
    "desincentivasse": "desincentivar",
    "desincentivassem": "desincentivar",
    "desincentivasses": "desincentivar",
    "desincentivaste": "desincentivar",
    "desincentivastes": "desincentivar",
    "desincentivava": "desincentivar",
    "desincentivavam": "desincentivar",
    "desincentivavas": "desincentivar",
    "desincentive": "desincentivar",
    "desincentivei": "desincentivar",
    "desincentiveis": "desincentivar",
    "desincentivem": "desincentivar",
    "desincentivemo": "desincentivar",
    "desincentivemos": "desincentivar",
    "desincentives": "desincentivar",
    "desincentivo": "desincentivar",
    "desincentivos": "desincentivo",
    "desincentivou": "desincentivar",
    "desincentivá": "desincentivar",
    "desincentivámo": "desincentivar",
    "desincentivámos": "desincentivar",
    "desincentiváramo": "desincentivar",
    "desincentiváramos": "desincentivar",
    "desincentivárei": "desincentivar",
    "desincentiváreis": "desincentivar",
    "desincentivásseis": "desincentivar",
    "desincentivássemos": "desincentivar",
    "desincentivávamo": "desincentivar",
    "desincentivávamos": "desincentivar",
    "desincentivávei": "desincentivar",
    "desincentiváveis": "desincentivar",
    "desinces": "desinçar",
    "desincha": "desinchar",
    "desinchada": "desinchar",
    "desinchadas": "desinchar",
    "desinchado": "desinchar",
    "desinchados": "desinchar",
    "desinchai": "desinchar",
    "desinchais": "desinchar",
    "desincham": "desinchar",
    "desinchamo": "desinchar",
    "desinchamos": "desinchar",
    "desinchando": "desinchar",
    "desinchara": "desinchar",
    "desincharam": "desinchar",
    "desincharas": "desinchar",
    "desincharde": "desinchar",
    "desinchardes": "desinchar",
    "desinchare": "desinchar",
    "desincharei": "desinchar",
    "desinchareis": "desinchar",
    "desincharem": "desinchar",
    "desincharemos": "desinchar",
    "desinchares": "desinchar",
    "desincharia": "desinchar",
    "desinchariam": "desinchar",
    "desincharias": "desinchar",
    "desincharmo": "desinchar",
    "desincharmos": "desinchar",
    "desinchará": "desinchar",
    "desincharás": "desinchar",
    "desincharão": "desinchar",
    "desincharíamos": "desinchar",
    "desincharíeis": "desinchar",
    "desinchas": "desinchar",
    "desinchasse": "desinchar",
    "desinchassem": "desinchar",
    "desinchasses": "desinchar",
    "desinchaste": "desinchar",
    "desinchastes": "desinchar",
    "desinchava": "desinchar",
    "desinchavam": "desinchar",
    "desinchavas": "desinchar",
    "desinchações": "desinchação",
    "desinche": "desinchar",
    "desinchei": "desinchar",
    "desincheis": "desinchar",
    "desinchem": "desinchar",
    "desinchemo": "desinchar",
    "desinchemos": "desinchar",
    "desinches": "desinchar",
    "desincho": "desinchar",
    "desinchou": "desinchar",
    "desinchá": "desinchar",
    "desinchámo": "desinchar",
    "desinchámos": "desinchar",
    "desincháramo": "desinchar",
    "desincháramos": "desinchar",
    "desinchárei": "desinchar",
    "desincháreis": "desinchar",
    "desinchásseis": "desinchar",
    "desinchássemos": "desinchar",
    "desinchávamo": "desinchar",
    "desinchávamos": "desinchar",
    "desinchávei": "desinchar",
    "desincháveis": "desinchar",
    "desinclina": "desinclinar",
    "desinclinada": "desinclinar",
    "desinclinadas": "desinclinar",
    "desinclinado": "desinclinar",
    "desinclinados": "desinclinar",
    "desinclinai": "desinclinar",
    "desinclinais": "desinclinar",
    "desinclinam": "desinclinar",
    "desinclinamo": "desinclinar",
    "desinclinamos": "desinclinar",
    "desinclinando": "desinclinar",
    "desinclinara": "desinclinar",
    "desinclinaram": "desinclinar",
    "desinclinaras": "desinclinar",
    "desinclinarde": "desinclinar",
    "desinclinardes": "desinclinar",
    "desinclinare": "desinclinar",
    "desinclinarei": "desinclinar",
    "desinclinareis": "desinclinar",
    "desinclinarem": "desinclinar",
    "desinclinaremos": "desinclinar",
    "desinclinares": "desinclinar",
    "desinclinaria": "desinclinar",
    "desinclinariam": "desinclinar",
    "desinclinarias": "desinclinar",
    "desinclinarmo": "desinclinar",
    "desinclinarmos": "desinclinar",
    "desinclinará": "desinclinar",
    "desinclinarás": "desinclinar",
    "desinclinarão": "desinclinar",
    "desinclinaríamos": "desinclinar",
    "desinclinaríeis": "desinclinar",
    "desinclinas": "desinclinar",
    "desinclinasse": "desinclinar",
    "desinclinassem": "desinclinar",
    "desinclinasses": "desinclinar",
    "desinclinaste": "desinclinar",
    "desinclinastes": "desinclinar",
    "desinclinava": "desinclinar",
    "desinclinavam": "desinclinar",
    "desinclinavas": "desinclinar",
    "desinclinações": "desinclinação",
    "desincline": "desinclinar",
    "desinclinei": "desinclinar",
    "desinclineis": "desinclinar",
    "desinclinem": "desinclinar",
    "desinclinemo": "desinclinar",
    "desinclinemos": "desinclinar",
    "desinclines": "desinclinar",
    "desinclino": "desinclinar",
    "desinclinou": "desinclinar",
    "desincliná": "desinclinar",
    "desinclinámo": "desinclinar",
    "desinclinámos": "desinclinar",
    "desinclináramo": "desinclinar",
    "desinclináramos": "desinclinar",
    "desinclinárei": "desinclinar",
    "desinclináreis": "desinclinar",
    "desinclinásseis": "desinclinar",
    "desinclinássemos": "desinclinar",
    "desinclinávamo": "desinclinar",
    "desinclinávamos": "desinclinar",
    "desinclinávei": "desinclinar",
    "desinclináveis": "desinclinar",
    "desincompatibiliza": "desincompatibilizar",
    "desincompatibilizada": "desincompatibilizar",
    "desincompatibilizadas": "desincompatibilizar",
    "desincompatibilizado": "desincompatibilizar",
    "desincompatibilizados": "desincompatibilizar",
    "desincompatibilizai": "desincompatibilizar",
    "desincompatibilizais": "desincompatibilizar",
    "desincompatibilizam": "desincompatibilizar",
    "desincompatibilizamo": "desincompatibilizar",
    "desincompatibilizamos": "desincompatibilizar",
    "desincompatibilizando": "desincompatibilizar",
    "desincompatibilizara": "desincompatibilizar",
    "desincompatibilizaram": "desincompatibilizar",
    "desincompatibilizaras": "desincompatibilizar",
    "desincompatibilizarde": "desincompatibilizar",
    "desincompatibilizardes": "desincompatibilizar",
    "desincompatibilizare": "desincompatibilizar",
    "desincompatibilizarei": "desincompatibilizar",
    "desincompatibilizareis": "desincompatibilizar",
    "desincompatibilizarem": "desincompatibilizar",
    "desincompatibilizaremos": "desincompatibilizar",
    "desincompatibilizares": "desincompatibilizar",
    "desincompatibilizaria": "desincompatibilizar",
    "desincompatibilizariam": "desincompatibilizar",
    "desincompatibilizarias": "desincompatibilizar",
    "desincompatibilizarmo": "desincompatibilizar",
    "desincompatibilizarmos": "desincompatibilizar",
    "desincompatibilizará": "desincompatibilizar",
    "desincompatibilizarás": "desincompatibilizar",
    "desincompatibilizarão": "desincompatibilizar",
    "desincompatibilizaríamos": "desincompatibilizar",
    "desincompatibilizaríeis": "desincompatibilizar",
    "desincompatibilizas": "desincompatibilizar",
    "desincompatibilizasse": "desincompatibilizar",
    "desincompatibilizassem": "desincompatibilizar",
    "desincompatibilizasses": "desincompatibilizar",
    "desincompatibilizaste": "desincompatibilizar",
    "desincompatibilizastes": "desincompatibilizar",
    "desincompatibilizava": "desincompatibilizar",
    "desincompatibilizavam": "desincompatibilizar",
    "desincompatibilizavas": "desincompatibilizar",
    "desincompatibilize": "desincompatibilizar",
    "desincompatibilizei": "desincompatibilizar",
    "desincompatibilizeis": "desincompatibilizar",
    "desincompatibilizem": "desincompatibilizar",
    "desincompatibilizemo": "desincompatibilizar",
    "desincompatibilizemos": "desincompatibilizar",
    "desincompatibilizes": "desincompatibilizar",
    "desincompatibilizo": "desincompatibilizar",
    "desincompatibilizou": "desincompatibilizar",
    "desincompatibilizá": "desincompatibilizar",
    "desincompatibilizámo": "desincompatibilizar",
    "desincompatibilizámos": "desincompatibilizar",
    "desincompatibilizáramo": "desincompatibilizar",
    "desincompatibilizáramos": "desincompatibilizar",
    "desincompatibilizárei": "desincompatibilizar",
    "desincompatibilizáreis": "desincompatibilizar",
    "desincompatibilizásseis": "desincompatibilizar",
    "desincompatibilizássemos": "desincompatibilizar",
    "desincompatibilizávamo": "desincompatibilizar",
    "desincompatibilizávamos": "desincompatibilizar",
    "desincompatibilizávei": "desincompatibilizar",
    "desincompatibilizáveis": "desincompatibilizar",
    "desincorpora": "desincorporar",
    "desincorporada": "desincorporar",
    "desincorporadas": "desincorporar",
    "desincorporado": "desincorporar",
    "desincorporados": "desincorporar",
    "desincorporai": "desincorporar",
    "desincorporais": "desincorporar",
    "desincorporam": "desincorporar",
    "desincorporamo": "desincorporar",
    "desincorporamos": "desincorporar",
    "desincorporando": "desincorporar",
    "desincorporara": "desincorporar",
    "desincorporaram": "desincorporar",
    "desincorporaras": "desincorporar",
    "desincorporarde": "desincorporar",
    "desincorporardes": "desincorporar",
    "desincorporare": "desincorporar",
    "desincorporarei": "desincorporar",
    "desincorporareis": "desincorporar",
    "desincorporarem": "desincorporar",
    "desincorporaremos": "desincorporar",
    "desincorporares": "desincorporar",
    "desincorporaria": "desincorporar",
    "desincorporariam": "desincorporar",
    "desincorporarias": "desincorporar",
    "desincorporarmo": "desincorporar",
    "desincorporarmos": "desincorporar",
    "desincorporará": "desincorporar",
    "desincorporarás": "desincorporar",
    "desincorporarão": "desincorporar",
    "desincorporaríamos": "desincorporar",
    "desincorporaríeis": "desincorporar",
    "desincorporas": "desincorporar",
    "desincorporasse": "desincorporar",
    "desincorporassem": "desincorporar",
    "desincorporasses": "desincorporar",
    "desincorporaste": "desincorporar",
    "desincorporastes": "desincorporar",
    "desincorporava": "desincorporar",
    "desincorporavam": "desincorporar",
    "desincorporavas": "desincorporar",
    "desincorporações": "desincorporação",
    "desincorpore": "desincorporar",
    "desincorporei": "desincorporar",
    "desincorporeis": "desincorporar",
    "desincorporem": "desincorporar",
    "desincorporemo": "desincorporar",
    "desincorporemos": "desincorporar",
    "desincorpores": "desincorporar",
    "desincorporo": "desincorporar",
    "desincorporou": "desincorporar",
    "desincorporá": "desincorporar",
    "desincorporámo": "desincorporar",
    "desincorporámos": "desincorporar",
    "desincorporáramo": "desincorporar",
    "desincorporáramos": "desincorporar",
    "desincorporárei": "desincorporar",
    "desincorporáreis": "desincorporar",
    "desincorporásseis": "desincorporar",
    "desincorporássemos": "desincorporar",
    "desincorporávamo": "desincorporar",
    "desincorporávamos": "desincorporar",
    "desincorporávei": "desincorporar",
    "desincorporáveis": "desincorporar",
    "desincrusta": "desincrustar",
    "desincrustada": "desincrustar",
    "desincrustadas": "desincrustar",
    "desincrustado": "desincrustar",
    "desincrustados": "desincrustar",
    "desincrustai": "desincrustar",
    "desincrustais": "desincrustar",
    "desincrustam": "desincrustar",
    "desincrustamo": "desincrustar",
    "desincrustamos": "desincrustar",
    "desincrustando": "desincrustar",
    "desincrustara": "desincrustar",
    "desincrustaram": "desincrustar",
    "desincrustaras": "desincrustar",
    "desincrustarde": "desincrustar",
    "desincrustardes": "desincrustar",
    "desincrustare": "desincrustar",
    "desincrustarei": "desincrustar",
    "desincrustareis": "desincrustar",
    "desincrustarem": "desincrustar",
    "desincrustaremos": "desincrustar",
    "desincrustares": "desincrustar",
    "desincrustaria": "desincrustar",
    "desincrustariam": "desincrustar",
    "desincrustarias": "desincrustar",
    "desincrustarmo": "desincrustar",
    "desincrustarmos": "desincrustar",
    "desincrustará": "desincrustar",
    "desincrustarás": "desincrustar",
    "desincrustarão": "desincrustar",
    "desincrustaríamos": "desincrustar",
    "desincrustaríeis": "desincrustar",
    "desincrustas": "desincrustar",
    "desincrustasse": "desincrustar",
    "desincrustassem": "desincrustar",
    "desincrustasses": "desincrustar",
    "desincrustaste": "desincrustar",
    "desincrustastes": "desincrustar",
    "desincrustava": "desincrustar",
    "desincrustavam": "desincrustar",
    "desincrustavas": "desincrustar",
    "desincrustações": "desincrustação",
    "desincruste": "desincrustar",
    "desincrustei": "desincrustar",
    "desincrusteis": "desincrustar",
    "desincrustem": "desincrustar",
    "desincrustemo": "desincrustar",
    "desincrustemos": "desincrustar",
    "desincrustes": "desincrustar",
    "desincrusto": "desincrustar",
    "desincrustou": "desincrustar",
    "desincrustá": "desincrustar",
    "desincrustámo": "desincrustar",
    "desincrustámos": "desincrustar",
    "desincrustáramo": "desincrustar",
    "desincrustáramos": "desincrustar",
    "desincrustárei": "desincrustar",
    "desincrustáreis": "desincrustar",
    "desincrustásseis": "desincrustar",
    "desincrustássemos": "desincrustar",
    "desincrustávamo": "desincrustar",
    "desincrustávamos": "desincrustar",
    "desincrustávei": "desincrustar",
    "desincrustáveis": "desincrustar",
    "desincuba": "desincubar",
    "desincubada": "desincubar",
    "desincubadas": "desincubar",
    "desincubado": "desincubar",
    "desincubados": "desincubar",
    "desincubai": "desincubar",
    "desincubais": "desincubar",
    "desincubam": "desincubar",
    "desincubamo": "desincubar",
    "desincubamos": "desincubar",
    "desincubando": "desincubar",
    "desincubara": "desincubar",
    "desincubaram": "desincubar",
    "desincubaras": "desincubar",
    "desincubarde": "desincubar",
    "desincubardes": "desincubar",
    "desincubare": "desincubar",
    "desincubarei": "desincubar",
    "desincubareis": "desincubar",
    "desincubarem": "desincubar",
    "desincubaremos": "desincubar",
    "desincubares": "desincubar",
    "desincubaria": "desincubar",
    "desincubariam": "desincubar",
    "desincubarias": "desincubar",
    "desincubarmo": "desincubar",
    "desincubarmos": "desincubar",
    "desincubará": "desincubar",
    "desincubarás": "desincubar",
    "desincubarão": "desincubar",
    "desincubaríamos": "desincubar",
    "desincubaríeis": "desincubar",
    "desincubas": "desincubar",
    "desincubasse": "desincubar",
    "desincubassem": "desincubar",
    "desincubasses": "desincubar",
    "desincubaste": "desincubar",
    "desincubastes": "desincubar",
    "desincubava": "desincubar",
    "desincubavam": "desincubar",
    "desincubavas": "desincubar",
    "desincubações": "desincubação",
    "desincube": "desincubar",
    "desincubei": "desincubar",
    "desincubeis": "desincubar",
    "desincubem": "desincubar",
    "desincubemo": "desincubar",
    "desincubemos": "desincubar",
    "desincubes": "desincubar",
    "desincubo": "desincubar",
    "desincubou": "desincubar",
    "desincubá": "desincubar",
    "desincubámo": "desincubar",
    "desincubámos": "desincubar",
    "desincubáramo": "desincubar",
    "desincubáramos": "desincubar",
    "desincubárei": "desincubar",
    "desincubáreis": "desincubar",
    "desincubásseis": "desincubar",
    "desincubássemos": "desincubar",
    "desincubávamo": "desincubar",
    "desincubávamos": "desincubar",
    "desincubávei": "desincubar",
    "desincubáveis": "desincubar",
    "desincumba": "desincumbir",
    "desincumbais": "desincumbir",
    "desincumbam": "desincumbir",
    "desincumbamo": "desincumbir",
    "desincumbamos": "desincumbir",
    "desincumbas": "desincumbir",
    "desincumbe": "desincumbir",
    "desincumbem": "desincumbir",
    "desincumbes": "desincumbir",
    "desincumbi": "desincumbir",
    "desincumbia": "desincumbir",
    "desincumbiam": "desincumbir",
    "desincumbias": "desincumbir",
    "desincumbida": "desincumbir",
    "desincumbidas": "desincumbir",
    "desincumbido": "desincumbir",
    "desincumbidos": "desincumbir",
    "desincumbimo": "desincumbir",
    "desincumbimos": "desincumbir",
    "desincumbindo": "desincumbir",
    "desincumbira": "desincumbir",
    "desincumbiram": "desincumbir",
    "desincumbiras": "desincumbir",
    "desincumbirde": "desincumbir",
    "desincumbirdes": "desincumbir",
    "desincumbire": "desincumbir",
    "desincumbirei": "desincumbir",
    "desincumbireis": "desincumbir",
    "desincumbirem": "desincumbir",
    "desincumbiremos": "desincumbir",
    "desincumbires": "desincumbir",
    "desincumbiria": "desincumbir",
    "desincumbiriam": "desincumbir",
    "desincumbirias": "desincumbir",
    "desincumbirmo": "desincumbir",
    "desincumbirmos": "desincumbir",
    "desincumbirá": "desincumbir",
    "desincumbirás": "desincumbir",
    "desincumbirão": "desincumbir",
    "desincumbiríamos": "desincumbir",
    "desincumbiríeis": "desincumbir",
    "desincumbis": "desincumbir",
    "desincumbisse": "desincumbir",
    "desincumbissem": "desincumbir",
    "desincumbisses": "desincumbir",
    "desincumbiste": "desincumbir",
    "desincumbistes": "desincumbir",
    "desincumbiu": "desincumbir",
    "desincumbo": "desincumbir",
    "desincumbíamo": "desincumbir",
    "desincumbíamos": "desincumbir",
    "desincumbíei": "desincumbir",
    "desincumbíeis": "desincumbir",
    "desincumbíramo": "desincumbir",
    "desincumbíramos": "desincumbir",
    "desincumbírei": "desincumbir",
    "desincumbíreis": "desincumbir",
    "desincumbísseis": "desincumbir",
    "desincumbíssemos": "desincumbir",
    "desindexações": "desindexação",
    "desindicia": "desindiciar",
    "desindiciada": "desindiciar",
    "desindiciadas": "desindiciar",
    "desindiciado": "desindiciar",
    "desindiciados": "desindiciar",
    "desindiciai": "desindiciar",
    "desindiciais": "desindiciar",
    "desindiciam": "desindiciar",
    "desindiciamo": "desindiciar",
    "desindiciamos": "desindiciar",
    "desindiciando": "desindiciar",
    "desindiciara": "desindiciar",
    "desindiciaram": "desindiciar",
    "desindiciaras": "desindiciar",
    "desindiciarde": "desindiciar",
    "desindiciardes": "desindiciar",
    "desindiciare": "desindiciar",
    "desindiciarei": "desindiciar",
    "desindiciareis": "desindiciar",
    "desindiciarem": "desindiciar",
    "desindiciaremos": "desindiciar",
    "desindiciares": "desindiciar",
    "desindiciaria": "desindiciar",
    "desindiciariam": "desindiciar",
    "desindiciarias": "desindiciar",
    "desindiciarmo": "desindiciar",
    "desindiciarmos": "desindiciar",
    "desindiciará": "desindiciar",
    "desindiciarás": "desindiciar",
    "desindiciarão": "desindiciar",
    "desindiciaríamos": "desindiciar",
    "desindiciaríeis": "desindiciar",
    "desindicias": "desindiciar",
    "desindiciasse": "desindiciar",
    "desindiciassem": "desindiciar",
    "desindiciasses": "desindiciar",
    "desindiciaste": "desindiciar",
    "desindiciastes": "desindiciar",
    "desindiciava": "desindiciar",
    "desindiciavam": "desindiciar",
    "desindiciavas": "desindiciar",
    "desindicie": "desindiciar",
    "desindiciei": "desindiciar",
    "desindicieis": "desindiciar",
    "desindiciem": "desindiciar",
    "desindiciemo": "desindiciar",
    "desindiciemos": "desindiciar",
    "desindicies": "desindiciar",
    "desindicio": "desindiciar",
    "desindiciou": "desindiciar",
    "desindiciá": "desindiciar",
    "desindiciámo": "desindiciar",
    "desindiciámos": "desindiciar",
    "desindiciáramo": "desindiciar",
    "desindiciáramos": "desindiciar",
    "desindiciárei": "desindiciar",
    "desindiciáreis": "desindiciar",
    "desindiciásseis": "desindiciar",
    "desindiciássemos": "desindiciar",
    "desindiciávamo": "desindiciar",
    "desindiciávamos": "desindiciar",
    "desindiciávei": "desindiciar",
    "desindiciáveis": "desindiciar",
    "desindustrializações": "desindustrialização",
    "desinenciais": "desinencial",
    "desinfama": "desinfamar",
    "desinfamada": "desinfamar",
    "desinfamadas": "desinfamar",
    "desinfamado": "desinfamar",
    "desinfamados": "desinfamar",
    "desinfamai": "desinfamar",
    "desinfamais": "desinfamar",
    "desinfamam": "desinfamar",
    "desinfamamo": "desinfamar",
    "desinfamamos": "desinfamar",
    "desinfamando": "desinfamar",
    "desinfamara": "desinfamar",
    "desinfamaram": "desinfamar",
    "desinfamaras": "desinfamar",
    "desinfamarde": "desinfamar",
    "desinfamardes": "desinfamar",
    "desinfamare": "desinfamar",
    "desinfamarei": "desinfamar",
    "desinfamareis": "desinfamar",
    "desinfamarem": "desinfamar",
    "desinfamaremos": "desinfamar",
    "desinfamares": "desinfamar",
    "desinfamaria": "desinfamar",
    "desinfamariam": "desinfamar",
    "desinfamarias": "desinfamar",
    "desinfamarmo": "desinfamar",
    "desinfamarmos": "desinfamar",
    "desinfamará": "desinfamar",
    "desinfamarás": "desinfamar",
    "desinfamarão": "desinfamar",
    "desinfamaríamos": "desinfamar",
    "desinfamaríeis": "desinfamar",
    "desinfamas": "desinfamar",
    "desinfamasse": "desinfamar",
    "desinfamassem": "desinfamar",
    "desinfamasses": "desinfamar",
    "desinfamaste": "desinfamar",
    "desinfamastes": "desinfamar",
    "desinfamava": "desinfamar",
    "desinfamavam": "desinfamar",
    "desinfamavas": "desinfamar",
    "desinfame": "desinfamar",
    "desinfamei": "desinfamar",
    "desinfameis": "desinfamar",
    "desinfamem": "desinfamar",
    "desinfamemo": "desinfamar",
    "desinfamemos": "desinfamar",
    "desinfames": "desinfamar",
    "desinfamo": "desinfamar",
    "desinfamou": "desinfamar",
    "desinfamá": "desinfamar",
    "desinfamámo": "desinfamar",
    "desinfamámos": "desinfamar",
    "desinfamáramo": "desinfamar",
    "desinfamáramos": "desinfamar",
    "desinfamárei": "desinfamar",
    "desinfamáreis": "desinfamar",
    "desinfamásseis": "desinfamar",
    "desinfamássemos": "desinfamar",
    "desinfamávamo": "desinfamar",
    "desinfamávamos": "desinfamar",
    "desinfamávei": "desinfamar",
    "desinfamáveis": "desinfamar",
    "desinfeccionada": "desinfeccionado",
    "desinfeccionadas": "desinfeccionado",
    "desinfeccionados": "desinfeccionado",
    "desinfecta": "desinfectar",
    "desinfectada": "desinfectar",
    "desinfectadas": "desinfectar",
    "desinfectado": "desinfectar",
    "desinfectadora": "desinfectador",
    "desinfectadoras": "desinfectador",
    "desinfectadores": "desinfectador",
    "desinfectados": "desinfectar",
    "desinfectai": "desinfectar",
    "desinfectais": "desinfectar",
    "desinfectam": "desinfectar",
    "desinfectamo": "desinfectar",
    "desinfectamos": "desinfectar",
    "desinfectando": "desinfectar",
    "desinfectantes": "desinfectante",
    "desinfectara": "desinfectar",
    "desinfectaram": "desinfectar",
    "desinfectaras": "desinfectar",
    "desinfectarde": "desinfectar",
    "desinfectardes": "desinfectar",
    "desinfectare": "desinfectar",
    "desinfectarei": "desinfectar",
    "desinfectareis": "desinfectar",
    "desinfectarem": "desinfectar",
    "desinfectaremos": "desinfectar",
    "desinfectares": "desinfectar",
    "desinfectaria": "desinfectar",
    "desinfectariam": "desinfectar",
    "desinfectarias": "desinfectar",
    "desinfectarmo": "desinfectar",
    "desinfectarmos": "desinfectar",
    "desinfectará": "desinfectar",
    "desinfectarás": "desinfectar",
    "desinfectarão": "desinfectar",
    "desinfectaríamos": "desinfectar",
    "desinfectaríeis": "desinfectar",
    "desinfectas": "desinfectar",
    "desinfectasse": "desinfectar",
    "desinfectassem": "desinfectar",
    "desinfectasses": "desinfectar",
    "desinfectaste": "desinfectar",
    "desinfectastes": "desinfectar",
    "desinfectava": "desinfectar",
    "desinfectavam": "desinfectar",
    "desinfectavas": "desinfectar",
    "desinfecte": "desinfectar",
    "desinfectei": "desinfectar",
    "desinfecteis": "desinfectar",
    "desinfectem": "desinfectar",
    "desinfectemo": "desinfectar",
    "desinfectemos": "desinfectar",
    "desinfectes": "desinfectar",
    "desinfecto": "desinfectar",
    "desinfectou": "desinfectar",
    "desinfectá": "desinfectar",
    "desinfectámo": "desinfectar",
    "desinfectámos": "desinfectar",
    "desinfectáramo": "desinfectar",
    "desinfectáramos": "desinfectar",
    "desinfectárei": "desinfectar",
    "desinfectáreis": "desinfectar",
    "desinfectásseis": "desinfectar",
    "desinfectássemos": "desinfectar",
    "desinfectávamo": "desinfectar",
    "desinfectávamos": "desinfectar",
    "desinfectávei": "desinfectar",
    "desinfectáveis": "desinfectável",
    "desinfectórios": "desinfectório",
    "desinfecções": "desinfecção",
    "desinfelicidades": "desinfelicidade",
    "desinfelizes": "desinfeliz",
    "desinfelizs": "desinfeliz",
    "desinfesta": "desinfestar",
    "desinfestada": "desinfestar",
    "desinfestadas": "desinfestar",
    "desinfestado": "desinfestar",
    "desinfestados": "desinfestar",
    "desinfestai": "desinfestar",
    "desinfestais": "desinfestar",
    "desinfestam": "desinfestar",
    "desinfestamo": "desinfestar",
    "desinfestamos": "desinfestar",
    "desinfestando": "desinfestar",
    "desinfestara": "desinfestar",
    "desinfestaram": "desinfestar",
    "desinfestaras": "desinfestar",
    "desinfestarde": "desinfestar",
    "desinfestardes": "desinfestar",
    "desinfestare": "desinfestar",
    "desinfestarei": "desinfestar",
    "desinfestareis": "desinfestar",
    "desinfestarem": "desinfestar",
    "desinfestaremos": "desinfestar",
    "desinfestares": "desinfestar",
    "desinfestaria": "desinfestar",
    "desinfestariam": "desinfestar",
    "desinfestarias": "desinfestar",
    "desinfestarmo": "desinfestar",
    "desinfestarmos": "desinfestar",
    "desinfestará": "desinfestar",
    "desinfestarás": "desinfestar",
    "desinfestarão": "desinfestar",
    "desinfestaríamos": "desinfestar",
    "desinfestaríeis": "desinfestar",
    "desinfestas": "desinfestar",
    "desinfestasse": "desinfestar",
    "desinfestassem": "desinfestar",
    "desinfestasses": "desinfestar",
    "desinfestaste": "desinfestar",
    "desinfestastes": "desinfestar",
    "desinfestava": "desinfestar",
    "desinfestavam": "desinfestar",
    "desinfestavas": "desinfestar",
    "desinfestações": "desinfestação",
    "desinfeste": "desinfestar",
    "desinfestei": "desinfestar",
    "desinfesteis": "desinfestar",
    "desinfestem": "desinfestar",
    "desinfestemo": "desinfestar",
    "desinfestemos": "desinfestar",
    "desinfestes": "desinfestar",
    "desinfesto": "desinfestar",
    "desinfestou": "desinfestar",
    "desinfestá": "desinfestar",
    "desinfestámo": "desinfestar",
    "desinfestámos": "desinfestar",
    "desinfestáramo": "desinfestar",
    "desinfestáramos": "desinfestar",
    "desinfestárei": "desinfestar",
    "desinfestáreis": "desinfestar",
    "desinfestásseis": "desinfestar",
    "desinfestássemos": "desinfestar",
    "desinfestávamo": "desinfestar",
    "desinfestávamos": "desinfestar",
    "desinfestávei": "desinfestar",
    "desinfestáveis": "desinfestar",
    "desinficionada": "desinficionado",
    "desinficionadas": "desinficionado",
    "desinficionados": "desinficionado",
    "desinflacciona": "desinflaccionar",
    "desinflaccionada": "desinflaccionar",
    "desinflaccionadas": "desinflaccionar",
    "desinflaccionado": "desinflaccionar",
    "desinflaccionados": "desinflaccionar",
    "desinflaccionai": "desinflaccionar",
    "desinflaccionais": "desinflaccionar",
    "desinflaccionam": "desinflaccionar",
    "desinflaccionamo": "desinflaccionar",
    "desinflaccionamos": "desinflaccionar",
    "desinflaccionando": "desinflaccionar",
    "desinflaccionara": "desinflaccionar",
    "desinflaccionaram": "desinflaccionar",
    "desinflaccionaras": "desinflaccionar",
    "desinflaccionarde": "desinflaccionar",
    "desinflaccionardes": "desinflaccionar",
    "desinflaccionare": "desinflaccionar",
    "desinflaccionarei": "desinflaccionar",
    "desinflaccionareis": "desinflaccionar",
    "desinflaccionarem": "desinflaccionar",
    "desinflaccionaremos": "desinflaccionar",
    "desinflaccionares": "desinflaccionar",
    "desinflaccionaria": "desinflaccionar",
    "desinflaccionariam": "desinflaccionar",
    "desinflaccionarias": "desinflaccionar",
    "desinflaccionarmo": "desinflaccionar",
    "desinflaccionarmos": "desinflaccionar",
    "desinflaccionará": "desinflaccionar",
    "desinflaccionarás": "desinflaccionar",
    "desinflaccionarão": "desinflaccionar",
    "desinflaccionaríamos": "desinflaccionar",
    "desinflaccionaríeis": "desinflaccionar",
    "desinflaccionas": "desinflaccionar",
    "desinflaccionasse": "desinflaccionar",
    "desinflaccionassem": "desinflaccionar",
    "desinflaccionasses": "desinflaccionar",
    "desinflaccionaste": "desinflaccionar",
    "desinflaccionastes": "desinflaccionar",
    "desinflaccionava": "desinflaccionar",
    "desinflaccionavam": "desinflaccionar",
    "desinflaccionavas": "desinflaccionar",
    "desinflaccione": "desinflaccionar",
    "desinflaccionei": "desinflaccionar",
    "desinflaccioneis": "desinflaccionar",
    "desinflaccionem": "desinflaccionar",
    "desinflaccionemo": "desinflaccionar",
    "desinflaccionemos": "desinflaccionar",
    "desinflacciones": "desinflaccionar",
    "desinflacciono": "desinflaccionar",
    "desinflaccionou": "desinflaccionar",
    "desinflaccioná": "desinflaccionar",
    "desinflaccionámo": "desinflaccionar",
    "desinflaccionámos": "desinflaccionar",
    "desinflaccionáramo": "desinflaccionar",
    "desinflaccionáramos": "desinflaccionar",
    "desinflaccionárei": "desinflaccionar",
    "desinflaccionáreis": "desinflaccionar",
    "desinflaccionásseis": "desinflaccionar",
    "desinflaccionássemos": "desinflaccionar",
    "desinflaccionávamo": "desinflaccionar",
    "desinflaccionávamos": "desinflaccionar",
    "desinflaccionávei": "desinflaccionar",
    "desinflaccionáveis": "desinflaccionar",
    "desinflacionada": "desinflacionado",
    "desinflacionadas": "desinflacionado",
    "desinflacionados": "desinflacionado",
    "desinflama": "desinflamar",
    "desinflamada": "desinflamar",
    "desinflamadas": "desinflamar",
    "desinflamado": "desinflamar",
    "desinflamados": "desinflamar",
    "desinflamai": "desinflamar",
    "desinflamais": "desinflamar",
    "desinflamam": "desinflamar",
    "desinflamamo": "desinflamar",
    "desinflamamos": "desinflamar",
    "desinflamando": "desinflamar",
    "desinflamara": "desinflamar",
    "desinflamaram": "desinflamar",
    "desinflamaras": "desinflamar",
    "desinflamarde": "desinflamar",
    "desinflamardes": "desinflamar",
    "desinflamare": "desinflamar",
    "desinflamarei": "desinflamar",
    "desinflamareis": "desinflamar",
    "desinflamarem": "desinflamar",
    "desinflamaremos": "desinflamar",
    "desinflamares": "desinflamar",
    "desinflamaria": "desinflamar",
    "desinflamariam": "desinflamar",
    "desinflamarias": "desinflamar",
    "desinflamarmo": "desinflamar",
    "desinflamarmos": "desinflamar",
    "desinflamará": "desinflamar",
    "desinflamarás": "desinflamar",
    "desinflamarão": "desinflamar",
    "desinflamaríamos": "desinflamar",
    "desinflamaríeis": "desinflamar",
    "desinflamas": "desinflamar",
    "desinflamasse": "desinflamar",
    "desinflamassem": "desinflamar",
    "desinflamasses": "desinflamar",
    "desinflamaste": "desinflamar",
    "desinflamastes": "desinflamar",
    "desinflamava": "desinflamar",
    "desinflamavam": "desinflamar",
    "desinflamavas": "desinflamar",
    "desinflamações": "desinflamação",
    "desinflame": "desinflamar",
    "desinflamei": "desinflamar",
    "desinflameis": "desinflamar",
    "desinflamem": "desinflamar",
    "desinflamemo": "desinflamar",
    "desinflamemos": "desinflamar",
    "desinflames": "desinflamar",
    "desinflamo": "desinflamar",
    "desinflamou": "desinflamar",
    "desinflamá": "desinflamar",
    "desinflamámo": "desinflamar",
    "desinflamámos": "desinflamar",
    "desinflamáramo": "desinflamar",
    "desinflamáramos": "desinflamar",
    "desinflamárei": "desinflamar",
    "desinflamáreis": "desinflamar",
    "desinflamásseis": "desinflamar",
    "desinflamássemos": "desinflamar",
    "desinflamávamo": "desinflamar",
    "desinflamávamos": "desinflamar",
    "desinflamávei": "desinflamar",
    "desinflamáveis": "desinflamar",
    "desinflações": "desinflação",
    "desinflua": "desinfluir",
    "desinfluais": "desinfluir",
    "desinfluam": "desinfluir",
    "desinfluamo": "desinfluir",
    "desinfluamos": "desinfluir",
    "desinfluas": "desinfluir",
    "desinfluem": "desinfluir",
    "desinflui": "desinfluir",
    "desinfluida": "desinfluido",
    "desinfluidas": "desinfluido",
    "desinfluidos": "desinfluido",
    "desinfluindo": "desinfluir",
    "desinfluirde": "desinfluir",
    "desinfluirdes": "desinfluir",
    "desinfluirei": "desinfluir",
    "desinfluireis": "desinfluir",
    "desinfluiremos": "desinfluir",
    "desinfluiria": "desinfluir",
    "desinfluiriam": "desinfluir",
    "desinfluirias": "desinfluir",
    "desinfluirmo": "desinfluir",
    "desinfluirmos": "desinfluir",
    "desinfluirá": "desinfluir",
    "desinfluirás": "desinfluir",
    "desinfluirão": "desinfluir",
    "desinfluiríamos": "desinfluir",
    "desinfluiríeis": "desinfluir",
    "desinfluis": "desinfluir",
    "desinfluiu": "desinfluir",
    "desinfluo": "desinfluir",
    "desinfluí": "desinfluir",
    "desinfluía": "desinfluir",
    "desinfluíam": "desinfluir",
    "desinfluíamo": "desinfluir",
    "desinfluíamos": "desinfluir",
    "desinfluías": "desinfluir",
    "desinfluída": "desinfluir",
    "desinfluídas": "desinfluir",
    "desinfluído": "desinfluir",
    "desinfluídos": "desinfluir",
    "desinfluíei": "desinfluir",
    "desinfluíeis": "desinfluir",
    "desinfluímo": "desinfluir",
    "desinfluímos": "desinfluir",
    "desinfluíra": "desinfluir",
    "desinfluíram": "desinfluir",
    "desinfluíramo": "desinfluir",
    "desinfluíramos": "desinfluir",
    "desinfluíras": "desinfluir",
    "desinfluíre": "desinfluir",
    "desinfluírei": "desinfluir",
    "desinfluíreis": "desinfluir",
    "desinfluírem": "desinfluir",
    "desinfluíres": "desinfluir",
    "desinfluís": "desinfluir",
    "desinfluísse": "desinfluir",
    "desinfluísseis": "desinfluir",
    "desinfluíssem": "desinfluir",
    "desinfluíssemos": "desinfluir",
    "desinfluísses": "desinfluir",
    "desinfluíste": "desinfluir",
    "desinfluístes": "desinfluir",
    "desinforma": "desinformar",
    "desinformada": "desinformar",
    "desinformadas": "desinformar",
    "desinformado": "desinformar",
    "desinformados": "desinformar",
    "desinformai": "desinformar",
    "desinformais": "desinformar",
    "desinformam": "desinformar",
    "desinformamo": "desinformar",
    "desinformamos": "desinformar",
    "desinformando": "desinformar",
    "desinformara": "desinformar",
    "desinformaram": "desinformar",
    "desinformaras": "desinformar",
    "desinformarde": "desinformar",
    "desinformardes": "desinformar",
    "desinformare": "desinformar",
    "desinformarei": "desinformar",
    "desinformareis": "desinformar",
    "desinformarem": "desinformar",
    "desinformaremos": "desinformar",
    "desinformares": "desinformar",
    "desinformaria": "desinformar",
    "desinformariam": "desinformar",
    "desinformarias": "desinformar",
    "desinformarmo": "desinformar",
    "desinformarmos": "desinformar",
    "desinformará": "desinformar",
    "desinformarás": "desinformar",
    "desinformarão": "desinformar",
    "desinformaríamos": "desinformar",
    "desinformaríeis": "desinformar",
    "desinformas": "desinformar",
    "desinformasse": "desinformar",
    "desinformassem": "desinformar",
    "desinformasses": "desinformar",
    "desinformaste": "desinformar",
    "desinformastes": "desinformar",
    "desinformativa": "desinformativo",
    "desinformativas": "desinformativo",
    "desinformativos": "desinformativo",
    "desinformava": "desinformar",
    "desinformavam": "desinformar",
    "desinformavas": "desinformar",
    "desinformações": "desinformação",
    "desinforme": "desinformar",
    "desinformei": "desinformar",
    "desinformeis": "desinformar",
    "desinformem": "desinformar",
    "desinformemo": "desinformar",
    "desinformemos": "desinformar",
    "desinformes": "desinformar",
    "desinformo": "desinformar",
    "desinformou": "desinformar",
    "desinformá": "desinformar",
    "desinformámo": "desinformar",
    "desinformámos": "desinformar",
    "desinformáramo": "desinformar",
    "desinformáramos": "desinformar",
    "desinformárei": "desinformar",
    "desinformáreis": "desinformar",
    "desinformásseis": "desinformar",
    "desinformássemos": "desinformar",
    "desinformávamo": "desinformar",
    "desinformávamos": "desinformar",
    "desinformávei": "desinformar",
    "desinformáveis": "desinformar",
    "desinframada": "desinframado",
    "desinframadas": "desinframado",
    "desinframados": "desinframado",
    "desingurgita": "desingurgitar",
    "desingurgitada": "desingurgitar",
    "desingurgitadas": "desingurgitar",
    "desingurgitado": "desingurgitar",
    "desingurgitados": "desingurgitar",
    "desingurgitai": "desingurgitar",
    "desingurgitais": "desingurgitar",
    "desingurgitam": "desingurgitar",
    "desingurgitamentos": "desingurgitamento",
    "desingurgitamo": "desingurgitar",
    "desingurgitamos": "desingurgitar",
    "desingurgitando": "desingurgitar",
    "desingurgitara": "desingurgitar",
    "desingurgitaram": "desingurgitar",
    "desingurgitaras": "desingurgitar",
    "desingurgitarde": "desingurgitar",
    "desingurgitardes": "desingurgitar",
    "desingurgitare": "desingurgitar",
    "desingurgitarei": "desingurgitar",
    "desingurgitareis": "desingurgitar",
    "desingurgitarem": "desingurgitar",
    "desingurgitaremos": "desingurgitar",
    "desingurgitares": "desingurgitar",
    "desingurgitaria": "desingurgitar",
    "desingurgitariam": "desingurgitar",
    "desingurgitarias": "desingurgitar",
    "desingurgitarmo": "desingurgitar",
    "desingurgitarmos": "desingurgitar",
    "desingurgitará": "desingurgitar",
    "desingurgitarás": "desingurgitar",
    "desingurgitarão": "desingurgitar",
    "desingurgitaríamos": "desingurgitar",
    "desingurgitaríeis": "desingurgitar",
    "desingurgitas": "desingurgitar",
    "desingurgitasse": "desingurgitar",
    "desingurgitassem": "desingurgitar",
    "desingurgitasses": "desingurgitar",
    "desingurgitaste": "desingurgitar",
    "desingurgitastes": "desingurgitar",
    "desingurgitava": "desingurgitar",
    "desingurgitavam": "desingurgitar",
    "desingurgitavas": "desingurgitar",
    "desingurgite": "desingurgitar",
    "desingurgitei": "desingurgitar",
    "desingurgiteis": "desingurgitar",
    "desingurgitem": "desingurgitar",
    "desingurgitemo": "desingurgitar",
    "desingurgitemos": "desingurgitar",
    "desingurgites": "desingurgitar",
    "desingurgito": "desingurgitar",
    "desingurgitou": "desingurgitar",
    "desingurgitá": "desingurgitar",
    "desingurgitámo": "desingurgitar",
    "desingurgitámos": "desingurgitar",
    "desingurgitáramo": "desingurgitar",
    "desingurgitáramos": "desingurgitar",
    "desingurgitárei": "desingurgitar",
    "desingurgitáreis": "desingurgitar",
    "desingurgitásseis": "desingurgitar",
    "desingurgitássemos": "desingurgitar",
    "desingurgitávamo": "desingurgitar",
    "desingurgitávamos": "desingurgitar",
    "desingurgitávei": "desingurgitar",
    "desingurgitáveis": "desingurgitar",
    "desiniba": "desinibir",
    "desinibais": "desinibir",
    "desinibam": "desinibir",
    "desinibamo": "desinibir",
    "desinibamos": "desinibir",
    "desinibas": "desinibir",
    "desinibe": "desinibir",
    "desinibem": "desinibir",
    "desinibes": "desinibir",
    "desinibi": "desinibir",
    "desinibia": "desinibir",
    "desinibiam": "desinibir",
    "desinibias": "desinibir",
    "desinibida": "desinibir",
    "desinibidas": "desinibir",
    "desinibido": "desinibir",
    "desinibidos": "desinibir",
    "desinibimo": "desinibir",
    "desinibimos": "desinibir",
    "desinibindo": "desinibir",
    "desinibira": "desinibir",
    "desinibiram": "desinibir",
    "desinibiras": "desinibir",
    "desinibirde": "desinibir",
    "desinibirdes": "desinibir",
    "desinibire": "desinibir",
    "desinibirei": "desinibir",
    "desinibireis": "desinibir",
    "desinibirem": "desinibir",
    "desinibiremos": "desinibir",
    "desinibires": "desinibir",
    "desinibiria": "desinibir",
    "desinibiriam": "desinibir",
    "desinibirias": "desinibir",
    "desinibirmo": "desinibir",
    "desinibirmos": "desinibir",
    "desinibirá": "desinibir",
    "desinibirás": "desinibir",
    "desinibirão": "desinibir",
    "desinibiríamos": "desinibir",
    "desinibiríeis": "desinibir",
    "desinibis": "desinibir",
    "desinibisse": "desinibir",
    "desinibissem": "desinibir",
    "desinibisses": "desinibir",
    "desinibiste": "desinibir",
    "desinibistes": "desinibir",
    "desinibiu": "desinibir",
    "desinibições": "desinibição",
    "desinibo": "desinibir",
    "desinibíamo": "desinibir",
    "desinibíamos": "desinibir",
    "desinibíei": "desinibir",
    "desinibíeis": "desinibir",
    "desinibíramo": "desinibir",
    "desinibíramos": "desinibir",
    "desinibírei": "desinibir",
    "desinibíreis": "desinibir",
    "desinibísseis": "desinibir",
    "desinibíssemos": "desinibir",
    "desinjuria": "desinjuriar",
    "desinjuriada": "desinjuriar",
    "desinjuriadas": "desinjuriar",
    "desinjuriado": "desinjuriar",
    "desinjuriados": "desinjuriar",
    "desinjuriai": "desinjuriar",
    "desinjuriais": "desinjuriar",
    "desinjuriam": "desinjuriar",
    "desinjuriamo": "desinjuriar",
    "desinjuriamos": "desinjuriar",
    "desinjuriando": "desinjuriar",
    "desinjuriara": "desinjuriar",
    "desinjuriaram": "desinjuriar",
    "desinjuriaras": "desinjuriar",
    "desinjuriarde": "desinjuriar",
    "desinjuriardes": "desinjuriar",
    "desinjuriare": "desinjuriar",
    "desinjuriarei": "desinjuriar",
    "desinjuriareis": "desinjuriar",
    "desinjuriarem": "desinjuriar",
    "desinjuriaremos": "desinjuriar",
    "desinjuriares": "desinjuriar",
    "desinjuriaria": "desinjuriar",
    "desinjuriariam": "desinjuriar",
    "desinjuriarias": "desinjuriar",
    "desinjuriarmo": "desinjuriar",
    "desinjuriarmos": "desinjuriar",
    "desinjuriará": "desinjuriar",
    "desinjuriarás": "desinjuriar",
    "desinjuriarão": "desinjuriar",
    "desinjuriaríamos": "desinjuriar",
    "desinjuriaríeis": "desinjuriar",
    "desinjurias": "desinjuriar",
    "desinjuriasse": "desinjuriar",
    "desinjuriassem": "desinjuriar",
    "desinjuriasses": "desinjuriar",
    "desinjuriaste": "desinjuriar",
    "desinjuriastes": "desinjuriar",
    "desinjuriava": "desinjuriar",
    "desinjuriavam": "desinjuriar",
    "desinjuriavas": "desinjuriar",
    "desinjurie": "desinjuriar",
    "desinjuriei": "desinjuriar",
    "desinjurieis": "desinjuriar",
    "desinjuriem": "desinjuriar",
    "desinjuriemo": "desinjuriar",
    "desinjuriemos": "desinjuriar",
    "desinjuries": "desinjuriar",
    "desinjurio": "desinjuriar",
    "desinjuriou": "desinjuriar",
    "desinjuriá": "desinjuriar",
    "desinjuriámo": "desinjuriar",
    "desinjuriámos": "desinjuriar",
    "desinjuriáramo": "desinjuriar",
    "desinjuriáramos": "desinjuriar",
    "desinjuriárei": "desinjuriar",
    "desinjuriáreis": "desinjuriar",
    "desinjuriásseis": "desinjuriar",
    "desinjuriássemos": "desinjuriar",
    "desinjuriávamo": "desinjuriar",
    "desinjuriávamos": "desinjuriar",
    "desinjuriávei": "desinjuriar",
    "desinjuriáveis": "desinjuriar",
    "desinquieta": "desinquieto",
    "desinquietada": "desinquietar",
    "desinquietadas": "desinquietar",
    "desinquietado": "desinquietar",
    "desinquietadora": "desinquietador",
    "desinquietadoras": "desinquietador",
    "desinquietadores": "desinquietador",
    "desinquietados": "desinquietar",
    "desinquietai": "desinquietar",
    "desinquietais": "desinquietar",
    "desinquietam": "desinquietar",
    "desinquietamo": "desinquietar",
    "desinquietamos": "desinquietar",
    "desinquietando": "desinquietar",
    "desinquietantes": "desinquietante",
    "desinquietara": "desinquietar",
    "desinquietaram": "desinquietar",
    "desinquietaras": "desinquietar",
    "desinquietarde": "desinquietar",
    "desinquietardes": "desinquietar",
    "desinquietare": "desinquietar",
    "desinquietarei": "desinquietar",
    "desinquietareis": "desinquietar",
    "desinquietarem": "desinquietar",
    "desinquietaremos": "desinquietar",
    "desinquietares": "desinquietar",
    "desinquietaria": "desinquietar",
    "desinquietariam": "desinquietar",
    "desinquietarias": "desinquietar",
    "desinquietarmo": "desinquietar",
    "desinquietarmos": "desinquietar",
    "desinquietará": "desinquietar",
    "desinquietarás": "desinquietar",
    "desinquietarão": "desinquietar",
    "desinquietaríamos": "desinquietar",
    "desinquietaríeis": "desinquietar",
    "desinquietas": "desinquieto",
    "desinquietasse": "desinquietar",
    "desinquietassem": "desinquietar",
    "desinquietasses": "desinquietar",
    "desinquietaste": "desinquietar",
    "desinquietastes": "desinquietar",
    "desinquietava": "desinquietar",
    "desinquietavam": "desinquietar",
    "desinquietavas": "desinquietar",
    "desinquietações": "desinquietação",
    "desinquiete": "desinquietar",
    "desinquietei": "desinquietar",
    "desinquieteis": "desinquietar",
    "desinquietem": "desinquietar",
    "desinquietemo": "desinquietar",
    "desinquietemos": "desinquietar",
    "desinquietes": "desinquietar",
    "desinquieto": "desinquietar",
    "desinquietos": "desinquieto",
    "desinquietou": "desinquietar",
    "desinquietá": "desinquietar",
    "desinquietámo": "desinquietar",
    "desinquietámos": "desinquietar",
    "desinquietáramo": "desinquietar",
    "desinquietáramos": "desinquietar",
    "desinquietárei": "desinquietar",
    "desinquietáreis": "desinquietar",
    "desinquietásseis": "desinquietar",
    "desinquietássemos": "desinquietar",
    "desinquietávamo": "desinquietar",
    "desinquietávamos": "desinquietar",
    "desinquietávei": "desinquietar",
    "desinquietáveis": "desinquietar",
    "desinserida": "desinserido",
    "desinseridas": "desinserido",
    "desinseridos": "desinserido",
    "desinserções": "desinserção",
    "desinsofrida": "desinsofrido",
    "desinsofridas": "desinsofrido",
    "desinsofridos": "desinsofrido",
    "desinstruída": "desinstruído",
    "desinstruídas": "desinstruído",
    "desinstruídos": "desinstruído",
    "desintegra": "desintegrar",
    "desintegrada": "desintegrar",
    "desintegradas": "desintegrar",
    "desintegrado": "desintegrar",
    "desintegradora": "desintegrador",
    "desintegradoras": "desintegrador",
    "desintegradores": "desintegrador",
    "desintegrados": "desintegrar",
    "desintegrai": "desintegrar",
    "desintegrais": "desintegrar",
    "desintegram": "desintegrar",
    "desintegramo": "desintegrar",
    "desintegramos": "desintegrar",
    "desintegrando": "desintegrar",
    "desintegrara": "desintegrar",
    "desintegraram": "desintegrar",
    "desintegraras": "desintegrar",
    "desintegrarde": "desintegrar",
    "desintegrardes": "desintegrar",
    "desintegrare": "desintegrar",
    "desintegrarei": "desintegrar",
    "desintegrareis": "desintegrar",
    "desintegrarem": "desintegrar",
    "desintegraremos": "desintegrar",
    "desintegrares": "desintegrar",
    "desintegraria": "desintegrar",
    "desintegrariam": "desintegrar",
    "desintegrarias": "desintegrar",
    "desintegrarmo": "desintegrar",
    "desintegrarmos": "desintegrar",
    "desintegrará": "desintegrar",
    "desintegrarás": "desintegrar",
    "desintegrarão": "desintegrar",
    "desintegraríamos": "desintegrar",
    "desintegraríeis": "desintegrar",
    "desintegras": "desintegrar",
    "desintegrasse": "desintegrar",
    "desintegrassem": "desintegrar",
    "desintegrasses": "desintegrar",
    "desintegraste": "desintegrar",
    "desintegrastes": "desintegrar",
    "desintegrava": "desintegrar",
    "desintegravam": "desintegrar",
    "desintegravas": "desintegrar",
    "desintegrações": "desintegração",
    "desintegre": "desintegrar",
    "desintegrei": "desintegrar",
    "desintegreis": "desintegrar",
    "desintegrem": "desintegrar",
    "desintegremo": "desintegrar",
    "desintegremos": "desintegrar",
    "desintegres": "desintegrar",
    "desintegro": "desintegrar",
    "desintegrou": "desintegrar",
    "desintegrá": "desintegrar",
    "desintegrámo": "desintegrar",
    "desintegrámos": "desintegrar",
    "desintegráramo": "desintegrar",
    "desintegráramos": "desintegrar",
    "desintegrárei": "desintegrar",
    "desintegráreis": "desintegrar",
    "desintegrásseis": "desintegrar",
    "desintegrássemos": "desintegrar",
    "desintegrávamo": "desintegrar",
    "desintegrávamos": "desintegrar",
    "desintegrávei": "desintegrar",
    "desintegráveis": "desintegrável",
    "desinteirice": "desinteiriçar",
    "desinteiricei": "desinteiriçar",
    "desinteiriceis": "desinteiriçar",
    "desinteiricem": "desinteiriçar",
    "desinteiricemo": "desinteiriçar",
    "desinteiricemos": "desinteiriçar",
    "desinteirices": "desinteiriçar",
    "desinteiriça": "desinteiriçar",
    "desinteiriçada": "desinteiriçar",
    "desinteiriçadas": "desinteiriçar",
    "desinteiriçado": "desinteiriçar",
    "desinteiriçados": "desinteiriçar",
    "desinteiriçai": "desinteiriçar",
    "desinteiriçais": "desinteiriçar",
    "desinteiriçam": "desinteiriçar",
    "desinteiriçamo": "desinteiriçar",
    "desinteiriçamos": "desinteiriçar",
    "desinteiriçando": "desinteiriçar",
    "desinteiriçara": "desinteiriçar",
    "desinteiriçaram": "desinteiriçar",
    "desinteiriçaras": "desinteiriçar",
    "desinteiriçarde": "desinteiriçar",
    "desinteiriçardes": "desinteiriçar",
    "desinteiriçare": "desinteiriçar",
    "desinteiriçarei": "desinteiriçar",
    "desinteiriçareis": "desinteiriçar",
    "desinteiriçarem": "desinteiriçar",
    "desinteiriçaremos": "desinteiriçar",
    "desinteiriçares": "desinteiriçar",
    "desinteiriçaria": "desinteiriçar",
    "desinteiriçariam": "desinteiriçar",
    "desinteiriçarias": "desinteiriçar",
    "desinteiriçarmo": "desinteiriçar",
    "desinteiriçarmos": "desinteiriçar",
    "desinteiriçará": "desinteiriçar",
    "desinteiriçarás": "desinteiriçar",
    "desinteiriçarão": "desinteiriçar",
    "desinteiriçaríamos": "desinteiriçar",
    "desinteiriçaríeis": "desinteiriçar",
    "desinteiriças": "desinteiriçar",
    "desinteiriçasse": "desinteiriçar",
    "desinteiriçassem": "desinteiriçar",
    "desinteiriçasses": "desinteiriçar",
    "desinteiriçaste": "desinteiriçar",
    "desinteiriçastes": "desinteiriçar",
    "desinteiriçava": "desinteiriçar",
    "desinteiriçavam": "desinteiriçar",
    "desinteiriçavas": "desinteiriçar",
    "desinteiriço": "desinteiriçar",
    "desinteiriçou": "desinteiriçar",
    "desinteiriçá": "desinteiriçar",
    "desinteiriçámo": "desinteiriçar",
    "desinteiriçámos": "desinteiriçar",
    "desinteiriçáramo": "desinteiriçar",
    "desinteiriçáramos": "desinteiriçar",
    "desinteiriçárei": "desinteiriçar",
    "desinteiriçáreis": "desinteiriçar",
    "desinteiriçásseis": "desinteiriçar",
    "desinteiriçássemos": "desinteiriçar",
    "desinteiriçávamo": "desinteiriçar",
    "desinteiriçávamos": "desinteiriçar",
    "desinteiriçávei": "desinteiriçar",
    "desinteiriçáveis": "desinteiriçar",
    "desinteligências": "desinteligência",
    "desintencionada": "desintencionado",
    "desintencionadas": "desintencionado",
    "desintencionados": "desintencionado",
    "desintencionais": "desintencional",
    "desinteressa": "desinteressar",
    "desinteressada": "desinteressar",
    "desinteressadas": "desinteressar",
    "desinteressado": "desinteressar",
    "desinteressados": "desinteressar",
    "desinteressai": "desinteressar",
    "desinteressais": "desinteressar",
    "desinteressam": "desinteressar",
    "desinteressamo": "desinteressar",
    "desinteressamos": "desinteressar",
    "desinteressando": "desinteressar",
    "desinteressantes": "desinteressante",
    "desinteressara": "desinteressar",
    "desinteressaram": "desinteressar",
    "desinteressaras": "desinteressar",
    "desinteressarde": "desinteressar",
    "desinteressardes": "desinteressar",
    "desinteressare": "desinteressar",
    "desinteressarei": "desinteressar",
    "desinteressareis": "desinteressar",
    "desinteressarem": "desinteressar",
    "desinteressaremos": "desinteressar",
    "desinteressares": "desinteressar",
    "desinteressaria": "desinteressar",
    "desinteressariam": "desinteressar",
    "desinteressarias": "desinteressar",
    "desinteressarmo": "desinteressar",
    "desinteressarmos": "desinteressar",
    "desinteressará": "desinteressar",
    "desinteressarás": "desinteressar",
    "desinteressarão": "desinteressar",
    "desinteressaríamos": "desinteressar",
    "desinteressaríeis": "desinteressar",
    "desinteressas": "desinteressar",
    "desinteressasse": "desinteressar",
    "desinteressassem": "desinteressar",
    "desinteressasses": "desinteressar",
    "desinteressaste": "desinteressar",
    "desinteressastes": "desinteressar",
    "desinteressava": "desinteressar",
    "desinteressavam": "desinteressar",
    "desinteressavas": "desinteressar",
    "desinteresse": "desinteressar",
    "desinteressei": "desinteressar",
    "desinteresseira": "desinteresseiro",
    "desinteresseiras": "desinteresseiro",
    "desinteresseiros": "desinteresseiro",
    "desinteresseis": "desinteressar",
    "desinteressem": "desinteressar",
    "desinteressemo": "desinteressar",
    "desinteressemos": "desinteressar",
    "desinteresses": "desinteresse",
    "desinteresso": "desinteressar",
    "desinteressou": "desinteressar",
    "desinteressá": "desinteressar",
    "desinteressámo": "desinteressar",
    "desinteressámos": "desinteressar",
    "desinteressáramo": "desinteressar",
    "desinteressáramos": "desinteressar",
    "desinteressárei": "desinteressar",
    "desinteressáreis": "desinteressar",
    "desinteressásseis": "desinteressar",
    "desinteressássemos": "desinteressar",
    "desinteressávamo": "desinteressar",
    "desinteressávamos": "desinteressar",
    "desinteressávei": "desinteressar",
    "desinteressáveis": "desinteressar",
    "desinterna": "desinternar",
    "desinternada": "desinternar",
    "desinternadas": "desinternar",
    "desinternado": "desinternar",
    "desinternados": "desinternar",
    "desinternai": "desinternar",
    "desinternais": "desinternar",
    "desinternam": "desinternar",
    "desinternamo": "desinternar",
    "desinternamos": "desinternar",
    "desinternando": "desinternar",
    "desinternara": "desinternar",
    "desinternaram": "desinternar",
    "desinternaras": "desinternar",
    "desinternarde": "desinternar",
    "desinternardes": "desinternar",
    "desinternare": "desinternar",
    "desinternarei": "desinternar",
    "desinternareis": "desinternar",
    "desinternarem": "desinternar",
    "desinternaremos": "desinternar",
    "desinternares": "desinternar",
    "desinternaria": "desinternar",
    "desinternariam": "desinternar",
    "desinternarias": "desinternar",
    "desinternarmo": "desinternar",
    "desinternarmos": "desinternar",
    "desinternará": "desinternar",
    "desinternarás": "desinternar",
    "desinternarão": "desinternar",
    "desinternaríamos": "desinternar",
    "desinternaríeis": "desinternar",
    "desinternas": "desinternar",
    "desinternasse": "desinternar",
    "desinternassem": "desinternar",
    "desinternasses": "desinternar",
    "desinternaste": "desinternar",
    "desinternastes": "desinternar",
    "desinternava": "desinternar",
    "desinternavam": "desinternar",
    "desinternavas": "desinternar",
    "desinterne": "desinternar",
    "desinternei": "desinternar",
    "desinterneis": "desinternar",
    "desinternem": "desinternar",
    "desinternemo": "desinternar",
    "desinternemos": "desinternar",
    "desinternes": "desinternar",
    "desinterno": "desinternar",
    "desinternou": "desinternar",
    "desinterná": "desinternar",
    "desinternámo": "desinternar",
    "desinternámos": "desinternar",
    "desinternáramo": "desinternar",
    "desinternáramos": "desinternar",
    "desinternárei": "desinternar",
    "desinternáreis": "desinternar",
    "desinternásseis": "desinternar",
    "desinternássemos": "desinternar",
    "desinternávamo": "desinternar",
    "desinternávamos": "desinternar",
    "desinternávei": "desinternar",
    "desinternáveis": "desinternar",
    "desintoxica": "desintoxicar",
    "desintoxicada": "desintoxicar",
    "desintoxicadas": "desintoxicar",
    "desintoxicado": "desintoxicar",
    "desintoxicados": "desintoxicar",
    "desintoxicai": "desintoxicar",
    "desintoxicais": "desintoxicar",
    "desintoxicam": "desintoxicar",
    "desintoxicamo": "desintoxicar",
    "desintoxicamos": "desintoxicar",
    "desintoxicando": "desintoxicar",
    "desintoxicara": "desintoxicar",
    "desintoxicaram": "desintoxicar",
    "desintoxicaras": "desintoxicar",
    "desintoxicarde": "desintoxicar",
    "desintoxicardes": "desintoxicar",
    "desintoxicare": "desintoxicar",
    "desintoxicarei": "desintoxicar",
    "desintoxicareis": "desintoxicar",
    "desintoxicarem": "desintoxicar",
    "desintoxicaremos": "desintoxicar",
    "desintoxicares": "desintoxicar",
    "desintoxicaria": "desintoxicar",
    "desintoxicariam": "desintoxicar",
    "desintoxicarias": "desintoxicar",
    "desintoxicarmo": "desintoxicar",
    "desintoxicarmos": "desintoxicar",
    "desintoxicará": "desintoxicar",
    "desintoxicarás": "desintoxicar",
    "desintoxicarão": "desintoxicar",
    "desintoxicaríamos": "desintoxicar",
    "desintoxicaríeis": "desintoxicar",
    "desintoxicas": "desintoxicar",
    "desintoxicasse": "desintoxicar",
    "desintoxicassem": "desintoxicar",
    "desintoxicasses": "desintoxicar",
    "desintoxicaste": "desintoxicar",
    "desintoxicastes": "desintoxicar",
    "desintoxicava": "desintoxicar",
    "desintoxicavam": "desintoxicar",
    "desintoxicavas": "desintoxicar",
    "desintoxicações": "desintoxicação",
    "desintoxico": "desintoxicar",
    "desintoxicou": "desintoxicar",
    "desintoxicá": "desintoxicar",
    "desintoxicámo": "desintoxicar",
    "desintoxicámos": "desintoxicar",
    "desintoxicáramo": "desintoxicar",
    "desintoxicáramos": "desintoxicar",
    "desintoxicárei": "desintoxicar",
    "desintoxicáreis": "desintoxicar",
    "desintoxicásseis": "desintoxicar",
    "desintoxicássemos": "desintoxicar",
    "desintoxicávamo": "desintoxicar",
    "desintoxicávamos": "desintoxicar",
    "desintoxicávei": "desintoxicar",
    "desintoxicáveis": "desintoxicar",
    "desintoxique": "desintoxicar",
    "desintoxiquei": "desintoxicar",
    "desintoxiqueis": "desintoxicar",
    "desintoxiquem": "desintoxicar",
    "desintoxiquemo": "desintoxicar",
    "desintoxiquemos": "desintoxicar",
    "desintoxiques": "desintoxicar",
    "desintrinca": "desintrincar",
    "desintrincada": "desintrincar",
    "desintrincadas": "desintrincar",
    "desintrincado": "desintrincar",
    "desintrincados": "desintrincar",
    "desintrincai": "desintrincar",
    "desintrincais": "desintrincar",
    "desintrincam": "desintrincar",
    "desintrincamo": "desintrincar",
    "desintrincamos": "desintrincar",
    "desintrincando": "desintrincar",
    "desintrincara": "desintrincar",
    "desintrincaram": "desintrincar",
    "desintrincaras": "desintrincar",
    "desintrincarde": "desintrincar",
    "desintrincardes": "desintrincar",
    "desintrincare": "desintrincar",
    "desintrincarei": "desintrincar",
    "desintrincareis": "desintrincar",
    "desintrincarem": "desintrincar",
    "desintrincaremos": "desintrincar",
    "desintrincares": "desintrincar",
    "desintrincaria": "desintrincar",
    "desintrincariam": "desintrincar",
    "desintrincarias": "desintrincar",
    "desintrincarmo": "desintrincar",
    "desintrincarmos": "desintrincar",
    "desintrincará": "desintrincar",
    "desintrincarás": "desintrincar",
    "desintrincarão": "desintrincar",
    "desintrincaríamos": "desintrincar",
    "desintrincaríeis": "desintrincar",
    "desintrincas": "desintrincar",
    "desintrincasse": "desintrincar",
    "desintrincassem": "desintrincar",
    "desintrincasses": "desintrincar",
    "desintrincaste": "desintrincar",
    "desintrincastes": "desintrincar",
    "desintrincava": "desintrincar",
    "desintrincavam": "desintrincar",
    "desintrincavas": "desintrincar",
    "desintrinco": "desintrincar",
    "desintrincou": "desintrincar",
    "desintrincá": "desintrincar",
    "desintrincámo": "desintrincar",
    "desintrincámos": "desintrincar",
    "desintrincáramo": "desintrincar",
    "desintrincáramos": "desintrincar",
    "desintrincárei": "desintrincar",
    "desintrincáreis": "desintrincar",
    "desintrincásseis": "desintrincar",
    "desintrincássemos": "desintrincar",
    "desintrincávamo": "desintrincar",
    "desintrincávamos": "desintrincar",
    "desintrincávei": "desintrincar",
    "desintrincáveis": "desintrincar",
    "desintrinque": "desintrincar",
    "desintrinquei": "desintrincar",
    "desintrinqueis": "desintrincar",
    "desintrinquem": "desintrincar",
    "desintrinquemo": "desintrincar",
    "desintrinquemos": "desintrincar",
    "desintrinques": "desintrincar",
    "desintumesce": "desintumescer",
    "desintumescei": "desintumescer",
    "desintumesceis": "desintumescer",
    "desintumescem": "desintumescer",
    "desintumescemo": "desintumescer",
    "desintumescemos": "desintumescer",
    "desintumescendo": "desintumescer",
    "desintumescera": "desintumescer",
    "desintumesceram": "desintumescer",
    "desintumesceras": "desintumescer",
    "desintumescerdes": "desintumescer",
    "desintumescerei": "desintumescer",
    "desintumescereis": "desintumescer",
    "desintumescerem": "desintumescer",
    "desintumesceremos": "desintumescer",
    "desintumesceres": "desintumescer",
    "desintumesceria": "desintumescer",
    "desintumesceriam": "desintumescer",
    "desintumescerias": "desintumescer",
    "desintumescermo": "desintumescer",
    "desintumescermos": "desintumescer",
    "desintumescerá": "desintumescer",
    "desintumescerás": "desintumescer",
    "desintumescerão": "desintumescer",
    "desintumesceríamos": "desintumescer",
    "desintumesceríeis": "desintumescer",
    "desintumesces": "desintumescer",
    "desintumescesse": "desintumescer",
    "desintumescessem": "desintumescer",
    "desintumescesses": "desintumescer",
    "desintumesceste": "desintumescer",
    "desintumescestes": "desintumescer",
    "desintumesceu": "desintumescer",
    "desintumesci": "desintumescer",
    "desintumescia": "desintumescer",
    "desintumesciam": "desintumescer",
    "desintumescias": "desintumescer",
    "desintumescida": "desintumescido",
    "desintumescidas": "desintumescido",
    "desintumescido": "desintumescer",
    "desintumescidos": "desintumescido",
    "desintumescêramo": "desintumescer",
    "desintumescêramos": "desintumescer",
    "desintumescêreis": "desintumescer",
    "desintumescêsseis": "desintumescer",
    "desintumescêssemos": "desintumescer",
    "desintumescíamo": "desintumescer",
    "desintumescíamos": "desintumescer",
    "desintumescíeis": "desintumescer",
    "desintumesça": "desintumescer",
    "desintumesçais": "desintumescer",
    "desintumesçam": "desintumescer",
    "desintumesçamo": "desintumescer",
    "desintumesçamos": "desintumescer",
    "desintumesças": "desintumescer",
    "desintumesço": "desintumescer",
    "desinverna": "desinvernar",
    "desinvernada": "desinvernar",
    "desinvernadas": "desinvernar",
    "desinvernado": "desinvernar",
    "desinvernados": "desinvernar",
    "desinvernai": "desinvernar",
    "desinvernais": "desinvernar",
    "desinvernam": "desinvernar",
    "desinvernamo": "desinvernar",
    "desinvernamos": "desinvernar",
    "desinvernando": "desinvernar",
    "desinvernara": "desinvernar",
    "desinvernaram": "desinvernar",
    "desinvernaras": "desinvernar",
    "desinvernarde": "desinvernar",
    "desinvernardes": "desinvernar",
    "desinvernare": "desinvernar",
    "desinvernarei": "desinvernar",
    "desinvernareis": "desinvernar",
    "desinvernarem": "desinvernar",
    "desinvernaremos": "desinvernar",
    "desinvernares": "desinvernar",
    "desinvernaria": "desinvernar",
    "desinvernariam": "desinvernar",
    "desinvernarias": "desinvernar",
    "desinvernarmo": "desinvernar",
    "desinvernarmos": "desinvernar",
    "desinvernará": "desinvernar",
    "desinvernarás": "desinvernar",
    "desinvernarão": "desinvernar",
    "desinvernaríamos": "desinvernar",
    "desinvernaríeis": "desinvernar",
    "desinvernas": "desinvernar",
    "desinvernasse": "desinvernar",
    "desinvernassem": "desinvernar",
    "desinvernasses": "desinvernar",
    "desinvernaste": "desinvernar",
    "desinvernastes": "desinvernar",
    "desinvernava": "desinvernar",
    "desinvernavam": "desinvernar",
    "desinvernavas": "desinvernar",
    "desinverne": "desinvernar",
    "desinvernei": "desinvernar",
    "desinverneis": "desinvernar",
    "desinvernem": "desinvernar",
    "desinvernemo": "desinvernar",
    "desinvernemos": "desinvernar",
    "desinvernes": "desinvernar",
    "desinverno": "desinvernar",
    "desinvernou": "desinvernar",
    "desinverná": "desinvernar",
    "desinvernámo": "desinvernar",
    "desinvernámos": "desinvernar",
    "desinvernáramo": "desinvernar",
    "desinvernáramos": "desinvernar",
    "desinvernárei": "desinvernar",
    "desinvernáreis": "desinvernar",
    "desinvernásseis": "desinvernar",
    "desinvernássemos": "desinvernar",
    "desinvernávamo": "desinvernar",
    "desinvernávamos": "desinvernar",
    "desinvernávei": "desinvernar",
    "desinvernáveis": "desinvernar",
    "desinvesta": "desinvestir",
    "desinvestais": "desinvestir",
    "desinvestam": "desinvestir",
    "desinvestamo": "desinvestir",
    "desinvestamos": "desinvestir",
    "desinvestas": "desinvestir",
    "desinveste": "desinvestir",
    "desinvestem": "desinvestir",
    "desinvestes": "desinvestir",
    "desinvesti": "desinvestir",
    "desinvestia": "desinvestir",
    "desinvestiam": "desinvestir",
    "desinvestias": "desinvestir",
    "desinvestida": "desinvestir",
    "desinvestidas": "desinvestir",
    "desinvestido": "desinvestir",
    "desinvestidos": "desinvestir",
    "desinvestimentos": "desinvestimento",
    "desinvestimo": "desinvestir",
    "desinvestimos": "desinvestir",
    "desinvestindo": "desinvestir",
    "desinvestira": "desinvestir",
    "desinvestiram": "desinvestir",
    "desinvestiras": "desinvestir",
    "desinvestirde": "desinvestir",
    "desinvestirdes": "desinvestir",
    "desinvestire": "desinvestir",
    "desinvestirei": "desinvestir",
    "desinvestireis": "desinvestir",
    "desinvestirem": "desinvestir",
    "desinvestiremos": "desinvestir",
    "desinvestires": "desinvestir",
    "desinvestiria": "desinvestir",
    "desinvestiriam": "desinvestir",
    "desinvestirias": "desinvestir",
    "desinvestirmo": "desinvestir",
    "desinvestirmos": "desinvestir",
    "desinvestirá": "desinvestir",
    "desinvestirás": "desinvestir",
    "desinvestirão": "desinvestir",
    "desinvestiríamos": "desinvestir",
    "desinvestiríeis": "desinvestir",
    "desinvestis": "desinvestir",
    "desinvestisse": "desinvestir",
    "desinvestissem": "desinvestir",
    "desinvestisses": "desinvestir",
    "desinvestiste": "desinvestir",
    "desinvestistes": "desinvestir",
    "desinvestiu": "desinvestir",
    "desinvesto": "desinvestir",
    "desinvestíamo": "desinvestir",
    "desinvestíamos": "desinvestir",
    "desinvestíei": "desinvestir",
    "desinvestíeis": "desinvestir",
    "desinvestíramo": "desinvestir",
    "desinvestíramos": "desinvestir",
    "desinvestírei": "desinvestir",
    "desinvestíreis": "desinvestir",
    "desinvestísseis": "desinvestir",
    "desinvestíssemos": "desinvestir",
    "desinça": "desinçar",
    "desinçada": "desinçar",
    "desinçadas": "desinçar",
    "desinçado": "desinçar",
    "desinçados": "desinçar",
    "desinçai": "desinçar",
    "desinçais": "desinçar",
    "desinçam": "desinçar",
    "desinçamo": "desinçar",
    "desinçamos": "desinçar",
    "desinçando": "desinçar",
    "desinçara": "desinçar",
    "desinçaram": "desinçar",
    "desinçaras": "desinçar",
    "desinçarde": "desinçar",
    "desinçardes": "desinçar",
    "desinçare": "desinçar",
    "desinçarei": "desinçar",
    "desinçareis": "desinçar",
    "desinçarem": "desinçar",
    "desinçaremos": "desinçar",
    "desinçares": "desinçar",
    "desinçaria": "desinçar",
    "desinçariam": "desinçar",
    "desinçarias": "desinçar",
    "desinçarmo": "desinçar",
    "desinçarmos": "desinçar",
    "desinçará": "desinçar",
    "desinçarás": "desinçar",
    "desinçarão": "desinçar",
    "desinçaríamos": "desinçar",
    "desinçaríeis": "desinçar",
    "desinças": "desinçar",
    "desinçasse": "desinçar",
    "desinçassem": "desinçar",
    "desinçasses": "desinçar",
    "desinçaste": "desinçar",
    "desinçastes": "desinçar",
    "desinçava": "desinçar",
    "desinçavam": "desinçar",
    "desinçavas": "desinçar",
    "desinço": "desinçar",
    "desinços": "desinço",
    "desinçou": "desinçar",
    "desinçá": "desinçar",
    "desinçámo": "desinçar",
    "desinçámos": "desinçar",
    "desinçáramo": "desinçar",
    "desinçáramos": "desinçar",
    "desinçárei": "desinçar",
    "desinçáreis": "desinçar",
    "desinçásseis": "desinçar",
    "desinçássemos": "desinçar",
    "desinçávamo": "desinçar",
    "desinçávamos": "desinçar",
    "desinçávei": "desinçar",
    "desinçáveis": "desinçar",
    "desinências": "desinência",
    "desipoteca": "desipotecar",
    "desipotecada": "desipotecar",
    "desipotecadas": "desipotecar",
    "desipotecado": "desipotecar",
    "desipotecados": "desipotecar",
    "desipotecai": "desipotecar",
    "desipotecais": "desipotecar",
    "desipotecam": "desipotecar",
    "desipotecamo": "desipotecar",
    "desipotecamos": "desipotecar",
    "desipotecando": "desipotecar",
    "desipotecara": "desipotecar",
    "desipotecaram": "desipotecar",
    "desipotecaras": "desipotecar",
    "desipotecarde": "desipotecar",
    "desipotecardes": "desipotecar",
    "desipotecare": "desipotecar",
    "desipotecarei": "desipotecar",
    "desipotecareis": "desipotecar",
    "desipotecarem": "desipotecar",
    "desipotecaremos": "desipotecar",
    "desipotecares": "desipotecar",
    "desipotecaria": "desipotecar",
    "desipotecariam": "desipotecar",
    "desipotecarias": "desipotecar",
    "desipotecarmo": "desipotecar",
    "desipotecarmos": "desipotecar",
    "desipotecará": "desipotecar",
    "desipotecarás": "desipotecar",
    "desipotecarão": "desipotecar",
    "desipotecaríamos": "desipotecar",
    "desipotecaríeis": "desipotecar",
    "desipotecas": "desipotecar",
    "desipotecasse": "desipotecar",
    "desipotecassem": "desipotecar",
    "desipotecasses": "desipotecar",
    "desipotecaste": "desipotecar",
    "desipotecastes": "desipotecar",
    "desipotecava": "desipotecar",
    "desipotecavam": "desipotecar",
    "desipotecavas": "desipotecar",
    "desipoteco": "desipotecar",
    "desipotecou": "desipotecar",
    "desipotecá": "desipotecar",
    "desipotecámo": "desipotecar",
    "desipotecámos": "desipotecar",
    "desipotecáramo": "desipotecar",
    "desipotecáramos": "desipotecar",
    "desipotecárei": "desipotecar",
    "desipotecáreis": "desipotecar",
    "desipotecásseis": "desipotecar",
    "desipotecássemos": "desipotecar",
    "desipotecávamo": "desipotecar",
    "desipotecávamos": "desipotecar",
    "desipotecávei": "desipotecar",
    "desipotecáveis": "desipotecável",
    "desipoteque": "desipotecar",
    "desipotequei": "desipotecar",
    "desipotequeis": "desipotecar",
    "desipotequem": "desipotecar",
    "desipotequemo": "desipotecar",
    "desipotequemos": "desipotecar",
    "desipoteques": "desipotecar",
    "desirmana": "desirmanar",
    "desirmanada": "desirmanar",
    "desirmanadas": "desirmanar",
    "desirmanado": "desirmanar",
    "desirmanados": "desirmanar",
    "desirmanai": "desirmanar",
    "desirmanais": "desirmanar",
    "desirmanam": "desirmanar",
    "desirmanamo": "desirmanar",
    "desirmanamos": "desirmanar",
    "desirmanando": "desirmanar",
    "desirmanara": "desirmanar",
    "desirmanaram": "desirmanar",
    "desirmanaras": "desirmanar",
    "desirmanarde": "desirmanar",
    "desirmanardes": "desirmanar",
    "desirmanare": "desirmanar",
    "desirmanarei": "desirmanar",
    "desirmanareis": "desirmanar",
    "desirmanarem": "desirmanar",
    "desirmanaremos": "desirmanar",
    "desirmanares": "desirmanar",
    "desirmanaria": "desirmanar",
    "desirmanariam": "desirmanar",
    "desirmanarias": "desirmanar",
    "desirmanarmo": "desirmanar",
    "desirmanarmos": "desirmanar",
    "desirmanará": "desirmanar",
    "desirmanarás": "desirmanar",
    "desirmanarão": "desirmanar",
    "desirmanaríamos": "desirmanar",
    "desirmanaríeis": "desirmanar",
    "desirmanas": "desirmanar",
    "desirmanasse": "desirmanar",
    "desirmanassem": "desirmanar",
    "desirmanasses": "desirmanar",
    "desirmanaste": "desirmanar",
    "desirmanastes": "desirmanar",
    "desirmanava": "desirmanar",
    "desirmanavam": "desirmanar",
    "desirmanavas": "desirmanar",
    "desirmane": "desirmanar",
    "desirmanei": "desirmanar",
    "desirmaneis": "desirmanar",
    "desirmanem": "desirmanar",
    "desirmanemo": "desirmanar",
    "desirmanemos": "desirmanar",
    "desirmanes": "desirmanar",
    "desirmano": "desirmanar",
    "desirmanou": "desirmanar",
    "desirmaná": "desirmanar",
    "desirmanámo": "desirmanar",
    "desirmanámos": "desirmanar",
    "desirmanáramo": "desirmanar",
    "desirmanáramos": "desirmanar",
    "desirmanárei": "desirmanar",
    "desirmanáreis": "desirmanar",
    "desirmanásseis": "desirmanar",
    "desirmanássemos": "desirmanar",
    "desirmanávamo": "desirmanar",
    "desirmanávamos": "desirmanar",
    "desirmanávei": "desirmanar",
    "desirmanáveis": "desirmanar",
    "desirmã": "desirmão",
    "desirmãos": "desirmão",
    "desirmãs": "desirmão",
    "desisca": "desiscar",
    "desiscada": "desiscar",
    "desiscadas": "desiscar",
    "desiscado": "desiscar",
    "desiscados": "desiscar",
    "desiscai": "desiscar",
    "desiscais": "desiscar",
    "desiscam": "desiscar",
    "desiscamo": "desiscar",
    "desiscamos": "desiscar",
    "desiscando": "desiscar",
    "desiscara": "desiscar",
    "desiscaram": "desiscar",
    "desiscaras": "desiscar",
    "desiscarde": "desiscar",
    "desiscardes": "desiscar",
    "desiscare": "desiscar",
    "desiscarei": "desiscar",
    "desiscareis": "desiscar",
    "desiscarem": "desiscar",
    "desiscaremos": "desiscar",
    "desiscares": "desiscar",
    "desiscaria": "desiscar",
    "desiscariam": "desiscar",
    "desiscarias": "desiscar",
    "desiscarmo": "desiscar",
    "desiscarmos": "desiscar",
    "desiscará": "desiscar",
    "desiscarás": "desiscar",
    "desiscarão": "desiscar",
    "desiscaríamos": "desiscar",
    "desiscaríeis": "desiscar",
    "desiscas": "desiscar",
    "desiscasse": "desiscar",
    "desiscassem": "desiscar",
    "desiscasses": "desiscar",
    "desiscaste": "desiscar",
    "desiscastes": "desiscar",
    "desiscava": "desiscar",
    "desiscavam": "desiscar",
    "desiscavas": "desiscar",
    "desisco": "desiscar",
    "desiscou": "desiscar",
    "desiscá": "desiscar",
    "desiscámo": "desiscar",
    "desiscámos": "desiscar",
    "desiscáramo": "desiscar",
    "desiscáramos": "desiscar",
    "desiscárei": "desiscar",
    "desiscáreis": "desiscar",
    "desiscásseis": "desiscar",
    "desiscássemos": "desiscar",
    "desiscávamo": "desiscar",
    "desiscávamos": "desiscar",
    "desiscávei": "desiscar",
    "desiscáveis": "desiscar",
    "desisque": "desiscar",
    "desisquei": "desiscar",
    "desisqueis": "desiscar",
    "desisquem": "desiscar",
    "desisquemo": "desiscar",
    "desisquemos": "desiscar",
    "desisques": "desiscar",
    "desista": "desistir",
    "desistais": "desistir",
    "desistam": "desistir",
    "desistamo": "desistir",
    "desistamos": "desistir",
    "desistas": "desistir",
    "desiste": "desistir",
    "desistem": "desistir",
    "desistentes": "desistente",
    "desistes": "desistir",
    "desisti": "desistir",
    "desistia": "desistir",
    "desistiam": "desistir",
    "desistias": "desistir",
    "desistida": "desistir",
    "desistidas": "desistir",
    "desistido": "desistir",
    "desistidos": "desistir",
    "desistimo": "desistir",
    "desistimos": "desistir",
    "desistindo": "desistir",
    "desistira": "desistir",
    "desistiram": "desistir",
    "desistiras": "desistir",
    "desistirdes": "desistir",
    "desistirei": "desistir",
    "desistireis": "desistir",
    "desistirem": "desistir",
    "desistiremos": "desistir",
    "desistires": "desistir",
    "desistiria": "desistir",
    "desistiriam": "desistir",
    "desistirias": "desistir",
    "desistirmo": "desistir",
    "desistirmos": "desistir",
    "desistirá": "desistir",
    "desistirás": "desistir",
    "desistirão": "desistir",
    "desistiríamos": "desistir",
    "desistiríeis": "desistir",
    "desistis": "desistir",
    "desistisse": "desistir",
    "desistissem": "desistir",
    "desistisses": "desistir",
    "desististe": "desistir",
    "desististes": "desistir",
    "desistiu": "desistir",
    "desisto": "desistir",
    "desistências": "desistência",
    "desistíamo": "desistir",
    "desistíamos": "desistir",
    "desistíeis": "desistir",
    "desistíramo": "desistir",
    "desistíramos": "desistir",
    "desistíreis": "desistir",
    "desistísseis": "desistir",
    "desistíssemos": "desistir",
    "desitiva": "desitivo",
    "desitivas": "desitivo",
    "desitivos": "desitivo",
    "desjarreta": "desjarretar",
    "desjarretada": "desjarretar",
    "desjarretadas": "desjarretar",
    "desjarretado": "desjarretar",
    "desjarretados": "desjarretar",
    "desjarretai": "desjarretar",
    "desjarretais": "desjarretar",
    "desjarretam": "desjarretar",
    "desjarretamo": "desjarretar",
    "desjarretamos": "desjarretar",
    "desjarretando": "desjarretar",
    "desjarretara": "desjarretar",
    "desjarretaram": "desjarretar",
    "desjarretaras": "desjarretar",
    "desjarretarde": "desjarretar",
    "desjarretardes": "desjarretar",
    "desjarretare": "desjarretar",
    "desjarretarei": "desjarretar",
    "desjarretareis": "desjarretar",
    "desjarretarem": "desjarretar",
    "desjarretaremos": "desjarretar",
    "desjarretares": "desjarretar",
    "desjarretaria": "desjarretar",
    "desjarretariam": "desjarretar",
    "desjarretarias": "desjarretar",
    "desjarretarmo": "desjarretar",
    "desjarretarmos": "desjarretar",
    "desjarretará": "desjarretar",
    "desjarretarás": "desjarretar",
    "desjarretarão": "desjarretar",
    "desjarretaríamos": "desjarretar",
    "desjarretaríeis": "desjarretar",
    "desjarretas": "desjarretar",
    "desjarretasse": "desjarretar",
    "desjarretassem": "desjarretar",
    "desjarretasses": "desjarretar",
    "desjarretaste": "desjarretar",
    "desjarretastes": "desjarretar",
    "desjarretava": "desjarretar",
    "desjarretavam": "desjarretar",
    "desjarretavas": "desjarretar",
    "desjarrete": "desjarretar",
    "desjarretei": "desjarretar",
    "desjarreteis": "desjarretar",
    "desjarretem": "desjarretar",
    "desjarretemo": "desjarretar",
    "desjarretemos": "desjarretar",
    "desjarretes": "desjarretar",
    "desjarreto": "desjarretar",
    "desjarretou": "desjarretar",
    "desjarretá": "desjarretar",
    "desjarretámo": "desjarretar",
    "desjarretámos": "desjarretar",
    "desjarretáramo": "desjarretar",
    "desjarretáramos": "desjarretar",
    "desjarretárei": "desjarretar",
    "desjarretáreis": "desjarretar",
    "desjarretásseis": "desjarretar",
    "desjarretássemos": "desjarretar",
    "desjarretávamo": "desjarretar",
    "desjarretávamos": "desjarretar",
    "desjarretávei": "desjarretar",
    "desjarretáveis": "desjarretar",
    "desjeitos": "desjeito",
    "desjeitosa": "desjeitoso",
    "desjeitosas": "desjeitoso",
    "desjeitosos": "desjeitoso",
    "desjejua": "desjejuar",
    "desjejuada": "desjejuar",
    "desjejuadas": "desjejuar",
    "desjejuado": "desjejuar",
    "desjejuados": "desjejuar",
    "desjejuai": "desjejuar",
    "desjejuais": "desjejuar",
    "desjejuam": "desjejuar",
    "desjejuamo": "desjejuar",
    "desjejuamos": "desjejuar",
    "desjejuando": "desjejuar",
    "desjejuara": "desjejuar",
    "desjejuaram": "desjejuar",
    "desjejuaras": "desjejuar",
    "desjejuardes": "desjejuar",
    "desjejuarei": "desjejuar",
    "desjejuareis": "desjejuar",
    "desjejuarem": "desjejuar",
    "desjejuaremos": "desjejuar",
    "desjejuares": "desjejuar",
    "desjejuaria": "desjejuar",
    "desjejuariam": "desjejuar",
    "desjejuarias": "desjejuar",
    "desjejuarmo": "desjejuar",
    "desjejuarmos": "desjejuar",
    "desjejuará": "desjejuar",
    "desjejuarás": "desjejuar",
    "desjejuarão": "desjejuar",
    "desjejuaríamos": "desjejuar",
    "desjejuaríeis": "desjejuar",
    "desjejuas": "desjejuar",
    "desjejuasse": "desjejuar",
    "desjejuassem": "desjejuar",
    "desjejuasses": "desjejuar",
    "desjejuaste": "desjejuar",
    "desjejuastes": "desjejuar",
    "desjejuava": "desjejuar",
    "desjejuavam": "desjejuar",
    "desjejuavas": "desjejuar",
    "desjejue": "desjejuar",
    "desjejuei": "desjejuar",
    "desjejueis": "desjejuar",
    "desjejuem": "desjejuar",
    "desjejuemo": "desjejuar",
    "desjejuemos": "desjejuar",
    "desjejues": "desjejuar",
    "desjejuns": "desjejum",
    "desjejuo": "desjejuar",
    "desjejuou": "desjejuar",
    "desjejuámo": "desjejuar",
    "desjejuámos": "desjejuar",
    "desjejuáramo": "desjejuar",
    "desjejuáramos": "desjejuar",
    "desjejuáreis": "desjejuar",
    "desjejuásseis": "desjejuar",
    "desjejuássemos": "desjejuar",
    "desjejuávamo": "desjejuar",
    "desjejuávamos": "desjejuar",
    "desjejuáveis": "desjejuar",
    "desjuizada": "desjuizar",
    "desjuizadas": "desjuizar",
    "desjuizado": "desjuizar",
    "desjuizados": "desjuizar",
    "desjuizai": "desjuizar",
    "desjuizais": "desjuizar",
    "desjuizamo": "desjuizar",
    "desjuizamos": "desjuizar",
    "desjuizando": "desjuizar",
    "desjuizara": "desjuizar",
    "desjuizaram": "desjuizar",
    "desjuizaras": "desjuizar",
    "desjuizarde": "desjuizar",
    "desjuizardes": "desjuizar",
    "desjuizare": "desjuizar",
    "desjuizarei": "desjuizar",
    "desjuizareis": "desjuizar",
    "desjuizarem": "desjuizar",
    "desjuizaremos": "desjuizar",
    "desjuizares": "desjuizar",
    "desjuizaria": "desjuizar",
    "desjuizariam": "desjuizar",
    "desjuizarias": "desjuizar",
    "desjuizarmo": "desjuizar",
    "desjuizarmos": "desjuizar",
    "desjuizará": "desjuizar",
    "desjuizarás": "desjuizar",
    "desjuizarão": "desjuizar",
    "desjuizaríamos": "desjuizar",
    "desjuizaríeis": "desjuizar",
    "desjuizasse": "desjuizar",
    "desjuizassem": "desjuizar",
    "desjuizasses": "desjuizar",
    "desjuizaste": "desjuizar",
    "desjuizastes": "desjuizar",
    "desjuizava": "desjuizar",
    "desjuizavam": "desjuizar",
    "desjuizavas": "desjuizar",
    "desjuizei": "desjuizar",
    "desjuizeis": "desjuizar",
    "desjuizemo": "desjuizar",
    "desjuizemos": "desjuizar",
    "desjuizou": "desjuizar",
    "desjuizá": "desjuizar",
    "desjuizámo": "desjuizar",
    "desjuizámos": "desjuizar",
    "desjuizáramo": "desjuizar",
    "desjuizáramos": "desjuizar",
    "desjuizárei": "desjuizar",
    "desjuizáreis": "desjuizar",
    "desjuizásseis": "desjuizar",
    "desjuizássemos": "desjuizar",
    "desjuizávamo": "desjuizar",
    "desjuizávamos": "desjuizar",
    "desjuizávei": "desjuizar",
    "desjuizáveis": "desjuizar",
    "desjunge": "desjungir",
    "desjungem": "desjungir",
    "desjunges": "desjungir",
    "desjungi": "desjungir",
    "desjungia": "desjungir",
    "desjungiam": "desjungir",
    "desjungias": "desjungir",
    "desjungida": "desjungir",
    "desjungidas": "desjungir",
    "desjungido": "desjungir",
    "desjungidos": "desjungir",
    "desjungimo": "desjungir",
    "desjungimos": "desjungir",
    "desjungindo": "desjungir",
    "desjungira": "desjungir",
    "desjungiram": "desjungir",
    "desjungiras": "desjungir",
    "desjungirde": "desjungir",
    "desjungirdes": "desjungir",
    "desjungire": "desjungir",
    "desjungirei": "desjungir",
    "desjungireis": "desjungir",
    "desjungirem": "desjungir",
    "desjungiremos": "desjungir",
    "desjungires": "desjungir",
    "desjungiria": "desjungir",
    "desjungiriam": "desjungir",
    "desjungirias": "desjungir",
    "desjungirmo": "desjungir",
    "desjungirmos": "desjungir",
    "desjungirá": "desjungir",
    "desjungirás": "desjungir",
    "desjungirão": "desjungir",
    "desjungiríamos": "desjungir",
    "desjungiríeis": "desjungir",
    "desjungis": "desjungir",
    "desjungisse": "desjungir",
    "desjungissem": "desjungir",
    "desjungisses": "desjungir",
    "desjungiste": "desjungir",
    "desjungistes": "desjungir",
    "desjungiu": "desjungir",
    "desjungíamo": "desjungir",
    "desjungíamos": "desjungir",
    "desjungíei": "desjungir",
    "desjungíeis": "desjungir",
    "desjungíramo": "desjungir",
    "desjungíramos": "desjungir",
    "desjungírei": "desjungir",
    "desjungíreis": "desjungir",
    "desjungísseis": "desjungir",
    "desjungíssemos": "desjungir",
    "desjunja": "desjungir",
    "desjunjais": "desjungir",
    "desjunjam": "desjungir",
    "desjunjamo": "desjungir",
    "desjunjamos": "desjungir",
    "desjunjas": "desjungir",
    "desjunjo": "desjungir",
    "desjunta": "desjunto",
    "desjuntada": "desjuntar",
    "desjuntadas": "desjuntar",
    "desjuntado": "desjuntar",
    "desjuntados": "desjuntar",
    "desjuntai": "desjuntar",
    "desjuntais": "desjuntar",
    "desjuntam": "desjuntar",
    "desjuntamo": "desjuntar",
    "desjuntamos": "desjuntar",
    "desjuntando": "desjuntar",
    "desjuntara": "desjuntar",
    "desjuntaram": "desjuntar",
    "desjuntaras": "desjuntar",
    "desjuntarde": "desjuntar",
    "desjuntardes": "desjuntar",
    "desjuntare": "desjuntar",
    "desjuntarei": "desjuntar",
    "desjuntareis": "desjuntar",
    "desjuntarem": "desjuntar",
    "desjuntaremos": "desjuntar",
    "desjuntares": "desjuntar",
    "desjuntaria": "desjuntar",
    "desjuntariam": "desjuntar",
    "desjuntarias": "desjuntar",
    "desjuntarmo": "desjuntar",
    "desjuntarmos": "desjuntar",
    "desjuntará": "desjuntar",
    "desjuntarás": "desjuntar",
    "desjuntarão": "desjuntar",
    "desjuntaríamos": "desjuntar",
    "desjuntaríeis": "desjuntar",
    "desjuntas": "desjunto",
    "desjuntasse": "desjuntar",
    "desjuntassem": "desjuntar",
    "desjuntasses": "desjuntar",
    "desjuntaste": "desjuntar",
    "desjuntastes": "desjuntar",
    "desjuntava": "desjuntar",
    "desjuntavam": "desjuntar",
    "desjuntavas": "desjuntar",
    "desjunte": "desjuntar",
    "desjuntei": "desjuntar",
    "desjunteis": "desjuntar",
    "desjuntem": "desjuntar",
    "desjuntemo": "desjuntar",
    "desjuntemos": "desjuntar",
    "desjuntes": "desjuntar",
    "desjunto": "desjuntar",
    "desjuntos": "desjunto",
    "desjuntou": "desjuntar",
    "desjuntá": "desjuntar",
    "desjuntámo": "desjuntar",
    "desjuntámos": "desjuntar",
    "desjuntáramo": "desjuntar",
    "desjuntáramos": "desjuntar",
    "desjuntárei": "desjuntar",
    "desjuntáreis": "desjuntar",
    "desjuntásseis": "desjuntar",
    "desjuntássemos": "desjuntar",
    "desjuntávamo": "desjuntar",
    "desjuntávamos": "desjuntar",
    "desjuntávei": "desjuntar",
    "desjuntáveis": "desjuntar",
    "desjuíza": "desjuizar",
    "desjuízam": "desjuizar",
    "desjuízas": "desjuizar",
    "desjuíze": "desjuizar",
    "desjuízem": "desjuizar",
    "desjuízes": "desjuizar",
    "desjuízo": "desjuizar",
    "deslace": "deslaçar",
    "deslacei": "deslaçar",
    "deslaceis": "deslaçar",
    "deslacem": "deslaçar",
    "deslacemo": "deslaçar",
    "deslacemos": "deslaçar",
    "deslaces": "deslaçar",
    "deslacra": "deslacrar",
    "deslacrada": "deslacrar",
    "deslacradas": "deslacrar",
    "deslacrado": "deslacrar",
    "deslacrados": "deslacrar",
    "deslacrai": "deslacrar",
    "deslacrais": "deslacrar",
    "deslacram": "deslacrar",
    "deslacramo": "deslacrar",
    "deslacramos": "deslacrar",
    "deslacrando": "deslacrar",
    "deslacrara": "deslacrar",
    "deslacraram": "deslacrar",
    "deslacraras": "deslacrar",
    "deslacrarde": "deslacrar",
    "deslacrardes": "deslacrar",
    "deslacrare": "deslacrar",
    "deslacrarei": "deslacrar",
    "deslacrareis": "deslacrar",
    "deslacrarem": "deslacrar",
    "deslacraremos": "deslacrar",
    "deslacrares": "deslacrar",
    "deslacraria": "deslacrar",
    "deslacrariam": "deslacrar",
    "deslacrarias": "deslacrar",
    "deslacrarmo": "deslacrar",
    "deslacrarmos": "deslacrar",
    "deslacrará": "deslacrar",
    "deslacrarás": "deslacrar",
    "deslacrarão": "deslacrar",
    "deslacraríamos": "deslacrar",
    "deslacraríeis": "deslacrar",
    "deslacras": "deslacrar",
    "deslacrasse": "deslacrar",
    "deslacrassem": "deslacrar",
    "deslacrasses": "deslacrar",
    "deslacraste": "deslacrar",
    "deslacrastes": "deslacrar",
    "deslacrava": "deslacrar",
    "deslacravam": "deslacrar",
    "deslacravas": "deslacrar",
    "deslacre": "deslacrar",
    "deslacrei": "deslacrar",
    "deslacreis": "deslacrar",
    "deslacrem": "deslacrar",
    "deslacremo": "deslacrar",
    "deslacremos": "deslacrar",
    "deslacres": "deslacrar",
    "deslacro": "deslacrar",
    "deslacrou": "deslacrar",
    "deslacrá": "deslacrar",
    "deslacrámo": "deslacrar",
    "deslacrámos": "deslacrar",
    "deslacráramo": "deslacrar",
    "deslacráramos": "deslacrar",
    "deslacrárei": "deslacrar",
    "deslacráreis": "deslacrar",
    "deslacrásseis": "deslacrar",
    "deslacrássemos": "deslacrar",
    "deslacrávamo": "deslacrar",
    "deslacrávamos": "deslacrar",
    "deslacrávei": "deslacrar",
    "deslacráveis": "deslacrar",
    "deslados": "deslado",
    "desladrilha": "desladrilhar",
    "desladrilhada": "desladrilhar",
    "desladrilhadas": "desladrilhar",
    "desladrilhado": "desladrilhar",
    "desladrilhados": "desladrilhar",
    "desladrilhai": "desladrilhar",
    "desladrilhais": "desladrilhar",
    "desladrilham": "desladrilhar",
    "desladrilhamo": "desladrilhar",
    "desladrilhamos": "desladrilhar",
    "desladrilhando": "desladrilhar",
    "desladrilhara": "desladrilhar",
    "desladrilharam": "desladrilhar",
    "desladrilharas": "desladrilhar",
    "desladrilharde": "desladrilhar",
    "desladrilhardes": "desladrilhar",
    "desladrilhare": "desladrilhar",
    "desladrilharei": "desladrilhar",
    "desladrilhareis": "desladrilhar",
    "desladrilharem": "desladrilhar",
    "desladrilharemos": "desladrilhar",
    "desladrilhares": "desladrilhar",
    "desladrilharia": "desladrilhar",
    "desladrilhariam": "desladrilhar",
    "desladrilharias": "desladrilhar",
    "desladrilharmo": "desladrilhar",
    "desladrilharmos": "desladrilhar",
    "desladrilhará": "desladrilhar",
    "desladrilharás": "desladrilhar",
    "desladrilharão": "desladrilhar",
    "desladrilharíamos": "desladrilhar",
    "desladrilharíeis": "desladrilhar",
    "desladrilhas": "desladrilhar",
    "desladrilhasse": "desladrilhar",
    "desladrilhassem": "desladrilhar",
    "desladrilhasses": "desladrilhar",
    "desladrilhaste": "desladrilhar",
    "desladrilhastes": "desladrilhar",
    "desladrilhava": "desladrilhar",
    "desladrilhavam": "desladrilhar",
    "desladrilhavas": "desladrilhar",
    "desladrilhe": "desladrilhar",
    "desladrilhei": "desladrilhar",
    "desladrilheis": "desladrilhar",
    "desladrilhem": "desladrilhar",
    "desladrilhemo": "desladrilhar",
    "desladrilhemos": "desladrilhar",
    "desladrilhes": "desladrilhar",
    "desladrilho": "desladrilhar",
    "desladrilhos": "desladrilho",
    "desladrilhou": "desladrilhar",
    "desladrilhá": "desladrilhar",
    "desladrilhámo": "desladrilhar",
    "desladrilhámos": "desladrilhar",
    "desladrilháramo": "desladrilhar",
    "desladrilháramos": "desladrilhar",
    "desladrilhárei": "desladrilhar",
    "desladrilháreis": "desladrilhar",
    "desladrilhásseis": "desladrilhar",
    "desladrilhássemos": "desladrilhar",
    "desladrilhávamo": "desladrilhar",
    "desladrilhávamos": "desladrilhar",
    "desladrilhávei": "desladrilhar",
    "desladrilháveis": "desladrilhar",
    "deslajeada": "deslajear",
    "deslajeadas": "deslajear",
    "deslajeado": "deslajear",
    "deslajeados": "deslajear",
    "deslajeai": "deslajear",
    "deslajeais": "deslajear",
    "deslajeamentos": "deslajeamento",
    "deslajeamo": "deslajear",
    "deslajeamos": "deslajear",
    "deslajeando": "deslajear",
    "deslajeara": "deslajear",
    "deslajearam": "deslajear",
    "deslajearas": "deslajear",
    "deslajearde": "deslajear",
    "deslajeardes": "deslajear",
    "deslajeare": "deslajear",
    "deslajearei": "deslajear",
    "deslajeareis": "deslajear",
    "deslajearem": "deslajear",
    "deslajearemos": "deslajear",
    "deslajeares": "deslajear",
    "deslajearia": "deslajear",
    "deslajeariam": "deslajear",
    "deslajearias": "deslajear",
    "deslajearmo": "deslajear",
    "deslajearmos": "deslajear",
    "deslajeará": "deslajear",
    "deslajearás": "deslajear",
    "deslajearão": "deslajear",
    "deslajearíamos": "deslajear",
    "deslajearíeis": "deslajear",
    "deslajeasse": "deslajear",
    "deslajeassem": "deslajear",
    "deslajeasses": "deslajear",
    "deslajeaste": "deslajear",
    "deslajeastes": "deslajear",
    "deslajeava": "deslajear",
    "deslajeavam": "deslajear",
    "deslajeavas": "deslajear",
    "deslajeei": "deslajear",
    "deslajeeis": "deslajear",
    "deslajeemo": "deslajear",
    "deslajeemos": "deslajear",
    "deslajeia": "deslajear",
    "deslajeiam": "deslajear",
    "deslajeias": "deslajear",
    "deslajeie": "deslajear",
    "deslajeiem": "deslajear",
    "deslajeies": "deslajear",
    "deslajeio": "deslajear",
    "deslajeou": "deslajear",
    "deslajeá": "deslajear",
    "deslajeámo": "deslajear",
    "deslajeámos": "deslajear",
    "deslajeáramo": "deslajear",
    "deslajeáramos": "deslajear",
    "deslajeárei": "deslajear",
    "deslajeáreis": "deslajear",
    "deslajeásseis": "deslajear",
    "deslajeássemos": "deslajear",
    "deslajeávamo": "deslajear",
    "deslajeávamos": "deslajear",
    "deslajeávei": "deslajear",
    "deslajeáveis": "deslajear",
    "deslana": "deslanar",
    "deslanada": "deslanar",
    "deslanadas": "deslanar",
    "deslanado": "deslanar",
    "deslanados": "deslanar",
    "deslanai": "deslanar",
    "deslanais": "deslanar",
    "deslanam": "deslanar",
    "deslanamo": "deslanar",
    "deslanamos": "deslanar",
    "deslanando": "deslanar",
    "deslanara": "deslanar",
    "deslanaram": "deslanar",
    "deslanaras": "deslanar",
    "deslanarde": "deslanar",
    "deslanardes": "deslanar",
    "deslanare": "deslanar",
    "deslanarei": "deslanar",
    "deslanareis": "deslanar",
    "deslanarem": "deslanar",
    "deslanaremos": "deslanar",
    "deslanares": "deslanar",
    "deslanaria": "deslanar",
    "deslanariam": "deslanar",
    "deslanarias": "deslanar",
    "deslanarmo": "deslanar",
    "deslanarmos": "deslanar",
    "deslanará": "deslanar",
    "deslanarás": "deslanar",
    "deslanarão": "deslanar",
    "deslanaríamos": "deslanar",
    "deslanaríeis": "deslanar",
    "deslanas": "deslanar",
    "deslanasse": "deslanar",
    "deslanassem": "deslanar",
    "deslanasses": "deslanar",
    "deslanaste": "deslanar",
    "deslanastes": "deslanar",
    "deslanava": "deslanar",
    "deslanavam": "deslanar",
    "deslanavas": "deslanar",
    "deslane": "deslanar",
    "deslanei": "deslanar",
    "deslaneis": "deslanar",
    "deslanem": "deslanar",
    "deslanemo": "deslanar",
    "deslanemos": "deslanar",
    "deslanes": "deslanar",
    "deslano": "deslanar",
    "deslanou": "deslanar",
    "deslaná": "deslanar",
    "deslanámo": "deslanar",
    "deslanámos": "deslanar",
    "deslanáramo": "deslanar",
    "deslanáramos": "deslanar",
    "deslanárei": "deslanar",
    "deslanáreis": "deslanar",
    "deslanásseis": "deslanar",
    "deslanássemos": "deslanar",
    "deslanávamo": "deslanar",
    "deslanávamos": "deslanar",
    "deslanávei": "deslanar",
    "deslanáveis": "deslanar",
    "deslapa": "deslapar",
    "deslapada": "deslapar",
    "deslapadas": "deslapar",
    "deslapado": "deslapar",
    "deslapados": "deslapar",
    "deslapai": "deslapar",
    "deslapais": "deslapar",
    "deslapam": "deslapar",
    "deslapamo": "deslapar",
    "deslapamos": "deslapar",
    "deslapando": "deslapar",
    "deslapara": "deslapar",
    "deslaparam": "deslapar",
    "deslaparas": "deslapar",
    "deslaparde": "deslapar",
    "deslapardes": "deslapar",
    "deslapare": "deslapar",
    "deslaparei": "deslapar",
    "deslapareis": "deslapar",
    "deslaparem": "deslapar",
    "deslaparemos": "deslapar",
    "deslapares": "deslapar",
    "deslaparia": "deslapar",
    "deslapariam": "deslapar",
    "deslaparias": "deslapar",
    "deslaparmo": "deslapar",
    "deslaparmos": "deslapar",
    "deslapará": "deslapar",
    "deslaparás": "deslapar",
    "deslaparão": "deslapar",
    "deslaparíamos": "deslapar",
    "deslaparíeis": "deslapar",
    "deslapas": "deslapar",
    "deslapasse": "deslapar",
    "deslapassem": "deslapar",
    "deslapasses": "deslapar",
    "deslapaste": "deslapar",
    "deslapastes": "deslapar",
    "deslapava": "deslapar",
    "deslapavam": "deslapar",
    "deslapavas": "deslapar",
    "deslape": "deslapar",
    "deslapei": "deslapar",
    "deslapeis": "deslapar",
    "deslapem": "deslapar",
    "deslapemo": "deslapar",
    "deslapemos": "deslapar",
    "deslapes": "deslapar",
    "deslapida": "deslapidar",
    "deslapidada": "deslapidar",
    "deslapidadas": "deslapidar",
    "deslapidado": "deslapidar",
    "deslapidados": "deslapidar",
    "deslapidai": "deslapidar",
    "deslapidais": "deslapidar",
    "deslapidam": "deslapidar",
    "deslapidamo": "deslapidar",
    "deslapidamos": "deslapidar",
    "deslapidando": "deslapidar",
    "deslapidara": "deslapidar",
    "deslapidaram": "deslapidar",
    "deslapidaras": "deslapidar",
    "deslapidarde": "deslapidar",
    "deslapidardes": "deslapidar",
    "deslapidare": "deslapidar",
    "deslapidarei": "deslapidar",
    "deslapidareis": "deslapidar",
    "deslapidarem": "deslapidar",
    "deslapidaremos": "deslapidar",
    "deslapidares": "deslapidar",
    "deslapidaria": "deslapidar",
    "deslapidariam": "deslapidar",
    "deslapidarias": "deslapidar",
    "deslapidarmo": "deslapidar",
    "deslapidarmos": "deslapidar",
    "deslapidará": "deslapidar",
    "deslapidarás": "deslapidar",
    "deslapidarão": "deslapidar",
    "deslapidaríamos": "deslapidar",
    "deslapidaríeis": "deslapidar",
    "deslapidas": "deslapidar",
    "deslapidasse": "deslapidar",
    "deslapidassem": "deslapidar",
    "deslapidasses": "deslapidar",
    "deslapidaste": "deslapidar",
    "deslapidastes": "deslapidar",
    "deslapidava": "deslapidar",
    "deslapidavam": "deslapidar",
    "deslapidavas": "deslapidar",
    "deslapide": "deslapidar",
    "deslapidei": "deslapidar",
    "deslapideis": "deslapidar",
    "deslapidem": "deslapidar",
    "deslapidemo": "deslapidar",
    "deslapidemos": "deslapidar",
    "deslapides": "deslapidar",
    "deslapido": "deslapidar",
    "deslapidou": "deslapidar",
    "deslapidá": "deslapidar",
    "deslapidámo": "deslapidar",
    "deslapidámos": "deslapidar",
    "deslapidáramo": "deslapidar",
    "deslapidáramos": "deslapidar",
    "deslapidárei": "deslapidar",
    "deslapidáreis": "deslapidar",
    "deslapidásseis": "deslapidar",
    "deslapidássemos": "deslapidar",
    "deslapidávamo": "deslapidar",
    "deslapidávamos": "deslapidar",
    "deslapidávei": "deslapidar",
    "deslapidáveis": "deslapidar",
    "deslapo": "deslapar",
    "deslapou": "deslapar",
    "deslapá": "deslapar",
    "deslapámo": "deslapar",
    "deslapámos": "deslapar",
    "deslapáramo": "deslapar",
    "deslapáramos": "deslapar",
    "deslapárei": "deslapar",
    "deslapáreis": "deslapar",
    "deslapásseis": "deslapar",
    "deslapássemos": "deslapar",
    "deslapávamo": "deslapar",
    "deslapávamos": "deslapar",
    "deslapávei": "deslapar",
    "deslapáveis": "deslapar",
    "deslarada": "deslarado",
    "deslaradas": "deslarado",
    "deslarados": "deslarado",
    "deslassa": "deslassar",
    "deslassada": "deslassar",
    "deslassadas": "deslassar",
    "deslassado": "deslassar",
    "deslassados": "deslassar",
    "deslassai": "deslassar",
    "deslassais": "deslassar",
    "deslassam": "deslassar",
    "deslassamo": "deslassar",
    "deslassamos": "deslassar",
    "deslassando": "deslassar",
    "deslassara": "deslassar",
    "deslassaram": "deslassar",
    "deslassaras": "deslassar",
    "deslassarde": "deslassar",
    "deslassardes": "deslassar",
    "deslassare": "deslassar",
    "deslassarei": "deslassar",
    "deslassareis": "deslassar",
    "deslassarem": "deslassar",
    "deslassaremos": "deslassar",
    "deslassares": "deslassar",
    "deslassaria": "deslassar",
    "deslassariam": "deslassar",
    "deslassarias": "deslassar",
    "deslassarmo": "deslassar",
    "deslassarmos": "deslassar",
    "deslassará": "deslassar",
    "deslassarás": "deslassar",
    "deslassarão": "deslassar",
    "deslassaríamos": "deslassar",
    "deslassaríeis": "deslassar",
    "deslassas": "deslassar",
    "deslassasse": "deslassar",
    "deslassassem": "deslassar",
    "deslassasses": "deslassar",
    "deslassaste": "deslassar",
    "deslassastes": "deslassar",
    "deslassava": "deslassar",
    "deslassavam": "deslassar",
    "deslassavas": "deslassar",
    "deslasse": "deslassar",
    "deslassei": "deslassar",
    "deslasseis": "deslassar",
    "deslassem": "deslassar",
    "deslassemo": "deslassar",
    "deslassemos": "deslassar",
    "deslasses": "deslassar",
    "deslasso": "deslassar",
    "deslassou": "deslassar",
    "deslassá": "deslassar",
    "deslassámo": "deslassar",
    "deslassámos": "deslassar",
    "deslassáramo": "deslassar",
    "deslassáramos": "deslassar",
    "deslassárei": "deslassar",
    "deslassáreis": "deslassar",
    "deslassásseis": "deslassar",
    "deslassássemos": "deslassar",
    "deslassávamo": "deslassar",
    "deslassávamos": "deslassar",
    "deslassávei": "deslassar",
    "deslassáveis": "deslassar",
    "deslastra": "deslastrar",
    "deslastrada": "deslastrar",
    "deslastradas": "deslastrar",
    "deslastrado": "deslastrar",
    "deslastradora": "deslastrador",
    "deslastradoras": "deslastrador",
    "deslastradores": "deslastrador",
    "deslastrados": "deslastrar",
    "deslastrai": "deslastrar",
    "deslastrais": "deslastrar",
    "deslastram": "deslastrar",
    "deslastramo": "deslastrar",
    "deslastramos": "deslastrar",
    "deslastrando": "deslastrar",
    "deslastrara": "deslastrar",
    "deslastraram": "deslastrar",
    "deslastraras": "deslastrar",
    "deslastrarde": "deslastrar",
    "deslastrardes": "deslastrar",
    "deslastrare": "deslastrar",
    "deslastrarei": "deslastrar",
    "deslastrareis": "deslastrar",
    "deslastrarem": "deslastrar",
    "deslastraremos": "deslastrar",
    "deslastrares": "deslastrar",
    "deslastraria": "deslastrar",
    "deslastrariam": "deslastrar",
    "deslastrarias": "deslastrar",
    "deslastrarmo": "deslastrar",
    "deslastrarmos": "deslastrar",
    "deslastrará": "deslastrar",
    "deslastrarás": "deslastrar",
    "deslastrarão": "deslastrar",
    "deslastraríamos": "deslastrar",
    "deslastraríeis": "deslastrar",
    "deslastras": "deslastrar",
    "deslastrasse": "deslastrar",
    "deslastrassem": "deslastrar",
    "deslastrasses": "deslastrar",
    "deslastraste": "deslastrar",
    "deslastrastes": "deslastrar",
    "deslastrava": "deslastrar",
    "deslastravam": "deslastrar",
    "deslastravas": "deslastrar",
    "deslastre": "deslastrar",
    "deslastrei": "deslastrar",
    "deslastreis": "deslastrar",
    "deslastrem": "deslastrar",
    "deslastremo": "deslastrar",
    "deslastremos": "deslastrar",
    "deslastres": "deslastre",
    "deslastro": "deslastrar",
    "deslastros": "deslastro",
    "deslastrou": "deslastrar",
    "deslastrá": "deslastrar",
    "deslastrámo": "deslastrar",
    "deslastrámos": "deslastrar",
    "deslastráramo": "deslastrar",
    "deslastráramos": "deslastrar",
    "deslastrárei": "deslastrar",
    "deslastráreis": "deslastrar",
    "deslastrásseis": "deslastrar",
    "deslastrássemos": "deslastrar",
    "deslastrávamo": "deslastrar",
    "deslastrávamos": "deslastrar",
    "deslastrávei": "deslastrar",
    "deslastráveis": "deslastrar",
    "deslaudativa": "deslaudativo",
    "deslaudativas": "deslaudativo",
    "deslaudativos": "deslaudativo",
    "deslava": "deslavar",
    "deslavada": "deslavar",
    "deslavadas": "deslavar",
    "deslavado": "deslavar",
    "deslavados": "deslavar",
    "deslavai": "deslavar",
    "deslavais": "deslavar",
    "deslavam": "deslavar",
    "deslavamentos": "deslavamento",
    "deslavamo": "deslavar",
    "deslavamos": "deslavar",
    "deslavando": "deslavar",
    "deslavara": "deslavar",
    "deslavaram": "deslavar",
    "deslavaras": "deslavar",
    "deslavarde": "deslavar",
    "deslavardes": "deslavar",
    "deslavare": "deslavar",
    "deslavarei": "deslavar",
    "deslavareis": "deslavar",
    "deslavarem": "deslavar",
    "deslavaremos": "deslavar",
    "deslavares": "deslavar",
    "deslavaria": "deslavar",
    "deslavariam": "deslavar",
    "deslavarias": "deslavar",
    "deslavarmo": "deslavar",
    "deslavarmos": "deslavar",
    "deslavará": "deslavar",
    "deslavarás": "deslavar",
    "deslavarão": "deslavar",
    "deslavaríamos": "deslavar",
    "deslavaríeis": "deslavar",
    "deslavas": "deslavar",
    "deslavasse": "deslavar",
    "deslavassem": "deslavar",
    "deslavasses": "deslavar",
    "deslavaste": "deslavar",
    "deslavastes": "deslavar",
    "deslavava": "deslavar",
    "deslavavam": "deslavar",
    "deslavavas": "deslavar",
    "deslave": "deslavar",
    "deslavei": "deslavar",
    "deslaveis": "deslavar",
    "deslavem": "deslavar",
    "deslavemo": "deslavar",
    "deslavemos": "deslavar",
    "deslaves": "deslavar",
    "deslavo": "deslavar",
    "deslavou": "deslavar",
    "deslavra": "deslavrar",
    "deslavrada": "deslavrar",
    "deslavradas": "deslavrar",
    "deslavrado": "deslavrar",
    "deslavrados": "deslavrar",
    "deslavrai": "deslavrar",
    "deslavrais": "deslavrar",
    "deslavram": "deslavrar",
    "deslavramo": "deslavrar",
    "deslavramos": "deslavrar",
    "deslavrando": "deslavrar",
    "deslavrara": "deslavrar",
    "deslavraram": "deslavrar",
    "deslavraras": "deslavrar",
    "deslavrarde": "deslavrar",
    "deslavrardes": "deslavrar",
    "deslavrare": "deslavrar",
    "deslavrarei": "deslavrar",
    "deslavrareis": "deslavrar",
    "deslavrarem": "deslavrar",
    "deslavraremos": "deslavrar",
    "deslavrares": "deslavrar",
    "deslavraria": "deslavrar",
    "deslavrariam": "deslavrar",
    "deslavrarias": "deslavrar",
    "deslavrarmo": "deslavrar",
    "deslavrarmos": "deslavrar",
    "deslavrará": "deslavrar",
    "deslavrarás": "deslavrar",
    "deslavrarão": "deslavrar",
    "deslavraríamos": "deslavrar",
    "deslavraríeis": "deslavrar",
    "deslavras": "deslavrar",
    "deslavrasse": "deslavrar",
    "deslavrassem": "deslavrar",
    "deslavrasses": "deslavrar",
    "deslavraste": "deslavrar",
    "deslavrastes": "deslavrar",
    "deslavrava": "deslavrar",
    "deslavravam": "deslavrar",
    "deslavravas": "deslavrar",
    "deslavre": "deslavrar",
    "deslavrei": "deslavrar",
    "deslavreis": "deslavrar",
    "deslavrem": "deslavrar",
    "deslavremo": "deslavrar",
    "deslavremos": "deslavrar",
    "deslavres": "deslavrar",
    "deslavro": "deslavrar",
    "deslavrou": "deslavrar",
    "deslavrá": "deslavrar",
    "deslavrámo": "deslavrar",
    "deslavrámos": "deslavrar",
    "deslavráramo": "deslavrar",
    "deslavráramos": "deslavrar",
    "deslavrárei": "deslavrar",
    "deslavráreis": "deslavrar",
    "deslavrásseis": "deslavrar",
    "deslavrássemos": "deslavrar",
    "deslavrávamo": "deslavrar",
    "deslavrávamos": "deslavrar",
    "deslavrávei": "deslavrar",
    "deslavráveis": "deslavrar",
    "deslavá": "deslavar",
    "deslavámo": "deslavar",
    "deslavámos": "deslavar",
    "deslaváramo": "deslavar",
    "deslaváramos": "deslavar",
    "deslavárei": "deslavar",
    "deslaváreis": "deslavar",
    "deslavásseis": "deslavar",
    "deslavássemos": "deslavar",
    "deslavávamo": "deslavar",
    "deslavávamos": "deslavar",
    "deslavávei": "deslavar",
    "deslaváveis": "deslavar",
    "deslaça": "deslaçar",
    "deslaçada": "deslaçar",
    "deslaçadas": "deslaçar",
    "deslaçado": "deslaçar",
    "deslaçados": "deslaçar",
    "deslaçai": "deslaçar",
    "deslaçais": "deslaçar",
    "deslaçam": "deslaçar",
    "deslaçamentos": "deslaçamento",
    "deslaçamo": "deslaçar",
    "deslaçamos": "deslaçar",
    "deslaçando": "deslaçar",
    "deslaçara": "deslaçar",
    "deslaçaram": "deslaçar",
    "deslaçaras": "deslaçar",
    "deslaçarde": "deslaçar",
    "deslaçardes": "deslaçar",
    "deslaçare": "deslaçar",
    "deslaçarei": "deslaçar",
    "deslaçareis": "deslaçar",
    "deslaçarem": "deslaçar",
    "deslaçaremos": "deslaçar",
    "deslaçares": "deslaçar",
    "deslaçaria": "deslaçar",
    "deslaçariam": "deslaçar",
    "deslaçarias": "deslaçar",
    "deslaçarmo": "deslaçar",
    "deslaçarmos": "deslaçar",
    "deslaçará": "deslaçar",
    "deslaçarás": "deslaçar",
    "deslaçarão": "deslaçar",
    "deslaçaríamos": "deslaçar",
    "deslaçaríeis": "deslaçar",
    "deslaças": "deslaçar",
    "deslaçasse": "deslaçar",
    "deslaçassem": "deslaçar",
    "deslaçasses": "deslaçar",
    "deslaçaste": "deslaçar",
    "deslaçastes": "deslaçar",
    "deslaçava": "deslaçar",
    "deslaçavam": "deslaçar",
    "deslaçavas": "deslaçar",
    "deslaço": "deslaçar",
    "deslaçou": "deslaçar",
    "deslaçá": "deslaçar",
    "deslaçámo": "deslaçar",
    "deslaçámos": "deslaçar",
    "deslaçáramo": "deslaçar",
    "deslaçáramos": "deslaçar",
    "deslaçárei": "deslaçar",
    "deslaçáreis": "deslaçar",
    "deslaçásseis": "deslaçar",
    "deslaçássemos": "deslaçar",
    "deslaçávamo": "deslaçar",
    "deslaçávamos": "deslaçar",
    "deslaçávei": "deslaçar",
    "deslaçáveis": "deslaçar",
    "desleais": "desleal",
    "deslealda": "deslealdar",
    "deslealdada": "deslealdar",
    "deslealdadas": "deslealdar",
    "deslealdades": "deslealdade",
    "deslealdado": "deslealdar",
    "deslealdados": "deslealdar",
    "deslealdai": "deslealdar",
    "deslealdais": "deslealdar",
    "deslealdam": "deslealdar",
    "deslealdamo": "deslealdar",
    "deslealdamos": "deslealdar",
    "deslealdando": "deslealdar",
    "deslealdara": "deslealdar",
    "deslealdaram": "deslealdar",
    "deslealdaras": "deslealdar",
    "deslealdarde": "deslealdar",
    "deslealdardes": "deslealdar",
    "deslealdare": "deslealdar",
    "deslealdarei": "deslealdar",
    "deslealdareis": "deslealdar",
    "deslealdarem": "deslealdar",
    "deslealdaremos": "deslealdar",
    "deslealdares": "deslealdar",
    "deslealdaria": "deslealdar",
    "deslealdariam": "deslealdar",
    "deslealdarias": "deslealdar",
    "deslealdarmo": "deslealdar",
    "deslealdarmos": "deslealdar",
    "deslealdará": "deslealdar",
    "deslealdarás": "deslealdar",
    "deslealdarão": "deslealdar",
    "deslealdaríamos": "deslealdar",
    "deslealdaríeis": "deslealdar",
    "deslealdas": "deslealdar",
    "deslealdasse": "deslealdar",
    "deslealdassem": "deslealdar",
    "deslealdasses": "deslealdar",
    "deslealdaste": "deslealdar",
    "deslealdastes": "deslealdar",
    "deslealdava": "deslealdar",
    "deslealdavam": "deslealdar",
    "deslealdavas": "deslealdar",
    "deslealde": "deslealdar",
    "deslealdei": "deslealdar",
    "deslealdeis": "deslealdar",
    "deslealdem": "deslealdar",
    "deslealdemo": "deslealdar",
    "deslealdemos": "deslealdar",
    "deslealdes": "deslealdar",
    "deslealdo": "deslealdar",
    "deslealdou": "deslealdar",
    "deslealdá": "deslealdar",
    "deslealdámo": "deslealdar",
    "deslealdámos": "deslealdar",
    "deslealdáramo": "deslealdar",
    "deslealdáramos": "deslealdar",
    "deslealdárei": "deslealdar",
    "deslealdáreis": "deslealdar",
    "deslealdásseis": "deslealdar",
    "deslealdássemos": "deslealdar",
    "deslealdávamo": "deslealdar",
    "deslealdávamos": "deslealdar",
    "deslealdávei": "deslealdar",
    "deslealdáveis": "deslealdar",
    "deslegitimada": "deslegitimado",
    "deslegitimadas": "deslegitimado",
    "deslegitimados": "deslegitimado",
    "desleita": "desleitar",
    "desleitada": "desleitar",
    "desleitadas": "desleitar",
    "desleitado": "desleitar",
    "desleitados": "desleitar",
    "desleitagens": "desleitagem",
    "desleitai": "desleitar",
    "desleitais": "desleitar",
    "desleitam": "desleitar",
    "desleitamo": "desleitar",
    "desleitamos": "desleitar",
    "desleitando": "desleitar",
    "desleitara": "desleitar",
    "desleitaram": "desleitar",
    "desleitaras": "desleitar",
    "desleitarde": "desleitar",
    "desleitardes": "desleitar",
    "desleitare": "desleitar",
    "desleitarei": "desleitar",
    "desleitareis": "desleitar",
    "desleitarem": "desleitar",
    "desleitaremos": "desleitar",
    "desleitares": "desleitar",
    "desleitaria": "desleitar",
    "desleitariam": "desleitar",
    "desleitarias": "desleitar",
    "desleitarmo": "desleitar",
    "desleitarmos": "desleitar",
    "desleitará": "desleitar",
    "desleitarás": "desleitar",
    "desleitarão": "desleitar",
    "desleitaríamos": "desleitar",
    "desleitaríeis": "desleitar",
    "desleitas": "desleitar",
    "desleitasse": "desleitar",
    "desleitassem": "desleitar",
    "desleitasses": "desleitar",
    "desleitaste": "desleitar",
    "desleitastes": "desleitar",
    "desleitava": "desleitar",
    "desleitavam": "desleitar",
    "desleitavas": "desleitar",
    "desleite": "desleitar",
    "desleitei": "desleitar",
    "desleiteis": "desleitar",
    "desleitem": "desleitar",
    "desleitemo": "desleitar",
    "desleitemos": "desleitar",
    "desleites": "desleitar",
    "desleito": "desleitar",
    "desleitou": "desleitar",
    "desleitá": "desleitar",
    "desleitámo": "desleitar",
    "desleitámos": "desleitar",
    "desleitáramo": "desleitar",
    "desleitáramos": "desleitar",
    "desleitárei": "desleitar",
    "desleitáreis": "desleitar",
    "desleitásseis": "desleitar",
    "desleitássemos": "desleitar",
    "desleitávamo": "desleitar",
    "desleitávamos": "desleitar",
    "desleitávei": "desleitar",
    "desleitáveis": "desleitar",
    "desleixa": "desleixar",
    "desleixada": "desleixar",
    "desleixadas": "desleixar",
    "desleixado": "desleixar",
    "desleixados": "desleixar",
    "desleixadíssima": "desleixado",
    "desleixadíssimas": "desleixado",
    "desleixadíssimo": "desleixado",
    "desleixadíssimos": "desleixado",
    "desleixai": "desleixar",
    "desleixais": "desleixar",
    "desleixam": "desleixar",
    "desleixamentos": "desleixamento",
    "desleixamo": "desleixar",
    "desleixamos": "desleixar",
    "desleixando": "desleixar",
    "desleixara": "desleixar",
    "desleixaram": "desleixar",
    "desleixaras": "desleixar",
    "desleixarde": "desleixar",
    "desleixardes": "desleixar",
    "desleixare": "desleixar",
    "desleixarei": "desleixar",
    "desleixareis": "desleixar",
    "desleixarem": "desleixar",
    "desleixaremos": "desleixar",
    "desleixares": "desleixar",
    "desleixaria": "desleixar",
    "desleixariam": "desleixar",
    "desleixarias": "desleixar",
    "desleixarmo": "desleixar",
    "desleixarmos": "desleixar",
    "desleixará": "desleixar",
    "desleixarás": "desleixar",
    "desleixarão": "desleixar",
    "desleixaríamos": "desleixar",
    "desleixaríeis": "desleixar",
    "desleixas": "desleixar",
    "desleixasse": "desleixar",
    "desleixassem": "desleixar",
    "desleixasses": "desleixar",
    "desleixaste": "desleixar",
    "desleixastes": "desleixar",
    "desleixava": "desleixar",
    "desleixavam": "desleixar",
    "desleixavas": "desleixar",
    "desleixações": "desleixação",
    "desleixe": "desleixar",
    "desleixei": "desleixar",
    "desleixeis": "desleixar",
    "desleixem": "desleixar",
    "desleixemo": "desleixar",
    "desleixemos": "desleixar",
    "desleixes": "desleixar",
    "desleixo": "desleixar",
    "desleixos": "desleixo",
    "desleixou": "desleixar",
    "desleixá": "desleixar",
    "desleixámo": "desleixar",
    "desleixámos": "desleixar",
    "desleixáramo": "desleixar",
    "desleixáramos": "desleixar",
    "desleixárei": "desleixar",
    "desleixáreis": "desleixar",
    "desleixásseis": "desleixar",
    "desleixássemos": "desleixar",
    "desleixávamo": "desleixar",
    "desleixávamos": "desleixar",
    "desleixávei": "desleixar",
    "desleixáveis": "desleixar",
    "deslembra": "deslembrar",
    "deslembrada": "deslembrar",
    "deslembradas": "deslembrar",
    "deslembrado": "deslembrar",
    "deslembrados": "deslembrar",
    "deslembrai": "deslembrar",
    "deslembrais": "deslembrar",
    "deslembram": "deslembrar",
    "deslembramo": "deslembrar",
    "deslembramos": "deslembrar",
    "deslembrando": "deslembrar",
    "deslembranças": "deslembrança",
    "deslembrara": "deslembrar",
    "deslembraram": "deslembrar",
    "deslembraras": "deslembrar",
    "deslembrarde": "deslembrar",
    "deslembrardes": "deslembrar",
    "deslembrare": "deslembrar",
    "deslembrarei": "deslembrar",
    "deslembrareis": "deslembrar",
    "deslembrarem": "deslembrar",
    "deslembraremos": "deslembrar",
    "deslembrares": "deslembrar",
    "deslembraria": "deslembrar",
    "deslembrariam": "deslembrar",
    "deslembrarias": "deslembrar",
    "deslembrarmo": "deslembrar",
    "deslembrarmos": "deslembrar",
    "deslembrará": "deslembrar",
    "deslembrarás": "deslembrar",
    "deslembrarão": "deslembrar",
    "deslembraríamos": "deslembrar",
    "deslembraríeis": "deslembrar",
    "deslembras": "deslembrar",
    "deslembrasse": "deslembrar",
    "deslembrassem": "deslembrar",
    "deslembrasses": "deslembrar",
    "deslembraste": "deslembrar",
    "deslembrastes": "deslembrar",
    "deslembrava": "deslembrar",
    "deslembravam": "deslembrar",
    "deslembravas": "deslembrar",
    "deslembre": "deslembrar",
    "deslembrei": "deslembrar",
    "deslembreis": "deslembrar",
    "deslembrem": "deslembrar",
    "deslembremo": "deslembrar",
    "deslembremos": "deslembrar",
    "deslembres": "deslembrar",
    "deslembro": "deslembrar",
    "deslembrou": "deslembrar",
    "deslembrá": "deslembrar",
    "deslembrámo": "deslembrar",
    "deslembrámos": "deslembrar",
    "deslembráramo": "deslembrar",
    "deslembráramos": "deslembrar",
    "deslembrárei": "deslembrar",
    "deslembráreis": "deslembrar",
    "deslembrásseis": "deslembrar",
    "deslembrássemos": "deslembrar",
    "deslembrávamo": "deslembrar",
    "deslembrávamos": "deslembrar",
    "deslembrávei": "deslembrar",
    "deslembráveis": "deslembrar",
    "deslendeada": "deslendear",
    "deslendeadas": "deslendear",
    "deslendeado": "deslendear",
    "deslendeados": "deslendear",
    "deslendeai": "deslendear",
    "deslendeais": "deslendear",
    "deslendeamo": "deslendear",
    "deslendeamos": "deslendear",
    "deslendeando": "deslendear",
    "deslendeara": "deslendear",
    "deslendearam": "deslendear",
    "deslendearas": "deslendear",
    "deslendearde": "deslendear",
    "deslendeardes": "deslendear",
    "deslendeare": "deslendear",
    "deslendearei": "deslendear",
    "deslendeareis": "deslendear",
    "deslendearem": "deslendear",
    "deslendearemos": "deslendear",
    "deslendeares": "deslendear",
    "deslendearia": "deslendear",
    "deslendeariam": "deslendear",
    "deslendearias": "deslendear",
    "deslendearmo": "deslendear",
    "deslendearmos": "deslendear",
    "deslendeará": "deslendear",
    "deslendearás": "deslendear",
    "deslendearão": "deslendear",
    "deslendearíamos": "deslendear",
    "deslendearíeis": "deslendear",
    "deslendeasse": "deslendear",
    "deslendeassem": "deslendear",
    "deslendeasses": "deslendear",
    "deslendeaste": "deslendear",
    "deslendeastes": "deslendear",
    "deslendeava": "deslendear",
    "deslendeavam": "deslendear",
    "deslendeavas": "deslendear",
    "deslendeei": "deslendear",
    "deslendeeis": "deslendear",
    "deslendeemo": "deslendear",
    "deslendeemos": "deslendear",
    "deslendeia": "deslendear",
    "deslendeiam": "deslendear",
    "deslendeias": "deslendear",
    "deslendeie": "deslendear",
    "deslendeiem": "deslendear",
    "deslendeies": "deslendear",
    "deslendeio": "deslendear",
    "deslendeou": "deslendear",
    "deslendeá": "deslendear",
    "deslendeámo": "deslendear",
    "deslendeámos": "deslendear",
    "deslendeáramo": "deslendear",
    "deslendeáramos": "deslendear",
    "deslendeárei": "deslendear",
    "deslendeáreis": "deslendear",
    "deslendeásseis": "deslendear",
    "deslendeássemos": "deslendear",
    "deslendeávamo": "deslendear",
    "deslendeávamos": "deslendear",
    "deslendeávei": "deslendear",
    "deslendeáveis": "deslendear",
    "deslia": "desliar",
    "desliada": "desliar",
    "desliadas": "desliar",
    "desliado": "desliar",
    "desliados": "desliar",
    "desliai": "desliar",
    "desliais": "desliar",
    "desliam": "desliar",
    "desliamo": "desliar",
    "desliamos": "desliar",
    "desliando": "desliar",
    "desliara": "desliar",
    "desliaram": "desliar",
    "desliaras": "desliar",
    "desliarde": "desliar",
    "desliardes": "desliar",
    "desliare": "desliar",
    "desliarei": "desliar",
    "desliareis": "desliar",
    "desliarem": "desliar",
    "desliaremos": "desliar",
    "desliares": "desliar",
    "desliaria": "desliar",
    "desliariam": "desliar",
    "desliarias": "desliar",
    "desliarmo": "desliar",
    "desliarmos": "desliar",
    "desliará": "desliar",
    "desliarás": "desliar",
    "desliarão": "desliar",
    "desliaríamos": "desliar",
    "desliaríeis": "desliar",
    "deslias": "desliar",
    "desliasse": "desliar",
    "desliassem": "desliar",
    "desliasses": "desliar",
    "desliaste": "desliar",
    "desliastes": "desliar",
    "desliava": "desliar",
    "desliavam": "desliar",
    "desliavas": "desliar",
    "deslie": "desliar",
    "desliei": "desliar",
    "deslieis": "desliar",
    "desliem": "desliar",
    "desliemo": "desliar",
    "desliemos": "desliar",
    "deslies": "desliar",
    "desliga": "desligar",
    "desligada": "desligar",
    "desligadas": "desligar",
    "desligado": "desligar",
    "desligadores": "desligador",
    "desligados": "desligar",
    "desligaduras": "desligadura",
    "desligai": "desligar",
    "desligais": "desligar",
    "desligam": "desligar",
    "desligamentos": "desligamento",
    "desligamo": "desligar",
    "desligamos": "desligar",
    "desligando": "desligar",
    "desligara": "desligar",
    "desligaram": "desligar",
    "desligaras": "desligar",
    "desligarde": "desligar",
    "desligardes": "desligar",
    "desligare": "desligar",
    "desligarei": "desligar",
    "desligareis": "desligar",
    "desligarem": "desligar",
    "desligaremos": "desligar",
    "desligares": "desligar",
    "desligaria": "desligar",
    "desligariam": "desligar",
    "desligarias": "desligar",
    "desligarmo": "desligar",
    "desligarmos": "desligar",
    "desligará": "desligar",
    "desligarás": "desligar",
    "desligarão": "desligar",
    "desligaríamos": "desligar",
    "desligaríeis": "desligar",
    "desligas": "desligar",
    "desligasse": "desligar",
    "desligassem": "desligar",
    "desligasses": "desligar",
    "desligaste": "desligar",
    "desligastes": "desligar",
    "desligava": "desligar",
    "desligavam": "desligar",
    "desligavas": "desligar",
    "desligações": "desligação",
    "desligo": "desligar",
    "desligou": "desligar",
    "desligue": "desligar",
    "desliguei": "desligar",
    "desligueis": "desligar",
    "desliguem": "desligar",
    "desliguemo": "desligar",
    "desliguemos": "desligar",
    "desligues": "desligar",
    "desligá": "desligar",
    "desligámo": "desligar",
    "desligámos": "desligar",
    "desligáramo": "desligar",
    "desligáramos": "desligar",
    "desligárei": "desligar",
    "desligáreis": "desligar",
    "desligásseis": "desligar",
    "desligássemos": "desligar",
    "desligávamo": "desligar",
    "desligávamos": "desligar",
    "desligávei": "desligar",
    "desligáveis": "desligável",
    "deslinda": "deslindar",
    "deslindada": "deslindar",
    "deslindadas": "deslindar",
    "deslindado": "deslindar",
    "deslindadora": "deslindador",
    "deslindadoras": "deslindador",
    "deslindadores": "deslindador",
    "deslindados": "deslindar",
    "deslindai": "deslindar",
    "deslindais": "deslindar",
    "deslindam": "deslindar",
    "deslindamentos": "deslindamento",
    "deslindamo": "deslindar",
    "deslindamos": "deslindar",
    "deslindando": "deslindar",
    "deslindara": "deslindar",
    "deslindaram": "deslindar",
    "deslindaras": "deslindar",
    "deslindarde": "deslindar",
    "deslindardes": "deslindar",
    "deslindare": "deslindar",
    "deslindarei": "deslindar",
    "deslindareis": "deslindar",
    "deslindarem": "deslindar",
    "deslindaremos": "deslindar",
    "deslindares": "deslindar",
    "deslindaria": "deslindar",
    "deslindariam": "deslindar",
    "deslindarias": "deslindar",
    "deslindarmo": "deslindar",
    "deslindarmos": "deslindar",
    "deslindará": "deslindar",
    "deslindarás": "deslindar",
    "deslindarão": "deslindar",
    "deslindaríamos": "deslindar",
    "deslindaríeis": "deslindar",
    "deslindas": "deslindar",
    "deslindasse": "deslindar",
    "deslindassem": "deslindar",
    "deslindasses": "deslindar",
    "deslindaste": "deslindar",
    "deslindastes": "deslindar",
    "deslindava": "deslindar",
    "deslindavam": "deslindar",
    "deslindavas": "deslindar",
    "deslindações": "deslindação",
    "deslinde": "deslindar",
    "deslindei": "deslindar",
    "deslindeis": "deslindar",
    "deslindem": "deslindar",
    "deslindemo": "deslindar",
    "deslindemos": "deslindar",
    "deslindes": "deslinde",
    "deslindo": "deslindar",
    "deslindou": "deslindar",
    "deslindá": "deslindar",
    "deslindámo": "deslindar",
    "deslindámos": "deslindar",
    "deslindáramo": "deslindar",
    "deslindáramos": "deslindar",
    "deslindárei": "deslindar",
    "deslindáreis": "deslindar",
    "deslindásseis": "deslindar",
    "deslindássemos": "deslindar",
    "deslindávamo": "deslindar",
    "deslindávamos": "deslindar",
    "deslindávei": "deslindar",
    "deslindáveis": "deslindar",
    "deslingua": "deslinguar",
    "deslinguada": "deslinguar",
    "deslinguadas": "deslinguar",
    "deslinguado": "deslinguar",
    "deslinguados": "deslinguar",
    "deslinguai": "deslinguar",
    "deslinguais": "deslinguar",
    "deslinguam": "deslinguar",
    "deslinguamentos": "deslinguamento",
    "deslinguamo": "deslinguar",
    "deslinguamos": "deslinguar",
    "deslinguando": "deslinguar",
    "deslinguara": "deslinguar",
    "deslinguaram": "deslinguar",
    "deslinguaras": "deslinguar",
    "deslinguarde": "deslinguar",
    "deslinguardes": "deslinguar",
    "deslinguare": "deslinguar",
    "deslinguarei": "deslinguar",
    "deslinguareis": "deslinguar",
    "deslinguarem": "deslinguar",
    "deslinguaremos": "deslinguar",
    "deslinguares": "deslinguar",
    "deslinguaria": "deslinguar",
    "deslinguariam": "deslinguar",
    "deslinguarias": "deslinguar",
    "deslinguarmo": "deslinguar",
    "deslinguarmos": "deslinguar",
    "deslinguará": "deslinguar",
    "deslinguarás": "deslinguar",
    "deslinguarão": "deslinguar",
    "deslinguaríamos": "deslinguar",
    "deslinguaríeis": "deslinguar",
    "deslinguas": "deslinguar",
    "deslinguasse": "deslinguar",
    "deslinguassem": "deslinguar",
    "deslinguasses": "deslinguar",
    "deslinguaste": "deslinguar",
    "deslinguastes": "deslinguar",
    "deslinguava": "deslinguar",
    "deslinguavam": "deslinguar",
    "deslinguavas": "deslinguar",
    "deslinguei": "deslinguar",
    "deslingueis": "deslinguar",
    "deslinguemo": "deslinguar",
    "deslinguemos": "deslinguar",
    "deslingues": "deslinguar",
    "deslinguo": "deslinguar",
    "deslinguou": "deslinguar",
    "deslinguá": "deslinguar",
    "deslinguámo": "deslinguar",
    "deslinguámos": "deslinguar",
    "deslinguáramo": "deslinguar",
    "deslinguáramos": "deslinguar",
    "deslinguárei": "deslinguar",
    "deslinguáreis": "deslinguar",
    "deslinguásseis": "deslinguar",
    "deslinguássemos": "deslinguar",
    "deslinguávamo": "deslinguar",
    "deslinguávamos": "deslinguar",
    "deslinguávei": "deslinguar",
    "deslinguáveis": "deslinguar",
    "deslingúe": "deslinguar",
    "deslingúem": "deslinguar",
    "deslingúes": "deslinguar",
    "deslio": "desliar",
    "desliou": "desliar",
    "deslisuras": "deslisura",
    "desliza": "deslizar",
    "deslizada": "deslizar",
    "deslizadas": "deslizar",
    "deslizadeiros": "deslizadeiro",
    "deslizado": "deslizar",
    "deslizados": "deslizar",
    "deslizai": "deslizar",
    "deslizais": "deslizar",
    "deslizam": "deslizar",
    "deslizamentos": "deslizamento",
    "deslizamo": "deslizar",
    "deslizamos": "deslizar",
    "deslizando": "deslizar",
    "deslizantes": "deslizante",
    "deslizara": "deslizar",
    "deslizaram": "deslizar",
    "deslizaras": "deslizar",
    "deslizarde": "deslizar",
    "deslizardes": "deslizar",
    "deslizare": "deslizar",
    "deslizarei": "deslizar",
    "deslizareis": "deslizar",
    "deslizarem": "deslizar",
    "deslizaremos": "deslizar",
    "deslizares": "deslizar",
    "deslizaria": "deslizar",
    "deslizariam": "deslizar",
    "deslizarias": "deslizar",
    "deslizarmo": "deslizar",
    "deslizarmos": "deslizar",
    "deslizará": "deslizar",
    "deslizarás": "deslizar",
    "deslizarão": "deslizar",
    "deslizaríamos": "deslizar",
    "deslizaríeis": "deslizar",
    "deslizas": "deslizar",
    "deslizasse": "deslizar",
    "deslizassem": "deslizar",
    "deslizasses": "deslizar",
    "deslizaste": "deslizar",
    "deslizastes": "deslizar",
    "deslizava": "deslizar",
    "deslizavam": "deslizar",
    "deslizavas": "deslizar",
    "deslize": "deslizar",
    "deslizei": "deslizar",
    "deslizeis": "deslizar",
    "deslizem": "deslizar",
    "deslizemo": "deslizar",
    "deslizemos": "deslizar",
    "deslizes": "deslize",
    "deslizo": "deslizar",
    "deslizou": "deslizar",
    "deslizá": "deslizar",
    "deslizámo": "deslizar",
    "deslizámos": "deslizar",
    "deslizáramo": "deslizar",
    "deslizáramos": "deslizar",
    "deslizárei": "deslizar",
    "deslizáreis": "deslizar",
    "deslizásseis": "deslizar",
    "deslizássemos": "deslizar",
    "deslizávamo": "deslizar",
    "deslizávamos": "deslizar",
    "deslizávei": "deslizar",
    "deslizáveis": "deslizar",
    "desliá": "desliar",
    "desliámo": "desliar",
    "desliámos": "desliar",
    "desliáramo": "desliar",
    "desliáramos": "desliar",
    "desliárei": "desliar",
    "desliáreis": "desliar",
    "desliásseis": "desliar",
    "desliássemos": "desliar",
    "desliávamo": "desliar",
    "desliávamos": "desliar",
    "desliávei": "desliar",
    "desliáveis": "desliar",
    "desloca": "deslocar",
    "deslocada": "deslocar",
    "deslocadas": "deslocar",
    "deslocado": "deslocar",
    "deslocadora": "deslocador",
    "deslocadoras": "deslocador",
    "deslocadores": "deslocador",
    "deslocados": "deslocar",
    "deslocai": "deslocar",
    "deslocais": "deslocar",
    "deslocam": "deslocar",
    "deslocamentos": "deslocamento",
    "deslocamo": "deslocar",
    "deslocamos": "deslocar",
    "deslocando": "deslocar",
    "deslocara": "deslocar",
    "deslocaram": "deslocar",
    "deslocaras": "deslocar",
    "deslocarde": "deslocar",
    "deslocardes": "deslocar",
    "deslocare": "deslocar",
    "deslocarei": "deslocar",
    "deslocareis": "deslocar",
    "deslocarem": "deslocar",
    "deslocaremos": "deslocar",
    "deslocares": "deslocar",
    "deslocaria": "deslocar",
    "deslocariam": "deslocar",
    "deslocarias": "deslocar",
    "deslocarmo": "deslocar",
    "deslocarmos": "deslocar",
    "deslocará": "deslocar",
    "deslocarás": "deslocar",
    "deslocarão": "deslocar",
    "deslocaríamos": "deslocar",
    "deslocaríeis": "deslocar",
    "deslocas": "deslocar",
    "deslocasse": "deslocar",
    "deslocassem": "deslocar",
    "deslocasses": "deslocar",
    "deslocaste": "deslocar",
    "deslocastes": "deslocar",
    "deslocava": "deslocar",
    "deslocavam": "deslocar",
    "deslocavas": "deslocar",
    "deslocações": "deslocação",
    "desloco": "deslocar",
    "deslocou": "deslocar",
    "deslocá": "deslocar",
    "deslocámo": "deslocar",
    "deslocámos": "deslocar",
    "deslocáramo": "deslocar",
    "deslocáramos": "deslocar",
    "deslocárei": "deslocar",
    "deslocáreis": "deslocar",
    "deslocásseis": "deslocar",
    "deslocássemos": "deslocar",
    "deslocávamo": "deslocar",
    "deslocávamos": "deslocar",
    "deslocávei": "deslocar",
    "deslocáveis": "deslocável",
    "deslogra": "deslograr",
    "deslograda": "deslograr",
    "deslogradas": "deslograr",
    "deslogrado": "deslograr",
    "deslogrados": "deslograr",
    "deslograi": "deslograr",
    "deslograis": "deslograr",
    "deslogram": "deslograr",
    "deslogramo": "deslograr",
    "deslogramos": "deslograr",
    "deslogrando": "deslograr",
    "deslograra": "deslograr",
    "deslograram": "deslograr",
    "deslograras": "deslograr",
    "deslograrde": "deslograr",
    "deslogrardes": "deslograr",
    "deslograre": "deslograr",
    "deslograrei": "deslograr",
    "deslograreis": "deslograr",
    "deslograrem": "deslograr",
    "deslograremos": "deslograr",
    "deslograres": "deslograr",
    "deslograria": "deslograr",
    "deslograriam": "deslograr",
    "deslograrias": "deslograr",
    "deslograrmo": "deslograr",
    "deslograrmos": "deslograr",
    "deslogrará": "deslograr",
    "deslograrás": "deslograr",
    "deslograrão": "deslograr",
    "deslograríamos": "deslograr",
    "deslograríeis": "deslograr",
    "deslogras": "deslograr",
    "deslograsse": "deslograr",
    "deslograssem": "deslograr",
    "deslograsses": "deslograr",
    "deslograste": "deslograr",
    "deslograstes": "deslograr",
    "deslograva": "deslograr",
    "deslogravam": "deslograr",
    "deslogravas": "deslograr",
    "deslogre": "deslograr",
    "deslogrei": "deslograr",
    "deslogreis": "deslograr",
    "deslogrem": "deslograr",
    "deslogremo": "deslograr",
    "deslogremos": "deslograr",
    "deslogres": "deslograr",
    "deslogro": "deslograr",
    "deslogrou": "deslograr",
    "deslográ": "deslograr",
    "deslográmo": "deslograr",
    "deslográmos": "deslograr",
    "deslográramo": "deslograr",
    "deslográramos": "deslograr",
    "deslográrei": "deslograr",
    "deslográreis": "deslograr",
    "deslográsseis": "deslograr",
    "deslográssemos": "deslograr",
    "deslográvamo": "deslograr",
    "deslográvamos": "deslograr",
    "deslográvei": "deslograr",
    "deslográveis": "deslograr",
    "deslomba": "deslombar",
    "deslombada": "deslombar",
    "deslombadas": "deslombar",
    "deslombado": "deslombar",
    "deslombados": "deslombar",
    "deslombai": "deslombar",
    "deslombais": "deslombar",
    "deslombam": "deslombar",
    "deslombamo": "deslombar",
    "deslombamos": "deslombar",
    "deslombando": "deslombar",
    "deslombara": "deslombar",
    "deslombaram": "deslombar",
    "deslombaras": "deslombar",
    "deslombarde": "deslombar",
    "deslombardes": "deslombar",
    "deslombare": "deslombar",
    "deslombarei": "deslombar",
    "deslombareis": "deslombar",
    "deslombarem": "deslombar",
    "deslombaremos": "deslombar",
    "deslombares": "deslombar",
    "deslombaria": "deslombar",
    "deslombariam": "deslombar",
    "deslombarias": "deslombar",
    "deslombarmo": "deslombar",
    "deslombarmos": "deslombar",
    "deslombará": "deslombar",
    "deslombarás": "deslombar",
    "deslombarão": "deslombar",
    "deslombaríamos": "deslombar",
    "deslombaríeis": "deslombar",
    "deslombas": "deslombar",
    "deslombasse": "deslombar",
    "deslombassem": "deslombar",
    "deslombasses": "deslombar",
    "deslombaste": "deslombar",
    "deslombastes": "deslombar",
    "deslombava": "deslombar",
    "deslombavam": "deslombar",
    "deslombavas": "deslombar",
    "deslombe": "deslombar",
    "deslombei": "deslombar",
    "deslombeis": "deslombar",
    "deslombem": "deslombar",
    "deslombemo": "deslombar",
    "deslombemos": "deslombar",
    "deslombes": "deslombar",
    "deslombo": "deslombar",
    "deslombou": "deslombar",
    "deslombá": "deslombar",
    "deslombámo": "deslombar",
    "deslombámos": "deslombar",
    "deslombáramo": "deslombar",
    "deslombáramos": "deslombar",
    "deslombárei": "deslombar",
    "deslombáreis": "deslombar",
    "deslombásseis": "deslombar",
    "deslombássemos": "deslombar",
    "deslombávamo": "deslombar",
    "deslombávamos": "deslombar",
    "deslombávei": "deslombar",
    "deslombáveis": "deslombar",
    "desloque": "deslocar",
    "desloquei": "deslocar",
    "desloqueis": "deslocar",
    "desloquem": "deslocar",
    "desloquemo": "deslocar",
    "desloquemos": "deslocar",
    "desloques": "deslocar",
    "deslouva": "deslouvar",
    "deslouvada": "deslouvar",
    "deslouvadas": "deslouvar",
    "deslouvado": "deslouvar",
    "deslouvados": "deslouvar",
    "deslouvai": "deslouvar",
    "deslouvais": "deslouvar",
    "deslouvam": "deslouvar",
    "deslouvamo": "deslouvar",
    "deslouvamos": "deslouvar",
    "deslouvando": "deslouvar",
    "deslouvara": "deslouvar",
    "deslouvaram": "deslouvar",
    "deslouvaras": "deslouvar",
    "deslouvarde": "deslouvar",
    "deslouvardes": "deslouvar",
    "deslouvare": "deslouvar",
    "deslouvarei": "deslouvar",
    "deslouvareis": "deslouvar",
    "deslouvarem": "deslouvar",
    "deslouvaremos": "deslouvar",
    "deslouvares": "deslouvar",
    "deslouvaria": "deslouvar",
    "deslouvariam": "deslouvar",
    "deslouvarias": "deslouvar",
    "deslouvarmo": "deslouvar",
    "deslouvarmos": "deslouvar",
    "deslouvará": "deslouvar",
    "deslouvarás": "deslouvar",
    "deslouvarão": "deslouvar",
    "deslouvaríamos": "deslouvar",
    "deslouvaríeis": "deslouvar",
    "deslouvas": "deslouvar",
    "deslouvasse": "deslouvar",
    "deslouvassem": "deslouvar",
    "deslouvasses": "deslouvar",
    "deslouvaste": "deslouvar",
    "deslouvastes": "deslouvar",
    "deslouvava": "deslouvar",
    "deslouvavam": "deslouvar",
    "deslouvavas": "deslouvar",
    "deslouve": "deslouvar",
    "deslouvei": "deslouvar",
    "deslouveis": "deslouvar",
    "deslouvem": "deslouvar",
    "deslouvemo": "deslouvar",
    "deslouvemos": "deslouvar",
    "deslouves": "deslouvar",
    "deslouvo": "deslouvar",
    "deslouvores": "deslouvor",
    "deslouvou": "deslouvar",
    "deslouvá": "deslouvar",
    "deslouvámo": "deslouvar",
    "deslouvámos": "deslouvar",
    "deslouváramo": "deslouvar",
    "deslouváramos": "deslouvar",
    "deslouvárei": "deslouvar",
    "deslouváreis": "deslouvar",
    "deslouvásseis": "deslouvar",
    "deslouvássemos": "deslouvar",
    "deslouvávamo": "deslouvar",
    "deslouvávamos": "deslouvar",
    "deslouvávei": "deslouvar",
    "deslouváveis": "deslouvar",
    "deslumbra": "deslumbrar",
    "deslumbrada": "deslumbrar",
    "deslumbradas": "deslumbrar",
    "deslumbrado": "deslumbrar",
    "deslumbradora": "deslumbrador",
    "deslumbradoras": "deslumbrador",
    "deslumbradores": "deslumbrador",
    "deslumbrados": "deslumbrar",
    "deslumbradíssima": "deslumbrado",
    "deslumbradíssimas": "deslumbrado",
    "deslumbradíssimo": "deslumbrado",
    "deslumbradíssimos": "deslumbrado",
    "deslumbrai": "deslumbrar",
    "deslumbrais": "deslumbrar",
    "deslumbram": "deslumbrar",
    "deslumbramentos": "deslumbramento",
    "deslumbramo": "deslumbrar",
    "deslumbramos": "deslumbrar",
    "deslumbrando": "deslumbrar",
    "deslumbrantes": "deslumbrante",
    "deslumbrara": "deslumbrar",
    "deslumbraram": "deslumbrar",
    "deslumbraras": "deslumbrar",
    "deslumbrarde": "deslumbrar",
    "deslumbrardes": "deslumbrar",
    "deslumbrare": "deslumbrar",
    "deslumbrarei": "deslumbrar",
    "deslumbrareis": "deslumbrar",
    "deslumbrarem": "deslumbrar",
    "deslumbraremos": "deslumbrar",
    "deslumbrares": "deslumbrar",
    "deslumbraria": "deslumbrar",
    "deslumbrariam": "deslumbrar",
    "deslumbrarias": "deslumbrar",
    "deslumbrarmo": "deslumbrar",
    "deslumbrarmos": "deslumbrar",
    "deslumbrará": "deslumbrar",
    "deslumbrarás": "deslumbrar",
    "deslumbrarão": "deslumbrar",
    "deslumbraríamos": "deslumbrar",
    "deslumbraríeis": "deslumbrar",
    "deslumbras": "deslumbrar",
    "deslumbrasse": "deslumbrar",
    "deslumbrassem": "deslumbrar",
    "deslumbrasses": "deslumbrar",
    "deslumbraste": "deslumbrar",
    "deslumbrastes": "deslumbrar",
    "deslumbrativa": "deslumbrativo",
    "deslumbrativas": "deslumbrativo",
    "deslumbrativos": "deslumbrativo",
    "deslumbrava": "deslumbrar",
    "deslumbravam": "deslumbrar",
    "deslumbravas": "deslumbrar",
    "deslumbre": "deslumbrar",
    "deslumbrei": "deslumbrar",
    "deslumbreis": "deslumbrar",
    "deslumbrem": "deslumbrar",
    "deslumbremo": "deslumbrar",
    "deslumbremos": "deslumbrar",
    "deslumbres": "deslumbrar",
    "deslumbro": "deslumbrar",
    "deslumbrosa": "deslumbroso",
    "deslumbrosas": "deslumbroso",
    "deslumbrosos": "deslumbroso",
    "deslumbrou": "deslumbrar",
    "deslumbrá": "deslumbrar",
    "deslumbrámo": "deslumbrar",
    "deslumbrámos": "deslumbrar",
    "deslumbráramo": "deslumbrar",
    "deslumbráramos": "deslumbrar",
    "deslumbrárei": "deslumbrar",
    "deslumbráreis": "deslumbrar",
    "deslumbrásseis": "deslumbrar",
    "deslumbrássemos": "deslumbrar",
    "deslumbrávamo": "deslumbrar",
    "deslumbrávamos": "deslumbrar",
    "deslumbrávei": "deslumbrar",
    "deslumbráveis": "deslumbrável",
    "deslustra": "deslustrar",
    "deslustrada": "deslustrar",
    "deslustradas": "deslustrar",
    "deslustrado": "deslustrar",
    "deslustrados": "deslustrar",
    "deslustrai": "deslustrar",
    "deslustrais": "deslustrar",
    "deslustram": "deslustrar",
    "deslustramo": "deslustrar",
    "deslustramos": "deslustrar",
    "deslustrando": "deslustrar",
    "deslustrara": "deslustrar",
    "deslustraram": "deslustrar",
    "deslustraras": "deslustrar",
    "deslustrarde": "deslustrar",
    "deslustrardes": "deslustrar",
    "deslustrare": "deslustrar",
    "deslustrarei": "deslustrar",
    "deslustrareis": "deslustrar",
    "deslustrarem": "deslustrar",
    "deslustraremos": "deslustrar",
    "deslustrares": "deslustrar",
    "deslustraria": "deslustrar",
    "deslustrariam": "deslustrar",
    "deslustrarias": "deslustrar",
    "deslustrarmo": "deslustrar",
    "deslustrarmos": "deslustrar",
    "deslustrará": "deslustrar",
    "deslustrarás": "deslustrar",
    "deslustrarão": "deslustrar",
    "deslustraríamos": "deslustrar",
    "deslustraríeis": "deslustrar",
    "deslustras": "deslustrar",
    "deslustrasse": "deslustrar",
    "deslustrassem": "deslustrar",
    "deslustrasses": "deslustrar",
    "deslustraste": "deslustrar",
    "deslustrastes": "deslustrar",
    "deslustrava": "deslustrar",
    "deslustravam": "deslustrar",
    "deslustravas": "deslustrar",
    "deslustre": "deslustrar",
    "deslustrei": "deslustrar",
    "deslustreis": "deslustrar",
    "deslustrem": "deslustrar",
    "deslustremo": "deslustrar",
    "deslustremos": "deslustrar",
    "deslustres": "deslustre",
    "deslustro": "deslustrar",
    "deslustros": "deslustro",
    "deslustrosa": "deslustroso",
    "deslustrosas": "deslustroso",
    "deslustrosos": "deslustroso",
    "deslustrou": "deslustrar",
    "deslustrá": "deslustrar",
    "deslustrámo": "deslustrar",
    "deslustrámos": "deslustrar",
    "deslustráramo": "deslustrar",
    "deslustráramos": "deslustrar",
    "deslustrárei": "deslustrar",
    "deslustráreis": "deslustrar",
    "deslustrásseis": "deslustrar",
    "deslustrássemos": "deslustrar",
    "deslustrávamo": "deslustrar",
    "deslustrávamos": "deslustrar",
    "deslustrávei": "deslustrar",
    "deslustráveis": "deslustrar",
    "desluz": "desluzir",
    "desluza": "desluzir",
    "desluzais": "desluzir",
    "desluzam": "desluzir",
    "desluzamo": "desluzir",
    "desluzamos": "desluzir",
    "desluzas": "desluzir",
    "desluze": "desluzir",
    "desluzem": "desluzir",
    "desluzes": "desluzir",
    "desluzi": "desluzir",
    "desluzia": "desluzir",
    "desluziam": "desluzir",
    "desluzias": "desluzir",
    "desluzida": "desluzir",
    "desluzidas": "desluzir",
    "desluzido": "desluzir",
    "desluzidora": "desluzidor",
    "desluzidoras": "desluzidor",
    "desluzidores": "desluzidor",
    "desluzidos": "desluzir",
    "desluzimentos": "desluzimento",
    "desluzimo": "desluzir",
    "desluzimos": "desluzir",
    "desluzindo": "desluzir",
    "desluzira": "desluzir",
    "desluziram": "desluzir",
    "desluziras": "desluzir",
    "desluzirde": "desluzir",
    "desluzirdes": "desluzir",
    "desluzire": "desluzir",
    "desluzirei": "desluzir",
    "desluzireis": "desluzir",
    "desluzirem": "desluzir",
    "desluziremos": "desluzir",
    "desluzires": "desluzir",
    "desluziria": "desluzir",
    "desluziriam": "desluzir",
    "desluzirias": "desluzir",
    "desluzirmo": "desluzir",
    "desluzirmos": "desluzir",
    "desluzirá": "desluzir",
    "desluzirás": "desluzir",
    "desluzirão": "desluzir",
    "desluziríamos": "desluzir",
    "desluziríeis": "desluzir",
    "desluzis": "desluzir",
    "desluzisse": "desluzir",
    "desluzissem": "desluzir",
    "desluzisses": "desluzir",
    "desluziste": "desluzir",
    "desluzistes": "desluzir",
    "desluziu": "desluzir",
    "desluzo": "desluzir",
    "desluzíamo": "desluzir",
    "desluzíamos": "desluzir",
    "desluzíei": "desluzir",
    "desluzíeis": "desluzir",
    "desluzíramo": "desluzir",
    "desluzíramos": "desluzir",
    "desluzírei": "desluzir",
    "desluzíreis": "desluzir",
    "desluzísseis": "desluzir",
    "desluzíssemos": "desluzir",
    "desmadeira": "desmadeirar",
    "desmadeirada": "desmadeirar",
    "desmadeiradas": "desmadeirar",
    "desmadeirado": "desmadeirar",
    "desmadeirados": "desmadeirar",
    "desmadeirai": "desmadeirar",
    "desmadeirais": "desmadeirar",
    "desmadeiram": "desmadeirar",
    "desmadeiramo": "desmadeirar",
    "desmadeiramos": "desmadeirar",
    "desmadeirando": "desmadeirar",
    "desmadeirara": "desmadeirar",
    "desmadeiraram": "desmadeirar",
    "desmadeiraras": "desmadeirar",
    "desmadeirarde": "desmadeirar",
    "desmadeirardes": "desmadeirar",
    "desmadeirare": "desmadeirar",
    "desmadeirarei": "desmadeirar",
    "desmadeirareis": "desmadeirar",
    "desmadeirarem": "desmadeirar",
    "desmadeiraremos": "desmadeirar",
    "desmadeirares": "desmadeirar",
    "desmadeiraria": "desmadeirar",
    "desmadeirariam": "desmadeirar",
    "desmadeirarias": "desmadeirar",
    "desmadeirarmo": "desmadeirar",
    "desmadeirarmos": "desmadeirar",
    "desmadeirará": "desmadeirar",
    "desmadeirarás": "desmadeirar",
    "desmadeirarão": "desmadeirar",
    "desmadeiraríamos": "desmadeirar",
    "desmadeiraríeis": "desmadeirar",
    "desmadeiras": "desmadeirar",
    "desmadeirasse": "desmadeirar",
    "desmadeirassem": "desmadeirar",
    "desmadeirasses": "desmadeirar",
    "desmadeiraste": "desmadeirar",
    "desmadeirastes": "desmadeirar",
    "desmadeirava": "desmadeirar",
    "desmadeiravam": "desmadeirar",
    "desmadeiravas": "desmadeirar",
    "desmadeire": "desmadeirar",
    "desmadeirei": "desmadeirar",
    "desmadeireis": "desmadeirar",
    "desmadeirem": "desmadeirar",
    "desmadeiremo": "desmadeirar",
    "desmadeiremos": "desmadeirar",
    "desmadeires": "desmadeirar",
    "desmadeiro": "desmadeirar",
    "desmadeirou": "desmadeirar",
    "desmadeirá": "desmadeirar",
    "desmadeirámo": "desmadeirar",
    "desmadeirámos": "desmadeirar",
    "desmadeiráramo": "desmadeirar",
    "desmadeiráramos": "desmadeirar",
    "desmadeirárei": "desmadeirar",
    "desmadeiráreis": "desmadeirar",
    "desmadeirásseis": "desmadeirar",
    "desmadeirássemos": "desmadeirar",
    "desmadeirávamo": "desmadeirar",
    "desmadeirávamos": "desmadeirar",
    "desmadeirávei": "desmadeirar",
    "desmadeiráveis": "desmadeirar",
    "desmagina": "desmaginar",
    "desmaginada": "desmaginar",
    "desmaginadas": "desmaginar",
    "desmaginado": "desmaginar",
    "desmaginados": "desmaginar",
    "desmaginai": "desmaginar",
    "desmaginais": "desmaginar",
    "desmaginam": "desmaginar",
    "desmaginamo": "desmaginar",
    "desmaginamos": "desmaginar",
    "desmaginando": "desmaginar",
    "desmaginara": "desmaginar",
    "desmaginaram": "desmaginar",
    "desmaginaras": "desmaginar",
    "desmaginarde": "desmaginar",
    "desmaginardes": "desmaginar",
    "desmaginare": "desmaginar",
    "desmaginarei": "desmaginar",
    "desmaginareis": "desmaginar",
    "desmaginarem": "desmaginar",
    "desmaginaremos": "desmaginar",
    "desmaginares": "desmaginar",
    "desmaginaria": "desmaginar",
    "desmaginariam": "desmaginar",
    "desmaginarias": "desmaginar",
    "desmaginarmo": "desmaginar",
    "desmaginarmos": "desmaginar",
    "desmaginará": "desmaginar",
    "desmaginarás": "desmaginar",
    "desmaginarão": "desmaginar",
    "desmaginaríamos": "desmaginar",
    "desmaginaríeis": "desmaginar",
    "desmaginas": "desmaginar",
    "desmaginasse": "desmaginar",
    "desmaginassem": "desmaginar",
    "desmaginasses": "desmaginar",
    "desmaginaste": "desmaginar",
    "desmaginastes": "desmaginar",
    "desmaginava": "desmaginar",
    "desmaginavam": "desmaginar",
    "desmaginavas": "desmaginar",
    "desmagine": "desmaginar",
    "desmaginei": "desmaginar",
    "desmagineis": "desmaginar",
    "desmaginem": "desmaginar",
    "desmaginemo": "desmaginar",
    "desmaginemos": "desmaginar",
    "desmagines": "desmaginar",
    "desmagino": "desmaginar",
    "desmaginou": "desmaginar",
    "desmaginá": "desmaginar",
    "desmaginámo": "desmaginar",
    "desmaginámos": "desmaginar",
    "desmagináramo": "desmaginar",
    "desmagináramos": "desmaginar",
    "desmaginárei": "desmaginar",
    "desmagináreis": "desmaginar",
    "desmaginásseis": "desmaginar",
    "desmaginássemos": "desmaginar",
    "desmaginávamo": "desmaginar",
    "desmaginávamos": "desmaginar",
    "desmaginávei": "desmaginar",
    "desmagináveis": "desmaginar",
    "desmagnetiza": "desmagnetizar",
    "desmagnetizada": "desmagnetizar",
    "desmagnetizadas": "desmagnetizar",
    "desmagnetizado": "desmagnetizar",
    "desmagnetizadora": "desmagnetizador",
    "desmagnetizadoras": "desmagnetizador",
    "desmagnetizadores": "desmagnetizador",
    "desmagnetizados": "desmagnetizar",
    "desmagnetizai": "desmagnetizar",
    "desmagnetizais": "desmagnetizar",
    "desmagnetizam": "desmagnetizar",
    "desmagnetizamo": "desmagnetizar",
    "desmagnetizamos": "desmagnetizar",
    "desmagnetizando": "desmagnetizar",
    "desmagnetizantes": "desmagnetizante",
    "desmagnetizara": "desmagnetizar",
    "desmagnetizaram": "desmagnetizar",
    "desmagnetizaras": "desmagnetizar",
    "desmagnetizarde": "desmagnetizar",
    "desmagnetizardes": "desmagnetizar",
    "desmagnetizare": "desmagnetizar",
    "desmagnetizarei": "desmagnetizar",
    "desmagnetizareis": "desmagnetizar",
    "desmagnetizarem": "desmagnetizar",
    "desmagnetizaremos": "desmagnetizar",
    "desmagnetizares": "desmagnetizar",
    "desmagnetizaria": "desmagnetizar",
    "desmagnetizariam": "desmagnetizar",
    "desmagnetizarias": "desmagnetizar",
    "desmagnetizarmo": "desmagnetizar",
    "desmagnetizarmos": "desmagnetizar",
    "desmagnetizará": "desmagnetizar",
    "desmagnetizarás": "desmagnetizar",
    "desmagnetizarão": "desmagnetizar",
    "desmagnetizaríamos": "desmagnetizar",
    "desmagnetizaríeis": "desmagnetizar",
    "desmagnetizas": "desmagnetizar",
    "desmagnetizasse": "desmagnetizar",
    "desmagnetizassem": "desmagnetizar",
    "desmagnetizasses": "desmagnetizar",
    "desmagnetizaste": "desmagnetizar",
    "desmagnetizastes": "desmagnetizar",
    "desmagnetizava": "desmagnetizar",
    "desmagnetizavam": "desmagnetizar",
    "desmagnetizavas": "desmagnetizar",
    "desmagnetizações": "desmagnetização",
    "desmagnetize": "desmagnetizar",
    "desmagnetizei": "desmagnetizar",
    "desmagnetizeis": "desmagnetizar",
    "desmagnetizem": "desmagnetizar",
    "desmagnetizemo": "desmagnetizar",
    "desmagnetizemos": "desmagnetizar",
    "desmagnetizes": "desmagnetizar",
    "desmagnetizo": "desmagnetizar",
    "desmagnetizou": "desmagnetizar",
    "desmagnetizá": "desmagnetizar",
    "desmagnetizámo": "desmagnetizar",
    "desmagnetizámos": "desmagnetizar",
    "desmagnetizáramo": "desmagnetizar",
    "desmagnetizáramos": "desmagnetizar",
    "desmagnetizárei": "desmagnetizar",
    "desmagnetizáreis": "desmagnetizar",
    "desmagnetizásseis": "desmagnetizar",
    "desmagnetizássemos": "desmagnetizar",
    "desmagnetizávamo": "desmagnetizar",
    "desmagnetizávamos": "desmagnetizar",
    "desmagnetizávei": "desmagnetizar",
    "desmagnetizáveis": "desmagnetizável",
    "desmaia": "desmaiar",
    "desmaiada": "desmaiar",
    "desmaiadas": "desmaiar",
    "desmaiado": "desmaiar",
    "desmaiados": "desmaiar",
    "desmaiai": "desmaiar",
    "desmaiais": "desmaiar",
    "desmaiam": "desmaiar",
    "desmaiamo": "desmaiar",
    "desmaiamos": "desmaiar",
    "desmaiando": "desmaiar",
    "desmaiara": "desmaiar",
    "desmaiaram": "desmaiar",
    "desmaiaras": "desmaiar",
    "desmaiardes": "desmaiar",
    "desmaiarei": "desmaiar",
    "desmaiareis": "desmaiar",
    "desmaiarem": "desmaiar",
    "desmaiaremos": "desmaiar",
    "desmaiares": "desmaiar",
    "desmaiaria": "desmaiar",
    "desmaiariam": "desmaiar",
    "desmaiarias": "desmaiar",
    "desmaiarmo": "desmaiar",
    "desmaiarmos": "desmaiar",
    "desmaiará": "desmaiar",
    "desmaiarás": "desmaiar",
    "desmaiarão": "desmaiar",
    "desmaiaríamos": "desmaiar",
    "desmaiaríeis": "desmaiar",
    "desmaias": "desmaiar",
    "desmaiasse": "desmaiar",
    "desmaiassem": "desmaiar",
    "desmaiasses": "desmaiar",
    "desmaiaste": "desmaiar",
    "desmaiastes": "desmaiar",
    "desmaiava": "desmaiar",
    "desmaiavam": "desmaiar",
    "desmaiavas": "desmaiar",
    "desmaie": "desmaiar",
    "desmaiei": "desmaiar",
    "desmaieis": "desmaiar",
    "desmaiem": "desmaiar",
    "desmaiemo": "desmaiar",
    "desmaiemos": "desmaiar",
    "desmaies": "desmaiar",
    "desmaio": "desmaiar",
    "desmaios": "desmaio",
    "desmaiou": "desmaiar",
    "desmaiámo": "desmaiar",
    "desmaiámos": "desmaiar",
    "desmaiáramo": "desmaiar",
    "desmaiáramos": "desmaiar",
    "desmaiáreis": "desmaiar",
    "desmaiásseis": "desmaiar",
    "desmaiássemos": "desmaiar",
    "desmaiávamo": "desmaiar",
    "desmaiávamos": "desmaiar",
    "desmaiáveis": "desmaiar",
    "desmalha": "desmalhar",
    "desmalhada": "desmalhar",
    "desmalhadas": "desmalhar",
    "desmalhado": "desmalhar",
    "desmalhados": "desmalhar",
    "desmalhai": "desmalhar",
    "desmalhais": "desmalhar",
    "desmalham": "desmalhar",
    "desmalhamo": "desmalhar",
    "desmalhamos": "desmalhar",
    "desmalhando": "desmalhar",
    "desmalhara": "desmalhar",
    "desmalharam": "desmalhar",
    "desmalharas": "desmalhar",
    "desmalharde": "desmalhar",
    "desmalhardes": "desmalhar",
    "desmalhare": "desmalhar",
    "desmalharei": "desmalhar",
    "desmalhareis": "desmalhar",
    "desmalharem": "desmalhar",
    "desmalharemos": "desmalhar",
    "desmalhares": "desmalhar",
    "desmalharia": "desmalhar",
    "desmalhariam": "desmalhar",
    "desmalharias": "desmalhar",
    "desmalharmo": "desmalhar",
    "desmalharmos": "desmalhar",
    "desmalhará": "desmalhar",
    "desmalharás": "desmalhar",
    "desmalharão": "desmalhar",
    "desmalharíamos": "desmalhar",
    "desmalharíeis": "desmalhar",
    "desmalhas": "desmalhar",
    "desmalhasse": "desmalhar",
    "desmalhassem": "desmalhar",
    "desmalhasses": "desmalhar",
    "desmalhaste": "desmalhar",
    "desmalhastes": "desmalhar",
    "desmalhava": "desmalhar",
    "desmalhavam": "desmalhar",
    "desmalhavas": "desmalhar",
    "desmalhe": "desmalhar",
    "desmalhei": "desmalhar",
    "desmalheis": "desmalhar",
    "desmalhem": "desmalhar",
    "desmalhemo": "desmalhar",
    "desmalhemos": "desmalhar",
    "desmalhes": "desmalhar",
    "desmalho": "desmalhar",
    "desmalhou": "desmalhar",
    "desmalhá": "desmalhar",
    "desmalhámo": "desmalhar",
    "desmalhámos": "desmalhar",
    "desmalháramo": "desmalhar",
    "desmalháramos": "desmalhar",
    "desmalhárei": "desmalhar",
    "desmalháreis": "desmalhar",
    "desmalhásseis": "desmalhar",
    "desmalhássemos": "desmalhar",
    "desmalhávamo": "desmalhar",
    "desmalhávamos": "desmalhar",
    "desmalhávei": "desmalhar",
    "desmalháveis": "desmalhar",
    "desmaliciosa": "desmalicioso",
    "desmaliciosas": "desmalicioso",
    "desmaliciosos": "desmalicioso",
    "desmama": "desmamar",
    "desmamada": "desmamar",
    "desmamadas": "desmamar",
    "desmamadeiras": "desmamadeira",
    "desmamado": "desmamar",
    "desmamados": "desmamar",
    "desmamai": "desmamar",
    "desmamais": "desmamar",
    "desmamam": "desmamar",
    "desmamamo": "desmamar",
    "desmamamos": "desmamar",
    "desmamando": "desmamar",
    "desmamara": "desmamar",
    "desmamaram": "desmamar",
    "desmamaras": "desmamar",
    "desmamarde": "desmamar",
    "desmamardes": "desmamar",
    "desmamare": "desmamar",
    "desmamarei": "desmamar",
    "desmamareis": "desmamar",
    "desmamarem": "desmamar",
    "desmamaremos": "desmamar",
    "desmamares": "desmamar",
    "desmamaria": "desmamar",
    "desmamariam": "desmamar",
    "desmamarias": "desmamar",
    "desmamarmo": "desmamar",
    "desmamarmos": "desmamar",
    "desmamará": "desmamar",
    "desmamarás": "desmamar",
    "desmamarão": "desmamar",
    "desmamaríamos": "desmamar",
    "desmamaríeis": "desmamar",
    "desmamas": "desmamar",
    "desmamasse": "desmamar",
    "desmamassem": "desmamar",
    "desmamasses": "desmamar",
    "desmamaste": "desmamar",
    "desmamastes": "desmamar",
    "desmamava": "desmamar",
    "desmamavam": "desmamar",
    "desmamavas": "desmamar",
    "desmamações": "desmamação",
    "desmame": "desmamar",
    "desmamei": "desmamar",
    "desmameis": "desmamar",
    "desmamem": "desmamar",
    "desmamemo": "desmamar",
    "desmamemos": "desmamar",
    "desmames": "desmame",
    "desmamo": "desmamar",
    "desmamos": "desmamo",
    "desmamou": "desmamar",
    "desmamá": "desmamar",
    "desmamámo": "desmamar",
    "desmamámos": "desmamar",
    "desmamáramo": "desmamar",
    "desmamáramos": "desmamar",
    "desmamárei": "desmamar",
    "desmamáreis": "desmamar",
    "desmamásseis": "desmamar",
    "desmamássemos": "desmamar",
    "desmamávamo": "desmamar",
    "desmamávamos": "desmamar",
    "desmamávei": "desmamar",
    "desmamáveis": "desmamar",
    "desmana": "desmanar",
    "desmanada": "desmanar",
    "desmanadas": "desmanar",
    "desmanado": "desmanar",
    "desmanados": "desmanar",
    "desmanai": "desmanar",
    "desmanais": "desmanar",
    "desmanam": "desmanar",
    "desmanamo": "desmanar",
    "desmanamos": "desmanar",
    "desmanando": "desmanar",
    "desmanara": "desmanar",
    "desmanaram": "desmanar",
    "desmanaras": "desmanar",
    "desmanarde": "desmanar",
    "desmanardes": "desmanar",
    "desmanare": "desmanar",
    "desmanarei": "desmanar",
    "desmanareis": "desmanar",
    "desmanarem": "desmanar",
    "desmanaremos": "desmanar",
    "desmanares": "desmanar",
    "desmanaria": "desmanar",
    "desmanariam": "desmanar",
    "desmanarias": "desmanar",
    "desmanarmo": "desmanar",
    "desmanarmos": "desmanar",
    "desmanará": "desmanar",
    "desmanarás": "desmanar",
    "desmanarão": "desmanar",
    "desmanaríamos": "desmanar",
    "desmanaríeis": "desmanar",
    "desmanas": "desmanar",
    "desmanasse": "desmanar",
    "desmanassem": "desmanar",
    "desmanasses": "desmanar",
    "desmanaste": "desmanar",
    "desmanastes": "desmanar",
    "desmanava": "desmanar",
    "desmanavam": "desmanar",
    "desmanavas": "desmanar",
    "desmancha": "desmanchar",
    "desmanchada": "desmanchar",
    "desmanchadas": "desmanchar",
    "desmanchadiça": "desmanchadiço",
    "desmanchadiças": "desmanchadiço",
    "desmanchadiços": "desmanchadiço",
    "desmanchado": "desmanchar",
    "desmanchados": "desmanchar",
    "desmanchai": "desmanchar",
    "desmanchais": "desmanchar",
    "desmancham": "desmanchar",
    "desmanchamo": "desmanchar",
    "desmanchamos": "desmanchar",
    "desmanchando": "desmanchar",
    "desmanchara": "desmanchar",
    "desmancharam": "desmanchar",
    "desmancharas": "desmanchar",
    "desmancharde": "desmanchar",
    "desmanchardes": "desmanchar",
    "desmanchare": "desmanchar",
    "desmancharei": "desmanchar",
    "desmanchareis": "desmanchar",
    "desmancharem": "desmanchar",
    "desmancharemos": "desmanchar",
    "desmanchares": "desmanchar",
    "desmancharia": "desmanchar",
    "desmanchariam": "desmanchar",
    "desmancharias": "desmanchar",
    "desmancharmo": "desmanchar",
    "desmancharmos": "desmanchar",
    "desmanchará": "desmanchar",
    "desmancharás": "desmanchar",
    "desmancharão": "desmanchar",
    "desmancharíamos": "desmanchar",
    "desmancharíeis": "desmanchar",
    "desmanchas": "desmanchar",
    "desmanchasse": "desmanchar",
    "desmanchassem": "desmanchar",
    "desmanchasses": "desmanchar",
    "desmanchaste": "desmanchar",
    "desmanchastes": "desmanchar",
    "desmanchava": "desmanchar",
    "desmanchavam": "desmanchar",
    "desmanchavas": "desmanchar",
    "desmanche": "desmanchar",
    "desmanchei": "desmanchar",
    "desmancheis": "desmanchar",
    "desmanchem": "desmanchar",
    "desmanchemo": "desmanchar",
    "desmanchemos": "desmanchar",
    "desmanches": "desmanchar",
    "desmancho": "desmanchar",
    "desmanchos": "desmancho",
    "desmanchou": "desmanchar",
    "desmanchá": "desmanchar",
    "desmanchámo": "desmanchar",
    "desmanchámos": "desmanchar",
    "desmancháramo": "desmanchar",
    "desmancháramos": "desmanchar",
    "desmanchárei": "desmanchar",
    "desmancháreis": "desmanchar",
    "desmanchásseis": "desmanchar",
    "desmanchássemos": "desmanchar",
    "desmanchávamo": "desmanchar",
    "desmanchávamos": "desmanchar",
    "desmanchávei": "desmanchar",
    "desmancháveis": "desmanchável",
    "desmanda": "desmandar",
    "desmandada": "desmandar",
    "desmandadas": "desmandar",
    "desmandado": "desmandar",
    "desmandados": "desmandar",
    "desmandai": "desmandar",
    "desmandais": "desmandar",
    "desmandam": "desmandar",
    "desmandamentos": "desmandamento",
    "desmandamo": "desmandar",
    "desmandamos": "desmandar",
    "desmandando": "desmandar",
    "desmandara": "desmandar",
    "desmandaram": "desmandar",
    "desmandaras": "desmandar",
    "desmandarde": "desmandar",
    "desmandardes": "desmandar",
    "desmandare": "desmandar",
    "desmandarei": "desmandar",
    "desmandareis": "desmandar",
    "desmandarem": "desmandar",
    "desmandaremos": "desmandar",
    "desmandares": "desmandar",
    "desmandaria": "desmandar",
    "desmandariam": "desmandar",
    "desmandarias": "desmandar",
    "desmandarmo": "desmandar",
    "desmandarmos": "desmandar",
    "desmandará": "desmandar",
    "desmandarás": "desmandar",
    "desmandarão": "desmandar",
    "desmandaríamos": "desmandar",
    "desmandaríeis": "desmandar",
    "desmandas": "desmandar",
    "desmandasse": "desmandar",
    "desmandassem": "desmandar",
    "desmandasses": "desmandar",
    "desmandaste": "desmandar",
    "desmandastes": "desmandar",
    "desmandava": "desmandar",
    "desmandavam": "desmandar",
    "desmandavas": "desmandar",
    "desmande": "desmandar",
    "desmandei": "desmandar",
    "desmandeis": "desmandar",
    "desmandem": "desmandar",
    "desmandemo": "desmandar",
    "desmandemos": "desmandar",
    "desmandes": "desmandar",
    "desmando": "desmandar",
    "desmandos": "desmando",
    "desmandou": "desmandar",
    "desmandá": "desmandar",
    "desmandámo": "desmandar",
    "desmandámos": "desmandar",
    "desmandáramo": "desmandar",
    "desmandáramos": "desmandar",
    "desmandárei": "desmandar",
    "desmandáreis": "desmandar",
    "desmandásseis": "desmandar",
    "desmandássemos": "desmandar",
    "desmandávamo": "desmandar",
    "desmandávamos": "desmandar",
    "desmandávei": "desmandar",
    "desmandáveis": "desmandar",
    "desmane": "desmanar",
    "desmanei": "desmanar",
    "desmaneis": "desmanar",
    "desmanem": "desmanar",
    "desmanemo": "desmanar",
    "desmanemos": "desmanar",
    "desmanes": "desmanar",
    "desmaninha": "desmaninhar",
    "desmaninhada": "desmaninhar",
    "desmaninhadas": "desmaninhar",
    "desmaninhado": "desmaninhar",
    "desmaninhados": "desmaninhar",
    "desmaninhai": "desmaninhar",
    "desmaninhais": "desmaninhar",
    "desmaninham": "desmaninhar",
    "desmaninhamo": "desmaninhar",
    "desmaninhamos": "desmaninhar",
    "desmaninhando": "desmaninhar",
    "desmaninhara": "desmaninhar",
    "desmaninharam": "desmaninhar",
    "desmaninharas": "desmaninhar",
    "desmaninharde": "desmaninhar",
    "desmaninhardes": "desmaninhar",
    "desmaninhare": "desmaninhar",
    "desmaninharei": "desmaninhar",
    "desmaninhareis": "desmaninhar",
    "desmaninharem": "desmaninhar",
    "desmaninharemos": "desmaninhar",
    "desmaninhares": "desmaninhar",
    "desmaninharia": "desmaninhar",
    "desmaninhariam": "desmaninhar",
    "desmaninharias": "desmaninhar",
    "desmaninharmo": "desmaninhar",
    "desmaninharmos": "desmaninhar",
    "desmaninhará": "desmaninhar",
    "desmaninharás": "desmaninhar",
    "desmaninharão": "desmaninhar",
    "desmaninharíamos": "desmaninhar",
    "desmaninharíeis": "desmaninhar",
    "desmaninhas": "desmaninhar",
    "desmaninhasse": "desmaninhar",
    "desmaninhassem": "desmaninhar",
    "desmaninhasses": "desmaninhar",
    "desmaninhaste": "desmaninhar",
    "desmaninhastes": "desmaninhar",
    "desmaninhava": "desmaninhar",
    "desmaninhavam": "desmaninhar",
    "desmaninhavas": "desmaninhar",
    "desmaninhe": "desmaninhar",
    "desmaninhei": "desmaninhar",
    "desmaninheis": "desmaninhar",
    "desmaninhem": "desmaninhar",
    "desmaninhemo": "desmaninhar",
    "desmaninhemos": "desmaninhar",
    "desmaninhes": "desmaninhar",
    "desmaninho": "desmaninhar",
    "desmaninhou": "desmaninhar",
    "desmaninhá": "desmaninhar",
    "desmaninhámo": "desmaninhar",
    "desmaninhámos": "desmaninhar",
    "desmaninháramo": "desmaninhar",
    "desmaninháramos": "desmaninhar",
    "desmaninhárei": "desmaninhar",
    "desmaninháreis": "desmaninhar",
    "desmaninhásseis": "desmaninhar",
    "desmaninhássemos": "desmaninhar",
    "desmaninhávamo": "desmaninhar",
    "desmaninhávamos": "desmaninhar",
    "desmaninhávei": "desmaninhar",
    "desmaninháveis": "desmaninhar",
    "desmano": "desmanar",
    "desmanou": "desmanar",
    "desmanta": "desmantar",
    "desmantada": "desmantar",
    "desmantadas": "desmantar",
    "desmantadelas": "desmantadela",
    "desmantado": "desmantar",
    "desmantados": "desmantar",
    "desmantai": "desmantar",
    "desmantais": "desmantar",
    "desmantam": "desmantar",
    "desmantamo": "desmantar",
    "desmantamos": "desmantar",
    "desmantando": "desmantar",
    "desmantara": "desmantar",
    "desmantaram": "desmantar",
    "desmantaras": "desmantar",
    "desmantarde": "desmantar",
    "desmantardes": "desmantar",
    "desmantare": "desmantar",
    "desmantarei": "desmantar",
    "desmantareis": "desmantar",
    "desmantarem": "desmantar",
    "desmantaremos": "desmantar",
    "desmantares": "desmantar",
    "desmantaria": "desmantar",
    "desmantariam": "desmantar",
    "desmantarias": "desmantar",
    "desmantarmo": "desmantar",
    "desmantarmos": "desmantar",
    "desmantará": "desmantar",
    "desmantarás": "desmantar",
    "desmantarão": "desmantar",
    "desmantaríamos": "desmantar",
    "desmantaríeis": "desmantar",
    "desmantas": "desmantar",
    "desmantasse": "desmantar",
    "desmantassem": "desmantar",
    "desmantasses": "desmantar",
    "desmantaste": "desmantar",
    "desmantastes": "desmantar",
    "desmantava": "desmantar",
    "desmantavam": "desmantar",
    "desmantavas": "desmantar",
    "desmante": "desmantar",
    "desmantei": "desmantar",
    "desmanteis": "desmantar",
    "desmantela": "desmantelar",
    "desmantelada": "desmantelar",
    "desmanteladas": "desmantelar",
    "desmantelado": "desmantelar",
    "desmanteladora": "desmantelador",
    "desmanteladoras": "desmantelador",
    "desmanteladores": "desmantelador",
    "desmantelados": "desmantelar",
    "desmantelai": "desmantelar",
    "desmantelais": "desmantelar",
    "desmantelam": "desmantelar",
    "desmantelamentos": "desmantelamento",
    "desmantelamo": "desmantelar",
    "desmantelamos": "desmantelar",
    "desmantelando": "desmantelar",
    "desmantelara": "desmantelar",
    "desmantelaram": "desmantelar",
    "desmantelaras": "desmantelar",
    "desmantelarde": "desmantelar",
    "desmantelardes": "desmantelar",
    "desmantelare": "desmantelar",
    "desmantelarei": "desmantelar",
    "desmantelareis": "desmantelar",
    "desmantelarem": "desmantelar",
    "desmantelaremos": "desmantelar",
    "desmantelares": "desmantelar",
    "desmantelaria": "desmantelar",
    "desmantelariam": "desmantelar",
    "desmantelarias": "desmantelar",
    "desmantelarmo": "desmantelar",
    "desmantelarmos": "desmantelar",
    "desmantelará": "desmantelar",
    "desmantelarás": "desmantelar",
    "desmantelarão": "desmantelar",
    "desmantelaríamos": "desmantelar",
    "desmantelaríeis": "desmantelar",
    "desmantelas": "desmantelar",
    "desmantelasse": "desmantelar",
    "desmantelassem": "desmantelar",
    "desmantelasses": "desmantelar",
    "desmantelaste": "desmantelar",
    "desmantelastes": "desmantelar",
    "desmantelava": "desmantelar",
    "desmantelavam": "desmantelar",
    "desmantelavas": "desmantelar",
    "desmantele": "desmantelar",
    "desmantelei": "desmantelar",
    "desmanteleis": "desmantelar",
    "desmantelem": "desmantelar",
    "desmantelemo": "desmantelar",
    "desmantelemos": "desmantelar",
    "desmanteles": "desmantelar",
    "desmantelo": "desmantelar",
    "desmantelos": "desmantelo",
    "desmantelou": "desmantelar",
    "desmantelá": "desmantelar",
    "desmantelámo": "desmantelar",
    "desmantelámos": "desmantelar",
    "desmanteláramo": "desmantelar",
    "desmanteláramos": "desmantelar",
    "desmantelárei": "desmantelar",
    "desmanteláreis": "desmantelar",
    "desmantelásseis": "desmantelar",
    "desmantelássemos": "desmantelar",
    "desmantelávamo": "desmantelar",
    "desmantelávamos": "desmantelar",
    "desmantelávei": "desmantelar",
    "desmanteláveis": "desmantelável",
    "desmantem": "desmantar",
    "desmantemo": "desmantar",
    "desmantemos": "desmantar",
    "desmantes": "desmantar",
    "desmanto": "desmantar",
    "desmantou": "desmantar",
    "desmantá": "desmantar",
    "desmantámo": "desmantar",
    "desmantámos": "desmantar",
    "desmantáramo": "desmantar",
    "desmantáramos": "desmantar",
    "desmantárei": "desmantar",
    "desmantáreis": "desmantar",
    "desmantásseis": "desmantar",
    "desmantássemos": "desmantar",
    "desmantávamo": "desmantar",
    "desmantávamos": "desmantar",
    "desmantávei": "desmantar",
    "desmantáveis": "desmantar",
    "desmaná": "desmanar",
    "desmanámo": "desmanar",
    "desmanámos": "desmanar",
    "desmanáramo": "desmanar",
    "desmanáramos": "desmanar",
    "desmanárei": "desmanar",
    "desmanáreis": "desmanar",
    "desmanásseis": "desmanar",
    "desmanássemos": "desmanar",
    "desmanávamo": "desmanar",
    "desmanávamos": "desmanar",
    "desmanávei": "desmanar",
    "desmanáveis": "desmanar",
    "desmaranha": "desmaranhar",
    "desmaranhada": "desmaranhar",
    "desmaranhadas": "desmaranhar",
    "desmaranhado": "desmaranhar",
    "desmaranhados": "desmaranhar",
    "desmaranhai": "desmaranhar",
    "desmaranhais": "desmaranhar",
    "desmaranham": "desmaranhar",
    "desmaranhamo": "desmaranhar",
    "desmaranhamos": "desmaranhar",
    "desmaranhando": "desmaranhar",
    "desmaranhara": "desmaranhar",
    "desmaranharam": "desmaranhar",
    "desmaranharas": "desmaranhar",
    "desmaranharde": "desmaranhar",
    "desmaranhardes": "desmaranhar",
    "desmaranhare": "desmaranhar",
    "desmaranharei": "desmaranhar",
    "desmaranhareis": "desmaranhar",
    "desmaranharem": "desmaranhar",
    "desmaranharemos": "desmaranhar",
    "desmaranhares": "desmaranhar",
    "desmaranharia": "desmaranhar",
    "desmaranhariam": "desmaranhar",
    "desmaranharias": "desmaranhar",
    "desmaranharmo": "desmaranhar",
    "desmaranharmos": "desmaranhar",
    "desmaranhará": "desmaranhar",
    "desmaranharás": "desmaranhar",
    "desmaranharão": "desmaranhar",
    "desmaranharíamos": "desmaranhar",
    "desmaranharíeis": "desmaranhar",
    "desmaranhas": "desmaranhar",
    "desmaranhasse": "desmaranhar",
    "desmaranhassem": "desmaranhar",
    "desmaranhasses": "desmaranhar",
    "desmaranhaste": "desmaranhar",
    "desmaranhastes": "desmaranhar",
    "desmaranhava": "desmaranhar",
    "desmaranhavam": "desmaranhar",
    "desmaranhavas": "desmaranhar",
    "desmaranhe": "desmaranhar",
    "desmaranhei": "desmaranhar",
    "desmaranheis": "desmaranhar",
    "desmaranhem": "desmaranhar",
    "desmaranhemo": "desmaranhar",
    "desmaranhemos": "desmaranhar",
    "desmaranhes": "desmaranhar",
    "desmaranho": "desmaranhar",
    "desmaranhos": "desmaranho",
    "desmaranhou": "desmaranhar",
    "desmaranhá": "desmaranhar",
    "desmaranhámo": "desmaranhar",
    "desmaranhámos": "desmaranhar",
    "desmaranháramo": "desmaranhar",
    "desmaranháramos": "desmaranhar",
    "desmaranhárei": "desmaranhar",
    "desmaranháreis": "desmaranhar",
    "desmaranhásseis": "desmaranhar",
    "desmaranhássemos": "desmaranhar",
    "desmaranhávamo": "desmaranhar",
    "desmaranhávamos": "desmaranhar",
    "desmaranhávei": "desmaranhar",
    "desmaranháveis": "desmaranhar",
    "desmarca": "desmarcar",
    "desmarcada": "desmarcar",
    "desmarcadas": "desmarcar",
    "desmarcado": "desmarcar",
    "desmarcados": "desmarcar",
    "desmarcai": "desmarcar",
    "desmarcais": "desmarcar",
    "desmarcam": "desmarcar",
    "desmarcamo": "desmarcar",
    "desmarcamos": "desmarcar",
    "desmarcando": "desmarcar",
    "desmarcara": "desmarcar",
    "desmarcaram": "desmarcar",
    "desmarcaras": "desmarcar",
    "desmarcarde": "desmarcar",
    "desmarcardes": "desmarcar",
    "desmarcare": "desmarcar",
    "desmarcarei": "desmarcar",
    "desmarcareis": "desmarcar",
    "desmarcarem": "desmarcar",
    "desmarcaremos": "desmarcar",
    "desmarcares": "desmarcar",
    "desmarcaria": "desmarcar",
    "desmarcariam": "desmarcar",
    "desmarcarias": "desmarcar",
    "desmarcarmo": "desmarcar",
    "desmarcarmos": "desmarcar",
    "desmarcará": "desmarcar",
    "desmarcarás": "desmarcar",
    "desmarcarão": "desmarcar",
    "desmarcaríamos": "desmarcar",
    "desmarcaríeis": "desmarcar",
    "desmarcas": "desmarcar",
    "desmarcasse": "desmarcar",
    "desmarcassem": "desmarcar",
    "desmarcasses": "desmarcar",
    "desmarcaste": "desmarcar",
    "desmarcastes": "desmarcar",
    "desmarcava": "desmarcar",
    "desmarcavam": "desmarcar",
    "desmarcavas": "desmarcar",
    "desmarcações": "desmarcação",
    "desmarco": "desmarcar",
    "desmarcou": "desmarcar",
    "desmarcá": "desmarcar",
    "desmarcámo": "desmarcar",
    "desmarcámos": "desmarcar",
    "desmarcáramo": "desmarcar",
    "desmarcáramos": "desmarcar",
    "desmarcárei": "desmarcar",
    "desmarcáreis": "desmarcar",
    "desmarcásseis": "desmarcar",
    "desmarcássemos": "desmarcar",
    "desmarcávamo": "desmarcar",
    "desmarcávamos": "desmarcar",
    "desmarcávei": "desmarcar",
    "desmarcáveis": "desmarcável",
    "desmareada": "desmarear",
    "desmareadas": "desmarear",
    "desmareado": "desmarear",
    "desmareados": "desmarear",
    "desmareai": "desmarear",
    "desmareais": "desmarear",
    "desmareamo": "desmarear",
    "desmareamos": "desmarear",
    "desmareando": "desmarear",
    "desmareara": "desmarear",
    "desmarearam": "desmarear",
    "desmarearas": "desmarear",
    "desmarearde": "desmarear",
    "desmareardes": "desmarear",
    "desmareare": "desmarear",
    "desmarearei": "desmarear",
    "desmareareis": "desmarear",
    "desmarearem": "desmarear",
    "desmarearemos": "desmarear",
    "desmareares": "desmarear",
    "desmarearia": "desmarear",
    "desmareariam": "desmarear",
    "desmarearias": "desmarear",
    "desmarearmo": "desmarear",
    "desmarearmos": "desmarear",
    "desmareará": "desmarear",
    "desmarearás": "desmarear",
    "desmarearão": "desmarear",
    "desmarearíamos": "desmarear",
    "desmarearíeis": "desmarear",
    "desmareasse": "desmarear",
    "desmareassem": "desmarear",
    "desmareasses": "desmarear",
    "desmareaste": "desmarear",
    "desmareastes": "desmarear",
    "desmareava": "desmarear",
    "desmareavam": "desmarear",
    "desmareavas": "desmarear",
    "desmareei": "desmarear",
    "desmareeis": "desmarear",
    "desmareemo": "desmarear",
    "desmareemos": "desmarear",
    "desmareia": "desmarear",
    "desmareiam": "desmarear",
    "desmareias": "desmarear",
    "desmareie": "desmarear",
    "desmareiem": "desmarear",
    "desmareies": "desmarear",
    "desmareio": "desmarear",
    "desmarelece": "desmarelecer",
    "desmarelecei": "desmarelecer",
    "desmareleceis": "desmarelecer",
    "desmarelecem": "desmarelecer",
    "desmarelecemo": "desmarelecer",
    "desmarelecemos": "desmarelecer",
    "desmarelecendo": "desmarelecer",
    "desmarelecera": "desmarelecer",
    "desmareleceram": "desmarelecer",
    "desmareleceras": "desmarelecer",
    "desmarelecerdes": "desmarelecer",
    "desmarelecerei": "desmarelecer",
    "desmarelecereis": "desmarelecer",
    "desmarelecerem": "desmarelecer",
    "desmareleceremos": "desmarelecer",
    "desmareleceres": "desmarelecer",
    "desmareleceria": "desmarelecer",
    "desmareleceriam": "desmarelecer",
    "desmarelecerias": "desmarelecer",
    "desmarelecermo": "desmarelecer",
    "desmarelecermos": "desmarelecer",
    "desmarelecerá": "desmarelecer",
    "desmarelecerás": "desmarelecer",
    "desmarelecerão": "desmarelecer",
    "desmareleceríamos": "desmarelecer",
    "desmareleceríeis": "desmarelecer",
    "desmareleces": "desmarelecer",
    "desmarelecesse": "desmarelecer",
    "desmarelecessem": "desmarelecer",
    "desmarelecesses": "desmarelecer",
    "desmareleceste": "desmarelecer",
    "desmarelecestes": "desmarelecer",
    "desmareleceu": "desmarelecer",
    "desmareleci": "desmarelecer",
    "desmarelecia": "desmarelecer",
    "desmareleciam": "desmarelecer",
    "desmarelecias": "desmarelecer",
    "desmarelecida": "desmarelecido",
    "desmarelecidas": "desmarelecido",
    "desmarelecido": "desmarelecer",
    "desmarelecidos": "desmarelecido",
    "desmarelecêramo": "desmarelecer",
    "desmarelecêramos": "desmarelecer",
    "desmarelecêreis": "desmarelecer",
    "desmarelecêsseis": "desmarelecer",
    "desmarelecêssemos": "desmarelecer",
    "desmarelecíamo": "desmarelecer",
    "desmarelecíamos": "desmarelecer",
    "desmarelecíeis": "desmarelecer",
    "desmareleça": "desmarelecer",
    "desmareleçais": "desmarelecer",
    "desmareleçam": "desmarelecer",
    "desmareleçamo": "desmarelecer",
    "desmareleçamos": "desmarelecer",
    "desmareleças": "desmarelecer",
    "desmareleço": "desmarelecer",
    "desmareou": "desmarear",
    "desmareá": "desmarear",
    "desmareámo": "desmarear",
    "desmareámos": "desmarear",
    "desmareáramo": "desmarear",
    "desmareáramos": "desmarear",
    "desmareárei": "desmarear",
    "desmareáreis": "desmarear",
    "desmareásseis": "desmarear",
    "desmareássemos": "desmarear",
    "desmareávamo": "desmarear",
    "desmareávamos": "desmarear",
    "desmareávei": "desmarear",
    "desmareáveis": "desmarear",
    "desmarque": "desmarcar",
    "desmarquei": "desmarcar",
    "desmarqueis": "desmarcar",
    "desmarquem": "desmarcar",
    "desmarquemo": "desmarcar",
    "desmarquemos": "desmarcar",
    "desmarques": "desmarcar",
    "desmascara": "desmascarar",
    "desmascarada": "desmascarar",
    "desmascaradas": "desmascarar",
    "desmascarado": "desmascarar",
    "desmascarados": "desmascarar",
    "desmascarai": "desmascarar",
    "desmascarais": "desmascarar",
    "desmascaram": "desmascarar",
    "desmascaramentos": "desmascaramento",
    "desmascaramo": "desmascarar",
    "desmascaramos": "desmascarar",
    "desmascarando": "desmascarar",
    "desmascarara": "desmascarar",
    "desmascararam": "desmascarar",
    "desmascararas": "desmascarar",
    "desmascararde": "desmascarar",
    "desmascarardes": "desmascarar",
    "desmascarare": "desmascarar",
    "desmascararei": "desmascarar",
    "desmascarareis": "desmascarar",
    "desmascararem": "desmascarar",
    "desmascararemos": "desmascarar",
    "desmascarares": "desmascarar",
    "desmascararia": "desmascarar",
    "desmascarariam": "desmascarar",
    "desmascararias": "desmascarar",
    "desmascararmo": "desmascarar",
    "desmascararmos": "desmascarar",
    "desmascarará": "desmascarar",
    "desmascararás": "desmascarar",
    "desmascararão": "desmascarar",
    "desmascararíamos": "desmascarar",
    "desmascararíeis": "desmascarar",
    "desmascaras": "desmascarar",
    "desmascarasse": "desmascarar",
    "desmascarassem": "desmascarar",
    "desmascarasses": "desmascarar",
    "desmascaraste": "desmascarar",
    "desmascarastes": "desmascarar",
    "desmascarava": "desmascarar",
    "desmascaravam": "desmascarar",
    "desmascaravas": "desmascarar",
    "desmascare": "desmascarar",
    "desmascarei": "desmascarar",
    "desmascareis": "desmascarar",
    "desmascarem": "desmascarar",
    "desmascaremo": "desmascarar",
    "desmascaremos": "desmascarar",
    "desmascares": "desmascarar",
    "desmascaro": "desmascarar",
    "desmascarou": "desmascarar",
    "desmascará": "desmascarar",
    "desmascarámo": "desmascarar",
    "desmascarámos": "desmascarar",
    "desmascaráramo": "desmascarar",
    "desmascaráramos": "desmascarar",
    "desmascarárei": "desmascarar",
    "desmascaráreis": "desmascarar",
    "desmascarásseis": "desmascarar",
    "desmascarássemos": "desmascarar",
    "desmascarávamo": "desmascarar",
    "desmascarávamos": "desmascarar",
    "desmascarávei": "desmascarar",
    "desmascaráveis": "desmascarável",
    "desmastra": "desmastrar",
    "desmastrada": "desmastrar",
    "desmastradas": "desmastrar",
    "desmastrado": "desmastrar",
    "desmastrados": "desmastrar",
    "desmastrai": "desmastrar",
    "desmastrais": "desmastrar",
    "desmastram": "desmastrar",
    "desmastramo": "desmastrar",
    "desmastramos": "desmastrar",
    "desmastrando": "desmastrar",
    "desmastrara": "desmastrar",
    "desmastraram": "desmastrar",
    "desmastraras": "desmastrar",
    "desmastrarde": "desmastrar",
    "desmastrardes": "desmastrar",
    "desmastrare": "desmastrar",
    "desmastrarei": "desmastrar",
    "desmastrareis": "desmastrar",
    "desmastrarem": "desmastrar",
    "desmastraremos": "desmastrar",
    "desmastrares": "desmastrar",
    "desmastraria": "desmastrar",
    "desmastrariam": "desmastrar",
    "desmastrarias": "desmastrar",
    "desmastrarmo": "desmastrar",
    "desmastrarmos": "desmastrar",
    "desmastrará": "desmastrar",
    "desmastrarás": "desmastrar",
    "desmastrarão": "desmastrar",
    "desmastraríamos": "desmastrar",
    "desmastraríeis": "desmastrar",
    "desmastras": "desmastrar",
    "desmastrasse": "desmastrar",
    "desmastrassem": "desmastrar",
    "desmastrasses": "desmastrar",
    "desmastraste": "desmastrar",
    "desmastrastes": "desmastrar",
    "desmastrava": "desmastrar",
    "desmastravam": "desmastrar",
    "desmastravas": "desmastrar",
    "desmastre": "desmastrar",
    "desmastreada": "desmastrear",
    "desmastreadas": "desmastrear",
    "desmastreado": "desmastrear",
    "desmastreados": "desmastrear",
    "desmastreai": "desmastrear",
    "desmastreais": "desmastrear",
    "desmastreamentos": "desmastreamento",
    "desmastreamo": "desmastrear",
    "desmastreamos": "desmastrear",
    "desmastreando": "desmastrear",
    "desmastreara": "desmastrear",
    "desmastrearam": "desmastrear",
    "desmastrearas": "desmastrear",
    "desmastrearde": "desmastrear",
    "desmastreardes": "desmastrear",
    "desmastreare": "desmastrear",
    "desmastrearei": "desmastrear",
    "desmastreareis": "desmastrear",
    "desmastrearem": "desmastrear",
    "desmastrearemos": "desmastrear",
    "desmastreares": "desmastrear",
    "desmastrearia": "desmastrear",
    "desmastreariam": "desmastrear",
    "desmastrearias": "desmastrear",
    "desmastrearmo": "desmastrear",
    "desmastrearmos": "desmastrear",
    "desmastreará": "desmastrear",
    "desmastrearás": "desmastrear",
    "desmastrearão": "desmastrear",
    "desmastrearíamos": "desmastrear",
    "desmastrearíeis": "desmastrear",
    "desmastreasse": "desmastrear",
    "desmastreassem": "desmastrear",
    "desmastreasses": "desmastrear",
    "desmastreaste": "desmastrear",
    "desmastreastes": "desmastrear",
    "desmastreava": "desmastrear",
    "desmastreavam": "desmastrear",
    "desmastreavas": "desmastrear",
    "desmastreei": "desmastrear",
    "desmastreeis": "desmastrear",
    "desmastreemo": "desmastrear",
    "desmastreemos": "desmastrear",
    "desmastrei": "desmastrar",
    "desmastreia": "desmastrear",
    "desmastreiam": "desmastrear",
    "desmastreias": "desmastrear",
    "desmastreie": "desmastrear",
    "desmastreiem": "desmastrear",
    "desmastreies": "desmastrear",
    "desmastreio": "desmastrear",
    "desmastreis": "desmastrar",
    "desmastrem": "desmastrar",
    "desmastremo": "desmastrar",
    "desmastremos": "desmastrar",
    "desmastreou": "desmastrear",
    "desmastres": "desmastrar",
    "desmastreá": "desmastrear",
    "desmastreámo": "desmastrear",
    "desmastreámos": "desmastrear",
    "desmastreáramo": "desmastrear",
    "desmastreáramos": "desmastrear",
    "desmastreárei": "desmastrear",
    "desmastreáreis": "desmastrear",
    "desmastreásseis": "desmastrear",
    "desmastreássemos": "desmastrear",
    "desmastreávamo": "desmastrear",
    "desmastreávamos": "desmastrear",
    "desmastreávei": "desmastrear",
    "desmastreáveis": "desmastrear",
    "desmastro": "desmastrar",
    "desmastrou": "desmastrar",
    "desmastrá": "desmastrar",
    "desmastrámo": "desmastrar",
    "desmastrámos": "desmastrar",
    "desmastráramo": "desmastrar",
    "desmastráramos": "desmastrar",
    "desmastrárei": "desmastrar",
    "desmastráreis": "desmastrar",
    "desmastrásseis": "desmastrar",
    "desmastrássemos": "desmastrar",
    "desmastrávamo": "desmastrar",
    "desmastrávamos": "desmastrar",
    "desmastrávei": "desmastrar",
    "desmastráveis": "desmastrar",
    "desmaterializa": "desmaterializar",
    "desmaterializada": "desmaterializar",
    "desmaterializadas": "desmaterializar",
    "desmaterializado": "desmaterializar",
    "desmaterializados": "desmaterializar",
    "desmaterializai": "desmaterializar",
    "desmaterializais": "desmaterializar",
    "desmaterializam": "desmaterializar",
    "desmaterializamo": "desmaterializar",
    "desmaterializamos": "desmaterializar",
    "desmaterializando": "desmaterializar",
    "desmaterializara": "desmaterializar",
    "desmaterializaram": "desmaterializar",
    "desmaterializaras": "desmaterializar",
    "desmaterializarde": "desmaterializar",
    "desmaterializardes": "desmaterializar",
    "desmaterializare": "desmaterializar",
    "desmaterializarei": "desmaterializar",
    "desmaterializareis": "desmaterializar",
    "desmaterializarem": "desmaterializar",
    "desmaterializaremos": "desmaterializar",
    "desmaterializares": "desmaterializar",
    "desmaterializaria": "desmaterializar",
    "desmaterializariam": "desmaterializar",
    "desmaterializarias": "desmaterializar",
    "desmaterializarmo": "desmaterializar",
    "desmaterializarmos": "desmaterializar",
    "desmaterializará": "desmaterializar",
    "desmaterializarás": "desmaterializar",
    "desmaterializarão": "desmaterializar",
    "desmaterializaríamos": "desmaterializar",
    "desmaterializaríeis": "desmaterializar",
    "desmaterializas": "desmaterializar",
    "desmaterializasse": "desmaterializar",
    "desmaterializassem": "desmaterializar",
    "desmaterializasses": "desmaterializar",
    "desmaterializaste": "desmaterializar",
    "desmaterializastes": "desmaterializar",
    "desmaterializava": "desmaterializar",
    "desmaterializavam": "desmaterializar",
    "desmaterializavas": "desmaterializar",
    "desmaterializações": "desmaterialização",
    "desmaterialize": "desmaterializar",
    "desmaterializei": "desmaterializar",
    "desmaterializeis": "desmaterializar",
    "desmaterializem": "desmaterializar",
    "desmaterializemo": "desmaterializar",
    "desmaterializemos": "desmaterializar",
    "desmaterializes": "desmaterializar",
    "desmaterializo": "desmaterializar",
    "desmaterializou": "desmaterializar",
    "desmaterializá": "desmaterializar",
    "desmaterializámo": "desmaterializar",
    "desmaterializámos": "desmaterializar",
    "desmaterializáramo": "desmaterializar",
    "desmaterializáramos": "desmaterializar",
    "desmaterializárei": "desmaterializar",
    "desmaterializáreis": "desmaterializar",
    "desmaterializásseis": "desmaterializar",
    "desmaterializássemos": "desmaterializar",
    "desmaterializávamo": "desmaterializar",
    "desmaterializávamos": "desmaterializar",
    "desmaterializávei": "desmaterializar",
    "desmaterializáveis": "desmaterializável",
    "desmazela": "desmazelar",
    "desmazelada": "desmazelar",
    "desmazeladas": "desmazelar",
    "desmazelado": "desmazelar",
    "desmazelados": "desmazelar",
    "desmazeladíssima": "desmazelado",
    "desmazeladíssimas": "desmazelado",
    "desmazeladíssimo": "desmazelado",
    "desmazeladíssimos": "desmazelado",
    "desmazelai": "desmazelar",
    "desmazelais": "desmazelar",
    "desmazelam": "desmazelar",
    "desmazelamo": "desmazelar",
    "desmazelamos": "desmazelar",
    "desmazelando": "desmazelar",
    "desmazelara": "desmazelar",
    "desmazelaram": "desmazelar",
    "desmazelaras": "desmazelar",
    "desmazelarde": "desmazelar",
    "desmazelardes": "desmazelar",
    "desmazelare": "desmazelar",
    "desmazelarei": "desmazelar",
    "desmazelareis": "desmazelar",
    "desmazelarem": "desmazelar",
    "desmazelaremos": "desmazelar",
    "desmazelares": "desmazelar",
    "desmazelaria": "desmazelar",
    "desmazelariam": "desmazelar",
    "desmazelarias": "desmazelar",
    "desmazelarmo": "desmazelar",
    "desmazelarmos": "desmazelar",
    "desmazelará": "desmazelar",
    "desmazelarás": "desmazelar",
    "desmazelarão": "desmazelar",
    "desmazelaríamos": "desmazelar",
    "desmazelaríeis": "desmazelar",
    "desmazelas": "desmazelar",
    "desmazelasse": "desmazelar",
    "desmazelassem": "desmazelar",
    "desmazelasses": "desmazelar",
    "desmazelaste": "desmazelar",
    "desmazelastes": "desmazelar",
    "desmazelava": "desmazelar",
    "desmazelavam": "desmazelar",
    "desmazelavas": "desmazelar",
    "desmazele": "desmazelar",
    "desmazelei": "desmazelar",
    "desmazeleis": "desmazelar",
    "desmazelem": "desmazelar",
    "desmazelemo": "desmazelar",
    "desmazelemos": "desmazelar",
    "desmazeles": "desmazelar",
    "desmazelo": "desmazelar",
    "desmazelos": "desmazelo",
    "desmazelou": "desmazelar",
    "desmazelá": "desmazelar",
    "desmazelámo": "desmazelar",
    "desmazelámos": "desmazelar",
    "desmazeláramo": "desmazelar",
    "desmazeláramos": "desmazelar",
    "desmazelárei": "desmazelar",
    "desmazeláreis": "desmazelar",
    "desmazelásseis": "desmazelar",
    "desmazelássemos": "desmazelar",
    "desmazelávamo": "desmazelar",
    "desmazelávamos": "desmazelar",
    "desmazelávei": "desmazelar",
    "desmazeláveis": "desmazelar",
    "desmeda": "desmedir",
    "desmedais": "desmedir",
    "desmedam": "desmedir",
    "desmedamo": "desmedir",
    "desmedamos": "desmedir",
    "desmedas": "desmedir",
    "desmede": "desmedir",
    "desmedem": "desmedir",
    "desmedes": "desmedir",
    "desmedi": "desmedir",
    "desmedia": "desmedir",
    "desmediam": "desmedir",
    "desmedias": "desmedir",
    "desmedida": "desmedir",
    "desmedidas": "desmedir",
    "desmedido": "desmedir",
    "desmedidos": "desmedir",
    "desmedimo": "desmedir",
    "desmedimos": "desmedir",
    "desmedindo": "desmedir",
    "desmedira": "desmedir",
    "desmediram": "desmedir",
    "desmediras": "desmedir",
    "desmedirde": "desmedir",
    "desmedirdes": "desmedir",
    "desmedire": "desmedir",
    "desmedirei": "desmedir",
    "desmedireis": "desmedir",
    "desmedirem": "desmedir",
    "desmediremos": "desmedir",
    "desmedires": "desmedir",
    "desmediria": "desmedir",
    "desmediriam": "desmedir",
    "desmedirias": "desmedir",
    "desmedirmo": "desmedir",
    "desmedirmos": "desmedir",
    "desmedirá": "desmedir",
    "desmedirás": "desmedir",
    "desmedirão": "desmedir",
    "desmediríamos": "desmedir",
    "desmediríeis": "desmedir",
    "desmedis": "desmedir",
    "desmedisse": "desmedir",
    "desmedissem": "desmedir",
    "desmedisses": "desmedir",
    "desmediste": "desmedir",
    "desmedistes": "desmedir",
    "desmediu": "desmedir",
    "desmedo": "desmedir",
    "desmedra": "desmedrar",
    "desmedrada": "desmedrar",
    "desmedradas": "desmedrar",
    "desmedrado": "desmedrar",
    "desmedrados": "desmedrar",
    "desmedrai": "desmedrar",
    "desmedrais": "desmedrar",
    "desmedram": "desmedrar",
    "desmedramo": "desmedrar",
    "desmedramos": "desmedrar",
    "desmedrando": "desmedrar",
    "desmedranças": "desmedrança",
    "desmedrara": "desmedrar",
    "desmedraram": "desmedrar",
    "desmedraras": "desmedrar",
    "desmedrardes": "desmedrar",
    "desmedrarei": "desmedrar",
    "desmedrareis": "desmedrar",
    "desmedrarem": "desmedrar",
    "desmedraremos": "desmedrar",
    "desmedrares": "desmedrar",
    "desmedraria": "desmedrar",
    "desmedrariam": "desmedrar",
    "desmedrarias": "desmedrar",
    "desmedrarmo": "desmedrar",
    "desmedrarmos": "desmedrar",
    "desmedrará": "desmedrar",
    "desmedrarás": "desmedrar",
    "desmedrarão": "desmedrar",
    "desmedraríamos": "desmedrar",
    "desmedraríeis": "desmedrar",
    "desmedras": "desmedrar",
    "desmedrasse": "desmedrar",
    "desmedrassem": "desmedrar",
    "desmedrasses": "desmedrar",
    "desmedraste": "desmedrar",
    "desmedrastes": "desmedrar",
    "desmedrava": "desmedrar",
    "desmedravam": "desmedrar",
    "desmedravas": "desmedrar",
    "desmedre": "desmedrar",
    "desmedrei": "desmedrar",
    "desmedreis": "desmedrar",
    "desmedrem": "desmedrar",
    "desmedremo": "desmedrar",
    "desmedremos": "desmedrar",
    "desmedres": "desmedrar",
    "desmedro": "desmedrar",
    "desmedros": "desmedro",
    "desmedrosa": "desmedroso",
    "desmedrosas": "desmedroso",
    "desmedrosos": "desmedroso",
    "desmedrou": "desmedrar",
    "desmedrámo": "desmedrar",
    "desmedrámos": "desmedrar",
    "desmedráramo": "desmedrar",
    "desmedráramos": "desmedrar",
    "desmedráreis": "desmedrar",
    "desmedrásseis": "desmedrar",
    "desmedrássemos": "desmedrar",
    "desmedrávamo": "desmedrar",
    "desmedrávamos": "desmedrar",
    "desmedráveis": "desmedrar",
    "desmedula": "desmedular",
    "desmedulada": "desmedular",
    "desmeduladas": "desmedular",
    "desmedulado": "desmedular",
    "desmedulados": "desmedular",
    "desmedulai": "desmedular",
    "desmedulais": "desmedular",
    "desmedulam": "desmedular",
    "desmedulamo": "desmedular",
    "desmedulamos": "desmedular",
    "desmedulando": "desmedular",
    "desmedulara": "desmedular",
    "desmedularam": "desmedular",
    "desmedularas": "desmedular",
    "desmedularde": "desmedular",
    "desmedulardes": "desmedular",
    "desmedulare": "desmedular",
    "desmedularei": "desmedular",
    "desmedulareis": "desmedular",
    "desmedularem": "desmedular",
    "desmedularemos": "desmedular",
    "desmedulares": "desmedular",
    "desmedularia": "desmedular",
    "desmedulariam": "desmedular",
    "desmedularias": "desmedular",
    "desmedularmo": "desmedular",
    "desmedularmos": "desmedular",
    "desmedulará": "desmedular",
    "desmedularás": "desmedular",
    "desmedularão": "desmedular",
    "desmedularíamos": "desmedular",
    "desmedularíeis": "desmedular",
    "desmedulas": "desmedular",
    "desmedulasse": "desmedular",
    "desmedulassem": "desmedular",
    "desmedulasses": "desmedular",
    "desmedulaste": "desmedular",
    "desmedulastes": "desmedular",
    "desmedulava": "desmedular",
    "desmedulavam": "desmedular",
    "desmedulavas": "desmedular",
    "desmedule": "desmedular",
    "desmedulei": "desmedular",
    "desmeduleis": "desmedular",
    "desmedulem": "desmedular",
    "desmedulemo": "desmedular",
    "desmedulemos": "desmedular",
    "desmedules": "desmedular",
    "desmedulo": "desmedular",
    "desmedulou": "desmedular",
    "desmedulá": "desmedular",
    "desmedulámo": "desmedular",
    "desmedulámos": "desmedular",
    "desmeduláramo": "desmedular",
    "desmeduláramos": "desmedular",
    "desmedulárei": "desmedular",
    "desmeduláreis": "desmedular",
    "desmedulásseis": "desmedular",
    "desmedulássemos": "desmedular",
    "desmedulávamo": "desmedular",
    "desmedulávamos": "desmedular",
    "desmedulávei": "desmedular",
    "desmeduláveis": "desmedular",
    "desmedíamo": "desmedir",
    "desmedíamos": "desmedir",
    "desmedíei": "desmedir",
    "desmedíeis": "desmedir",
    "desmedíramo": "desmedir",
    "desmedíramos": "desmedir",
    "desmedírei": "desmedir",
    "desmedíreis": "desmedir",
    "desmedísseis": "desmedir",
    "desmedíssemos": "desmedir",
    "desmelancoliza": "desmelancolizar",
    "desmelancolizada": "desmelancolizar",
    "desmelancolizadas": "desmelancolizar",
    "desmelancolizado": "desmelancolizar",
    "desmelancolizados": "desmelancolizar",
    "desmelancolizai": "desmelancolizar",
    "desmelancolizais": "desmelancolizar",
    "desmelancolizam": "desmelancolizar",
    "desmelancolizamo": "desmelancolizar",
    "desmelancolizamos": "desmelancolizar",
    "desmelancolizando": "desmelancolizar",
    "desmelancolizara": "desmelancolizar",
    "desmelancolizaram": "desmelancolizar",
    "desmelancolizaras": "desmelancolizar",
    "desmelancolizarde": "desmelancolizar",
    "desmelancolizardes": "desmelancolizar",
    "desmelancolizare": "desmelancolizar",
    "desmelancolizarei": "desmelancolizar",
    "desmelancolizareis": "desmelancolizar",
    "desmelancolizarem": "desmelancolizar",
    "desmelancolizaremos": "desmelancolizar",
    "desmelancolizares": "desmelancolizar",
    "desmelancolizaria": "desmelancolizar",
    "desmelancolizariam": "desmelancolizar",
    "desmelancolizarias": "desmelancolizar",
    "desmelancolizarmo": "desmelancolizar",
    "desmelancolizarmos": "desmelancolizar",
    "desmelancolizará": "desmelancolizar",
    "desmelancolizarás": "desmelancolizar",
    "desmelancolizarão": "desmelancolizar",
    "desmelancolizaríamos": "desmelancolizar",
    "desmelancolizaríeis": "desmelancolizar",
    "desmelancolizas": "desmelancolizar",
    "desmelancolizasse": "desmelancolizar",
    "desmelancolizassem": "desmelancolizar",
    "desmelancolizasses": "desmelancolizar",
    "desmelancolizaste": "desmelancolizar",
    "desmelancolizastes": "desmelancolizar",
    "desmelancolizava": "desmelancolizar",
    "desmelancolizavam": "desmelancolizar",
    "desmelancolizavas": "desmelancolizar",
    "desmelancolize": "desmelancolizar",
    "desmelancolizei": "desmelancolizar",
    "desmelancolizeis": "desmelancolizar",
    "desmelancolizem": "desmelancolizar",
    "desmelancolizemo": "desmelancolizar",
    "desmelancolizemos": "desmelancolizar",
    "desmelancolizes": "desmelancolizar",
    "desmelancolizo": "desmelancolizar",
    "desmelancolizou": "desmelancolizar",
    "desmelancolizá": "desmelancolizar",
    "desmelancolizámo": "desmelancolizar",
    "desmelancolizámos": "desmelancolizar",
    "desmelancolizáramo": "desmelancolizar",
    "desmelancolizáramos": "desmelancolizar",
    "desmelancolizárei": "desmelancolizar",
    "desmelancolizáreis": "desmelancolizar",
    "desmelancolizásseis": "desmelancolizar",
    "desmelancolizássemos": "desmelancolizar",
    "desmelancolizávamo": "desmelancolizar",
    "desmelancolizávamos": "desmelancolizar",
    "desmelancolizávei": "desmelancolizar",
    "desmelancolizáveis": "desmelancolizar",
    "desmelenada": "desmelenado",
    "desmelenadas": "desmelenado",
    "desmelenados": "desmelenado",
    "desmelhora": "desmelhorar",
    "desmelhorada": "desmelhorar",
    "desmelhoradas": "desmelhorar",
    "desmelhorado": "desmelhorar",
    "desmelhorados": "desmelhorar",
    "desmelhorai": "desmelhorar",
    "desmelhorais": "desmelhorar",
    "desmelhoram": "desmelhorar",
    "desmelhoramo": "desmelhorar",
    "desmelhoramos": "desmelhorar",
    "desmelhorando": "desmelhorar",
    "desmelhorara": "desmelhorar",
    "desmelhoraram": "desmelhorar",
    "desmelhoraras": "desmelhorar",
    "desmelhorarde": "desmelhorar",
    "desmelhorardes": "desmelhorar",
    "desmelhorare": "desmelhorar",
    "desmelhorarei": "desmelhorar",
    "desmelhorareis": "desmelhorar",
    "desmelhorarem": "desmelhorar",
    "desmelhoraremos": "desmelhorar",
    "desmelhorares": "desmelhorar",
    "desmelhoraria": "desmelhorar",
    "desmelhorariam": "desmelhorar",
    "desmelhorarias": "desmelhorar",
    "desmelhorarmo": "desmelhorar",
    "desmelhorarmos": "desmelhorar",
    "desmelhorará": "desmelhorar",
    "desmelhorarás": "desmelhorar",
    "desmelhorarão": "desmelhorar",
    "desmelhoraríamos": "desmelhorar",
    "desmelhoraríeis": "desmelhorar",
    "desmelhoras": "desmelhorar",
    "desmelhorasse": "desmelhorar",
    "desmelhorassem": "desmelhorar",
    "desmelhorasses": "desmelhorar",
    "desmelhoraste": "desmelhorar",
    "desmelhorastes": "desmelhorar",
    "desmelhorava": "desmelhorar",
    "desmelhoravam": "desmelhorar",
    "desmelhoravas": "desmelhorar",
    "desmelhore": "desmelhorar",
    "desmelhorei": "desmelhorar",
    "desmelhoreis": "desmelhorar",
    "desmelhorem": "desmelhorar",
    "desmelhoremo": "desmelhorar",
    "desmelhoremos": "desmelhorar",
    "desmelhores": "desmelhorar",
    "desmelhoro": "desmelhorar",
    "desmelhorou": "desmelhorar",
    "desmelhorá": "desmelhorar",
    "desmelhorámo": "desmelhorar",
    "desmelhorámos": "desmelhorar",
    "desmelhoráramo": "desmelhorar",
    "desmelhoráramos": "desmelhorar",
    "desmelhorárei": "desmelhorar",
    "desmelhoráreis": "desmelhorar",
    "desmelhorásseis": "desmelhorar",
    "desmelhorássemos": "desmelhorar",
    "desmelhorávamo": "desmelhorar",
    "desmelhorávamos": "desmelhorar",
    "desmelhorávei": "desmelhorar",
    "desmelhoráveis": "desmelhorar",
    "desmelindra": "desmelindrar",
    "desmelindrada": "desmelindrar",
    "desmelindradas": "desmelindrar",
    "desmelindrado": "desmelindrar",
    "desmelindrados": "desmelindrar",
    "desmelindrai": "desmelindrar",
    "desmelindrais": "desmelindrar",
    "desmelindram": "desmelindrar",
    "desmelindramo": "desmelindrar",
    "desmelindramos": "desmelindrar",
    "desmelindrando": "desmelindrar",
    "desmelindrara": "desmelindrar",
    "desmelindraram": "desmelindrar",
    "desmelindraras": "desmelindrar",
    "desmelindrarde": "desmelindrar",
    "desmelindrardes": "desmelindrar",
    "desmelindrare": "desmelindrar",
    "desmelindrarei": "desmelindrar",
    "desmelindrareis": "desmelindrar",
    "desmelindrarem": "desmelindrar",
    "desmelindraremos": "desmelindrar",
    "desmelindrares": "desmelindrar",
    "desmelindraria": "desmelindrar",
    "desmelindrariam": "desmelindrar",
    "desmelindrarias": "desmelindrar",
    "desmelindrarmo": "desmelindrar",
    "desmelindrarmos": "desmelindrar",
    "desmelindrará": "desmelindrar",
    "desmelindrarás": "desmelindrar",
    "desmelindrarão": "desmelindrar",
    "desmelindraríamos": "desmelindrar",
    "desmelindraríeis": "desmelindrar",
    "desmelindras": "desmelindrar",
    "desmelindrasse": "desmelindrar",
    "desmelindrassem": "desmelindrar",
    "desmelindrasses": "desmelindrar",
    "desmelindraste": "desmelindrar",
    "desmelindrastes": "desmelindrar",
    "desmelindrava": "desmelindrar",
    "desmelindravam": "desmelindrar",
    "desmelindravas": "desmelindrar",
    "desmelindre": "desmelindrar",
    "desmelindrei": "desmelindrar",
    "desmelindreis": "desmelindrar",
    "desmelindrem": "desmelindrar",
    "desmelindremo": "desmelindrar",
    "desmelindremos": "desmelindrar",
    "desmelindres": "desmelindrar",
    "desmelindro": "desmelindrar",
    "desmelindrou": "desmelindrar",
    "desmelindrá": "desmelindrar",
    "desmelindrámo": "desmelindrar",
    "desmelindrámos": "desmelindrar",
    "desmelindráramo": "desmelindrar",
    "desmelindráramos": "desmelindrar",
    "desmelindrárei": "desmelindrar",
    "desmelindráreis": "desmelindrar",
    "desmelindrásseis": "desmelindrar",
    "desmelindrássemos": "desmelindrar",
    "desmelindrávamo": "desmelindrar",
    "desmelindrávamos": "desmelindrar",
    "desmelindrávei": "desmelindrar",
    "desmelindráveis": "desmelindrar",
    "desmembra": "desmembrar",
    "desmembrada": "desmembrar",
    "desmembradas": "desmembrar",
    "desmembrado": "desmembrar",
    "desmembradora": "desmembrador",
    "desmembradoras": "desmembrador",
    "desmembradores": "desmembrador",
    "desmembrados": "desmembrar",
    "desmembrai": "desmembrar",
    "desmembrais": "desmembrar",
    "desmembram": "desmembrar",
    "desmembramentos": "desmembramento",
    "desmembramo": "desmembrar",
    "desmembramos": "desmembrar",
    "desmembrando": "desmembrar",
    "desmembrara": "desmembrar",
    "desmembraram": "desmembrar",
    "desmembraras": "desmembrar",
    "desmembrarde": "desmembrar",
    "desmembrardes": "desmembrar",
    "desmembrare": "desmembrar",
    "desmembrarei": "desmembrar",
    "desmembrareis": "desmembrar",
    "desmembrarem": "desmembrar",
    "desmembraremos": "desmembrar",
    "desmembrares": "desmembrar",
    "desmembraria": "desmembrar",
    "desmembrariam": "desmembrar",
    "desmembrarias": "desmembrar",
    "desmembrarmo": "desmembrar",
    "desmembrarmos": "desmembrar",
    "desmembrará": "desmembrar",
    "desmembrarás": "desmembrar",
    "desmembrarão": "desmembrar",
    "desmembraríamos": "desmembrar",
    "desmembraríeis": "desmembrar",
    "desmembras": "desmembrar",
    "desmembrasse": "desmembrar",
    "desmembrassem": "desmembrar",
    "desmembrasses": "desmembrar",
    "desmembraste": "desmembrar",
    "desmembrastes": "desmembrar",
    "desmembrava": "desmembrar",
    "desmembravam": "desmembrar",
    "desmembravas": "desmembrar",
    "desmembrações": "desmembração",
    "desmembre": "desmembrar",
    "desmembrei": "desmembrar",
    "desmembreis": "desmembrar",
    "desmembrem": "desmembrar",
    "desmembremo": "desmembrar",
    "desmembremos": "desmembrar",
    "desmembres": "desmembrar",
    "desmembro": "desmembrar",
    "desmembrou": "desmembrar",
    "desmembrá": "desmembrar",
    "desmembrámo": "desmembrar",
    "desmembrámos": "desmembrar",
    "desmembráramo": "desmembrar",
    "desmembráramos": "desmembrar",
    "desmembrárei": "desmembrar",
    "desmembráreis": "desmembrar",
    "desmembrásseis": "desmembrar",
    "desmembrássemos": "desmembrar",
    "desmembrávamo": "desmembrar",
    "desmembrávamos": "desmembrar",
    "desmembrávei": "desmembrar",
    "desmembráveis": "desmembrável",
    "desmemoria": "desmemoriar",
    "desmemoriada": "desmemoriar",
    "desmemoriadas": "desmemoriar",
    "desmemoriado": "desmemoriar",
    "desmemoriados": "desmemoriar",
    "desmemoriai": "desmemoriar",
    "desmemoriais": "desmemoriar",
    "desmemoriam": "desmemoriar",
    "desmemoriamo": "desmemoriar",
    "desmemoriamos": "desmemoriar",
    "desmemoriando": "desmemoriar",
    "desmemoriara": "desmemoriar",
    "desmemoriaram": "desmemoriar",
    "desmemoriaras": "desmemoriar",
    "desmemoriarde": "desmemoriar",
    "desmemoriardes": "desmemoriar",
    "desmemoriare": "desmemoriar",
    "desmemoriarei": "desmemoriar",
    "desmemoriareis": "desmemoriar",
    "desmemoriarem": "desmemoriar",
    "desmemoriaremos": "desmemoriar",
    "desmemoriares": "desmemoriar",
    "desmemoriaria": "desmemoriar",
    "desmemoriariam": "desmemoriar",
    "desmemoriarias": "desmemoriar",
    "desmemoriarmo": "desmemoriar",
    "desmemoriarmos": "desmemoriar",
    "desmemoriará": "desmemoriar",
    "desmemoriarás": "desmemoriar",
    "desmemoriarão": "desmemoriar",
    "desmemoriaríamos": "desmemoriar",
    "desmemoriaríeis": "desmemoriar",
    "desmemorias": "desmemoriar",
    "desmemoriasse": "desmemoriar",
    "desmemoriassem": "desmemoriar",
    "desmemoriasses": "desmemoriar",
    "desmemoriaste": "desmemoriar",
    "desmemoriastes": "desmemoriar",
    "desmemoriava": "desmemoriar",
    "desmemoriavam": "desmemoriar",
    "desmemoriavas": "desmemoriar",
    "desmemorie": "desmemoriar",
    "desmemoriei": "desmemoriar",
    "desmemorieis": "desmemoriar",
    "desmemoriem": "desmemoriar",
    "desmemoriemo": "desmemoriar",
    "desmemoriemos": "desmemoriar",
    "desmemories": "desmemoriar",
    "desmemorio": "desmemoriar",
    "desmemoriou": "desmemoriar",
    "desmemoriá": "desmemoriar",
    "desmemoriámo": "desmemoriar",
    "desmemoriámos": "desmemoriar",
    "desmemoriáramo": "desmemoriar",
    "desmemoriáramos": "desmemoriar",
    "desmemoriárei": "desmemoriar",
    "desmemoriáreis": "desmemoriar",
    "desmemoriásseis": "desmemoriar",
    "desmemoriássemos": "desmemoriar",
    "desmemoriávamo": "desmemoriar",
    "desmemoriávamos": "desmemoriar",
    "desmemoriávei": "desmemoriar",
    "desmemoriáveis": "desmemoriar",
    "desmemórias": "desmemória",
    "desmente": "desmentir",
    "desmentem": "desmentir",
    "desmentes": "desmentir",
    "desmenti": "desmentir",
    "desmentia": "desmentir",
    "desmentiam": "desmentir",
    "desmentias": "desmentir",
    "desmentida": "desmentir",
    "desmentidas": "desmentir",
    "desmentido": "desmentir",
    "desmentidora": "desmentidor",
    "desmentidoras": "desmentidor",
    "desmentidores": "desmentidor",
    "desmentidos": "desmentir",
    "desmentimo": "desmentir",
    "desmentimos": "desmentir",
    "desmentindo": "desmentir",
    "desmentira": "desmentir",
    "desmentiram": "desmentir",
    "desmentiras": "desmentir",
    "desmentirde": "desmentir",
    "desmentirdes": "desmentir",
    "desmentire": "desmentir",
    "desmentirei": "desmentir",
    "desmentireis": "desmentir",
    "desmentirem": "desmentir",
    "desmentiremos": "desmentir",
    "desmentires": "desmentir",
    "desmentiria": "desmentir",
    "desmentiriam": "desmentir",
    "desmentirias": "desmentir",
    "desmentirmo": "desmentir",
    "desmentirmos": "desmentir",
    "desmentirá": "desmentir",
    "desmentirás": "desmentir",
    "desmentirão": "desmentir",
    "desmentiríamos": "desmentir",
    "desmentiríeis": "desmentir",
    "desmentis": "desmentir",
    "desmentisse": "desmentir",
    "desmentissem": "desmentir",
    "desmentisses": "desmentir",
    "desmentiste": "desmentir",
    "desmentistes": "desmentir",
    "desmentiu": "desmentir",
    "desmentíamo": "desmentir",
    "desmentíamos": "desmentir",
    "desmentíei": "desmentir",
    "desmentíeis": "desmentir",
    "desmentíramo": "desmentir",
    "desmentíramos": "desmentir",
    "desmentírei": "desmentir",
    "desmentíreis": "desmentir",
    "desmentísseis": "desmentir",
    "desmentíssemos": "desmentir",
    "desmentíveis": "desmentível",
    "desmerece": "desmerecer",
    "desmerecedora": "desmerecedor",
    "desmerecedoras": "desmerecedor",
    "desmerecedores": "desmerecedor",
    "desmerecei": "desmerecer",
    "desmereceis": "desmerecer",
    "desmerecem": "desmerecer",
    "desmerecemo": "desmerecer",
    "desmerecemos": "desmerecer",
    "desmerecendo": "desmerecer",
    "desmerecera": "desmerecer",
    "desmereceram": "desmerecer",
    "desmereceras": "desmerecer",
    "desmerecerde": "desmerecer",
    "desmerecerdes": "desmerecer",
    "desmerecere": "desmerecer",
    "desmerecerei": "desmerecer",
    "desmerecereis": "desmerecer",
    "desmerecerem": "desmerecer",
    "desmereceremos": "desmerecer",
    "desmereceres": "desmerecer",
    "desmereceria": "desmerecer",
    "desmereceriam": "desmerecer",
    "desmerecerias": "desmerecer",
    "desmerecermo": "desmerecer",
    "desmerecermos": "desmerecer",
    "desmerecerá": "desmerecer",
    "desmerecerás": "desmerecer",
    "desmerecerão": "desmerecer",
    "desmereceríamos": "desmerecer",
    "desmereceríeis": "desmerecer",
    "desmereces": "desmerecer",
    "desmerecesse": "desmerecer",
    "desmerecessem": "desmerecer",
    "desmerecesses": "desmerecer",
    "desmereceste": "desmerecer",
    "desmerecestes": "desmerecer",
    "desmereceu": "desmerecer",
    "desmereci": "desmerecer",
    "desmerecia": "desmerecer",
    "desmereciam": "desmerecer",
    "desmerecias": "desmerecer",
    "desmerecida": "desmerecido",
    "desmerecidas": "desmerecido",
    "desmerecido": "desmerecer",
    "desmerecidos": "desmerecido",
    "desmerecimentos": "desmerecimento",
    "desmerecê": "desmerecer",
    "desmerecêramo": "desmerecer",
    "desmerecêramos": "desmerecer",
    "desmerecêrei": "desmerecer",
    "desmerecêreis": "desmerecer",
    "desmerecêsseis": "desmerecer",
    "desmerecêssemos": "desmerecer",
    "desmerecíamo": "desmerecer",
    "desmerecíamos": "desmerecer",
    "desmerecíei": "desmerecer",
    "desmerecíeis": "desmerecer",
    "desmereça": "desmerecer",
    "desmereçais": "desmerecer",
    "desmereçam": "desmerecer",
    "desmereçamo": "desmerecer",
    "desmereçamos": "desmerecer",
    "desmereças": "desmerecer",
    "desmereço": "desmerecer",
    "desmesura": "desmesurar",
    "desmesurada": "desmesurar",
    "desmesuradas": "desmesurar",
    "desmesurado": "desmesurar",
    "desmesurados": "desmesurar",
    "desmesurai": "desmesurar",
    "desmesurais": "desmesurar",
    "desmesuram": "desmesurar",
    "desmesuramo": "desmesurar",
    "desmesuramos": "desmesurar",
    "desmesurando": "desmesurar",
    "desmesurara": "desmesurar",
    "desmesuraram": "desmesurar",
    "desmesuraras": "desmesurar",
    "desmesurarde": "desmesurar",
    "desmesurardes": "desmesurar",
    "desmesurare": "desmesurar",
    "desmesurarei": "desmesurar",
    "desmesurareis": "desmesurar",
    "desmesurarem": "desmesurar",
    "desmesuraremos": "desmesurar",
    "desmesurares": "desmesurar",
    "desmesuraria": "desmesurar",
    "desmesurariam": "desmesurar",
    "desmesurarias": "desmesurar",
    "desmesurarmo": "desmesurar",
    "desmesurarmos": "desmesurar",
    "desmesurará": "desmesurar",
    "desmesurarás": "desmesurar",
    "desmesurarão": "desmesurar",
    "desmesuraríamos": "desmesurar",
    "desmesuraríeis": "desmesurar",
    "desmesuras": "desmesurar",
    "desmesurasse": "desmesurar",
    "desmesurassem": "desmesurar",
    "desmesurasses": "desmesurar",
    "desmesuraste": "desmesurar",
    "desmesurastes": "desmesurar",
    "desmesurava": "desmesurar",
    "desmesuravam": "desmesurar",
    "desmesuravas": "desmesurar",
    "desmesure": "desmesurar",
    "desmesurei": "desmesurar",
    "desmesureis": "desmesurar",
    "desmesurem": "desmesurar",
    "desmesuremo": "desmesurar",
    "desmesuremos": "desmesurar",
    "desmesures": "desmesurar",
    "desmesuro": "desmesurar",
    "desmesurou": "desmesurar",
    "desmesurá": "desmesurar",
    "desmesurámo": "desmesurar",
    "desmesurámos": "desmesurar",
    "desmesuráramo": "desmesurar",
    "desmesuráramos": "desmesurar",
    "desmesurárei": "desmesurar",
    "desmesuráreis": "desmesurar",
    "desmesurásseis": "desmesurar",
    "desmesurássemos": "desmesurar",
    "desmesurávamo": "desmesurar",
    "desmesurávamos": "desmesurar",
    "desmesurávei": "desmesurar",
    "desmesuráveis": "desmesurável",
    "desmidiáceas": "desmidiácea",
    "desmilitariza": "desmilitarizar",
    "desmilitarizada": "desmilitarizar",
    "desmilitarizadas": "desmilitarizar",
    "desmilitarizado": "desmilitarizar",
    "desmilitarizados": "desmilitarizar",
    "desmilitarizai": "desmilitarizar",
    "desmilitarizais": "desmilitarizar",
    "desmilitarizam": "desmilitarizar",
    "desmilitarizamo": "desmilitarizar",
    "desmilitarizamos": "desmilitarizar",
    "desmilitarizando": "desmilitarizar",
    "desmilitarizara": "desmilitarizar",
    "desmilitarizaram": "desmilitarizar",
    "desmilitarizaras": "desmilitarizar",
    "desmilitarizarde": "desmilitarizar",
    "desmilitarizardes": "desmilitarizar",
    "desmilitarizare": "desmilitarizar",
    "desmilitarizarei": "desmilitarizar",
    "desmilitarizareis": "desmilitarizar",
    "desmilitarizarem": "desmilitarizar",
    "desmilitarizaremos": "desmilitarizar",
    "desmilitarizares": "desmilitarizar",
    "desmilitarizaria": "desmilitarizar",
    "desmilitarizariam": "desmilitarizar",
    "desmilitarizarias": "desmilitarizar",
    "desmilitarizarmo": "desmilitarizar",
    "desmilitarizarmos": "desmilitarizar",
    "desmilitarizará": "desmilitarizar",
    "desmilitarizarás": "desmilitarizar",
    "desmilitarizarão": "desmilitarizar",
    "desmilitarizaríamos": "desmilitarizar",
    "desmilitarizaríeis": "desmilitarizar",
    "desmilitarizas": "desmilitarizar",
    "desmilitarizasse": "desmilitarizar",
    "desmilitarizassem": "desmilitarizar",
    "desmilitarizasses": "desmilitarizar",
    "desmilitarizaste": "desmilitarizar",
    "desmilitarizastes": "desmilitarizar",
    "desmilitarizava": "desmilitarizar",
    "desmilitarizavam": "desmilitarizar",
    "desmilitarizavas": "desmilitarizar",
    "desmilitarizações": "desmilitarização",
    "desmilitarize": "desmilitarizar",
    "desmilitarizei": "desmilitarizar",
    "desmilitarizeis": "desmilitarizar",
    "desmilitarizem": "desmilitarizar",
    "desmilitarizemo": "desmilitarizar",
    "desmilitarizemos": "desmilitarizar",
    "desmilitarizes": "desmilitarizar",
    "desmilitarizo": "desmilitarizar",
    "desmilitarizou": "desmilitarizar",
    "desmilitarizá": "desmilitarizar",
    "desmilitarizámo": "desmilitarizar",
    "desmilitarizámos": "desmilitarizar",
    "desmilitarizáramo": "desmilitarizar",
    "desmilitarizáramos": "desmilitarizar",
    "desmilitarizárei": "desmilitarizar",
    "desmilitarizáreis": "desmilitarizar",
    "desmilitarizásseis": "desmilitarizar",
    "desmilitarizássemos": "desmilitarizar",
    "desmilitarizávamo": "desmilitarizar",
    "desmilitarizávamos": "desmilitarizar",
    "desmilitarizávei": "desmilitarizar",
    "desmilitarizáveis": "desmilitarizável",
    "desminada": "desminado",
    "desminadas": "desminado",
    "desminados": "desminado",
    "desminagens": "desminagem",
    "desmineraliza": "desmineralizar",
    "desmineralizada": "desmineralizar",
    "desmineralizadas": "desmineralizar",
    "desmineralizado": "desmineralizar",
    "desmineralizados": "desmineralizar",
    "desmineralizai": "desmineralizar",
    "desmineralizais": "desmineralizar",
    "desmineralizam": "desmineralizar",
    "desmineralizamo": "desmineralizar",
    "desmineralizamos": "desmineralizar",
    "desmineralizando": "desmineralizar",
    "desmineralizara": "desmineralizar",
    "desmineralizaram": "desmineralizar",
    "desmineralizaras": "desmineralizar",
    "desmineralizarde": "desmineralizar",
    "desmineralizardes": "desmineralizar",
    "desmineralizare": "desmineralizar",
    "desmineralizarei": "desmineralizar",
    "desmineralizareis": "desmineralizar",
    "desmineralizarem": "desmineralizar",
    "desmineralizaremos": "desmineralizar",
    "desmineralizares": "desmineralizar",
    "desmineralizaria": "desmineralizar",
    "desmineralizariam": "desmineralizar",
    "desmineralizarias": "desmineralizar",
    "desmineralizarmo": "desmineralizar",
    "desmineralizarmos": "desmineralizar",
    "desmineralizará": "desmineralizar",
    "desmineralizarás": "desmineralizar",
    "desmineralizarão": "desmineralizar",
    "desmineralizaríamos": "desmineralizar",
    "desmineralizaríeis": "desmineralizar",
    "desmineralizas": "desmineralizar",
    "desmineralizasse": "desmineralizar",
    "desmineralizassem": "desmineralizar",
    "desmineralizasses": "desmineralizar",
    "desmineralizaste": "desmineralizar",
    "desmineralizastes": "desmineralizar",
    "desmineralizava": "desmineralizar",
    "desmineralizavam": "desmineralizar",
    "desmineralizavas": "desmineralizar",
    "desmineralizações": "desmineralização",
    "desmineralize": "desmineralizar",
    "desmineralizei": "desmineralizar",
    "desmineralizeis": "desmineralizar",
    "desmineralizem": "desmineralizar",
    "desmineralizemo": "desmineralizar",
    "desmineralizemos": "desmineralizar",
    "desmineralizes": "desmineralizar",
    "desmineralizo": "desmineralizar",
    "desmineralizou": "desmineralizar",
    "desmineralizá": "desmineralizar",
    "desmineralizámo": "desmineralizar",
    "desmineralizámos": "desmineralizar",
    "desmineralizáramo": "desmineralizar",
    "desmineralizáramos": "desmineralizar",
    "desmineralizárei": "desmineralizar",
    "desmineralizáreis": "desmineralizar",
    "desmineralizásseis": "desmineralizar",
    "desmineralizássemos": "desmineralizar",
    "desmineralizávamo": "desmineralizar",
    "desmineralizávamos": "desmineralizar",
    "desmineralizávei": "desmineralizar",
    "desmineralizáveis": "desmineralizar",
    "desminta": "desmentir",
    "desmintais": "desmentir",
    "desmintam": "desmentir",
    "desmintamo": "desmentir",
    "desmintamos": "desmentir",
    "desmintas": "desmentir",
    "desminto": "desmentir",
    "desmináveis": "desminável",
    "desmiola": "desmiolar",
    "desmiolada": "desmiolar",
    "desmioladas": "desmiolar",
    "desmiolado": "desmiolar",
    "desmiolados": "desmiolar",
    "desmiolai": "desmiolar",
    "desmiolais": "desmiolar",
    "desmiolam": "desmiolar",
    "desmiolamo": "desmiolar",
    "desmiolamos": "desmiolar",
    "desmiolando": "desmiolar",
    "desmiolara": "desmiolar",
    "desmiolaram": "desmiolar",
    "desmiolaras": "desmiolar",
    "desmiolarde": "desmiolar",
    "desmiolardes": "desmiolar",
    "desmiolare": "desmiolar",
    "desmiolarei": "desmiolar",
    "desmiolareis": "desmiolar",
    "desmiolarem": "desmiolar",
    "desmiolaremos": "desmiolar",
    "desmiolares": "desmiolar",
    "desmiolaria": "desmiolar",
    "desmiolariam": "desmiolar",
    "desmiolarias": "desmiolar",
    "desmiolarmo": "desmiolar",
    "desmiolarmos": "desmiolar",
    "desmiolará": "desmiolar",
    "desmiolarás": "desmiolar",
    "desmiolarão": "desmiolar",
    "desmiolaríamos": "desmiolar",
    "desmiolaríeis": "desmiolar",
    "desmiolas": "desmiolar",
    "desmiolasse": "desmiolar",
    "desmiolassem": "desmiolar",
    "desmiolasses": "desmiolar",
    "desmiolaste": "desmiolar",
    "desmiolastes": "desmiolar",
    "desmiolava": "desmiolar",
    "desmiolavam": "desmiolar",
    "desmiolavas": "desmiolar",
    "desmiole": "desmiolar",
    "desmiolei": "desmiolar",
    "desmioleis": "desmiolar",
    "desmiolem": "desmiolar",
    "desmiolemo": "desmiolar",
    "desmiolemos": "desmiolar",
    "desmioles": "desmiolar",
    "desmiolo": "desmiolar",
    "desmiolou": "desmiolar",
    "desmiolá": "desmiolar",
    "desmiolámo": "desmiolar",
    "desmiolámos": "desmiolar",
    "desmioláramo": "desmiolar",
    "desmioláramos": "desmiolar",
    "desmiolárei": "desmiolar",
    "desmioláreis": "desmiolar",
    "desmiolásseis": "desmiolar",
    "desmiolássemos": "desmiolar",
    "desmiolávamo": "desmiolar",
    "desmiolávamos": "desmiolar",
    "desmiolávei": "desmiolar",
    "desmioláveis": "desmiolar",
    "desmistifica": "desmistificar",
    "desmistificada": "desmistificar",
    "desmistificadas": "desmistificar",
    "desmistificado": "desmistificar",
    "desmistificadora": "desmistificador",
    "desmistificadoras": "desmistificador",
    "desmistificadores": "desmistificador",
    "desmistificados": "desmistificar",
    "desmistificai": "desmistificar",
    "desmistificais": "desmistificar",
    "desmistificam": "desmistificar",
    "desmistificamo": "desmistificar",
    "desmistificamos": "desmistificar",
    "desmistificando": "desmistificar",
    "desmistificara": "desmistificar",
    "desmistificaram": "desmistificar",
    "desmistificaras": "desmistificar",
    "desmistificarde": "desmistificar",
    "desmistificardes": "desmistificar",
    "desmistificare": "desmistificar",
    "desmistificarei": "desmistificar",
    "desmistificareis": "desmistificar",
    "desmistificarem": "desmistificar",
    "desmistificaremos": "desmistificar",
    "desmistificares": "desmistificar",
    "desmistificaria": "desmistificar",
    "desmistificariam": "desmistificar",
    "desmistificarias": "desmistificar",
    "desmistificarmo": "desmistificar",
    "desmistificarmos": "desmistificar",
    "desmistificará": "desmistificar",
    "desmistificarás": "desmistificar",
    "desmistificarão": "desmistificar",
    "desmistificaríamos": "desmistificar",
    "desmistificaríeis": "desmistificar",
    "desmistificas": "desmistificar",
    "desmistificasse": "desmistificar",
    "desmistificassem": "desmistificar",
    "desmistificasses": "desmistificar",
    "desmistificaste": "desmistificar",
    "desmistificastes": "desmistificar",
    "desmistificava": "desmistificar",
    "desmistificavam": "desmistificar",
    "desmistificavas": "desmistificar",
    "desmistificações": "desmistificação",
    "desmistifico": "desmistificar",
    "desmistificou": "desmistificar",
    "desmistificá": "desmistificar",
    "desmistificámo": "desmistificar",
    "desmistificámos": "desmistificar",
    "desmistificáramo": "desmistificar",
    "desmistificáramos": "desmistificar",
    "desmistificárei": "desmistificar",
    "desmistificáreis": "desmistificar",
    "desmistificásseis": "desmistificar",
    "desmistificássemos": "desmistificar",
    "desmistificávamo": "desmistificar",
    "desmistificávamos": "desmistificar",
    "desmistificávei": "desmistificar",
    "desmistificáveis": "desmistificável",
    "desmistifique": "desmistificar",
    "desmistifiquei": "desmistificar",
    "desmistifiqueis": "desmistificar",
    "desmistifiquem": "desmistificar",
    "desmistifiquemo": "desmistificar",
    "desmistifiquemos": "desmistificar",
    "desmistifiques": "desmistificar",
    "desmitifica": "desmitificar",
    "desmitificada": "desmitificar",
    "desmitificadas": "desmitificar",
    "desmitificado": "desmitificar",
    "desmitificados": "desmitificar",
    "desmitificai": "desmitificar",
    "desmitificais": "desmitificar",
    "desmitificam": "desmitificar",
    "desmitificamo": "desmitificar",
    "desmitificamos": "desmitificar",
    "desmitificando": "desmitificar",
    "desmitificara": "desmitificar",
    "desmitificaram": "desmitificar",
    "desmitificaras": "desmitificar",
    "desmitificarde": "desmitificar",
    "desmitificardes": "desmitificar",
    "desmitificare": "desmitificar",
    "desmitificarei": "desmitificar",
    "desmitificareis": "desmitificar",
    "desmitificarem": "desmitificar",
    "desmitificaremos": "desmitificar",
    "desmitificares": "desmitificar",
    "desmitificaria": "desmitificar",
    "desmitificariam": "desmitificar",
    "desmitificarias": "desmitificar",
    "desmitificarmo": "desmitificar",
    "desmitificarmos": "desmitificar",
    "desmitificará": "desmitificar",
    "desmitificarás": "desmitificar",
    "desmitificarão": "desmitificar",
    "desmitificaríamos": "desmitificar",
    "desmitificaríeis": "desmitificar",
    "desmitificas": "desmitificar",
    "desmitificasse": "desmitificar",
    "desmitificassem": "desmitificar",
    "desmitificasses": "desmitificar",
    "desmitificaste": "desmitificar",
    "desmitificastes": "desmitificar",
    "desmitificava": "desmitificar",
    "desmitificavam": "desmitificar",
    "desmitificavas": "desmitificar",
    "desmitificações": "desmitificação",
    "desmitifico": "desmitificar",
    "desmitificou": "desmitificar",
    "desmitificá": "desmitificar",
    "desmitificámo": "desmitificar",
    "desmitificámos": "desmitificar",
    "desmitificáramo": "desmitificar",
    "desmitificáramos": "desmitificar",
    "desmitificárei": "desmitificar",
    "desmitificáreis": "desmitificar",
    "desmitificásseis": "desmitificar",
    "desmitificássemos": "desmitificar",
    "desmitificávamo": "desmitificar",
    "desmitificávamos": "desmitificar",
    "desmitificávei": "desmitificar",
    "desmitificáveis": "desmitificável",
    "desmitifique": "desmitificar",
    "desmitifiquei": "desmitificar",
    "desmitifiqueis": "desmitificar",
    "desmitifiquem": "desmitificar",
    "desmitifiquemo": "desmitificar",
    "desmitifiquemos": "desmitificar",
    "desmitifiques": "desmitificar",
    "desmiudada": "desmiudar",
    "desmiudadas": "desmiudar",
    "desmiudado": "desmiudar",
    "desmiudados": "desmiudar",
    "desmiudai": "desmiudar",
    "desmiudais": "desmiudar",
    "desmiudamo": "desmiudar",
    "desmiudamos": "desmiudar",
    "desmiudando": "desmiudar",
    "desmiudara": "desmiudar",
    "desmiudaram": "desmiudar",
    "desmiudaras": "desmiudar",
    "desmiudarde": "desmiudar",
    "desmiudardes": "desmiudar",
    "desmiudare": "desmiudar",
    "desmiudarei": "desmiudar",
    "desmiudareis": "desmiudar",
    "desmiudarem": "desmiudar",
    "desmiudaremos": "desmiudar",
    "desmiudares": "desmiudar",
    "desmiudaria": "desmiudar",
    "desmiudariam": "desmiudar",
    "desmiudarias": "desmiudar",
    "desmiudarmo": "desmiudar",
    "desmiudarmos": "desmiudar",
    "desmiudará": "desmiudar",
    "desmiudarás": "desmiudar",
    "desmiudarão": "desmiudar",
    "desmiudaríamos": "desmiudar",
    "desmiudaríeis": "desmiudar",
    "desmiudasse": "desmiudar",
    "desmiudassem": "desmiudar",
    "desmiudasses": "desmiudar",
    "desmiudaste": "desmiudar",
    "desmiudastes": "desmiudar",
    "desmiudava": "desmiudar",
    "desmiudavam": "desmiudar",
    "desmiudavas": "desmiudar",
    "desmiudei": "desmiudar",
    "desmiudeis": "desmiudar",
    "desmiudemo": "desmiudar",
    "desmiudemos": "desmiudar",
    "desmiudou": "desmiudar",
    "desmiudá": "desmiudar",
    "desmiudámo": "desmiudar",
    "desmiudámos": "desmiudar",
    "desmiudáramo": "desmiudar",
    "desmiudáramos": "desmiudar",
    "desmiudárei": "desmiudar",
    "desmiudáreis": "desmiudar",
    "desmiudásseis": "desmiudar",
    "desmiudássemos": "desmiudar",
    "desmiudávamo": "desmiudar",
    "desmiudávamos": "desmiudar",
    "desmiudávei": "desmiudar",
    "desmiudáveis": "desmiudar",
    "desmiúda": "desmiudar",
    "desmiúdam": "desmiudar",
    "desmiúdas": "desmiudar",
    "desmiúde": "desmiudar",
    "desmiúdem": "desmiudar",
    "desmiúdes": "desmiudar",
    "desmiúdo": "desmiudar",
    "desmobila": "desmobilar",
    "desmobilada": "desmobilar",
    "desmobiladas": "desmobilar",
    "desmobilado": "desmobilar",
    "desmobilados": "desmobilar",
    "desmobilai": "desmobilar",
    "desmobilais": "desmobilar",
    "desmobilam": "desmobilar",
    "desmobilamo": "desmobilar",
    "desmobilamos": "desmobilar",
    "desmobilando": "desmobilar",
    "desmobilara": "desmobilar",
    "desmobilaram": "desmobilar",
    "desmobilaras": "desmobilar",
    "desmobilarde": "desmobilar",
    "desmobilardes": "desmobilar",
    "desmobilare": "desmobilar",
    "desmobilarei": "desmobilar",
    "desmobilareis": "desmobilar",
    "desmobilarem": "desmobilar",
    "desmobilaremos": "desmobilar",
    "desmobilares": "desmobilar",
    "desmobilaria": "desmobilar",
    "desmobilariam": "desmobilar",
    "desmobilarias": "desmobilar",
    "desmobilarmo": "desmobilar",
    "desmobilarmos": "desmobilar",
    "desmobilará": "desmobilar",
    "desmobilarás": "desmobilar",
    "desmobilarão": "desmobilar",
    "desmobilaríamos": "desmobilar",
    "desmobilaríeis": "desmobilar",
    "desmobilas": "desmobilar",
    "desmobilasse": "desmobilar",
    "desmobilassem": "desmobilar",
    "desmobilasses": "desmobilar",
    "desmobilaste": "desmobilar",
    "desmobilastes": "desmobilar",
    "desmobilava": "desmobilar",
    "desmobilavam": "desmobilar",
    "desmobilavas": "desmobilar",
    "desmobile": "desmobilar",
    "desmobilei": "desmobilar",
    "desmobileis": "desmobilar",
    "desmobilem": "desmobilar",
    "desmobilemo": "desmobilar",
    "desmobilemos": "desmobilar",
    "desmobiles": "desmobilar",
    "desmobiliza": "desmobilizar",
    "desmobilizada": "desmobilizar",
    "desmobilizadas": "desmobilizar",
    "desmobilizado": "desmobilizar",
    "desmobilizadora": "desmobilizador",
    "desmobilizadoras": "desmobilizador",
    "desmobilizadores": "desmobilizador",
    "desmobilizados": "desmobilizar",
    "desmobilizai": "desmobilizar",
    "desmobilizais": "desmobilizar",
    "desmobilizam": "desmobilizar",
    "desmobilizamo": "desmobilizar",
    "desmobilizamos": "desmobilizar",
    "desmobilizando": "desmobilizar",
    "desmobilizara": "desmobilizar",
    "desmobilizaram": "desmobilizar",
    "desmobilizaras": "desmobilizar",
    "desmobilizarde": "desmobilizar",
    "desmobilizardes": "desmobilizar",
    "desmobilizare": "desmobilizar",
    "desmobilizarei": "desmobilizar",
    "desmobilizareis": "desmobilizar",
    "desmobilizarem": "desmobilizar",
    "desmobilizaremos": "desmobilizar",
    "desmobilizares": "desmobilizar",
    "desmobilizaria": "desmobilizar",
    "desmobilizariam": "desmobilizar",
    "desmobilizarias": "desmobilizar",
    "desmobilizarmo": "desmobilizar",
    "desmobilizarmos": "desmobilizar",
    "desmobilizará": "desmobilizar",
    "desmobilizarás": "desmobilizar",
    "desmobilizarão": "desmobilizar",
    "desmobilizaríamos": "desmobilizar",
    "desmobilizaríeis": "desmobilizar",
    "desmobilizas": "desmobilizar",
    "desmobilizasse": "desmobilizar",
    "desmobilizassem": "desmobilizar",
    "desmobilizasses": "desmobilizar",
    "desmobilizaste": "desmobilizar",
    "desmobilizastes": "desmobilizar",
    "desmobilizava": "desmobilizar",
    "desmobilizavam": "desmobilizar",
    "desmobilizavas": "desmobilizar",
    "desmobilizações": "desmobilização",
    "desmobilize": "desmobilizar",
    "desmobilizei": "desmobilizar",
    "desmobilizeis": "desmobilizar",
    "desmobilizem": "desmobilizar",
    "desmobilizemo": "desmobilizar",
    "desmobilizemos": "desmobilizar",
    "desmobilizes": "desmobilizar",
    "desmobilizo": "desmobilizar",
    "desmobilizou": "desmobilizar",
    "desmobilizá": "desmobilizar",
    "desmobilizámo": "desmobilizar",
    "desmobilizámos": "desmobilizar",
    "desmobilizáramo": "desmobilizar",
    "desmobilizáramos": "desmobilizar",
    "desmobilizárei": "desmobilizar",
    "desmobilizáreis": "desmobilizar",
    "desmobilizásseis": "desmobilizar",
    "desmobilizássemos": "desmobilizar",
    "desmobilizávamo": "desmobilizar",
    "desmobilizávamos": "desmobilizar",
    "desmobilizávei": "desmobilizar",
    "desmobilizáveis": "desmobilizável",
    "desmobilo": "desmobilar",
    "desmobilou": "desmobilar",
    "desmobilá": "desmobilar",
    "desmobilámo": "desmobilar",
    "desmobilámos": "desmobilar",
    "desmobiláramo": "desmobilar",
    "desmobiláramos": "desmobilar",
    "desmobilárei": "desmobilar",
    "desmobiláreis": "desmobilar",
    "desmobilásseis": "desmobilar",
    "desmobilássemos": "desmobilar",
    "desmobilávamo": "desmobilar",
    "desmobilávamos": "desmobilar",
    "desmobilávei": "desmobilar",
    "desmobiláveis": "desmobilar",
    "desmocha": "desmochar",
    "desmochada": "desmochar",
    "desmochadas": "desmochar",
    "desmochado": "desmochar",
    "desmochados": "desmochar",
    "desmochai": "desmochar",
    "desmochais": "desmochar",
    "desmocham": "desmochar",
    "desmochamo": "desmochar",
    "desmochamos": "desmochar",
    "desmochando": "desmochar",
    "desmochara": "desmochar",
    "desmocharam": "desmochar",
    "desmocharas": "desmochar",
    "desmocharde": "desmochar",
    "desmochardes": "desmochar",
    "desmochare": "desmochar",
    "desmocharei": "desmochar",
    "desmochareis": "desmochar",
    "desmocharem": "desmochar",
    "desmocharemos": "desmochar",
    "desmochares": "desmochar",
    "desmocharia": "desmochar",
    "desmochariam": "desmochar",
    "desmocharias": "desmochar",
    "desmocharmo": "desmochar",
    "desmocharmos": "desmochar",
    "desmochará": "desmochar",
    "desmocharás": "desmochar",
    "desmocharão": "desmochar",
    "desmocharíamos": "desmochar",
    "desmocharíeis": "desmochar",
    "desmochas": "desmochar",
    "desmochasse": "desmochar",
    "desmochassem": "desmochar",
    "desmochasses": "desmochar",
    "desmochaste": "desmochar",
    "desmochastes": "desmochar",
    "desmochava": "desmochar",
    "desmochavam": "desmochar",
    "desmochavas": "desmochar",
    "desmoche": "desmochar",
    "desmochei": "desmochar",
    "desmocheis": "desmochar",
    "desmochem": "desmochar",
    "desmochemo": "desmochar",
    "desmochemos": "desmochar",
    "desmoches": "desmochar",
    "desmocho": "desmochar",
    "desmochou": "desmochar",
    "desmochá": "desmochar",
    "desmochámo": "desmochar",
    "desmochámos": "desmochar",
    "desmocháramo": "desmochar",
    "desmocháramos": "desmochar",
    "desmochárei": "desmochar",
    "desmocháreis": "desmochar",
    "desmochásseis": "desmochar",
    "desmochássemos": "desmochar",
    "desmochávamo": "desmochar",
    "desmochávamos": "desmochar",
    "desmochávei": "desmochar",
    "desmocháveis": "desmochar",
    "desmodada": "desmodado",
    "desmodadas": "desmodado",
    "desmodados": "desmodado",
    "desmodas": "desmoda",
    "desmodera": "desmoderar",
    "desmoderada": "desmoderar",
    "desmoderadas": "desmoderar",
    "desmoderado": "desmoderar",
    "desmoderados": "desmoderar",
    "desmoderai": "desmoderar",
    "desmoderais": "desmoderar",
    "desmoderam": "desmoderar",
    "desmoderamo": "desmoderar",
    "desmoderamos": "desmoderar",
    "desmoderando": "desmoderar",
    "desmoderara": "desmoderar",
    "desmoderaram": "desmoderar",
    "desmoderaras": "desmoderar",
    "desmoderarde": "desmoderar",
    "desmoderardes": "desmoderar",
    "desmoderare": "desmoderar",
    "desmoderarei": "desmoderar",
    "desmoderareis": "desmoderar",
    "desmoderarem": "desmoderar",
    "desmoderaremos": "desmoderar",
    "desmoderares": "desmoderar",
    "desmoderaria": "desmoderar",
    "desmoderariam": "desmoderar",
    "desmoderarias": "desmoderar",
    "desmoderarmo": "desmoderar",
    "desmoderarmos": "desmoderar",
    "desmoderará": "desmoderar",
    "desmoderarás": "desmoderar",
    "desmoderarão": "desmoderar",
    "desmoderaríamos": "desmoderar",
    "desmoderaríeis": "desmoderar",
    "desmoderas": "desmoderar",
    "desmoderasse": "desmoderar",
    "desmoderassem": "desmoderar",
    "desmoderasses": "desmoderar",
    "desmoderaste": "desmoderar",
    "desmoderastes": "desmoderar",
    "desmoderava": "desmoderar",
    "desmoderavam": "desmoderar",
    "desmoderavas": "desmoderar",
    "desmodere": "desmoderar",
    "desmoderei": "desmoderar",
    "desmodereis": "desmoderar",
    "desmoderem": "desmoderar",
    "desmoderemo": "desmoderar",
    "desmoderemos": "desmoderar",
    "desmoderes": "desmoderar",
    "desmodero": "desmoderar",
    "desmoderou": "desmoderar",
    "desmoderá": "desmoderar",
    "desmoderámo": "desmoderar",
    "desmoderámos": "desmoderar",
    "desmoderáramo": "desmoderar",
    "desmoderáramos": "desmoderar",
    "desmoderárei": "desmoderar",
    "desmoderáreis": "desmoderar",
    "desmoderásseis": "desmoderar",
    "desmoderássemos": "desmoderar",
    "desmoderávamo": "desmoderar",
    "desmoderávamos": "desmoderar",
    "desmoderávei": "desmoderar",
    "desmoderáveis": "desmoderar",
    "desmoita": "desmoitar",
    "desmoitada": "desmoitar",
    "desmoitadas": "desmoitar",
    "desmoitado": "desmoitar",
    "desmoitadora": "desmoitador",
    "desmoitadoras": "desmoitador",
    "desmoitadores": "desmoitador",
    "desmoitados": "desmoitar",
    "desmoitai": "desmoitar",
    "desmoitais": "desmoitar",
    "desmoitam": "desmoitar",
    "desmoitamo": "desmoitar",
    "desmoitamos": "desmoitar",
    "desmoitando": "desmoitar",
    "desmoitara": "desmoitar",
    "desmoitaram": "desmoitar",
    "desmoitaras": "desmoitar",
    "desmoitarde": "desmoitar",
    "desmoitardes": "desmoitar",
    "desmoitare": "desmoitar",
    "desmoitarei": "desmoitar",
    "desmoitareis": "desmoitar",
    "desmoitarem": "desmoitar",
    "desmoitaremos": "desmoitar",
    "desmoitares": "desmoitar",
    "desmoitaria": "desmoitar",
    "desmoitariam": "desmoitar",
    "desmoitarias": "desmoitar",
    "desmoitarmo": "desmoitar",
    "desmoitarmos": "desmoitar",
    "desmoitará": "desmoitar",
    "desmoitarás": "desmoitar",
    "desmoitarão": "desmoitar",
    "desmoitaríamos": "desmoitar",
    "desmoitaríeis": "desmoitar",
    "desmoitas": "desmoitar",
    "desmoitasse": "desmoitar",
    "desmoitassem": "desmoitar",
    "desmoitasses": "desmoitar",
    "desmoitaste": "desmoitar",
    "desmoitastes": "desmoitar",
    "desmoitava": "desmoitar",
    "desmoitavam": "desmoitar",
    "desmoitavas": "desmoitar",
    "desmoite": "desmoitar",
    "desmoitei": "desmoitar",
    "desmoiteis": "desmoitar",
    "desmoitem": "desmoitar",
    "desmoitemo": "desmoitar",
    "desmoitemos": "desmoitar",
    "desmoites": "desmoitar",
    "desmoito": "desmoitar",
    "desmoitou": "desmoitar",
    "desmoitá": "desmoitar",
    "desmoitámo": "desmoitar",
    "desmoitámos": "desmoitar",
    "desmoitáramo": "desmoitar",
    "desmoitáramos": "desmoitar",
    "desmoitárei": "desmoitar",
    "desmoitáreis": "desmoitar",
    "desmoitásseis": "desmoitar",
    "desmoitássemos": "desmoitar",
    "desmoitávamo": "desmoitar",
    "desmoitávamos": "desmoitar",
    "desmoitávei": "desmoitar",
    "desmoitáveis": "desmoitar",
    "desmolda": "desmoldar",
    "desmoldada": "desmoldar",
    "desmoldadas": "desmoldar",
    "desmoldado": "desmoldar",
    "desmoldados": "desmoldar",
    "desmoldagens": "desmoldagem",
    "desmoldai": "desmoldar",
    "desmoldais": "desmoldar",
    "desmoldam": "desmoldar",
    "desmoldamo": "desmoldar",
    "desmoldamos": "desmoldar",
    "desmoldando": "desmoldar",
    "desmoldara": "desmoldar",
    "desmoldaram": "desmoldar",
    "desmoldaras": "desmoldar",
    "desmoldarde": "desmoldar",
    "desmoldardes": "desmoldar",
    "desmoldare": "desmoldar",
    "desmoldarei": "desmoldar",
    "desmoldareis": "desmoldar",
    "desmoldarem": "desmoldar",
    "desmoldaremos": "desmoldar",
    "desmoldares": "desmoldar",
    "desmoldaria": "desmoldar",
    "desmoldariam": "desmoldar",
    "desmoldarias": "desmoldar",
    "desmoldarmo": "desmoldar",
    "desmoldarmos": "desmoldar",
    "desmoldará": "desmoldar",
    "desmoldarás": "desmoldar",
    "desmoldarão": "desmoldar",
    "desmoldaríamos": "desmoldar",
    "desmoldaríeis": "desmoldar",
    "desmoldas": "desmoldar",
    "desmoldasse": "desmoldar",
    "desmoldassem": "desmoldar",
    "desmoldasses": "desmoldar",
    "desmoldaste": "desmoldar",
    "desmoldastes": "desmoldar",
    "desmoldava": "desmoldar",
    "desmoldavam": "desmoldar",
    "desmoldavas": "desmoldar",
    "desmolde": "desmoldar",
    "desmoldei": "desmoldar",
    "desmoldeis": "desmoldar",
    "desmoldem": "desmoldar",
    "desmoldemo": "desmoldar",
    "desmoldemos": "desmoldar",
    "desmoldes": "desmoldar",
    "desmoldo": "desmoldar",
    "desmoldou": "desmoldar",
    "desmoldá": "desmoldar",
    "desmoldámo": "desmoldar",
    "desmoldámos": "desmoldar",
    "desmoldáramo": "desmoldar",
    "desmoldáramos": "desmoldar",
    "desmoldárei": "desmoldar",
    "desmoldáreis": "desmoldar",
    "desmoldásseis": "desmoldar",
    "desmoldássemos": "desmoldar",
    "desmoldávamo": "desmoldar",
    "desmoldávamos": "desmoldar",
    "desmoldávei": "desmoldar",
    "desmoldáveis": "desmoldar",
    "desmonetiza": "desmonetizar",
    "desmonetizada": "desmonetizar",
    "desmonetizadas": "desmonetizar",
    "desmonetizado": "desmonetizar",
    "desmonetizados": "desmonetizar",
    "desmonetizai": "desmonetizar",
    "desmonetizais": "desmonetizar",
    "desmonetizam": "desmonetizar",
    "desmonetizamo": "desmonetizar",
    "desmonetizamos": "desmonetizar",
    "desmonetizando": "desmonetizar",
    "desmonetizara": "desmonetizar",
    "desmonetizaram": "desmonetizar",
    "desmonetizaras": "desmonetizar",
    "desmonetizarde": "desmonetizar",
    "desmonetizardes": "desmonetizar",
    "desmonetizare": "desmonetizar",
    "desmonetizarei": "desmonetizar",
    "desmonetizareis": "desmonetizar",
    "desmonetizarem": "desmonetizar",
    "desmonetizaremos": "desmonetizar",
    "desmonetizares": "desmonetizar",
    "desmonetizaria": "desmonetizar",
    "desmonetizariam": "desmonetizar",
    "desmonetizarias": "desmonetizar",
    "desmonetizarmo": "desmonetizar",
    "desmonetizarmos": "desmonetizar",
    "desmonetizará": "desmonetizar",
    "desmonetizarás": "desmonetizar",
    "desmonetizarão": "desmonetizar",
    "desmonetizaríamos": "desmonetizar",
    "desmonetizaríeis": "desmonetizar",
    "desmonetizas": "desmonetizar",
    "desmonetizasse": "desmonetizar",
    "desmonetizassem": "desmonetizar",
    "desmonetizasses": "desmonetizar",
    "desmonetizaste": "desmonetizar",
    "desmonetizastes": "desmonetizar",
    "desmonetizava": "desmonetizar",
    "desmonetizavam": "desmonetizar",
    "desmonetizavas": "desmonetizar",
    "desmonetizações": "desmonetização",
    "desmonetize": "desmonetizar",
    "desmonetizei": "desmonetizar",
    "desmonetizeis": "desmonetizar",
    "desmonetizem": "desmonetizar",
    "desmonetizemo": "desmonetizar",
    "desmonetizemos": "desmonetizar",
    "desmonetizes": "desmonetizar",
    "desmonetizo": "desmonetizar",
    "desmonetizou": "desmonetizar",
    "desmonetizá": "desmonetizar",
    "desmonetizámo": "desmonetizar",
    "desmonetizámos": "desmonetizar",
    "desmonetizáramo": "desmonetizar",
    "desmonetizáramos": "desmonetizar",
    "desmonetizárei": "desmonetizar",
    "desmonetizáreis": "desmonetizar",
    "desmonetizásseis": "desmonetizar",
    "desmonetizássemos": "desmonetizar",
    "desmonetizávamo": "desmonetizar",
    "desmonetizávamos": "desmonetizar",
    "desmonetizávei": "desmonetizar",
    "desmonetizáveis": "desmonetizar",
    "desmonopoliza": "desmonopolizar",
    "desmonopolizada": "desmonopolizar",
    "desmonopolizadas": "desmonopolizar",
    "desmonopolizado": "desmonopolizar",
    "desmonopolizados": "desmonopolizar",
    "desmonopolizai": "desmonopolizar",
    "desmonopolizais": "desmonopolizar",
    "desmonopolizam": "desmonopolizar",
    "desmonopolizamo": "desmonopolizar",
    "desmonopolizamos": "desmonopolizar",
    "desmonopolizando": "desmonopolizar",
    "desmonopolizara": "desmonopolizar",
    "desmonopolizaram": "desmonopolizar",
    "desmonopolizaras": "desmonopolizar",
    "desmonopolizarde": "desmonopolizar",
    "desmonopolizardes": "desmonopolizar",
    "desmonopolizare": "desmonopolizar",
    "desmonopolizarei": "desmonopolizar",
    "desmonopolizareis": "desmonopolizar",
    "desmonopolizarem": "desmonopolizar",
    "desmonopolizaremos": "desmonopolizar",
    "desmonopolizares": "desmonopolizar",
    "desmonopolizaria": "desmonopolizar",
    "desmonopolizariam": "desmonopolizar",
    "desmonopolizarias": "desmonopolizar",
    "desmonopolizarmo": "desmonopolizar",
    "desmonopolizarmos": "desmonopolizar",
    "desmonopolizará": "desmonopolizar",
    "desmonopolizarás": "desmonopolizar",
    "desmonopolizarão": "desmonopolizar",
    "desmonopolizaríamos": "desmonopolizar",
    "desmonopolizaríeis": "desmonopolizar",
    "desmonopolizas": "desmonopolizar",
    "desmonopolizasse": "desmonopolizar",
    "desmonopolizassem": "desmonopolizar",
    "desmonopolizasses": "desmonopolizar",
    "desmonopolizaste": "desmonopolizar",
    "desmonopolizastes": "desmonopolizar",
    "desmonopolizava": "desmonopolizar",
    "desmonopolizavam": "desmonopolizar",
    "desmonopolizavas": "desmonopolizar",
    "desmonopolizações": "desmonopolização",
    "desmonopolize": "desmonopolizar",
    "desmonopolizei": "desmonopolizar",
    "desmonopolizeis": "desmonopolizar",
    "desmonopolizem": "desmonopolizar",
    "desmonopolizemo": "desmonopolizar",
    "desmonopolizemos": "desmonopolizar",
    "desmonopolizes": "desmonopolizar",
    "desmonopolizo": "desmonopolizar",
    "desmonopolizou": "desmonopolizar",
    "desmonopolizá": "desmonopolizar",
    "desmonopolizámo": "desmonopolizar",
    "desmonopolizámos": "desmonopolizar",
    "desmonopolizáramo": "desmonopolizar",
    "desmonopolizáramos": "desmonopolizar",
    "desmonopolizárei": "desmonopolizar",
    "desmonopolizáreis": "desmonopolizar",
    "desmonopolizásseis": "desmonopolizar",
    "desmonopolizássemos": "desmonopolizar",
    "desmonopolizávamo": "desmonopolizar",
    "desmonopolizávamos": "desmonopolizar",
    "desmonopolizávei": "desmonopolizar",
    "desmonopolizáveis": "desmonopolizar",
    "desmonta": "desmontar",
    "desmontada": "desmontar",
    "desmontadas": "desmontar",
    "desmontado": "desmontar",
    "desmontados": "desmontar",
    "desmontagens": "desmontagem",
    "desmontai": "desmontar",
    "desmontais": "desmontar",
    "desmontam": "desmontar",
    "desmontamo": "desmontar",
    "desmontamos": "desmontar",
    "desmontando": "desmontar",
    "desmontara": "desmontar",
    "desmontaram": "desmontar",
    "desmontaras": "desmontar",
    "desmontarde": "desmontar",
    "desmontardes": "desmontar",
    "desmontare": "desmontar",
    "desmontarei": "desmontar",
    "desmontareis": "desmontar",
    "desmontarem": "desmontar",
    "desmontaremos": "desmontar",
    "desmontares": "desmontar",
    "desmontaria": "desmontar",
    "desmontariam": "desmontar",
    "desmontarias": "desmontar",
    "desmontarmo": "desmontar",
    "desmontarmos": "desmontar",
    "desmontará": "desmontar",
    "desmontarás": "desmontar",
    "desmontarão": "desmontar",
    "desmontaríamos": "desmontar",
    "desmontaríeis": "desmontar",
    "desmontas": "desmontar",
    "desmontasse": "desmontar",
    "desmontassem": "desmontar",
    "desmontasses": "desmontar",
    "desmontaste": "desmontar",
    "desmontastes": "desmontar",
    "desmontava": "desmontar",
    "desmontavam": "desmontar",
    "desmontavas": "desmontar",
    "desmonte": "desmontar",
    "desmontei": "desmontar",
    "desmonteis": "desmontar",
    "desmontem": "desmontar",
    "desmontemo": "desmontar",
    "desmontemos": "desmontar",
    "desmontes": "desmonte",
    "desmonto": "desmontar",
    "desmontou": "desmontar",
    "desmontá": "desmontar",
    "desmontámo": "desmontar",
    "desmontámos": "desmontar",
    "desmontáramo": "desmontar",
    "desmontáramos": "desmontar",
    "desmontárei": "desmontar",
    "desmontáreis": "desmontar",
    "desmontásseis": "desmontar",
    "desmontássemos": "desmontar",
    "desmontávamo": "desmontar",
    "desmontávamos": "desmontar",
    "desmontávei": "desmontar",
    "desmontáveis": "desmontável",
    "desmoraliza": "desmoralizar",
    "desmoralizada": "desmoralizar",
    "desmoralizadas": "desmoralizar",
    "desmoralizado": "desmoralizar",
    "desmoralizadora": "desmoralizador",
    "desmoralizadoras": "desmoralizador",
    "desmoralizadores": "desmoralizador",
    "desmoralizados": "desmoralizar",
    "desmoralizadíssima": "desmoralizado",
    "desmoralizadíssimas": "desmoralizado",
    "desmoralizadíssimo": "desmoralizado",
    "desmoralizadíssimos": "desmoralizado",
    "desmoralizai": "desmoralizar",
    "desmoralizais": "desmoralizar",
    "desmoralizam": "desmoralizar",
    "desmoralizamo": "desmoralizar",
    "desmoralizamos": "desmoralizar",
    "desmoralizando": "desmoralizar",
    "desmoralizara": "desmoralizar",
    "desmoralizaram": "desmoralizar",
    "desmoralizaras": "desmoralizar",
    "desmoralizarde": "desmoralizar",
    "desmoralizardes": "desmoralizar",
    "desmoralizare": "desmoralizar",
    "desmoralizarei": "desmoralizar",
    "desmoralizareis": "desmoralizar",
    "desmoralizarem": "desmoralizar",
    "desmoralizaremos": "desmoralizar",
    "desmoralizares": "desmoralizar",
    "desmoralizaria": "desmoralizar",
    "desmoralizariam": "desmoralizar",
    "desmoralizarias": "desmoralizar",
    "desmoralizarmo": "desmoralizar",
    "desmoralizarmos": "desmoralizar",
    "desmoralizará": "desmoralizar",
    "desmoralizarás": "desmoralizar",
    "desmoralizarão": "desmoralizar",
    "desmoralizaríamos": "desmoralizar",
    "desmoralizaríeis": "desmoralizar",
    "desmoralizas": "desmoralizar",
    "desmoralizasse": "desmoralizar",
    "desmoralizassem": "desmoralizar",
    "desmoralizasses": "desmoralizar",
    "desmoralizaste": "desmoralizar",
    "desmoralizastes": "desmoralizar",
    "desmoralizava": "desmoralizar",
    "desmoralizavam": "desmoralizar",
    "desmoralizavas": "desmoralizar",
    "desmoralizações": "desmoralização",
    "desmoralize": "desmoralizar",
    "desmoralizei": "desmoralizar",
    "desmoralizeis": "desmoralizar",
    "desmoralizem": "desmoralizar",
    "desmoralizemo": "desmoralizar",
    "desmoralizemos": "desmoralizar",
    "desmoralizes": "desmoralizar",
    "desmoralizo": "desmoralizar",
    "desmoralizou": "desmoralizar",
    "desmoralizá": "desmoralizar",
    "desmoralizámo": "desmoralizar",
    "desmoralizámos": "desmoralizar",
    "desmoralizáramo": "desmoralizar",
    "desmoralizáramos": "desmoralizar",
    "desmoralizárei": "desmoralizar",
    "desmoralizáreis": "desmoralizar",
    "desmoralizásseis": "desmoralizar",
    "desmoralizássemos": "desmoralizar",
    "desmoralizávamo": "desmoralizar",
    "desmoralizávamos": "desmoralizar",
    "desmoralizávei": "desmoralizar",
    "desmoralizáveis": "desmoralizável",
    "desmorona": "desmoronar",
    "desmoronada": "desmoronar",
    "desmoronadas": "desmoronar",
    "desmoronadiça": "desmoronadiço",
    "desmoronadiças": "desmoronadiço",
    "desmoronadiços": "desmoronadiço",
    "desmoronado": "desmoronar",
    "desmoronados": "desmoronar",
    "desmoronai": "desmoronar",
    "desmoronais": "desmoronar",
    "desmoronam": "desmoronar",
    "desmoronamentos": "desmoronamento",
    "desmoronamo": "desmoronar",
    "desmoronamos": "desmoronar",
    "desmoronando": "desmoronar",
    "desmoronara": "desmoronar",
    "desmoronaram": "desmoronar",
    "desmoronaras": "desmoronar",
    "desmoronardes": "desmoronar",
    "desmoronarei": "desmoronar",
    "desmoronareis": "desmoronar",
    "desmoronarem": "desmoronar",
    "desmoronaremos": "desmoronar",
    "desmoronares": "desmoronar",
    "desmoronaria": "desmoronar",
    "desmoronariam": "desmoronar",
    "desmoronarias": "desmoronar",
    "desmoronarmo": "desmoronar",
    "desmoronarmos": "desmoronar",
    "desmoronará": "desmoronar",
    "desmoronarás": "desmoronar",
    "desmoronarão": "desmoronar",
    "desmoronaríamos": "desmoronar",
    "desmoronaríeis": "desmoronar",
    "desmoronas": "desmoronar",
    "desmoronasse": "desmoronar",
    "desmoronassem": "desmoronar",
    "desmoronasses": "desmoronar",
    "desmoronaste": "desmoronar",
    "desmoronastes": "desmoronar",
    "desmoronava": "desmoronar",
    "desmoronavam": "desmoronar",
    "desmoronavas": "desmoronar",
    "desmorone": "desmoronar",
    "desmoronei": "desmoronar",
    "desmoroneis": "desmoronar",
    "desmoronem": "desmoronar",
    "desmoronemo": "desmoronar",
    "desmoronemos": "desmoronar",
    "desmorones": "desmoronar",
    "desmorono": "desmoronar",
    "desmoronou": "desmoronar",
    "desmoronámo": "desmoronar",
    "desmoronámos": "desmoronar",
    "desmoronáramo": "desmoronar",
    "desmoronáramos": "desmoronar",
    "desmoronáreis": "desmoronar",
    "desmoronásseis": "desmoronar",
    "desmoronássemos": "desmoronar",
    "desmoronávamo": "desmoronar",
    "desmoronávamos": "desmoronar",
    "desmoronáveis": "desmoronar",
    "desmortificada": "desmortificado",
    "desmortificadas": "desmortificado",
    "desmortificados": "desmortificado",
    "desmotiva": "desmotivar",
    "desmotivada": "desmotivar",
    "desmotivadas": "desmotivar",
    "desmotivado": "desmotivar",
    "desmotivadora": "desmotivador",
    "desmotivadoras": "desmotivador",
    "desmotivadores": "desmotivador",
    "desmotivados": "desmotivar",
    "desmotivai": "desmotivar",
    "desmotivais": "desmotivar",
    "desmotivam": "desmotivar",
    "desmotivamo": "desmotivar",
    "desmotivamos": "desmotivar",
    "desmotivando": "desmotivar",
    "desmotivantes": "desmotivante",
    "desmotivara": "desmotivar",
    "desmotivaram": "desmotivar",
    "desmotivaras": "desmotivar",
    "desmotivarde": "desmotivar",
    "desmotivardes": "desmotivar",
    "desmotivare": "desmotivar",
    "desmotivarei": "desmotivar",
    "desmotivareis": "desmotivar",
    "desmotivarem": "desmotivar",
    "desmotivaremos": "desmotivar",
    "desmotivares": "desmotivar",
    "desmotivaria": "desmotivar",
    "desmotivariam": "desmotivar",
    "desmotivarias": "desmotivar",
    "desmotivarmo": "desmotivar",
    "desmotivarmos": "desmotivar",
    "desmotivará": "desmotivar",
    "desmotivarás": "desmotivar",
    "desmotivarão": "desmotivar",
    "desmotivaríamos": "desmotivar",
    "desmotivaríeis": "desmotivar",
    "desmotivas": "desmotivar",
    "desmotivasse": "desmotivar",
    "desmotivassem": "desmotivar",
    "desmotivasses": "desmotivar",
    "desmotivaste": "desmotivar",
    "desmotivastes": "desmotivar",
    "desmotivava": "desmotivar",
    "desmotivavam": "desmotivar",
    "desmotivavas": "desmotivar",
    "desmotivações": "desmotivação",
    "desmotive": "desmotivar",
    "desmotivei": "desmotivar",
    "desmotiveis": "desmotivar",
    "desmotivem": "desmotivar",
    "desmotivemo": "desmotivar",
    "desmotivemos": "desmotivar",
    "desmotives": "desmotivar",
    "desmotivo": "desmotivar",
    "desmotivou": "desmotivar",
    "desmotivá": "desmotivar",
    "desmotivámo": "desmotivar",
    "desmotivámos": "desmotivar",
    "desmotiváramo": "desmotivar",
    "desmotiváramos": "desmotivar",
    "desmotivárei": "desmotivar",
    "desmotiváreis": "desmotivar",
    "desmotivásseis": "desmotivar",
    "desmotivássemos": "desmotivar",
    "desmotivávamo": "desmotivar",
    "desmotivávamos": "desmotivar",
    "desmotivávei": "desmotivar",
    "desmotiváveis": "desmotivar",
    "desmoutas": "desmouta",
    "desmuda": "desmudar",
    "desmudada": "desmudar",
    "desmudadas": "desmudar",
    "desmudado": "desmudar",
    "desmudados": "desmudar",
    "desmudai": "desmudar",
    "desmudais": "desmudar",
    "desmudam": "desmudar",
    "desmudamo": "desmudar",
    "desmudamos": "desmudar",
    "desmudando": "desmudar",
    "desmudara": "desmudar",
    "desmudaram": "desmudar",
    "desmudaras": "desmudar",
    "desmudarde": "desmudar",
    "desmudardes": "desmudar",
    "desmudare": "desmudar",
    "desmudarei": "desmudar",
    "desmudareis": "desmudar",
    "desmudarem": "desmudar",
    "desmudaremos": "desmudar",
    "desmudares": "desmudar",
    "desmudaria": "desmudar",
    "desmudariam": "desmudar",
    "desmudarias": "desmudar",
    "desmudarmo": "desmudar",
    "desmudarmos": "desmudar",
    "desmudará": "desmudar",
    "desmudarás": "desmudar",
    "desmudarão": "desmudar",
    "desmudaríamos": "desmudar",
    "desmudaríeis": "desmudar",
    "desmudas": "desmudar",
    "desmudasse": "desmudar",
    "desmudassem": "desmudar",
    "desmudasses": "desmudar",
    "desmudaste": "desmudar",
    "desmudastes": "desmudar",
    "desmudava": "desmudar",
    "desmudavam": "desmudar",
    "desmudavas": "desmudar",
    "desmude": "desmudar",
    "desmudei": "desmudar",
    "desmudeis": "desmudar",
    "desmudem": "desmudar",
    "desmudemo": "desmudar",
    "desmudemos": "desmudar",
    "desmudes": "desmudar",
    "desmudo": "desmudar",
    "desmudou": "desmudar",
    "desmudá": "desmudar",
    "desmudámo": "desmudar",
    "desmudámos": "desmudar",
    "desmudáramo": "desmudar",
    "desmudáramos": "desmudar",
    "desmudárei": "desmudar",
    "desmudáreis": "desmudar",
    "desmudásseis": "desmudar",
    "desmudássemos": "desmudar",
    "desmudávamo": "desmudar",
    "desmudávamos": "desmudar",
    "desmudávei": "desmudar",
    "desmudáveis": "desmudar",
    "desmultiplica": "desmultiplicar",
    "desmultiplicada": "desmultiplicar",
    "desmultiplicadas": "desmultiplicar",
    "desmultiplicado": "desmultiplicar",
    "desmultiplicadora": "desmultiplicador",
    "desmultiplicadoras": "desmultiplicador",
    "desmultiplicadores": "desmultiplicador",
    "desmultiplicados": "desmultiplicar",
    "desmultiplicai": "desmultiplicar",
    "desmultiplicais": "desmultiplicar",
    "desmultiplicam": "desmultiplicar",
    "desmultiplicamo": "desmultiplicar",
    "desmultiplicamos": "desmultiplicar",
    "desmultiplicando": "desmultiplicar",
    "desmultiplicara": "desmultiplicar",
    "desmultiplicaram": "desmultiplicar",
    "desmultiplicaras": "desmultiplicar",
    "desmultiplicarde": "desmultiplicar",
    "desmultiplicardes": "desmultiplicar",
    "desmultiplicare": "desmultiplicar",
    "desmultiplicarei": "desmultiplicar",
    "desmultiplicareis": "desmultiplicar",
    "desmultiplicarem": "desmultiplicar",
    "desmultiplicaremos": "desmultiplicar",
    "desmultiplicares": "desmultiplicar",
    "desmultiplicaria": "desmultiplicar",
    "desmultiplicariam": "desmultiplicar",
    "desmultiplicarias": "desmultiplicar",
    "desmultiplicarmo": "desmultiplicar",
    "desmultiplicarmos": "desmultiplicar",
    "desmultiplicará": "desmultiplicar",
    "desmultiplicarás": "desmultiplicar",
    "desmultiplicarão": "desmultiplicar",
    "desmultiplicaríamos": "desmultiplicar",
    "desmultiplicaríeis": "desmultiplicar",
    "desmultiplicas": "desmultiplicar",
    "desmultiplicasse": "desmultiplicar",
    "desmultiplicassem": "desmultiplicar",
    "desmultiplicasses": "desmultiplicar",
    "desmultiplicaste": "desmultiplicar",
    "desmultiplicastes": "desmultiplicar",
    "desmultiplicava": "desmultiplicar",
    "desmultiplicavam": "desmultiplicar",
    "desmultiplicavas": "desmultiplicar",
    "desmultiplicações": "desmultiplicação",
    "desmultiplico": "desmultiplicar",
    "desmultiplicou": "desmultiplicar",
    "desmultiplicá": "desmultiplicar",
    "desmultiplicámo": "desmultiplicar",
    "desmultiplicámos": "desmultiplicar",
    "desmultiplicáramo": "desmultiplicar",
    "desmultiplicáramos": "desmultiplicar",
    "desmultiplicárei": "desmultiplicar",
    "desmultiplicáreis": "desmultiplicar",
    "desmultiplicásseis": "desmultiplicar",
    "desmultiplicássemos": "desmultiplicar",
    "desmultiplicávamo": "desmultiplicar",
    "desmultiplicávamos": "desmultiplicar",
    "desmultiplicávei": "desmultiplicar",
    "desmultiplicáveis": "desmultiplicar",
    "desmultiplique": "desmultiplicar",
    "desmultipliquei": "desmultiplicar",
    "desmultipliqueis": "desmultiplicar",
    "desmultipliquem": "desmultiplicar",
    "desmultipliquemo": "desmultiplicar",
    "desmultipliquemos": "desmultiplicar",
    "desmultipliques": "desmultiplicar",
    "desmunicia": "desmuniciar",
    "desmuniciada": "desmuniciar",
    "desmuniciadas": "desmuniciar",
    "desmuniciado": "desmuniciar",
    "desmuniciados": "desmuniciar",
    "desmuniciai": "desmuniciar",
    "desmuniciais": "desmuniciar",
    "desmuniciam": "desmuniciar",
    "desmuniciamo": "desmuniciar",
    "desmuniciamos": "desmuniciar",
    "desmuniciando": "desmuniciar",
    "desmuniciara": "desmuniciar",
    "desmuniciaram": "desmuniciar",
    "desmuniciaras": "desmuniciar",
    "desmuniciarde": "desmuniciar",
    "desmuniciardes": "desmuniciar",
    "desmuniciare": "desmuniciar",
    "desmuniciarei": "desmuniciar",
    "desmuniciareis": "desmuniciar",
    "desmuniciarem": "desmuniciar",
    "desmuniciaremos": "desmuniciar",
    "desmuniciares": "desmuniciar",
    "desmuniciaria": "desmuniciar",
    "desmuniciariam": "desmuniciar",
    "desmuniciarias": "desmuniciar",
    "desmuniciarmo": "desmuniciar",
    "desmuniciarmos": "desmuniciar",
    "desmuniciará": "desmuniciar",
    "desmuniciarás": "desmuniciar",
    "desmuniciarão": "desmuniciar",
    "desmuniciaríamos": "desmuniciar",
    "desmuniciaríeis": "desmuniciar",
    "desmunicias": "desmuniciar",
    "desmuniciasse": "desmuniciar",
    "desmuniciassem": "desmuniciar",
    "desmuniciasses": "desmuniciar",
    "desmuniciaste": "desmuniciar",
    "desmuniciastes": "desmuniciar",
    "desmuniciava": "desmuniciar",
    "desmuniciavam": "desmuniciar",
    "desmuniciavas": "desmuniciar",
    "desmunicie": "desmuniciar",
    "desmuniciei": "desmuniciar",
    "desmunicieis": "desmuniciar",
    "desmuniciem": "desmuniciar",
    "desmuniciemo": "desmuniciar",
    "desmuniciemos": "desmuniciar",
    "desmunicies": "desmuniciar",
    "desmunicio": "desmuniciar",
    "desmuniciona": "desmunicionar",
    "desmunicionada": "desmunicionar",
    "desmunicionadas": "desmunicionar",
    "desmunicionado": "desmunicionar",
    "desmunicionados": "desmunicionar",
    "desmunicionai": "desmunicionar",
    "desmunicionais": "desmunicionar",
    "desmunicionam": "desmunicionar",
    "desmunicionamo": "desmunicionar",
    "desmunicionamos": "desmunicionar",
    "desmunicionando": "desmunicionar",
    "desmunicionara": "desmunicionar",
    "desmunicionaram": "desmunicionar",
    "desmunicionaras": "desmunicionar",
    "desmunicionarde": "desmunicionar",
    "desmunicionardes": "desmunicionar",
    "desmunicionare": "desmunicionar",
    "desmunicionarei": "desmunicionar",
    "desmunicionareis": "desmunicionar",
    "desmunicionarem": "desmunicionar",
    "desmunicionaremos": "desmunicionar",
    "desmunicionares": "desmunicionar",
    "desmunicionaria": "desmunicionar",
    "desmunicionariam": "desmunicionar",
    "desmunicionarias": "desmunicionar",
    "desmunicionarmo": "desmunicionar",
    "desmunicionarmos": "desmunicionar",
    "desmunicionará": "desmunicionar",
    "desmunicionarás": "desmunicionar",
    "desmunicionarão": "desmunicionar",
    "desmunicionaríamos": "desmunicionar",
    "desmunicionaríeis": "desmunicionar",
    "desmunicionas": "desmunicionar",
    "desmunicionasse": "desmunicionar",
    "desmunicionassem": "desmunicionar",
    "desmunicionasses": "desmunicionar",
    "desmunicionaste": "desmunicionar",
    "desmunicionastes": "desmunicionar",
    "desmunicionava": "desmunicionar",
    "desmunicionavam": "desmunicionar",
    "desmunicionavas": "desmunicionar",
    "desmunicione": "desmunicionar",
    "desmunicionei": "desmunicionar",
    "desmunicioneis": "desmunicionar",
    "desmunicionem": "desmunicionar",
    "desmunicionemo": "desmunicionar",
    "desmunicionemos": "desmunicionar",
    "desmuniciones": "desmunicionar",
    "desmuniciono": "desmunicionar",
    "desmunicionou": "desmunicionar",
    "desmunicioná": "desmunicionar",
    "desmunicionámo": "desmunicionar",
    "desmunicionámos": "desmunicionar",
    "desmunicionáramo": "desmunicionar",
    "desmunicionáramos": "desmunicionar",
    "desmunicionárei": "desmunicionar",
    "desmunicionáreis": "desmunicionar",
    "desmunicionásseis": "desmunicionar",
    "desmunicionássemos": "desmunicionar",
    "desmunicionávamo": "desmunicionar",
    "desmunicionávamos": "desmunicionar",
    "desmunicionávei": "desmunicionar",
    "desmunicionáveis": "desmunicionar",
    "desmuniciou": "desmuniciar",
    "desmuniciá": "desmuniciar",
    "desmuniciámo": "desmuniciar",
    "desmuniciámos": "desmuniciar",
    "desmuniciáramo": "desmuniciar",
    "desmuniciáramos": "desmuniciar",
    "desmuniciárei": "desmuniciar",
    "desmuniciáreis": "desmuniciar",
    "desmuniciásseis": "desmuniciar",
    "desmuniciássemos": "desmuniciar",
    "desmuniciávamo": "desmuniciar",
    "desmuniciávamos": "desmuniciar",
    "desmuniciávei": "desmuniciar",
    "desmuniciáveis": "desmuniciar",
    "desmura": "desmurar",
    "desmurada": "desmurar",
    "desmuradas": "desmurar",
    "desmurado": "desmurar",
    "desmurados": "desmurar",
    "desmurai": "desmurar",
    "desmurais": "desmurar",
    "desmuram": "desmurar",
    "desmuramo": "desmurar",
    "desmuramos": "desmurar",
    "desmurando": "desmurar",
    "desmurara": "desmurar",
    "desmuraram": "desmurar",
    "desmuraras": "desmurar",
    "desmurarde": "desmurar",
    "desmurardes": "desmurar",
    "desmurare": "desmurar",
    "desmurarei": "desmurar",
    "desmurareis": "desmurar",
    "desmurarem": "desmurar",
    "desmuraremos": "desmurar",
    "desmurares": "desmurar",
    "desmuraria": "desmurar",
    "desmurariam": "desmurar",
    "desmurarias": "desmurar",
    "desmurarmo": "desmurar",
    "desmurarmos": "desmurar",
    "desmurará": "desmurar",
    "desmurarás": "desmurar",
    "desmurarão": "desmurar",
    "desmuraríamos": "desmurar",
    "desmuraríeis": "desmurar",
    "desmuras": "desmurar",
    "desmurasse": "desmurar",
    "desmurassem": "desmurar",
    "desmurasses": "desmurar",
    "desmuraste": "desmurar",
    "desmurastes": "desmurar",
    "desmurava": "desmurar",
    "desmuravam": "desmurar",
    "desmuravas": "desmurar",
    "desmure": "desmurar",
    "desmurei": "desmurar",
    "desmureis": "desmurar",
    "desmurem": "desmurar",
    "desmuremo": "desmurar",
    "desmuremos": "desmurar",
    "desmures": "desmurar",
    "desmuro": "desmurar",
    "desmurou": "desmurar",
    "desmurá": "desmurar",
    "desmurámo": "desmurar",
    "desmurámos": "desmurar",
    "desmuráramo": "desmurar",
    "desmuráramos": "desmurar",
    "desmurárei": "desmurar",
    "desmuráreis": "desmurar",
    "desmurásseis": "desmurar",
    "desmurássemos": "desmurar",
    "desmurávamo": "desmurar",
    "desmurávamos": "desmurar",
    "desmurávei": "desmurar",
    "desmuráveis": "desmurar",
    "desméritos": "desmérito",
    "desnacionais": "desnacional",
    "desnacionaliza": "desnacionalizar",
    "desnacionalizada": "desnacionalizar",
    "desnacionalizadas": "desnacionalizar",
    "desnacionalizado": "desnacionalizar",
    "desnacionalizadora": "desnacionalizador",
    "desnacionalizadoras": "desnacionalizador",
    "desnacionalizadores": "desnacionalizador",
    "desnacionalizados": "desnacionalizar",
    "desnacionalizai": "desnacionalizar",
    "desnacionalizais": "desnacionalizar",
    "desnacionalizam": "desnacionalizar",
    "desnacionalizamo": "desnacionalizar",
    "desnacionalizamos": "desnacionalizar",
    "desnacionalizando": "desnacionalizar",
    "desnacionalizara": "desnacionalizar",
    "desnacionalizaram": "desnacionalizar",
    "desnacionalizaras": "desnacionalizar",
    "desnacionalizarde": "desnacionalizar",
    "desnacionalizardes": "desnacionalizar",
    "desnacionalizare": "desnacionalizar",
    "desnacionalizarei": "desnacionalizar",
    "desnacionalizareis": "desnacionalizar",
    "desnacionalizarem": "desnacionalizar",
    "desnacionalizaremos": "desnacionalizar",
    "desnacionalizares": "desnacionalizar",
    "desnacionalizaria": "desnacionalizar",
    "desnacionalizariam": "desnacionalizar",
    "desnacionalizarias": "desnacionalizar",
    "desnacionalizarmo": "desnacionalizar",
    "desnacionalizarmos": "desnacionalizar",
    "desnacionalizará": "desnacionalizar",
    "desnacionalizarás": "desnacionalizar",
    "desnacionalizarão": "desnacionalizar",
    "desnacionalizaríamos": "desnacionalizar",
    "desnacionalizaríeis": "desnacionalizar",
    "desnacionalizas": "desnacionalizar",
    "desnacionalizasse": "desnacionalizar",
    "desnacionalizassem": "desnacionalizar",
    "desnacionalizasses": "desnacionalizar",
    "desnacionalizaste": "desnacionalizar",
    "desnacionalizastes": "desnacionalizar",
    "desnacionalizava": "desnacionalizar",
    "desnacionalizavam": "desnacionalizar",
    "desnacionalizavas": "desnacionalizar",
    "desnacionalizações": "desnacionalização",
    "desnacionalize": "desnacionalizar",
    "desnacionalizei": "desnacionalizar",
    "desnacionalizeis": "desnacionalizar",
    "desnacionalizem": "desnacionalizar",
    "desnacionalizemo": "desnacionalizar",
    "desnacionalizemos": "desnacionalizar",
    "desnacionalizes": "desnacionalizar",
    "desnacionalizo": "desnacionalizar",
    "desnacionalizou": "desnacionalizar",
    "desnacionalizá": "desnacionalizar",
    "desnacionalizámo": "desnacionalizar",
    "desnacionalizámos": "desnacionalizar",
    "desnacionalizáramo": "desnacionalizar",
    "desnacionalizáramos": "desnacionalizar",
    "desnacionalizárei": "desnacionalizar",
    "desnacionalizáreis": "desnacionalizar",
    "desnacionalizásseis": "desnacionalizar",
    "desnacionalizássemos": "desnacionalizar",
    "desnacionalizávamo": "desnacionalizar",
    "desnacionalizávamos": "desnacionalizar",
    "desnacionalizávei": "desnacionalizar",
    "desnacionalizáveis": "desnacionalizável",
    "desnalga": "desnalgar",
    "desnalgada": "desnalgar",
    "desnalgadas": "desnalgar",
    "desnalgado": "desnalgar",
    "desnalgados": "desnalgar",
    "desnalgai": "desnalgar",
    "desnalgais": "desnalgar",
    "desnalgam": "desnalgar",
    "desnalgamo": "desnalgar",
    "desnalgamos": "desnalgar",
    "desnalgando": "desnalgar",
    "desnalgara": "desnalgar",
    "desnalgaram": "desnalgar",
    "desnalgaras": "desnalgar",
    "desnalgarde": "desnalgar",
    "desnalgardes": "desnalgar",
    "desnalgare": "desnalgar",
    "desnalgarei": "desnalgar",
    "desnalgareis": "desnalgar",
    "desnalgarem": "desnalgar",
    "desnalgaremos": "desnalgar",
    "desnalgares": "desnalgar",
    "desnalgaria": "desnalgar",
    "desnalgariam": "desnalgar",
    "desnalgarias": "desnalgar",
    "desnalgarmo": "desnalgar",
    "desnalgarmos": "desnalgar",
    "desnalgará": "desnalgar",
    "desnalgarás": "desnalgar",
    "desnalgarão": "desnalgar",
    "desnalgaríamos": "desnalgar",
    "desnalgaríeis": "desnalgar",
    "desnalgas": "desnalgar",
    "desnalgasse": "desnalgar",
    "desnalgassem": "desnalgar",
    "desnalgasses": "desnalgar",
    "desnalgaste": "desnalgar",
    "desnalgastes": "desnalgar",
    "desnalgava": "desnalgar",
    "desnalgavam": "desnalgar",
    "desnalgavas": "desnalgar",
    "desnalgo": "desnalgar",
    "desnalgou": "desnalgar",
    "desnalgue": "desnalgar",
    "desnalguei": "desnalgar",
    "desnalgueis": "desnalgar",
    "desnalguem": "desnalgar",
    "desnalguemo": "desnalgar",
    "desnalguemos": "desnalgar",
    "desnalgues": "desnalgar",
    "desnalgá": "desnalgar",
    "desnalgámo": "desnalgar",
    "desnalgámos": "desnalgar",
    "desnalgáramo": "desnalgar",
    "desnalgáramos": "desnalgar",
    "desnalgárei": "desnalgar",
    "desnalgáreis": "desnalgar",
    "desnalgásseis": "desnalgar",
    "desnalgássemos": "desnalgar",
    "desnalgávamo": "desnalgar",
    "desnalgávamos": "desnalgar",
    "desnalgávei": "desnalgar",
    "desnalgáveis": "desnalgar",
    "desnariga": "desnarigar",
    "desnarigada": "desnarigar",
    "desnarigadas": "desnarigar",
    "desnarigado": "desnarigar",
    "desnarigados": "desnarigar",
    "desnarigai": "desnarigar",
    "desnarigais": "desnarigar",
    "desnarigam": "desnarigar",
    "desnarigamo": "desnarigar",
    "desnarigamos": "desnarigar",
    "desnarigando": "desnarigar",
    "desnarigara": "desnarigar",
    "desnarigaram": "desnarigar",
    "desnarigaras": "desnarigar",
    "desnarigarde": "desnarigar",
    "desnarigardes": "desnarigar",
    "desnarigare": "desnarigar",
    "desnarigarei": "desnarigar",
    "desnarigareis": "desnarigar",
    "desnarigarem": "desnarigar",
    "desnarigaremos": "desnarigar",
    "desnarigares": "desnarigar",
    "desnarigaria": "desnarigar",
    "desnarigariam": "desnarigar",
    "desnarigarias": "desnarigar",
    "desnarigarmo": "desnarigar",
    "desnarigarmos": "desnarigar",
    "desnarigará": "desnarigar",
    "desnarigarás": "desnarigar",
    "desnarigarão": "desnarigar",
    "desnarigaríamos": "desnarigar",
    "desnarigaríeis": "desnarigar",
    "desnarigas": "desnarigar",
    "desnarigasse": "desnarigar",
    "desnarigassem": "desnarigar",
    "desnarigasses": "desnarigar",
    "desnarigaste": "desnarigar",
    "desnarigastes": "desnarigar",
    "desnarigava": "desnarigar",
    "desnarigavam": "desnarigar",
    "desnarigavas": "desnarigar",
    "desnarigo": "desnarigar",
    "desnarigou": "desnarigar",
    "desnarigue": "desnarigar",
    "desnariguei": "desnarigar",
    "desnarigueis": "desnarigar",
    "desnariguem": "desnarigar",
    "desnariguemo": "desnarigar",
    "desnariguemos": "desnarigar",
    "desnarigues": "desnarigar",
    "desnarigá": "desnarigar",
    "desnarigámo": "desnarigar",
    "desnarigámos": "desnarigar",
    "desnarigáramo": "desnarigar",
    "desnarigáramos": "desnarigar",
    "desnarigárei": "desnarigar",
    "desnarigáreis": "desnarigar",
    "desnarigásseis": "desnarigar",
    "desnarigássemos": "desnarigar",
    "desnarigávamo": "desnarigar",
    "desnarigávamos": "desnarigar",
    "desnarigávei": "desnarigar",
    "desnarigáveis": "desnarigar",
    "desnasala": "desnasalar",
    "desnasalada": "desnasalar",
    "desnasaladas": "desnasalar",
    "desnasalado": "desnasalar",
    "desnasalados": "desnasalar",
    "desnasalai": "desnasalar",
    "desnasalais": "desnasalar",
    "desnasalam": "desnasalar",
    "desnasalamo": "desnasalar",
    "desnasalamos": "desnasalar",
    "desnasalando": "desnasalar",
    "desnasalara": "desnasalar",
    "desnasalaram": "desnasalar",
    "desnasalaras": "desnasalar",
    "desnasalarde": "desnasalar",
    "desnasalardes": "desnasalar",
    "desnasalare": "desnasalar",
    "desnasalarei": "desnasalar",
    "desnasalareis": "desnasalar",
    "desnasalarem": "desnasalar",
    "desnasalaremos": "desnasalar",
    "desnasalares": "desnasalar",
    "desnasalaria": "desnasalar",
    "desnasalariam": "desnasalar",
    "desnasalarias": "desnasalar",
    "desnasalarmo": "desnasalar",
    "desnasalarmos": "desnasalar",
    "desnasalará": "desnasalar",
    "desnasalarás": "desnasalar",
    "desnasalarão": "desnasalar",
    "desnasalaríamos": "desnasalar",
    "desnasalaríeis": "desnasalar",
    "desnasalas": "desnasalar",
    "desnasalasse": "desnasalar",
    "desnasalassem": "desnasalar",
    "desnasalasses": "desnasalar",
    "desnasalaste": "desnasalar",
    "desnasalastes": "desnasalar",
    "desnasalava": "desnasalar",
    "desnasalavam": "desnasalar",
    "desnasalavas": "desnasalar",
    "desnasalações": "desnasalação",
    "desnasale": "desnasalar",
    "desnasalei": "desnasalar",
    "desnasaleis": "desnasalar",
    "desnasalem": "desnasalar",
    "desnasalemo": "desnasalar",
    "desnasalemos": "desnasalar",
    "desnasales": "desnasalar",
    "desnasaliza": "desnasalizar",
    "desnasalizada": "desnasalizar",
    "desnasalizadas": "desnasalizar",
    "desnasalizado": "desnasalizar",
    "desnasalizados": "desnasalizar",
    "desnasalizai": "desnasalizar",
    "desnasalizais": "desnasalizar",
    "desnasalizam": "desnasalizar",
    "desnasalizamo": "desnasalizar",
    "desnasalizamos": "desnasalizar",
    "desnasalizando": "desnasalizar",
    "desnasalizara": "desnasalizar",
    "desnasalizaram": "desnasalizar",
    "desnasalizaras": "desnasalizar",
    "desnasalizarde": "desnasalizar",
    "desnasalizardes": "desnasalizar",
    "desnasalizare": "desnasalizar",
    "desnasalizarei": "desnasalizar",
    "desnasalizareis": "desnasalizar",
    "desnasalizarem": "desnasalizar",
    "desnasalizaremos": "desnasalizar",
    "desnasalizares": "desnasalizar",
    "desnasalizaria": "desnasalizar",
    "desnasalizariam": "desnasalizar",
    "desnasalizarias": "desnasalizar",
    "desnasalizarmo": "desnasalizar",
    "desnasalizarmos": "desnasalizar",
    "desnasalizará": "desnasalizar",
    "desnasalizarás": "desnasalizar",
    "desnasalizarão": "desnasalizar",
    "desnasalizaríamos": "desnasalizar",
    "desnasalizaríeis": "desnasalizar",
    "desnasalizas": "desnasalizar",
    "desnasalizasse": "desnasalizar",
    "desnasalizassem": "desnasalizar",
    "desnasalizasses": "desnasalizar",
    "desnasalizaste": "desnasalizar",
    "desnasalizastes": "desnasalizar",
    "desnasalizava": "desnasalizar",
    "desnasalizavam": "desnasalizar",
    "desnasalizavas": "desnasalizar",
    "desnasalizações": "desnasalização",
    "desnasalize": "desnasalizar",
    "desnasalizei": "desnasalizar",
    "desnasalizeis": "desnasalizar",
    "desnasalizem": "desnasalizar",
    "desnasalizemo": "desnasalizar",
    "desnasalizemos": "desnasalizar",
    "desnasalizes": "desnasalizar",
    "desnasalizo": "desnasalizar",
    "desnasalizou": "desnasalizar",
    "desnasalizá": "desnasalizar",
    "desnasalizámo": "desnasalizar",
    "desnasalizámos": "desnasalizar",
    "desnasalizáramo": "desnasalizar",
    "desnasalizáramos": "desnasalizar",
    "desnasalizárei": "desnasalizar",
    "desnasalizáreis": "desnasalizar",
    "desnasalizásseis": "desnasalizar",
    "desnasalizássemos": "desnasalizar",
    "desnasalizávamo": "desnasalizar",
    "desnasalizávamos": "desnasalizar",
    "desnasalizávei": "desnasalizar",
    "desnasalizáveis": "desnasalizar",
    "desnasalo": "desnasalar",
    "desnasalou": "desnasalar",
    "desnasalá": "desnasalar",
    "desnasalámo": "desnasalar",
    "desnasalámos": "desnasalar",
    "desnasaláramo": "desnasalar",
    "desnasaláramos": "desnasalar",
    "desnasalárei": "desnasalar",
    "desnasaláreis": "desnasalar",
    "desnasalásseis": "desnasalar",
    "desnasalássemos": "desnasalar",
    "desnasalávamo": "desnasalar",
    "desnasalávamos": "desnasalar",
    "desnasalávei": "desnasalar",
    "desnasaláveis": "desnasalar",
    "desnastra": "desnastrar",
    "desnastrada": "desnastrar",
    "desnastradas": "desnastrar",
    "desnastrado": "desnastrar",
    "desnastrados": "desnastrar",
    "desnastrai": "desnastrar",
    "desnastrais": "desnastrar",
    "desnastram": "desnastrar",
    "desnastramo": "desnastrar",
    "desnastramos": "desnastrar",
    "desnastrando": "desnastrar",
    "desnastrara": "desnastrar",
    "desnastraram": "desnastrar",
    "desnastraras": "desnastrar",
    "desnastrarde": "desnastrar",
    "desnastrardes": "desnastrar",
    "desnastrare": "desnastrar",
    "desnastrarei": "desnastrar",
    "desnastrareis": "desnastrar",
    "desnastrarem": "desnastrar",
    "desnastraremos": "desnastrar",
    "desnastrares": "desnastrar",
    "desnastraria": "desnastrar",
    "desnastrariam": "desnastrar",
    "desnastrarias": "desnastrar",
    "desnastrarmo": "desnastrar",
    "desnastrarmos": "desnastrar",
    "desnastrará": "desnastrar",
    "desnastrarás": "desnastrar",
    "desnastrarão": "desnastrar",
    "desnastraríamos": "desnastrar",
    "desnastraríeis": "desnastrar",
    "desnastras": "desnastrar",
    "desnastrasse": "desnastrar",
    "desnastrassem": "desnastrar",
    "desnastrasses": "desnastrar",
    "desnastraste": "desnastrar",
    "desnastrastes": "desnastrar",
    "desnastrava": "desnastrar",
    "desnastravam": "desnastrar",
    "desnastravas": "desnastrar",
    "desnastre": "desnastrar",
    "desnastrei": "desnastrar",
    "desnastreis": "desnastrar",
    "desnastrem": "desnastrar",
    "desnastremo": "desnastrar",
    "desnastremos": "desnastrar",
    "desnastres": "desnastrar",
    "desnastro": "desnastrar",
    "desnastrou": "desnastrar",
    "desnastrá": "desnastrar",
    "desnastrámo": "desnastrar",
    "desnastrámos": "desnastrar",
    "desnastráramo": "desnastrar",
    "desnastráramos": "desnastrar",
    "desnastrárei": "desnastrar",
    "desnastráreis": "desnastrar",
    "desnastrásseis": "desnastrar",
    "desnastrássemos": "desnastrar",
    "desnastrávamo": "desnastrar",
    "desnastrávamos": "desnastrar",
    "desnastrávei": "desnastrar",
    "desnastráveis": "desnastrar",
    "desnata": "desnatar",
    "desnatada": "desnatar",
    "desnatadas": "desnatar",
    "desnatadeiras": "desnatadeira",
    "desnatado": "desnatar",
    "desnatados": "desnatar",
    "desnatai": "desnatar",
    "desnatais": "desnatar",
    "desnatam": "desnatar",
    "desnatamo": "desnatar",
    "desnatamos": "desnatar",
    "desnatando": "desnatar",
    "desnatara": "desnatar",
    "desnataram": "desnatar",
    "desnataras": "desnatar",
    "desnatarde": "desnatar",
    "desnatardes": "desnatar",
    "desnatare": "desnatar",
    "desnatarei": "desnatar",
    "desnatareis": "desnatar",
    "desnatarem": "desnatar",
    "desnataremos": "desnatar",
    "desnatares": "desnatar",
    "desnataria": "desnatar",
    "desnatariam": "desnatar",
    "desnatarias": "desnatar",
    "desnatarmo": "desnatar",
    "desnatarmos": "desnatar",
    "desnatará": "desnatar",
    "desnatarás": "desnatar",
    "desnatarão": "desnatar",
    "desnataríamos": "desnatar",
    "desnataríeis": "desnatar",
    "desnatas": "desnatar",
    "desnatasse": "desnatar",
    "desnatassem": "desnatar",
    "desnatasses": "desnatar",
    "desnataste": "desnatar",
    "desnatastes": "desnatar",
    "desnatava": "desnatar",
    "desnatavam": "desnatar",
    "desnatavas": "desnatar",
    "desnatações": "desnatação",
    "desnate": "desnatar",
    "desnatei": "desnatar",
    "desnateis": "desnatar",
    "desnatem": "desnatar",
    "desnatemo": "desnatar",
    "desnatemos": "desnatar",
    "desnates": "desnatar",
    "desnato": "desnatar",
    "desnatou": "desnatar",
    "desnatura": "desnaturar",
    "desnaturada": "desnaturar",
    "desnaturadas": "desnaturar",
    "desnaturado": "desnaturar",
    "desnaturados": "desnaturar",
    "desnaturai": "desnaturar",
    "desnaturais": "desnaturar",
    "desnaturalidades": "desnaturalidade",
    "desnaturaliza": "desnaturalizar",
    "desnaturalizada": "desnaturalizar",
    "desnaturalizadas": "desnaturalizar",
    "desnaturalizado": "desnaturalizar",
    "desnaturalizados": "desnaturalizar",
    "desnaturalizai": "desnaturalizar",
    "desnaturalizais": "desnaturalizar",
    "desnaturalizam": "desnaturalizar",
    "desnaturalizamo": "desnaturalizar",
    "desnaturalizamos": "desnaturalizar",
    "desnaturalizando": "desnaturalizar",
    "desnaturalizara": "desnaturalizar",
    "desnaturalizaram": "desnaturalizar",
    "desnaturalizaras": "desnaturalizar",
    "desnaturalizarde": "desnaturalizar",
    "desnaturalizardes": "desnaturalizar",
    "desnaturalizare": "desnaturalizar",
    "desnaturalizarei": "desnaturalizar",
    "desnaturalizareis": "desnaturalizar",
    "desnaturalizarem": "desnaturalizar",
    "desnaturalizaremos": "desnaturalizar",
    "desnaturalizares": "desnaturalizar",
    "desnaturalizaria": "desnaturalizar",
    "desnaturalizariam": "desnaturalizar",
    "desnaturalizarias": "desnaturalizar",
    "desnaturalizarmo": "desnaturalizar",
    "desnaturalizarmos": "desnaturalizar",
    "desnaturalizará": "desnaturalizar",
    "desnaturalizarás": "desnaturalizar",
    "desnaturalizarão": "desnaturalizar",
    "desnaturalizaríamos": "desnaturalizar",
    "desnaturalizaríeis": "desnaturalizar",
    "desnaturalizas": "desnaturalizar",
    "desnaturalizasse": "desnaturalizar",
    "desnaturalizassem": "desnaturalizar",
    "desnaturalizasses": "desnaturalizar",
    "desnaturalizaste": "desnaturalizar",
    "desnaturalizastes": "desnaturalizar",
    "desnaturalizava": "desnaturalizar",
    "desnaturalizavam": "desnaturalizar",
    "desnaturalizavas": "desnaturalizar",
    "desnaturalizações": "desnaturalização",
    "desnaturalize": "desnaturalizar",
    "desnaturalizei": "desnaturalizar",
    "desnaturalizeis": "desnaturalizar",
    "desnaturalizem": "desnaturalizar",
    "desnaturalizemo": "desnaturalizar",
    "desnaturalizemos": "desnaturalizar",
    "desnaturalizes": "desnaturalizar",
    "desnaturalizo": "desnaturalizar",
    "desnaturalizou": "desnaturalizar",
    "desnaturalizá": "desnaturalizar",
    "desnaturalizámo": "desnaturalizar",
    "desnaturalizámos": "desnaturalizar",
    "desnaturalizáramo": "desnaturalizar",
    "desnaturalizáramos": "desnaturalizar",
    "desnaturalizárei": "desnaturalizar",
    "desnaturalizáreis": "desnaturalizar",
    "desnaturalizásseis": "desnaturalizar",
    "desnaturalizássemos": "desnaturalizar",
    "desnaturalizávamo": "desnaturalizar",
    "desnaturalizávamos": "desnaturalizar",
    "desnaturalizávei": "desnaturalizar",
    "desnaturalizáveis": "desnaturalizar",
    "desnaturam": "desnaturar",
    "desnaturamo": "desnaturar",
    "desnaturamos": "desnaturar",
    "desnaturando": "desnaturar",
    "desnaturara": "desnaturar",
    "desnaturaram": "desnaturar",
    "desnaturaras": "desnaturar",
    "desnaturarde": "desnaturar",
    "desnaturardes": "desnaturar",
    "desnaturare": "desnaturar",
    "desnaturarei": "desnaturar",
    "desnaturareis": "desnaturar",
    "desnaturarem": "desnaturar",
    "desnaturaremos": "desnaturar",
    "desnaturares": "desnaturar",
    "desnaturaria": "desnaturar",
    "desnaturariam": "desnaturar",
    "desnaturarias": "desnaturar",
    "desnaturarmo": "desnaturar",
    "desnaturarmos": "desnaturar",
    "desnaturará": "desnaturar",
    "desnaturarás": "desnaturar",
    "desnaturarão": "desnaturar",
    "desnaturaríamos": "desnaturar",
    "desnaturaríeis": "desnaturar",
    "desnaturas": "desnaturar",
    "desnaturasse": "desnaturar",
    "desnaturassem": "desnaturar",
    "desnaturasses": "desnaturar",
    "desnaturaste": "desnaturar",
    "desnaturastes": "desnaturar",
    "desnaturava": "desnaturar",
    "desnaturavam": "desnaturar",
    "desnaturavas": "desnaturar",
    "desnaturações": "desnaturação",
    "desnature": "desnaturar",
    "desnaturei": "desnaturar",
    "desnatureis": "desnaturar",
    "desnaturem": "desnaturar",
    "desnaturemo": "desnaturar",
    "desnaturemos": "desnaturar",
    "desnatures": "desnaturar",
    "desnaturo": "desnaturar",
    "desnaturou": "desnaturar",
    "desnaturá": "desnaturar",
    "desnaturámo": "desnaturar",
    "desnaturámos": "desnaturar",
    "desnaturáramo": "desnaturar",
    "desnaturáramos": "desnaturar",
    "desnaturárei": "desnaturar",
    "desnaturáreis": "desnaturar",
    "desnaturásseis": "desnaturar",
    "desnaturássemos": "desnaturar",
    "desnaturávamo": "desnaturar",
    "desnaturávamos": "desnaturar",
    "desnaturávei": "desnaturar",
    "desnaturáveis": "desnaturar",
    "desnatá": "desnatar",
    "desnatámo": "desnatar",
    "desnatámos": "desnatar",
    "desnatáramo": "desnatar",
    "desnatáramos": "desnatar",
    "desnatárei": "desnatar",
    "desnatáreis": "desnatar",
    "desnatásseis": "desnatar",
    "desnatássemos": "desnatar",
    "desnatávamo": "desnatar",
    "desnatávamos": "desnatar",
    "desnatávei": "desnatar",
    "desnatáveis": "desnatar",
    "desnavegáveis": "desnavegável",
    "desnecessidades": "desnecessidade",
    "desnecessita": "desnecessitar",
    "desnecessitada": "desnecessitar",
    "desnecessitadas": "desnecessitar",
    "desnecessitado": "desnecessitar",
    "desnecessitados": "desnecessitar",
    "desnecessitai": "desnecessitar",
    "desnecessitais": "desnecessitar",
    "desnecessitam": "desnecessitar",
    "desnecessitamo": "desnecessitar",
    "desnecessitamos": "desnecessitar",
    "desnecessitando": "desnecessitar",
    "desnecessitara": "desnecessitar",
    "desnecessitaram": "desnecessitar",
    "desnecessitaras": "desnecessitar",
    "desnecessitarde": "desnecessitar",
    "desnecessitardes": "desnecessitar",
    "desnecessitare": "desnecessitar",
    "desnecessitarei": "desnecessitar",
    "desnecessitareis": "desnecessitar",
    "desnecessitarem": "desnecessitar",
    "desnecessitaremos": "desnecessitar",
    "desnecessitares": "desnecessitar",
    "desnecessitaria": "desnecessitar",
    "desnecessitariam": "desnecessitar",
    "desnecessitarias": "desnecessitar",
    "desnecessitarmo": "desnecessitar",
    "desnecessitarmos": "desnecessitar",
    "desnecessitará": "desnecessitar",
    "desnecessitarás": "desnecessitar",
    "desnecessitarão": "desnecessitar",
    "desnecessitaríamos": "desnecessitar",
    "desnecessitaríeis": "desnecessitar",
    "desnecessitas": "desnecessitar",
    "desnecessitasse": "desnecessitar",
    "desnecessitassem": "desnecessitar",
    "desnecessitasses": "desnecessitar",
    "desnecessitaste": "desnecessitar",
    "desnecessitastes": "desnecessitar",
    "desnecessitava": "desnecessitar",
    "desnecessitavam": "desnecessitar",
    "desnecessitavas": "desnecessitar",
    "desnecessite": "desnecessitar",
    "desnecessitei": "desnecessitar",
    "desnecessiteis": "desnecessitar",
    "desnecessitem": "desnecessitar",
    "desnecessitemo": "desnecessitar",
    "desnecessitemos": "desnecessitar",
    "desnecessites": "desnecessitar",
    "desnecessito": "desnecessitar",
    "desnecessitou": "desnecessitar",
    "desnecessitá": "desnecessitar",
    "desnecessitámo": "desnecessitar",
    "desnecessitámos": "desnecessitar",
    "desnecessitáramo": "desnecessitar",
    "desnecessitáramos": "desnecessitar",
    "desnecessitárei": "desnecessitar",
    "desnecessitáreis": "desnecessitar",
    "desnecessitásseis": "desnecessitar",
    "desnecessitássemos": "desnecessitar",
    "desnecessitávamo": "desnecessitar",
    "desnecessitávamos": "desnecessitar",
    "desnecessitávei": "desnecessitar",
    "desnecessitáveis": "desnecessitar",
    "desnecessária": "desnecessário",
    "desnecessárias": "desnecessário",
    "desnecessários": "desnecessário",
    "desnegoceia": "desnegociar",
    "desnegoceiam": "desnegociar",
    "desnegoceias": "desnegociar",
    "desnegoceie": "desnegociar",
    "desnegoceiem": "desnegociar",
    "desnegoceies": "desnegociar",
    "desnegoceio": "desnegociar",
    "desnegocia": "desnegociar",
    "desnegociada": "desnegociar",
    "desnegociadas": "desnegociar",
    "desnegociado": "desnegociar",
    "desnegociados": "desnegociar",
    "desnegociai": "desnegociar",
    "desnegociais": "desnegociar",
    "desnegociam": "desnegociar",
    "desnegociamo": "desnegociar",
    "desnegociamos": "desnegociar",
    "desnegociando": "desnegociar",
    "desnegociara": "desnegociar",
    "desnegociaram": "desnegociar",
    "desnegociaras": "desnegociar",
    "desnegociarde": "desnegociar",
    "desnegociardes": "desnegociar",
    "desnegociare": "desnegociar",
    "desnegociarei": "desnegociar",
    "desnegociareis": "desnegociar",
    "desnegociarem": "desnegociar",
    "desnegociaremos": "desnegociar",
    "desnegociares": "desnegociar",
    "desnegociaria": "desnegociar",
    "desnegociariam": "desnegociar",
    "desnegociarias": "desnegociar",
    "desnegociarmo": "desnegociar",
    "desnegociarmos": "desnegociar",
    "desnegociará": "desnegociar",
    "desnegociarás": "desnegociar",
    "desnegociarão": "desnegociar",
    "desnegociaríamos": "desnegociar",
    "desnegociaríeis": "desnegociar",
    "desnegocias": "desnegociar",
    "desnegociasse": "desnegociar",
    "desnegociassem": "desnegociar",
    "desnegociasses": "desnegociar",
    "desnegociaste": "desnegociar",
    "desnegociastes": "desnegociar",
    "desnegociava": "desnegociar",
    "desnegociavam": "desnegociar",
    "desnegociavas": "desnegociar",
    "desnegocie": "desnegociar",
    "desnegociei": "desnegociar",
    "desnegocieis": "desnegociar",
    "desnegociem": "desnegociar",
    "desnegociemo": "desnegociar",
    "desnegociemos": "desnegociar",
    "desnegocies": "desnegociar",
    "desnegocio": "desnegociar",
    "desnegociou": "desnegociar",
    "desnegociá": "desnegociar",
    "desnegociámo": "desnegociar",
    "desnegociámos": "desnegociar",
    "desnegociáramo": "desnegociar",
    "desnegociáramos": "desnegociar",
    "desnegociárei": "desnegociar",
    "desnegociáreis": "desnegociar",
    "desnegociásseis": "desnegociar",
    "desnegociássemos": "desnegociar",
    "desnegociávamo": "desnegociar",
    "desnegociávamos": "desnegociar",
    "desnegociávei": "desnegociar",
    "desnegociáveis": "desnegociar",
    "desnerva": "desnervar",
    "desnervada": "desnervar",
    "desnervadas": "desnervar",
    "desnervado": "desnervar",
    "desnervados": "desnervar",
    "desnervai": "desnervar",
    "desnervais": "desnervar",
    "desnervam": "desnervar",
    "desnervamentos": "desnervamento",
    "desnervamo": "desnervar",
    "desnervamos": "desnervar",
    "desnervando": "desnervar",
    "desnervara": "desnervar",
    "desnervaram": "desnervar",
    "desnervaras": "desnervar",
    "desnervarde": "desnervar",
    "desnervardes": "desnervar",
    "desnervare": "desnervar",
    "desnervarei": "desnervar",
    "desnervareis": "desnervar",
    "desnervarem": "desnervar",
    "desnervaremos": "desnervar",
    "desnervares": "desnervar",
    "desnervaria": "desnervar",
    "desnervariam": "desnervar",
    "desnervarias": "desnervar",
    "desnervarmo": "desnervar",
    "desnervarmos": "desnervar",
    "desnervará": "desnervar",
    "desnervarás": "desnervar",
    "desnervarão": "desnervar",
    "desnervaríamos": "desnervar",
    "desnervaríeis": "desnervar",
    "desnervas": "desnervar",
    "desnervasse": "desnervar",
    "desnervassem": "desnervar",
    "desnervasses": "desnervar",
    "desnervaste": "desnervar",
    "desnervastes": "desnervar",
    "desnervava": "desnervar",
    "desnervavam": "desnervar",
    "desnervavas": "desnervar",
    "desnerve": "desnervar",
    "desnervei": "desnervar",
    "desnerveis": "desnervar",
    "desnervem": "desnervar",
    "desnervemo": "desnervar",
    "desnervemos": "desnervar",
    "desnerves": "desnervar",
    "desnervo": "desnervar",
    "desnervou": "desnervar",
    "desnervá": "desnervar",
    "desnervámo": "desnervar",
    "desnervámos": "desnervar",
    "desnerváramo": "desnervar",
    "desnerváramos": "desnervar",
    "desnervárei": "desnervar",
    "desnerváreis": "desnervar",
    "desnervásseis": "desnervar",
    "desnervássemos": "desnervar",
    "desnervávamo": "desnervar",
    "desnervávamos": "desnervar",
    "desnervávei": "desnervar",
    "desnerváveis": "desnervar",
    "desneva": "desnevar",
    "desnevada": "desnevar",
    "desnevadas": "desnevar",
    "desnevado": "desnevar",
    "desnevados": "desnevar",
    "desnevai": "desnevar",
    "desnevam": "desnevar",
    "desnevando": "desnevar",
    "desnevara": "desnevar",
    "desnevaram": "desnevar",
    "desnevardes": "desnevar",
    "desnevarem": "desnevar",
    "desnevares": "desnevar",
    "desnevaria": "desnevar",
    "desnevariam": "desnevar",
    "desnevarmos": "desnevar",
    "desnevará": "desnevar",
    "desnevarão": "desnevar",
    "desnevasse": "desnevar",
    "desnevassem": "desnevar",
    "desnevasses": "desnevar",
    "desnevava": "desnevar",
    "desnevavam": "desnevar",
    "desneve": "desnevar",
    "desneveis": "desnevar",
    "desnevem": "desnevar",
    "desneves": "desnevar",
    "desnevou": "desnevar",
    "desnevásseis": "desnevar",
    "desnevássemos": "desnevar",
    "desninha": "desninhar",
    "desninhada": "desninhar",
    "desninhadas": "desninhar",
    "desninhado": "desninhar",
    "desninhados": "desninhar",
    "desninhai": "desninhar",
    "desninhais": "desninhar",
    "desninham": "desninhar",
    "desninhamo": "desninhar",
    "desninhamos": "desninhar",
    "desninhando": "desninhar",
    "desninhara": "desninhar",
    "desninharam": "desninhar",
    "desninharas": "desninhar",
    "desninharde": "desninhar",
    "desninhardes": "desninhar",
    "desninhare": "desninhar",
    "desninharei": "desninhar",
    "desninhareis": "desninhar",
    "desninharem": "desninhar",
    "desninharemos": "desninhar",
    "desninhares": "desninhar",
    "desninharia": "desninhar",
    "desninhariam": "desninhar",
    "desninharias": "desninhar",
    "desninharmo": "desninhar",
    "desninharmos": "desninhar",
    "desninhará": "desninhar",
    "desninharás": "desninhar",
    "desninharão": "desninhar",
    "desninharíamos": "desninhar",
    "desninharíeis": "desninhar",
    "desninhas": "desninhar",
    "desninhasse": "desninhar",
    "desninhassem": "desninhar",
    "desninhasses": "desninhar",
    "desninhaste": "desninhar",
    "desninhastes": "desninhar",
    "desninhava": "desninhar",
    "desninhavam": "desninhar",
    "desninhavas": "desninhar",
    "desninhe": "desninhar",
    "desninhei": "desninhar",
    "desninheis": "desninhar",
    "desninhem": "desninhar",
    "desninhemo": "desninhar",
    "desninhemos": "desninhar",
    "desninhes": "desninhar",
    "desninho": "desninhar",
    "desninhou": "desninhar",
    "desninhá": "desninhar",
    "desninhámo": "desninhar",
    "desninhámos": "desninhar",
    "desninháramo": "desninhar",
    "desninháramos": "desninhar",
    "desninhárei": "desninhar",
    "desninháreis": "desninhar",
    "desninhásseis": "desninhar",
    "desninhássemos": "desninhar",
    "desninhávamo": "desninhar",
    "desninhávamos": "desninhar",
    "desninhávei": "desninhar",
    "desninháveis": "desninhar",
    "desniquela": "desniquelar",
    "desniquelada": "desniquelar",
    "desniqueladas": "desniquelar",
    "desniquelado": "desniquelar",
    "desniquelados": "desniquelar",
    "desniquelagens": "desniquelagem",
    "desniquelai": "desniquelar",
    "desniquelais": "desniquelar",
    "desniquelam": "desniquelar",
    "desniquelamo": "desniquelar",
    "desniquelamos": "desniquelar",
    "desniquelando": "desniquelar",
    "desniquelara": "desniquelar",
    "desniquelaram": "desniquelar",
    "desniquelaras": "desniquelar",
    "desniquelarde": "desniquelar",
    "desniquelardes": "desniquelar",
    "desniquelare": "desniquelar",
    "desniquelarei": "desniquelar",
    "desniquelareis": "desniquelar",
    "desniquelarem": "desniquelar",
    "desniquelaremos": "desniquelar",
    "desniquelares": "desniquelar",
    "desniquelaria": "desniquelar",
    "desniquelariam": "desniquelar",
    "desniquelarias": "desniquelar",
    "desniquelarmo": "desniquelar",
    "desniquelarmos": "desniquelar",
    "desniquelará": "desniquelar",
    "desniquelarás": "desniquelar",
    "desniquelarão": "desniquelar",
    "desniquelaríamos": "desniquelar",
    "desniquelaríeis": "desniquelar",
    "desniquelas": "desniquelar",
    "desniquelasse": "desniquelar",
    "desniquelassem": "desniquelar",
    "desniquelasses": "desniquelar",
    "desniquelaste": "desniquelar",
    "desniquelastes": "desniquelar",
    "desniquelava": "desniquelar",
    "desniquelavam": "desniquelar",
    "desniquelavas": "desniquelar",
    "desniquele": "desniquelar",
    "desniquelei": "desniquelar",
    "desniqueleis": "desniquelar",
    "desniquelem": "desniquelar",
    "desniquelemo": "desniquelar",
    "desniquelemos": "desniquelar",
    "desniqueles": "desniquelar",
    "desniquelo": "desniquelar",
    "desniquelou": "desniquelar",
    "desniquelá": "desniquelar",
    "desniquelámo": "desniquelar",
    "desniquelámos": "desniquelar",
    "desniqueláramo": "desniquelar",
    "desniqueláramos": "desniquelar",
    "desniquelárei": "desniquelar",
    "desniqueláreis": "desniquelar",
    "desniquelásseis": "desniquelar",
    "desniquelássemos": "desniquelar",
    "desniquelávamo": "desniquelar",
    "desniquelávamos": "desniquelar",
    "desniquelávei": "desniquelar",
    "desniqueláveis": "desniquelar",
    "desnivela": "desnivelar",
    "desnivelada": "desnivelar",
    "desniveladas": "desnivelar",
    "desnivelado": "desnivelar",
    "desnivelados": "desnivelar",
    "desnivelai": "desnivelar",
    "desnivelais": "desnivelar",
    "desnivelam": "desnivelar",
    "desnivelamentos": "desnivelamento",
    "desnivelamo": "desnivelar",
    "desnivelamos": "desnivelar",
    "desnivelando": "desnivelar",
    "desnivelara": "desnivelar",
    "desnivelaram": "desnivelar",
    "desnivelaras": "desnivelar",
    "desnivelarde": "desnivelar",
    "desnivelardes": "desnivelar",
    "desnivelare": "desnivelar",
    "desnivelarei": "desnivelar",
    "desnivelareis": "desnivelar",
    "desnivelarem": "desnivelar",
    "desnivelaremos": "desnivelar",
    "desnivelares": "desnivelar",
    "desnivelaria": "desnivelar",
    "desnivelariam": "desnivelar",
    "desnivelarias": "desnivelar",
    "desnivelarmo": "desnivelar",
    "desnivelarmos": "desnivelar",
    "desnivelará": "desnivelar",
    "desnivelarás": "desnivelar",
    "desnivelarão": "desnivelar",
    "desnivelaríamos": "desnivelar",
    "desnivelaríeis": "desnivelar",
    "desnivelas": "desnivelar",
    "desnivelasse": "desnivelar",
    "desnivelassem": "desnivelar",
    "desnivelasses": "desnivelar",
    "desnivelaste": "desnivelar",
    "desnivelastes": "desnivelar",
    "desnivelava": "desnivelar",
    "desnivelavam": "desnivelar",
    "desnivelavas": "desnivelar",
    "desnivele": "desnivelar",
    "desnivelei": "desnivelar",
    "desniveleis": "desnivelar",
    "desnivelem": "desnivelar",
    "desnivelemo": "desnivelar",
    "desnivelemos": "desnivelar",
    "desniveles": "desnivelar",
    "desnivelo": "desnivelar",
    "desnivelou": "desnivelar",
    "desnivelá": "desnivelar",
    "desnivelámo": "desnivelar",
    "desnivelámos": "desnivelar",
    "desniveláramo": "desnivelar",
    "desniveláramos": "desnivelar",
    "desnivelárei": "desnivelar",
    "desniveláreis": "desnivelar",
    "desnivelásseis": "desnivelar",
    "desnivelássemos": "desnivelar",
    "desnivelávamo": "desnivelar",
    "desnivelávamos": "desnivelar",
    "desnivelávei": "desnivelar",
    "desniveláveis": "desnivelável",
    "desnobrece": "desnobrecer",
    "desnobrecei": "desnobrecer",
    "desnobreceis": "desnobrecer",
    "desnobrecem": "desnobrecer",
    "desnobrecemo": "desnobrecer",
    "desnobrecemos": "desnobrecer",
    "desnobrecendo": "desnobrecer",
    "desnobrecera": "desnobrecer",
    "desnobreceram": "desnobrecer",
    "desnobreceras": "desnobrecer",
    "desnobrecerde": "desnobrecer",
    "desnobrecerdes": "desnobrecer",
    "desnobrecere": "desnobrecer",
    "desnobrecerei": "desnobrecer",
    "desnobrecereis": "desnobrecer",
    "desnobrecerem": "desnobrecer",
    "desnobreceremos": "desnobrecer",
    "desnobreceres": "desnobrecer",
    "desnobreceria": "desnobrecer",
    "desnobreceriam": "desnobrecer",
    "desnobrecerias": "desnobrecer",
    "desnobrecermo": "desnobrecer",
    "desnobrecermos": "desnobrecer",
    "desnobrecerá": "desnobrecer",
    "desnobrecerás": "desnobrecer",
    "desnobrecerão": "desnobrecer",
    "desnobreceríamos": "desnobrecer",
    "desnobreceríeis": "desnobrecer",
    "desnobreces": "desnobrecer",
    "desnobrecesse": "desnobrecer",
    "desnobrecessem": "desnobrecer",
    "desnobrecesses": "desnobrecer",
    "desnobreceste": "desnobrecer",
    "desnobrecestes": "desnobrecer",
    "desnobreceu": "desnobrecer",
    "desnobreci": "desnobrecer",
    "desnobrecia": "desnobrecer",
    "desnobreciam": "desnobrecer",
    "desnobrecias": "desnobrecer",
    "desnobrecida": "desnobrecido",
    "desnobrecidas": "desnobrecido",
    "desnobrecido": "desnobrecer",
    "desnobrecidos": "desnobrecido",
    "desnobrecê": "desnobrecer",
    "desnobrecêramo": "desnobrecer",
    "desnobrecêramos": "desnobrecer",
    "desnobrecêrei": "desnobrecer",
    "desnobrecêreis": "desnobrecer",
    "desnobrecêsseis": "desnobrecer",
    "desnobrecêssemos": "desnobrecer",
    "desnobrecíamo": "desnobrecer",
    "desnobrecíamos": "desnobrecer",
    "desnobrecíei": "desnobrecer",
    "desnobrecíeis": "desnobrecer",
    "desnobreça": "desnobrecer",
    "desnobreçais": "desnobrecer",
    "desnobreçam": "desnobrecer",
    "desnobreçamo": "desnobrecer",
    "desnobreçamos": "desnobrecer",
    "desnobreças": "desnobrecer",
    "desnobreço": "desnobrecer",
    "desnoca": "desnocar",
    "desnocada": "desnocar",
    "desnocadas": "desnocar",
    "desnocado": "desnocar",
    "desnocados": "desnocar",
    "desnocai": "desnocar",
    "desnocais": "desnocar",
    "desnocam": "desnocar",
    "desnocamo": "desnocar",
    "desnocamos": "desnocar",
    "desnocando": "desnocar",
    "desnocara": "desnocar",
    "desnocaram": "desnocar",
    "desnocaras": "desnocar",
    "desnocarde": "desnocar",
    "desnocardes": "desnocar",
    "desnocare": "desnocar",
    "desnocarei": "desnocar",
    "desnocareis": "desnocar",
    "desnocarem": "desnocar",
    "desnocaremos": "desnocar",
    "desnocares": "desnocar",
    "desnocaria": "desnocar",
    "desnocariam": "desnocar",
    "desnocarias": "desnocar",
    "desnocarmo": "desnocar",
    "desnocarmos": "desnocar",
    "desnocará": "desnocar",
    "desnocarás": "desnocar",
    "desnocarão": "desnocar",
    "desnocaríamos": "desnocar",
    "desnocaríeis": "desnocar",
    "desnocas": "desnocar",
    "desnocasse": "desnocar",
    "desnocassem": "desnocar",
    "desnocasses": "desnocar",
    "desnocaste": "desnocar",
    "desnocastes": "desnocar",
    "desnocava": "desnocar",
    "desnocavam": "desnocar",
    "desnocavas": "desnocar",
    "desnoco": "desnocar",
    "desnocou": "desnocar",
    "desnocá": "desnocar",
    "desnocámo": "desnocar",
    "desnocámos": "desnocar",
    "desnocáramo": "desnocar",
    "desnocáramos": "desnocar",
    "desnocárei": "desnocar",
    "desnocáreis": "desnocar",
    "desnocásseis": "desnocar",
    "desnocássemos": "desnocar",
    "desnocávamo": "desnocar",
    "desnocávamos": "desnocar",
    "desnocávei": "desnocar",
    "desnocáveis": "desnocar",
    "desnodoa": "desnodoar",
    "desnodoada": "desnodoar",
    "desnodoadas": "desnodoar",
    "desnodoado": "desnodoar",
    "desnodoados": "desnodoar",
    "desnodoai": "desnodoar",
    "desnodoais": "desnodoar",
    "desnodoam": "desnodoar",
    "desnodoamo": "desnodoar",
    "desnodoamos": "desnodoar",
    "desnodoando": "desnodoar",
    "desnodoara": "desnodoar",
    "desnodoaram": "desnodoar",
    "desnodoaras": "desnodoar",
    "desnodoarde": "desnodoar",
    "desnodoardes": "desnodoar",
    "desnodoare": "desnodoar",
    "desnodoarei": "desnodoar",
    "desnodoareis": "desnodoar",
    "desnodoarem": "desnodoar",
    "desnodoaremos": "desnodoar",
    "desnodoares": "desnodoar",
    "desnodoaria": "desnodoar",
    "desnodoariam": "desnodoar",
    "desnodoarias": "desnodoar",
    "desnodoarmo": "desnodoar",
    "desnodoarmos": "desnodoar",
    "desnodoará": "desnodoar",
    "desnodoarás": "desnodoar",
    "desnodoarão": "desnodoar",
    "desnodoaríamos": "desnodoar",
    "desnodoaríeis": "desnodoar",
    "desnodoas": "desnodoar",
    "desnodoasse": "desnodoar",
    "desnodoassem": "desnodoar",
    "desnodoasses": "desnodoar",
    "desnodoaste": "desnodoar",
    "desnodoastes": "desnodoar",
    "desnodoava": "desnodoar",
    "desnodoavam": "desnodoar",
    "desnodoavas": "desnodoar",
    "desnodoe": "desnodoar",
    "desnodoei": "desnodoar",
    "desnodoeis": "desnodoar",
    "desnodoem": "desnodoar",
    "desnodoemo": "desnodoar",
    "desnodoemos": "desnodoar",
    "desnodoes": "desnodoar",
    "desnodoo": "desnodoar",
    "desnodoou": "desnodoar",
    "desnodosa": "desnodoso",
    "desnodosas": "desnodoso",
    "desnodosos": "desnodoso",
    "desnodoá": "desnodoar",
    "desnodoámo": "desnodoar",
    "desnodoámos": "desnodoar",
    "desnodoáramo": "desnodoar",
    "desnodoáramos": "desnodoar",
    "desnodoárei": "desnodoar",
    "desnodoáreis": "desnodoar",
    "desnodoásseis": "desnodoar",
    "desnodoássemos": "desnodoar",
    "desnodoávamo": "desnodoar",
    "desnodoávamos": "desnodoar",
    "desnodoávei": "desnodoar",
    "desnodoáveis": "desnodoar",
    "desnoita": "desnoitar",
    "desnoitada": "desnoitar",
    "desnoitadas": "desnoitar",
    "desnoitado": "desnoitar",
    "desnoitados": "desnoitar",
    "desnoitai": "desnoitar",
    "desnoitais": "desnoitar",
    "desnoitam": "desnoitar",
    "desnoitamo": "desnoitar",
    "desnoitamos": "desnoitar",
    "desnoitando": "desnoitar",
    "desnoitara": "desnoitar",
    "desnoitaram": "desnoitar",
    "desnoitaras": "desnoitar",
    "desnoitarde": "desnoitar",
    "desnoitardes": "desnoitar",
    "desnoitare": "desnoitar",
    "desnoitarei": "desnoitar",
    "desnoitareis": "desnoitar",
    "desnoitarem": "desnoitar",
    "desnoitaremos": "desnoitar",
    "desnoitares": "desnoitar",
    "desnoitaria": "desnoitar",
    "desnoitariam": "desnoitar",
    "desnoitarias": "desnoitar",
    "desnoitarmo": "desnoitar",
    "desnoitarmos": "desnoitar",
    "desnoitará": "desnoitar",
    "desnoitarás": "desnoitar",
    "desnoitarão": "desnoitar",
    "desnoitaríamos": "desnoitar",
    "desnoitaríeis": "desnoitar",
    "desnoitas": "desnoitar",
    "desnoitasse": "desnoitar",
    "desnoitassem": "desnoitar",
    "desnoitasses": "desnoitar",
    "desnoitaste": "desnoitar",
    "desnoitastes": "desnoitar",
    "desnoitava": "desnoitar",
    "desnoitavam": "desnoitar",
    "desnoitavas": "desnoitar",
    "desnoite": "desnoitar",
    "desnoitei": "desnoitar",
    "desnoiteis": "desnoitar",
    "desnoitem": "desnoitar",
    "desnoitemo": "desnoitar",
    "desnoitemos": "desnoitar",
    "desnoites": "desnoitar",
    "desnoito": "desnoitar",
    "desnoitou": "desnoitar",
    "desnoitá": "desnoitar",
    "desnoitámo": "desnoitar",
    "desnoitámos": "desnoitar",
    "desnoitáramo": "desnoitar",
    "desnoitáramos": "desnoitar",
    "desnoitárei": "desnoitar",
    "desnoitáreis": "desnoitar",
    "desnoitásseis": "desnoitar",
    "desnoitássemos": "desnoitar",
    "desnoitávamo": "desnoitar",
    "desnoitávamos": "desnoitar",
    "desnoitávei": "desnoitar",
    "desnoitáveis": "desnoitar",
    "desnoiva": "desnoivar",
    "desnoivada": "desnoivar",
    "desnoivadas": "desnoivar",
    "desnoivado": "desnoivar",
    "desnoivados": "desnoivar",
    "desnoivai": "desnoivar",
    "desnoivais": "desnoivar",
    "desnoivam": "desnoivar",
    "desnoivamo": "desnoivar",
    "desnoivamos": "desnoivar",
    "desnoivando": "desnoivar",
    "desnoivara": "desnoivar",
    "desnoivaram": "desnoivar",
    "desnoivaras": "desnoivar",
    "desnoivarde": "desnoivar",
    "desnoivardes": "desnoivar",
    "desnoivare": "desnoivar",
    "desnoivarei": "desnoivar",
    "desnoivareis": "desnoivar",
    "desnoivarem": "desnoivar",
    "desnoivaremos": "desnoivar",
    "desnoivares": "desnoivar",
    "desnoivaria": "desnoivar",
    "desnoivariam": "desnoivar",
    "desnoivarias": "desnoivar",
    "desnoivarmo": "desnoivar",
    "desnoivarmos": "desnoivar",
    "desnoivará": "desnoivar",
    "desnoivarás": "desnoivar",
    "desnoivarão": "desnoivar",
    "desnoivaríamos": "desnoivar",
    "desnoivaríeis": "desnoivar",
    "desnoivas": "desnoivar",
    "desnoivasse": "desnoivar",
    "desnoivassem": "desnoivar",
    "desnoivasses": "desnoivar",
    "desnoivaste": "desnoivar",
    "desnoivastes": "desnoivar",
    "desnoivava": "desnoivar",
    "desnoivavam": "desnoivar",
    "desnoivavas": "desnoivar",
    "desnoive": "desnoivar",
    "desnoivei": "desnoivar",
    "desnoiveis": "desnoivar",
    "desnoivem": "desnoivar",
    "desnoivemo": "desnoivar",
    "desnoivemos": "desnoivar",
    "desnoives": "desnoivar",
    "desnoivo": "desnoivar",
    "desnoivou": "desnoivar",
    "desnoivá": "desnoivar",
    "desnoivámo": "desnoivar",
    "desnoivámos": "desnoivar",
    "desnoiváramo": "desnoivar",
    "desnoiváramos": "desnoivar",
    "desnoivárei": "desnoivar",
    "desnoiváreis": "desnoivar",
    "desnoivásseis": "desnoivar",
    "desnoivássemos": "desnoivar",
    "desnoivávamo": "desnoivar",
    "desnoivávamos": "desnoivar",
    "desnoivávei": "desnoivar",
    "desnoiváveis": "desnoivar",
    "desnoque": "desnocar",
    "desnoquei": "desnocar",
    "desnoqueis": "desnocar",
    "desnoquem": "desnocar",
    "desnoquemo": "desnocar",
    "desnoquemos": "desnocar",
    "desnoques": "desnocar",
    "desnorteada": "desnortear",
    "desnorteadas": "desnortear",
    "desnorteado": "desnortear",
    "desnorteadora": "desnorteador",
    "desnorteadoras": "desnorteador",
    "desnorteadores": "desnorteador",
    "desnorteados": "desnortear",
    "desnorteadíssima": "desnorteado",
    "desnorteadíssimas": "desnorteado",
    "desnorteadíssimo": "desnorteado",
    "desnorteadíssimos": "desnorteado",
    "desnorteai": "desnortear",
    "desnorteais": "desnortear",
    "desnorteamentos": "desnorteamento",
    "desnorteamo": "desnortear",
    "desnorteamos": "desnortear",
    "desnorteando": "desnortear",
    "desnorteantes": "desnorteante",
    "desnorteara": "desnortear",
    "desnortearam": "desnortear",
    "desnortearas": "desnortear",
    "desnortearde": "desnortear",
    "desnorteardes": "desnortear",
    "desnorteare": "desnortear",
    "desnortearei": "desnortear",
    "desnorteareis": "desnortear",
    "desnortearem": "desnortear",
    "desnortearemos": "desnortear",
    "desnorteares": "desnortear",
    "desnortearia": "desnortear",
    "desnorteariam": "desnortear",
    "desnortearias": "desnortear",
    "desnortearmo": "desnortear",
    "desnortearmos": "desnortear",
    "desnorteará": "desnortear",
    "desnortearás": "desnortear",
    "desnortearão": "desnortear",
    "desnortearíamos": "desnortear",
    "desnortearíeis": "desnortear",
    "desnorteasse": "desnortear",
    "desnorteassem": "desnortear",
    "desnorteasses": "desnortear",
    "desnorteaste": "desnortear",
    "desnorteastes": "desnortear",
    "desnorteava": "desnortear",
    "desnorteavam": "desnortear",
    "desnorteavas": "desnortear",
    "desnorteei": "desnortear",
    "desnorteeis": "desnortear",
    "desnorteemo": "desnortear",
    "desnorteemos": "desnortear",
    "desnorteia": "desnortear",
    "desnorteiam": "desnortear",
    "desnorteias": "desnortear",
    "desnorteie": "desnortear",
    "desnorteiem": "desnortear",
    "desnorteies": "desnortear",
    "desnorteio": "desnortear",
    "desnorteou": "desnortear",
    "desnortes": "desnorte",
    "desnorteá": "desnortear",
    "desnorteámo": "desnortear",
    "desnorteámos": "desnortear",
    "desnorteáramo": "desnortear",
    "desnorteáramos": "desnortear",
    "desnorteárei": "desnortear",
    "desnorteáreis": "desnortear",
    "desnorteásseis": "desnortear",
    "desnorteássemos": "desnortear",
    "desnorteávamo": "desnortear",
    "desnorteávamos": "desnortear",
    "desnorteávei": "desnortear",
    "desnorteáveis": "desnorteável",
    "desnovela": "desnovelar",
    "desnovelada": "desnovelar",
    "desnoveladas": "desnovelar",
    "desnovelado": "desnovelar",
    "desnovelados": "desnovelar",
    "desnovelai": "desnovelar",
    "desnovelais": "desnovelar",
    "desnovelam": "desnovelar",
    "desnovelamo": "desnovelar",
    "desnovelamos": "desnovelar",
    "desnovelando": "desnovelar",
    "desnovelara": "desnovelar",
    "desnovelaram": "desnovelar",
    "desnovelaras": "desnovelar",
    "desnovelarde": "desnovelar",
    "desnovelardes": "desnovelar",
    "desnovelare": "desnovelar",
    "desnovelarei": "desnovelar",
    "desnovelareis": "desnovelar",
    "desnovelarem": "desnovelar",
    "desnovelaremos": "desnovelar",
    "desnovelares": "desnovelar",
    "desnovelaria": "desnovelar",
    "desnovelariam": "desnovelar",
    "desnovelarias": "desnovelar",
    "desnovelarmo": "desnovelar",
    "desnovelarmos": "desnovelar",
    "desnovelará": "desnovelar",
    "desnovelarás": "desnovelar",
    "desnovelarão": "desnovelar",
    "desnovelaríamos": "desnovelar",
    "desnovelaríeis": "desnovelar",
    "desnovelas": "desnovelar",
    "desnovelasse": "desnovelar",
    "desnovelassem": "desnovelar",
    "desnovelasses": "desnovelar",
    "desnovelaste": "desnovelar",
    "desnovelastes": "desnovelar",
    "desnovelava": "desnovelar",
    "desnovelavam": "desnovelar",
    "desnovelavas": "desnovelar",
    "desnovele": "desnovelar",
    "desnovelei": "desnovelar",
    "desnoveleis": "desnovelar",
    "desnovelem": "desnovelar",
    "desnovelemo": "desnovelar",
    "desnovelemos": "desnovelar",
    "desnoveles": "desnovelar",
    "desnovelo": "desnovelar",
    "desnovelou": "desnovelar",
    "desnovelá": "desnovelar",
    "desnovelámo": "desnovelar",
    "desnovelámos": "desnovelar",
    "desnoveláramo": "desnovelar",
    "desnoveláramos": "desnovelar",
    "desnovelárei": "desnovelar",
    "desnoveláreis": "desnovelar",
    "desnovelásseis": "desnovelar",
    "desnovelássemos": "desnovelar",
    "desnovelávamo": "desnovelar",
    "desnovelávamos": "desnovelar",
    "desnovelávei": "desnovelar",
    "desnoveláveis": "desnovelar",
    "desnubla": "desnublar",
    "desnublada": "desnublar",
    "desnubladas": "desnublar",
    "desnublado": "desnublar",
    "desnublados": "desnublar",
    "desnublai": "desnublar",
    "desnublais": "desnublar",
    "desnublam": "desnublar",
    "desnublamo": "desnublar",
    "desnublamos": "desnublar",
    "desnublando": "desnublar",
    "desnublara": "desnublar",
    "desnublaram": "desnublar",
    "desnublaras": "desnublar",
    "desnublardes": "desnublar",
    "desnublarei": "desnublar",
    "desnublareis": "desnublar",
    "desnublarem": "desnublar",
    "desnublaremos": "desnublar",
    "desnublares": "desnublar",
    "desnublaria": "desnublar",
    "desnublariam": "desnublar",
    "desnublarias": "desnublar",
    "desnublarmo": "desnublar",
    "desnublarmos": "desnublar",
    "desnublará": "desnublar",
    "desnublarás": "desnublar",
    "desnublarão": "desnublar",
    "desnublaríamos": "desnublar",
    "desnublaríeis": "desnublar",
    "desnublas": "desnublar",
    "desnublasse": "desnublar",
    "desnublassem": "desnublar",
    "desnublasses": "desnublar",
    "desnublaste": "desnublar",
    "desnublastes": "desnublar",
    "desnublava": "desnublar",
    "desnublavam": "desnublar",
    "desnublavas": "desnublar",
    "desnuble": "desnublar",
    "desnublei": "desnublar",
    "desnubleis": "desnublar",
    "desnublem": "desnublar",
    "desnublemo": "desnublar",
    "desnublemos": "desnublar",
    "desnubles": "desnublar",
    "desnublo": "desnublar",
    "desnublou": "desnublar",
    "desnublámo": "desnublar",
    "desnublámos": "desnublar",
    "desnubláramo": "desnublar",
    "desnubláramos": "desnublar",
    "desnubláreis": "desnublar",
    "desnublásseis": "desnublar",
    "desnublássemos": "desnublar",
    "desnublávamo": "desnublar",
    "desnublávamos": "desnublar",
    "desnubláveis": "desnublar",
    "desnuca": "desnucar",
    "desnucada": "desnucar",
    "desnucadas": "desnucar",
    "desnucado": "desnucar",
    "desnucados": "desnucar",
    "desnucai": "desnucar",
    "desnucais": "desnucar",
    "desnucam": "desnucar",
    "desnucamo": "desnucar",
    "desnucamos": "desnucar",
    "desnucando": "desnucar",
    "desnucara": "desnucar",
    "desnucaram": "desnucar",
    "desnucaras": "desnucar",
    "desnucarde": "desnucar",
    "desnucardes": "desnucar",
    "desnucare": "desnucar",
    "desnucarei": "desnucar",
    "desnucareis": "desnucar",
    "desnucarem": "desnucar",
    "desnucaremos": "desnucar",
    "desnucares": "desnucar",
    "desnucaria": "desnucar",
    "desnucariam": "desnucar",
    "desnucarias": "desnucar",
    "desnucarmo": "desnucar",
    "desnucarmos": "desnucar",
    "desnucará": "desnucar",
    "desnucarás": "desnucar",
    "desnucarão": "desnucar",
    "desnucaríamos": "desnucar",
    "desnucaríeis": "desnucar",
    "desnucas": "desnucar",
    "desnucasse": "desnucar",
    "desnucassem": "desnucar",
    "desnucasses": "desnucar",
    "desnucaste": "desnucar",
    "desnucastes": "desnucar",
    "desnucava": "desnucar",
    "desnucavam": "desnucar",
    "desnucavas": "desnucar",
    "desnuco": "desnucar",
    "desnucou": "desnucar",
    "desnucá": "desnucar",
    "desnucámo": "desnucar",
    "desnucámos": "desnucar",
    "desnucáramo": "desnucar",
    "desnucáramos": "desnucar",
    "desnucárei": "desnucar",
    "desnucáreis": "desnucar",
    "desnucásseis": "desnucar",
    "desnucássemos": "desnucar",
    "desnucávamo": "desnucar",
    "desnucávamos": "desnucar",
    "desnucávei": "desnucar",
    "desnucáveis": "desnucar",
    "desnuda": "desnudo",
    "desnudada": "desnudar",
    "desnudadas": "desnudar",
    "desnudado": "desnudar",
    "desnudados": "desnudar",
    "desnudai": "desnudar",
    "desnudais": "desnudar",
    "desnudam": "desnudar",
    "desnudamentos": "desnudamento",
    "desnudamo": "desnudar",
    "desnudamos": "desnudar",
    "desnudando": "desnudar",
    "desnudara": "desnudar",
    "desnudaram": "desnudar",
    "desnudaras": "desnudar",
    "desnudarde": "desnudar",
    "desnudardes": "desnudar",
    "desnudare": "desnudar",
    "desnudarei": "desnudar",
    "desnudareis": "desnudar",
    "desnudarem": "desnudar",
    "desnudaremos": "desnudar",
    "desnudares": "desnudar",
    "desnudaria": "desnudar",
    "desnudariam": "desnudar",
    "desnudarias": "desnudar",
    "desnudarmo": "desnudar",
    "desnudarmos": "desnudar",
    "desnudará": "desnudar",
    "desnudarás": "desnudar",
    "desnudarão": "desnudar",
    "desnudaríamos": "desnudar",
    "desnudaríeis": "desnudar",
    "desnudas": "desnudo",
    "desnudasse": "desnudar",
    "desnudassem": "desnudar",
    "desnudasses": "desnudar",
    "desnudaste": "desnudar",
    "desnudastes": "desnudar",
    "desnudava": "desnudar",
    "desnudavam": "desnudar",
    "desnudavas": "desnudar",
    "desnudações": "desnudação",
    "desnude": "desnudar",
    "desnudei": "desnudar",
    "desnudeis": "desnudar",
    "desnudem": "desnudar",
    "desnudemo": "desnudar",
    "desnudemos": "desnudar",
    "desnudes": "desnudar",
    "desnudezes": "desnudez",
    "desnudo": "desnudar",
    "desnudos": "desnudo",
    "desnudou": "desnudar",
    "desnudá": "desnudar",
    "desnudámo": "desnudar",
    "desnudámos": "desnudar",
    "desnudáramo": "desnudar",
    "desnudáramos": "desnudar",
    "desnudárei": "desnudar",
    "desnudáreis": "desnudar",
    "desnudásseis": "desnudar",
    "desnudássemos": "desnudar",
    "desnudávamo": "desnudar",
    "desnudávamos": "desnudar",
    "desnudávei": "desnudar",
    "desnudáveis": "desnudar",
    "desnuque": "desnucar",
    "desnuquei": "desnucar",
    "desnuqueis": "desnucar",
    "desnuquem": "desnucar",
    "desnuquemo": "desnucar",
    "desnuquemos": "desnucar",
    "desnuques": "desnucar",
    "desnutra": "desnutrir",
    "desnutrais": "desnutrir",
    "desnutram": "desnutrir",
    "desnutramo": "desnutrir",
    "desnutramos": "desnutrir",
    "desnutras": "desnutrir",
    "desnutre": "desnutrir",
    "desnutrem": "desnutrir",
    "desnutres": "desnutrir",
    "desnutri": "desnutrir",
    "desnutria": "desnutrir",
    "desnutriam": "desnutrir",
    "desnutrias": "desnutrir",
    "desnutrida": "desnutrir",
    "desnutridas": "desnutrir",
    "desnutrido": "desnutrir",
    "desnutridos": "desnutrir",
    "desnutrientes": "desnutriente",
    "desnutrimo": "desnutrir",
    "desnutrimos": "desnutrir",
    "desnutrindo": "desnutrir",
    "desnutrira": "desnutrir",
    "desnutriram": "desnutrir",
    "desnutriras": "desnutrir",
    "desnutrirde": "desnutrir",
    "desnutrirdes": "desnutrir",
    "desnutrire": "desnutrir",
    "desnutrirei": "desnutrir",
    "desnutrireis": "desnutrir",
    "desnutrirem": "desnutrir",
    "desnutriremos": "desnutrir",
    "desnutrires": "desnutrir",
    "desnutriria": "desnutrir",
    "desnutririam": "desnutrir",
    "desnutririas": "desnutrir",
    "desnutrirmo": "desnutrir",
    "desnutrirmos": "desnutrir",
    "desnutrirá": "desnutrir",
    "desnutrirás": "desnutrir",
    "desnutrirão": "desnutrir",
    "desnutriríamos": "desnutrir",
    "desnutriríeis": "desnutrir",
    "desnutris": "desnutrir",
    "desnutrisse": "desnutrir",
    "desnutrissem": "desnutrir",
    "desnutrisses": "desnutrir",
    "desnutriste": "desnutrir",
    "desnutristes": "desnutrir",
    "desnutriu": "desnutrir",
    "desnutrições": "desnutrição",
    "desnutro": "desnutrir",
    "desnutríamo": "desnutrir",
    "desnutríamos": "desnutrir",
    "desnutríei": "desnutrir",
    "desnutríeis": "desnutrir",
    "desnutríramo": "desnutrir",
    "desnutríramos": "desnutrir",
    "desnutrírei": "desnutrir",
    "desnutríreis": "desnutrir",
    "desnutrísseis": "desnutrir",
    "desnutríssemos": "desnutrir",
    "desníveis": "desnível",
    "desobedece": "desobedecer",
    "desobedecei": "desobedecer",
    "desobedeceis": "desobedecer",
    "desobedecem": "desobedecer",
    "desobedecemo": "desobedecer",
    "desobedecemos": "desobedecer",
    "desobedecendo": "desobedecer",
    "desobedecera": "desobedecer",
    "desobedeceram": "desobedecer",
    "desobedeceras": "desobedecer",
    "desobedecerde": "desobedecer",
    "desobedecerdes": "desobedecer",
    "desobedecere": "desobedecer",
    "desobedecerei": "desobedecer",
    "desobedecereis": "desobedecer",
    "desobedecerem": "desobedecer",
    "desobedeceremos": "desobedecer",
    "desobedeceres": "desobedecer",
    "desobedeceria": "desobedecer",
    "desobedeceriam": "desobedecer",
    "desobedecerias": "desobedecer",
    "desobedecermo": "desobedecer",
    "desobedecermos": "desobedecer",
    "desobedecerá": "desobedecer",
    "desobedecerás": "desobedecer",
    "desobedecerão": "desobedecer",
    "desobedeceríamos": "desobedecer",
    "desobedeceríeis": "desobedecer",
    "desobedeces": "desobedecer",
    "desobedecesse": "desobedecer",
    "desobedecessem": "desobedecer",
    "desobedecesses": "desobedecer",
    "desobedeceste": "desobedecer",
    "desobedecestes": "desobedecer",
    "desobedeceu": "desobedecer",
    "desobedeci": "desobedecer",
    "desobedecia": "desobedecer",
    "desobedeciam": "desobedecer",
    "desobedecias": "desobedecer",
    "desobedecida": "desobedecido",
    "desobedecidas": "desobedecido",
    "desobedecido": "desobedecer",
    "desobedecidos": "desobedecido",
    "desobedecê": "desobedecer",
    "desobedecêramo": "desobedecer",
    "desobedecêramos": "desobedecer",
    "desobedecêrei": "desobedecer",
    "desobedecêreis": "desobedecer",
    "desobedecêsseis": "desobedecer",
    "desobedecêssemos": "desobedecer",
    "desobedecíamo": "desobedecer",
    "desobedecíamos": "desobedecer",
    "desobedecíei": "desobedecer",
    "desobedecíeis": "desobedecer",
    "desobedeça": "desobedecer",
    "desobedeçais": "desobedecer",
    "desobedeçam": "desobedecer",
    "desobedeçamo": "desobedecer",
    "desobedeçamos": "desobedecer",
    "desobedeças": "desobedecer",
    "desobedeço": "desobedecer",
    "desobedientes": "desobediente",
    "desobediências": "desobediência",
    "desobriga": "desobrigar",
    "desobrigada": "desobrigar",
    "desobrigadas": "desobrigar",
    "desobrigado": "desobrigar",
    "desobrigados": "desobrigar",
    "desobrigai": "desobrigar",
    "desobrigais": "desobrigar",
    "desobrigam": "desobrigar",
    "desobrigamo": "desobrigar",
    "desobrigamos": "desobrigar",
    "desobrigando": "desobrigar",
    "desobrigara": "desobrigar",
    "desobrigaram": "desobrigar",
    "desobrigaras": "desobrigar",
    "desobrigarde": "desobrigar",
    "desobrigardes": "desobrigar",
    "desobrigare": "desobrigar",
    "desobrigarei": "desobrigar",
    "desobrigareis": "desobrigar",
    "desobrigarem": "desobrigar",
    "desobrigaremos": "desobrigar",
    "desobrigares": "desobrigar",
    "desobrigaria": "desobrigar",
    "desobrigariam": "desobrigar",
    "desobrigarias": "desobrigar",
    "desobrigarmo": "desobrigar",
    "desobrigarmos": "desobrigar",
    "desobrigará": "desobrigar",
    "desobrigarás": "desobrigar",
    "desobrigarão": "desobrigar",
    "desobrigaríamos": "desobrigar",
    "desobrigaríeis": "desobrigar",
    "desobrigas": "desobrigar",
    "desobrigasse": "desobrigar",
    "desobrigassem": "desobrigar",
    "desobrigasses": "desobrigar",
    "desobrigaste": "desobrigar",
    "desobrigastes": "desobrigar",
    "desobrigatória": "desobrigatório",
    "desobrigatórias": "desobrigatório",
    "desobrigatórios": "desobrigatório",
    "desobrigava": "desobrigar",
    "desobrigavam": "desobrigar",
    "desobrigavas": "desobrigar",
    "desobrigações": "desobrigação",
    "desobrigo": "desobrigar",
    "desobrigou": "desobrigar",
    "desobrigue": "desobrigar",
    "desobriguei": "desobrigar",
    "desobrigueis": "desobrigar",
    "desobriguem": "desobrigar",
    "desobriguemo": "desobrigar",
    "desobriguemos": "desobrigar",
    "desobrigues": "desobrigar",
    "desobrigá": "desobrigar",
    "desobrigámo": "desobrigar",
    "desobrigámos": "desobrigar",
    "desobrigáramo": "desobrigar",
    "desobrigáramos": "desobrigar",
    "desobrigárei": "desobrigar",
    "desobrigáreis": "desobrigar",
    "desobrigásseis": "desobrigar",
    "desobrigássemos": "desobrigar",
    "desobrigávamo": "desobrigar",
    "desobrigávamos": "desobrigar",
    "desobrigávei": "desobrigar",
    "desobrigáveis": "desobrigar",
    "desobscurece": "desobscurecer",
    "desobscurecei": "desobscurecer",
    "desobscureceis": "desobscurecer",
    "desobscurecem": "desobscurecer",
    "desobscurecemo": "desobscurecer",
    "desobscurecemos": "desobscurecer",
    "desobscurecendo": "desobscurecer",
    "desobscurecera": "desobscurecer",
    "desobscureceram": "desobscurecer",
    "desobscureceras": "desobscurecer",
    "desobscurecerde": "desobscurecer",
    "desobscurecerdes": "desobscurecer",
    "desobscurecere": "desobscurecer",
    "desobscurecerei": "desobscurecer",
    "desobscurecereis": "desobscurecer",
    "desobscurecerem": "desobscurecer",
    "desobscureceremos": "desobscurecer",
    "desobscureceres": "desobscurecer",
    "desobscureceria": "desobscurecer",
    "desobscureceriam": "desobscurecer",
    "desobscurecerias": "desobscurecer",
    "desobscurecermo": "desobscurecer",
    "desobscurecermos": "desobscurecer",
    "desobscurecerá": "desobscurecer",
    "desobscurecerás": "desobscurecer",
    "desobscurecerão": "desobscurecer",
    "desobscureceríamos": "desobscurecer",
    "desobscureceríeis": "desobscurecer",
    "desobscureces": "desobscurecer",
    "desobscurecesse": "desobscurecer",
    "desobscurecessem": "desobscurecer",
    "desobscurecesses": "desobscurecer",
    "desobscureceste": "desobscurecer",
    "desobscurecestes": "desobscurecer",
    "desobscureceu": "desobscurecer",
    "desobscureci": "desobscurecer",
    "desobscurecia": "desobscurecer",
    "desobscureciam": "desobscurecer",
    "desobscurecias": "desobscurecer",
    "desobscurecida": "desobscurecido",
    "desobscurecidas": "desobscurecido",
    "desobscurecido": "desobscurecer",
    "desobscurecidos": "desobscurecido",
    "desobscurecê": "desobscurecer",
    "desobscurecêramo": "desobscurecer",
    "desobscurecêramos": "desobscurecer",
    "desobscurecêrei": "desobscurecer",
    "desobscurecêreis": "desobscurecer",
    "desobscurecêsseis": "desobscurecer",
    "desobscurecêssemos": "desobscurecer",
    "desobscurecíamo": "desobscurecer",
    "desobscurecíamos": "desobscurecer",
    "desobscurecíei": "desobscurecer",
    "desobscurecíeis": "desobscurecer",
    "desobscureça": "desobscurecer",
    "desobscureçais": "desobscurecer",
    "desobscureçam": "desobscurecer",
    "desobscureçamo": "desobscurecer",
    "desobscureçamos": "desobscurecer",
    "desobscureças": "desobscurecer",
    "desobscureço": "desobscurecer",
    "desobstinada": "desobstinado",
    "desobstinadas": "desobstinado",
    "desobstinados": "desobstinado",
    "desobstrua": "desobstruir",
    "desobstruais": "desobstruir",
    "desobstruam": "desobstruir",
    "desobstruamo": "desobstruir",
    "desobstruamos": "desobstruir",
    "desobstruas": "desobstruir",
    "desobstruem": "desobstruir",
    "desobstruentes": "desobstruente",
    "desobstrui": "desobstruir",
    "desobstruindo": "desobstruir",
    "desobstruirde": "desobstruir",
    "desobstruirdes": "desobstruir",
    "desobstruirei": "desobstruir",
    "desobstruireis": "desobstruir",
    "desobstruiremos": "desobstruir",
    "desobstruiria": "desobstruir",
    "desobstruiriam": "desobstruir",
    "desobstruirias": "desobstruir",
    "desobstruirmo": "desobstruir",
    "desobstruirmos": "desobstruir",
    "desobstruirá": "desobstruir",
    "desobstruirás": "desobstruir",
    "desobstruirão": "desobstruir",
    "desobstruiríamos": "desobstruir",
    "desobstruiríeis": "desobstruir",
    "desobstruis": "desobstruir",
    "desobstruiu": "desobstruir",
    "desobstruo": "desobstruir",
    "desobstrutiva": "desobstrutivo",
    "desobstrutivas": "desobstrutivo",
    "desobstrutivos": "desobstrutivo",
    "desobstruções": "desobstrução",
    "desobstruí": "desobstruir",
    "desobstruía": "desobstruir",
    "desobstruíam": "desobstruir",
    "desobstruíamo": "desobstruir",
    "desobstruíamos": "desobstruir",
    "desobstruías": "desobstruir",
    "desobstruída": "desobstruir",
    "desobstruídas": "desobstruir",
    "desobstruído": "desobstruir",
    "desobstruídos": "desobstruir",
    "desobstruíei": "desobstruir",
    "desobstruíeis": "desobstruir",
    "desobstruímo": "desobstruir",
    "desobstruímos": "desobstruir",
    "desobstruíra": "desobstruir",
    "desobstruíram": "desobstruir",
    "desobstruíramo": "desobstruir",
    "desobstruíramos": "desobstruir",
    "desobstruíras": "desobstruir",
    "desobstruíre": "desobstruir",
    "desobstruírei": "desobstruir",
    "desobstruíreis": "desobstruir",
    "desobstruírem": "desobstruir",
    "desobstruíres": "desobstruir",
    "desobstruís": "desobstruir",
    "desobstruísse": "desobstruir",
    "desobstruísseis": "desobstruir",
    "desobstruíssem": "desobstruir",
    "desobstruíssemos": "desobstruir",
    "desobstruísses": "desobstruir",
    "desobstruíste": "desobstruir",
    "desobstruístes": "desobstruir",
    "desocasionada": "desocasionado",
    "desocasionadas": "desocasionado",
    "desocasionados": "desocasionado",
    "desocupa": "desocupar",
    "desocupada": "desocupar",
    "desocupadas": "desocupar",
    "desocupado": "desocupar",
    "desocupados": "desocupar",
    "desocupai": "desocupar",
    "desocupais": "desocupar",
    "desocupam": "desocupar",
    "desocupamo": "desocupar",
    "desocupamos": "desocupar",
    "desocupando": "desocupar",
    "desocupara": "desocupar",
    "desocuparam": "desocupar",
    "desocuparas": "desocupar",
    "desocuparde": "desocupar",
    "desocupardes": "desocupar",
    "desocupare": "desocupar",
    "desocuparei": "desocupar",
    "desocupareis": "desocupar",
    "desocuparem": "desocupar",
    "desocuparemos": "desocupar",
    "desocupares": "desocupar",
    "desocuparia": "desocupar",
    "desocupariam": "desocupar",
    "desocuparias": "desocupar",
    "desocuparmo": "desocupar",
    "desocuparmos": "desocupar",
    "desocupará": "desocupar",
    "desocuparás": "desocupar",
    "desocuparão": "desocupar",
    "desocuparíamos": "desocupar",
    "desocuparíeis": "desocupar",
    "desocupas": "desocupar",
    "desocupasse": "desocupar",
    "desocupassem": "desocupar",
    "desocupasses": "desocupar",
    "desocupaste": "desocupar",
    "desocupastes": "desocupar",
    "desocupava": "desocupar",
    "desocupavam": "desocupar",
    "desocupavas": "desocupar",
    "desocupações": "desocupação",
    "desocupe": "desocupar",
    "desocupei": "desocupar",
    "desocupeis": "desocupar",
    "desocupem": "desocupar",
    "desocupemo": "desocupar",
    "desocupemos": "desocupar",
    "desocupes": "desocupar",
    "desocupo": "desocupar",
    "desocupou": "desocupar",
    "desocupá": "desocupar",
    "desocupámo": "desocupar",
    "desocupámos": "desocupar",
    "desocupáramo": "desocupar",
    "desocupáramos": "desocupar",
    "desocupárei": "desocupar",
    "desocupáreis": "desocupar",
    "desocupásseis": "desocupar",
    "desocupássemos": "desocupar",
    "desocupávamo": "desocupar",
    "desocupávamos": "desocupar",
    "desocupávei": "desocupar",
    "desocupáveis": "desocupar",
    "desodorantes": "desodorante",
    "desodoriza": "desodorizar",
    "desodorizada": "desodorizar",
    "desodorizadas": "desodorizar",
    "desodorizado": "desodorizar",
    "desodorizados": "desodorizar",
    "desodorizai": "desodorizar",
    "desodorizais": "desodorizar",
    "desodorizam": "desodorizar",
    "desodorizamo": "desodorizar",
    "desodorizamos": "desodorizar",
    "desodorizando": "desodorizar",
    "desodorizantes": "desodorizante",
    "desodorizara": "desodorizar",
    "desodorizaram": "desodorizar",
    "desodorizaras": "desodorizar",
    "desodorizarde": "desodorizar",
    "desodorizardes": "desodorizar",
    "desodorizare": "desodorizar",
    "desodorizarei": "desodorizar",
    "desodorizareis": "desodorizar",
    "desodorizarem": "desodorizar",
    "desodorizaremos": "desodorizar",
    "desodorizares": "desodorizar",
    "desodorizaria": "desodorizar",
    "desodorizariam": "desodorizar",
    "desodorizarias": "desodorizar",
    "desodorizarmo": "desodorizar",
    "desodorizarmos": "desodorizar",
    "desodorizará": "desodorizar",
    "desodorizarás": "desodorizar",
    "desodorizarão": "desodorizar",
    "desodorizaríamos": "desodorizar",
    "desodorizaríeis": "desodorizar",
    "desodorizas": "desodorizar",
    "desodorizasse": "desodorizar",
    "desodorizassem": "desodorizar",
    "desodorizasses": "desodorizar",
    "desodorizaste": "desodorizar",
    "desodorizastes": "desodorizar",
    "desodorizava": "desodorizar",
    "desodorizavam": "desodorizar",
    "desodorizavas": "desodorizar",
    "desodorize": "desodorizar",
    "desodorizei": "desodorizar",
    "desodorizeis": "desodorizar",
    "desodorizem": "desodorizar",
    "desodorizemo": "desodorizar",
    "desodorizemos": "desodorizar",
    "desodorizes": "desodorizar",
    "desodorizo": "desodorizar",
    "desodorizou": "desodorizar",
    "desodorizá": "desodorizar",
    "desodorizámo": "desodorizar",
    "desodorizámos": "desodorizar",
    "desodorizáramo": "desodorizar",
    "desodorizáramos": "desodorizar",
    "desodorizárei": "desodorizar",
    "desodorizáreis": "desodorizar",
    "desodorizásseis": "desodorizar",
    "desodorizássemos": "desodorizar",
    "desodorizávamo": "desodorizar",
    "desodorizávamos": "desodorizar",
    "desodorizávei": "desodorizar",
    "desodorizáveis": "desodorizar",
    "desoficializa": "desoficializar",
    "desoficializada": "desoficializar",
    "desoficializadas": "desoficializar",
    "desoficializado": "desoficializar",
    "desoficializados": "desoficializar",
    "desoficializai": "desoficializar",
    "desoficializais": "desoficializar",
    "desoficializam": "desoficializar",
    "desoficializamo": "desoficializar",
    "desoficializamos": "desoficializar",
    "desoficializando": "desoficializar",
    "desoficializara": "desoficializar",
    "desoficializaram": "desoficializar",
    "desoficializaras": "desoficializar",
    "desoficializarde": "desoficializar",
    "desoficializardes": "desoficializar",
    "desoficializare": "desoficializar",
    "desoficializarei": "desoficializar",
    "desoficializareis": "desoficializar",
    "desoficializarem": "desoficializar",
    "desoficializaremos": "desoficializar",
    "desoficializares": "desoficializar",
    "desoficializaria": "desoficializar",
    "desoficializariam": "desoficializar",
    "desoficializarias": "desoficializar",
    "desoficializarmo": "desoficializar",
    "desoficializarmos": "desoficializar",
    "desoficializará": "desoficializar",
    "desoficializarás": "desoficializar",
    "desoficializarão": "desoficializar",
    "desoficializaríamos": "desoficializar",
    "desoficializaríeis": "desoficializar",
    "desoficializas": "desoficializar",
    "desoficializasse": "desoficializar",
    "desoficializassem": "desoficializar",
    "desoficializasses": "desoficializar",
    "desoficializaste": "desoficializar",
    "desoficializastes": "desoficializar",
    "desoficializava": "desoficializar",
    "desoficializavam": "desoficializar",
    "desoficializavas": "desoficializar",
    "desoficializações": "desoficialização",
    "desoficialize": "desoficializar",
    "desoficializei": "desoficializar",
    "desoficializeis": "desoficializar",
    "desoficializem": "desoficializar",
    "desoficializemo": "desoficializar",
    "desoficializemos": "desoficializar",
    "desoficializes": "desoficializar",
    "desoficializo": "desoficializar",
    "desoficializou": "desoficializar",
    "desoficializá": "desoficializar",
    "desoficializámo": "desoficializar",
    "desoficializámos": "desoficializar",
    "desoficializáramo": "desoficializar",
    "desoficializáramos": "desoficializar",
    "desoficializárei": "desoficializar",
    "desoficializáreis": "desoficializar",
    "desoficializásseis": "desoficializar",
    "desoficializássemos": "desoficializar",
    "desoficializávamo": "desoficializar",
    "desoficializávamos": "desoficializar",
    "desoficializávei": "desoficializar",
    "desoficializáveis": "desoficializar",
    "desofusca": "desofuscar",
    "desofuscada": "desofuscar",
    "desofuscadas": "desofuscar",
    "desofuscado": "desofuscar",
    "desofuscados": "desofuscar",
    "desofuscai": "desofuscar",
    "desofuscais": "desofuscar",
    "desofuscam": "desofuscar",
    "desofuscamo": "desofuscar",
    "desofuscamos": "desofuscar",
    "desofuscando": "desofuscar",
    "desofuscara": "desofuscar",
    "desofuscaram": "desofuscar",
    "desofuscaras": "desofuscar",
    "desofuscarde": "desofuscar",
    "desofuscardes": "desofuscar",
    "desofuscare": "desofuscar",
    "desofuscarei": "desofuscar",
    "desofuscareis": "desofuscar",
    "desofuscarem": "desofuscar",
    "desofuscaremos": "desofuscar",
    "desofuscares": "desofuscar",
    "desofuscaria": "desofuscar",
    "desofuscariam": "desofuscar",
    "desofuscarias": "desofuscar",
    "desofuscarmo": "desofuscar",
    "desofuscarmos": "desofuscar",
    "desofuscará": "desofuscar",
    "desofuscarás": "desofuscar",
    "desofuscarão": "desofuscar",
    "desofuscaríamos": "desofuscar",
    "desofuscaríeis": "desofuscar",
    "desofuscas": "desofuscar",
    "desofuscasse": "desofuscar",
    "desofuscassem": "desofuscar",
    "desofuscasses": "desofuscar",
    "desofuscaste": "desofuscar",
    "desofuscastes": "desofuscar",
    "desofuscava": "desofuscar",
    "desofuscavam": "desofuscar",
    "desofuscavas": "desofuscar",
    "desofusco": "desofuscar",
    "desofuscou": "desofuscar",
    "desofuscá": "desofuscar",
    "desofuscámo": "desofuscar",
    "desofuscámos": "desofuscar",
    "desofuscáramo": "desofuscar",
    "desofuscáramos": "desofuscar",
    "desofuscárei": "desofuscar",
    "desofuscáreis": "desofuscar",
    "desofuscásseis": "desofuscar",
    "desofuscássemos": "desofuscar",
    "desofuscávamo": "desofuscar",
    "desofuscávamos": "desofuscar",
    "desofuscávei": "desofuscar",
    "desofuscáveis": "desofuscar",
    "desofusque": "desofuscar",
    "desofusquei": "desofuscar",
    "desofusqueis": "desofuscar",
    "desofusquem": "desofuscar",
    "desofusquemo": "desofuscar",
    "desofusquemos": "desofuscar",
    "desofusques": "desofuscar",
    "desola": "desolar",
    "desolada": "desolar",
    "desoladas": "desolar",
    "desolado": "desolar",
    "desoladora": "desolador",
    "desoladoras": "desolador",
    "desoladores": "desolador",
    "desolados": "desolar",
    "desoladíssima": "desolado",
    "desoladíssimas": "desolado",
    "desoladíssimo": "desolado",
    "desoladíssimos": "desolado",
    "desolai": "desolar",
    "desolais": "desolar",
    "desolam": "desolar",
    "desolamentos": "desolamento",
    "desolamo": "desolar",
    "desolamos": "desolar",
    "desolando": "desolar",
    "desolara": "desolar",
    "desolaram": "desolar",
    "desolaras": "desolar",
    "desolarde": "desolar",
    "desolardes": "desolar",
    "desolare": "desolar",
    "desolarei": "desolar",
    "desolareis": "desolar",
    "desolarem": "desolar",
    "desolaremos": "desolar",
    "desolares": "desolar",
    "desolaria": "desolar",
    "desolariam": "desolar",
    "desolarias": "desolar",
    "desolarmo": "desolar",
    "desolarmos": "desolar",
    "desolará": "desolar",
    "desolarás": "desolar",
    "desolarão": "desolar",
    "desolaríamos": "desolar",
    "desolaríeis": "desolar",
    "desolas": "desolar",
    "desolasse": "desolar",
    "desolassem": "desolar",
    "desolasses": "desolar",
    "desolaste": "desolar",
    "desolastes": "desolar",
    "desolava": "desolar",
    "desolavam": "desolar",
    "desolavas": "desolar",
    "desolações": "desolação",
    "desole": "desolar",
    "desolei": "desolar",
    "desoleifica": "desoleificar",
    "desoleificada": "desoleificar",
    "desoleificadas": "desoleificar",
    "desoleificado": "desoleificar",
    "desoleificados": "desoleificar",
    "desoleificai": "desoleificar",
    "desoleificais": "desoleificar",
    "desoleificam": "desoleificar",
    "desoleificamo": "desoleificar",
    "desoleificamos": "desoleificar",
    "desoleificando": "desoleificar",
    "desoleificara": "desoleificar",
    "desoleificaram": "desoleificar",
    "desoleificaras": "desoleificar",
    "desoleificarde": "desoleificar",
    "desoleificardes": "desoleificar",
    "desoleificare": "desoleificar",
    "desoleificarei": "desoleificar",
    "desoleificareis": "desoleificar",
    "desoleificarem": "desoleificar",
    "desoleificaremos": "desoleificar",
    "desoleificares": "desoleificar",
    "desoleificaria": "desoleificar",
    "desoleificariam": "desoleificar",
    "desoleificarias": "desoleificar",
    "desoleificarmo": "desoleificar",
    "desoleificarmos": "desoleificar",
    "desoleificará": "desoleificar",
    "desoleificarás": "desoleificar",
    "desoleificarão": "desoleificar",
    "desoleificaríamos": "desoleificar",
    "desoleificaríeis": "desoleificar",
    "desoleificas": "desoleificar",
    "desoleificasse": "desoleificar",
    "desoleificassem": "desoleificar",
    "desoleificasses": "desoleificar",
    "desoleificaste": "desoleificar",
    "desoleificastes": "desoleificar",
    "desoleificava": "desoleificar",
    "desoleificavam": "desoleificar",
    "desoleificavas": "desoleificar",
    "desoleifico": "desoleificar",
    "desoleificou": "desoleificar",
    "desoleificá": "desoleificar",
    "desoleificámo": "desoleificar",
    "desoleificámos": "desoleificar",
    "desoleificáramo": "desoleificar",
    "desoleificáramos": "desoleificar",
    "desoleificárei": "desoleificar",
    "desoleificáreis": "desoleificar",
    "desoleificásseis": "desoleificar",
    "desoleificássemos": "desoleificar",
    "desoleificávamo": "desoleificar",
    "desoleificávamos": "desoleificar",
    "desoleificávei": "desoleificar",
    "desoleificáveis": "desoleificar",
    "desoleifique": "desoleificar",
    "desoleifiquei": "desoleificar",
    "desoleifiqueis": "desoleificar",
    "desoleifiquem": "desoleificar",
    "desoleifiquemo": "desoleificar",
    "desoleifiquemos": "desoleificar",
    "desoleifiques": "desoleificar",
    "desoleis": "desolar",
    "desolem": "desolar",
    "desolemo": "desolar",
    "desolemos": "desolar",
    "desoles": "desolar",
    "desolha": "desolhar",
    "desolhada": "desolhar",
    "desolhadas": "desolhar",
    "desolhado": "desolhar",
    "desolhados": "desolhar",
    "desolhai": "desolhar",
    "desolhais": "desolhar",
    "desolham": "desolhar",
    "desolhamo": "desolhar",
    "desolhamos": "desolhar",
    "desolhando": "desolhar",
    "desolhara": "desolhar",
    "desolharam": "desolhar",
    "desolharas": "desolhar",
    "desolharde": "desolhar",
    "desolhardes": "desolhar",
    "desolhare": "desolhar",
    "desolharei": "desolhar",
    "desolhareis": "desolhar",
    "desolharem": "desolhar",
    "desolharemos": "desolhar",
    "desolhares": "desolhar",
    "desolharia": "desolhar",
    "desolhariam": "desolhar",
    "desolharias": "desolhar",
    "desolharmo": "desolhar",
    "desolharmos": "desolhar",
    "desolhará": "desolhar",
    "desolharás": "desolhar",
    "desolharão": "desolhar",
    "desolharíamos": "desolhar",
    "desolharíeis": "desolhar",
    "desolhas": "desolhar",
    "desolhasse": "desolhar",
    "desolhassem": "desolhar",
    "desolhasses": "desolhar",
    "desolhaste": "desolhar",
    "desolhastes": "desolhar",
    "desolhava": "desolhar",
    "desolhavam": "desolhar",
    "desolhavas": "desolhar",
    "desolhe": "desolhar",
    "desolhei": "desolhar",
    "desolheis": "desolhar",
    "desolhem": "desolhar",
    "desolhemo": "desolhar",
    "desolhemos": "desolhar",
    "desolhes": "desolhar",
    "desolho": "desolhar",
    "desolhou": "desolhar",
    "desolhá": "desolhar",
    "desolhámo": "desolhar",
    "desolhámos": "desolhar",
    "desolháramo": "desolhar",
    "desolháramos": "desolhar",
    "desolhárei": "desolhar",
    "desolháreis": "desolhar",
    "desolhásseis": "desolhar",
    "desolhássemos": "desolhar",
    "desolhávamo": "desolhar",
    "desolhávamos": "desolhar",
    "desolhávei": "desolhar",
    "desolháveis": "desolhar",
    "desolo": "desolar",
    "desolou": "desolar",
    "desolá": "desolar",
    "desolámo": "desolar",
    "desolámos": "desolar",
    "desoláramo": "desolar",
    "desoláramos": "desolar",
    "desolárei": "desolar",
    "desoláreis": "desolar",
    "desolásseis": "desolar",
    "desolássemos": "desolar",
    "desolávamo": "desolar",
    "desolávamos": "desolar",
    "desolávei": "desolar",
    "desoláveis": "desolar",
    "desonera": "desonerar",
    "desonerada": "desonerar",
    "desoneradas": "desonerar",
    "desonerado": "desonerar",
    "desonerados": "desonerar",
    "desonerai": "desonerar",
    "desonerais": "desonerar",
    "desoneram": "desonerar",
    "desoneramo": "desonerar",
    "desoneramos": "desonerar",
    "desonerando": "desonerar",
    "desonerara": "desonerar",
    "desoneraram": "desonerar",
    "desoneraras": "desonerar",
    "desonerarde": "desonerar",
    "desonerardes": "desonerar",
    "desonerare": "desonerar",
    "desonerarei": "desonerar",
    "desonerareis": "desonerar",
    "desonerarem": "desonerar",
    "desoneraremos": "desonerar",
    "desonerares": "desonerar",
    "desoneraria": "desonerar",
    "desonerariam": "desonerar",
    "desonerarias": "desonerar",
    "desonerarmo": "desonerar",
    "desonerarmos": "desonerar",
    "desonerará": "desonerar",
    "desonerarás": "desonerar",
    "desonerarão": "desonerar",
    "desoneraríamos": "desonerar",
    "desoneraríeis": "desonerar",
    "desoneras": "desonerar",
    "desonerasse": "desonerar",
    "desonerassem": "desonerar",
    "desonerasses": "desonerar",
    "desoneraste": "desonerar",
    "desonerastes": "desonerar",
    "desonerava": "desonerar",
    "desoneravam": "desonerar",
    "desoneravas": "desonerar",
    "desonerações": "desoneração",
    "desonere": "desonerar",
    "desonerei": "desonerar",
    "desonereis": "desonerar",
    "desonerem": "desonerar",
    "desoneremo": "desonerar",
    "desoneremos": "desonerar",
    "desoneres": "desonerar",
    "desonero": "desonerar",
    "desonerou": "desonerar",
    "desonerá": "desonerar",
    "desonerámo": "desonerar",
    "desonerámos": "desonerar",
    "desoneráramo": "desonerar",
    "desoneráramos": "desonerar",
    "desonerárei": "desonerar",
    "desoneráreis": "desonerar",
    "desonerásseis": "desonerar",
    "desonerássemos": "desonerar",
    "desonerávamo": "desonerar",
    "desonerávamos": "desonerar",
    "desonerávei": "desonerar",
    "desoneráveis": "desonerar",
    "desonesta": "desonesto",
    "desonestada": "desonestar",
    "desonestadas": "desonestar",
    "desonestado": "desonestar",
    "desonestados": "desonestar",
    "desonestai": "desonestar",
    "desonestais": "desonestar",
    "desonestam": "desonestar",
    "desonestamo": "desonestar",
    "desonestamos": "desonestar",
    "desonestando": "desonestar",
    "desonestara": "desonestar",
    "desonestaram": "desonestar",
    "desonestaras": "desonestar",
    "desonestarde": "desonestar",
    "desonestardes": "desonestar",
    "desonestare": "desonestar",
    "desonestarei": "desonestar",
    "desonestareis": "desonestar",
    "desonestarem": "desonestar",
    "desonestaremos": "desonestar",
    "desonestares": "desonestar",
    "desonestaria": "desonestar",
    "desonestariam": "desonestar",
    "desonestarias": "desonestar",
    "desonestarmo": "desonestar",
    "desonestarmos": "desonestar",
    "desonestará": "desonestar",
    "desonestarás": "desonestar",
    "desonestarão": "desonestar",
    "desonestaríamos": "desonestar",
    "desonestaríeis": "desonestar",
    "desonestas": "desonesto",
    "desonestasse": "desonestar",
    "desonestassem": "desonestar",
    "desonestasses": "desonestar",
    "desonestaste": "desonestar",
    "desonestastes": "desonestar",
    "desonestava": "desonestar",
    "desonestavam": "desonestar",
    "desonestavas": "desonestar",
    "desoneste": "desonestar",
    "desonestei": "desonestar",
    "desonesteis": "desonestar",
    "desonestem": "desonestar",
    "desonestemo": "desonestar",
    "desonestemos": "desonestar",
    "desonestes": "desonestar",
    "desonestidades": "desonestidade",
    "desonesto": "desonestar",
    "desonestos": "desonesto",
    "desonestou": "desonestar",
    "desonestá": "desonestar",
    "desonestámo": "desonestar",
    "desonestámos": "desonestar",
    "desonestáramo": "desonestar",
    "desonestáramos": "desonestar",
    "desonestárei": "desonestar",
    "desonestáreis": "desonestar",
    "desonestásseis": "desonestar",
    "desonestássemos": "desonestar",
    "desonestávamo": "desonestar",
    "desonestávamos": "desonestar",
    "desonestávei": "desonestar",
    "desonestáveis": "desonestar",
    "desonra": "desonrar",
    "desonrada": "desonrar",
    "desonradas": "desonrar",
    "desonrado": "desonrar",
    "desonrados": "desonrar",
    "desonrai": "desonrar",
    "desonrais": "desonrar",
    "desonram": "desonrar",
    "desonramo": "desonrar",
    "desonramos": "desonrar",
    "desonrando": "desonrar",
    "desonrara": "desonrar",
    "desonraram": "desonrar",
    "desonraras": "desonrar",
    "desonrarde": "desonrar",
    "desonrardes": "desonrar",
    "desonrare": "desonrar",
    "desonrarei": "desonrar",
    "desonrareis": "desonrar",
    "desonrarem": "desonrar",
    "desonraremos": "desonrar",
    "desonrares": "desonrar",
    "desonraria": "desonrar",
    "desonrariam": "desonrar",
    "desonrarias": "desonrar",
    "desonrarmo": "desonrar",
    "desonrarmos": "desonrar",
    "desonrará": "desonrar",
    "desonrarás": "desonrar",
    "desonrarão": "desonrar",
    "desonraríamos": "desonrar",
    "desonraríeis": "desonrar",
    "desonras": "desonrar",
    "desonrasse": "desonrar",
    "desonrassem": "desonrar",
    "desonrasses": "desonrar",
    "desonraste": "desonrar",
    "desonrastes": "desonrar",
    "desonrava": "desonrar",
    "desonravam": "desonrar",
    "desonravas": "desonrar",
    "desonre": "desonrar",
    "desonrei": "desonrar",
    "desonreis": "desonrar",
    "desonrem": "desonrar",
    "desonremo": "desonrar",
    "desonremos": "desonrar",
    "desonres": "desonrar",
    "desonro": "desonrar",
    "desonrosa": "desonroso",
    "desonrosas": "desonroso",
    "desonrosos": "desonroso",
    "desonrou": "desonrar",
    "desonrá": "desonrar",
    "desonrámo": "desonrar",
    "desonrámos": "desonrar",
    "desonráramo": "desonrar",
    "desonráramos": "desonrar",
    "desonrárei": "desonrar",
    "desonráreis": "desonrar",
    "desonrásseis": "desonrar",
    "desonrássemos": "desonrar",
    "desonrávamo": "desonrar",
    "desonrávamos": "desonrar",
    "desonrávei": "desonrar",
    "desonráveis": "desonrável",
    "desopila": "desopilar",
    "desopilada": "desopilar",
    "desopiladas": "desopilar",
    "desopilado": "desopilar",
    "desopilados": "desopilar",
    "desopilai": "desopilar",
    "desopilais": "desopilar",
    "desopilam": "desopilar",
    "desopilamo": "desopilar",
    "desopilamos": "desopilar",
    "desopilando": "desopilar",
    "desopilantes": "desopilante",
    "desopilara": "desopilar",
    "desopilaram": "desopilar",
    "desopilaras": "desopilar",
    "desopilarde": "desopilar",
    "desopilardes": "desopilar",
    "desopilare": "desopilar",
    "desopilarei": "desopilar",
    "desopilareis": "desopilar",
    "desopilarem": "desopilar",
    "desopilaremos": "desopilar",
    "desopilares": "desopilar",
    "desopilaria": "desopilar",
    "desopilariam": "desopilar",
    "desopilarias": "desopilar",
    "desopilarmo": "desopilar",
    "desopilarmos": "desopilar",
    "desopilará": "desopilar",
    "desopilarás": "desopilar",
    "desopilarão": "desopilar",
    "desopilaríamos": "desopilar",
    "desopilaríeis": "desopilar",
    "desopilas": "desopilar",
    "desopilasse": "desopilar",
    "desopilassem": "desopilar",
    "desopilasses": "desopilar",
    "desopilaste": "desopilar",
    "desopilastes": "desopilar",
    "desopilativa": "desopilativo",
    "desopilativas": "desopilativo",
    "desopilativos": "desopilativo",
    "desopilava": "desopilar",
    "desopilavam": "desopilar",
    "desopilavas": "desopilar",
    "desopilações": "desopilação",
    "desopile": "desopilar",
    "desopilei": "desopilar",
    "desopileis": "desopilar",
    "desopilem": "desopilar",
    "desopilemo": "desopilar",
    "desopilemos": "desopilar",
    "desopiles": "desopilar",
    "desopilo": "desopilar",
    "desopilou": "desopilar",
    "desopilá": "desopilar",
    "desopilámo": "desopilar",
    "desopilámos": "desopilar",
    "desopiláramo": "desopilar",
    "desopiláramos": "desopilar",
    "desopilárei": "desopilar",
    "desopiláreis": "desopilar",
    "desopilásseis": "desopilar",
    "desopilássemos": "desopilar",
    "desopilávamo": "desopilar",
    "desopilávamos": "desopilar",
    "desopilávei": "desopilar",
    "desopiláveis": "desopilar",
    "desopressora": "desopressor",
    "desopressoras": "desopressor",
    "desopressores": "desopressor",
    "desopressões": "desopressão",
    "desoprima": "desoprimir",
    "desoprimais": "desoprimir",
    "desoprimam": "desoprimir",
    "desoprimamo": "desoprimir",
    "desoprimamos": "desoprimir",
    "desoprimas": "desoprimir",
    "desoprime": "desoprimir",
    "desoprimem": "desoprimir",
    "desoprimes": "desoprimir",
    "desoprimi": "desoprimir",
    "desoprimia": "desoprimir",
    "desoprimiam": "desoprimir",
    "desoprimias": "desoprimir",
    "desoprimida": "desoprimir",
    "desoprimidas": "desoprimir",
    "desoprimido": "desoprimir",
    "desoprimidos": "desoprimir",
    "desoprimimo": "desoprimir",
    "desoprimimos": "desoprimir",
    "desoprimindo": "desoprimir",
    "desoprimira": "desoprimir",
    "desoprimiram": "desoprimir",
    "desoprimiras": "desoprimir",
    "desoprimirde": "desoprimir",
    "desoprimirdes": "desoprimir",
    "desoprimire": "desoprimir",
    "desoprimirei": "desoprimir",
    "desoprimireis": "desoprimir",
    "desoprimirem": "desoprimir",
    "desoprimiremos": "desoprimir",
    "desoprimires": "desoprimir",
    "desoprimiria": "desoprimir",
    "desoprimiriam": "desoprimir",
    "desoprimirias": "desoprimir",
    "desoprimirmo": "desoprimir",
    "desoprimirmos": "desoprimir",
    "desoprimirá": "desoprimir",
    "desoprimirás": "desoprimir",
    "desoprimirão": "desoprimir",
    "desoprimiríamos": "desoprimir",
    "desoprimiríeis": "desoprimir",
    "desoprimis": "desoprimir",
    "desoprimisse": "desoprimir",
    "desoprimissem": "desoprimir",
    "desoprimisses": "desoprimir",
    "desoprimiste": "desoprimir",
    "desoprimistes": "desoprimir",
    "desoprimiu": "desoprimir",
    "desoprimo": "desoprimir",
    "desoprimíamo": "desoprimir",
    "desoprimíamos": "desoprimir",
    "desoprimíei": "desoprimir",
    "desoprimíeis": "desoprimir",
    "desoprimíramo": "desoprimir",
    "desoprimíramos": "desoprimir",
    "desoprimírei": "desoprimir",
    "desoprimíreis": "desoprimir",
    "desoprimísseis": "desoprimir",
    "desoprimíssemos": "desoprimir",
    "desorbita": "desorbitar",
    "desorbitada": "desorbitar",
    "desorbitadas": "desorbitar",
    "desorbitado": "desorbitar",
    "desorbitados": "desorbitar",
    "desorbitai": "desorbitar",
    "desorbitais": "desorbitar",
    "desorbitam": "desorbitar",
    "desorbitamo": "desorbitar",
    "desorbitamos": "desorbitar",
    "desorbitando": "desorbitar",
    "desorbitara": "desorbitar",
    "desorbitaram": "desorbitar",
    "desorbitaras": "desorbitar",
    "desorbitarde": "desorbitar",
    "desorbitardes": "desorbitar",
    "desorbitare": "desorbitar",
    "desorbitarei": "desorbitar",
    "desorbitareis": "desorbitar",
    "desorbitarem": "desorbitar",
    "desorbitaremos": "desorbitar",
    "desorbitares": "desorbitar",
    "desorbitaria": "desorbitar",
    "desorbitariam": "desorbitar",
    "desorbitarias": "desorbitar",
    "desorbitarmo": "desorbitar",
    "desorbitarmos": "desorbitar",
    "desorbitará": "desorbitar",
    "desorbitarás": "desorbitar",
    "desorbitarão": "desorbitar",
    "desorbitaríamos": "desorbitar",
    "desorbitaríeis": "desorbitar",
    "desorbitas": "desorbitar",
    "desorbitasse": "desorbitar",
    "desorbitassem": "desorbitar",
    "desorbitasses": "desorbitar",
    "desorbitaste": "desorbitar",
    "desorbitastes": "desorbitar",
    "desorbitava": "desorbitar",
    "desorbitavam": "desorbitar",
    "desorbitavas": "desorbitar",
    "desorbite": "desorbitar",
    "desorbitei": "desorbitar",
    "desorbiteis": "desorbitar",
    "desorbitem": "desorbitar",
    "desorbitemo": "desorbitar",
    "desorbitemos": "desorbitar",
    "desorbites": "desorbitar",
    "desorbito": "desorbitar",
    "desorbitou": "desorbitar",
    "desorbitá": "desorbitar",
    "desorbitámo": "desorbitar",
    "desorbitámos": "desorbitar",
    "desorbitáramo": "desorbitar",
    "desorbitáramos": "desorbitar",
    "desorbitárei": "desorbitar",
    "desorbitáreis": "desorbitar",
    "desorbitásseis": "desorbitar",
    "desorbitássemos": "desorbitar",
    "desorbitávamo": "desorbitar",
    "desorbitávamos": "desorbitar",
    "desorbitávei": "desorbitar",
    "desorbitáveis": "desorbitar",
    "desordeira": "desordeiro",
    "desordeiras": "desordeiro",
    "desordeiros": "desordeiro",
    "desordena": "desordenar",
    "desordenada": "desordenar",
    "desordenadas": "desordenar",
    "desordenado": "desordenar",
    "desordenadora": "desordenador",
    "desordenadoras": "desordenador",
    "desordenadores": "desordenador",
    "desordenados": "desordenar",
    "desordenai": "desordenar",
    "desordenais": "desordenar",
    "desordenam": "desordenar",
    "desordenamentos": "desordenamento",
    "desordenamo": "desordenar",
    "desordenamos": "desordenar",
    "desordenando": "desordenar",
    "desordenara": "desordenar",
    "desordenaram": "desordenar",
    "desordenaras": "desordenar",
    "desordenarde": "desordenar",
    "desordenardes": "desordenar",
    "desordenare": "desordenar",
    "desordenarei": "desordenar",
    "desordenareis": "desordenar",
    "desordenarem": "desordenar",
    "desordenaremos": "desordenar",
    "desordenares": "desordenar",
    "desordenaria": "desordenar",
    "desordenariam": "desordenar",
    "desordenarias": "desordenar",
    "desordenarmo": "desordenar",
    "desordenarmos": "desordenar",
    "desordenará": "desordenar",
    "desordenarás": "desordenar",
    "desordenarão": "desordenar",
    "desordenaríamos": "desordenar",
    "desordenaríeis": "desordenar",
    "desordenas": "desordenar",
    "desordenasse": "desordenar",
    "desordenassem": "desordenar",
    "desordenasses": "desordenar",
    "desordenaste": "desordenar",
    "desordenastes": "desordenar",
    "desordenava": "desordenar",
    "desordenavam": "desordenar",
    "desordenavas": "desordenar",
    "desordenações": "desordenação",
    "desordene": "desordenar",
    "desordenei": "desordenar",
    "desordeneis": "desordenar",
    "desordenem": "desordenar",
    "desordenemo": "desordenar",
    "desordenemos": "desordenar",
    "desordenes": "desordenar",
    "desordeno": "desordenar",
    "desordenou": "desordenar",
    "desordens": "desordem",
    "desordená": "desordenar",
    "desordenámo": "desordenar",
    "desordenámos": "desordenar",
    "desordenáramo": "desordenar",
    "desordenáramos": "desordenar",
    "desordenárei": "desordenar",
    "desordenáreis": "desordenar",
    "desordenásseis": "desordenar",
    "desordenássemos": "desordenar",
    "desordenávamo": "desordenar",
    "desordenávamos": "desordenar",
    "desordenávei": "desordenar",
    "desordenáveis": "desordenar",
    "desorelha": "desorelhar",
    "desorelhada": "desorelhar",
    "desorelhadas": "desorelhar",
    "desorelhado": "desorelhar",
    "desorelhados": "desorelhar",
    "desorelhai": "desorelhar",
    "desorelhais": "desorelhar",
    "desorelham": "desorelhar",
    "desorelhamo": "desorelhar",
    "desorelhamos": "desorelhar",
    "desorelhando": "desorelhar",
    "desorelhara": "desorelhar",
    "desorelharam": "desorelhar",
    "desorelharas": "desorelhar",
    "desorelharde": "desorelhar",
    "desorelhardes": "desorelhar",
    "desorelhare": "desorelhar",
    "desorelharei": "desorelhar",
    "desorelhareis": "desorelhar",
    "desorelharem": "desorelhar",
    "desorelharemos": "desorelhar",
    "desorelhares": "desorelhar",
    "desorelharia": "desorelhar",
    "desorelhariam": "desorelhar",
    "desorelharias": "desorelhar",
    "desorelharmo": "desorelhar",
    "desorelharmos": "desorelhar",
    "desorelhará": "desorelhar",
    "desorelharás": "desorelhar",
    "desorelharão": "desorelhar",
    "desorelharíamos": "desorelhar",
    "desorelharíeis": "desorelhar",
    "desorelhas": "desorelhar",
    "desorelhasse": "desorelhar",
    "desorelhassem": "desorelhar",
    "desorelhasses": "desorelhar",
    "desorelhaste": "desorelhar",
    "desorelhastes": "desorelhar",
    "desorelhava": "desorelhar",
    "desorelhavam": "desorelhar",
    "desorelhavas": "desorelhar",
    "desorelhe": "desorelhar",
    "desorelhei": "desorelhar",
    "desorelheis": "desorelhar",
    "desorelhem": "desorelhar",
    "desorelhemo": "desorelhar",
    "desorelhemos": "desorelhar",
    "desorelhes": "desorelhar",
    "desorelho": "desorelhar",
    "desorelhou": "desorelhar",
    "desorelhá": "desorelhar",
    "desorelhámo": "desorelhar",
    "desorelhámos": "desorelhar",
    "desorelháramo": "desorelhar",
    "desorelháramos": "desorelhar",
    "desorelhárei": "desorelhar",
    "desorelháreis": "desorelhar",
    "desorelhásseis": "desorelhar",
    "desorelhássemos": "desorelhar",
    "desorelhávamo": "desorelhar",
    "desorelhávamos": "desorelhar",
    "desorelhávei": "desorelhar",
    "desorelháveis": "desorelhar",
    "desorganiza": "desorganizar",
    "desorganizada": "desorganizar",
    "desorganizadas": "desorganizar",
    "desorganizado": "desorganizar",
    "desorganizadora": "desorganizador",
    "desorganizadoras": "desorganizador",
    "desorganizadores": "desorganizador",
    "desorganizados": "desorganizar",
    "desorganizai": "desorganizar",
    "desorganizais": "desorganizar",
    "desorganizam": "desorganizar",
    "desorganizamo": "desorganizar",
    "desorganizamos": "desorganizar",
    "desorganizando": "desorganizar",
    "desorganizara": "desorganizar",
    "desorganizaram": "desorganizar",
    "desorganizaras": "desorganizar",
    "desorganizarde": "desorganizar",
    "desorganizardes": "desorganizar",
    "desorganizare": "desorganizar",
    "desorganizarei": "desorganizar",
    "desorganizareis": "desorganizar",
    "desorganizarem": "desorganizar",
    "desorganizaremos": "desorganizar",
    "desorganizares": "desorganizar",
    "desorganizaria": "desorganizar",
    "desorganizariam": "desorganizar",
    "desorganizarias": "desorganizar",
    "desorganizarmo": "desorganizar",
    "desorganizarmos": "desorganizar",
    "desorganizará": "desorganizar",
    "desorganizarás": "desorganizar",
    "desorganizarão": "desorganizar",
    "desorganizaríamos": "desorganizar",
    "desorganizaríeis": "desorganizar",
    "desorganizas": "desorganizar",
    "desorganizasse": "desorganizar",
    "desorganizassem": "desorganizar",
    "desorganizasses": "desorganizar",
    "desorganizaste": "desorganizar",
    "desorganizastes": "desorganizar",
    "desorganizava": "desorganizar",
    "desorganizavam": "desorganizar",
    "desorganizavas": "desorganizar",
    "desorganizações": "desorganização",
    "desorganize": "desorganizar",
    "desorganizei": "desorganizar",
    "desorganizeis": "desorganizar",
    "desorganizem": "desorganizar",
    "desorganizemo": "desorganizar",
    "desorganizemos": "desorganizar",
    "desorganizes": "desorganizar",
    "desorganizo": "desorganizar",
    "desorganizou": "desorganizar",
    "desorganizá": "desorganizar",
    "desorganizámo": "desorganizar",
    "desorganizámos": "desorganizar",
    "desorganizáramo": "desorganizar",
    "desorganizáramos": "desorganizar",
    "desorganizárei": "desorganizar",
    "desorganizáreis": "desorganizar",
    "desorganizásseis": "desorganizar",
    "desorganizássemos": "desorganizar",
    "desorganizávamo": "desorganizar",
    "desorganizávamos": "desorganizar",
    "desorganizávei": "desorganizar",
    "desorganizáveis": "desorganizável",
    "desorienta": "desorientar",
    "desorientada": "desorientar",
    "desorientadas": "desorientar",
    "desorientado": "desorientar",
    "desorientadora": "desorientador",
    "desorientadoras": "desorientador",
    "desorientadores": "desorientador",
    "desorientados": "desorientar",
    "desorientai": "desorientar",
    "desorientais": "desorientar",
    "desorientam": "desorientar",
    "desorientamentos": "desorientamento",
    "desorientamo": "desorientar",
    "desorientamos": "desorientar",
    "desorientando": "desorientar",
    "desorientara": "desorientar",
    "desorientaram": "desorientar",
    "desorientaras": "desorientar",
    "desorientarde": "desorientar",
    "desorientardes": "desorientar",
    "desorientare": "desorientar",
    "desorientarei": "desorientar",
    "desorientareis": "desorientar",
    "desorientarem": "desorientar",
    "desorientaremos": "desorientar",
    "desorientares": "desorientar",
    "desorientaria": "desorientar",
    "desorientariam": "desorientar",
    "desorientarias": "desorientar",
    "desorientarmo": "desorientar",
    "desorientarmos": "desorientar",
    "desorientará": "desorientar",
    "desorientarás": "desorientar",
    "desorientarão": "desorientar",
    "desorientaríamos": "desorientar",
    "desorientaríeis": "desorientar",
    "desorientas": "desorientar",
    "desorientasse": "desorientar",
    "desorientassem": "desorientar",
    "desorientasses": "desorientar",
    "desorientaste": "desorientar",
    "desorientastes": "desorientar",
    "desorientava": "desorientar",
    "desorientavam": "desorientar",
    "desorientavas": "desorientar",
    "desorientações": "desorientação",
    "desoriente": "desorientar",
    "desorientei": "desorientar",
    "desorienteis": "desorientar",
    "desorientem": "desorientar",
    "desorientemo": "desorientar",
    "desorientemos": "desorientar",
    "desorientes": "desorientar",
    "desoriento": "desorientar",
    "desorientou": "desorientar",
    "desorientá": "desorientar",
    "desorientámo": "desorientar",
    "desorientámos": "desorientar",
    "desorientáramo": "desorientar",
    "desorientáramos": "desorientar",
    "desorientárei": "desorientar",
    "desorientáreis": "desorientar",
    "desorientásseis": "desorientar",
    "desorientássemos": "desorientar",
    "desorientávamo": "desorientar",
    "desorientávamos": "desorientar",
    "desorientávei": "desorientar",
    "desorientáveis": "desorientável",
    "desorna": "desornar",
    "desornada": "desornar",
    "desornadas": "desornar",
    "desornado": "desornar",
    "desornados": "desornar",
    "desornai": "desornar",
    "desornais": "desornar",
    "desornam": "desornar",
    "desornamo": "desornar",
    "desornamos": "desornar",
    "desornando": "desornar",
    "desornara": "desornar",
    "desornaram": "desornar",
    "desornaras": "desornar",
    "desornarde": "desornar",
    "desornardes": "desornar",
    "desornare": "desornar",
    "desornarei": "desornar",
    "desornareis": "desornar",
    "desornarem": "desornar",
    "desornaremos": "desornar",
    "desornares": "desornar",
    "desornaria": "desornar",
    "desornariam": "desornar",
    "desornarias": "desornar",
    "desornarmo": "desornar",
    "desornarmos": "desornar",
    "desornará": "desornar",
    "desornarás": "desornar",
    "desornarão": "desornar",
    "desornaríamos": "desornar",
    "desornaríeis": "desornar",
    "desornas": "desornar",
    "desornasse": "desornar",
    "desornassem": "desornar",
    "desornasses": "desornar",
    "desornaste": "desornar",
    "desornastes": "desornar",
    "desornava": "desornar",
    "desornavam": "desornar",
    "desornavas": "desornar",
    "desorne": "desornar",
    "desornei": "desornar",
    "desorneis": "desornar",
    "desornem": "desornar",
    "desornemo": "desornar",
    "desornemos": "desornar",
    "desornes": "desornar",
    "desorno": "desornar",
    "desornou": "desornar",
    "desorná": "desornar",
    "desornámo": "desornar",
    "desornámos": "desornar",
    "desornáramo": "desornar",
    "desornáramos": "desornar",
    "desornárei": "desornar",
    "desornáreis": "desornar",
    "desornásseis": "desornar",
    "desornássemos": "desornar",
    "desornávamo": "desornar",
    "desornávamos": "desornar",
    "desornávei": "desornar",
    "desornáveis": "desornar",
    "desorvalhada": "desorvalhado",
    "desorvalhadas": "desorvalhado",
    "desorvalhados": "desorvalhado",
    "desorçamentações": "desorçamentação",
    "desossa": "desossar",
    "desossada": "desossar",
    "desossadas": "desossar",
    "desossado": "desossar",
    "desossados": "desossar",
    "desossai": "desossar",
    "desossais": "desossar",
    "desossam": "desossar",
    "desossamentos": "desossamento",
    "desossamo": "desossar",
    "desossamos": "desossar",
    "desossando": "desossar",
    "desossara": "desossar",
    "desossaram": "desossar",
    "desossaras": "desossar",
    "desossarde": "desossar",
    "desossardes": "desossar",
    "desossare": "desossar",
    "desossarei": "desossar",
    "desossareis": "desossar",
    "desossarem": "desossar",
    "desossaremos": "desossar",
    "desossares": "desossar",
    "desossaria": "desossar",
    "desossariam": "desossar",
    "desossarias": "desossar",
    "desossarmo": "desossar",
    "desossarmos": "desossar",
    "desossará": "desossar",
    "desossarás": "desossar",
    "desossarão": "desossar",
    "desossaríamos": "desossar",
    "desossaríeis": "desossar",
    "desossas": "desossar",
    "desossasse": "desossar",
    "desossassem": "desossar",
    "desossasses": "desossar",
    "desossaste": "desossar",
    "desossastes": "desossar",
    "desossava": "desossar",
    "desossavam": "desossar",
    "desossavas": "desossar",
    "desosse": "desossar",
    "desossei": "desossar",
    "desosseis": "desossar",
    "desossem": "desossar",
    "desossemo": "desossar",
    "desossemos": "desossar",
    "desosses": "desossar",
    "desossificações": "desossificação",
    "desosso": "desossar",
    "desossou": "desossar",
    "desossá": "desossar",
    "desossámo": "desossar",
    "desossámos": "desossar",
    "desossáramo": "desossar",
    "desossáramos": "desossar",
    "desossárei": "desossar",
    "desossáreis": "desossar",
    "desossásseis": "desossar",
    "desossássemos": "desossar",
    "desossávamo": "desossar",
    "desossávamos": "desossar",
    "desossávei": "desossar",
    "desossáveis": "desossar",
    "desouga": "desougar",
    "desougada": "desougar",
    "desougadas": "desougar",
    "desougado": "desougar",
    "desougados": "desougar",
    "desougai": "desougar",
    "desougais": "desougar",
    "desougam": "desougar",
    "desougamo": "desougar",
    "desougamos": "desougar",
    "desougando": "desougar",
    "desougara": "desougar",
    "desougaram": "desougar",
    "desougaras": "desougar",
    "desougardes": "desougar",
    "desougarei": "desougar",
    "desougareis": "desougar",
    "desougarem": "desougar",
    "desougaremos": "desougar",
    "desougares": "desougar",
    "desougaria": "desougar",
    "desougariam": "desougar",
    "desougarias": "desougar",
    "desougarmo": "desougar",
    "desougarmos": "desougar",
    "desougará": "desougar",
    "desougarás": "desougar",
    "desougarão": "desougar",
    "desougaríamos": "desougar",
    "desougaríeis": "desougar",
    "desougas": "desougar",
    "desougasse": "desougar",
    "desougassem": "desougar",
    "desougasses": "desougar",
    "desougaste": "desougar",
    "desougastes": "desougar",
    "desougava": "desougar",
    "desougavam": "desougar",
    "desougavas": "desougar",
    "desougo": "desougar",
    "desougou": "desougar",
    "desougue": "desougar",
    "desouguei": "desougar",
    "desougueis": "desougar",
    "desouguem": "desougar",
    "desouguemo": "desougar",
    "desouguemos": "desougar",
    "desougues": "desougar",
    "desougámo": "desougar",
    "desougámos": "desougar",
    "desougáramo": "desougar",
    "desougáramos": "desougar",
    "desougáreis": "desougar",
    "desougásseis": "desougar",
    "desougássemos": "desougar",
    "desougávamo": "desougar",
    "desougávamos": "desougar",
    "desougáveis": "desougar",
    "desova": "desovar",
    "desovada": "desovar",
    "desovadas": "desovar",
    "desovado": "desovar",
    "desovados": "desovar",
    "desovadouros": "desovadouro",
    "desovai": "desovar",
    "desovais": "desovar",
    "desovam": "desovar",
    "desovamentos": "desovamento",
    "desovamo": "desovar",
    "desovamos": "desovar",
    "desovando": "desovar",
    "desovara": "desovar",
    "desovaram": "desovar",
    "desovaras": "desovar",
    "desovardes": "desovar",
    "desovarei": "desovar",
    "desovareis": "desovar",
    "desovarem": "desovar",
    "desovaremos": "desovar",
    "desovares": "desovar",
    "desovaria": "desovar",
    "desovariam": "desovar",
    "desovarias": "desovar",
    "desovarmo": "desovar",
    "desovarmos": "desovar",
    "desovará": "desovar",
    "desovarás": "desovar",
    "desovarão": "desovar",
    "desovaríamos": "desovar",
    "desovaríeis": "desovar",
    "desovas": "desovar",
    "desovasse": "desovar",
    "desovassem": "desovar",
    "desovasses": "desovar",
    "desovaste": "desovar",
    "desovastes": "desovar",
    "desovava": "desovar",
    "desovavam": "desovar",
    "desovavas": "desovar",
    "desove": "desovar",
    "desovei": "desovar",
    "desoveis": "desovar",
    "desovem": "desovar",
    "desovemo": "desovar",
    "desovemos": "desovar",
    "desoves": "desovar",
    "desovo": "desovar",
    "desovou": "desovar",
    "desovámo": "desovar",
    "desovámos": "desovar",
    "desováramo": "desovar",
    "desováramos": "desovar",
    "desováreis": "desovar",
    "desovásseis": "desovar",
    "desovássemos": "desovar",
    "desovávamo": "desovar",
    "desovávamos": "desovar",
    "desováveis": "desovar",
    "desoxida": "desoxidar",
    "desoxidada": "desoxidar",
    "desoxidadas": "desoxidar",
    "desoxidado": "desoxidar",
    "desoxidados": "desoxidar",
    "desoxidai": "desoxidar",
    "desoxidais": "desoxidar",
    "desoxidam": "desoxidar",
    "desoxidamo": "desoxidar",
    "desoxidamos": "desoxidar",
    "desoxidando": "desoxidar",
    "desoxidantes": "desoxidante",
    "desoxidara": "desoxidar",
    "desoxidaram": "desoxidar",
    "desoxidaras": "desoxidar",
    "desoxidarde": "desoxidar",
    "desoxidardes": "desoxidar",
    "desoxidare": "desoxidar",
    "desoxidarei": "desoxidar",
    "desoxidareis": "desoxidar",
    "desoxidarem": "desoxidar",
    "desoxidaremos": "desoxidar",
    "desoxidares": "desoxidar",
    "desoxidaria": "desoxidar",
    "desoxidariam": "desoxidar",
    "desoxidarias": "desoxidar",
    "desoxidarmo": "desoxidar",
    "desoxidarmos": "desoxidar",
    "desoxidará": "desoxidar",
    "desoxidarás": "desoxidar",
    "desoxidarão": "desoxidar",
    "desoxidaríamos": "desoxidar",
    "desoxidaríeis": "desoxidar",
    "desoxidas": "desoxidar",
    "desoxidasse": "desoxidar",
    "desoxidassem": "desoxidar",
    "desoxidasses": "desoxidar",
    "desoxidaste": "desoxidar",
    "desoxidastes": "desoxidar",
    "desoxidava": "desoxidar",
    "desoxidavam": "desoxidar",
    "desoxidavas": "desoxidar",
    "desoxidações": "desoxidação",
    "desoxide": "desoxidar",
    "desoxidei": "desoxidar",
    "desoxideis": "desoxidar",
    "desoxidem": "desoxidar",
    "desoxidemo": "desoxidar",
    "desoxidemos": "desoxidar",
    "desoxides": "desoxidar",
    "desoxido": "desoxidar",
    "desoxidou": "desoxidar",
    "desoxidá": "desoxidar",
    "desoxidámo": "desoxidar",
    "desoxidámos": "desoxidar",
    "desoxidáramo": "desoxidar",
    "desoxidáramos": "desoxidar",
    "desoxidárei": "desoxidar",
    "desoxidáreis": "desoxidar",
    "desoxidásseis": "desoxidar",
    "desoxidássemos": "desoxidar",
    "desoxidávamo": "desoxidar",
    "desoxidávamos": "desoxidar",
    "desoxidávei": "desoxidar",
    "desoxidáveis": "desoxidável",
    "desoxigena": "desoxigenar",
    "desoxigenada": "desoxigenar",
    "desoxigenadas": "desoxigenar",
    "desoxigenado": "desoxigenar",
    "desoxigenados": "desoxigenar",
    "desoxigenai": "desoxigenar",
    "desoxigenais": "desoxigenar",
    "desoxigenam": "desoxigenar",
    "desoxigenamo": "desoxigenar",
    "desoxigenamos": "desoxigenar",
    "desoxigenando": "desoxigenar",
    "desoxigenara": "desoxigenar",
    "desoxigenaram": "desoxigenar",
    "desoxigenaras": "desoxigenar",
    "desoxigenarde": "desoxigenar",
    "desoxigenardes": "desoxigenar",
    "desoxigenare": "desoxigenar",
    "desoxigenarei": "desoxigenar",
    "desoxigenareis": "desoxigenar",
    "desoxigenarem": "desoxigenar",
    "desoxigenaremos": "desoxigenar",
    "desoxigenares": "desoxigenar",
    "desoxigenaria": "desoxigenar",
    "desoxigenariam": "desoxigenar",
    "desoxigenarias": "desoxigenar",
    "desoxigenarmo": "desoxigenar",
    "desoxigenarmos": "desoxigenar",
    "desoxigenará": "desoxigenar",
    "desoxigenarás": "desoxigenar",
    "desoxigenarão": "desoxigenar",
    "desoxigenaríamos": "desoxigenar",
    "desoxigenaríeis": "desoxigenar",
    "desoxigenas": "desoxigenar",
    "desoxigenasse": "desoxigenar",
    "desoxigenassem": "desoxigenar",
    "desoxigenasses": "desoxigenar",
    "desoxigenaste": "desoxigenar",
    "desoxigenastes": "desoxigenar",
    "desoxigenava": "desoxigenar",
    "desoxigenavam": "desoxigenar",
    "desoxigenavas": "desoxigenar",
    "desoxigenações": "desoxigenação",
    "desoxigene": "desoxigenar",
    "desoxigenei": "desoxigenar",
    "desoxigeneis": "desoxigenar",
    "desoxigenem": "desoxigenar",
    "desoxigenemo": "desoxigenar",
    "desoxigenemos": "desoxigenar",
    "desoxigenes": "desoxigenar",
    "desoxigeno": "desoxigenar",
    "desoxigenou": "desoxigenar",
    "desoxigená": "desoxigenar",
    "desoxigenámo": "desoxigenar",
    "desoxigenámos": "desoxigenar",
    "desoxigenáramo": "desoxigenar",
    "desoxigenáramos": "desoxigenar",
    "desoxigenárei": "desoxigenar",
    "desoxigenáreis": "desoxigenar",
    "desoxigenásseis": "desoxigenar",
    "desoxigenássemos": "desoxigenar",
    "desoxigenávamo": "desoxigenar",
    "desoxigenávamos": "desoxigenar",
    "desoxigenávei": "desoxigenar",
    "desoxigenáveis": "desoxigenar",
    "desoxirribonucleica": "desoxirribonucleico",
    "desoxirribonucleicas": "desoxirribonucleico",
    "desoxirribonucleicos": "desoxirribonucleico",
    "despacha": "despachar",
    "despachada": "despachar",
    "despachadas": "despachar",
    "despachado": "despachar",
    "despachadora": "despachador",
    "despachadoras": "despachador",
    "despachadores": "despachador",
    "despachados": "despachar",
    "despachadíssima": "despachado",
    "despachadíssimas": "despachado",
    "despachadíssimo": "despachado",
    "despachadíssimos": "despachado",
    "despachai": "despachar",
    "despachais": "despachar",
    "despacham": "despachar",
    "despachamo": "despachar",
    "despachamos": "despachar",
    "despachando": "despachar",
    "despachantes": "despachante",
    "despachara": "despachar",
    "despacharam": "despachar",
    "despacharas": "despachar",
    "despacharde": "despachar",
    "despachardes": "despachar",
    "despachare": "despachar",
    "despacharei": "despachar",
    "despachareis": "despachar",
    "despacharem": "despachar",
    "despacharemos": "despachar",
    "despachares": "despachar",
    "despacharia": "despachar",
    "despachariam": "despachar",
    "despacharias": "despachar",
    "despacharmo": "despachar",
    "despacharmos": "despachar",
    "despachará": "despachar",
    "despacharás": "despachar",
    "despacharão": "despachar",
    "despacharíamos": "despachar",
    "despacharíeis": "despachar",
    "despachas": "despachar",
    "despachasse": "despachar",
    "despachassem": "despachar",
    "despachasses": "despachar",
    "despachaste": "despachar",
    "despachastes": "despachar",
    "despachava": "despachar",
    "despachavam": "despachar",
    "despachavas": "despachar",
    "despache": "despachar",
    "despachei": "despachar",
    "despacheis": "despachar",
    "despachem": "despachar",
    "despachemo": "despachar",
    "despachemos": "despachar",
    "despaches": "despachar",
    "despacho": "despachar",
    "despachos": "despacho",
    "despachou": "despachar",
    "despachá": "despachar",
    "despachámo": "despachar",
    "despachámos": "despachar",
    "despacháramo": "despachar",
    "despacháramos": "despachar",
    "despachárei": "despachar",
    "despacháreis": "despachar",
    "despachásseis": "despachar",
    "despachássemos": "despachar",
    "despachávamo": "despachar",
    "despachávamos": "despachar",
    "despachávei": "despachar",
    "despacháveis": "despachável",
    "despadra": "despadrar",
    "despadrada": "despadrar",
    "despadradas": "despadrar",
    "despadrado": "despadrar",
    "despadrados": "despadrar",
    "despadrai": "despadrar",
    "despadrais": "despadrar",
    "despadram": "despadrar",
    "despadramo": "despadrar",
    "despadramos": "despadrar",
    "despadrando": "despadrar",
    "despadrara": "despadrar",
    "despadraram": "despadrar",
    "despadraras": "despadrar",
    "despadrarde": "despadrar",
    "despadrardes": "despadrar",
    "despadrare": "despadrar",
    "despadrarei": "despadrar",
    "despadrareis": "despadrar",
    "despadrarem": "despadrar",
    "despadraremos": "despadrar",
    "despadrares": "despadrar",
    "despadraria": "despadrar",
    "despadrariam": "despadrar",
    "despadrarias": "despadrar",
    "despadrarmo": "despadrar",
    "despadrarmos": "despadrar",
    "despadrará": "despadrar",
    "despadrarás": "despadrar",
    "despadrarão": "despadrar",
    "despadraríamos": "despadrar",
    "despadraríeis": "despadrar",
    "despadras": "despadrar",
    "despadrasse": "despadrar",
    "despadrassem": "despadrar",
    "despadrasses": "despadrar",
    "despadraste": "despadrar",
    "despadrastes": "despadrar",
    "despadrava": "despadrar",
    "despadravam": "despadrar",
    "despadravas": "despadrar",
    "despadre": "despadrar",
    "despadrei": "despadrar",
    "despadreis": "despadrar",
    "despadrem": "despadrar",
    "despadremo": "despadrar",
    "despadremos": "despadrar",
    "despadres": "despadrar",
    "despadro": "despadrar",
    "despadrou": "despadrar",
    "despadrá": "despadrar",
    "despadrámo": "despadrar",
    "despadrámos": "despadrar",
    "despadráramo": "despadrar",
    "despadráramos": "despadrar",
    "despadrárei": "despadrar",
    "despadráreis": "despadrar",
    "despadrásseis": "despadrar",
    "despadrássemos": "despadrar",
    "despadrávamo": "despadrar",
    "despadrávamos": "despadrar",
    "despadrávei": "despadrar",
    "despadráveis": "despadrar",
    "despaganiza": "despaganizar",
    "despaganizada": "despaganizar",
    "despaganizadas": "despaganizar",
    "despaganizado": "despaganizar",
    "despaganizados": "despaganizar",
    "despaganizai": "despaganizar",
    "despaganizais": "despaganizar",
    "despaganizam": "despaganizar",
    "despaganizamo": "despaganizar",
    "despaganizamos": "despaganizar",
    "despaganizando": "despaganizar",
    "despaganizara": "despaganizar",
    "despaganizaram": "despaganizar",
    "despaganizaras": "despaganizar",
    "despaganizarde": "despaganizar",
    "despaganizardes": "despaganizar",
    "despaganizare": "despaganizar",
    "despaganizarei": "despaganizar",
    "despaganizareis": "despaganizar",
    "despaganizarem": "despaganizar",
    "despaganizaremos": "despaganizar",
    "despaganizares": "despaganizar",
    "despaganizaria": "despaganizar",
    "despaganizariam": "despaganizar",
    "despaganizarias": "despaganizar",
    "despaganizarmo": "despaganizar",
    "despaganizarmos": "despaganizar",
    "despaganizará": "despaganizar",
    "despaganizarás": "despaganizar",
    "despaganizarão": "despaganizar",
    "despaganizaríamos": "despaganizar",
    "despaganizaríeis": "despaganizar",
    "despaganizas": "despaganizar",
    "despaganizasse": "despaganizar",
    "despaganizassem": "despaganizar",
    "despaganizasses": "despaganizar",
    "despaganizaste": "despaganizar",
    "despaganizastes": "despaganizar",
    "despaganizava": "despaganizar",
    "despaganizavam": "despaganizar",
    "despaganizavas": "despaganizar",
    "despaganize": "despaganizar",
    "despaganizei": "despaganizar",
    "despaganizeis": "despaganizar",
    "despaganizem": "despaganizar",
    "despaganizemo": "despaganizar",
    "despaganizemos": "despaganizar",
    "despaganizes": "despaganizar",
    "despaganizo": "despaganizar",
    "despaganizou": "despaganizar",
    "despaganizá": "despaganizar",
    "despaganizámo": "despaganizar",
    "despaganizámos": "despaganizar",
    "despaganizáramo": "despaganizar",
    "despaganizáramos": "despaganizar",
    "despaganizárei": "despaganizar",
    "despaganizáreis": "despaganizar",
    "despaganizásseis": "despaganizar",
    "despaganizássemos": "despaganizar",
    "despaganizávamo": "despaganizar",
    "despaganizávamos": "despaganizar",
    "despaganizávei": "despaganizar",
    "despaganizáveis": "despaganizar",
    "despalatalizações": "despalatalização",
    "despalatizações": "despalatização",
    "despalha": "despalhar",
    "despalhada": "despalhar",
    "despalhadas": "despalhar",
    "despalhado": "despalhar",
    "despalhados": "despalhar",
    "despalhai": "despalhar",
    "despalhais": "despalhar",
    "despalham": "despalhar",
    "despalhamo": "despalhar",
    "despalhamos": "despalhar",
    "despalhando": "despalhar",
    "despalhara": "despalhar",
    "despalharam": "despalhar",
    "despalharas": "despalhar",
    "despalharde": "despalhar",
    "despalhardes": "despalhar",
    "despalhare": "despalhar",
    "despalharei": "despalhar",
    "despalhareis": "despalhar",
    "despalharem": "despalhar",
    "despalharemos": "despalhar",
    "despalhares": "despalhar",
    "despalharia": "despalhar",
    "despalhariam": "despalhar",
    "despalharias": "despalhar",
    "despalharmo": "despalhar",
    "despalharmos": "despalhar",
    "despalhará": "despalhar",
    "despalharás": "despalhar",
    "despalharão": "despalhar",
    "despalharíamos": "despalhar",
    "despalharíeis": "despalhar",
    "despalhas": "despalhar",
    "despalhasse": "despalhar",
    "despalhassem": "despalhar",
    "despalhasses": "despalhar",
    "despalhaste": "despalhar",
    "despalhastes": "despalhar",
    "despalhava": "despalhar",
    "despalhavam": "despalhar",
    "despalhavas": "despalhar",
    "despalhe": "despalhar",
    "despalhei": "despalhar",
    "despalheis": "despalhar",
    "despalhem": "despalhar",
    "despalhemo": "despalhar",
    "despalhemos": "despalhar",
    "despalhes": "despalhar",
    "despalho": "despalhar",
    "despalhou": "despalhar",
    "despalhá": "despalhar",
    "despalhámo": "despalhar",
    "despalhámos": "despalhar",
    "despalháramo": "despalhar",
    "despalháramos": "despalhar",
    "despalhárei": "despalhar",
    "despalháreis": "despalhar",
    "despalhásseis": "despalhar",
    "despalhássemos": "despalhar",
    "despalhávamo": "despalhar",
    "despalhávamos": "despalhar",
    "despalhávei": "despalhar",
    "despalháveis": "despalhar",
    "despalma": "despalmar",
    "despalmada": "despalmar",
    "despalmadas": "despalmar",
    "despalmado": "despalmar",
    "despalmados": "despalmar",
    "despalmai": "despalmar",
    "despalmais": "despalmar",
    "despalmam": "despalmar",
    "despalmamo": "despalmar",
    "despalmamos": "despalmar",
    "despalmando": "despalmar",
    "despalmara": "despalmar",
    "despalmaram": "despalmar",
    "despalmaras": "despalmar",
    "despalmarde": "despalmar",
    "despalmardes": "despalmar",
    "despalmare": "despalmar",
    "despalmarei": "despalmar",
    "despalmareis": "despalmar",
    "despalmarem": "despalmar",
    "despalmaremos": "despalmar",
    "despalmares": "despalmar",
    "despalmaria": "despalmar",
    "despalmariam": "despalmar",
    "despalmarias": "despalmar",
    "despalmarmo": "despalmar",
    "despalmarmos": "despalmar",
    "despalmará": "despalmar",
    "despalmarás": "despalmar",
    "despalmarão": "despalmar",
    "despalmaríamos": "despalmar",
    "despalmaríeis": "despalmar",
    "despalmas": "despalmar",
    "despalmasse": "despalmar",
    "despalmassem": "despalmar",
    "despalmasses": "despalmar",
    "despalmaste": "despalmar",
    "despalmastes": "despalmar",
    "despalmava": "despalmar",
    "despalmavam": "despalmar",
    "despalmavas": "despalmar",
    "despalme": "despalmar",
    "despalmei": "despalmar",
    "despalmeis": "despalmar",
    "despalmem": "despalmar",
    "despalmemo": "despalmar",
    "despalmemos": "despalmar",
    "despalmes": "despalmar",
    "despalmilha": "despalmilhar",
    "despalmilhada": "despalmilhar",
    "despalmilhadas": "despalmilhar",
    "despalmilhado": "despalmilhar",
    "despalmilhados": "despalmilhar",
    "despalmilhai": "despalmilhar",
    "despalmilhais": "despalmilhar",
    "despalmilham": "despalmilhar",
    "despalmilhamo": "despalmilhar",
    "despalmilhamos": "despalmilhar",
    "despalmilhando": "despalmilhar",
    "despalmilhara": "despalmilhar",
    "despalmilharam": "despalmilhar",
    "despalmilharas": "despalmilhar",
    "despalmilharde": "despalmilhar",
    "despalmilhardes": "despalmilhar",
    "despalmilhare": "despalmilhar",
    "despalmilharei": "despalmilhar",
    "despalmilhareis": "despalmilhar",
    "despalmilharem": "despalmilhar",
    "despalmilharemos": "despalmilhar",
    "despalmilhares": "despalmilhar",
    "despalmilharia": "despalmilhar",
    "despalmilhariam": "despalmilhar",
    "despalmilharias": "despalmilhar",
    "despalmilharmo": "despalmilhar",
    "despalmilharmos": "despalmilhar",
    "despalmilhará": "despalmilhar",
    "despalmilharás": "despalmilhar",
    "despalmilharão": "despalmilhar",
    "despalmilharíamos": "despalmilhar",
    "despalmilharíeis": "despalmilhar",
    "despalmilhas": "despalmilhar",
    "despalmilhasse": "despalmilhar",
    "despalmilhassem": "despalmilhar",
    "despalmilhasses": "despalmilhar",
    "despalmilhaste": "despalmilhar",
    "despalmilhastes": "despalmilhar",
    "despalmilhava": "despalmilhar",
    "despalmilhavam": "despalmilhar",
    "despalmilhavas": "despalmilhar",
    "despalmilhe": "despalmilhar",
    "despalmilhei": "despalmilhar",
    "despalmilheis": "despalmilhar",
    "despalmilhem": "despalmilhar",
    "despalmilhemo": "despalmilhar",
    "despalmilhemos": "despalmilhar",
    "despalmilhes": "despalmilhar",
    "despalmilho": "despalmilhar",
    "despalmilhou": "despalmilhar",
    "despalmilhá": "despalmilhar",
    "despalmilhámo": "despalmilhar",
    "despalmilhámos": "despalmilhar",
    "despalmilháramo": "despalmilhar",
    "despalmilháramos": "despalmilhar",
    "despalmilhárei": "despalmilhar",
    "despalmilháreis": "despalmilhar",
    "despalmilhásseis": "despalmilhar",
    "despalmilhássemos": "despalmilhar",
    "despalmilhávamo": "despalmilhar",
    "despalmilhávamos": "despalmilhar",
    "despalmilhávei": "despalmilhar",
    "despalmilháveis": "despalmilhar",
    "despalmo": "despalmar",
    "despalmou": "despalmar",
    "despalmá": "despalmar",
    "despalmámo": "despalmar",
    "despalmámos": "despalmar",
    "despalmáramo": "despalmar",
    "despalmáramos": "despalmar",
    "despalmárei": "despalmar",
    "despalmáreis": "despalmar",
    "despalmásseis": "despalmar",
    "despalmássemos": "despalmar",
    "despalmávamo": "despalmar",
    "despalmávamos": "despalmar",
    "despalmávei": "despalmar",
    "despalmáveis": "despalmar",
    "despampa": "despampar",
    "despampada": "despampar",
    "despampadas": "despampar",
    "despampado": "despampar",
    "despampados": "despampar",
    "despampai": "despampar",
    "despampais": "despampar",
    "despampam": "despampar",
    "despampamo": "despampar",
    "despampamos": "despampar",
    "despampana": "despampanar",
    "despampanada": "despampanar",
    "despampanadas": "despampanar",
    "despampanado": "despampanar",
    "despampanados": "despampanar",
    "despampanai": "despampanar",
    "despampanais": "despampanar",
    "despampanam": "despampanar",
    "despampanamo": "despampanar",
    "despampanamos": "despampanar",
    "despampanando": "despampanar",
    "despampanara": "despampanar",
    "despampanaram": "despampanar",
    "despampanaras": "despampanar",
    "despampanarde": "despampanar",
    "despampanardes": "despampanar",
    "despampanare": "despampanar",
    "despampanarei": "despampanar",
    "despampanareis": "despampanar",
    "despampanarem": "despampanar",
    "despampanaremos": "despampanar",
    "despampanares": "despampanar",
    "despampanaria": "despampanar",
    "despampanariam": "despampanar",
    "despampanarias": "despampanar",
    "despampanarmo": "despampanar",
    "despampanarmos": "despampanar",
    "despampanará": "despampanar",
    "despampanarás": "despampanar",
    "despampanarão": "despampanar",
    "despampanaríamos": "despampanar",
    "despampanaríeis": "despampanar",
    "despampanas": "despampanar",
    "despampanasse": "despampanar",
    "despampanassem": "despampanar",
    "despampanasses": "despampanar",
    "despampanaste": "despampanar",
    "despampanastes": "despampanar",
    "despampanava": "despampanar",
    "despampanavam": "despampanar",
    "despampanavas": "despampanar",
    "despampando": "despampar",
    "despampane": "despampanar",
    "despampanei": "despampanar",
    "despampaneis": "despampanar",
    "despampanem": "despampanar",
    "despampanemo": "despampanar",
    "despampanemos": "despampanar",
    "despampanes": "despampanar",
    "despampano": "despampanar",
    "despampanou": "despampanar",
    "despampaná": "despampanar",
    "despampanámo": "despampanar",
    "despampanámos": "despampanar",
    "despampanáramo": "despampanar",
    "despampanáramos": "despampanar",
    "despampanárei": "despampanar",
    "despampanáreis": "despampanar",
    "despampanásseis": "despampanar",
    "despampanássemos": "despampanar",
    "despampanávamo": "despampanar",
    "despampanávamos": "despampanar",
    "despampanávei": "despampanar",
    "despampanáveis": "despampanar",
    "despampara": "despampar",
    "despamparam": "despampar",
    "despamparas": "despampar",
    "despamparde": "despampar",
    "despampardes": "despampar",
    "despampare": "despampar",
    "despamparei": "despampar",
    "despampareis": "despampar",
    "despamparem": "despampar",
    "despamparemos": "despampar",
    "despampares": "despampar",
    "despamparia": "despampar",
    "despampariam": "despampar",
    "despamparias": "despampar",
    "despamparmo": "despampar",
    "despamparmos": "despampar",
    "despampará": "despampar",
    "despamparás": "despampar",
    "despamparão": "despampar",
    "despamparíamos": "despampar",
    "despamparíeis": "despampar",
    "despampas": "despampar",
    "despampasse": "despampar",
    "despampassem": "despampar",
    "despampasses": "despampar",
    "despampaste": "despampar",
    "despampastes": "despampar",
    "despampava": "despampar",
    "despampavam": "despampar",
    "despampavas": "despampar",
    "despampe": "despampar",
    "despampei": "despampar",
    "despampeis": "despampar",
    "despampem": "despampar",
    "despampemo": "despampar",
    "despampemos": "despampar",
    "despampes": "despampar",
    "despampo": "despampar",
    "despampou": "despampar",
    "despampá": "despampar",
    "despampámo": "despampar",
    "despampámos": "despampar",
    "despampáramo": "despampar",
    "despampáramos": "despampar",
    "despampárei": "despampar",
    "despampáreis": "despampar",
    "despampásseis": "despampar",
    "despampássemos": "despampar",
    "despampávamo": "despampar",
    "despampávamos": "despampar",
    "despampávei": "despampar",
    "despampáveis": "despampar",
    "despapa": "despapar",
    "despapada": "despapar",
    "despapadas": "despapar",
    "despapado": "despapar",
    "despapados": "despapar",
    "despapai": "despapar",
    "despapais": "despapar",
    "despapam": "despapar",
    "despapamo": "despapar",
    "despapamos": "despapar",
    "despapando": "despapar",
    "despapara": "despapar",
    "despaparam": "despapar",
    "despaparas": "despapar",
    "despaparde": "despapar",
    "despapardes": "despapar",
    "despapare": "despapar",
    "despaparei": "despapar",
    "despapareis": "despapar",
    "despaparem": "despapar",
    "despaparemos": "despapar",
    "despapares": "despapar",
    "despaparia": "despapar",
    "despapariam": "despapar",
    "despaparias": "despapar",
    "despaparmo": "despapar",
    "despaparmos": "despapar",
    "despapará": "despapar",
    "despaparás": "despapar",
    "despaparão": "despapar",
    "despaparíamos": "despapar",
    "despaparíeis": "despapar",
    "despapas": "despapar",
    "despapasse": "despapar",
    "despapassem": "despapar",
    "despapasses": "despapar",
    "despapaste": "despapar",
    "despapastes": "despapar",
    "despapava": "despapar",
    "despapavam": "despapar",
    "despapavas": "despapar",
    "despape": "despapar",
    "despapei": "despapar",
    "despapeis": "despapar",
    "despapem": "despapar",
    "despapemo": "despapar",
    "despapemos": "despapar",
    "despapes": "despapar",
    "despapo": "despapar",
    "despapou": "despapar",
    "despapá": "despapar",
    "despapámo": "despapar",
    "despapámos": "despapar",
    "despapáramo": "despapar",
    "despapáramos": "despapar",
    "despapárei": "despapar",
    "despapáreis": "despapar",
    "despapásseis": "despapar",
    "despapássemos": "despapar",
    "despapávamo": "despapar",
    "despapávamos": "despapar",
    "despapávei": "despapar",
    "despapáveis": "despapar",
    "desparafina": "desparafinar",
    "desparafinada": "desparafinar",
    "desparafinadas": "desparafinar",
    "desparafinado": "desparafinar",
    "desparafinados": "desparafinar",
    "desparafinai": "desparafinar",
    "desparafinais": "desparafinar",
    "desparafinam": "desparafinar",
    "desparafinamo": "desparafinar",
    "desparafinamos": "desparafinar",
    "desparafinando": "desparafinar",
    "desparafinara": "desparafinar",
    "desparafinaram": "desparafinar",
    "desparafinaras": "desparafinar",
    "desparafinarde": "desparafinar",
    "desparafinardes": "desparafinar",
    "desparafinare": "desparafinar",
    "desparafinarei": "desparafinar",
    "desparafinareis": "desparafinar",
    "desparafinarem": "desparafinar",
    "desparafinaremos": "desparafinar",
    "desparafinares": "desparafinar",
    "desparafinaria": "desparafinar",
    "desparafinariam": "desparafinar",
    "desparafinarias": "desparafinar",
    "desparafinarmo": "desparafinar",
    "desparafinarmos": "desparafinar",
    "desparafinará": "desparafinar",
    "desparafinarás": "desparafinar",
    "desparafinarão": "desparafinar",
    "desparafinaríamos": "desparafinar",
    "desparafinaríeis": "desparafinar",
    "desparafinas": "desparafinar",
    "desparafinasse": "desparafinar",
    "desparafinassem": "desparafinar",
    "desparafinasses": "desparafinar",
    "desparafinaste": "desparafinar",
    "desparafinastes": "desparafinar",
    "desparafinava": "desparafinar",
    "desparafinavam": "desparafinar",
    "desparafinavas": "desparafinar",
    "desparafine": "desparafinar",
    "desparafinei": "desparafinar",
    "desparafineis": "desparafinar",
    "desparafinem": "desparafinar",
    "desparafinemo": "desparafinar",
    "desparafinemos": "desparafinar",
    "desparafines": "desparafinar",
    "desparafino": "desparafinar",
    "desparafinou": "desparafinar",
    "desparafiná": "desparafinar",
    "desparafinámo": "desparafinar",
    "desparafinámos": "desparafinar",
    "desparafináramo": "desparafinar",
    "desparafináramos": "desparafinar",
    "desparafinárei": "desparafinar",
    "desparafináreis": "desparafinar",
    "desparafinásseis": "desparafinar",
    "desparafinássemos": "desparafinar",
    "desparafinávamo": "desparafinar",
    "desparafinávamos": "desparafinar",
    "desparafinávei": "desparafinar",
    "desparafináveis": "desparafinar",
    "desparafusa": "desparafusar",
    "desparafusada": "desparafusar",
    "desparafusadas": "desparafusar",
    "desparafusado": "desparafusar",
    "desparafusados": "desparafusar",
    "desparafusai": "desparafusar",
    "desparafusais": "desparafusar",
    "desparafusam": "desparafusar",
    "desparafusamo": "desparafusar",
    "desparafusamos": "desparafusar",
    "desparafusando": "desparafusar",
    "desparafusara": "desparafusar",
    "desparafusaram": "desparafusar",
    "desparafusaras": "desparafusar",
    "desparafusarde": "desparafusar",
    "desparafusardes": "desparafusar",
    "desparafusare": "desparafusar",
    "desparafusarei": "desparafusar",
    "desparafusareis": "desparafusar",
    "desparafusarem": "desparafusar",
    "desparafusaremos": "desparafusar",
    "desparafusares": "desparafusar",
    "desparafusaria": "desparafusar",
    "desparafusariam": "desparafusar",
    "desparafusarias": "desparafusar",
    "desparafusarmo": "desparafusar",
    "desparafusarmos": "desparafusar",
    "desparafusará": "desparafusar",
    "desparafusarás": "desparafusar",
    "desparafusarão": "desparafusar",
    "desparafusaríamos": "desparafusar",
    "desparafusaríeis": "desparafusar",
    "desparafusas": "desparafusar",
    "desparafusasse": "desparafusar",
    "desparafusassem": "desparafusar",
    "desparafusasses": "desparafusar",
    "desparafusaste": "desparafusar",
    "desparafusastes": "desparafusar",
    "desparafusava": "desparafusar",
    "desparafusavam": "desparafusar",
    "desparafusavas": "desparafusar",
    "desparafuse": "desparafusar",
    "desparafusei": "desparafusar",
    "desparafuseis": "desparafusar",
    "desparafusem": "desparafusar",
    "desparafusemo": "desparafusar",
    "desparafusemos": "desparafusar",
    "desparafuses": "desparafusar",
    "desparafuso": "desparafusar",
    "desparafusou": "desparafusar",
    "desparafusá": "desparafusar",
    "desparafusámo": "desparafusar",
    "desparafusámos": "desparafusar",
    "desparafusáramo": "desparafusar",
    "desparafusáramos": "desparafusar",
    "desparafusárei": "desparafusar",
    "desparafusáreis": "desparafusar",
    "desparafusásseis": "desparafusar",
    "desparafusássemos": "desparafusar",
    "desparafusávamo": "desparafusar",
    "desparafusávamos": "desparafusar",
    "desparafusávei": "desparafusar",
    "desparafusáveis": "desparafusar",
    "desparamenta": "desparamentar",
    "desparamentada": "desparamentar",
    "desparamentadas": "desparamentar",
    "desparamentado": "desparamentar",
    "desparamentados": "desparamentar",
    "desparamentai": "desparamentar",
    "desparamentais": "desparamentar",
    "desparamentam": "desparamentar",
    "desparamentamo": "desparamentar",
    "desparamentamos": "desparamentar",
    "desparamentando": "desparamentar",
    "desparamentara": "desparamentar",
    "desparamentaram": "desparamentar",
    "desparamentaras": "desparamentar",
    "desparamentarde": "desparamentar",
    "desparamentardes": "desparamentar",
    "desparamentare": "desparamentar",
    "desparamentarei": "desparamentar",
    "desparamentareis": "desparamentar",
    "desparamentarem": "desparamentar",
    "desparamentaremos": "desparamentar",
    "desparamentares": "desparamentar",
    "desparamentaria": "desparamentar",
    "desparamentariam": "desparamentar",
    "desparamentarias": "desparamentar",
    "desparamentarmo": "desparamentar",
    "desparamentarmos": "desparamentar",
    "desparamentará": "desparamentar",
    "desparamentarás": "desparamentar",
    "desparamentarão": "desparamentar",
    "desparamentaríamos": "desparamentar",
    "desparamentaríeis": "desparamentar",
    "desparamentas": "desparamentar",
    "desparamentasse": "desparamentar",
    "desparamentassem": "desparamentar",
    "desparamentasses": "desparamentar",
    "desparamentaste": "desparamentar",
    "desparamentastes": "desparamentar",
    "desparamentava": "desparamentar",
    "desparamentavam": "desparamentar",
    "desparamentavas": "desparamentar",
    "desparamente": "desparamentar",
    "desparamentei": "desparamentar",
    "desparamenteis": "desparamentar",
    "desparamentem": "desparamentar",
    "desparamentemo": "desparamentar",
    "desparamentemos": "desparamentar",
    "desparamentes": "desparamentar",
    "desparamento": "desparamentar",
    "desparamentou": "desparamentar",
    "desparamentá": "desparamentar",
    "desparamentámo": "desparamentar",
    "desparamentámos": "desparamentar",
    "desparamentáramo": "desparamentar",
    "desparamentáramos": "desparamentar",
    "desparamentárei": "desparamentar",
    "desparamentáreis": "desparamentar",
    "desparamentásseis": "desparamentar",
    "desparamentássemos": "desparamentar",
    "desparamentávamo": "desparamentar",
    "desparamentávamos": "desparamentar",
    "desparamentávei": "desparamentar",
    "desparamentáveis": "desparamentar",
    "desparece": "desparecer",
    "desparecei": "desparecer",
    "despareceis": "desparecer",
    "desparecem": "desparecer",
    "desparecemo": "desparecer",
    "desparecemos": "desparecer",
    "desparecendo": "desparecer",
    "desparecera": "desparecer",
    "despareceram": "desparecer",
    "despareceras": "desparecer",
    "desparecerdes": "desparecer",
    "desparecerei": "desparecer",
    "desparecereis": "desparecer",
    "desparecerem": "desparecer",
    "despareceremos": "desparecer",
    "despareceres": "desparecer",
    "despareceria": "desparecer",
    "despareceriam": "desparecer",
    "desparecerias": "desparecer",
    "desparecermo": "desparecer",
    "desparecermos": "desparecer",
    "desparecerá": "desparecer",
    "desparecerás": "desparecer",
    "desparecerão": "desparecer",
    "despareceríamos": "desparecer",
    "despareceríeis": "desparecer",
    "despareces": "desparecer",
    "desparecesse": "desparecer",
    "desparecessem": "desparecer",
    "desparecesses": "desparecer",
    "despareceste": "desparecer",
    "desparecestes": "desparecer",
    "despareceu": "desparecer",
    "despareci": "desparecer",
    "desparecia": "desparecer",
    "despareciam": "desparecer",
    "desparecias": "desparecer",
    "desparecida": "desparecido",
    "desparecidas": "desparecido",
    "desparecido": "desparecer",
    "desparecidos": "desparecido",
    "desparecêramo": "desparecer",
    "desparecêramos": "desparecer",
    "desparecêreis": "desparecer",
    "desparecêsseis": "desparecer",
    "desparecêssemos": "desparecer",
    "desparecíamo": "desparecer",
    "desparecíamos": "desparecer",
    "desparecíeis": "desparecer",
    "despareça": "desparecer",
    "despareçais": "desparecer",
    "despareçam": "desparecer",
    "despareçamo": "desparecer",
    "despareçamos": "desparecer",
    "despareças": "desparecer",
    "despareço": "desparecer",
    "desparge": "despargir",
    "despargem": "despargir",
    "desparges": "despargir",
    "despargi": "despargir",
    "despargia": "despargir",
    "despargiam": "despargir",
    "despargias": "despargir",
    "despargida": "despargir",
    "despargidas": "despargir",
    "despargido": "despargir",
    "despargidos": "despargir",
    "despargimo": "despargir",
    "despargimos": "despargir",
    "despargindo": "despargir",
    "despargira": "despargir",
    "despargiram": "despargir",
    "despargiras": "despargir",
    "despargirdes": "despargir",
    "despargirei": "despargir",
    "despargireis": "despargir",
    "despargirem": "despargir",
    "despargiremos": "despargir",
    "despargires": "despargir",
    "despargiria": "despargir",
    "despargiriam": "despargir",
    "despargirias": "despargir",
    "despargirmo": "despargir",
    "despargirmos": "despargir",
    "despargirá": "despargir",
    "despargirás": "despargir",
    "despargirão": "despargir",
    "despargiríamos": "despargir",
    "despargiríeis": "despargir",
    "despargis": "despargir",
    "despargisse": "despargir",
    "despargissem": "despargir",
    "despargisses": "despargir",
    "despargiste": "despargir",
    "despargistes": "despargir",
    "despargiu": "despargir",
    "despargíamo": "despargir",
    "despargíamos": "despargir",
    "despargíeis": "despargir",
    "despargíramo": "despargir",
    "despargíramos": "despargir",
    "despargíreis": "despargir",
    "despargísseis": "despargir",
    "despargíssemos": "despargir",
    "desparja": "despargir",
    "desparjais": "despargir",
    "desparjam": "despargir",
    "desparjamo": "despargir",
    "desparjamos": "despargir",
    "desparjas": "despargir",
    "desparjo": "despargir",
    "desparra": "desparrar",
    "desparrada": "desparrar",
    "desparradas": "desparrar",
    "desparrado": "desparrar",
    "desparrados": "desparrar",
    "desparrafusagens": "desparrafusagem",
    "desparrai": "desparrar",
    "desparrais": "desparrar",
    "desparram": "desparrar",
    "desparramo": "desparrar",
    "desparramos": "desparrar",
    "desparrando": "desparrar",
    "desparrara": "desparrar",
    "desparraram": "desparrar",
    "desparraras": "desparrar",
    "desparrarde": "desparrar",
    "desparrardes": "desparrar",
    "desparrare": "desparrar",
    "desparrarei": "desparrar",
    "desparrareis": "desparrar",
    "desparrarem": "desparrar",
    "desparraremos": "desparrar",
    "desparrares": "desparrar",
    "desparraria": "desparrar",
    "desparrariam": "desparrar",
    "desparrarias": "desparrar",
    "desparrarmo": "desparrar",
    "desparrarmos": "desparrar",
    "desparrará": "desparrar",
    "desparrarás": "desparrar",
    "desparrarão": "desparrar",
    "desparraríamos": "desparrar",
    "desparraríeis": "desparrar",
    "desparras": "desparrar",
    "desparrasse": "desparrar",
    "desparrassem": "desparrar",
    "desparrasses": "desparrar",
    "desparraste": "desparrar",
    "desparrastes": "desparrar",
    "desparrava": "desparrar",
    "desparravam": "desparrar",
    "desparravas": "desparrar",
    "desparre": "desparrar",
    "desparrei": "desparrar",
    "desparreis": "desparrar",
    "desparrem": "desparrar",
    "desparremo": "desparrar",
    "desparremos": "desparrar",
    "desparres": "desparrar",
    "desparro": "desparrar",
    "desparrou": "desparrar",
    "desparrá": "desparrar",
    "desparrámo": "desparrar",
    "desparrámos": "desparrar",
    "desparráramo": "desparrar",
    "desparráramos": "desparrar",
    "desparrárei": "desparrar",
    "desparráreis": "desparrar",
    "desparrásseis": "desparrar",
    "desparrássemos": "desparrar",
    "desparrávamo": "desparrar",
    "desparrávamos": "desparrar",
    "desparrávei": "desparrar",
    "desparráveis": "desparrar",
    "despartidarizações": "despartidarização",
    "desparza": "desparzir",
    "desparzais": "desparzir",
    "desparzam": "desparzir",
    "desparzamo": "desparzir",
    "desparzamos": "desparzir",
    "desparzas": "desparzir",
    "desparze": "desparzir",
    "desparzem": "desparzir",
    "desparzes": "desparzir",
    "desparzi": "desparzir",
    "desparzia": "desparzir",
    "desparziam": "desparzir",
    "desparzias": "desparzir",
    "desparzida": "desparzir",
    "desparzidas": "desparzir",
    "desparzido": "desparzir",
    "desparzidos": "desparzir",
    "desparzimo": "desparzir",
    "desparzimos": "desparzir",
    "desparzindo": "desparzir",
    "desparzira": "desparzir",
    "desparziram": "desparzir",
    "desparziras": "desparzir",
    "desparzirde": "desparzir",
    "desparzirdes": "desparzir",
    "desparzire": "desparzir",
    "desparzirei": "desparzir",
    "desparzireis": "desparzir",
    "desparzirem": "desparzir",
    "desparziremos": "desparzir",
    "desparzires": "desparzir",
    "desparziria": "desparzir",
    "desparziriam": "desparzir",
    "desparzirias": "desparzir",
    "desparzirmo": "desparzir",
    "desparzirmos": "desparzir",
    "desparzirá": "desparzir",
    "desparzirás": "desparzir",
    "desparzirão": "desparzir",
    "desparziríamos": "desparzir",
    "desparziríeis": "desparzir",
    "desparzis": "desparzir",
    "desparzisse": "desparzir",
    "desparzissem": "desparzir",
    "desparzisses": "desparzir",
    "desparziste": "desparzir",
    "desparzistes": "desparzir",
    "desparziu": "desparzir",
    "desparzo": "desparzir",
    "desparzíamo": "desparzir",
    "desparzíamos": "desparzir",
    "desparzíei": "desparzir",
    "desparzíeis": "desparzir",
    "desparzíramo": "desparzir",
    "desparzíramos": "desparzir",
    "desparzírei": "desparzir",
    "desparzíreis": "desparzir",
    "desparzísseis": "desparzir",
    "desparzíssemos": "desparzir",
    "despassa": "despassar",
    "despassada": "despassar",
    "despassadas": "despassar",
    "despassado": "despassar",
    "despassados": "despassar",
    "despassai": "despassar",
    "despassais": "despassar",
    "despassam": "despassar",
    "despassamo": "despassar",
    "despassamos": "despassar",
    "despassando": "despassar",
    "despassara": "despassar",
    "despassaram": "despassar",
    "despassaras": "despassar",
    "despassarde": "despassar",
    "despassardes": "despassar",
    "despassare": "despassar",
    "despassarei": "despassar",
    "despassareis": "despassar",
    "despassarem": "despassar",
    "despassaremos": "despassar",
    "despassares": "despassar",
    "despassaria": "despassar",
    "despassariam": "despassar",
    "despassarias": "despassar",
    "despassarmo": "despassar",
    "despassarmos": "despassar",
    "despassará": "despassar",
    "despassarás": "despassar",
    "despassarão": "despassar",
    "despassaríamos": "despassar",
    "despassaríeis": "despassar",
    "despassas": "despassar",
    "despassasse": "despassar",
    "despassassem": "despassar",
    "despassasses": "despassar",
    "despassaste": "despassar",
    "despassastes": "despassar",
    "despassava": "despassar",
    "despassavam": "despassar",
    "despassavas": "despassar",
    "despasse": "despassar",
    "despassei": "despassar",
    "despasseis": "despassar",
    "despassem": "despassar",
    "despassemo": "despassar",
    "despassemos": "despassar",
    "despasses": "despasse",
    "despasso": "despassar",
    "despassou": "despassar",
    "despassá": "despassar",
    "despassámo": "despassar",
    "despassámos": "despassar",
    "despassáramo": "despassar",
    "despassáramos": "despassar",
    "despassárei": "despassar",
    "despassáreis": "despassar",
    "despassásseis": "despassar",
    "despassássemos": "despassar",
    "despassávamo": "despassar",
    "despassávamos": "despassar",
    "despassávei": "despassar",
    "despassáveis": "despassar",
    "despatria": "despatriar",
    "despatriada": "despatriar",
    "despatriadas": "despatriar",
    "despatriado": "despatriar",
    "despatriados": "despatriar",
    "despatriai": "despatriar",
    "despatriais": "despatriar",
    "despatriam": "despatriar",
    "despatriamo": "despatriar",
    "despatriamos": "despatriar",
    "despatriando": "despatriar",
    "despatriara": "despatriar",
    "despatriaram": "despatriar",
    "despatriaras": "despatriar",
    "despatriarde": "despatriar",
    "despatriardes": "despatriar",
    "despatriare": "despatriar",
    "despatriarei": "despatriar",
    "despatriareis": "despatriar",
    "despatriarem": "despatriar",
    "despatriaremos": "despatriar",
    "despatriares": "despatriar",
    "despatriaria": "despatriar",
    "despatriariam": "despatriar",
    "despatriarias": "despatriar",
    "despatriarmo": "despatriar",
    "despatriarmos": "despatriar",
    "despatriará": "despatriar",
    "despatriarás": "despatriar",
    "despatriarão": "despatriar",
    "despatriaríamos": "despatriar",
    "despatriaríeis": "despatriar",
    "despatrias": "despatriar",
    "despatriasse": "despatriar",
    "despatriassem": "despatriar",
    "despatriasses": "despatriar",
    "despatriaste": "despatriar",
    "despatriastes": "despatriar",
    "despatriava": "despatriar",
    "despatriavam": "despatriar",
    "despatriavas": "despatriar",
    "despatrie": "despatriar",
    "despatriei": "despatriar",
    "despatrieis": "despatriar",
    "despatriem": "despatriar",
    "despatriemo": "despatriar",
    "despatriemos": "despatriar",
    "despatries": "despatriar",
    "despatrio": "despatriar",
    "despatriotas": "despatriota",
    "despatriotismos": "despatriotismo",
    "despatriou": "despatriar",
    "despatriá": "despatriar",
    "despatriámo": "despatriar",
    "despatriámos": "despatriar",
    "despatriáramo": "despatriar",
    "despatriáramos": "despatriar",
    "despatriárei": "despatriar",
    "despatriáreis": "despatriar",
    "despatriásseis": "despatriar",
    "despatriássemos": "despatriar",
    "despatriávamo": "despatriar",
    "despatriávamos": "despatriar",
    "despatriávei": "despatriar",
    "despatriáveis": "despatriar",
    "despatriótica": "despatriótico",
    "despatrióticas": "despatriótico",
    "despatrióticos": "despatriótico",
    "despautérios": "despautério",
    "despavorida": "despavorido",
    "despavoridas": "despavorido",
    "despavoridos": "despavorido",
    "despe": "despir",
    "despeada": "despear",
    "despeadas": "despear",
    "despeado": "despear",
    "despeados": "despear",
    "despeai": "despear",
    "despeais": "despear",
    "despeamo": "despear",
    "despeamos": "despear",
    "despeando": "despear",
    "despeara": "despear",
    "despearam": "despear",
    "despearas": "despear",
    "despearde": "despear",
    "despeardes": "despear",
    "despeare": "despear",
    "despearei": "despear",
    "despeareis": "despear",
    "despearem": "despear",
    "despearemos": "despear",
    "despeares": "despear",
    "despearia": "despear",
    "despeariam": "despear",
    "despearias": "despear",
    "despearmo": "despear",
    "despearmos": "despear",
    "despeará": "despear",
    "despearás": "despear",
    "despearão": "despear",
    "despearíamos": "despear",
    "despearíeis": "despear",
    "despeasse": "despear",
    "despeassem": "despear",
    "despeasses": "despear",
    "despeaste": "despear",
    "despeastes": "despear",
    "despeava": "despear",
    "despeavam": "despear",
    "despeavas": "despear",
    "despecunia": "despecuniar",
    "despecuniada": "despecuniar",
    "despecuniadas": "despecuniar",
    "despecuniado": "despecuniar",
    "despecuniados": "despecuniar",
    "despecuniai": "despecuniar",
    "despecuniais": "despecuniar",
    "despecuniam": "despecuniar",
    "despecuniamo": "despecuniar",
    "despecuniamos": "despecuniar",
    "despecuniando": "despecuniar",
    "despecuniara": "despecuniar",
    "despecuniaram": "despecuniar",
    "despecuniaras": "despecuniar",
    "despecuniarde": "despecuniar",
    "despecuniardes": "despecuniar",
    "despecuniare": "despecuniar",
    "despecuniarei": "despecuniar",
    "despecuniareis": "despecuniar",
    "despecuniarem": "despecuniar",
    "despecuniaremos": "despecuniar",
    "despecuniares": "despecuniar",
    "despecuniaria": "despecuniar",
    "despecuniariam": "despecuniar",
    "despecuniarias": "despecuniar",
    "despecuniarmo": "despecuniar",
    "despecuniarmos": "despecuniar",
    "despecuniará": "despecuniar",
    "despecuniarás": "despecuniar",
    "despecuniarão": "despecuniar",
    "despecuniaríamos": "despecuniar",
    "despecuniaríeis": "despecuniar",
    "despecunias": "despecuniar",
    "despecuniasse": "despecuniar",
    "despecuniassem": "despecuniar",
    "despecuniasses": "despecuniar",
    "despecuniaste": "despecuniar",
    "despecuniastes": "despecuniar",
    "despecuniava": "despecuniar",
    "despecuniavam": "despecuniar",
    "despecuniavas": "despecuniar",
    "despecunie": "despecuniar",
    "despecuniei": "despecuniar",
    "despecunieis": "despecuniar",
    "despecuniem": "despecuniar",
    "despecuniemo": "despecuniar",
    "despecuniemos": "despecuniar",
    "despecunies": "despecuniar",
    "despecunio": "despecuniar",
    "despecuniou": "despecuniar",
    "despecuniá": "despecuniar",
    "despecuniámo": "despecuniar",
    "despecuniámos": "despecuniar",
    "despecuniáramo": "despecuniar",
    "despecuniáramos": "despecuniar",
    "despecuniárei": "despecuniar",
    "despecuniáreis": "despecuniar",
    "despecuniásseis": "despecuniar",
    "despecuniássemos": "despecuniar",
    "despecuniávamo": "despecuniar",
    "despecuniávamos": "despecuniar",
    "despecuniávei": "despecuniar",
    "despecuniáveis": "despecuniar",
    "despedace": "despedaçar",
    "despedacei": "despedaçar",
    "despedaceis": "despedaçar",
    "despedacem": "despedaçar",
    "despedacemo": "despedaçar",
    "despedacemos": "despedaçar",
    "despedaces": "despedaçar",
    "despedaça": "despedaçar",
    "despedaçada": "despedaçar",
    "despedaçadas": "despedaçar",
    "despedaçado": "despedaçar",
    "despedaçadora": "despedaçador",
    "despedaçadoras": "despedaçador",
    "despedaçadores": "despedaçador",
    "despedaçados": "despedaçar",
    "despedaçai": "despedaçar",
    "despedaçais": "despedaçar",
    "despedaçam": "despedaçar",
    "despedaçamentos": "despedaçamento",
    "despedaçamo": "despedaçar",
    "despedaçamos": "despedaçar",
    "despedaçando": "despedaçar",
    "despedaçara": "despedaçar",
    "despedaçaram": "despedaçar",
    "despedaçaras": "despedaçar",
    "despedaçarde": "despedaçar",
    "despedaçardes": "despedaçar",
    "despedaçare": "despedaçar",
    "despedaçarei": "despedaçar",
    "despedaçareis": "despedaçar",
    "despedaçarem": "despedaçar",
    "despedaçaremos": "despedaçar",
    "despedaçares": "despedaçar",
    "despedaçaria": "despedaçar",
    "despedaçariam": "despedaçar",
    "despedaçarias": "despedaçar",
    "despedaçarmo": "despedaçar",
    "despedaçarmos": "despedaçar",
    "despedaçará": "despedaçar",
    "despedaçarás": "despedaçar",
    "despedaçarão": "despedaçar",
    "despedaçaríamos": "despedaçar",
    "despedaçaríeis": "despedaçar",
    "despedaças": "despedaçar",
    "despedaçasse": "despedaçar",
    "despedaçassem": "despedaçar",
    "despedaçasses": "despedaçar",
    "despedaçaste": "despedaçar",
    "despedaçastes": "despedaçar",
    "despedaçava": "despedaçar",
    "despedaçavam": "despedaçar",
    "despedaçavas": "despedaçar",
    "despedaço": "despedaçar",
    "despedaçou": "despedaçar",
    "despedaçá": "despedaçar",
    "despedaçámo": "despedaçar",
    "despedaçámos": "despedaçar",
    "despedaçáramo": "despedaçar",
    "despedaçáramos": "despedaçar",
    "despedaçárei": "despedaçar",
    "despedaçáreis": "despedaçar",
    "despedaçásseis": "despedaçar",
    "despedaçássemos": "despedaçar",
    "despedaçávamo": "despedaçar",
    "despedaçávamos": "despedaçar",
    "despedaçávei": "despedaçar",
    "despedaçáveis": "despedaçável",
    "despede": "despedir",
    "despedem": "despedir",
    "despedes": "despedir",
    "despedi": "despedir",
    "despedia": "despedir",
    "despediam": "despedir",
    "despedias": "despedir",
    "despedida": "despedir",
    "despedidas": "despedir",
    "despedido": "despedir",
    "despedidos": "despedir",
    "despedimentos": "despedimento",
    "despedimo": "despedir",
    "despedimos": "despedir",
    "despedindo": "despedir",
    "despedira": "despedir",
    "despediram": "despedir",
    "despediras": "despedir",
    "despedirde": "despedir",
    "despedirdes": "despedir",
    "despedire": "despedir",
    "despedirei": "despedir",
    "despedireis": "despedir",
    "despedirem": "despedir",
    "despediremos": "despedir",
    "despedires": "despedir",
    "despediria": "despedir",
    "despediriam": "despedir",
    "despedirias": "despedir",
    "despedirmo": "despedir",
    "despedirmos": "despedir",
    "despedirá": "despedir",
    "despedirás": "despedir",
    "despedirão": "despedir",
    "despediríamos": "despedir",
    "despediríeis": "despedir",
    "despedis": "despedir",
    "despedisse": "despedir",
    "despedissem": "despedir",
    "despedisses": "despedir",
    "despediste": "despedir",
    "despedistes": "despedir",
    "despediu": "despedir",
    "despedra": "despedrar",
    "despedrada": "despedrar",
    "despedradas": "despedrar",
    "despedrado": "despedrar",
    "despedrados": "despedrar",
    "despedrai": "despedrar",
    "despedrais": "despedrar",
    "despedram": "despedrar",
    "despedramo": "despedrar",
    "despedramos": "despedrar",
    "despedrando": "despedrar",
    "despedrara": "despedrar",
    "despedraram": "despedrar",
    "despedraras": "despedrar",
    "despedrarde": "despedrar",
    "despedrardes": "despedrar",
    "despedrare": "despedrar",
    "despedrarei": "despedrar",
    "despedrareis": "despedrar",
    "despedrarem": "despedrar",
    "despedraremos": "despedrar",
    "despedrares": "despedrar",
    "despedraria": "despedrar",
    "despedrariam": "despedrar",
    "despedrarias": "despedrar",
    "despedrarmo": "despedrar",
    "despedrarmos": "despedrar",
    "despedrará": "despedrar",
    "despedrarás": "despedrar",
    "despedrarão": "despedrar",
    "despedraríamos": "despedrar",
    "despedraríeis": "despedrar",
    "despedras": "despedrar",
    "despedrasse": "despedrar",
    "despedrassem": "despedrar",
    "despedrasses": "despedrar",
    "despedraste": "despedrar",
    "despedrastes": "despedrar",
    "despedrava": "despedrar",
    "despedravam": "despedrar",
    "despedravas": "despedrar",
    "despedre": "despedrar",
    "despedrei": "despedrar",
    "despedreis": "despedrar",
    "despedrem": "despedrar",
    "despedremo": "despedrar",
    "despedremos": "despedrar",
    "despedres": "despedrar",
    "despedro": "despedrar",
    "despedrou": "despedrar",
    "despedrá": "despedrar",
    "despedrámo": "despedrar",
    "despedrámos": "despedrar",
    "despedráramo": "despedrar",
    "despedráramos": "despedrar",
    "despedrárei": "despedrar",
    "despedráreis": "despedrar",
    "despedrásseis": "despedrar",
    "despedrássemos": "despedrar",
    "despedrávamo": "despedrar",
    "despedrávamos": "despedrar",
    "despedrávei": "despedrar",
    "despedráveis": "despedrar",
    "despedíamo": "despedir",
    "despedíamos": "despedir",
    "despedíei": "despedir",
    "despedíeis": "despedir",
    "despedíramo": "despedir",
    "despedíramos": "despedir",
    "despedírei": "despedir",
    "despedíreis": "despedir",
    "despedísseis": "despedir",
    "despedíssemos": "despedir",
    "despeei": "despear",
    "despeeis": "despear",
    "despeemo": "despear",
    "despeemos": "despear",
    "despega": "despegar",
    "despegada": "despegar",
    "despegadas": "despegar",
    "despegado": "despegar",
    "despegados": "despegar",
    "despegai": "despegar",
    "despegais": "despegar",
    "despegam": "despegar",
    "despegamentos": "despegamento",
    "despegamo": "despegar",
    "despegamos": "despegar",
    "despegando": "despegar",
    "despegara": "despegar",
    "despegaram": "despegar",
    "despegaras": "despegar",
    "despegarde": "despegar",
    "despegardes": "despegar",
    "despegare": "despegar",
    "despegarei": "despegar",
    "despegareis": "despegar",
    "despegarem": "despegar",
    "despegaremos": "despegar",
    "despegares": "despegar",
    "despegaria": "despegar",
    "despegariam": "despegar",
    "despegarias": "despegar",
    "despegarmo": "despegar",
    "despegarmos": "despegar",
    "despegará": "despegar",
    "despegarás": "despegar",
    "despegarão": "despegar",
    "despegaríamos": "despegar",
    "despegaríeis": "despegar",
    "despegas": "despegar",
    "despegasse": "despegar",
    "despegassem": "despegar",
    "despegasses": "despegar",
    "despegaste": "despegar",
    "despegastes": "despegar",
    "despegava": "despegar",
    "despegavam": "despegar",
    "despegavas": "despegar",
    "despego": "despegar",
    "despegos": "despego",
    "despegou": "despegar",
    "despegue": "despegar",
    "despeguei": "despegar",
    "despegueis": "despegar",
    "despeguem": "despegar",
    "despeguemo": "despegar",
    "despeguemos": "despegar",
    "despegues": "despegar",
    "despegá": "despegar",
    "despegámo": "despegar",
    "despegámos": "despegar",
    "despegáramo": "despegar",
    "despegáramos": "despegar",
    "despegárei": "despegar",
    "despegáreis": "despegar",
    "despegásseis": "despegar",
    "despegássemos": "despegar",
    "despegávamo": "despegar",
    "despegávamos": "despegar",
    "despegávei": "despegar",
    "despegáveis": "despegável",
    "despeia": "despear",
    "despeiam": "despear",
    "despeias": "despear",
    "despeie": "despear",
    "despeiem": "despear",
    "despeies": "despear",
    "despeio": "despear",
    "despeita": "despeitar",
    "despeitada": "despeitar",
    "despeitadas": "despeitar",
    "despeitado": "despeitar",
    "despeitadora": "despeitador",
    "despeitadoras": "despeitador",
    "despeitadores": "despeitador",
    "despeitados": "despeitar",
    "despeitai": "despeitar",
    "despeitais": "despeitar",
    "despeitam": "despeitar",
    "despeitamentos": "despeitamento",
    "despeitamo": "despeitar",
    "despeitamos": "despeitar",
    "despeitando": "despeitar",
    "despeitara": "despeitar",
    "despeitaram": "despeitar",
    "despeitaras": "despeitar",
    "despeitarde": "despeitar",
    "despeitardes": "despeitar",
    "despeitare": "despeitar",
    "despeitarei": "despeitar",
    "despeitareis": "despeitar",
    "despeitarem": "despeitar",
    "despeitaremos": "despeitar",
    "despeitares": "despeitar",
    "despeitaria": "despeitar",
    "despeitariam": "despeitar",
    "despeitarias": "despeitar",
    "despeitarmo": "despeitar",
    "despeitarmos": "despeitar",
    "despeitará": "despeitar",
    "despeitarás": "despeitar",
    "despeitarão": "despeitar",
    "despeitaríamos": "despeitar",
    "despeitaríeis": "despeitar",
    "despeitas": "despeitar",
    "despeitasse": "despeitar",
    "despeitassem": "despeitar",
    "despeitasses": "despeitar",
    "despeitaste": "despeitar",
    "despeitastes": "despeitar",
    "despeitava": "despeitar",
    "despeitavam": "despeitar",
    "despeitavas": "despeitar",
    "despeite": "despeitar",
    "despeitei": "despeitar",
    "despeiteis": "despeitar",
    "despeitem": "despeitar",
    "despeitemo": "despeitar",
    "despeitemos": "despeitar",
    "despeites": "despeitar",
    "despeito": "despeitar",
    "despeitora": "despeitorar",
    "despeitorada": "despeitorar",
    "despeitoradas": "despeitorar",
    "despeitorado": "despeitorar",
    "despeitorados": "despeitorar",
    "despeitorai": "despeitorar",
    "despeitorais": "despeitorar",
    "despeitoram": "despeitorar",
    "despeitoramo": "despeitorar",
    "despeitoramos": "despeitorar",
    "despeitorando": "despeitorar",
    "despeitorara": "despeitorar",
    "despeitoraram": "despeitorar",
    "despeitoraras": "despeitorar",
    "despeitorarde": "despeitorar",
    "despeitorardes": "despeitorar",
    "despeitorare": "despeitorar",
    "despeitorarei": "despeitorar",
    "despeitorareis": "despeitorar",
    "despeitorarem": "despeitorar",
    "despeitoraremos": "despeitorar",
    "despeitorares": "despeitorar",
    "despeitoraria": "despeitorar",
    "despeitorariam": "despeitorar",
    "despeitorarias": "despeitorar",
    "despeitorarmo": "despeitorar",
    "despeitorarmos": "despeitorar",
    "despeitorará": "despeitorar",
    "despeitorarás": "despeitorar",
    "despeitorarão": "despeitorar",
    "despeitoraríamos": "despeitorar",
    "despeitoraríeis": "despeitorar",
    "despeitoras": "despeitorar",
    "despeitorasse": "despeitorar",
    "despeitorassem": "despeitorar",
    "despeitorasses": "despeitorar",
    "despeitoraste": "despeitorar",
    "despeitorastes": "despeitorar",
    "despeitorava": "despeitorar",
    "despeitoravam": "despeitorar",
    "despeitoravas": "despeitorar",
    "despeitore": "despeitorar",
    "despeitorei": "despeitorar",
    "despeitoreis": "despeitorar",
    "despeitorem": "despeitorar",
    "despeitoremo": "despeitorar",
    "despeitoremos": "despeitorar",
    "despeitores": "despeitorar",
    "despeitoro": "despeitorar",
    "despeitorou": "despeitorar",
    "despeitorá": "despeitorar",
    "despeitorámo": "despeitorar",
    "despeitorámos": "despeitorar",
    "despeitoráramo": "despeitorar",
    "despeitoráramos": "despeitorar",
    "despeitorárei": "despeitorar",
    "despeitoráreis": "despeitorar",
    "despeitorásseis": "despeitorar",
    "despeitorássemos": "despeitorar",
    "despeitorávamo": "despeitorar",
    "despeitorávamos": "despeitorar",
    "despeitorávei": "despeitorar",
    "despeitoráveis": "despeitorar",
    "despeitos": "despeito",
    "despeitosa": "despeitoso",
    "despeitosas": "despeitoso",
    "despeitosos": "despeitoso",
    "despeitou": "despeitar",
    "despeitá": "despeitar",
    "despeitámo": "despeitar",
    "despeitámos": "despeitar",
    "despeitáramo": "despeitar",
    "despeitáramos": "despeitar",
    "despeitárei": "despeitar",
    "despeitáreis": "despeitar",
    "despeitásseis": "despeitar",
    "despeitássemos": "despeitar",
    "despeitávamo": "despeitar",
    "despeitávamos": "despeitar",
    "despeitávei": "despeitar",
    "despeitáveis": "despeitar",
    "despeja": "despejar",
    "despejada": "despejar",
    "despejadas": "despejar",
    "despejado": "despejar",
    "despejadora": "despejador",
    "despejadoras": "despejador",
    "despejadores": "despejador",
    "despejados": "despejar",
    "despejadouros": "despejadouro",
    "despejai": "despejar",
    "despejais": "despejar",
    "despejam": "despejar",
    "despejamentos": "despejamento",
    "despejamo": "despejar",
    "despejamos": "despejar",
    "despejando": "despejar",
    "despejara": "despejar",
    "despejaram": "despejar",
    "despejaras": "despejar",
    "despejarde": "despejar",
    "despejardes": "despejar",
    "despejare": "despejar",
    "despejarei": "despejar",
    "despejareis": "despejar",
    "despejarem": "despejar",
    "despejaremos": "despejar",
    "despejares": "despejar",
    "despejaria": "despejar",
    "despejariam": "despejar",
    "despejarias": "despejar",
    "despejarmo": "despejar",
    "despejarmos": "despejar",
    "despejará": "despejar",
    "despejarás": "despejar",
    "despejarão": "despejar",
    "despejaríamos": "despejar",
    "despejaríeis": "despejar",
    "despejas": "despejar",
    "despejasse": "despejar",
    "despejassem": "despejar",
    "despejasses": "despejar",
    "despejaste": "despejar",
    "despejastes": "despejar",
    "despejava": "despejar",
    "despejavam": "despejar",
    "despejavas": "despejar",
    "despeje": "despejar",
    "despejei": "despejar",
    "despejeis": "despejar",
    "despejem": "despejar",
    "despejemo": "despejar",
    "despejemos": "despejar",
    "despejes": "despejar",
    "despejo": "despejar",
    "despejos": "despejo",
    "despejou": "despejar",
    "despejá": "despejar",
    "despejámo": "despejar",
    "despejámos": "despejar",
    "despejáramo": "despejar",
    "despejáramos": "despejar",
    "despejárei": "despejar",
    "despejáreis": "despejar",
    "despejásseis": "despejar",
    "despejássemos": "despejar",
    "despejávamo": "despejar",
    "despejávamos": "despejar",
    "despejávei": "despejar",
    "despejáveis": "despejar",
    "despela": "despelar",
    "despelada": "despelar",
    "despeladas": "despelar",
    "despelado": "despelar",
    "despelados": "despelar",
    "despelai": "despelar",
    "despelais": "despelar",
    "despelam": "despelar",
    "despelamo": "despelar",
    "despelamos": "despelar",
    "despelando": "despelar",
    "despelara": "despelar",
    "despelaram": "despelar",
    "despelaras": "despelar",
    "despelarde": "despelar",
    "despelardes": "despelar",
    "despelare": "despelar",
    "despelarei": "despelar",
    "despelareis": "despelar",
    "despelarem": "despelar",
    "despelaremos": "despelar",
    "despelares": "despelar",
    "despelaria": "despelar",
    "despelariam": "despelar",
    "despelarias": "despelar",
    "despelarmo": "despelar",
    "despelarmos": "despelar",
    "despelará": "despelar",
    "despelarás": "despelar",
    "despelarão": "despelar",
    "despelaríamos": "despelar",
    "despelaríeis": "despelar",
    "despelas": "despelar",
    "despelasse": "despelar",
    "despelassem": "despelar",
    "despelasses": "despelar",
    "despelaste": "despelar",
    "despelastes": "despelar",
    "despelava": "despelar",
    "despelavam": "despelar",
    "despelavas": "despelar",
    "despele": "despelar",
    "despelei": "despelar",
    "despeleis": "despelar",
    "despelem": "despelar",
    "despelemo": "despelar",
    "despelemos": "despelar",
    "despeles": "despelar",
    "despelo": "despelar",
    "despelou": "despelar",
    "despelá": "despelar",
    "despelámo": "despelar",
    "despelámos": "despelar",
    "despeláramo": "despelar",
    "despeláramos": "despelar",
    "despelárei": "despelar",
    "despeláreis": "despelar",
    "despelásseis": "despelar",
    "despelássemos": "despelar",
    "despelávamo": "despelar",
    "despelávamos": "despelar",
    "despelávei": "despelar",
    "despeláveis": "despelar",
    "despem": "despir",
    "despena": "despenar",
    "despenada": "despenar",
    "despenadas": "despenar",
    "despenado": "despenar",
    "despenados": "despenar",
    "despenai": "despenar",
    "despenais": "despenar",
    "despenaliza": "despenalizar",
    "despenalizada": "despenalizar",
    "despenalizadas": "despenalizar",
    "despenalizado": "despenalizar",
    "despenalizadora": "despenalizador",
    "despenalizadoras": "despenalizador",
    "despenalizadores": "despenalizador",
    "despenalizados": "despenalizar",
    "despenalizai": "despenalizar",
    "despenalizais": "despenalizar",
    "despenalizam": "despenalizar",
    "despenalizamo": "despenalizar",
    "despenalizamos": "despenalizar",
    "despenalizando": "despenalizar",
    "despenalizara": "despenalizar",
    "despenalizaram": "despenalizar",
    "despenalizaras": "despenalizar",
    "despenalizarde": "despenalizar",
    "despenalizardes": "despenalizar",
    "despenalizare": "despenalizar",
    "despenalizarei": "despenalizar",
    "despenalizareis": "despenalizar",
    "despenalizarem": "despenalizar",
    "despenalizaremos": "despenalizar",
    "despenalizares": "despenalizar",
    "despenalizaria": "despenalizar",
    "despenalizariam": "despenalizar",
    "despenalizarias": "despenalizar",
    "despenalizarmo": "despenalizar",
    "despenalizarmos": "despenalizar",
    "despenalizará": "despenalizar",
    "despenalizarás": "despenalizar",
    "despenalizarão": "despenalizar",
    "despenalizaríamos": "despenalizar",
    "despenalizaríeis": "despenalizar",
    "despenalizas": "despenalizar",
    "despenalizasse": "despenalizar",
    "despenalizassem": "despenalizar",
    "despenalizasses": "despenalizar",
    "despenalizaste": "despenalizar",
    "despenalizastes": "despenalizar",
    "despenalizava": "despenalizar",
    "despenalizavam": "despenalizar",
    "despenalizavas": "despenalizar",
    "despenalizações": "despenalização",
    "despenalize": "despenalizar",
    "despenalizei": "despenalizar",
    "despenalizeis": "despenalizar",
    "despenalizem": "despenalizar",
    "despenalizemo": "despenalizar",
    "despenalizemos": "despenalizar",
    "despenalizes": "despenalizar",
    "despenalizo": "despenalizar",
    "despenalizou": "despenalizar",
    "despenalizá": "despenalizar",
    "despenalizámo": "despenalizar",
    "despenalizámos": "despenalizar",
    "despenalizáramo": "despenalizar",
    "despenalizáramos": "despenalizar",
    "despenalizárei": "despenalizar",
    "despenalizáreis": "despenalizar",
    "despenalizásseis": "despenalizar",
    "despenalizássemos": "despenalizar",
    "despenalizávamo": "despenalizar",
    "despenalizávamos": "despenalizar",
    "despenalizávei": "despenalizar",
    "despenalizáveis": "despenalizável",
    "despenam": "despenar",
    "despenamo": "despenar",
    "despenamos": "despenar",
    "despenando": "despenar",
    "despenara": "despenar",
    "despenaram": "despenar",
    "despenaras": "despenar",
    "despenarde": "despenar",
    "despenardes": "despenar",
    "despenare": "despenar",
    "despenarei": "despenar",
    "despenareis": "despenar",
    "despenarem": "despenar",
    "despenaremos": "despenar",
    "despenares": "despenar",
    "despenaria": "despenar",
    "despenariam": "despenar",
    "despenarias": "despenar",
    "despenarmo": "despenar",
    "despenarmos": "despenar",
    "despenará": "despenar",
    "despenarás": "despenar",
    "despenarão": "despenar",
    "despenaríamos": "despenar",
    "despenaríeis": "despenar",
    "despenas": "despenar",
    "despenasse": "despenar",
    "despenassem": "despenar",
    "despenasses": "despenar",
    "despenaste": "despenar",
    "despenastes": "despenar",
    "despenava": "despenar",
    "despenavam": "despenar",
    "despenavas": "despenar",
    "despenca": "despencar",
    "despencada": "despencar",
    "despencadas": "despencar",
    "despencado": "despencar",
    "despencados": "despencar",
    "despencai": "despencar",
    "despencais": "despencar",
    "despencam": "despencar",
    "despencamo": "despencar",
    "despencamos": "despencar",
    "despencando": "despencar",
    "despencara": "despencar",
    "despencaram": "despencar",
    "despencaras": "despencar",
    "despencarde": "despencar",
    "despencardes": "despencar",
    "despencare": "despencar",
    "despencarei": "despencar",
    "despencareis": "despencar",
    "despencarem": "despencar",
    "despencaremos": "despencar",
    "despencares": "despencar",
    "despencaria": "despencar",
    "despencariam": "despencar",
    "despencarias": "despencar",
    "despencarmo": "despencar",
    "despencarmos": "despencar",
    "despencará": "despencar",
    "despencarás": "despencar",
    "despencarão": "despencar",
    "despencaríamos": "despencar",
    "despencaríeis": "despencar",
    "despencas": "despencar",
    "despencasse": "despencar",
    "despencassem": "despencar",
    "despencasses": "despencar",
    "despencaste": "despencar",
    "despencastes": "despencar",
    "despencava": "despencar",
    "despencavam": "despencar",
    "despencavas": "despencar",
    "despenco": "despencar",
    "despencou": "despencar",
    "despencá": "despencar",
    "despencámo": "despencar",
    "despencámos": "despencar",
    "despencáramo": "despencar",
    "despencáramos": "despencar",
    "despencárei": "despencar",
    "despencáreis": "despencar",
    "despencásseis": "despencar",
    "despencássemos": "despencar",
    "despencávamo": "despencar",
    "despencávamos": "despencar",
    "despencávei": "despencar",
    "despencáveis": "despencar",
    "despenda": "despender",
    "despendais": "despender",
    "despendam": "despender",
    "despendamo": "despender",
    "despendamos": "despender",
    "despendas": "despender",
    "despende": "despender",
    "despendedora": "despendedor",
    "despendedoras": "despendedor",
    "despendedores": "despendedor",
    "despendei": "despender",
    "despendeis": "despender",
    "despendem": "despender",
    "despendemo": "despender",
    "despendemos": "despender",
    "despendendo": "despender",
    "despendera": "despender",
    "despenderam": "despender",
    "despenderas": "despender",
    "despenderde": "despender",
    "despenderdes": "despender",
    "despendere": "despender",
    "despenderei": "despender",
    "despendereis": "despender",
    "despenderem": "despender",
    "despenderemos": "despender",
    "despenderes": "despender",
    "despenderia": "despender",
    "despenderiam": "despender",
    "despenderias": "despender",
    "despendermo": "despender",
    "despendermos": "despender",
    "despenderá": "despender",
    "despenderás": "despender",
    "despenderão": "despender",
    "despenderíamos": "despender",
    "despenderíeis": "despender",
    "despendes": "despender",
    "despendesse": "despender",
    "despendessem": "despender",
    "despendesses": "despender",
    "despendeste": "despender",
    "despendestes": "despender",
    "despendeu": "despender",
    "despendi": "despender",
    "despendia": "despender",
    "despendiam": "despender",
    "despendias": "despender",
    "despendida": "despendido",
    "despendidas": "despendido",
    "despendido": "despender",
    "despendidos": "despendido",
    "despendo": "despender",
    "despendura": "despendurar",
    "despendurada": "despendurar",
    "despenduradas": "despendurar",
    "despendurado": "despendurar",
    "despendurados": "despendurar",
    "despendurai": "despendurar",
    "despendurais": "despendurar",
    "despenduram": "despendurar",
    "despenduramo": "despendurar",
    "despenduramos": "despendurar",
    "despendurando": "despendurar",
    "despendurara": "despendurar",
    "despenduraram": "despendurar",
    "despenduraras": "despendurar",
    "despendurarde": "despendurar",
    "despendurardes": "despendurar",
    "despendurare": "despendurar",
    "despendurarei": "despendurar",
    "despendurareis": "despendurar",
    "despendurarem": "despendurar",
    "despenduraremos": "despendurar",
    "despendurares": "despendurar",
    "despenduraria": "despendurar",
    "despendurariam": "despendurar",
    "despendurarias": "despendurar",
    "despendurarmo": "despendurar",
    "despendurarmos": "despendurar",
    "despendurará": "despendurar",
    "despendurarás": "despendurar",
    "despendurarão": "despendurar",
    "despenduraríamos": "despendurar",
    "despenduraríeis": "despendurar",
    "despenduras": "despendurar",
    "despendurasse": "despendurar",
    "despendurassem": "despendurar",
    "despendurasses": "despendurar",
    "despenduraste": "despendurar",
    "despendurastes": "despendurar",
    "despendurava": "despendurar",
    "despenduravam": "despendurar",
    "despenduravas": "despendurar",
    "despendure": "despendurar",
    "despendurei": "despendurar",
    "despendureis": "despendurar",
    "despendurem": "despendurar",
    "despenduremo": "despendurar",
    "despenduremos": "despendurar",
    "despendures": "despendurar",
    "despenduro": "despendurar",
    "despendurou": "despendurar",
    "despendurá": "despendurar",
    "despendurámo": "despendurar",
    "despendurámos": "despendurar",
    "despenduráramo": "despendurar",
    "despenduráramos": "despendurar",
    "despendurárei": "despendurar",
    "despenduráreis": "despendurar",
    "despendurásseis": "despendurar",
    "despendurássemos": "despendurar",
    "despendurávamo": "despendurar",
    "despendurávamos": "despendurar",
    "despendurávei": "despendurar",
    "despenduráveis": "despendurar",
    "despendê": "despender",
    "despendêramo": "despender",
    "despendêramos": "despender",
    "despendêrei": "despender",
    "despendêreis": "despender",
    "despendêsseis": "despender",
    "despendêssemos": "despender",
    "despendíamo": "despender",
    "despendíamos": "despender",
    "despendíei": "despender",
    "despendíeis": "despender",
    "despene": "despenar",
    "despenei": "despenar",
    "despeneis": "despenar",
    "despenem": "despenar",
    "despenemo": "despenar",
    "despenemos": "despenar",
    "despenes": "despenar",
    "despenha": "despenhar",
    "despenhada": "despenhar",
    "despenhadas": "despenhar",
    "despenhadeiros": "despenhadeiro",
    "despenhado": "despenhar",
    "despenhados": "despenhar",
    "despenhai": "despenhar",
    "despenhais": "despenhar",
    "despenham": "despenhar",
    "despenhamentos": "despenhamento",
    "despenhamo": "despenhar",
    "despenhamos": "despenhar",
    "despenhando": "despenhar",
    "despenhara": "despenhar",
    "despenharam": "despenhar",
    "despenharas": "despenhar",
    "despenharde": "despenhar",
    "despenhardes": "despenhar",
    "despenhare": "despenhar",
    "despenharei": "despenhar",
    "despenhareis": "despenhar",
    "despenharem": "despenhar",
    "despenharemos": "despenhar",
    "despenhares": "despenhar",
    "despenharia": "despenhar",
    "despenhariam": "despenhar",
    "despenharias": "despenhar",
    "despenharmo": "despenhar",
    "despenharmos": "despenhar",
    "despenhará": "despenhar",
    "despenharás": "despenhar",
    "despenharão": "despenhar",
    "despenharíamos": "despenhar",
    "despenharíeis": "despenhar",
    "despenhas": "despenhar",
    "despenhasse": "despenhar",
    "despenhassem": "despenhar",
    "despenhasses": "despenhar",
    "despenhaste": "despenhar",
    "despenhastes": "despenhar",
    "despenhava": "despenhar",
    "despenhavam": "despenhar",
    "despenhavas": "despenhar",
    "despenhe": "despenhar",
    "despenhei": "despenhar",
    "despenheis": "despenhar",
    "despenhem": "despenhar",
    "despenhemo": "despenhar",
    "despenhemos": "despenhar",
    "despenhes": "despenhar",
    "despenho": "despenhar",
    "despenhos": "despenho",
    "despenhosa": "despenhoso",
    "despenhosas": "despenhoso",
    "despenhosos": "despenhoso",
    "despenhou": "despenhar",
    "despenhá": "despenhar",
    "despenhámo": "despenhar",
    "despenhámos": "despenhar",
    "despenháramo": "despenhar",
    "despenháramos": "despenhar",
    "despenhárei": "despenhar",
    "despenháreis": "despenhar",
    "despenhásseis": "despenhar",
    "despenhássemos": "despenhar",
    "despenhávamo": "despenhar",
    "despenhávamos": "despenhar",
    "despenhávei": "despenhar",
    "despenháveis": "despenhar",
    "despenhões": "despenhão",
    "despenitencia": "despenitenciar",
    "despenitenciada": "despenitenciar",
    "despenitenciadas": "despenitenciar",
    "despenitenciado": "despenitenciar",
    "despenitenciados": "despenitenciar",
    "despenitenciai": "despenitenciar",
    "despenitenciais": "despenitenciar",
    "despenitenciam": "despenitenciar",
    "despenitenciamo": "despenitenciar",
    "despenitenciamos": "despenitenciar",
    "despenitenciando": "despenitenciar",
    "despenitenciara": "despenitenciar",
    "despenitenciaram": "despenitenciar",
    "despenitenciaras": "despenitenciar",
    "despenitenciarde": "despenitenciar",
    "despenitenciardes": "despenitenciar",
    "despenitenciare": "despenitenciar",
    "despenitenciarei": "despenitenciar",
    "despenitenciareis": "despenitenciar",
    "despenitenciarem": "despenitenciar",
    "despenitenciaremos": "despenitenciar",
    "despenitenciares": "despenitenciar",
    "despenitenciaria": "despenitenciar",
    "despenitenciariam": "despenitenciar",
    "despenitenciarias": "despenitenciar",
    "despenitenciarmo": "despenitenciar",
    "despenitenciarmos": "despenitenciar",
    "despenitenciará": "despenitenciar",
    "despenitenciarás": "despenitenciar",
    "despenitenciarão": "despenitenciar",
    "despenitenciaríamos": "despenitenciar",
    "despenitenciaríeis": "despenitenciar",
    "despenitencias": "despenitenciar",
    "despenitenciasse": "despenitenciar",
    "despenitenciassem": "despenitenciar",
    "despenitenciasses": "despenitenciar",
    "despenitenciaste": "despenitenciar",
    "despenitenciastes": "despenitenciar",
    "despenitenciava": "despenitenciar",
    "despenitenciavam": "despenitenciar",
    "despenitenciavas": "despenitenciar",
    "despenitencie": "despenitenciar",
    "despenitenciei": "despenitenciar",
    "despenitencieis": "despenitenciar",
    "despenitenciem": "despenitenciar",
    "despenitenciemo": "despenitenciar",
    "despenitenciemos": "despenitenciar",
    "despenitencies": "despenitenciar",
    "despenitencio": "despenitenciar",
    "despenitenciou": "despenitenciar",
    "despenitenciá": "despenitenciar",
    "despenitenciámo": "despenitenciar",
    "despenitenciámos": "despenitenciar",
    "despenitenciáramo": "despenitenciar",
    "despenitenciáramos": "despenitenciar",
    "despenitenciárei": "despenitenciar",
    "despenitenciáreis": "despenitenciar",
    "despenitenciásseis": "despenitenciar",
    "despenitenciássemos": "despenitenciar",
    "despenitenciávamo": "despenitenciar",
    "despenitenciávamos": "despenitenciar",
    "despenitenciávei": "despenitenciar",
    "despenitenciáveis": "despenitenciar",
    "despeno": "despenar",
    "despenou": "despenar",
    "despenque": "despencar",
    "despenquei": "despencar",
    "despenqueis": "despencar",
    "despenquem": "despencar",
    "despenquemo": "despencar",
    "despenquemos": "despencar",
    "despenques": "despencar",
    "despensas": "despensa",
    "despenseira": "despenseiro",
    "despenseiras": "despenseiro",
    "despenseiros": "despenseiro",
    "despenteada": "despentear",
    "despenteadas": "despentear",
    "despenteado": "despentear",
    "despenteados": "despentear",
    "despenteai": "despentear",
    "despenteais": "despentear",
    "despenteamo": "despentear",
    "despenteamos": "despentear",
    "despenteando": "despentear",
    "despenteara": "despentear",
    "despentearam": "despentear",
    "despentearas": "despentear",
    "despentearde": "despentear",
    "despenteardes": "despentear",
    "despenteare": "despentear",
    "despentearei": "despentear",
    "despenteareis": "despentear",
    "despentearem": "despentear",
    "despentearemos": "despentear",
    "despenteares": "despentear",
    "despentearia": "despentear",
    "despenteariam": "despentear",
    "despentearias": "despentear",
    "despentearmo": "despentear",
    "despentearmos": "despentear",
    "despenteará": "despentear",
    "despentearás": "despentear",
    "despentearão": "despentear",
    "despentearíamos": "despentear",
    "despentearíeis": "despentear",
    "despenteasse": "despentear",
    "despenteassem": "despentear",
    "despenteasses": "despentear",
    "despenteaste": "despentear",
    "despenteastes": "despentear",
    "despenteava": "despentear",
    "despenteavam": "despentear",
    "despenteavas": "despentear",
    "despenteei": "despentear",
    "despenteeis": "despentear",
    "despenteemo": "despentear",
    "despenteemos": "despentear",
    "despenteia": "despentear",
    "despenteiam": "despentear",
    "despenteias": "despentear",
    "despenteie": "despentear",
    "despenteiem": "despentear",
    "despenteies": "despentear",
    "despenteio": "despentear",
    "despenteou": "despentear",
    "despenteá": "despentear",
    "despenteámo": "despentear",
    "despenteámos": "despentear",
    "despenteáramo": "despentear",
    "despenteáramos": "despentear",
    "despenteárei": "despentear",
    "despenteáreis": "despentear",
    "despenteásseis": "despentear",
    "despenteássemos": "despentear",
    "despenteávamo": "despentear",
    "despenteávamos": "despentear",
    "despenteávei": "despentear",
    "despenteáveis": "despentear",
    "despená": "despenar",
    "despenámo": "despenar",
    "despenámos": "despenar",
    "despenáramo": "despenar",
    "despenáramos": "despenar",
    "despenárei": "despenar",
    "despenáreis": "despenar",
    "despenásseis": "despenar",
    "despenássemos": "despenar",
    "despenávamo": "despenar",
    "despenávamos": "despenar",
    "despenávei": "despenar",
    "despenáveis": "despenar",
    "despeou": "despear",
    "desperceba": "desperceber",
    "despercebais": "desperceber",
    "despercebam": "desperceber",
    "despercebamo": "desperceber",
    "despercebamos": "desperceber",
    "despercebas": "desperceber",
    "despercebe": "desperceber",
    "despercebei": "desperceber",
    "despercebeis": "desperceber",
    "despercebem": "desperceber",
    "despercebemo": "desperceber",
    "despercebemos": "desperceber",
    "despercebendo": "desperceber",
    "despercebera": "desperceber",
    "desperceberam": "desperceber",
    "desperceberas": "desperceber",
    "desperceberde": "desperceber",
    "desperceberdes": "desperceber",
    "despercebere": "desperceber",
    "desperceberei": "desperceber",
    "despercebereis": "desperceber",
    "desperceberem": "desperceber",
    "desperceberemos": "desperceber",
    "desperceberes": "desperceber",
    "desperceberia": "desperceber",
    "desperceberiam": "desperceber",
    "desperceberias": "desperceber",
    "despercebermo": "desperceber",
    "despercebermos": "desperceber",
    "desperceberá": "desperceber",
    "desperceberás": "desperceber",
    "desperceberão": "desperceber",
    "desperceberíamos": "desperceber",
    "desperceberíeis": "desperceber",
    "despercebes": "desperceber",
    "despercebesse": "desperceber",
    "despercebessem": "desperceber",
    "despercebesses": "desperceber",
    "despercebeste": "desperceber",
    "despercebestes": "desperceber",
    "despercebeu": "desperceber",
    "despercebi": "desperceber",
    "despercebia": "desperceber",
    "despercebiam": "desperceber",
    "despercebias": "desperceber",
    "despercebida": "despercebido",
    "despercebidas": "despercebido",
    "despercebido": "desperceber",
    "despercebidos": "despercebido",
    "despercebimentos": "despercebimento",
    "despercebo": "desperceber",
    "despercebê": "desperceber",
    "despercebêramo": "desperceber",
    "despercebêramos": "desperceber",
    "despercebêrei": "desperceber",
    "despercebêreis": "desperceber",
    "despercebêsseis": "desperceber",
    "despercebêssemos": "desperceber",
    "despercebíamo": "desperceber",
    "despercebíamos": "desperceber",
    "despercebíei": "desperceber",
    "despercebíeis": "desperceber",
    "desperdice": "desperdiçar",
    "desperdicei": "desperdiçar",
    "desperdiceis": "desperdiçar",
    "desperdicem": "desperdiçar",
    "desperdicemo": "desperdiçar",
    "desperdicemos": "desperdiçar",
    "desperdices": "desperdiçar",
    "desperdiça": "desperdiçar",
    "desperdiçada": "desperdiçar",
    "desperdiçadas": "desperdiçar",
    "desperdiçado": "desperdiçar",
    "desperdiçadora": "desperdiçador",
    "desperdiçadoras": "desperdiçador",
    "desperdiçadores": "desperdiçador",
    "desperdiçados": "desperdiçar",
    "desperdiçai": "desperdiçar",
    "desperdiçais": "desperdiçar",
    "desperdiçam": "desperdiçar",
    "desperdiçamentos": "desperdiçamento",
    "desperdiçamo": "desperdiçar",
    "desperdiçamos": "desperdiçar",
    "desperdiçando": "desperdiçar",
    "desperdiçara": "desperdiçar",
    "desperdiçaram": "desperdiçar",
    "desperdiçaras": "desperdiçar",
    "desperdiçarde": "desperdiçar",
    "desperdiçardes": "desperdiçar",
    "desperdiçare": "desperdiçar",
    "desperdiçarei": "desperdiçar",
    "desperdiçareis": "desperdiçar",
    "desperdiçarem": "desperdiçar",
    "desperdiçaremos": "desperdiçar",
    "desperdiçares": "desperdiçar",
    "desperdiçaria": "desperdiçar",
    "desperdiçariam": "desperdiçar",
    "desperdiçarias": "desperdiçar",
    "desperdiçarmo": "desperdiçar",
    "desperdiçarmos": "desperdiçar",
    "desperdiçará": "desperdiçar",
    "desperdiçarás": "desperdiçar",
    "desperdiçarão": "desperdiçar",
    "desperdiçaríamos": "desperdiçar",
    "desperdiçaríeis": "desperdiçar",
    "desperdiças": "desperdiçar",
    "desperdiçasse": "desperdiçar",
    "desperdiçassem": "desperdiçar",
    "desperdiçasses": "desperdiçar",
    "desperdiçaste": "desperdiçar",
    "desperdiçastes": "desperdiçar",
    "desperdiçava": "desperdiçar",
    "desperdiçavam": "desperdiçar",
    "desperdiçavas": "desperdiçar",
    "desperdiço": "desperdiçar",
    "desperdiçou": "desperdiçar",
    "desperdiçá": "desperdiçar",
    "desperdiçámo": "desperdiçar",
    "desperdiçámos": "desperdiçar",
    "desperdiçáramo": "desperdiçar",
    "desperdiçáramos": "desperdiçar",
    "desperdiçárei": "desperdiçar",
    "desperdiçáreis": "desperdiçar",
    "desperdiçásseis": "desperdiçar",
    "desperdiçássemos": "desperdiçar",
    "desperdiçávamo": "desperdiçar",
    "desperdiçávamos": "desperdiçar",
    "desperdiçávei": "desperdiçar",
    "desperdiçáveis": "desperdiçar",
    "desperdícios": "desperdício",
    "desperece": "desperecer",
    "desperecei": "desperecer",
    "despereceis": "desperecer",
    "desperecem": "desperecer",
    "desperecemo": "desperecer",
    "desperecemos": "desperecer",
    "desperecendo": "desperecer",
    "desperecera": "desperecer",
    "despereceram": "desperecer",
    "despereceras": "desperecer",
    "desperecerdes": "desperecer",
    "desperecerei": "desperecer",
    "desperecereis": "desperecer",
    "desperecerem": "desperecer",
    "despereceremos": "desperecer",
    "despereceres": "desperecer",
    "despereceria": "desperecer",
    "despereceriam": "desperecer",
    "desperecerias": "desperecer",
    "desperecermo": "desperecer",
    "desperecermos": "desperecer",
    "desperecerá": "desperecer",
    "desperecerás": "desperecer",
    "desperecerão": "desperecer",
    "despereceríamos": "desperecer",
    "despereceríeis": "desperecer",
    "despereces": "desperecer",
    "desperecesse": "desperecer",
    "desperecessem": "desperecer",
    "desperecesses": "desperecer",
    "despereceste": "desperecer",
    "desperecestes": "desperecer",
    "despereceu": "desperecer",
    "despereci": "desperecer",
    "desperecia": "desperecer",
    "despereciam": "desperecer",
    "desperecias": "desperecer",
    "desperecida": "desperecido",
    "desperecidas": "desperecido",
    "desperecido": "desperecer",
    "desperecidos": "desperecido",
    "desperecêramo": "desperecer",
    "desperecêramos": "desperecer",
    "desperecêreis": "desperecer",
    "desperecêsseis": "desperecer",
    "desperecêssemos": "desperecer",
    "desperecíamo": "desperecer",
    "desperecíamos": "desperecer",
    "desperecíeis": "desperecer",
    "despereça": "desperecer",
    "despereçais": "desperecer",
    "despereçam": "desperecer",
    "despereçamo": "desperecer",
    "despereçamos": "desperecer",
    "despereças": "desperecer",
    "despereço": "desperecer",
    "desperfila": "desperfilar",
    "desperfilada": "desperfilar",
    "desperfiladas": "desperfilar",
    "desperfilado": "desperfilar",
    "desperfilados": "desperfilar",
    "desperfilai": "desperfilar",
    "desperfilais": "desperfilar",
    "desperfilam": "desperfilar",
    "desperfilamentos": "desperfilamento",
    "desperfilamo": "desperfilar",
    "desperfilamos": "desperfilar",
    "desperfilando": "desperfilar",
    "desperfilara": "desperfilar",
    "desperfilaram": "desperfilar",
    "desperfilaras": "desperfilar",
    "desperfilarde": "desperfilar",
    "desperfilardes": "desperfilar",
    "desperfilare": "desperfilar",
    "desperfilarei": "desperfilar",
    "desperfilareis": "desperfilar",
    "desperfilarem": "desperfilar",
    "desperfilaremos": "desperfilar",
    "desperfilares": "desperfilar",
    "desperfilaria": "desperfilar",
    "desperfilariam": "desperfilar",
    "desperfilarias": "desperfilar",
    "desperfilarmo": "desperfilar",
    "desperfilarmos": "desperfilar",
    "desperfilará": "desperfilar",
    "desperfilarás": "desperfilar",
    "desperfilarão": "desperfilar",
    "desperfilaríamos": "desperfilar",
    "desperfilaríeis": "desperfilar",
    "desperfilas": "desperfilar",
    "desperfilasse": "desperfilar",
    "desperfilassem": "desperfilar",
    "desperfilasses": "desperfilar",
    "desperfilaste": "desperfilar",
    "desperfilastes": "desperfilar",
    "desperfilava": "desperfilar",
    "desperfilavam": "desperfilar",
    "desperfilavas": "desperfilar",
    "desperfile": "desperfilar",
    "desperfilei": "desperfilar",
    "desperfileis": "desperfilar",
    "desperfilem": "desperfilar",
    "desperfilemo": "desperfilar",
    "desperfilemos": "desperfilar",
    "desperfiles": "desperfilar",
    "desperfilo": "desperfilar",
    "desperfilou": "desperfilar",
    "desperfilá": "desperfilar",
    "desperfilámo": "desperfilar",
    "desperfilámos": "desperfilar",
    "desperfiláramo": "desperfilar",
    "desperfiláramos": "desperfilar",
    "desperfilárei": "desperfilar",
    "desperfiláreis": "desperfilar",
    "desperfilásseis": "desperfilar",
    "desperfilássemos": "desperfilar",
    "desperfilávamo": "desperfilar",
    "desperfilávamos": "desperfilar",
    "desperfilávei": "desperfilar",
    "desperfiláveis": "desperfilar",
    "despersonaliza": "despersonalizar",
    "despersonalizada": "despersonalizar",
    "despersonalizadas": "despersonalizar",
    "despersonalizado": "despersonalizar",
    "despersonalizados": "despersonalizar",
    "despersonalizai": "despersonalizar",
    "despersonalizais": "despersonalizar",
    "despersonalizam": "despersonalizar",
    "despersonalizamo": "despersonalizar",
    "despersonalizamos": "despersonalizar",
    "despersonalizando": "despersonalizar",
    "despersonalizara": "despersonalizar",
    "despersonalizaram": "despersonalizar",
    "despersonalizaras": "despersonalizar",
    "despersonalizarde": "despersonalizar",
    "despersonalizardes": "despersonalizar",
    "despersonalizare": "despersonalizar",
    "despersonalizarei": "despersonalizar",
    "despersonalizareis": "despersonalizar",
    "despersonalizarem": "despersonalizar",
    "despersonalizaremos": "despersonalizar",
    "despersonalizares": "despersonalizar",
    "despersonalizaria": "despersonalizar",
    "despersonalizariam": "despersonalizar",
    "despersonalizarias": "despersonalizar",
    "despersonalizarmo": "despersonalizar",
    "despersonalizarmos": "despersonalizar",
    "despersonalizará": "despersonalizar",
    "despersonalizarás": "despersonalizar",
    "despersonalizarão": "despersonalizar",
    "despersonalizaríamos": "despersonalizar",
    "despersonalizaríeis": "despersonalizar",
    "despersonalizas": "despersonalizar",
    "despersonalizasse": "despersonalizar",
    "despersonalizassem": "despersonalizar",
    "despersonalizasses": "despersonalizar",
    "despersonalizaste": "despersonalizar",
    "despersonalizastes": "despersonalizar",
    "despersonalizava": "despersonalizar",
    "despersonalizavam": "despersonalizar",
    "despersonalizavas": "despersonalizar",
    "despersonalizações": "despersonalização",
    "despersonalize": "despersonalizar",
    "despersonalizei": "despersonalizar",
    "despersonalizeis": "despersonalizar",
    "despersonalizem": "despersonalizar",
    "despersonalizemo": "despersonalizar",
    "despersonalizemos": "despersonalizar",
    "despersonalizes": "despersonalizar",
    "despersonalizo": "despersonalizar",
    "despersonalizou": "despersonalizar",
    "despersonalizá": "despersonalizar",
    "despersonalizámo": "despersonalizar",
    "despersonalizámos": "despersonalizar",
    "despersonalizáramo": "despersonalizar",
    "despersonalizáramos": "despersonalizar",
    "despersonalizárei": "despersonalizar",
    "despersonalizáreis": "despersonalizar",
    "despersonalizásseis": "despersonalizar",
    "despersonalizássemos": "despersonalizar",
    "despersonalizávamo": "despersonalizar",
    "despersonalizávamos": "despersonalizar",
    "despersonalizávei": "despersonalizar",
    "despersonalizáveis": "despersonalizar",
    "despersuada": "despersuadir",
    "despersuadais": "despersuadir",
    "despersuadam": "despersuadir",
    "despersuadamo": "despersuadir",
    "despersuadamos": "despersuadir",
    "despersuadas": "despersuadir",
    "despersuade": "despersuadir",
    "despersuadem": "despersuadir",
    "despersuades": "despersuadir",
    "despersuadi": "despersuadir",
    "despersuadia": "despersuadir",
    "despersuadiam": "despersuadir",
    "despersuadias": "despersuadir",
    "despersuadida": "despersuadir",
    "despersuadidas": "despersuadir",
    "despersuadido": "despersuadir",
    "despersuadidos": "despersuadir",
    "despersuadimo": "despersuadir",
    "despersuadimos": "despersuadir",
    "despersuadindo": "despersuadir",
    "despersuadira": "despersuadir",
    "despersuadiram": "despersuadir",
    "despersuadiras": "despersuadir",
    "despersuadirde": "despersuadir",
    "despersuadirdes": "despersuadir",
    "despersuadire": "despersuadir",
    "despersuadirei": "despersuadir",
    "despersuadireis": "despersuadir",
    "despersuadirem": "despersuadir",
    "despersuadiremos": "despersuadir",
    "despersuadires": "despersuadir",
    "despersuadiria": "despersuadir",
    "despersuadiriam": "despersuadir",
    "despersuadirias": "despersuadir",
    "despersuadirmo": "despersuadir",
    "despersuadirmos": "despersuadir",
    "despersuadirá": "despersuadir",
    "despersuadirás": "despersuadir",
    "despersuadirão": "despersuadir",
    "despersuadiríamos": "despersuadir",
    "despersuadiríeis": "despersuadir",
    "despersuadis": "despersuadir",
    "despersuadisse": "despersuadir",
    "despersuadissem": "despersuadir",
    "despersuadisses": "despersuadir",
    "despersuadiste": "despersuadir",
    "despersuadistes": "despersuadir",
    "despersuadiu": "despersuadir",
    "despersuado": "despersuadir",
    "despersuadíamo": "despersuadir",
    "despersuadíamos": "despersuadir",
    "despersuadíei": "despersuadir",
    "despersuadíeis": "despersuadir",
    "despersuadíramo": "despersuadir",
    "despersuadíramos": "despersuadir",
    "despersuadírei": "despersuadir",
    "despersuadíreis": "despersuadir",
    "despersuadísseis": "despersuadir",
    "despersuadíssemos": "despersuadir",
    "despersuações": "despersuação",
    "desperta": "desperto",
    "despertada": "despertar",
    "despertadas": "despertar",
    "despertado": "despertar",
    "despertadora": "despertador",
    "despertadoras": "despertador",
    "despertadores": "despertador",
    "despertados": "despertar",
    "despertai": "despertar",
    "despertais": "despertar",
    "despertam": "despertar",
    "despertamo": "despertar",
    "despertamos": "despertar",
    "despertando": "despertar",
    "despertara": "despertar",
    "despertaram": "despertar",
    "despertaras": "despertar",
    "despertarde": "despertar",
    "despertardes": "despertar",
    "despertare": "despertar",
    "despertarei": "despertar",
    "despertareis": "despertar",
    "despertarem": "despertar",
    "despertaremos": "despertar",
    "despertares": "despertar",
    "despertaria": "despertar",
    "despertariam": "despertar",
    "despertarias": "despertar",
    "despertarmo": "despertar",
    "despertarmos": "despertar",
    "despertará": "despertar",
    "despertarás": "despertar",
    "despertarão": "despertar",
    "despertaríamos": "despertar",
    "despertaríeis": "despertar",
    "despertas": "desperto",
    "despertasse": "despertar",
    "despertassem": "despertar",
    "despertasses": "despertar",
    "despertaste": "despertar",
    "despertastes": "despertar",
    "despertativa": "despertativo",
    "despertativas": "despertativo",
    "despertativos": "despertativo",
    "despertava": "despertar",
    "despertavam": "despertar",
    "despertavas": "despertar",
    "desperte": "despertar",
    "despertei": "despertar",
    "desperteis": "despertar",
    "despertem": "despertar",
    "despertemo": "despertar",
    "despertemos": "despertar",
    "despertes": "despertar",
    "desperto": "despertar",
    "despertos": "desperto",
    "despertou": "despertar",
    "despertá": "despertar",
    "despertámo": "despertar",
    "despertámos": "despertar",
    "despertáramo": "despertar",
    "despertáramos": "despertar",
    "despertárei": "despertar",
    "despertáreis": "despertar",
    "despertásseis": "despertar",
    "despertássemos": "despertar",
    "despertávamo": "despertar",
    "despertávamos": "despertar",
    "despertávei": "despertar",
    "despertáveis": "despertável",
    "despes": "despir",
    "despesas": "despesa",
    "despesismos": "despesismo",
    "despesões": "despesão",
    "despetala": "despetalar",
    "despetalada": "despetalar",
    "despetaladas": "despetalar",
    "despetalado": "despetalar",
    "despetalados": "despetalar",
    "despetalai": "despetalar",
    "despetalais": "despetalar",
    "despetalam": "despetalar",
    "despetalamo": "despetalar",
    "despetalamos": "despetalar",
    "despetalando": "despetalar",
    "despetalara": "despetalar",
    "despetalaram": "despetalar",
    "despetalaras": "despetalar",
    "despetalarde": "despetalar",
    "despetalardes": "despetalar",
    "despetalare": "despetalar",
    "despetalarei": "despetalar",
    "despetalareis": "despetalar",
    "despetalarem": "despetalar",
    "despetalaremos": "despetalar",
    "despetalares": "despetalar",
    "despetalaria": "despetalar",
    "despetalariam": "despetalar",
    "despetalarias": "despetalar",
    "despetalarmo": "despetalar",
    "despetalarmos": "despetalar",
    "despetalará": "despetalar",
    "despetalarás": "despetalar",
    "despetalarão": "despetalar",
    "despetalaríamos": "despetalar",
    "despetalaríeis": "despetalar",
    "despetalas": "despetalar",
    "despetalasse": "despetalar",
    "despetalassem": "despetalar",
    "despetalasses": "despetalar",
    "despetalaste": "despetalar",
    "despetalastes": "despetalar",
    "despetalava": "despetalar",
    "despetalavam": "despetalar",
    "despetalavas": "despetalar",
    "despetale": "despetalar",
    "despetaleada": "despetalear",
    "despetaleadas": "despetalear",
    "despetaleado": "despetalear",
    "despetaleados": "despetalear",
    "despetaleai": "despetalear",
    "despetaleais": "despetalear",
    "despetaleamo": "despetalear",
    "despetaleamos": "despetalear",
    "despetaleando": "despetalear",
    "despetaleara": "despetalear",
    "despetalearam": "despetalear",
    "despetalearas": "despetalear",
    "despetalearde": "despetalear",
    "despetaleardes": "despetalear",
    "despetaleare": "despetalear",
    "despetalearei": "despetalear",
    "despetaleareis": "despetalear",
    "despetalearem": "despetalear",
    "despetalearemos": "despetalear",
    "despetaleares": "despetalear",
    "despetalearia": "despetalear",
    "despetaleariam": "despetalear",
    "despetalearias": "despetalear",
    "despetalearmo": "despetalear",
    "despetalearmos": "despetalear",
    "despetaleará": "despetalear",
    "despetalearás": "despetalear",
    "despetalearão": "despetalear",
    "despetalearíamos": "despetalear",
    "despetalearíeis": "despetalear",
    "despetaleasse": "despetalear",
    "despetaleassem": "despetalear",
    "despetaleasses": "despetalear",
    "despetaleaste": "despetalear",
    "despetaleastes": "despetalear",
    "despetaleava": "despetalear",
    "despetaleavam": "despetalear",
    "despetaleavas": "despetalear",
    "despetaleei": "despetalear",
    "despetaleeis": "despetalear",
    "despetaleemo": "despetalear",
    "despetaleemos": "despetalear",
    "despetalei": "despetalar",
    "despetaleia": "despetalear",
    "despetaleiam": "despetalear",
    "despetaleias": "despetalear",
    "despetaleie": "despetalear",
    "despetaleiem": "despetalear",
    "despetaleies": "despetalear",
    "despetaleio": "despetalear",
    "despetaleis": "despetalar",
    "despetalem": "despetalar",
    "despetalemo": "despetalar",
    "despetalemos": "despetalar",
    "despetaleou": "despetalear",
    "despetales": "despetalar",
    "despetaleá": "despetalear",
    "despetaleámo": "despetalear",
    "despetaleámos": "despetalear",
    "despetaleáramo": "despetalear",
    "despetaleáramos": "despetalear",
    "despetaleárei": "despetalear",
    "despetaleáreis": "despetalear",
    "despetaleásseis": "despetalear",
    "despetaleássemos": "despetalear",
    "despetaleávamo": "despetalear",
    "despetaleávamos": "despetalear",
    "despetaleávei": "despetalear",
    "despetaleáveis": "despetalear",
    "despetalo": "despetalar",
    "despetalou": "despetalar",
    "despetalá": "despetalar",
    "despetalámo": "despetalar",
    "despetalámos": "despetalar",
    "despetaláramo": "despetalar",
    "despetaláramos": "despetalar",
    "despetalárei": "despetalar",
    "despetaláreis": "despetalar",
    "despetalásseis": "despetalar",
    "despetalássemos": "despetalar",
    "despetalávamo": "despetalar",
    "despetalávamos": "despetalar",
    "despetalávei": "despetalar",
    "despetaláveis": "despetalar",
    "despeá": "despear",
    "despeámo": "despear",
    "despeámos": "despear",
    "despeáramo": "despear",
    "despeáramos": "despear",
    "despeárei": "despear",
    "despeáreis": "despear",
    "despeásseis": "despear",
    "despeássemos": "despear",
    "despeávamo": "despear",
    "despeávamos": "despear",
    "despeávei": "despear",
    "despeáveis": "despear",
    "despeça": "despedir",
    "despeçais": "despedir",
    "despeçam": "despedir",
    "despeçamo": "despedir",
    "despeçamos": "despedir",
    "despeças": "despedir",
    "despeço": "despedir",
    "despi": "despir",
    "despia": "despir",
    "despiam": "despir",
    "despias": "despir",
    "despica": "despicar",
    "despicada": "despicar",
    "despicadas": "despicar",
    "despicado": "despicar",
    "despicadora": "despicador",
    "despicadoras": "despicador",
    "despicadores": "despicador",
    "despicados": "despicar",
    "despicai": "despicar",
    "despicais": "despicar",
    "despicam": "despicar",
    "despicamo": "despicar",
    "despicamos": "despicar",
    "despicando": "despicar",
    "despicara": "despicar",
    "despicaram": "despicar",
    "despicaras": "despicar",
    "despicarde": "despicar",
    "despicardes": "despicar",
    "despicare": "despicar",
    "despicarei": "despicar",
    "despicareis": "despicar",
    "despicarem": "despicar",
    "despicaremos": "despicar",
    "despicares": "despicar",
    "despicaria": "despicar",
    "despicariam": "despicar",
    "despicarias": "despicar",
    "despicarmo": "despicar",
    "despicarmos": "despicar",
    "despicará": "despicar",
    "despicarás": "despicar",
    "despicarão": "despicar",
    "despicaríamos": "despicar",
    "despicaríeis": "despicar",
    "despicas": "despicar",
    "despicasse": "despicar",
    "despicassem": "despicar",
    "despicasses": "despicar",
    "despicaste": "despicar",
    "despicastes": "despicar",
    "despicava": "despicar",
    "despicavam": "despicar",
    "despicavas": "despicar",
    "despicienda": "despiciendo",
    "despiciendas": "despiciendo",
    "despiciendos": "despiciendo",
    "despicientes": "despiciente",
    "despico": "despicar",
    "despicou": "despicar",
    "despicá": "despicar",
    "despicámo": "despicar",
    "despicámos": "despicar",
    "despicáramo": "despicar",
    "despicáramos": "despicar",
    "despicárei": "despicar",
    "despicáreis": "despicar",
    "despicásseis": "despicar",
    "despicássemos": "despicar",
    "despicávamo": "despicar",
    "despicávamos": "despicar",
    "despicávei": "despicar",
    "despicáveis": "despicar",
    "despida": "despir",
    "despidas": "despir",
    "despido": "despir",
    "despidos": "despir",
    "despieda": "despiedar",
    "despiedada": "despiedar",
    "despiedadas": "despiedar",
    "despiedades": "despiedade",
    "despiedado": "despiedar",
    "despiedados": "despiedar",
    "despiedai": "despiedar",
    "despiedais": "despiedar",
    "despiedam": "despiedar",
    "despiedamo": "despiedar",
    "despiedamos": "despiedar",
    "despiedando": "despiedar",
    "despiedara": "despiedar",
    "despiedaram": "despiedar",
    "despiedaras": "despiedar",
    "despiedarde": "despiedar",
    "despiedardes": "despiedar",
    "despiedare": "despiedar",
    "despiedarei": "despiedar",
    "despiedareis": "despiedar",
    "despiedarem": "despiedar",
    "despiedaremos": "despiedar",
    "despiedares": "despiedar",
    "despiedaria": "despiedar",
    "despiedariam": "despiedar",
    "despiedarias": "despiedar",
    "despiedarmo": "despiedar",
    "despiedarmos": "despiedar",
    "despiedará": "despiedar",
    "despiedarás": "despiedar",
    "despiedarão": "despiedar",
    "despiedaríamos": "despiedar",
    "despiedaríeis": "despiedar",
    "despiedas": "despiedar",
    "despiedasse": "despiedar",
    "despiedassem": "despiedar",
    "despiedasses": "despiedar",
    "despiedaste": "despiedar",
    "despiedastes": "despiedar",
    "despiedava": "despiedar",
    "despiedavam": "despiedar",
    "despiedavas": "despiedar",
    "despiede": "despiedar",
    "despiedei": "despiedar",
    "despiedeis": "despiedar",
    "despiedem": "despiedar",
    "despiedemo": "despiedar",
    "despiedemos": "despiedar",
    "despiedes": "despiedar",
    "despiedo": "despiedar",
    "despiedosa": "despiedoso",
    "despiedosas": "despiedoso",
    "despiedosos": "despiedoso",
    "despiedou": "despiedar",
    "despiedá": "despiedar",
    "despiedámo": "despiedar",
    "despiedámos": "despiedar",
    "despiedáramo": "despiedar",
    "despiedáramos": "despiedar",
    "despiedárei": "despiedar",
    "despiedáreis": "despiedar",
    "despiedásseis": "despiedar",
    "despiedássemos": "despiedar",
    "despiedávamo": "despiedar",
    "despiedávamos": "despiedar",
    "despiedávei": "despiedar",
    "despiedáveis": "despiedar",
    "despigmenta": "despigmentar",
    "despigmentada": "despigmentar",
    "despigmentadas": "despigmentar",
    "despigmentado": "despigmentar",
    "despigmentados": "despigmentar",
    "despigmentai": "despigmentar",
    "despigmentais": "despigmentar",
    "despigmentam": "despigmentar",
    "despigmentamo": "despigmentar",
    "despigmentamos": "despigmentar",
    "despigmentando": "despigmentar",
    "despigmentara": "despigmentar",
    "despigmentaram": "despigmentar",
    "despigmentaras": "despigmentar",
    "despigmentarde": "despigmentar",
    "despigmentardes": "despigmentar",
    "despigmentare": "despigmentar",
    "despigmentarei": "despigmentar",
    "despigmentareis": "despigmentar",
    "despigmentarem": "despigmentar",
    "despigmentaremos": "despigmentar",
    "despigmentares": "despigmentar",
    "despigmentaria": "despigmentar",
    "despigmentariam": "despigmentar",
    "despigmentarias": "despigmentar",
    "despigmentarmo": "despigmentar",
    "despigmentarmos": "despigmentar",
    "despigmentará": "despigmentar",
    "despigmentarás": "despigmentar",
    "despigmentarão": "despigmentar",
    "despigmentaríamos": "despigmentar",
    "despigmentaríeis": "despigmentar",
    "despigmentas": "despigmentar",
    "despigmentasse": "despigmentar",
    "despigmentassem": "despigmentar",
    "despigmentasses": "despigmentar",
    "despigmentaste": "despigmentar",
    "despigmentastes": "despigmentar",
    "despigmentava": "despigmentar",
    "despigmentavam": "despigmentar",
    "despigmentavas": "despigmentar",
    "despigmentações": "despigmentação",
    "despigmente": "despigmentar",
    "despigmentei": "despigmentar",
    "despigmenteis": "despigmentar",
    "despigmentem": "despigmentar",
    "despigmentemo": "despigmentar",
    "despigmentemos": "despigmentar",
    "despigmentes": "despigmentar",
    "despigmento": "despigmentar",
    "despigmentou": "despigmentar",
    "despigmentá": "despigmentar",
    "despigmentámo": "despigmentar",
    "despigmentámos": "despigmentar",
    "despigmentáramo": "despigmentar",
    "despigmentáramos": "despigmentar",
    "despigmentárei": "despigmentar",
    "despigmentáreis": "despigmentar",
    "despigmentásseis": "despigmentar",
    "despigmentássemos": "despigmentar",
    "despigmentávamo": "despigmentar",
    "despigmentávamos": "despigmentar",
    "despigmentávei": "despigmentar",
    "despigmentáveis": "despigmentar",
    "despimentos": "despimento",
    "despimo": "despir",
    "despimos": "despir",
    "despindo": "despir",
    "despinta": "despintar",
    "despintada": "despintar",
    "despintadas": "despintar",
    "despintado": "despintar",
    "despintados": "despintar",
    "despintai": "despintar",
    "despintais": "despintar",
    "despintam": "despintar",
    "despintamo": "despintar",
    "despintamos": "despintar",
    "despintando": "despintar",
    "despintara": "despintar",
    "despintaram": "despintar",
    "despintaras": "despintar",
    "despintarde": "despintar",
    "despintardes": "despintar",
    "despintare": "despintar",
    "despintarei": "despintar",
    "despintareis": "despintar",
    "despintarem": "despintar",
    "despintaremos": "despintar",
    "despintares": "despintar",
    "despintaria": "despintar",
    "despintariam": "despintar",
    "despintarias": "despintar",
    "despintarmo": "despintar",
    "despintarmos": "despintar",
    "despintará": "despintar",
    "despintarás": "despintar",
    "despintarão": "despintar",
    "despintaríamos": "despintar",
    "despintaríeis": "despintar",
    "despintas": "despintar",
    "despintasse": "despintar",
    "despintassem": "despintar",
    "despintasses": "despintar",
    "despintaste": "despintar",
    "despintastes": "despintar",
    "despintava": "despintar",
    "despintavam": "despintar",
    "despintavas": "despintar",
    "despinte": "despintar",
    "despintei": "despintar",
    "despinteis": "despintar",
    "despintem": "despintar",
    "despintemo": "despintar",
    "despintemos": "despintar",
    "despintes": "despintar",
    "despinto": "despintar",
    "despintou": "despintar",
    "despintá": "despintar",
    "despintámo": "despintar",
    "despintámos": "despintar",
    "despintáramo": "despintar",
    "despintáramos": "despintar",
    "despintárei": "despintar",
    "despintáreis": "despintar",
    "despintásseis": "despintar",
    "despintássemos": "despintar",
    "despintávamo": "despintar",
    "despintávamos": "despintar",
    "despintávei": "despintar",
    "despintáveis": "despintar",
    "despinçada": "despinçado",
    "despinçadas": "despinçado",
    "despinçados": "despinçado",
    "despiolha": "despiolhar",
    "despiolhada": "despiolhar",
    "despiolhadas": "despiolhar",
    "despiolhado": "despiolhar",
    "despiolhados": "despiolhar",
    "despiolhai": "despiolhar",
    "despiolhais": "despiolhar",
    "despiolham": "despiolhar",
    "despiolhamentos": "despiolhamento",
    "despiolhamo": "despiolhar",
    "despiolhamos": "despiolhar",
    "despiolhando": "despiolhar",
    "despiolhara": "despiolhar",
    "despiolharam": "despiolhar",
    "despiolharas": "despiolhar",
    "despiolharde": "despiolhar",
    "despiolhardes": "despiolhar",
    "despiolhare": "despiolhar",
    "despiolharei": "despiolhar",
    "despiolhareis": "despiolhar",
    "despiolharem": "despiolhar",
    "despiolharemos": "despiolhar",
    "despiolhares": "despiolhar",
    "despiolharia": "despiolhar",
    "despiolhariam": "despiolhar",
    "despiolharias": "despiolhar",
    "despiolharmo": "despiolhar",
    "despiolharmos": "despiolhar",
    "despiolhará": "despiolhar",
    "despiolharás": "despiolhar",
    "despiolharão": "despiolhar",
    "despiolharíamos": "despiolhar",
    "despiolharíeis": "despiolhar",
    "despiolhas": "despiolhar",
    "despiolhasse": "despiolhar",
    "despiolhassem": "despiolhar",
    "despiolhasses": "despiolhar",
    "despiolhaste": "despiolhar",
    "despiolhastes": "despiolhar",
    "despiolhava": "despiolhar",
    "despiolhavam": "despiolhar",
    "despiolhavas": "despiolhar",
    "despiolhações": "despiolhação",
    "despiolhe": "despiolhar",
    "despiolhei": "despiolhar",
    "despiolheis": "despiolhar",
    "despiolhem": "despiolhar",
    "despiolhemo": "despiolhar",
    "despiolhemos": "despiolhar",
    "despiolhes": "despiolhar",
    "despiolho": "despiolhar",
    "despiolhou": "despiolhar",
    "despiolhá": "despiolhar",
    "despiolhámo": "despiolhar",
    "despiolhámos": "despiolhar",
    "despiolháramo": "despiolhar",
    "despiolháramos": "despiolhar",
    "despiolhárei": "despiolhar",
    "despiolháreis": "despiolhar",
    "despiolhásseis": "despiolhar",
    "despiolhássemos": "despiolhar",
    "despiolhávamo": "despiolhar",
    "despiolhávamos": "despiolhar",
    "despiolhávei": "despiolhar",
    "despiolháveis": "despiolhar",
    "despique": "despicar",
    "despiquei": "despicar",
    "despiqueis": "despicar",
    "despiquem": "despicar",
    "despiquemo": "despicar",
    "despiquemos": "despicar",
    "despiques": "despique",
    "despira": "despir",
    "despiram": "despir",
    "despiras": "despir",
    "despirde": "despir",
    "despirdes": "despir",
    "despire": "despir",
    "despirei": "despir",
    "despireis": "despir",
    "despirem": "despir",
    "despiremos": "despir",
    "despires": "despir",
    "despiria": "despir",
    "despiriam": "despir",
    "despirias": "despir",
    "despirmo": "despir",
    "despirmos": "despir",
    "despirá": "despir",
    "despirás": "despir",
    "despirão": "despir",
    "despiríamos": "despir",
    "despiríeis": "despir",
    "despis": "despir",
    "despisse": "despir",
    "despissem": "despir",
    "despisses": "despir",
    "despista": "despistar",
    "despistada": "despistar",
    "despistadas": "despistar",
    "despistado": "despistar",
    "despistados": "despistar",
    "despistadíssima": "despistado",
    "despistadíssimas": "despistado",
    "despistadíssimo": "despistado",
    "despistadíssimos": "despistado",
    "despistagens": "despistagem",
    "despistai": "despistar",
    "despistais": "despistar",
    "despistam": "despistar",
    "despistamentos": "despistamento",
    "despistamo": "despistar",
    "despistamos": "despistar",
    "despistando": "despistar",
    "despistara": "despistar",
    "despistaram": "despistar",
    "despistaras": "despistar",
    "despistarde": "despistar",
    "despistardes": "despistar",
    "despistare": "despistar",
    "despistarei": "despistar",
    "despistareis": "despistar",
    "despistarem": "despistar",
    "despistaremos": "despistar",
    "despistares": "despistar",
    "despistaria": "despistar",
    "despistariam": "despistar",
    "despistarias": "despistar",
    "despistarmo": "despistar",
    "despistarmos": "despistar",
    "despistará": "despistar",
    "despistarás": "despistar",
    "despistarão": "despistar",
    "despistaríamos": "despistar",
    "despistaríeis": "despistar",
    "despistas": "despistar",
    "despistasse": "despistar",
    "despistassem": "despistar",
    "despistasses": "despistar",
    "despistaste": "despistar",
    "despistastes": "despistar",
    "despistava": "despistar",
    "despistavam": "despistar",
    "despistavas": "despistar",
    "despiste": "despistar",
    "despistei": "despistar",
    "despisteis": "despistar",
    "despistem": "despistar",
    "despistemo": "despistar",
    "despistemos": "despistar",
    "despistes": "despistar",
    "despisto": "despistar",
    "despistou": "despistar",
    "despistá": "despistar",
    "despistámo": "despistar",
    "despistámos": "despistar",
    "despistáramo": "despistar",
    "despistáramos": "despistar",
    "despistárei": "despistar",
    "despistáreis": "despistar",
    "despistásseis": "despistar",
    "despistássemos": "despistar",
    "despistávamo": "despistar",
    "despistávamos": "despistar",
    "despistávei": "despistar",
    "despistáveis": "despistável",
    "despiu": "despir",
    "desplanta": "desplantar",
    "desplantada": "desplantar",
    "desplantadas": "desplantar",
    "desplantado": "desplantar",
    "desplantados": "desplantar",
    "desplantai": "desplantar",
    "desplantais": "desplantar",
    "desplantam": "desplantar",
    "desplantamo": "desplantar",
    "desplantamos": "desplantar",
    "desplantando": "desplantar",
    "desplantara": "desplantar",
    "desplantaram": "desplantar",
    "desplantaras": "desplantar",
    "desplantarde": "desplantar",
    "desplantardes": "desplantar",
    "desplantare": "desplantar",
    "desplantarei": "desplantar",
    "desplantareis": "desplantar",
    "desplantarem": "desplantar",
    "desplantaremos": "desplantar",
    "desplantares": "desplantar",
    "desplantaria": "desplantar",
    "desplantariam": "desplantar",
    "desplantarias": "desplantar",
    "desplantarmo": "desplantar",
    "desplantarmos": "desplantar",
    "desplantará": "desplantar",
    "desplantarás": "desplantar",
    "desplantarão": "desplantar",
    "desplantaríamos": "desplantar",
    "desplantaríeis": "desplantar",
    "desplantas": "desplantar",
    "desplantasse": "desplantar",
    "desplantassem": "desplantar",
    "desplantasses": "desplantar",
    "desplantaste": "desplantar",
    "desplantastes": "desplantar",
    "desplantava": "desplantar",
    "desplantavam": "desplantar",
    "desplantavas": "desplantar",
    "desplante": "desplantar",
    "desplantei": "desplantar",
    "desplanteis": "desplantar",
    "desplantem": "desplantar",
    "desplantemo": "desplantar",
    "desplantemos": "desplantar",
    "desplantes": "desplante",
    "desplanto": "desplantar",
    "desplantou": "desplantar",
    "desplantá": "desplantar",
    "desplantámo": "desplantar",
    "desplantámos": "desplantar",
    "desplantáramo": "desplantar",
    "desplantáramos": "desplantar",
    "desplantárei": "desplantar",
    "desplantáreis": "desplantar",
    "desplantásseis": "desplantar",
    "desplantássemos": "desplantar",
    "desplantávamo": "desplantar",
    "desplantávamos": "desplantar",
    "desplantávei": "desplantar",
    "desplantáveis": "desplantar",
    "despluma": "desplumar",
    "desplumada": "desplumar",
    "desplumadas": "desplumar",
    "desplumado": "desplumar",
    "desplumados": "desplumar",
    "desplumai": "desplumar",
    "desplumais": "desplumar",
    "desplumam": "desplumar",
    "desplumamo": "desplumar",
    "desplumamos": "desplumar",
    "desplumando": "desplumar",
    "desplumara": "desplumar",
    "desplumaram": "desplumar",
    "desplumaras": "desplumar",
    "desplumarde": "desplumar",
    "desplumardes": "desplumar",
    "desplumare": "desplumar",
    "desplumarei": "desplumar",
    "desplumareis": "desplumar",
    "desplumarem": "desplumar",
    "desplumaremos": "desplumar",
    "desplumares": "desplumar",
    "desplumaria": "desplumar",
    "desplumariam": "desplumar",
    "desplumarias": "desplumar",
    "desplumarmo": "desplumar",
    "desplumarmos": "desplumar",
    "desplumará": "desplumar",
    "desplumarás": "desplumar",
    "desplumarão": "desplumar",
    "desplumaríamos": "desplumar",
    "desplumaríeis": "desplumar",
    "desplumas": "desplumar",
    "desplumasse": "desplumar",
    "desplumassem": "desplumar",
    "desplumasses": "desplumar",
    "desplumaste": "desplumar",
    "desplumastes": "desplumar",
    "desplumava": "desplumar",
    "desplumavam": "desplumar",
    "desplumavas": "desplumar",
    "desplume": "desplumar",
    "desplumei": "desplumar",
    "desplumeis": "desplumar",
    "desplumem": "desplumar",
    "desplumemo": "desplumar",
    "desplumemos": "desplumar",
    "desplumes": "desplumar",
    "desplumo": "desplumar",
    "desplumou": "desplumar",
    "desplumá": "desplumar",
    "desplumámo": "desplumar",
    "desplumámos": "desplumar",
    "desplumáramo": "desplumar",
    "desplumáramos": "desplumar",
    "desplumárei": "desplumar",
    "desplumáreis": "desplumar",
    "desplumásseis": "desplumar",
    "desplumássemos": "desplumar",
    "desplumávamo": "desplumar",
    "desplumávamos": "desplumar",
    "desplumávei": "desplumar",
    "desplumáveis": "desplumar",
    "despoetiza": "despoetizar",
    "despoetizada": "despoetizar",
    "despoetizadas": "despoetizar",
    "despoetizado": "despoetizar",
    "despoetizadora": "despoetizador",
    "despoetizadoras": "despoetizador",
    "despoetizadores": "despoetizador",
    "despoetizados": "despoetizar",
    "despoetizai": "despoetizar",
    "despoetizais": "despoetizar",
    "despoetizam": "despoetizar",
    "despoetizamo": "despoetizar",
    "despoetizamos": "despoetizar",
    "despoetizando": "despoetizar",
    "despoetizara": "despoetizar",
    "despoetizaram": "despoetizar",
    "despoetizaras": "despoetizar",
    "despoetizarde": "despoetizar",
    "despoetizardes": "despoetizar",
    "despoetizare": "despoetizar",
    "despoetizarei": "despoetizar",
    "despoetizareis": "despoetizar",
    "despoetizarem": "despoetizar",
    "despoetizaremos": "despoetizar",
    "despoetizares": "despoetizar",
    "despoetizaria": "despoetizar",
    "despoetizariam": "despoetizar",
    "despoetizarias": "despoetizar",
    "despoetizarmo": "despoetizar",
    "despoetizarmos": "despoetizar",
    "despoetizará": "despoetizar",
    "despoetizarás": "despoetizar",
    "despoetizarão": "despoetizar",
    "despoetizaríamos": "despoetizar",
    "despoetizaríeis": "despoetizar",
    "despoetizas": "despoetizar",
    "despoetizasse": "despoetizar",
    "despoetizassem": "despoetizar",
    "despoetizasses": "despoetizar",
    "despoetizaste": "despoetizar",
    "despoetizastes": "despoetizar",
    "despoetizava": "despoetizar",
    "despoetizavam": "despoetizar",
    "despoetizavas": "despoetizar",
    "despoetizações": "despoetização",
    "despoetize": "despoetizar",
    "despoetizei": "despoetizar",
    "despoetizeis": "despoetizar",
    "despoetizem": "despoetizar",
    "despoetizemo": "despoetizar",
    "despoetizemos": "despoetizar",
    "despoetizes": "despoetizar",
    "despoetizo": "despoetizar",
    "despoetizou": "despoetizar",
    "despoetizá": "despoetizar",
    "despoetizámo": "despoetizar",
    "despoetizámos": "despoetizar",
    "despoetizáramo": "despoetizar",
    "despoetizáramos": "despoetizar",
    "despoetizárei": "despoetizar",
    "despoetizáreis": "despoetizar",
    "despoetizásseis": "despoetizar",
    "despoetizássemos": "despoetizar",
    "despoetizávamo": "despoetizar",
    "despoetizávamos": "despoetizar",
    "despoetizávei": "despoetizar",
    "despoetizáveis": "despoetizar",
    "despoja": "despojar",
    "despojada": "despojar",
    "despojadas": "despojar",
    "despojado": "despojar",
    "despojadora": "despojador",
    "despojadoras": "despojador",
    "despojadores": "despojador",
    "despojados": "despojar",
    "despojai": "despojar",
    "despojais": "despojar",
    "despojam": "despojar",
    "despojamentos": "despojamento",
    "despojamo": "despojar",
    "despojamos": "despojar",
    "despojando": "despojar",
    "despojara": "despojar",
    "despojaram": "despojar",
    "despojaras": "despojar",
    "despojarde": "despojar",
    "despojardes": "despojar",
    "despojare": "despojar",
    "despojarei": "despojar",
    "despojareis": "despojar",
    "despojarem": "despojar",
    "despojaremos": "despojar",
    "despojares": "despojar",
    "despojaria": "despojar",
    "despojariam": "despojar",
    "despojarias": "despojar",
    "despojarmo": "despojar",
    "despojarmos": "despojar",
    "despojará": "despojar",
    "despojarás": "despojar",
    "despojarão": "despojar",
    "despojaríamos": "despojar",
    "despojaríeis": "despojar",
    "despojas": "despojar",
    "despojasse": "despojar",
    "despojassem": "despojar",
    "despojasses": "despojar",
    "despojaste": "despojar",
    "despojastes": "despojar",
    "despojava": "despojar",
    "despojavam": "despojar",
    "despojavas": "despojar",
    "despoje": "despojar",
    "despojei": "despojar",
    "despojeis": "despojar",
    "despojem": "despojar",
    "despojemo": "despojar",
    "despojemos": "despojar",
    "despojes": "despojar",
    "despojo": "despojar",
    "despojos": "despojo",
    "despojou": "despojar",
    "despojá": "despojar",
    "despojámo": "despojar",
    "despojámos": "despojar",
    "despojáramo": "despojar",
    "despojáramos": "despojar",
    "despojárei": "despojar",
    "despojáreis": "despojar",
    "despojásseis": "despojar",
    "despojássemos": "despojar",
    "despojávamo": "despojar",
    "despojávamos": "despojar",
    "despojávei": "despojar",
    "despojáveis": "despojável",
    "despolariza": "despolarizar",
    "despolarizada": "despolarizar",
    "despolarizadas": "despolarizar",
    "despolarizado": "despolarizar",
    "despolarizadores": "despolarizador",
    "despolarizados": "despolarizar",
    "despolarizai": "despolarizar",
    "despolarizais": "despolarizar",
    "despolarizam": "despolarizar",
    "despolarizamo": "despolarizar",
    "despolarizamos": "despolarizar",
    "despolarizando": "despolarizar",
    "despolarizantes": "despolarizante",
    "despolarizara": "despolarizar",
    "despolarizaram": "despolarizar",
    "despolarizaras": "despolarizar",
    "despolarizarde": "despolarizar",
    "despolarizardes": "despolarizar",
    "despolarizare": "despolarizar",
    "despolarizarei": "despolarizar",
    "despolarizareis": "despolarizar",
    "despolarizarem": "despolarizar",
    "despolarizaremos": "despolarizar",
    "despolarizares": "despolarizar",
    "despolarizaria": "despolarizar",
    "despolarizariam": "despolarizar",
    "despolarizarias": "despolarizar",
    "despolarizarmo": "despolarizar",
    "despolarizarmos": "despolarizar",
    "despolarizará": "despolarizar",
    "despolarizarás": "despolarizar",
    "despolarizarão": "despolarizar",
    "despolarizaríamos": "despolarizar",
    "despolarizaríeis": "despolarizar",
    "despolarizas": "despolarizar",
    "despolarizasse": "despolarizar",
    "despolarizassem": "despolarizar",
    "despolarizasses": "despolarizar",
    "despolarizaste": "despolarizar",
    "despolarizastes": "despolarizar",
    "despolarizava": "despolarizar",
    "despolarizavam": "despolarizar",
    "despolarizavas": "despolarizar",
    "despolarizações": "despolarização",
    "despolarize": "despolarizar",
    "despolarizei": "despolarizar",
    "despolarizeis": "despolarizar",
    "despolarizem": "despolarizar",
    "despolarizemo": "despolarizar",
    "despolarizemos": "despolarizar",
    "despolarizes": "despolarizar",
    "despolarizo": "despolarizar",
    "despolarizou": "despolarizar",
    "despolarizá": "despolarizar",
    "despolarizámo": "despolarizar",
    "despolarizámos": "despolarizar",
    "despolarizáramo": "despolarizar",
    "despolarizáramos": "despolarizar",
    "despolarizárei": "despolarizar",
    "despolarizáreis": "despolarizar",
    "despolarizásseis": "despolarizar",
    "despolarizássemos": "despolarizar",
    "despolarizávamo": "despolarizar",
    "despolarizávamos": "despolarizar",
    "despolarizávei": "despolarizar",
    "despolarizáveis": "despolarizar",
    "despoleta": "despoletar",
    "despoletada": "despoletar",
    "despoletadas": "despoletar",
    "despoletado": "despoletar",
    "despoletados": "despoletar",
    "despoletai": "despoletar",
    "despoletais": "despoletar",
    "despoletam": "despoletar",
    "despoletamo": "despoletar",
    "despoletamos": "despoletar",
    "despoletando": "despoletar",
    "despoletara": "despoletar",
    "despoletaram": "despoletar",
    "despoletaras": "despoletar",
    "despoletarde": "despoletar",
    "despoletardes": "despoletar",
    "despoletare": "despoletar",
    "despoletarei": "despoletar",
    "despoletareis": "despoletar",
    "despoletarem": "despoletar",
    "despoletaremos": "despoletar",
    "despoletares": "despoletar",
    "despoletaria": "despoletar",
    "despoletariam": "despoletar",
    "despoletarias": "despoletar",
    "despoletarmo": "despoletar",
    "despoletarmos": "despoletar",
    "despoletará": "despoletar",
    "despoletarás": "despoletar",
    "despoletarão": "despoletar",
    "despoletaríamos": "despoletar",
    "despoletaríeis": "despoletar",
    "despoletas": "despoletar",
    "despoletasse": "despoletar",
    "despoletassem": "despoletar",
    "despoletasses": "despoletar",
    "despoletaste": "despoletar",
    "despoletastes": "despoletar",
    "despoletava": "despoletar",
    "despoletavam": "despoletar",
    "despoletavas": "despoletar",
    "despolete": "despoletar",
    "despoletei": "despoletar",
    "despoleteis": "despoletar",
    "despoletem": "despoletar",
    "despoletemo": "despoletar",
    "despoletemos": "despoletar",
    "despoletes": "despoletar",
    "despoleto": "despoletar",
    "despoletou": "despoletar",
    "despoletá": "despoletar",
    "despoletámo": "despoletar",
    "despoletámos": "despoletar",
    "despoletáramo": "despoletar",
    "despoletáramos": "despoletar",
    "despoletárei": "despoletar",
    "despoletáreis": "despoletar",
    "despoletásseis": "despoletar",
    "despoletássemos": "despoletar",
    "despoletávamo": "despoletar",
    "despoletávamos": "despoletar",
    "despoletávei": "despoletar",
    "despoletáveis": "despoletar",
    "despoli": "despolir",
    "despolia": "despolir",
    "despoliam": "despolir",
    "despolias": "despolir",
    "despolida": "despolir",
    "despolidas": "despolir",
    "despolidezes": "despolidez",
    "despolido": "despolir",
    "despolidos": "despolir",
    "despolimentos": "despolimento",
    "despolimo": "despolir",
    "despolimos": "despolir",
    "despolindo": "despolir",
    "despolira": "despolir",
    "despoliram": "despolir",
    "despoliras": "despolir",
    "despolirde": "despolir",
    "despolirdes": "despolir",
    "despolire": "despolir",
    "despolirei": "despolir",
    "despolireis": "despolir",
    "despolirem": "despolir",
    "despoliremos": "despolir",
    "despolires": "despolir",
    "despoliria": "despolir",
    "despoliriam": "despolir",
    "despolirias": "despolir",
    "despolirmo": "despolir",
    "despolirmos": "despolir",
    "despolirá": "despolir",
    "despolirás": "despolir",
    "despolirão": "despolir",
    "despoliríamos": "despolir",
    "despoliríeis": "despolir",
    "despolis": "despolir",
    "despolisse": "despolir",
    "despolissem": "despolir",
    "despolisses": "despolir",
    "despoliste": "despolir",
    "despolistes": "despolir",
    "despolitizada": "despolitizado",
    "despolitizadas": "despolitizado",
    "despolitizados": "despolitizado",
    "despolitizações": "despolitização",
    "despoliu": "despolir",
    "despolpa": "despolpar",
    "despolpada": "despolpar",
    "despolpadas": "despolpar",
    "despolpado": "despolpar",
    "despolpadora": "despolpador",
    "despolpadoras": "despolpador",
    "despolpadores": "despolpador",
    "despolpados": "despolpar",
    "despolpai": "despolpar",
    "despolpais": "despolpar",
    "despolpam": "despolpar",
    "despolpamo": "despolpar",
    "despolpamos": "despolpar",
    "despolpando": "despolpar",
    "despolpara": "despolpar",
    "despolparam": "despolpar",
    "despolparas": "despolpar",
    "despolparde": "despolpar",
    "despolpardes": "despolpar",
    "despolpare": "despolpar",
    "despolparei": "despolpar",
    "despolpareis": "despolpar",
    "despolparem": "despolpar",
    "despolparemos": "despolpar",
    "despolpares": "despolpar",
    "despolparia": "despolpar",
    "despolpariam": "despolpar",
    "despolparias": "despolpar",
    "despolparmo": "despolpar",
    "despolparmos": "despolpar",
    "despolpará": "despolpar",
    "despolparás": "despolpar",
    "despolparão": "despolpar",
    "despolparíamos": "despolpar",
    "despolparíeis": "despolpar",
    "despolpas": "despolpar",
    "despolpasse": "despolpar",
    "despolpassem": "despolpar",
    "despolpasses": "despolpar",
    "despolpaste": "despolpar",
    "despolpastes": "despolpar",
    "despolpava": "despolpar",
    "despolpavam": "despolpar",
    "despolpavas": "despolpar",
    "despolpe": "despolpar",
    "despolpei": "despolpar",
    "despolpeis": "despolpar",
    "despolpem": "despolpar",
    "despolpemo": "despolpar",
    "despolpemos": "despolpar",
    "despolpes": "despolpar",
    "despolpo": "despolpar",
    "despolpou": "despolpar",
    "despolpá": "despolpar",
    "despolpámo": "despolpar",
    "despolpámos": "despolpar",
    "despolpáramo": "despolpar",
    "despolpáramos": "despolpar",
    "despolpárei": "despolpar",
    "despolpáreis": "despolpar",
    "despolpásseis": "despolpar",
    "despolpássemos": "despolpar",
    "despolpávamo": "despolpar",
    "despolpávamos": "despolpar",
    "despolpávei": "despolpar",
    "despolpáveis": "despolpar",
    "despolua": "despoluir",
    "despoluais": "despoluir",
    "despoluam": "despoluir",
    "despoluamo": "despoluir",
    "despoluamos": "despoluir",
    "despoluas": "despoluir",
    "despoluem": "despoluir",
    "despoluentes": "despoluente",
    "despolui": "despoluir",
    "despoluindo": "despoluir",
    "despoluirde": "despoluir",
    "despoluirdes": "despoluir",
    "despoluirei": "despoluir",
    "despoluireis": "despoluir",
    "despoluiremos": "despoluir",
    "despoluiria": "despoluir",
    "despoluiriam": "despoluir",
    "despoluirias": "despoluir",
    "despoluirmo": "despoluir",
    "despoluirmos": "despoluir",
    "despoluirá": "despoluir",
    "despoluirás": "despoluir",
    "despoluirão": "despoluir",
    "despoluiríamos": "despoluir",
    "despoluiríeis": "despoluir",
    "despoluis": "despoluir",
    "despoluiu": "despoluir",
    "despoluições": "despoluição",
    "despoluo": "despoluir",
    "despoluí": "despoluir",
    "despoluía": "despoluir",
    "despoluíam": "despoluir",
    "despoluíamo": "despoluir",
    "despoluíamos": "despoluir",
    "despoluías": "despoluir",
    "despoluída": "despoluir",
    "despoluídas": "despoluir",
    "despoluído": "despoluir",
    "despoluídos": "despoluir",
    "despoluíei": "despoluir",
    "despoluíeis": "despoluir",
    "despoluímo": "despoluir",
    "despoluímos": "despoluir",
    "despoluíra": "despoluir",
    "despoluíram": "despoluir",
    "despoluíramo": "despoluir",
    "despoluíramos": "despoluir",
    "despoluíras": "despoluir",
    "despoluíre": "despoluir",
    "despoluírei": "despoluir",
    "despoluíreis": "despoluir",
    "despoluírem": "despoluir",
    "despoluíres": "despoluir",
    "despoluís": "despoluir",
    "despoluísse": "despoluir",
    "despoluísseis": "despoluir",
    "despoluíssem": "despoluir",
    "despoluíssemos": "despoluir",
    "despoluísses": "despoluir",
    "despoluíste": "despoluir",
    "despoluístes": "despoluir",
    "despolíamo": "despolir",
    "despolíamos": "despolir",
    "despolíei": "despolir",
    "despolíeis": "despolir",
    "despolíramo": "despolir",
    "despolíramos": "despolir",
    "despolírei": "despolir",
    "despolíreis": "despolir",
    "despolísseis": "despolir",
    "despolíssemos": "despolir",
    "despomo": "despor",
    "despomos": "despor",
    "desponde": "despor",
    "desponderações": "desponderação",
    "despondes": "despor",
    "despondo": "despor",
    "desponha": "despor",
    "desponhais": "despor",
    "desponham": "despor",
    "desponhamo": "despor",
    "desponhamos": "despor",
    "desponhas": "despor",
    "desponho": "despor",
    "desponsórios": "desponsório",
    "desponta": "despontar",
    "despontada": "despontar",
    "despontadas": "despontar",
    "despontado": "despontar",
    "despontadora": "despontador",
    "despontadoras": "despontador",
    "despontadores": "despontador",
    "despontados": "despontar",
    "despontai": "despontar",
    "despontais": "despontar",
    "despontam": "despontar",
    "despontamo": "despontar",
    "despontamos": "despontar",
    "despontando": "despontar",
    "despontantes": "despontante",
    "despontara": "despontar",
    "despontaram": "despontar",
    "despontaras": "despontar",
    "despontarde": "despontar",
    "despontardes": "despontar",
    "despontare": "despontar",
    "despontarei": "despontar",
    "despontareis": "despontar",
    "despontarem": "despontar",
    "despontaremos": "despontar",
    "despontares": "despontar",
    "despontaria": "despontar",
    "despontariam": "despontar",
    "despontarias": "despontar",
    "despontarmo": "despontar",
    "despontarmos": "despontar",
    "despontará": "despontar",
    "despontarás": "despontar",
    "despontarão": "despontar",
    "despontaríamos": "despontar",
    "despontaríeis": "despontar",
    "despontas": "despontar",
    "despontasse": "despontar",
    "despontassem": "despontar",
    "despontasses": "despontar",
    "despontaste": "despontar",
    "despontastes": "despontar",
    "despontava": "despontar",
    "despontavam": "despontar",
    "despontavas": "despontar",
    "desponte": "despontar",
    "despontei": "despontar",
    "desponteis": "despontar",
    "despontem": "despontar",
    "despontemo": "despontar",
    "despontemos": "despontar",
    "despontes": "desponte",
    "desponto": "despontar",
    "despontou": "despontar",
    "despontua": "despontuar",
    "despontuada": "despontuar",
    "despontuadas": "despontuar",
    "despontuado": "despontuar",
    "despontuados": "despontuar",
    "despontuai": "despontuar",
    "despontuais": "despontuar",
    "despontuam": "despontuar",
    "despontuamo": "despontuar",
    "despontuamos": "despontuar",
    "despontuando": "despontuar",
    "despontuara": "despontuar",
    "despontuaram": "despontuar",
    "despontuaras": "despontuar",
    "despontuarde": "despontuar",
    "despontuardes": "despontuar",
    "despontuare": "despontuar",
    "despontuarei": "despontuar",
    "despontuareis": "despontuar",
    "despontuarem": "despontuar",
    "despontuaremos": "despontuar",
    "despontuares": "despontuar",
    "despontuaria": "despontuar",
    "despontuariam": "despontuar",
    "despontuarias": "despontuar",
    "despontuarmo": "despontuar",
    "despontuarmos": "despontuar",
    "despontuará": "despontuar",
    "despontuarás": "despontuar",
    "despontuarão": "despontuar",
    "despontuaríamos": "despontuar",
    "despontuaríeis": "despontuar",
    "despontuas": "despontuar",
    "despontuasse": "despontuar",
    "despontuassem": "despontuar",
    "despontuasses": "despontuar",
    "despontuaste": "despontuar",
    "despontuastes": "despontuar",
    "despontuava": "despontuar",
    "despontuavam": "despontuar",
    "despontuavas": "despontuar",
    "despontue": "despontuar",
    "despontuei": "despontuar",
    "despontueis": "despontuar",
    "despontuem": "despontuar",
    "despontuemo": "despontuar",
    "despontuemos": "despontuar",
    "despontues": "despontuar",
    "despontuo": "despontuar",
    "despontuou": "despontuar",
    "despontuá": "despontuar",
    "despontuámo": "despontuar",
    "despontuámos": "despontuar",
    "despontuáramo": "despontuar",
    "despontuáramos": "despontuar",
    "despontuárei": "despontuar",
    "despontuáreis": "despontuar",
    "despontuásseis": "despontuar",
    "despontuássemos": "despontuar",
    "despontuávamo": "despontuar",
    "despontuávamos": "despontuar",
    "despontuávei": "despontuar",
    "despontuáveis": "despontuar",
    "despontá": "despontar",
    "despontámo": "despontar",
    "despontámos": "despontar",
    "despontáramo": "despontar",
    "despontáramos": "despontar",
    "despontárei": "despontar",
    "despontáreis": "despontar",
    "despontásseis": "despontar",
    "despontássemos": "despontar",
    "despontávamo": "despontar",
    "despontávamos": "despontar",
    "despontávei": "despontar",
    "despontáveis": "despontar",
    "despopulariza": "despopularizar",
    "despopularizada": "despopularizar",
    "despopularizadas": "despopularizar",
    "despopularizado": "despopularizar",
    "despopularizados": "despopularizar",
    "despopularizai": "despopularizar",
    "despopularizais": "despopularizar",
    "despopularizam": "despopularizar",
    "despopularizamo": "despopularizar",
    "despopularizamos": "despopularizar",
    "despopularizando": "despopularizar",
    "despopularizara": "despopularizar",
    "despopularizaram": "despopularizar",
    "despopularizaras": "despopularizar",
    "despopularizarde": "despopularizar",
    "despopularizardes": "despopularizar",
    "despopularizare": "despopularizar",
    "despopularizarei": "despopularizar",
    "despopularizareis": "despopularizar",
    "despopularizarem": "despopularizar",
    "despopularizaremos": "despopularizar",
    "despopularizares": "despopularizar",
    "despopularizaria": "despopularizar",
    "despopularizariam": "despopularizar",
    "despopularizarias": "despopularizar",
    "despopularizarmo": "despopularizar",
    "despopularizarmos": "despopularizar",
    "despopularizará": "despopularizar",
    "despopularizarás": "despopularizar",
    "despopularizarão": "despopularizar",
    "despopularizaríamos": "despopularizar",
    "despopularizaríeis": "despopularizar",
    "despopularizas": "despopularizar",
    "despopularizasse": "despopularizar",
    "despopularizassem": "despopularizar",
    "despopularizasses": "despopularizar",
    "despopularizaste": "despopularizar",
    "despopularizastes": "despopularizar",
    "despopularizava": "despopularizar",
    "despopularizavam": "despopularizar",
    "despopularizavas": "despopularizar",
    "despopularizações": "despopularização",
    "despopularize": "despopularizar",
    "despopularizei": "despopularizar",
    "despopularizeis": "despopularizar",
    "despopularizem": "despopularizar",
    "despopularizemo": "despopularizar",
    "despopularizemos": "despopularizar",
    "despopularizes": "despopularizar",
    "despopularizo": "despopularizar",
    "despopularizou": "despopularizar",
    "despopularizá": "despopularizar",
    "despopularizámo": "despopularizar",
    "despopularizámos": "despopularizar",
    "despopularizáramo": "despopularizar",
    "despopularizáramos": "despopularizar",
    "despopularizárei": "despopularizar",
    "despopularizáreis": "despopularizar",
    "despopularizásseis": "despopularizar",
    "despopularizássemos": "despopularizar",
    "despopularizávamo": "despopularizar",
    "despopularizávamos": "despopularizar",
    "despopularizávei": "despopularizar",
    "despopularizáveis": "despopularizar",
    "desporde": "despor",
    "despordes": "despor",
    "despore": "despor",
    "desporei": "despor",
    "desporeis": "despor",
    "desporem": "despor",
    "desporemos": "despor",
    "despores": "despor",
    "desporia": "despor",
    "desporiam": "despor",
    "desporias": "despor",
    "despormo": "despor",
    "despormos": "despor",
    "desportilha": "desportilhar",
    "desportilhada": "desportilhar",
    "desportilhadas": "desportilhar",
    "desportilhado": "desportilhar",
    "desportilhados": "desportilhar",
    "desportilhai": "desportilhar",
    "desportilhais": "desportilhar",
    "desportilham": "desportilhar",
    "desportilhamo": "desportilhar",
    "desportilhamos": "desportilhar",
    "desportilhando": "desportilhar",
    "desportilhara": "desportilhar",
    "desportilharam": "desportilhar",
    "desportilharas": "desportilhar",
    "desportilharde": "desportilhar",
    "desportilhardes": "desportilhar",
    "desportilhare": "desportilhar",
    "desportilharei": "desportilhar",
    "desportilhareis": "desportilhar",
    "desportilharem": "desportilhar",
    "desportilharemos": "desportilhar",
    "desportilhares": "desportilhar",
    "desportilharia": "desportilhar",
    "desportilhariam": "desportilhar",
    "desportilharias": "desportilhar",
    "desportilharmo": "desportilhar",
    "desportilharmos": "desportilhar",
    "desportilhará": "desportilhar",
    "desportilharás": "desportilhar",
    "desportilharão": "desportilhar",
    "desportilharíamos": "desportilhar",
    "desportilharíeis": "desportilhar",
    "desportilhas": "desportilhar",
    "desportilhasse": "desportilhar",
    "desportilhassem": "desportilhar",
    "desportilhasses": "desportilhar",
    "desportilhaste": "desportilhar",
    "desportilhastes": "desportilhar",
    "desportilhava": "desportilhar",
    "desportilhavam": "desportilhar",
    "desportilhavas": "desportilhar",
    "desportilhe": "desportilhar",
    "desportilhei": "desportilhar",
    "desportilheis": "desportilhar",
    "desportilhem": "desportilhar",
    "desportilhemo": "desportilhar",
    "desportilhemos": "desportilhar",
    "desportilhes": "desportilhar",
    "desportilho": "desportilhar",
    "desportilhou": "desportilhar",
    "desportilhá": "desportilhar",
    "desportilhámo": "desportilhar",
    "desportilhámos": "desportilhar",
    "desportilháramo": "desportilhar",
    "desportilháramos": "desportilhar",
    "desportilhárei": "desportilhar",
    "desportilháreis": "desportilhar",
    "desportilhásseis": "desportilhar",
    "desportilhássemos": "desportilhar",
    "desportilhávamo": "desportilhar",
    "desportilhávamos": "desportilhar",
    "desportilhávei": "desportilhar",
    "desportilháveis": "desportilhar",
    "desportismos": "desportismo",
    "desportistas": "desportista",
    "desportiva": "desportivo",
    "desportivas": "desportivo",
    "desportivismos": "desportivismo",
    "desportivos": "desportivo",
    "desportos": "desporto",
    "desporá": "despor",
    "desporás": "despor",
    "desporão": "despor",
    "desporíamos": "despor",
    "desporíeis": "despor",
    "desposa": "desposar",
    "desposada": "desposar",
    "desposadas": "desposar",
    "desposado": "desposar",
    "desposados": "desposar",
    "desposai": "desposar",
    "desposais": "desposar",
    "desposam": "desposar",
    "desposamo": "desposar",
    "desposamos": "desposar",
    "desposando": "desposar",
    "desposara": "desposar",
    "desposaram": "desposar",
    "desposaras": "desposar",
    "desposarde": "desposar",
    "desposardes": "desposar",
    "desposare": "desposar",
    "desposarei": "desposar",
    "desposareis": "desposar",
    "desposarem": "desposar",
    "desposaremos": "desposar",
    "desposares": "desposar",
    "desposaria": "desposar",
    "desposariam": "desposar",
    "desposarias": "desposar",
    "desposarmo": "desposar",
    "desposarmos": "desposar",
    "desposará": "desposar",
    "desposarás": "desposar",
    "desposarão": "desposar",
    "desposaríamos": "desposar",
    "desposaríeis": "desposar",
    "desposas": "desposar",
    "desposasse": "desposar",
    "desposassem": "desposar",
    "desposasses": "desposar",
    "desposaste": "desposar",
    "desposastes": "desposar",
    "desposava": "desposar",
    "desposavam": "desposar",
    "desposavas": "desposar",
    "despose": "desposar",
    "desposei": "desposar",
    "desposeis": "desposar",
    "desposem": "desposar",
    "desposemo": "desposar",
    "desposemos": "desposar",
    "desposes": "desposar",
    "desposo": "desposar",
    "desposou": "desposar",
    "despossessões": "despossessão",
    "despossuída": "despossuído",
    "despossuídas": "despossuído",
    "despossuídos": "despossuído",
    "desposta": "desposto",
    "despostas": "desposto",
    "despostice": "despostiçar",
    "desposticei": "despostiçar",
    "desposticeis": "despostiçar",
    "desposticem": "despostiçar",
    "desposticemo": "despostiçar",
    "desposticemos": "despostiçar",
    "despostices": "despostiçar",
    "despostiça": "despostiçar",
    "despostiçada": "despostiçar",
    "despostiçadas": "despostiçar",
    "despostiçado": "despostiçar",
    "despostiçados": "despostiçar",
    "despostiçai": "despostiçar",
    "despostiçais": "despostiçar",
    "despostiçam": "despostiçar",
    "despostiçamo": "despostiçar",
    "despostiçamos": "despostiçar",
    "despostiçando": "despostiçar",
    "despostiçara": "despostiçar",
    "despostiçaram": "despostiçar",
    "despostiçaras": "despostiçar",
    "despostiçarde": "despostiçar",
    "despostiçardes": "despostiçar",
    "despostiçare": "despostiçar",
    "despostiçarei": "despostiçar",
    "despostiçareis": "despostiçar",
    "despostiçarem": "despostiçar",
    "despostiçaremos": "despostiçar",
    "despostiçares": "despostiçar",
    "despostiçaria": "despostiçar",
    "despostiçariam": "despostiçar",
    "despostiçarias": "despostiçar",
    "despostiçarmo": "despostiçar",
    "despostiçarmos": "despostiçar",
    "despostiçará": "despostiçar",
    "despostiçarás": "despostiçar",
    "despostiçarão": "despostiçar",
    "despostiçaríamos": "despostiçar",
    "despostiçaríeis": "despostiçar",
    "despostiças": "despostiçar",
    "despostiçasse": "despostiçar",
    "despostiçassem": "despostiçar",
    "despostiçasses": "despostiçar",
    "despostiçaste": "despostiçar",
    "despostiçastes": "despostiçar",
    "despostiçava": "despostiçar",
    "despostiçavam": "despostiçar",
    "despostiçavas": "despostiçar",
    "despostiço": "despostiçar",
    "despostiçou": "despostiçar",
    "despostiçá": "despostiçar",
    "despostiçámo": "despostiçar",
    "despostiçámos": "despostiçar",
    "despostiçáramo": "despostiçar",
    "despostiçáramos": "despostiçar",
    "despostiçárei": "despostiçar",
    "despostiçáreis": "despostiçar",
    "despostiçásseis": "despostiçar",
    "despostiçássemos": "despostiçar",
    "despostiçávamo": "despostiçar",
    "despostiçávamos": "despostiçar",
    "despostiçávei": "despostiçar",
    "despostiçáveis": "despostiçar",
    "desposto": "despor",
    "despostos": "desposto",
    "desposá": "desposar",
    "desposámo": "desposar",
    "desposámos": "desposar",
    "desposáramo": "desposar",
    "desposáramos": "desposar",
    "desposárei": "desposar",
    "desposáreis": "desposar",
    "desposásseis": "desposar",
    "desposássemos": "desposar",
    "desposávamo": "desposar",
    "desposávamos": "desposar",
    "desposávei": "desposar",
    "desposáveis": "desposar",
    "desposórios": "desposório",
    "despotismos": "despotismo",
    "despovoa": "despovoar",
    "despovoada": "despovoar",
    "despovoadas": "despovoar",
    "despovoado": "despovoar",
    "despovoadora": "despovoador",
    "despovoadoras": "despovoador",
    "despovoadores": "despovoador",
    "despovoados": "despovoar",
    "despovoai": "despovoar",
    "despovoais": "despovoar",
    "despovoam": "despovoar",
    "despovoamentos": "despovoamento",
    "despovoamo": "despovoar",
    "despovoamos": "despovoar",
    "despovoando": "despovoar",
    "despovoara": "despovoar",
    "despovoaram": "despovoar",
    "despovoaras": "despovoar",
    "despovoarde": "despovoar",
    "despovoardes": "despovoar",
    "despovoare": "despovoar",
    "despovoarei": "despovoar",
    "despovoareis": "despovoar",
    "despovoarem": "despovoar",
    "despovoaremos": "despovoar",
    "despovoares": "despovoar",
    "despovoaria": "despovoar",
    "despovoariam": "despovoar",
    "despovoarias": "despovoar",
    "despovoarmo": "despovoar",
    "despovoarmos": "despovoar",
    "despovoará": "despovoar",
    "despovoarás": "despovoar",
    "despovoarão": "despovoar",
    "despovoaríamos": "despovoar",
    "despovoaríeis": "despovoar",
    "despovoas": "despovoar",
    "despovoasse": "despovoar",
    "despovoassem": "despovoar",
    "despovoasses": "despovoar",
    "despovoaste": "despovoar",
    "despovoastes": "despovoar",
    "despovoava": "despovoar",
    "despovoavam": "despovoar",
    "despovoavas": "despovoar",
    "despovoações": "despovoação",
    "despovoe": "despovoar",
    "despovoei": "despovoar",
    "despovoeis": "despovoar",
    "despovoem": "despovoar",
    "despovoemo": "despovoar",
    "despovoemos": "despovoar",
    "despovoes": "despovoar",
    "despovoo": "despovoar",
    "despovoou": "despovoar",
    "despovoá": "despovoar",
    "despovoámo": "despovoar",
    "despovoámos": "despovoar",
    "despovoáramo": "despovoar",
    "despovoáramos": "despovoar",
    "despovoárei": "despovoar",
    "despovoáreis": "despovoar",
    "despovoásseis": "despovoar",
    "despovoássemos": "despovoar",
    "despovoávamo": "despovoar",
    "despovoávamos": "despovoar",
    "despovoávei": "despovoar",
    "despovoáveis": "despovoável",
    "despoética": "despoético",
    "despoéticas": "despoético",
    "despoéticos": "despoético",
    "desprateada": "despratear",
    "desprateadas": "despratear",
    "desprateado": "despratear",
    "desprateados": "despratear",
    "desprateai": "despratear",
    "desprateais": "despratear",
    "desprateamo": "despratear",
    "desprateamos": "despratear",
    "desprateando": "despratear",
    "desprateara": "despratear",
    "despratearam": "despratear",
    "despratearas": "despratear",
    "despratearde": "despratear",
    "desprateardes": "despratear",
    "desprateare": "despratear",
    "despratearei": "despratear",
    "desprateareis": "despratear",
    "despratearem": "despratear",
    "despratearemos": "despratear",
    "desprateares": "despratear",
    "despratearia": "despratear",
    "desprateariam": "despratear",
    "despratearias": "despratear",
    "despratearmo": "despratear",
    "despratearmos": "despratear",
    "desprateará": "despratear",
    "despratearás": "despratear",
    "despratearão": "despratear",
    "despratearíamos": "despratear",
    "despratearíeis": "despratear",
    "desprateasse": "despratear",
    "desprateassem": "despratear",
    "desprateasses": "despratear",
    "desprateaste": "despratear",
    "desprateastes": "despratear",
    "desprateava": "despratear",
    "desprateavam": "despratear",
    "desprateavas": "despratear",
    "desprateei": "despratear",
    "desprateeis": "despratear",
    "desprateemo": "despratear",
    "desprateemos": "despratear",
    "desprateia": "despratear",
    "desprateiam": "despratear",
    "desprateias": "despratear",
    "desprateie": "despratear",
    "desprateiem": "despratear",
    "desprateies": "despratear",
    "desprateio": "despratear",
    "desprateou": "despratear",
    "desprateá": "despratear",
    "desprateámo": "despratear",
    "desprateámos": "despratear",
    "desprateáramo": "despratear",
    "desprateáramos": "despratear",
    "desprateárei": "despratear",
    "desprateáreis": "despratear",
    "desprateásseis": "despratear",
    "desprateássemos": "despratear",
    "desprateávamo": "despratear",
    "desprateávamos": "despratear",
    "desprateávei": "despratear",
    "desprateáveis": "despratear",
    "despraz": "desprazer",
    "despraza": "desprazer",
    "desprazam": "desprazer",
    "desprazem": "desprazer",
    "desprazendo": "desprazer",
    "desprazerem": "desprazer",
    "desprazeres": "desprazer",
    "desprazeria": "desprazer",
    "desprazeriam": "desprazer",
    "desprazerá": "desprazer",
    "desprazerão": "desprazer",
    "desprazia": "desprazer",
    "despraziam": "desprazer",
    "desprazida": "desprazer",
    "desprazidas": "desprazer",
    "desprazido": "desprazer",
    "desprazidos": "desprazer",
    "desprazimentos": "desprazimento",
    "desprazíveis": "desprazível",
    "desprecata": "desprecatar",
    "desprecatada": "desprecatar",
    "desprecatadas": "desprecatar",
    "desprecatado": "desprecatar",
    "desprecatados": "desprecatar",
    "desprecatai": "desprecatar",
    "desprecatais": "desprecatar",
    "desprecatam": "desprecatar",
    "desprecatamo": "desprecatar",
    "desprecatamos": "desprecatar",
    "desprecatando": "desprecatar",
    "desprecatara": "desprecatar",
    "desprecataram": "desprecatar",
    "desprecataras": "desprecatar",
    "desprecatarde": "desprecatar",
    "desprecatardes": "desprecatar",
    "desprecatare": "desprecatar",
    "desprecatarei": "desprecatar",
    "desprecatareis": "desprecatar",
    "desprecatarem": "desprecatar",
    "desprecataremos": "desprecatar",
    "desprecatares": "desprecatar",
    "desprecataria": "desprecatar",
    "desprecatariam": "desprecatar",
    "desprecatarias": "desprecatar",
    "desprecatarmo": "desprecatar",
    "desprecatarmos": "desprecatar",
    "desprecatará": "desprecatar",
    "desprecatarás": "desprecatar",
    "desprecatarão": "desprecatar",
    "desprecataríamos": "desprecatar",
    "desprecataríeis": "desprecatar",
    "desprecatas": "desprecatar",
    "desprecatasse": "desprecatar",
    "desprecatassem": "desprecatar",
    "desprecatasses": "desprecatar",
    "desprecataste": "desprecatar",
    "desprecatastes": "desprecatar",
    "desprecatava": "desprecatar",
    "desprecatavam": "desprecatar",
    "desprecatavas": "desprecatar",
    "desprecate": "desprecatar",
    "desprecatei": "desprecatar",
    "desprecateis": "desprecatar",
    "desprecatem": "desprecatar",
    "desprecatemo": "desprecatar",
    "desprecatemos": "desprecatar",
    "desprecates": "desprecatar",
    "desprecato": "desprecatar",
    "desprecatou": "desprecatar",
    "desprecatá": "desprecatar",
    "desprecatámo": "desprecatar",
    "desprecatámos": "desprecatar",
    "desprecatáramo": "desprecatar",
    "desprecatáramos": "desprecatar",
    "desprecatárei": "desprecatar",
    "desprecatáreis": "desprecatar",
    "desprecatásseis": "desprecatar",
    "desprecatássemos": "desprecatar",
    "desprecatávamo": "desprecatar",
    "desprecatávamos": "desprecatar",
    "desprecatávei": "desprecatar",
    "desprecatáveis": "desprecatar",
    "desprecauções": "desprecaução",
    "desprecava": "desprecaver",
    "desprecavais": "desprecaver",
    "desprecavam": "desprecaver",
    "desprecavamo": "desprecaver",
    "desprecavamos": "desprecaver",
    "desprecavas": "desprecaver",
    "desprecave": "desprecaver",
    "desprecavei": "desprecaver",
    "desprecaveis": "desprecaver",
    "desprecavem": "desprecaver",
    "desprecavemo": "desprecaver",
    "desprecavemos": "desprecaver",
    "desprecavendo": "desprecaver",
    "desprecavera": "desprecaver",
    "desprecaveram": "desprecaver",
    "desprecaveras": "desprecaver",
    "desprecaverde": "desprecaver",
    "desprecaverdes": "desprecaver",
    "desprecavere": "desprecaver",
    "desprecaverei": "desprecaver",
    "desprecavereis": "desprecaver",
    "desprecaverem": "desprecaver",
    "desprecaveremos": "desprecaver",
    "desprecaveres": "desprecaver",
    "desprecaveria": "desprecaver",
    "desprecaveriam": "desprecaver",
    "desprecaverias": "desprecaver",
    "desprecavermo": "desprecaver",
    "desprecavermos": "desprecaver",
    "desprecaverá": "desprecaver",
    "desprecaverás": "desprecaver",
    "desprecaverão": "desprecaver",
    "desprecaveríamos": "desprecaver",
    "desprecaveríeis": "desprecaver",
    "desprecaves": "desprecaver",
    "desprecavesse": "desprecaver",
    "desprecavessem": "desprecaver",
    "desprecavesses": "desprecaver",
    "desprecaveste": "desprecaver",
    "desprecavestes": "desprecaver",
    "desprecaveu": "desprecaver",
    "desprecavi": "desprecaver",
    "desprecavia": "desprecaver",
    "desprecaviam": "desprecaver",
    "desprecavias": "desprecaver",
    "desprecavida": "desprecavido",
    "desprecavidas": "desprecavido",
    "desprecavido": "desprecaver",
    "desprecavidos": "desprecavido",
    "desprecavo": "desprecaver",
    "desprecavê": "desprecaver",
    "desprecavêramo": "desprecaver",
    "desprecavêramos": "desprecaver",
    "desprecavêrei": "desprecaver",
    "desprecavêreis": "desprecaver",
    "desprecavêsseis": "desprecaver",
    "desprecavêssemos": "desprecaver",
    "desprecavíamo": "desprecaver",
    "desprecavíamos": "desprecaver",
    "desprecavíei": "desprecaver",
    "desprecavíeis": "desprecaver",
    "despreconceitos": "despreconceito",
    "desprega": "despregar",
    "despregada": "despregar",
    "despregadas": "despregar",
    "despregado": "despregar",
    "despregados": "despregar",
    "despregaduras": "despregadura",
    "despregai": "despregar",
    "despregais": "despregar",
    "despregam": "despregar",
    "despregamo": "despregar",
    "despregamos": "despregar",
    "despregando": "despregar",
    "despregara": "despregar",
    "despregaram": "despregar",
    "despregaras": "despregar",
    "despregarde": "despregar",
    "despregardes": "despregar",
    "despregare": "despregar",
    "despregarei": "despregar",
    "despregareis": "despregar",
    "despregarem": "despregar",
    "despregaremos": "despregar",
    "despregares": "despregar",
    "despregaria": "despregar",
    "despregariam": "despregar",
    "despregarias": "despregar",
    "despregarmo": "despregar",
    "despregarmos": "despregar",
    "despregará": "despregar",
    "despregarás": "despregar",
    "despregarão": "despregar",
    "despregaríamos": "despregar",
    "despregaríeis": "despregar",
    "despregas": "despregar",
    "despregasse": "despregar",
    "despregassem": "despregar",
    "despregasses": "despregar",
    "despregaste": "despregar",
    "despregastes": "despregar",
    "despregava": "despregar",
    "despregavam": "despregar",
    "despregavas": "despregar",
    "desprego": "despregar",
    "despregou": "despregar",
    "despregue": "despregar",
    "despreguei": "despregar",
    "despregueis": "despregar",
    "despreguem": "despregar",
    "despreguemo": "despregar",
    "despreguemos": "despregar",
    "despregues": "despregar",
    "despregá": "despregar",
    "despregámo": "despregar",
    "despregámos": "despregar",
    "despregáramo": "despregar",
    "despregáramos": "despregar",
    "despregárei": "despregar",
    "despregáreis": "despregar",
    "despregásseis": "despregar",
    "despregássemos": "despregar",
    "despregávamo": "despregar",
    "despregávamos": "despregar",
    "despregávei": "despregar",
    "despregáveis": "despregar",
    "despremeia": "despremiar",
    "despremeiam": "despremiar",
    "despremeias": "despremiar",
    "despremeie": "despremiar",
    "despremeiem": "despremiar",
    "despremeies": "despremiar",
    "despremeio": "despremiar",
    "despremiada": "despremiar",
    "despremiadas": "despremiar",
    "despremiado": "despremiar",
    "despremiados": "despremiar",
    "despremiai": "despremiar",
    "despremiais": "despremiar",
    "despremiamo": "despremiar",
    "despremiamos": "despremiar",
    "despremiando": "despremiar",
    "despremiara": "despremiar",
    "despremiaram": "despremiar",
    "despremiaras": "despremiar",
    "despremiarde": "despremiar",
    "despremiardes": "despremiar",
    "despremiare": "despremiar",
    "despremiarei": "despremiar",
    "despremiareis": "despremiar",
    "despremiarem": "despremiar",
    "despremiaremos": "despremiar",
    "despremiares": "despremiar",
    "despremiaria": "despremiar",
    "despremiariam": "despremiar",
    "despremiarias": "despremiar",
    "despremiarmo": "despremiar",
    "despremiarmos": "despremiar",
    "despremiará": "despremiar",
    "despremiarás": "despremiar",
    "despremiarão": "despremiar",
    "despremiaríamos": "despremiar",
    "despremiaríeis": "despremiar",
    "despremiasse": "despremiar",
    "despremiassem": "despremiar",
    "despremiasses": "despremiar",
    "despremiaste": "despremiar",
    "despremiastes": "despremiar",
    "despremiava": "despremiar",
    "despremiavam": "despremiar",
    "despremiavas": "despremiar",
    "despremiei": "despremiar",
    "despremieis": "despremiar",
    "despremiemo": "despremiar",
    "despremiemos": "despremiar",
    "despremiou": "despremiar",
    "despremiá": "despremiar",
    "despremiámo": "despremiar",
    "despremiámos": "despremiar",
    "despremiáramo": "despremiar",
    "despremiáramos": "despremiar",
    "despremiárei": "despremiar",
    "despremiáreis": "despremiar",
    "despremiásseis": "despremiar",
    "despremiássemos": "despremiar",
    "despremiávamo": "despremiar",
    "despremiávamos": "despremiar",
    "despremiávei": "despremiar",
    "despremiáveis": "despremiar",
    "desprenda": "desprender",
    "desprendada": "desprendado",
    "desprendadas": "desprendado",
    "desprendados": "desprendado",
    "desprendais": "desprender",
    "desprendam": "desprender",
    "desprendamo": "desprender",
    "desprendamos": "desprender",
    "desprendas": "desprender",
    "desprende": "desprender",
    "desprendei": "desprender",
    "desprendeis": "desprender",
    "desprendem": "desprender",
    "desprendemo": "desprender",
    "desprendemos": "desprender",
    "desprendendo": "desprender",
    "desprendera": "desprender",
    "desprenderam": "desprender",
    "desprenderas": "desprender",
    "desprenderde": "desprender",
    "desprenderdes": "desprender",
    "desprendere": "desprender",
    "desprenderei": "desprender",
    "desprendereis": "desprender",
    "desprenderem": "desprender",
    "desprenderemos": "desprender",
    "desprenderes": "desprender",
    "desprenderia": "desprender",
    "desprenderiam": "desprender",
    "desprenderias": "desprender",
    "desprendermo": "desprender",
    "desprendermos": "desprender",
    "desprenderá": "desprender",
    "desprenderás": "desprender",
    "desprenderão": "desprender",
    "desprenderíamos": "desprender",
    "desprenderíeis": "desprender",
    "desprendes": "desprender",
    "desprendesse": "desprender",
    "desprendessem": "desprender",
    "desprendesses": "desprender",
    "desprendeste": "desprender",
    "desprendestes": "desprender",
    "desprendeu": "desprender",
    "desprendi": "desprender",
    "desprendia": "desprender",
    "desprendiam": "desprender",
    "desprendias": "desprender",
    "desprendida": "desprendido",
    "desprendidas": "desprendido",
    "desprendido": "desprender",
    "desprendidos": "desprendido",
    "desprendidíssima": "desprendido",
    "desprendidíssimas": "desprendido",
    "desprendidíssimo": "desprendido",
    "desprendidíssimos": "desprendido",
    "desprendimentos": "desprendimento",
    "desprendo": "desprender",
    "desprendê": "desprender",
    "desprendêramo": "desprender",
    "desprendêramos": "desprender",
    "desprendêrei": "desprender",
    "desprendêreis": "desprender",
    "desprendêsseis": "desprender",
    "desprendêssemos": "desprender",
    "desprendíamo": "desprender",
    "desprendíamos": "desprender",
    "desprendíei": "desprender",
    "desprendíeis": "desprender",
    "despreocupa": "despreocupar",
    "despreocupada": "despreocupar",
    "despreocupadas": "despreocupar",
    "despreocupado": "despreocupar",
    "despreocupados": "despreocupar",
    "despreocupadíssima": "despreocupado",
    "despreocupadíssimas": "despreocupado",
    "despreocupadíssimo": "despreocupado",
    "despreocupadíssimos": "despreocupado",
    "despreocupai": "despreocupar",
    "despreocupais": "despreocupar",
    "despreocupam": "despreocupar",
    "despreocupamo": "despreocupar",
    "despreocupamos": "despreocupar",
    "despreocupando": "despreocupar",
    "despreocupara": "despreocupar",
    "despreocuparam": "despreocupar",
    "despreocuparas": "despreocupar",
    "despreocuparde": "despreocupar",
    "despreocupardes": "despreocupar",
    "despreocupare": "despreocupar",
    "despreocuparei": "despreocupar",
    "despreocupareis": "despreocupar",
    "despreocuparem": "despreocupar",
    "despreocuparemos": "despreocupar",
    "despreocupares": "despreocupar",
    "despreocuparia": "despreocupar",
    "despreocupariam": "despreocupar",
    "despreocuparias": "despreocupar",
    "despreocuparmo": "despreocupar",
    "despreocuparmos": "despreocupar",
    "despreocupará": "despreocupar",
    "despreocuparás": "despreocupar",
    "despreocuparão": "despreocupar",
    "despreocuparíamos": "despreocupar",
    "despreocuparíeis": "despreocupar",
    "despreocupas": "despreocupar",
    "despreocupasse": "despreocupar",
    "despreocupassem": "despreocupar",
    "despreocupasses": "despreocupar",
    "despreocupaste": "despreocupar",
    "despreocupastes": "despreocupar",
    "despreocupava": "despreocupar",
    "despreocupavam": "despreocupar",
    "despreocupavas": "despreocupar",
    "despreocupações": "despreocupação",
    "despreocupe": "despreocupar",
    "despreocupei": "despreocupar",
    "despreocupeis": "despreocupar",
    "despreocupem": "despreocupar",
    "despreocupemo": "despreocupar",
    "despreocupemos": "despreocupar",
    "despreocupes": "despreocupar",
    "despreocupo": "despreocupar",
    "despreocupou": "despreocupar",
    "despreocupá": "despreocupar",
    "despreocupámo": "despreocupar",
    "despreocupámos": "despreocupar",
    "despreocupáramo": "despreocupar",
    "despreocupáramos": "despreocupar",
    "despreocupárei": "despreocupar",
    "despreocupáreis": "despreocupar",
    "despreocupásseis": "despreocupar",
    "despreocupássemos": "despreocupar",
    "despreocupávamo": "despreocupar",
    "despreocupávamos": "despreocupar",
    "despreocupávei": "despreocupar",
    "despreocupáveis": "despreocupar",
    "despreparos": "despreparo",
    "despressurizações": "despressurização",
    "desprestigia": "desprestigiar",
    "desprestigiada": "desprestigiar",
    "desprestigiadas": "desprestigiar",
    "desprestigiado": "desprestigiar",
    "desprestigiadora": "desprestigiador",
    "desprestigiadoras": "desprestigiador",
    "desprestigiadores": "desprestigiador",
    "desprestigiados": "desprestigiar",
    "desprestigiai": "desprestigiar",
    "desprestigiais": "desprestigiar",
    "desprestigiam": "desprestigiar",
    "desprestigiamo": "desprestigiar",
    "desprestigiamos": "desprestigiar",
    "desprestigiando": "desprestigiar",
    "desprestigiara": "desprestigiar",
    "desprestigiaram": "desprestigiar",
    "desprestigiaras": "desprestigiar",
    "desprestigiarde": "desprestigiar",
    "desprestigiardes": "desprestigiar",
    "desprestigiare": "desprestigiar",
    "desprestigiarei": "desprestigiar",
    "desprestigiareis": "desprestigiar",
    "desprestigiarem": "desprestigiar",
    "desprestigiaremos": "desprestigiar",
    "desprestigiares": "desprestigiar",
    "desprestigiaria": "desprestigiar",
    "desprestigiariam": "desprestigiar",
    "desprestigiarias": "desprestigiar",
    "desprestigiarmo": "desprestigiar",
    "desprestigiarmos": "desprestigiar",
    "desprestigiará": "desprestigiar",
    "desprestigiarás": "desprestigiar",
    "desprestigiarão": "desprestigiar",
    "desprestigiaríamos": "desprestigiar",
    "desprestigiaríeis": "desprestigiar",
    "desprestigias": "desprestigiar",
    "desprestigiasse": "desprestigiar",
    "desprestigiassem": "desprestigiar",
    "desprestigiasses": "desprestigiar",
    "desprestigiaste": "desprestigiar",
    "desprestigiastes": "desprestigiar",
    "desprestigiava": "desprestigiar",
    "desprestigiavam": "desprestigiar",
    "desprestigiavas": "desprestigiar",
    "desprestigie": "desprestigiar",
    "desprestigiei": "desprestigiar",
    "desprestigieis": "desprestigiar",
    "desprestigiem": "desprestigiar",
    "desprestigiemo": "desprestigiar",
    "desprestigiemos": "desprestigiar",
    "desprestigies": "desprestigiar",
    "desprestigio": "desprestigiar",
    "desprestigiou": "desprestigiar",
    "desprestigiá": "desprestigiar",
    "desprestigiámo": "desprestigiar",
    "desprestigiámos": "desprestigiar",
    "desprestigiáramo": "desprestigiar",
    "desprestigiáramos": "desprestigiar",
    "desprestigiárei": "desprestigiar",
    "desprestigiáreis": "desprestigiar",
    "desprestigiásseis": "desprestigiar",
    "desprestigiássemos": "desprestigiar",
    "desprestigiávamo": "desprestigiar",
    "desprestigiávamos": "desprestigiar",
    "desprestigiávei": "desprestigiar",
    "desprestigiáveis": "desprestigiar",
    "desprestígios": "desprestígio",
    "despretensiosa": "despretensioso",
    "despretensiosas": "despretensioso",
    "despretensiosos": "despretensioso",
    "despretensões": "despretensão",
    "desprevena": "desprevenir",
    "desprevenais": "desprevenir",
    "desprevenam": "desprevenir",
    "desprevenamo": "desprevenir",
    "desprevenamos": "desprevenir",
    "desprevenas": "desprevenir",
    "desprevene": "desprevenir",
    "desprevenem": "desprevenir",
    "desprevenes": "desprevenir",
    "despreveni": "desprevenir",
    "desprevenia": "desprevenir",
    "despreveniam": "desprevenir",
    "desprevenias": "desprevenir",
    "desprevenida": "desprevenir",
    "desprevenidas": "desprevenir",
    "desprevenido": "desprevenir",
    "desprevenidos": "desprevenir",
    "desprevenimo": "desprevenir",
    "desprevenimos": "desprevenir",
    "desprevenindo": "desprevenir",
    "desprevenira": "desprevenir",
    "despreveniram": "desprevenir",
    "despreveniras": "desprevenir",
    "desprevenirde": "desprevenir",
    "desprevenirdes": "desprevenir",
    "desprevenire": "desprevenir",
    "desprevenirei": "desprevenir",
    "desprevenireis": "desprevenir",
    "desprevenirem": "desprevenir",
    "despreveniremos": "desprevenir",
    "desprevenires": "desprevenir",
    "despreveniria": "desprevenir",
    "despreveniriam": "desprevenir",
    "desprevenirias": "desprevenir",
    "desprevenirmo": "desprevenir",
    "desprevenirmos": "desprevenir",
    "desprevenirá": "desprevenir",
    "desprevenirás": "desprevenir",
    "desprevenirão": "desprevenir",
    "despreveniríamos": "desprevenir",
    "despreveniríeis": "desprevenir",
    "desprevenis": "desprevenir",
    "desprevenisse": "desprevenir",
    "desprevenissem": "desprevenir",
    "desprevenisses": "desprevenir",
    "despreveniste": "desprevenir",
    "desprevenistes": "desprevenir",
    "despreveniu": "desprevenir",
    "despreveno": "desprevenir",
    "desprevenções": "desprevenção",
    "despreveníamo": "desprevenir",
    "despreveníamos": "desprevenir",
    "despreveníei": "desprevenir",
    "despreveníeis": "desprevenir",
    "despreveníramo": "desprevenir",
    "despreveníramos": "desprevenir",
    "desprevenírei": "desprevenir",
    "despreveníreis": "desprevenir",
    "desprevenísseis": "desprevenir",
    "despreveníssemos": "desprevenir",
    "despreza": "desprezar",
    "desprezada": "desprezar",
    "desprezadas": "desprezar",
    "desprezado": "desprezar",
    "desprezadora": "desprezador",
    "desprezadoras": "desprezador",
    "desprezadores": "desprezador",
    "desprezados": "desprezar",
    "desprezadíssima": "desprezado",
    "desprezadíssimas": "desprezado",
    "desprezadíssimo": "desprezado",
    "desprezadíssimos": "desprezado",
    "desprezai": "desprezar",
    "desprezais": "desprezar",
    "desprezam": "desprezar",
    "desprezamo": "desprezar",
    "desprezamos": "desprezar",
    "desprezando": "desprezar",
    "desprezara": "desprezar",
    "desprezaram": "desprezar",
    "desprezaras": "desprezar",
    "desprezarde": "desprezar",
    "desprezardes": "desprezar",
    "desprezare": "desprezar",
    "desprezarei": "desprezar",
    "desprezareis": "desprezar",
    "desprezarem": "desprezar",
    "desprezaremos": "desprezar",
    "desprezares": "desprezar",
    "desprezaria": "desprezar",
    "desprezariam": "desprezar",
    "desprezarias": "desprezar",
    "desprezarmo": "desprezar",
    "desprezarmos": "desprezar",
    "desprezará": "desprezar",
    "desprezarás": "desprezar",
    "desprezarão": "desprezar",
    "desprezaríamos": "desprezar",
    "desprezaríeis": "desprezar",
    "desprezas": "desprezar",
    "desprezasse": "desprezar",
    "desprezassem": "desprezar",
    "desprezasses": "desprezar",
    "desprezaste": "desprezar",
    "desprezastes": "desprezar",
    "desprezativa": "desprezativo",
    "desprezativas": "desprezativo",
    "desprezativos": "desprezativo",
    "desprezava": "desprezar",
    "desprezavam": "desprezar",
    "desprezavas": "desprezar",
    "despreze": "desprezar",
    "desprezei": "desprezar",
    "desprezeis": "desprezar",
    "desprezem": "desprezar",
    "desprezemo": "desprezar",
    "desprezemos": "desprezar",
    "desprezes": "desprezar",
    "desprezo": "desprezar",
    "desprezos": "desprezo",
    "desprezou": "desprezar",
    "desprezá": "desprezar",
    "desprezámo": "desprezar",
    "desprezámos": "desprezar",
    "desprezáramo": "desprezar",
    "desprezáramos": "desprezar",
    "desprezárei": "desprezar",
    "desprezáreis": "desprezar",
    "desprezásseis": "desprezar",
    "desprezássemos": "desprezar",
    "desprezávamo": "desprezar",
    "desprezávamos": "desprezar",
    "desprezávei": "desprezar",
    "desprezáveis": "desprezável",
    "desprezíveis": "desprezível",
    "desprimora": "desprimorar",
    "desprimorada": "desprimorar",
    "desprimoradas": "desprimorar",
    "desprimorado": "desprimorar",
    "desprimorados": "desprimorar",
    "desprimorai": "desprimorar",
    "desprimorais": "desprimorar",
    "desprimoram": "desprimorar",
    "desprimoramo": "desprimorar",
    "desprimoramos": "desprimorar",
    "desprimorando": "desprimorar",
    "desprimorara": "desprimorar",
    "desprimoraram": "desprimorar",
    "desprimoraras": "desprimorar",
    "desprimorarde": "desprimorar",
    "desprimorardes": "desprimorar",
    "desprimorare": "desprimorar",
    "desprimorarei": "desprimorar",
    "desprimorareis": "desprimorar",
    "desprimorarem": "desprimorar",
    "desprimoraremos": "desprimorar",
    "desprimorares": "desprimorar",
    "desprimoraria": "desprimorar",
    "desprimorariam": "desprimorar",
    "desprimorarias": "desprimorar",
    "desprimorarmo": "desprimorar",
    "desprimorarmos": "desprimorar",
    "desprimorará": "desprimorar",
    "desprimorarás": "desprimorar",
    "desprimorarão": "desprimorar",
    "desprimoraríamos": "desprimorar",
    "desprimoraríeis": "desprimorar",
    "desprimoras": "desprimorar",
    "desprimorasse": "desprimorar",
    "desprimorassem": "desprimorar",
    "desprimorasses": "desprimorar",
    "desprimoraste": "desprimorar",
    "desprimorastes": "desprimorar",
    "desprimorava": "desprimorar",
    "desprimoravam": "desprimorar",
    "desprimoravas": "desprimorar",
    "desprimore": "desprimorar",
    "desprimorei": "desprimorar",
    "desprimoreis": "desprimorar",
    "desprimorem": "desprimorar",
    "desprimoremo": "desprimorar",
    "desprimoremos": "desprimorar",
    "desprimores": "desprimorar",
    "desprimoro": "desprimorar",
    "desprimorosa": "desprimoroso",
    "desprimorosas": "desprimoroso",
    "desprimorosos": "desprimoroso",
    "desprimorou": "desprimorar",
    "desprimorá": "desprimorar",
    "desprimorámo": "desprimorar",
    "desprimorámos": "desprimorar",
    "desprimoráramo": "desprimorar",
    "desprimoráramos": "desprimorar",
    "desprimorárei": "desprimorar",
    "desprimoráreis": "desprimorar",
    "desprimorásseis": "desprimorar",
    "desprimorássemos": "desprimorar",
    "desprimorávamo": "desprimorar",
    "desprimorávamos": "desprimorar",
    "desprimorávei": "desprimorar",
    "desprimoráveis": "desprimorar",
    "despriva": "desprivar",
    "desprivada": "desprivar",
    "desprivadas": "desprivar",
    "desprivado": "desprivar",
    "desprivados": "desprivar",
    "desprivai": "desprivar",
    "desprivais": "desprivar",
    "desprivam": "desprivar",
    "desprivamo": "desprivar",
    "desprivamos": "desprivar",
    "desprivando": "desprivar",
    "desprivara": "desprivar",
    "desprivaram": "desprivar",
    "desprivaras": "desprivar",
    "desprivarde": "desprivar",
    "desprivardes": "desprivar",
    "desprivare": "desprivar",
    "desprivarei": "desprivar",
    "desprivareis": "desprivar",
    "desprivarem": "desprivar",
    "desprivaremos": "desprivar",
    "desprivares": "desprivar",
    "desprivaria": "desprivar",
    "desprivariam": "desprivar",
    "desprivarias": "desprivar",
    "desprivarmo": "desprivar",
    "desprivarmos": "desprivar",
    "desprivará": "desprivar",
    "desprivarás": "desprivar",
    "desprivarão": "desprivar",
    "desprivaríamos": "desprivar",
    "desprivaríeis": "desprivar",
    "desprivas": "desprivar",
    "desprivasse": "desprivar",
    "desprivassem": "desprivar",
    "desprivasses": "desprivar",
    "desprivaste": "desprivar",
    "desprivastes": "desprivar",
    "desprivava": "desprivar",
    "desprivavam": "desprivar",
    "desprivavas": "desprivar",
    "desprive": "desprivar",
    "desprivei": "desprivar",
    "despriveis": "desprivar",
    "desprivem": "desprivar",
    "desprivemo": "desprivar",
    "desprivemos": "desprivar",
    "desprives": "desprivar",
    "desprivilegia": "desprivilegiar",
    "desprivilegiada": "desprivilegiar",
    "desprivilegiadas": "desprivilegiar",
    "desprivilegiado": "desprivilegiar",
    "desprivilegiados": "desprivilegiar",
    "desprivilegiai": "desprivilegiar",
    "desprivilegiais": "desprivilegiar",
    "desprivilegiam": "desprivilegiar",
    "desprivilegiamo": "desprivilegiar",
    "desprivilegiamos": "desprivilegiar",
    "desprivilegiando": "desprivilegiar",
    "desprivilegiara": "desprivilegiar",
    "desprivilegiaram": "desprivilegiar",
    "desprivilegiaras": "desprivilegiar",
    "desprivilegiarde": "desprivilegiar",
    "desprivilegiardes": "desprivilegiar",
    "desprivilegiare": "desprivilegiar",
    "desprivilegiarei": "desprivilegiar",
    "desprivilegiareis": "desprivilegiar",
    "desprivilegiarem": "desprivilegiar",
    "desprivilegiaremos": "desprivilegiar",
    "desprivilegiares": "desprivilegiar",
    "desprivilegiaria": "desprivilegiar",
    "desprivilegiariam": "desprivilegiar",
    "desprivilegiarias": "desprivilegiar",
    "desprivilegiarmo": "desprivilegiar",
    "desprivilegiarmos": "desprivilegiar",
    "desprivilegiará": "desprivilegiar",
    "desprivilegiarás": "desprivilegiar",
    "desprivilegiarão": "desprivilegiar",
    "desprivilegiaríamos": "desprivilegiar",
    "desprivilegiaríeis": "desprivilegiar",
    "desprivilegias": "desprivilegiar",
    "desprivilegiasse": "desprivilegiar",
    "desprivilegiassem": "desprivilegiar",
    "desprivilegiasses": "desprivilegiar",
    "desprivilegiaste": "desprivilegiar",
    "desprivilegiastes": "desprivilegiar",
    "desprivilegiava": "desprivilegiar",
    "desprivilegiavam": "desprivilegiar",
    "desprivilegiavas": "desprivilegiar",
    "desprivilegie": "desprivilegiar",
    "desprivilegiei": "desprivilegiar",
    "desprivilegieis": "desprivilegiar",
    "desprivilegiem": "desprivilegiar",
    "desprivilegiemo": "desprivilegiar",
    "desprivilegiemos": "desprivilegiar",
    "desprivilegies": "desprivilegiar",
    "desprivilegio": "desprivilegiar",
    "desprivilegiou": "desprivilegiar",
    "desprivilegiá": "desprivilegiar",
    "desprivilegiámo": "desprivilegiar",
    "desprivilegiámos": "desprivilegiar",
    "desprivilegiáramo": "desprivilegiar",
    "desprivilegiáramos": "desprivilegiar",
    "desprivilegiárei": "desprivilegiar",
    "desprivilegiáreis": "desprivilegiar",
    "desprivilegiásseis": "desprivilegiar",
    "desprivilegiássemos": "desprivilegiar",
    "desprivilegiávamo": "desprivilegiar",
    "desprivilegiávamos": "desprivilegiar",
    "desprivilegiávei": "desprivilegiar",
    "desprivilegiáveis": "desprivilegiar",
    "desprivo": "desprivar",
    "desprivou": "desprivar",
    "desprivá": "desprivar",
    "desprivámo": "desprivar",
    "desprivámos": "desprivar",
    "despriváramo": "desprivar",
    "despriváramos": "desprivar",
    "desprivárei": "desprivar",
    "despriváreis": "desprivar",
    "desprivásseis": "desprivar",
    "desprivássemos": "desprivar",
    "desprivávamo": "desprivar",
    "desprivávamos": "desprivar",
    "desprivávei": "desprivar",
    "despriváveis": "desprivar",
    "desprofanada": "desprofanado",
    "desprofanadas": "desprofanado",
    "desprofanados": "desprofanado",
    "desprogramações": "desprogramação",
    "desprogramáveis": "desprogramável",
    "despromova": "despromover",
    "despromovais": "despromover",
    "despromovam": "despromover",
    "despromovamo": "despromover",
    "despromovamos": "despromover",
    "despromovas": "despromover",
    "despromove": "despromover",
    "despromovei": "despromover",
    "despromoveis": "despromover",
    "despromovem": "despromover",
    "despromovemo": "despromover",
    "despromovemos": "despromover",
    "despromovendo": "despromover",
    "despromovera": "despromover",
    "despromoveram": "despromover",
    "despromoveras": "despromover",
    "despromoverde": "despromover",
    "despromoverdes": "despromover",
    "despromovere": "despromover",
    "despromoverei": "despromover",
    "despromovereis": "despromover",
    "despromoverem": "despromover",
    "despromoveremos": "despromover",
    "despromoveres": "despromover",
    "despromoveria": "despromover",
    "despromoveriam": "despromover",
    "despromoverias": "despromover",
    "despromovermo": "despromover",
    "despromovermos": "despromover",
    "despromoverá": "despromover",
    "despromoverás": "despromover",
    "despromoverão": "despromover",
    "despromoveríamos": "despromover",
    "despromoveríeis": "despromover",
    "despromoves": "despromover",
    "despromovesse": "despromover",
    "despromovessem": "despromover",
    "despromovesses": "despromover",
    "despromoveste": "despromover",
    "despromovestes": "despromover",
    "despromoveu": "despromover",
    "despromovi": "despromover",
    "despromovia": "despromover",
    "despromoviam": "despromover",
    "despromovias": "despromover",
    "despromovida": "despromovido",
    "despromovidas": "despromovido",
    "despromovido": "despromover",
    "despromovidos": "despromovido",
    "despromovo": "despromover",
    "despromovê": "despromover",
    "despromovêramo": "despromover",
    "despromovêramos": "despromover",
    "despromovêrei": "despromover",
    "despromovêreis": "despromover",
    "despromovêsseis": "despromover",
    "despromovêssemos": "despromover",
    "despromovíamo": "despromover",
    "despromovíamos": "despromover",
    "despromovíei": "despromover",
    "despromovíeis": "despromover",
    "despromovíveis": "despromovível",
    "despromoções": "despromoção",
    "despronuncia": "despronunciar",
    "despronunciada": "despronunciar",
    "despronunciadas": "despronunciar",
    "despronunciado": "despronunciar",
    "despronunciados": "despronunciar",
    "despronunciai": "despronunciar",
    "despronunciais": "despronunciar",
    "despronunciam": "despronunciar",
    "despronunciamo": "despronunciar",
    "despronunciamos": "despronunciar",
    "despronunciando": "despronunciar",
    "despronunciara": "despronunciar",
    "despronunciaram": "despronunciar",
    "despronunciaras": "despronunciar",
    "despronunciarde": "despronunciar",
    "despronunciardes": "despronunciar",
    "despronunciare": "despronunciar",
    "despronunciarei": "despronunciar",
    "despronunciareis": "despronunciar",
    "despronunciarem": "despronunciar",
    "despronunciaremos": "despronunciar",
    "despronunciares": "despronunciar",
    "despronunciaria": "despronunciar",
    "despronunciariam": "despronunciar",
    "despronunciarias": "despronunciar",
    "despronunciarmo": "despronunciar",
    "despronunciarmos": "despronunciar",
    "despronunciará": "despronunciar",
    "despronunciarás": "despronunciar",
    "despronunciarão": "despronunciar",
    "despronunciaríamos": "despronunciar",
    "despronunciaríeis": "despronunciar",
    "despronuncias": "despronunciar",
    "despronunciasse": "despronunciar",
    "despronunciassem": "despronunciar",
    "despronunciasses": "despronunciar",
    "despronunciaste": "despronunciar",
    "despronunciastes": "despronunciar",
    "despronunciava": "despronunciar",
    "despronunciavam": "despronunciar",
    "despronunciavas": "despronunciar",
    "despronuncie": "despronunciar",
    "despronunciei": "despronunciar",
    "despronuncieis": "despronunciar",
    "despronunciem": "despronunciar",
    "despronunciemo": "despronunciar",
    "despronunciemos": "despronunciar",
    "despronuncies": "despronunciar",
    "despronuncio": "despronunciar",
    "despronunciou": "despronunciar",
    "despronunciá": "despronunciar",
    "despronunciámo": "despronunciar",
    "despronunciámos": "despronunciar",
    "despronunciáramo": "despronunciar",
    "despronunciáramos": "despronunciar",
    "despronunciárei": "despronunciar",
    "despronunciáreis": "despronunciar",
    "despronunciásseis": "despronunciar",
    "despronunciássemos": "despronunciar",
    "despronunciávamo": "despronunciar",
    "despronunciávamos": "despronunciar",
    "despronunciávei": "despronunciar",
    "despronunciáveis": "despronunciar",
    "despronúncias": "despronúncia",
    "desproporciona": "desproporcionar",
    "desproporcionada": "desproporcionar",
    "desproporcionadas": "desproporcionar",
    "desproporcionado": "desproporcionar",
    "desproporcionados": "desproporcionar",
    "desproporcionai": "desproporcionar",
    "desproporcionais": "desproporcionar",
    "desproporcionalidades": "desproporcionalidade",
    "desproporcionam": "desproporcionar",
    "desproporcionamo": "desproporcionar",
    "desproporcionamos": "desproporcionar",
    "desproporcionando": "desproporcionar",
    "desproporcionara": "desproporcionar",
    "desproporcionaram": "desproporcionar",
    "desproporcionaras": "desproporcionar",
    "desproporcionarde": "desproporcionar",
    "desproporcionardes": "desproporcionar",
    "desproporcionare": "desproporcionar",
    "desproporcionarei": "desproporcionar",
    "desproporcionareis": "desproporcionar",
    "desproporcionarem": "desproporcionar",
    "desproporcionaremos": "desproporcionar",
    "desproporcionares": "desproporcionar",
    "desproporcionaria": "desproporcionar",
    "desproporcionariam": "desproporcionar",
    "desproporcionarias": "desproporcionar",
    "desproporcionarmo": "desproporcionar",
    "desproporcionarmos": "desproporcionar",
    "desproporcionará": "desproporcionar",
    "desproporcionarás": "desproporcionar",
    "desproporcionarão": "desproporcionar",
    "desproporcionaríamos": "desproporcionar",
    "desproporcionaríeis": "desproporcionar",
    "desproporcionas": "desproporcionar",
    "desproporcionasse": "desproporcionar",
    "desproporcionassem": "desproporcionar",
    "desproporcionasses": "desproporcionar",
    "desproporcionaste": "desproporcionar",
    "desproporcionastes": "desproporcionar",
    "desproporcionava": "desproporcionar",
    "desproporcionavam": "desproporcionar",
    "desproporcionavas": "desproporcionar",
    "desproporcionações": "desproporcionação",
    "desproporcione": "desproporcionar",
    "desproporcionei": "desproporcionar",
    "desproporcioneis": "desproporcionar",
    "desproporcionem": "desproporcionar",
    "desproporcionemo": "desproporcionar",
    "desproporcionemos": "desproporcionar",
    "desproporciones": "desproporcionar",
    "desproporciono": "desproporcionar",
    "desproporcionou": "desproporcionar",
    "desproporcioná": "desproporcionar",
    "desproporcionámo": "desproporcionar",
    "desproporcionámos": "desproporcionar",
    "desproporcionáramo": "desproporcionar",
    "desproporcionáramos": "desproporcionar",
    "desproporcionárei": "desproporcionar",
    "desproporcionáreis": "desproporcionar",
    "desproporcionásseis": "desproporcionar",
    "desproporcionássemos": "desproporcionar",
    "desproporcionávamo": "desproporcionar",
    "desproporcionávamos": "desproporcionar",
    "desproporcionávei": "desproporcionar",
    "desproporcionáveis": "desproporcionar",
    "desproporções": "desproporção",
    "desproposita": "despropositar",
    "despropositada": "despropositar",
    "despropositadas": "despropositar",
    "despropositado": "despropositar",
    "despropositados": "despropositar",
    "despropositai": "despropositar",
    "despropositais": "despropositar",
    "despropositam": "despropositar",
    "despropositamo": "despropositar",
    "despropositamos": "despropositar",
    "despropositando": "despropositar",
    "despropositara": "despropositar",
    "despropositaram": "despropositar",
    "despropositaras": "despropositar",
    "despropositardes": "despropositar",
    "despropositarei": "despropositar",
    "despropositareis": "despropositar",
    "despropositarem": "despropositar",
    "despropositaremos": "despropositar",
    "despropositares": "despropositar",
    "despropositaria": "despropositar",
    "despropositariam": "despropositar",
    "despropositarias": "despropositar",
    "despropositarmo": "despropositar",
    "despropositarmos": "despropositar",
    "despropositará": "despropositar",
    "despropositarás": "despropositar",
    "despropositarão": "despropositar",
    "despropositaríamos": "despropositar",
    "despropositaríeis": "despropositar",
    "despropositas": "despropositar",
    "despropositasse": "despropositar",
    "despropositassem": "despropositar",
    "despropositasses": "despropositar",
    "despropositaste": "despropositar",
    "despropositastes": "despropositar",
    "despropositava": "despropositar",
    "despropositavam": "despropositar",
    "despropositavas": "despropositar",
    "desproposite": "despropositar",
    "despropositei": "despropositar",
    "despropositeis": "despropositar",
    "despropositem": "despropositar",
    "despropositemo": "despropositar",
    "despropositemos": "despropositar",
    "desproposites": "despropositar",
    "desproposito": "despropositar",
    "despropositou": "despropositar",
    "despropositámo": "despropositar",
    "despropositámos": "despropositar",
    "despropositáramo": "despropositar",
    "despropositáramos": "despropositar",
    "despropositáreis": "despropositar",
    "despropositásseis": "despropositar",
    "despropositássemos": "despropositar",
    "despropositávamo": "despropositar",
    "despropositávamos": "despropositar",
    "despropositáveis": "despropositar",
    "despropósitos": "despropósito",
    "desprotecções": "desprotecção",
    "desprotege": "desproteger",
    "desprotegei": "desproteger",
    "desprotegeis": "desproteger",
    "desprotegem": "desproteger",
    "desprotegemo": "desproteger",
    "desprotegemos": "desproteger",
    "desprotegendo": "desproteger",
    "desprotegera": "desproteger",
    "desprotegeram": "desproteger",
    "desprotegeras": "desproteger",
    "desprotegerde": "desproteger",
    "desprotegerdes": "desproteger",
    "desprotegere": "desproteger",
    "desprotegerei": "desproteger",
    "desprotegereis": "desproteger",
    "desprotegerem": "desproteger",
    "desprotegeremos": "desproteger",
    "desprotegeres": "desproteger",
    "desprotegeria": "desproteger",
    "desprotegeriam": "desproteger",
    "desprotegerias": "desproteger",
    "desprotegermo": "desproteger",
    "desprotegermos": "desproteger",
    "desprotegerá": "desproteger",
    "desprotegerás": "desproteger",
    "desprotegerão": "desproteger",
    "desprotegeríamos": "desproteger",
    "desprotegeríeis": "desproteger",
    "desproteges": "desproteger",
    "desprotegesse": "desproteger",
    "desprotegessem": "desproteger",
    "desprotegesses": "desproteger",
    "desprotegeste": "desproteger",
    "desprotegestes": "desproteger",
    "desprotegeu": "desproteger",
    "desprotegi": "desproteger",
    "desprotegia": "desproteger",
    "desprotegiam": "desproteger",
    "desprotegias": "desproteger",
    "desprotegida": "desprotegido",
    "desprotegidas": "desprotegido",
    "desprotegido": "desproteger",
    "desprotegidos": "desprotegido",
    "desprotegidíssima": "desprotegido",
    "desprotegidíssimas": "desprotegido",
    "desprotegidíssimo": "desprotegido",
    "desprotegidíssimos": "desprotegido",
    "desprotegê": "desproteger",
    "desprotegêramo": "desproteger",
    "desprotegêramos": "desproteger",
    "desprotegêrei": "desproteger",
    "desprotegêreis": "desproteger",
    "desprotegêsseis": "desproteger",
    "desprotegêssemos": "desproteger",
    "desprotegíamo": "desproteger",
    "desprotegíamos": "desproteger",
    "desprotegíei": "desproteger",
    "desprotegíeis": "desproteger",
    "desproteja": "desproteger",
    "desprotejais": "desproteger",
    "desprotejam": "desproteger",
    "desprotejamo": "desproteger",
    "desprotejamos": "desproteger",
    "desprotejas": "desproteger",
    "desprotejo": "desproteger",
    "desprouve": "desprazer",
    "desprouver": "desprazer",
    "desprouvera": "desprazer",
    "desprouveram": "desprazer",
    "desprouverem": "desprazer",
    "desprouvesse": "desprazer",
    "desprouvessem": "desprazer",
    "desprova": "desprover",
    "desprovais": "desprover",
    "desprovam": "desprover",
    "desprovamo": "desprover",
    "desprovamos": "desprover",
    "desprovas": "desprover",
    "desprove": "desprover",
    "desprovei": "desprover",
    "desproveis": "desprover",
    "desproveitos": "desproveito",
    "desprovem": "desprover",
    "desprovemo": "desprover",
    "desprovemos": "desprover",
    "desprovendo": "desprover",
    "desprovera": "desprover",
    "desproveram": "desprover",
    "desproveras": "desprover",
    "desproverde": "desprover",
    "desproverdes": "desprover",
    "desprovere": "desprover",
    "desproverei": "desprover",
    "desprovereis": "desprover",
    "desproverem": "desprover",
    "desproveremos": "desprover",
    "desproveres": "desprover",
    "desproveria": "desprover",
    "desproveriam": "desprover",
    "desproverias": "desprover",
    "desprovermo": "desprover",
    "desprovermos": "desprover",
    "desproverá": "desprover",
    "desproverás": "desprover",
    "desproverão": "desprover",
    "desproveríamos": "desprover",
    "desproveríeis": "desprover",
    "desproves": "desprover",
    "desprovesse": "desprover",
    "desprovessem": "desprover",
    "desprovesses": "desprover",
    "desproveste": "desprover",
    "desprovestes": "desprover",
    "desproveu": "desprover",
    "desprovi": "desprover",
    "desprovia": "desprover",
    "desproviam": "desprover",
    "desprovias": "desprover",
    "desprovida": "desprovido",
    "desprovidas": "desprovido",
    "desprovido": "desprover",
    "desprovidos": "desprovido",
    "desprovimentos": "desprovimento",
    "desprovo": "desprover",
    "desprovê": "desprover",
    "desprovêramo": "desprover",
    "desprovêramos": "desprover",
    "desprovêrei": "desprover",
    "desprovêreis": "desprover",
    "desprovêsseis": "desprover",
    "desprovêssemos": "desprover",
    "desprovíamo": "desprover",
    "desprovíamos": "desprover",
    "desprovíei": "desprover",
    "desprovíeis": "desprover",
    "despudorada": "despudorado",
    "despudoradas": "despudorado",
    "despudorados": "despudorado",
    "despudores": "despudor",
    "despula": "despolir",
    "despulais": "despolir",
    "despulam": "despolir",
    "despulamo": "despolir",
    "despulamos": "despolir",
    "despulas": "despolir",
    "despule": "despolir",
    "despulem": "despolir",
    "despules": "despolir",
    "despulo": "despolir",
    "despundonores": "despundonor",
    "despundonorosa": "despundonoroso",
    "despundonorosas": "despundonoroso",
    "despundonorosos": "despundonoroso",
    "despunha": "despor",
    "despunham": "despor",
    "despunhas": "despor",
    "despus": "despor",
    "despusemo": "despor",
    "despusemos": "despor",
    "despuser": "despor",
    "despusera": "despor",
    "despuseram": "despor",
    "despuseras": "despor",
    "despuserdes": "despor",
    "despuserem": "despor",
    "despuseres": "despor",
    "despusermos": "despor",
    "despusesse": "despor",
    "despusessem": "despor",
    "despusesses": "despor",
    "despuseste": "despor",
    "despusestes": "despor",
    "despuséramo": "despor",
    "despuséramos": "despor",
    "despusérei": "despor",
    "despuséreis": "despor",
    "despusésseis": "despor",
    "despuséssemos": "despor",
    "despíamo": "despir",
    "despíamos": "despir",
    "despíei": "despir",
    "despíeis": "despir",
    "despíramo": "despir",
    "despíramos": "despir",
    "despírei": "despir",
    "despíreis": "despir",
    "despísseis": "despir",
    "despíssemos": "despir",
    "despótica": "despótico",
    "despóticas": "despótico",
    "despóticos": "despótico",
    "despô": "despor",
    "despôs": "despor",
    "despõe": "despor",
    "despõem": "despor",
    "despões": "despor",
    "despúnhamo": "despor",
    "despúnhamos": "despor",
    "despúnhei": "despor",
    "despúnheis": "despor",
    "desquadra": "desquadrar",
    "desquadrada": "desquadrar",
    "desquadradas": "desquadrar",
    "desquadrado": "desquadrar",
    "desquadrados": "desquadrar",
    "desquadrai": "desquadrar",
    "desquadrais": "desquadrar",
    "desquadram": "desquadrar",
    "desquadramo": "desquadrar",
    "desquadramos": "desquadrar",
    "desquadrando": "desquadrar",
    "desquadrara": "desquadrar",
    "desquadraram": "desquadrar",
    "desquadraras": "desquadrar",
    "desquadrardes": "desquadrar",
    "desquadrarei": "desquadrar",
    "desquadrareis": "desquadrar",
    "desquadrarem": "desquadrar",
    "desquadraremos": "desquadrar",
    "desquadrares": "desquadrar",
    "desquadraria": "desquadrar",
    "desquadrariam": "desquadrar",
    "desquadrarias": "desquadrar",
    "desquadrarmo": "desquadrar",
    "desquadrarmos": "desquadrar",
    "desquadrará": "desquadrar",
    "desquadrarás": "desquadrar",
    "desquadrarão": "desquadrar",
    "desquadraríamos": "desquadrar",
    "desquadraríeis": "desquadrar",
    "desquadras": "desquadrar",
    "desquadrasse": "desquadrar",
    "desquadrassem": "desquadrar",
    "desquadrasses": "desquadrar",
    "desquadraste": "desquadrar",
    "desquadrastes": "desquadrar",
    "desquadrava": "desquadrar",
    "desquadravam": "desquadrar",
    "desquadravas": "desquadrar",
    "desquadre": "desquadrar",
    "desquadrei": "desquadrar",
    "desquadreis": "desquadrar",
    "desquadrem": "desquadrar",
    "desquadremo": "desquadrar",
    "desquadremos": "desquadrar",
    "desquadres": "desquadrar",
    "desquadrilha": "desquadrilhar",
    "desquadrilhada": "desquadrilhar",
    "desquadrilhadas": "desquadrilhar",
    "desquadrilhado": "desquadrilhar",
    "desquadrilhados": "desquadrilhar",
    "desquadrilhai": "desquadrilhar",
    "desquadrilhais": "desquadrilhar",
    "desquadrilham": "desquadrilhar",
    "desquadrilhamo": "desquadrilhar",
    "desquadrilhamos": "desquadrilhar",
    "desquadrilhando": "desquadrilhar",
    "desquadrilhara": "desquadrilhar",
    "desquadrilharam": "desquadrilhar",
    "desquadrilharas": "desquadrilhar",
    "desquadrilharde": "desquadrilhar",
    "desquadrilhardes": "desquadrilhar",
    "desquadrilhare": "desquadrilhar",
    "desquadrilharei": "desquadrilhar",
    "desquadrilhareis": "desquadrilhar",
    "desquadrilharem": "desquadrilhar",
    "desquadrilharemos": "desquadrilhar",
    "desquadrilhares": "desquadrilhar",
    "desquadrilharia": "desquadrilhar",
    "desquadrilhariam": "desquadrilhar",
    "desquadrilharias": "desquadrilhar",
    "desquadrilharmo": "desquadrilhar",
    "desquadrilharmos": "desquadrilhar",
    "desquadrilhará": "desquadrilhar",
    "desquadrilharás": "desquadrilhar",
    "desquadrilharão": "desquadrilhar",
    "desquadrilharíamos": "desquadrilhar",
    "desquadrilharíeis": "desquadrilhar",
    "desquadrilhas": "desquadrilhar",
    "desquadrilhasse": "desquadrilhar",
    "desquadrilhassem": "desquadrilhar",
    "desquadrilhasses": "desquadrilhar",
    "desquadrilhaste": "desquadrilhar",
    "desquadrilhastes": "desquadrilhar",
    "desquadrilhava": "desquadrilhar",
    "desquadrilhavam": "desquadrilhar",
    "desquadrilhavas": "desquadrilhar",
    "desquadrilhe": "desquadrilhar",
    "desquadrilhei": "desquadrilhar",
    "desquadrilheis": "desquadrilhar",
    "desquadrilhem": "desquadrilhar",
    "desquadrilhemo": "desquadrilhar",
    "desquadrilhemos": "desquadrilhar",
    "desquadrilhes": "desquadrilhar",
    "desquadrilho": "desquadrilhar",
    "desquadrilhou": "desquadrilhar",
    "desquadrilhá": "desquadrilhar",
    "desquadrilhámo": "desquadrilhar",
    "desquadrilhámos": "desquadrilhar",
    "desquadrilháramo": "desquadrilhar",
    "desquadrilháramos": "desquadrilhar",
    "desquadrilhárei": "desquadrilhar",
    "desquadrilháreis": "desquadrilhar",
    "desquadrilhásseis": "desquadrilhar",
    "desquadrilhássemos": "desquadrilhar",
    "desquadrilhávamo": "desquadrilhar",
    "desquadrilhávamos": "desquadrilhar",
    "desquadrilhávei": "desquadrilhar",
    "desquadrilháveis": "desquadrilhar",
    "desquadro": "desquadrar",
    "desquadrou": "desquadrar",
    "desquadrámo": "desquadrar",
    "desquadrámos": "desquadrar",
    "desquadráramo": "desquadrar",
    "desquadráramos": "desquadrar",
    "desquadráreis": "desquadrar",
    "desquadrásseis": "desquadrar",
    "desquadrássemos": "desquadrar",
    "desquadrávamo": "desquadrar",
    "desquadrávamos": "desquadrar",
    "desquadráveis": "desquadrar",
    "desqualifica": "desqualificar",
    "desqualificada": "desqualificar",
    "desqualificadas": "desqualificar",
    "desqualificado": "desqualificar",
    "desqualificadora": "desqualificador",
    "desqualificadoras": "desqualificador",
    "desqualificadores": "desqualificador",
    "desqualificados": "desqualificar",
    "desqualificai": "desqualificar",
    "desqualificais": "desqualificar",
    "desqualificam": "desqualificar",
    "desqualificamo": "desqualificar",
    "desqualificamos": "desqualificar",
    "desqualificando": "desqualificar",
    "desqualificara": "desqualificar",
    "desqualificaram": "desqualificar",
    "desqualificaras": "desqualificar",
    "desqualificarde": "desqualificar",
    "desqualificardes": "desqualificar",
    "desqualificare": "desqualificar",
    "desqualificarei": "desqualificar",
    "desqualificareis": "desqualificar",
    "desqualificarem": "desqualificar",
    "desqualificaremos": "desqualificar",
    "desqualificares": "desqualificar",
    "desqualificaria": "desqualificar",
    "desqualificariam": "desqualificar",
    "desqualificarias": "desqualificar",
    "desqualificarmo": "desqualificar",
    "desqualificarmos": "desqualificar",
    "desqualificará": "desqualificar",
    "desqualificarás": "desqualificar",
    "desqualificarão": "desqualificar",
    "desqualificaríamos": "desqualificar",
    "desqualificaríeis": "desqualificar",
    "desqualificas": "desqualificar",
    "desqualificasse": "desqualificar",
    "desqualificassem": "desqualificar",
    "desqualificasses": "desqualificar",
    "desqualificaste": "desqualificar",
    "desqualificastes": "desqualificar",
    "desqualificativa": "desqualificativo",
    "desqualificativas": "desqualificativo",
    "desqualificativos": "desqualificativo",
    "desqualificava": "desqualificar",
    "desqualificavam": "desqualificar",
    "desqualificavas": "desqualificar",
    "desqualificações": "desqualificação",
    "desqualifico": "desqualificar",
    "desqualificou": "desqualificar",
    "desqualificá": "desqualificar",
    "desqualificámo": "desqualificar",
    "desqualificámos": "desqualificar",
    "desqualificáramo": "desqualificar",
    "desqualificáramos": "desqualificar",
    "desqualificárei": "desqualificar",
    "desqualificáreis": "desqualificar",
    "desqualificásseis": "desqualificar",
    "desqualificássemos": "desqualificar",
    "desqualificávamo": "desqualificar",
    "desqualificávamos": "desqualificar",
    "desqualificávei": "desqualificar",
    "desqualificáveis": "desqualificável",
    "desqualifique": "desqualificar",
    "desqualifiquei": "desqualificar",
    "desqualifiqueis": "desqualificar",
    "desqualifiquem": "desqualificar",
    "desqualifiquemo": "desqualificar",
    "desqualifiquemos": "desqualificar",
    "desqualifiques": "desqualificar",
    "desquebra": "desquebrar",
    "desquebrada": "desquebrar",
    "desquebradas": "desquebrar",
    "desquebrado": "desquebrar",
    "desquebrados": "desquebrar",
    "desquebrai": "desquebrar",
    "desquebrais": "desquebrar",
    "desquebram": "desquebrar",
    "desquebramo": "desquebrar",
    "desquebramos": "desquebrar",
    "desquebrando": "desquebrar",
    "desquebrara": "desquebrar",
    "desquebraram": "desquebrar",
    "desquebraras": "desquebrar",
    "desquebrarde": "desquebrar",
    "desquebrardes": "desquebrar",
    "desquebrare": "desquebrar",
    "desquebrarei": "desquebrar",
    "desquebrareis": "desquebrar",
    "desquebrarem": "desquebrar",
    "desquebraremos": "desquebrar",
    "desquebrares": "desquebrar",
    "desquebraria": "desquebrar",
    "desquebrariam": "desquebrar",
    "desquebrarias": "desquebrar",
    "desquebrarmo": "desquebrar",
    "desquebrarmos": "desquebrar",
    "desquebrará": "desquebrar",
    "desquebrarás": "desquebrar",
    "desquebrarão": "desquebrar",
    "desquebraríamos": "desquebrar",
    "desquebraríeis": "desquebrar",
    "desquebras": "desquebrar",
    "desquebrasse": "desquebrar",
    "desquebrassem": "desquebrar",
    "desquebrasses": "desquebrar",
    "desquebraste": "desquebrar",
    "desquebrastes": "desquebrar",
    "desquebrava": "desquebrar",
    "desquebravam": "desquebrar",
    "desquebravas": "desquebrar",
    "desquebre": "desquebrar",
    "desquebrei": "desquebrar",
    "desquebreis": "desquebrar",
    "desquebrem": "desquebrar",
    "desquebremo": "desquebrar",
    "desquebremos": "desquebrar",
    "desquebres": "desquebrar",
    "desquebro": "desquebrar",
    "desquebrou": "desquebrar",
    "desquebrá": "desquebrar",
    "desquebrámo": "desquebrar",
    "desquebrámos": "desquebrar",
    "desquebráramo": "desquebrar",
    "desquebráramos": "desquebrar",
    "desquebrárei": "desquebrar",
    "desquebráreis": "desquebrar",
    "desquebrásseis": "desquebrar",
    "desquebrássemos": "desquebrar",
    "desquebrávamo": "desquebrar",
    "desquebrávamos": "desquebrar",
    "desquebrávei": "desquebrar",
    "desquebráveis": "desquebrar",
    "desqueixa": "desqueixar",
    "desqueixada": "desqueixar",
    "desqueixadas": "desqueixar",
    "desqueixado": "desqueixar",
    "desqueixadora": "desqueixador",
    "desqueixadoras": "desqueixador",
    "desqueixadores": "desqueixador",
    "desqueixados": "desqueixar",
    "desqueixai": "desqueixar",
    "desqueixais": "desqueixar",
    "desqueixam": "desqueixar",
    "desqueixamo": "desqueixar",
    "desqueixamos": "desqueixar",
    "desqueixando": "desqueixar",
    "desqueixara": "desqueixar",
    "desqueixaram": "desqueixar",
    "desqueixaras": "desqueixar",
    "desqueixarde": "desqueixar",
    "desqueixardes": "desqueixar",
    "desqueixare": "desqueixar",
    "desqueixarei": "desqueixar",
    "desqueixareis": "desqueixar",
    "desqueixarem": "desqueixar",
    "desqueixaremos": "desqueixar",
    "desqueixares": "desqueixar",
    "desqueixaria": "desqueixar",
    "desqueixariam": "desqueixar",
    "desqueixarias": "desqueixar",
    "desqueixarmo": "desqueixar",
    "desqueixarmos": "desqueixar",
    "desqueixará": "desqueixar",
    "desqueixarás": "desqueixar",
    "desqueixarão": "desqueixar",
    "desqueixaríamos": "desqueixar",
    "desqueixaríeis": "desqueixar",
    "desqueixas": "desqueixar",
    "desqueixasse": "desqueixar",
    "desqueixassem": "desqueixar",
    "desqueixasses": "desqueixar",
    "desqueixaste": "desqueixar",
    "desqueixastes": "desqueixar",
    "desqueixava": "desqueixar",
    "desqueixavam": "desqueixar",
    "desqueixavas": "desqueixar",
    "desqueixe": "desqueixar",
    "desqueixei": "desqueixar",
    "desqueixeis": "desqueixar",
    "desqueixelada": "desqueixelado",
    "desqueixeladas": "desqueixelado",
    "desqueixelados": "desqueixelado",
    "desqueixem": "desqueixar",
    "desqueixemo": "desqueixar",
    "desqueixemos": "desqueixar",
    "desqueixes": "desqueixar",
    "desqueixo": "desqueixar",
    "desqueixou": "desqueixar",
    "desqueixá": "desqueixar",
    "desqueixámo": "desqueixar",
    "desqueixámos": "desqueixar",
    "desqueixáramo": "desqueixar",
    "desqueixáramos": "desqueixar",
    "desqueixárei": "desqueixar",
    "desqueixáreis": "desqueixar",
    "desqueixásseis": "desqueixar",
    "desqueixássemos": "desqueixar",
    "desqueixávamo": "desqueixar",
    "desqueixávamos": "desqueixar",
    "desqueixávei": "desqueixar",
    "desqueixáveis": "desqueixar",
    "desquera": "desquerer",
    "desquerais": "desquerer",
    "desqueram": "desquerer",
    "desqueramo": "desquerer",
    "desqueramos": "desquerer",
    "desqueras": "desquerer",
    "desquere": "desquerer",
    "desquerei": "desquerer",
    "desquereis": "desquerer",
    "desquerem": "desquerer",
    "desqueremo": "desquerer",
    "desqueremos": "desquerer",
    "desquerendo": "desquerer",
    "desquerera": "desquerer",
    "desquereram": "desquerer",
    "desquereras": "desquerer",
    "desquererde": "desquerer",
    "desquererdes": "desquerer",
    "desquerere": "desquerer",
    "desquererei": "desquerer",
    "desquerereis": "desquerer",
    "desquererem": "desquerer",
    "desquereremos": "desquerer",
    "desquereres": "desquerer",
    "desquereria": "desquerer",
    "desquereriam": "desquerer",
    "desquererias": "desquerer",
    "desquerermo": "desquerer",
    "desquerermos": "desquerer",
    "desquererá": "desquerer",
    "desquererás": "desquerer",
    "desquererão": "desquerer",
    "desquereríamos": "desquerer",
    "desquereríeis": "desquerer",
    "desqueres": "desquerer",
    "desqueresse": "desquerer",
    "desqueressem": "desquerer",
    "desqueresses": "desquerer",
    "desquereste": "desquerer",
    "desquerestes": "desquerer",
    "desquereu": "desquerer",
    "desqueri": "desquerer",
    "desqueria": "desquerer",
    "desqueriam": "desquerer",
    "desquerias": "desquerer",
    "desquerida": "desquerido",
    "desqueridas": "desquerido",
    "desquerido": "desquerer",
    "desqueridos": "desquerido",
    "desquero": "desquerer",
    "desquerê": "desquerer",
    "desquerêramo": "desquerer",
    "desquerêramos": "desquerer",
    "desquerêrei": "desquerer",
    "desquerêreis": "desquerer",
    "desquerêsseis": "desquerer",
    "desquerêssemos": "desquerer",
    "desqueríamo": "desquerer",
    "desqueríamos": "desquerer",
    "desqueríei": "desquerer",
    "desqueríeis": "desquerer",
    "desquicia": "desquiciar",
    "desquiciada": "desquiciar",
    "desquiciadas": "desquiciar",
    "desquiciado": "desquiciar",
    "desquiciados": "desquiciar",
    "desquiciai": "desquiciar",
    "desquiciais": "desquiciar",
    "desquiciam": "desquiciar",
    "desquiciamo": "desquiciar",
    "desquiciamos": "desquiciar",
    "desquiciando": "desquiciar",
    "desquiciara": "desquiciar",
    "desquiciaram": "desquiciar",
    "desquiciaras": "desquiciar",
    "desquiciarde": "desquiciar",
    "desquiciardes": "desquiciar",
    "desquiciare": "desquiciar",
    "desquiciarei": "desquiciar",
    "desquiciareis": "desquiciar",
    "desquiciarem": "desquiciar",
    "desquiciaremos": "desquiciar",
    "desquiciares": "desquiciar",
    "desquiciaria": "desquiciar",
    "desquiciariam": "desquiciar",
    "desquiciarias": "desquiciar",
    "desquiciarmo": "desquiciar",
    "desquiciarmos": "desquiciar",
    "desquiciará": "desquiciar",
    "desquiciarás": "desquiciar",
    "desquiciarão": "desquiciar",
    "desquiciaríamos": "desquiciar",
    "desquiciaríeis": "desquiciar",
    "desquicias": "desquiciar",
    "desquiciasse": "desquiciar",
    "desquiciassem": "desquiciar",
    "desquiciasses": "desquiciar",
    "desquiciaste": "desquiciar",
    "desquiciastes": "desquiciar",
    "desquiciava": "desquiciar",
    "desquiciavam": "desquiciar",
    "desquiciavas": "desquiciar",
    "desquicie": "desquiciar",
    "desquiciei": "desquiciar",
    "desquicieis": "desquiciar",
    "desquiciem": "desquiciar",
    "desquiciemo": "desquiciar",
    "desquiciemos": "desquiciar",
    "desquicies": "desquiciar",
    "desquicio": "desquiciar",
    "desquiciou": "desquiciar",
    "desquiciá": "desquiciar",
    "desquiciámo": "desquiciar",
    "desquiciámos": "desquiciar",
    "desquiciáramo": "desquiciar",
    "desquiciáramos": "desquiciar",
    "desquiciárei": "desquiciar",
    "desquiciáreis": "desquiciar",
    "desquiciásseis": "desquiciar",
    "desquiciássemos": "desquiciar",
    "desquiciávamo": "desquiciar",
    "desquiciávamos": "desquiciar",
    "desquiciávei": "desquiciar",
    "desquiciáveis": "desquiciar",
    "desquita": "desquitar",
    "desquitada": "desquitar",
    "desquitadas": "desquitar",
    "desquitado": "desquitar",
    "desquitados": "desquitar",
    "desquitai": "desquitar",
    "desquitais": "desquitar",
    "desquitam": "desquitar",
    "desquitamo": "desquitar",
    "desquitamos": "desquitar",
    "desquitando": "desquitar",
    "desquitara": "desquitar",
    "desquitaram": "desquitar",
    "desquitaras": "desquitar",
    "desquitarde": "desquitar",
    "desquitardes": "desquitar",
    "desquitare": "desquitar",
    "desquitarei": "desquitar",
    "desquitareis": "desquitar",
    "desquitarem": "desquitar",
    "desquitaremos": "desquitar",
    "desquitares": "desquitar",
    "desquitaria": "desquitar",
    "desquitariam": "desquitar",
    "desquitarias": "desquitar",
    "desquitarmo": "desquitar",
    "desquitarmos": "desquitar",
    "desquitará": "desquitar",
    "desquitarás": "desquitar",
    "desquitarão": "desquitar",
    "desquitaríamos": "desquitar",
    "desquitaríeis": "desquitar",
    "desquitas": "desquitar",
    "desquitasse": "desquitar",
    "desquitassem": "desquitar",
    "desquitasses": "desquitar",
    "desquitaste": "desquitar",
    "desquitastes": "desquitar",
    "desquitava": "desquitar",
    "desquitavam": "desquitar",
    "desquitavas": "desquitar",
    "desquitações": "desquitação",
    "desquite": "desquitar",
    "desquitei": "desquitar",
    "desquiteis": "desquitar",
    "desquitem": "desquitar",
    "desquitemo": "desquitar",
    "desquitemos": "desquitar",
    "desquites": "desquite",
    "desquito": "desquitar",
    "desquitou": "desquitar",
    "desquitá": "desquitar",
    "desquitámo": "desquitar",
    "desquitámos": "desquitar",
    "desquitáramo": "desquitar",
    "desquitáramos": "desquitar",
    "desquitárei": "desquitar",
    "desquitáreis": "desquitar",
    "desquitásseis": "desquitar",
    "desquitássemos": "desquitar",
    "desquitávamo": "desquitar",
    "desquitávamos": "desquitar",
    "desquitávei": "desquitar",
    "desquitáveis": "desquitar",
    "desraba": "desrabar",
    "desrabada": "desrabar",
    "desrabadas": "desrabar",
    "desrabado": "desrabar",
    "desrabados": "desrabar",
    "desrabai": "desrabar",
    "desrabais": "desrabar",
    "desrabam": "desrabar",
    "desrabamo": "desrabar",
    "desrabamos": "desrabar",
    "desrabando": "desrabar",
    "desrabara": "desrabar",
    "desrabaram": "desrabar",
    "desrabaras": "desrabar",
    "desrabarde": "desrabar",
    "desrabardes": "desrabar",
    "desrabare": "desrabar",
    "desrabarei": "desrabar",
    "desrabareis": "desrabar",
    "desrabarem": "desrabar",
    "desrabaremos": "desrabar",
    "desrabares": "desrabar",
    "desrabaria": "desrabar",
    "desrabariam": "desrabar",
    "desrabarias": "desrabar",
    "desrabarmo": "desrabar",
    "desrabarmos": "desrabar",
    "desrabará": "desrabar",
    "desrabarás": "desrabar",
    "desrabarão": "desrabar",
    "desrabaríamos": "desrabar",
    "desrabaríeis": "desrabar",
    "desrabas": "desrabar",
    "desrabasse": "desrabar",
    "desrabassem": "desrabar",
    "desrabasses": "desrabar",
    "desrabaste": "desrabar",
    "desrabastes": "desrabar",
    "desrabava": "desrabar",
    "desrabavam": "desrabar",
    "desrabavas": "desrabar",
    "desrabe": "desrabar",
    "desrabei": "desrabar",
    "desrabeis": "desrabar",
    "desrabem": "desrabar",
    "desrabemo": "desrabar",
    "desrabemos": "desrabar",
    "desrabes": "desrabar",
    "desrabo": "desrabar",
    "desrabou": "desrabar",
    "desrabá": "desrabar",
    "desrabámo": "desrabar",
    "desrabámos": "desrabar",
    "desrabáramo": "desrabar",
    "desrabáramos": "desrabar",
    "desrabárei": "desrabar",
    "desrabáreis": "desrabar",
    "desrabásseis": "desrabar",
    "desrabássemos": "desrabar",
    "desrabávamo": "desrabar",
    "desrabávamos": "desrabar",
    "desrabávei": "desrabar",
    "desrabáveis": "desrabar",
    "desraiga": "desraigar",
    "desraigada": "desraigar",
    "desraigadas": "desraigar",
    "desraigado": "desraigar",
    "desraigados": "desraigar",
    "desraigai": "desraigar",
    "desraigais": "desraigar",
    "desraigam": "desraigar",
    "desraigamo": "desraigar",
    "desraigamos": "desraigar",
    "desraigando": "desraigar",
    "desraigara": "desraigar",
    "desraigaram": "desraigar",
    "desraigaras": "desraigar",
    "desraigarde": "desraigar",
    "desraigardes": "desraigar",
    "desraigare": "desraigar",
    "desraigarei": "desraigar",
    "desraigareis": "desraigar",
    "desraigarem": "desraigar",
    "desraigaremos": "desraigar",
    "desraigares": "desraigar",
    "desraigaria": "desraigar",
    "desraigariam": "desraigar",
    "desraigarias": "desraigar",
    "desraigarmo": "desraigar",
    "desraigarmos": "desraigar",
    "desraigará": "desraigar",
    "desraigarás": "desraigar",
    "desraigarão": "desraigar",
    "desraigaríamos": "desraigar",
    "desraigaríeis": "desraigar",
    "desraigas": "desraigar",
    "desraigasse": "desraigar",
    "desraigassem": "desraigar",
    "desraigasses": "desraigar",
    "desraigaste": "desraigar",
    "desraigastes": "desraigar",
    "desraigava": "desraigar",
    "desraigavam": "desraigar",
    "desraigavas": "desraigar",
    "desraigo": "desraigar",
    "desraigou": "desraigar",
    "desraigue": "desraigar",
    "desraiguei": "desraigar",
    "desraigueis": "desraigar",
    "desraiguem": "desraigar",
    "desraiguemo": "desraigar",
    "desraiguemos": "desraigar",
    "desraigues": "desraigar",
    "desraigá": "desraigar",
    "desraigámo": "desraigar",
    "desraigámos": "desraigar",
    "desraigáramo": "desraigar",
    "desraigáramos": "desraigar",
    "desraigárei": "desraigar",
    "desraigáreis": "desraigar",
    "desraigásseis": "desraigar",
    "desraigássemos": "desraigar",
    "desraigávamo": "desraigar",
    "desraigávamos": "desraigar",
    "desraigávei": "desraigar",
    "desraigáveis": "desraigar",
    "desraiza": "desraizar",
    "desraizada": "desraizar",
    "desraizadas": "desraizar",
    "desraizado": "desraizar",
    "desraizados": "desraizar",
    "desraizai": "desraizar",
    "desraizais": "desraizar",
    "desraizam": "desraizar",
    "desraizamo": "desraizar",
    "desraizamos": "desraizar",
    "desraizando": "desraizar",
    "desraizara": "desraizar",
    "desraizaram": "desraizar",
    "desraizaras": "desraizar",
    "desraizarde": "desraizar",
    "desraizardes": "desraizar",
    "desraizare": "desraizar",
    "desraizarei": "desraizar",
    "desraizareis": "desraizar",
    "desraizarem": "desraizar",
    "desraizaremos": "desraizar",
    "desraizares": "desraizar",
    "desraizaria": "desraizar",
    "desraizariam": "desraizar",
    "desraizarias": "desraizar",
    "desraizarmo": "desraizar",
    "desraizarmos": "desraizar",
    "desraizará": "desraizar",
    "desraizarás": "desraizar",
    "desraizarão": "desraizar",
    "desraizaríamos": "desraizar",
    "desraizaríeis": "desraizar",
    "desraizas": "desraizar",
    "desraizasse": "desraizar",
    "desraizassem": "desraizar",
    "desraizasses": "desraizar",
    "desraizaste": "desraizar",
    "desraizastes": "desraizar",
    "desraizava": "desraizar",
    "desraizavam": "desraizar",
    "desraizavas": "desraizar",
    "desraize": "desraizar",
    "desraizei": "desraizar",
    "desraizeis": "desraizar",
    "desraizem": "desraizar",
    "desraizemo": "desraizar",
    "desraizemos": "desraizar",
    "desraizes": "desraizar",
    "desraizo": "desraizar",
    "desraizou": "desraizar",
    "desraizá": "desraizar",
    "desraizámo": "desraizar",
    "desraizámos": "desraizar",
    "desraizáramo": "desraizar",
    "desraizáramos": "desraizar",
    "desraizárei": "desraizar",
    "desraizáreis": "desraizar",
    "desraizásseis": "desraizar",
    "desraizássemos": "desraizar",
    "desraizávamo": "desraizar",
    "desraizávamos": "desraizar",
    "desraizávei": "desraizar",
    "desraizáveis": "desraizar",
    "desrama": "desramar",
    "desramada": "desramar",
    "desramadas": "desramar",
    "desramado": "desramar",
    "desramados": "desramar",
    "desramai": "desramar",
    "desramais": "desramar",
    "desramam": "desramar",
    "desramamo": "desramar",
    "desramamos": "desramar",
    "desramando": "desramar",
    "desramara": "desramar",
    "desramaram": "desramar",
    "desramaras": "desramar",
    "desramarde": "desramar",
    "desramardes": "desramar",
    "desramare": "desramar",
    "desramarei": "desramar",
    "desramareis": "desramar",
    "desramarem": "desramar",
    "desramaremos": "desramar",
    "desramares": "desramar",
    "desramaria": "desramar",
    "desramariam": "desramar",
    "desramarias": "desramar",
    "desramarmo": "desramar",
    "desramarmos": "desramar",
    "desramará": "desramar",
    "desramarás": "desramar",
    "desramarão": "desramar",
    "desramaríamos": "desramar",
    "desramaríeis": "desramar",
    "desramas": "desramar",
    "desramasse": "desramar",
    "desramassem": "desramar",
    "desramasses": "desramar",
    "desramaste": "desramar",
    "desramastes": "desramar",
    "desramava": "desramar",
    "desramavam": "desramar",
    "desramavas": "desramar",
    "desramações": "desramação",
    "desrame": "desramar",
    "desramei": "desramar",
    "desrameis": "desramar",
    "desramem": "desramar",
    "desramemo": "desramar",
    "desramemos": "desramar",
    "desrames": "desramar",
    "desramo": "desramar",
    "desramou": "desramar",
    "desramá": "desramar",
    "desramámo": "desramar",
    "desramámos": "desramar",
    "desramáramo": "desramar",
    "desramáramos": "desramar",
    "desramárei": "desramar",
    "desramáreis": "desramar",
    "desramásseis": "desramar",
    "desramássemos": "desramar",
    "desramávamo": "desramar",
    "desramávamos": "desramar",
    "desramávei": "desramar",
    "desramáveis": "desramar",
    "desrata": "desratar",
    "desratada": "desratar",
    "desratadas": "desratar",
    "desratado": "desratar",
    "desratados": "desratar",
    "desratai": "desratar",
    "desratais": "desratar",
    "desratam": "desratar",
    "desratamo": "desratar",
    "desratamos": "desratar",
    "desratando": "desratar",
    "desratara": "desratar",
    "desrataram": "desratar",
    "desrataras": "desratar",
    "desratarde": "desratar",
    "desratardes": "desratar",
    "desratare": "desratar",
    "desratarei": "desratar",
    "desratareis": "desratar",
    "desratarem": "desratar",
    "desrataremos": "desratar",
    "desratares": "desratar",
    "desrataria": "desratar",
    "desratariam": "desratar",
    "desratarias": "desratar",
    "desratarmo": "desratar",
    "desratarmos": "desratar",
    "desratará": "desratar",
    "desratarás": "desratar",
    "desratarão": "desratar",
    "desrataríamos": "desratar",
    "desrataríeis": "desratar",
    "desratas": "desratar",
    "desratasse": "desratar",
    "desratassem": "desratar",
    "desratasses": "desratar",
    "desrataste": "desratar",
    "desratastes": "desratar",
    "desratava": "desratar",
    "desratavam": "desratar",
    "desratavas": "desratar",
    "desrate": "desratar",
    "desratei": "desratar",
    "desrateis": "desratar",
    "desratem": "desratar",
    "desratemo": "desratar",
    "desratemos": "desratar",
    "desrates": "desratar",
    "desratiza": "desratizar",
    "desratizada": "desratizar",
    "desratizadas": "desratizar",
    "desratizado": "desratizar",
    "desratizados": "desratizar",
    "desratizai": "desratizar",
    "desratizais": "desratizar",
    "desratizam": "desratizar",
    "desratizamo": "desratizar",
    "desratizamos": "desratizar",
    "desratizando": "desratizar",
    "desratizara": "desratizar",
    "desratizaram": "desratizar",
    "desratizaras": "desratizar",
    "desratizarde": "desratizar",
    "desratizardes": "desratizar",
    "desratizare": "desratizar",
    "desratizarei": "desratizar",
    "desratizareis": "desratizar",
    "desratizarem": "desratizar",
    "desratizaremos": "desratizar",
    "desratizares": "desratizar",
    "desratizaria": "desratizar",
    "desratizariam": "desratizar",
    "desratizarias": "desratizar",
    "desratizarmo": "desratizar",
    "desratizarmos": "desratizar",
    "desratizará": "desratizar",
    "desratizarás": "desratizar",
    "desratizarão": "desratizar",
    "desratizaríamos": "desratizar",
    "desratizaríeis": "desratizar",
    "desratizas": "desratizar",
    "desratizasse": "desratizar",
    "desratizassem": "desratizar",
    "desratizasses": "desratizar",
    "desratizaste": "desratizar",
    "desratizastes": "desratizar",
    "desratizava": "desratizar",
    "desratizavam": "desratizar",
    "desratizavas": "desratizar",
    "desratizações": "desratização",
    "desratize": "desratizar",
    "desratizei": "desratizar",
    "desratizeis": "desratizar",
    "desratizem": "desratizar",
    "desratizemo": "desratizar",
    "desratizemos": "desratizar",
    "desratizes": "desratizar",
    "desratizo": "desratizar",
    "desratizou": "desratizar",
    "desratizá": "desratizar",
    "desratizámo": "desratizar",
    "desratizámos": "desratizar",
    "desratizáramo": "desratizar",
    "desratizáramos": "desratizar",
    "desratizárei": "desratizar",
    "desratizáreis": "desratizar",
    "desratizásseis": "desratizar",
    "desratizássemos": "desratizar",
    "desratizávamo": "desratizar",
    "desratizávamos": "desratizar",
    "desratizávei": "desratizar",
    "desratizáveis": "desratizar",
    "desrato": "desratar",
    "desratou": "desratar",
    "desratá": "desratar",
    "desratámo": "desratar",
    "desratámos": "desratar",
    "desratáramo": "desratar",
    "desratáramos": "desratar",
    "desratárei": "desratar",
    "desratáreis": "desratar",
    "desratásseis": "desratar",
    "desratássemos": "desratar",
    "desratávamo": "desratar",
    "desratávamos": "desratar",
    "desratávei": "desratar",
    "desratáveis": "desratar",
    "desrazões": "desrazão",
    "desrealizações": "desrealização",
    "desrebuçada": "desrebuçado",
    "desrebuçadas": "desrebuçado",
    "desrebuçados": "desrebuçado",
    "desrefolha": "desrefolhar",
    "desrefolhada": "desrefolhar",
    "desrefolhadas": "desrefolhar",
    "desrefolhado": "desrefolhar",
    "desrefolhados": "desrefolhar",
    "desrefolhai": "desrefolhar",
    "desrefolhais": "desrefolhar",
    "desrefolham": "desrefolhar",
    "desrefolhamo": "desrefolhar",
    "desrefolhamos": "desrefolhar",
    "desrefolhando": "desrefolhar",
    "desrefolhara": "desrefolhar",
    "desrefolharam": "desrefolhar",
    "desrefolharas": "desrefolhar",
    "desrefolharde": "desrefolhar",
    "desrefolhardes": "desrefolhar",
    "desrefolhare": "desrefolhar",
    "desrefolharei": "desrefolhar",
    "desrefolhareis": "desrefolhar",
    "desrefolharem": "desrefolhar",
    "desrefolharemos": "desrefolhar",
    "desrefolhares": "desrefolhar",
    "desrefolharia": "desrefolhar",
    "desrefolhariam": "desrefolhar",
    "desrefolharias": "desrefolhar",
    "desrefolharmo": "desrefolhar",
    "desrefolharmos": "desrefolhar",
    "desrefolhará": "desrefolhar",
    "desrefolharás": "desrefolhar",
    "desrefolharão": "desrefolhar",
    "desrefolharíamos": "desrefolhar",
    "desrefolharíeis": "desrefolhar",
    "desrefolhas": "desrefolhar",
    "desrefolhasse": "desrefolhar",
    "desrefolhassem": "desrefolhar",
    "desrefolhasses": "desrefolhar",
    "desrefolhaste": "desrefolhar",
    "desrefolhastes": "desrefolhar",
    "desrefolhava": "desrefolhar",
    "desrefolhavam": "desrefolhar",
    "desrefolhavas": "desrefolhar",
    "desrefolhe": "desrefolhar",
    "desrefolhei": "desrefolhar",
    "desrefolheis": "desrefolhar",
    "desrefolhem": "desrefolhar",
    "desrefolhemo": "desrefolhar",
    "desrefolhemos": "desrefolhar",
    "desrefolhes": "desrefolhar",
    "desrefolho": "desrefolhar",
    "desrefolhos": "desrefolho",
    "desrefolhou": "desrefolhar",
    "desrefolhá": "desrefolhar",
    "desrefolhámo": "desrefolhar",
    "desrefolhámos": "desrefolhar",
    "desrefolháramo": "desrefolhar",
    "desrefolháramos": "desrefolhar",
    "desrefolhárei": "desrefolhar",
    "desrefolháreis": "desrefolhar",
    "desrefolhásseis": "desrefolhar",
    "desrefolhássemos": "desrefolhar",
    "desrefolhávamo": "desrefolhar",
    "desrefolhávamos": "desrefolhar",
    "desrefolhávei": "desrefolhar",
    "desrefolháveis": "desrefolhar",
    "desregra": "desregrar",
    "desregrada": "desregrar",
    "desregradas": "desregrar",
    "desregrado": "desregrar",
    "desregrados": "desregrar",
    "desregradíssima": "desregrado",
    "desregradíssimas": "desregrado",
    "desregradíssimo": "desregrado",
    "desregradíssimos": "desregrado",
    "desregrai": "desregrar",
    "desregrais": "desregrar",
    "desregram": "desregrar",
    "desregramentos": "desregramento",
    "desregramo": "desregrar",
    "desregramos": "desregrar",
    "desregrando": "desregrar",
    "desregrara": "desregrar",
    "desregraram": "desregrar",
    "desregraras": "desregrar",
    "desregrarde": "desregrar",
    "desregrardes": "desregrar",
    "desregrare": "desregrar",
    "desregrarei": "desregrar",
    "desregrareis": "desregrar",
    "desregrarem": "desregrar",
    "desregraremos": "desregrar",
    "desregrares": "desregrar",
    "desregraria": "desregrar",
    "desregrariam": "desregrar",
    "desregrarias": "desregrar",
    "desregrarmo": "desregrar",
    "desregrarmos": "desregrar",
    "desregrará": "desregrar",
    "desregrarás": "desregrar",
    "desregrarão": "desregrar",
    "desregraríamos": "desregrar",
    "desregraríeis": "desregrar",
    "desregras": "desregrar",
    "desregrasse": "desregrar",
    "desregrassem": "desregrar",
    "desregrasses": "desregrar",
    "desregraste": "desregrar",
    "desregrastes": "desregrar",
    "desregrava": "desregrar",
    "desregravam": "desregrar",
    "desregravas": "desregrar",
    "desregre": "desregrar",
    "desregrei": "desregrar",
    "desregreis": "desregrar",
    "desregrem": "desregrar",
    "desregremo": "desregrar",
    "desregremos": "desregrar",
    "desregres": "desregrar",
    "desregro": "desregrar",
    "desregrou": "desregrar",
    "desregrá": "desregrar",
    "desregrámo": "desregrar",
    "desregrámos": "desregrar",
    "desregráramo": "desregrar",
    "desregráramos": "desregrar",
    "desregrárei": "desregrar",
    "desregráreis": "desregrar",
    "desregrásseis": "desregrar",
    "desregrássemos": "desregrar",
    "desregrávamo": "desregrar",
    "desregrávamos": "desregrar",
    "desregrávei": "desregrar",
    "desregráveis": "desregrar",
    "desregulada": "desregulado",
    "desreguladas": "desregulado",
    "desregulados": "desregulado",
    "desreguladíssima": "desregulado",
    "desreguladíssimas": "desregulado",
    "desreguladíssimo": "desregulado",
    "desreguladíssimos": "desregulado",
    "desregulamentações": "desregulamentação",
    "desregularizações": "desregularização",
    "desregulações": "desregulação",
    "desrelva": "desrelvar",
    "desrelvada": "desrelvar",
    "desrelvadas": "desrelvar",
    "desrelvado": "desrelvar",
    "desrelvados": "desrelvar",
    "desrelvai": "desrelvar",
    "desrelvais": "desrelvar",
    "desrelvam": "desrelvar",
    "desrelvamo": "desrelvar",
    "desrelvamos": "desrelvar",
    "desrelvando": "desrelvar",
    "desrelvara": "desrelvar",
    "desrelvaram": "desrelvar",
    "desrelvaras": "desrelvar",
    "desrelvarde": "desrelvar",
    "desrelvardes": "desrelvar",
    "desrelvare": "desrelvar",
    "desrelvarei": "desrelvar",
    "desrelvareis": "desrelvar",
    "desrelvarem": "desrelvar",
    "desrelvaremos": "desrelvar",
    "desrelvares": "desrelvar",
    "desrelvaria": "desrelvar",
    "desrelvariam": "desrelvar",
    "desrelvarias": "desrelvar",
    "desrelvarmo": "desrelvar",
    "desrelvarmos": "desrelvar",
    "desrelvará": "desrelvar",
    "desrelvarás": "desrelvar",
    "desrelvarão": "desrelvar",
    "desrelvaríamos": "desrelvar",
    "desrelvaríeis": "desrelvar",
    "desrelvas": "desrelvar",
    "desrelvasse": "desrelvar",
    "desrelvassem": "desrelvar",
    "desrelvasses": "desrelvar",
    "desrelvaste": "desrelvar",
    "desrelvastes": "desrelvar",
    "desrelvava": "desrelvar",
    "desrelvavam": "desrelvar",
    "desrelvavas": "desrelvar",
    "desrelve": "desrelvar",
    "desrelvei": "desrelvar",
    "desrelveis": "desrelvar",
    "desrelvem": "desrelvar",
    "desrelvemo": "desrelvar",
    "desrelvemos": "desrelvar",
    "desrelves": "desrelvar",
    "desrelvo": "desrelvar",
    "desrelvou": "desrelvar",
    "desrelvá": "desrelvar",
    "desrelvámo": "desrelvar",
    "desrelvámos": "desrelvar",
    "desrelváramo": "desrelvar",
    "desrelváramos": "desrelvar",
    "desrelvárei": "desrelvar",
    "desrelváreis": "desrelvar",
    "desrelvásseis": "desrelvar",
    "desrelvássemos": "desrelvar",
    "desrelvávamo": "desrelvar",
    "desrelvávamos": "desrelvar",
    "desrelvávei": "desrelvar",
    "desrelváveis": "desrelvar",
    "desremedeia": "desremediar",
    "desremedeiam": "desremediar",
    "desremedeias": "desremediar",
    "desremedeie": "desremediar",
    "desremedeiem": "desremediar",
    "desremedeies": "desremediar",
    "desremedeio": "desremediar",
    "desremediada": "desremediar",
    "desremediadas": "desremediar",
    "desremediado": "desremediar",
    "desremediados": "desremediar",
    "desremediai": "desremediar",
    "desremediais": "desremediar",
    "desremediamo": "desremediar",
    "desremediamos": "desremediar",
    "desremediando": "desremediar",
    "desremediara": "desremediar",
    "desremediaram": "desremediar",
    "desremediaras": "desremediar",
    "desremediarde": "desremediar",
    "desremediardes": "desremediar",
    "desremediare": "desremediar",
    "desremediarei": "desremediar",
    "desremediareis": "desremediar",
    "desremediarem": "desremediar",
    "desremediaremos": "desremediar",
    "desremediares": "desremediar",
    "desremediaria": "desremediar",
    "desremediariam": "desremediar",
    "desremediarias": "desremediar",
    "desremediarmo": "desremediar",
    "desremediarmos": "desremediar",
    "desremediará": "desremediar",
    "desremediarás": "desremediar",
    "desremediarão": "desremediar",
    "desremediaríamos": "desremediar",
    "desremediaríeis": "desremediar",
    "desremediasse": "desremediar",
    "desremediassem": "desremediar",
    "desremediasses": "desremediar",
    "desremediaste": "desremediar",
    "desremediastes": "desremediar",
    "desremediava": "desremediar",
    "desremediavam": "desremediar",
    "desremediavas": "desremediar",
    "desremediei": "desremediar",
    "desremedieis": "desremediar",
    "desremediemo": "desremediar",
    "desremediemos": "desremediar",
    "desremediou": "desremediar",
    "desremediá": "desremediar",
    "desremediámo": "desremediar",
    "desremediámos": "desremediar",
    "desremediáramo": "desremediar",
    "desremediáramos": "desremediar",
    "desremediárei": "desremediar",
    "desremediáreis": "desremediar",
    "desremediásseis": "desremediar",
    "desremediássemos": "desremediar",
    "desremediávamo": "desremediar",
    "desremediávamos": "desremediar",
    "desremediávei": "desremediar",
    "desremediáveis": "desremediar",
    "desrepublicaniza": "desrepublicanizar",
    "desrepublicanizada": "desrepublicanizar",
    "desrepublicanizadas": "desrepublicanizar",
    "desrepublicanizado": "desrepublicanizar",
    "desrepublicanizados": "desrepublicanizar",
    "desrepublicanizai": "desrepublicanizar",
    "desrepublicanizais": "desrepublicanizar",
    "desrepublicanizam": "desrepublicanizar",
    "desrepublicanizamo": "desrepublicanizar",
    "desrepublicanizamos": "desrepublicanizar",
    "desrepublicanizando": "desrepublicanizar",
    "desrepublicanizara": "desrepublicanizar",
    "desrepublicanizaram": "desrepublicanizar",
    "desrepublicanizaras": "desrepublicanizar",
    "desrepublicanizarde": "desrepublicanizar",
    "desrepublicanizardes": "desrepublicanizar",
    "desrepublicanizare": "desrepublicanizar",
    "desrepublicanizarei": "desrepublicanizar",
    "desrepublicanizareis": "desrepublicanizar",
    "desrepublicanizarem": "desrepublicanizar",
    "desrepublicanizaremos": "desrepublicanizar",
    "desrepublicanizares": "desrepublicanizar",
    "desrepublicanizaria": "desrepublicanizar",
    "desrepublicanizariam": "desrepublicanizar",
    "desrepublicanizarias": "desrepublicanizar",
    "desrepublicanizarmo": "desrepublicanizar",
    "desrepublicanizarmos": "desrepublicanizar",
    "desrepublicanizará": "desrepublicanizar",
    "desrepublicanizarás": "desrepublicanizar",
    "desrepublicanizarão": "desrepublicanizar",
    "desrepublicanizaríamos": "desrepublicanizar",
    "desrepublicanizaríeis": "desrepublicanizar",
    "desrepublicanizas": "desrepublicanizar",
    "desrepublicanizasse": "desrepublicanizar",
    "desrepublicanizassem": "desrepublicanizar",
    "desrepublicanizasses": "desrepublicanizar",
    "desrepublicanizaste": "desrepublicanizar",
    "desrepublicanizastes": "desrepublicanizar",
    "desrepublicanizava": "desrepublicanizar",
    "desrepublicanizavam": "desrepublicanizar",
    "desrepublicanizavas": "desrepublicanizar",
    "desrepublicanize": "desrepublicanizar",
    "desrepublicanizei": "desrepublicanizar",
    "desrepublicanizeis": "desrepublicanizar",
    "desrepublicanizem": "desrepublicanizar",
    "desrepublicanizemo": "desrepublicanizar",
    "desrepublicanizemos": "desrepublicanizar",
    "desrepublicanizes": "desrepublicanizar",
    "desrepublicanizo": "desrepublicanizar",
    "desrepublicanizou": "desrepublicanizar",
    "desrepublicanizá": "desrepublicanizar",
    "desrepublicanizámo": "desrepublicanizar",
    "desrepublicanizámos": "desrepublicanizar",
    "desrepublicanizáramo": "desrepublicanizar",
    "desrepublicanizáramos": "desrepublicanizar",
    "desrepublicanizárei": "desrepublicanizar",
    "desrepublicanizáreis": "desrepublicanizar",
    "desrepublicanizásseis": "desrepublicanizar",
    "desrepublicanizássemos": "desrepublicanizar",
    "desrepublicanizávamo": "desrepublicanizar",
    "desrepublicanizávamos": "desrepublicanizar",
    "desrepublicanizávei": "desrepublicanizar",
    "desrepublicanizáveis": "desrepublicanizar",
    "desrespeita": "desrespeitar",
    "desrespeitada": "desrespeitar",
    "desrespeitadas": "desrespeitar",
    "desrespeitado": "desrespeitar",
    "desrespeitadora": "desrespeitador",
    "desrespeitadoras": "desrespeitador",
    "desrespeitadores": "desrespeitador",
    "desrespeitados": "desrespeitar",
    "desrespeitai": "desrespeitar",
    "desrespeitais": "desrespeitar",
    "desrespeitam": "desrespeitar",
    "desrespeitamo": "desrespeitar",
    "desrespeitamos": "desrespeitar",
    "desrespeitando": "desrespeitar",
    "desrespeitara": "desrespeitar",
    "desrespeitaram": "desrespeitar",
    "desrespeitaras": "desrespeitar",
    "desrespeitarde": "desrespeitar",
    "desrespeitardes": "desrespeitar",
    "desrespeitare": "desrespeitar",
    "desrespeitarei": "desrespeitar",
    "desrespeitareis": "desrespeitar",
    "desrespeitarem": "desrespeitar",
    "desrespeitaremos": "desrespeitar",
    "desrespeitares": "desrespeitar",
    "desrespeitaria": "desrespeitar",
    "desrespeitariam": "desrespeitar",
    "desrespeitarias": "desrespeitar",
    "desrespeitarmo": "desrespeitar",
    "desrespeitarmos": "desrespeitar",
    "desrespeitará": "desrespeitar",
    "desrespeitarás": "desrespeitar",
    "desrespeitarão": "desrespeitar",
    "desrespeitaríamos": "desrespeitar",
    "desrespeitaríeis": "desrespeitar",
    "desrespeitas": "desrespeitar",
    "desrespeitasse": "desrespeitar",
    "desrespeitassem": "desrespeitar",
    "desrespeitasses": "desrespeitar",
    "desrespeitaste": "desrespeitar",
    "desrespeitastes": "desrespeitar",
    "desrespeitava": "desrespeitar",
    "desrespeitavam": "desrespeitar",
    "desrespeitavas": "desrespeitar",
    "desrespeite": "desrespeitar",
    "desrespeitei": "desrespeitar",
    "desrespeiteis": "desrespeitar",
    "desrespeitem": "desrespeitar",
    "desrespeitemo": "desrespeitar",
    "desrespeitemos": "desrespeitar",
    "desrespeites": "desrespeitar",
    "desrespeito": "desrespeitar",
    "desrespeitos": "desrespeito",
    "desrespeitosa": "desrespeitoso",
    "desrespeitosas": "desrespeitoso",
    "desrespeitosos": "desrespeitoso",
    "desrespeitou": "desrespeitar",
    "desrespeituosa": "desrespeituoso",
    "desrespeituosas": "desrespeituoso",
    "desrespeituosos": "desrespeituoso",
    "desrespeitá": "desrespeitar",
    "desrespeitámo": "desrespeitar",
    "desrespeitámos": "desrespeitar",
    "desrespeitáramo": "desrespeitar",
    "desrespeitáramos": "desrespeitar",
    "desrespeitárei": "desrespeitar",
    "desrespeitáreis": "desrespeitar",
    "desrespeitásseis": "desrespeitar",
    "desrespeitássemos": "desrespeitar",
    "desrespeitávamo": "desrespeitar",
    "desrespeitávamos": "desrespeitar",
    "desrespeitávei": "desrespeitar",
    "desrespeitáveis": "desrespeitar",
    "desresponsabiliza": "desresponsabilizar",
    "desresponsabilizada": "desresponsabilizar",
    "desresponsabilizadas": "desresponsabilizar",
    "desresponsabilizado": "desresponsabilizar",
    "desresponsabilizados": "desresponsabilizar",
    "desresponsabilizai": "desresponsabilizar",
    "desresponsabilizais": "desresponsabilizar",
    "desresponsabilizam": "desresponsabilizar",
    "desresponsabilizamo": "desresponsabilizar",
    "desresponsabilizamos": "desresponsabilizar",
    "desresponsabilizando": "desresponsabilizar",
    "desresponsabilizara": "desresponsabilizar",
    "desresponsabilizaram": "desresponsabilizar",
    "desresponsabilizaras": "desresponsabilizar",
    "desresponsabilizarde": "desresponsabilizar",
    "desresponsabilizardes": "desresponsabilizar",
    "desresponsabilizare": "desresponsabilizar",
    "desresponsabilizarei": "desresponsabilizar",
    "desresponsabilizareis": "desresponsabilizar",
    "desresponsabilizarem": "desresponsabilizar",
    "desresponsabilizaremos": "desresponsabilizar",
    "desresponsabilizares": "desresponsabilizar",
    "desresponsabilizaria": "desresponsabilizar",
    "desresponsabilizariam": "desresponsabilizar",
    "desresponsabilizarias": "desresponsabilizar",
    "desresponsabilizarmo": "desresponsabilizar",
    "desresponsabilizarmos": "desresponsabilizar",
    "desresponsabilizará": "desresponsabilizar",
    "desresponsabilizarás": "desresponsabilizar",
    "desresponsabilizarão": "desresponsabilizar",
    "desresponsabilizaríamos": "desresponsabilizar",
    "desresponsabilizaríeis": "desresponsabilizar",
    "desresponsabilizas": "desresponsabilizar",
    "desresponsabilizasse": "desresponsabilizar",
    "desresponsabilizassem": "desresponsabilizar",
    "desresponsabilizasses": "desresponsabilizar",
    "desresponsabilizaste": "desresponsabilizar",
    "desresponsabilizastes": "desresponsabilizar",
    "desresponsabilizava": "desresponsabilizar",
    "desresponsabilizavam": "desresponsabilizar",
    "desresponsabilizavas": "desresponsabilizar",
    "desresponsabilizações": "desresponsabilização",
    "desresponsabilize": "desresponsabilizar",
    "desresponsabilizei": "desresponsabilizar",
    "desresponsabilizeis": "desresponsabilizar",
    "desresponsabilizem": "desresponsabilizar",
    "desresponsabilizemo": "desresponsabilizar",
    "desresponsabilizemos": "desresponsabilizar",
    "desresponsabilizes": "desresponsabilizar",
    "desresponsabilizo": "desresponsabilizar",
    "desresponsabilizou": "desresponsabilizar",
    "desresponsabilizá": "desresponsabilizar",
    "desresponsabilizámo": "desresponsabilizar",
    "desresponsabilizámos": "desresponsabilizar",
    "desresponsabilizáramo": "desresponsabilizar",
    "desresponsabilizáramos": "desresponsabilizar",
    "desresponsabilizárei": "desresponsabilizar",
    "desresponsabilizáreis": "desresponsabilizar",
    "desresponsabilizásseis": "desresponsabilizar",
    "desresponsabilizássemos": "desresponsabilizar",
    "desresponsabilizávamo": "desresponsabilizar",
    "desresponsabilizávamos": "desresponsabilizar",
    "desresponsabilizávei": "desresponsabilizar",
    "desresponsabilizáveis": "desresponsabilizar",
    "desrevesta": "desrevestir",
    "desrevestais": "desrevestir",
    "desrevestam": "desrevestir",
    "desrevestamo": "desrevestir",
    "desrevestamos": "desrevestir",
    "desrevestas": "desrevestir",
    "desreveste": "desrevestir",
    "desrevestem": "desrevestir",
    "desrevestes": "desrevestir",
    "desrevesti": "desrevestir",
    "desrevestia": "desrevestir",
    "desrevestiam": "desrevestir",
    "desrevestias": "desrevestir",
    "desrevestida": "desrevestir",
    "desrevestidas": "desrevestir",
    "desrevestido": "desrevestir",
    "desrevestidos": "desrevestir",
    "desrevestimo": "desrevestir",
    "desrevestimos": "desrevestir",
    "desrevestindo": "desrevestir",
    "desrevestira": "desrevestir",
    "desrevestiram": "desrevestir",
    "desrevestiras": "desrevestir",
    "desrevestirde": "desrevestir",
    "desrevestirdes": "desrevestir",
    "desrevestire": "desrevestir",
    "desrevestirei": "desrevestir",
    "desrevestireis": "desrevestir",
    "desrevestirem": "desrevestir",
    "desrevestiremos": "desrevestir",
    "desrevestires": "desrevestir",
    "desrevestiria": "desrevestir",
    "desrevestiriam": "desrevestir",
    "desrevestirias": "desrevestir",
    "desrevestirmo": "desrevestir",
    "desrevestirmos": "desrevestir",
    "desrevestirá": "desrevestir",
    "desrevestirás": "desrevestir",
    "desrevestirão": "desrevestir",
    "desrevestiríamos": "desrevestir",
    "desrevestiríeis": "desrevestir",
    "desrevestis": "desrevestir",
    "desrevestisse": "desrevestir",
    "desrevestissem": "desrevestir",
    "desrevestisses": "desrevestir",
    "desrevestiste": "desrevestir",
    "desrevestistes": "desrevestir",
    "desrevestiu": "desrevestir",
    "desrevesto": "desrevestir",
    "desrevestíamo": "desrevestir",
    "desrevestíamos": "desrevestir",
    "desrevestíei": "desrevestir",
    "desrevestíeis": "desrevestir",
    "desrevestíramo": "desrevestir",
    "desrevestíramos": "desrevestir",
    "desrevestírei": "desrevestir",
    "desrevestíreis": "desrevestir",
    "desrevestísseis": "desrevestir",
    "desrevestíssemos": "desrevestir",
    "desrice": "desriçar",
    "desricei": "desriçar",
    "desriceis": "desriçar",
    "desricem": "desriçar",
    "desricemo": "desriçar",
    "desricemos": "desriçar",
    "desrices": "desriçar",
    "desrisca": "desriscar",
    "desriscada": "desriscar",
    "desriscadas": "desriscar",
    "desriscado": "desriscar",
    "desriscados": "desriscar",
    "desriscai": "desriscar",
    "desriscais": "desriscar",
    "desriscam": "desriscar",
    "desriscamo": "desriscar",
    "desriscamos": "desriscar",
    "desriscando": "desriscar",
    "desriscara": "desriscar",
    "desriscaram": "desriscar",
    "desriscaras": "desriscar",
    "desriscarde": "desriscar",
    "desriscardes": "desriscar",
    "desriscare": "desriscar",
    "desriscarei": "desriscar",
    "desriscareis": "desriscar",
    "desriscarem": "desriscar",
    "desriscaremos": "desriscar",
    "desriscares": "desriscar",
    "desriscaria": "desriscar",
    "desriscariam": "desriscar",
    "desriscarias": "desriscar",
    "desriscarmo": "desriscar",
    "desriscarmos": "desriscar",
    "desriscará": "desriscar",
    "desriscarás": "desriscar",
    "desriscarão": "desriscar",
    "desriscaríamos": "desriscar",
    "desriscaríeis": "desriscar",
    "desriscas": "desriscar",
    "desriscasse": "desriscar",
    "desriscassem": "desriscar",
    "desriscasses": "desriscar",
    "desriscaste": "desriscar",
    "desriscastes": "desriscar",
    "desriscava": "desriscar",
    "desriscavam": "desriscar",
    "desriscavas": "desriscar",
    "desrisco": "desriscar",
    "desriscou": "desriscar",
    "desriscá": "desriscar",
    "desriscámo": "desriscar",
    "desriscámos": "desriscar",
    "desriscáramo": "desriscar",
    "desriscáramos": "desriscar",
    "desriscárei": "desriscar",
    "desriscáreis": "desriscar",
    "desriscásseis": "desriscar",
    "desriscássemos": "desriscar",
    "desriscávamo": "desriscar",
    "desriscávamos": "desriscar",
    "desriscávei": "desriscar",
    "desriscáveis": "desriscar",
    "desrisos": "desriso",
    "desrisque": "desriscar",
    "desrisquei": "desriscar",
    "desrisqueis": "desriscar",
    "desrisquem": "desriscar",
    "desrisquemo": "desriscar",
    "desrisquemos": "desriscar",
    "desrisques": "desriscar",
    "desriça": "desriçar",
    "desriçada": "desriçar",
    "desriçadas": "desriçar",
    "desriçado": "desriçar",
    "desriçados": "desriçar",
    "desriçai": "desriçar",
    "desriçais": "desriçar",
    "desriçam": "desriçar",
    "desriçamo": "desriçar",
    "desriçamos": "desriçar",
    "desriçando": "desriçar",
    "desriçara": "desriçar",
    "desriçaram": "desriçar",
    "desriçaras": "desriçar",
    "desriçarde": "desriçar",
    "desriçardes": "desriçar",
    "desriçare": "desriçar",
    "desriçarei": "desriçar",
    "desriçareis": "desriçar",
    "desriçarem": "desriçar",
    "desriçaremos": "desriçar",
    "desriçares": "desriçar",
    "desriçaria": "desriçar",
    "desriçariam": "desriçar",
    "desriçarias": "desriçar",
    "desriçarmo": "desriçar",
    "desriçarmos": "desriçar",
    "desriçará": "desriçar",
    "desriçarás": "desriçar",
    "desriçarão": "desriçar",
    "desriçaríamos": "desriçar",
    "desriçaríeis": "desriçar",
    "desriças": "desriçar",
    "desriçasse": "desriçar",
    "desriçassem": "desriçar",
    "desriçasses": "desriçar",
    "desriçaste": "desriçar",
    "desriçastes": "desriçar",
    "desriçava": "desriçar",
    "desriçavam": "desriçar",
    "desriçavas": "desriçar",
    "desriço": "desriçar",
    "desriçou": "desriçar",
    "desriçá": "desriçar",
    "desriçámo": "desriçar",
    "desriçámos": "desriçar",
    "desriçáramo": "desriçar",
    "desriçáramos": "desriçar",
    "desriçárei": "desriçar",
    "desriçáreis": "desriçar",
    "desriçásseis": "desriçar",
    "desriçássemos": "desriçar",
    "desriçávamo": "desriçar",
    "desriçávamos": "desriçar",
    "desriçávei": "desriçar",
    "desriçáveis": "desriçar",
    "desrolha": "desrolhar",
    "desrolhada": "desrolhar",
    "desrolhadas": "desrolhar",
    "desrolhado": "desrolhar",
    "desrolhados": "desrolhar",
    "desrolhai": "desrolhar",
    "desrolhais": "desrolhar",
    "desrolham": "desrolhar",
    "desrolhamentos": "desrolhamento",
    "desrolhamo": "desrolhar",
    "desrolhamos": "desrolhar",
    "desrolhando": "desrolhar",
    "desrolhara": "desrolhar",
    "desrolharam": "desrolhar",
    "desrolharas": "desrolhar",
    "desrolharde": "desrolhar",
    "desrolhardes": "desrolhar",
    "desrolhare": "desrolhar",
    "desrolharei": "desrolhar",
    "desrolhareis": "desrolhar",
    "desrolharem": "desrolhar",
    "desrolharemos": "desrolhar",
    "desrolhares": "desrolhar",
    "desrolharia": "desrolhar",
    "desrolhariam": "desrolhar",
    "desrolharias": "desrolhar",
    "desrolharmo": "desrolhar",
    "desrolharmos": "desrolhar",
    "desrolhará": "desrolhar",
    "desrolharás": "desrolhar",
    "desrolharão": "desrolhar",
    "desrolharíamos": "desrolhar",
    "desrolharíeis": "desrolhar",
    "desrolhas": "desrolhar",
    "desrolhasse": "desrolhar",
    "desrolhassem": "desrolhar",
    "desrolhasses": "desrolhar",
    "desrolhaste": "desrolhar",
    "desrolhastes": "desrolhar",
    "desrolhava": "desrolhar",
    "desrolhavam": "desrolhar",
    "desrolhavas": "desrolhar",
    "desrolhe": "desrolhar",
    "desrolhei": "desrolhar",
    "desrolheis": "desrolhar",
    "desrolhem": "desrolhar",
    "desrolhemo": "desrolhar",
    "desrolhemos": "desrolhar",
    "desrolhes": "desrolhar",
    "desrolho": "desrolhar",
    "desrolhou": "desrolhar",
    "desrolhá": "desrolhar",
    "desrolhámo": "desrolhar",
    "desrolhámos": "desrolhar",
    "desrolháramo": "desrolhar",
    "desrolháramos": "desrolhar",
    "desrolhárei": "desrolhar",
    "desrolháreis": "desrolhar",
    "desrolhásseis": "desrolhar",
    "desrolhássemos": "desrolhar",
    "desrolhávamo": "desrolhar",
    "desrolhávamos": "desrolhar",
    "desrolhávei": "desrolhar",
    "desrolháveis": "desrolhar",
    "desrosca": "desroscar",
    "desroscada": "desroscar",
    "desroscadas": "desroscar",
    "desroscado": "desroscar",
    "desroscados": "desroscar",
    "desroscai": "desroscar",
    "desroscais": "desroscar",
    "desroscam": "desroscar",
    "desroscamo": "desroscar",
    "desroscamos": "desroscar",
    "desroscando": "desroscar",
    "desroscara": "desroscar",
    "desroscaram": "desroscar",
    "desroscaras": "desroscar",
    "desroscarde": "desroscar",
    "desroscardes": "desroscar",
    "desroscare": "desroscar",
    "desroscarei": "desroscar",
    "desroscareis": "desroscar",
    "desroscarem": "desroscar",
    "desroscaremos": "desroscar",
    "desroscares": "desroscar",
    "desroscaria": "desroscar",
    "desroscariam": "desroscar",
    "desroscarias": "desroscar",
    "desroscarmo": "desroscar",
    "desroscarmos": "desroscar",
    "desroscará": "desroscar",
    "desroscarás": "desroscar",
    "desroscarão": "desroscar",
    "desroscaríamos": "desroscar",
    "desroscaríeis": "desroscar",
    "desroscas": "desroscar",
    "desroscasse": "desroscar",
    "desroscassem": "desroscar",
    "desroscasses": "desroscar",
    "desroscaste": "desroscar",
    "desroscastes": "desroscar",
    "desroscava": "desroscar",
    "desroscavam": "desroscar",
    "desroscavas": "desroscar",
    "desrosco": "desroscar",
    "desroscou": "desroscar",
    "desroscá": "desroscar",
    "desroscámo": "desroscar",
    "desroscámos": "desroscar",
    "desroscáramo": "desroscar",
    "desroscáramos": "desroscar",
    "desroscárei": "desroscar",
    "desroscáreis": "desroscar",
    "desroscásseis": "desroscar",
    "desroscássemos": "desroscar",
    "desroscávamo": "desroscar",
    "desroscávamos": "desroscar",
    "desroscávei": "desroscar",
    "desroscáveis": "desroscar",
    "desrosque": "desroscar",
    "desrosquei": "desroscar",
    "desrosqueis": "desroscar",
    "desrosquem": "desroscar",
    "desrosquemo": "desroscar",
    "desrosquemos": "desroscar",
    "desrosques": "desroscar",
    "desruga": "desrugar",
    "desrugada": "desrugar",
    "desrugadas": "desrugar",
    "desrugado": "desrugar",
    "desrugados": "desrugar",
    "desrugai": "desrugar",
    "desrugais": "desrugar",
    "desrugam": "desrugar",
    "desrugamo": "desrugar",
    "desrugamos": "desrugar",
    "desrugando": "desrugar",
    "desrugara": "desrugar",
    "desrugaram": "desrugar",
    "desrugaras": "desrugar",
    "desrugarde": "desrugar",
    "desrugardes": "desrugar",
    "desrugare": "desrugar",
    "desrugarei": "desrugar",
    "desrugareis": "desrugar",
    "desrugarem": "desrugar",
    "desrugaremos": "desrugar",
    "desrugares": "desrugar",
    "desrugaria": "desrugar",
    "desrugariam": "desrugar",
    "desrugarias": "desrugar",
    "desrugarmo": "desrugar",
    "desrugarmos": "desrugar",
    "desrugará": "desrugar",
    "desrugarás": "desrugar",
    "desrugarão": "desrugar",
    "desrugaríamos": "desrugar",
    "desrugaríeis": "desrugar",
    "desrugas": "desrugar",
    "desrugasse": "desrugar",
    "desrugassem": "desrugar",
    "desrugasses": "desrugar",
    "desrugaste": "desrugar",
    "desrugastes": "desrugar",
    "desrugava": "desrugar",
    "desrugavam": "desrugar",
    "desrugavas": "desrugar",
    "desrugo": "desrugar",
    "desrugou": "desrugar",
    "desrugue": "desrugar",
    "desruguei": "desrugar",
    "desrugueis": "desrugar",
    "desruguem": "desrugar",
    "desruguemo": "desrugar",
    "desruguemos": "desrugar",
    "desrugues": "desrugar",
    "desrugá": "desrugar",
    "desrugámo": "desrugar",
    "desrugámos": "desrugar",
    "desrugáramo": "desrugar",
    "desrugáramos": "desrugar",
    "desrugárei": "desrugar",
    "desrugáreis": "desrugar",
    "desrugásseis": "desrugar",
    "desrugássemos": "desrugar",
    "desrugávamo": "desrugar",
    "desrugávamos": "desrugar",
    "desrugávei": "desrugar",
    "desrugáveis": "desrugar",
    "dessa": "dessar",
    "dessabe": "dessaber",
    "dessabei": "dessaber",
    "dessabeis": "dessaber",
    "dessabem": "dessaber",
    "dessabemo": "dessaber",
    "dessabemos": "dessaber",
    "dessabendo": "dessaber",
    "dessaberde": "dessaber",
    "dessaberdes": "dessaber",
    "dessabere": "dessaber",
    "dessaberei": "dessaber",
    "dessabereis": "dessaber",
    "dessaberem": "dessaber",
    "dessaberemos": "dessaber",
    "dessaberes": "dessaber",
    "dessaberia": "dessaber",
    "dessaberiam": "dessaber",
    "dessaberias": "dessaber",
    "dessabermo": "dessaber",
    "dessabermos": "dessaber",
    "dessaberá": "dessaber",
    "dessaberás": "dessaber",
    "dessaberão": "dessaber",
    "dessaberíamos": "dessaber",
    "dessaberíeis": "dessaber",
    "dessabes": "dessaber",
    "dessabia": "dessaber",
    "dessabiam": "dessaber",
    "dessabias": "dessaber",
    "dessabida": "dessaber",
    "dessabidas": "dessaber",
    "dessabido": "dessaber",
    "dessabidos": "dessaber",
    "dessabora": "dessaborar",
    "dessaborada": "dessaborar",
    "dessaboradas": "dessaborar",
    "dessaborado": "dessaborar",
    "dessaborados": "dessaborar",
    "dessaborai": "dessaborar",
    "dessaborais": "dessaborar",
    "dessaboram": "dessaborar",
    "dessaboramo": "dessaborar",
    "dessaboramos": "dessaborar",
    "dessaborando": "dessaborar",
    "dessaborara": "dessaborar",
    "dessaboraram": "dessaborar",
    "dessaboraras": "dessaborar",
    "dessaborarde": "dessaborar",
    "dessaborardes": "dessaborar",
    "dessaborare": "dessaborar",
    "dessaborarei": "dessaborar",
    "dessaborareis": "dessaborar",
    "dessaborarem": "dessaborar",
    "dessaboraremos": "dessaborar",
    "dessaborares": "dessaborar",
    "dessaboraria": "dessaborar",
    "dessaborariam": "dessaborar",
    "dessaborarias": "dessaborar",
    "dessaborarmo": "dessaborar",
    "dessaborarmos": "dessaborar",
    "dessaborará": "dessaborar",
    "dessaborarás": "dessaborar",
    "dessaborarão": "dessaborar",
    "dessaboraríamos": "dessaborar",
    "dessaboraríeis": "dessaborar",
    "dessaboras": "dessaborar",
    "dessaborasse": "dessaborar",
    "dessaborassem": "dessaborar",
    "dessaborasses": "dessaborar",
    "dessaboraste": "dessaborar",
    "dessaborastes": "dessaborar",
    "dessaborava": "dessaborar",
    "dessaboravam": "dessaborar",
    "dessaboravas": "dessaborar",
    "dessabore": "dessaborar",
    "dessaboreada": "dessaborear",
    "dessaboreadas": "dessaborear",
    "dessaboreado": "dessaborear",
    "dessaboreados": "dessaborear",
    "dessaboreai": "dessaborear",
    "dessaboreais": "dessaborear",
    "dessaboreamo": "dessaborear",
    "dessaboreamos": "dessaborear",
    "dessaboreando": "dessaborear",
    "dessaboreara": "dessaborear",
    "dessaborearam": "dessaborear",
    "dessaborearas": "dessaborear",
    "dessaborearde": "dessaborear",
    "dessaboreardes": "dessaborear",
    "dessaboreare": "dessaborear",
    "dessaborearei": "dessaborear",
    "dessaboreareis": "dessaborear",
    "dessaborearem": "dessaborear",
    "dessaborearemos": "dessaborear",
    "dessaboreares": "dessaborear",
    "dessaborearia": "dessaborear",
    "dessaboreariam": "dessaborear",
    "dessaborearias": "dessaborear",
    "dessaborearmo": "dessaborear",
    "dessaborearmos": "dessaborear",
    "dessaboreará": "dessaborear",
    "dessaborearás": "dessaborear",
    "dessaborearão": "dessaborear",
    "dessaborearíamos": "dessaborear",
    "dessaborearíeis": "dessaborear",
    "dessaboreasse": "dessaborear",
    "dessaboreassem": "dessaborear",
    "dessaboreasses": "dessaborear",
    "dessaboreaste": "dessaborear",
    "dessaboreastes": "dessaborear",
    "dessaboreava": "dessaborear",
    "dessaboreavam": "dessaborear",
    "dessaboreavas": "dessaborear",
    "dessaboreei": "dessaborear",
    "dessaboreeis": "dessaborear",
    "dessaboreemo": "dessaborear",
    "dessaboreemos": "dessaborear",
    "dessaborei": "dessaborar",
    "dessaboreia": "dessaborear",
    "dessaboreiam": "dessaborear",
    "dessaboreias": "dessaborear",
    "dessaboreie": "dessaborear",
    "dessaboreiem": "dessaborear",
    "dessaboreies": "dessaborear",
    "dessaboreio": "dessaborear",
    "dessaboreis": "dessaborar",
    "dessaborem": "dessaborar",
    "dessaboremo": "dessaborar",
    "dessaboremos": "dessaborar",
    "dessaboreou": "dessaborear",
    "dessabores": "dessaborar",
    "dessaboreá": "dessaborear",
    "dessaboreámo": "dessaborear",
    "dessaboreámos": "dessaborear",
    "dessaboreáramo": "dessaborear",
    "dessaboreáramos": "dessaborear",
    "dessaboreárei": "dessaborear",
    "dessaboreáreis": "dessaborear",
    "dessaboreásseis": "dessaborear",
    "dessaboreássemos": "dessaborear",
    "dessaboreávamo": "dessaborear",
    "dessaboreávamos": "dessaborear",
    "dessaboreávei": "dessaborear",
    "dessaboreáveis": "dessaborear",
    "dessaborida": "dessaborido",
    "dessaboridas": "dessaborido",
    "dessaboridos": "dessaborido",
    "dessaboro": "dessaborar",
    "dessaborosa": "dessaboroso",
    "dessaborosas": "dessaboroso",
    "dessaborosos": "dessaboroso",
    "dessaborou": "dessaborar",
    "dessaborá": "dessaborar",
    "dessaborámo": "dessaborar",
    "dessaborámos": "dessaborar",
    "dessaboráramo": "dessaborar",
    "dessaboráramos": "dessaborar",
    "dessaborárei": "dessaborar",
    "dessaboráreis": "dessaborar",
    "dessaborásseis": "dessaborar",
    "dessaborássemos": "dessaborar",
    "dessaborávamo": "dessaborar",
    "dessaborávamos": "dessaborar",
    "dessaborávei": "dessaborar",
    "dessaboráveis": "dessaborar",
    "dessaburra": "dessaburrar",
    "dessaburrada": "dessaburrar",
    "dessaburradas": "dessaburrar",
    "dessaburrado": "dessaburrar",
    "dessaburrados": "dessaburrar",
    "dessaburrai": "dessaburrar",
    "dessaburrais": "dessaburrar",
    "dessaburram": "dessaburrar",
    "dessaburramo": "dessaburrar",
    "dessaburramos": "dessaburrar",
    "dessaburrando": "dessaburrar",
    "dessaburrara": "dessaburrar",
    "dessaburraram": "dessaburrar",
    "dessaburraras": "dessaburrar",
    "dessaburrarde": "dessaburrar",
    "dessaburrardes": "dessaburrar",
    "dessaburrare": "dessaburrar",
    "dessaburrarei": "dessaburrar",
    "dessaburrareis": "dessaburrar",
    "dessaburrarem": "dessaburrar",
    "dessaburraremos": "dessaburrar",
    "dessaburrares": "dessaburrar",
    "dessaburraria": "dessaburrar",
    "dessaburrariam": "dessaburrar",
    "dessaburrarias": "dessaburrar",
    "dessaburrarmo": "dessaburrar",
    "dessaburrarmos": "dessaburrar",
    "dessaburrará": "dessaburrar",
    "dessaburrarás": "dessaburrar",
    "dessaburrarão": "dessaburrar",
    "dessaburraríamos": "dessaburrar",
    "dessaburraríeis": "dessaburrar",
    "dessaburras": "dessaburrar",
    "dessaburrasse": "dessaburrar",
    "dessaburrassem": "dessaburrar",
    "dessaburrasses": "dessaburrar",
    "dessaburraste": "dessaburrar",
    "dessaburrastes": "dessaburrar",
    "dessaburrava": "dessaburrar",
    "dessaburravam": "dessaburrar",
    "dessaburravas": "dessaburrar",
    "dessaburre": "dessaburrar",
    "dessaburrei": "dessaburrar",
    "dessaburreis": "dessaburrar",
    "dessaburrem": "dessaburrar",
    "dessaburremo": "dessaburrar",
    "dessaburremos": "dessaburrar",
    "dessaburres": "dessaburrar",
    "dessaburro": "dessaburrar",
    "dessaburrou": "dessaburrar",
    "dessaburrá": "dessaburrar",
    "dessaburrámo": "dessaburrar",
    "dessaburrámos": "dessaburrar",
    "dessaburráramo": "dessaburrar",
    "dessaburráramos": "dessaburrar",
    "dessaburrárei": "dessaburrar",
    "dessaburráreis": "dessaburrar",
    "dessaburrásseis": "dessaburrar",
    "dessaburrássemos": "dessaburrar",
    "dessaburrávamo": "dessaburrar",
    "dessaburrávamos": "dessaburrar",
    "dessaburrávei": "dessaburrar",
    "dessaburráveis": "dessaburrar",
    "dessabê": "dessaber",
    "dessabíamo": "dessaber",
    "dessabíamos": "dessaber",
    "dessabíei": "dessaber",
    "dessabíeis": "dessaber",
    "dessacraliza": "dessacralizar",
    "dessacralizada": "dessacralizar",
    "dessacralizadas": "dessacralizar",
    "dessacralizado": "dessacralizar",
    "dessacralizados": "dessacralizar",
    "dessacralizai": "dessacralizar",
    "dessacralizais": "dessacralizar",
    "dessacralizam": "dessacralizar",
    "dessacralizamo": "dessacralizar",
    "dessacralizamos": "dessacralizar",
    "dessacralizando": "dessacralizar",
    "dessacralizara": "dessacralizar",
    "dessacralizaram": "dessacralizar",
    "dessacralizaras": "dessacralizar",
    "dessacralizarde": "dessacralizar",
    "dessacralizardes": "dessacralizar",
    "dessacralizare": "dessacralizar",
    "dessacralizarei": "dessacralizar",
    "dessacralizareis": "dessacralizar",
    "dessacralizarem": "dessacralizar",
    "dessacralizaremos": "dessacralizar",
    "dessacralizares": "dessacralizar",
    "dessacralizaria": "dessacralizar",
    "dessacralizariam": "dessacralizar",
    "dessacralizarias": "dessacralizar",
    "dessacralizarmo": "dessacralizar",
    "dessacralizarmos": "dessacralizar",
    "dessacralizará": "dessacralizar",
    "dessacralizarás": "dessacralizar",
    "dessacralizarão": "dessacralizar",
    "dessacralizaríamos": "dessacralizar",
    "dessacralizaríeis": "dessacralizar",
    "dessacralizas": "dessacralizar",
    "dessacralizasse": "dessacralizar",
    "dessacralizassem": "dessacralizar",
    "dessacralizasses": "dessacralizar",
    "dessacralizaste": "dessacralizar",
    "dessacralizastes": "dessacralizar",
    "dessacralizava": "dessacralizar",
    "dessacralizavam": "dessacralizar",
    "dessacralizavas": "dessacralizar",
    "dessacralizações": "dessacralização",
    "dessacralize": "dessacralizar",
    "dessacralizei": "dessacralizar",
    "dessacralizeis": "dessacralizar",
    "dessacralizem": "dessacralizar",
    "dessacralizemo": "dessacralizar",
    "dessacralizemos": "dessacralizar",
    "dessacralizes": "dessacralizar",
    "dessacralizo": "dessacralizar",
    "dessacralizou": "dessacralizar",
    "dessacralizá": "dessacralizar",
    "dessacralizámo": "dessacralizar",
    "dessacralizámos": "dessacralizar",
    "dessacralizáramo": "dessacralizar",
    "dessacralizáramos": "dessacralizar",
    "dessacralizárei": "dessacralizar",
    "dessacralizáreis": "dessacralizar",
    "dessacralizásseis": "dessacralizar",
    "dessacralizássemos": "dessacralizar",
    "dessacralizávamo": "dessacralizar",
    "dessacralizávamos": "dessacralizar",
    "dessacralizávei": "dessacralizar",
    "dessacralizáveis": "dessacralizar",
    "dessada": "dessar",
    "dessadas": "dessar",
    "dessado": "dessar",
    "dessados": "dessar",
    "dessagra": "dessagrar",
    "dessagrada": "dessagrar",
    "dessagradas": "dessagrar",
    "dessagrado": "dessagrar",
    "dessagrados": "dessagrar",
    "dessagrai": "dessagrar",
    "dessagrais": "dessagrar",
    "dessagram": "dessagrar",
    "dessagramo": "dessagrar",
    "dessagramos": "dessagrar",
    "dessagrando": "dessagrar",
    "dessagrara": "dessagrar",
    "dessagraram": "dessagrar",
    "dessagraras": "dessagrar",
    "dessagrarde": "dessagrar",
    "dessagrardes": "dessagrar",
    "dessagrare": "dessagrar",
    "dessagrarei": "dessagrar",
    "dessagrareis": "dessagrar",
    "dessagrarem": "dessagrar",
    "dessagraremos": "dessagrar",
    "dessagrares": "dessagrar",
    "dessagraria": "dessagrar",
    "dessagrariam": "dessagrar",
    "dessagrarias": "dessagrar",
    "dessagrarmo": "dessagrar",
    "dessagrarmos": "dessagrar",
    "dessagrará": "dessagrar",
    "dessagrarás": "dessagrar",
    "dessagrarão": "dessagrar",
    "dessagraríamos": "dessagrar",
    "dessagraríeis": "dessagrar",
    "dessagras": "dessagrar",
    "dessagrasse": "dessagrar",
    "dessagrassem": "dessagrar",
    "dessagrasses": "dessagrar",
    "dessagraste": "dessagrar",
    "dessagrastes": "dessagrar",
    "dessagrava": "dessagrar",
    "dessagravam": "dessagrar",
    "dessagravas": "dessagrar",
    "dessagre": "dessagrar",
    "dessagrei": "dessagrar",
    "dessagreis": "dessagrar",
    "dessagrem": "dessagrar",
    "dessagremo": "dessagrar",
    "dessagremos": "dessagrar",
    "dessagres": "dessagrar",
    "dessagro": "dessagrar",
    "dessagrou": "dessagrar",
    "dessagrá": "dessagrar",
    "dessagrámo": "dessagrar",
    "dessagrámos": "dessagrar",
    "dessagráramo": "dessagrar",
    "dessagráramos": "dessagrar",
    "dessagrárei": "dessagrar",
    "dessagráreis": "dessagrar",
    "dessagrásseis": "dessagrar",
    "dessagrássemos": "dessagrar",
    "dessagrávamo": "dessagrar",
    "dessagrávamos": "dessagrar",
    "dessagrávei": "dessagrar",
    "dessagráveis": "dessagrar",
    "dessai": "dessar",
    "dessaiba": "dessaber",
    "dessaibais": "dessaber",
    "dessaibam": "dessaber",
    "dessaibamo": "dessaber",
    "dessaibamos": "dessaber",
    "dessaibas": "dessaber",
    "dessaibei": "dessaber",
    "dessaibra": "dessaibrar",
    "dessaibrada": "dessaibrar",
    "dessaibradas": "dessaibrar",
    "dessaibrado": "dessaibrar",
    "dessaibrados": "dessaibrar",
    "dessaibrai": "dessaibrar",
    "dessaibrais": "dessaibrar",
    "dessaibram": "dessaibrar",
    "dessaibramo": "dessaibrar",
    "dessaibramos": "dessaibrar",
    "dessaibrando": "dessaibrar",
    "dessaibrara": "dessaibrar",
    "dessaibraram": "dessaibrar",
    "dessaibraras": "dessaibrar",
    "dessaibrarde": "dessaibrar",
    "dessaibrardes": "dessaibrar",
    "dessaibrare": "dessaibrar",
    "dessaibrarei": "dessaibrar",
    "dessaibrareis": "dessaibrar",
    "dessaibrarem": "dessaibrar",
    "dessaibraremos": "dessaibrar",
    "dessaibrares": "dessaibrar",
    "dessaibraria": "dessaibrar",
    "dessaibrariam": "dessaibrar",
    "dessaibrarias": "dessaibrar",
    "dessaibrarmo": "dessaibrar",
    "dessaibrarmos": "dessaibrar",
    "dessaibrará": "dessaibrar",
    "dessaibrarás": "dessaibrar",
    "dessaibrarão": "dessaibrar",
    "dessaibraríamos": "dessaibrar",
    "dessaibraríeis": "dessaibrar",
    "dessaibras": "dessaibrar",
    "dessaibrasse": "dessaibrar",
    "dessaibrassem": "dessaibrar",
    "dessaibrasses": "dessaibrar",
    "dessaibraste": "dessaibrar",
    "dessaibrastes": "dessaibrar",
    "dessaibrava": "dessaibrar",
    "dessaibravam": "dessaibrar",
    "dessaibravas": "dessaibrar",
    "dessaibre": "dessaibrar",
    "dessaibrei": "dessaibrar",
    "dessaibreis": "dessaibrar",
    "dessaibrem": "dessaibrar",
    "dessaibremo": "dessaibrar",
    "dessaibremos": "dessaibrar",
    "dessaibres": "dessaibrar",
    "dessaibro": "dessaibrar",
    "dessaibrou": "dessaibrar",
    "dessaibrá": "dessaibrar",
    "dessaibrámo": "dessaibrar",
    "dessaibrámos": "dessaibrar",
    "dessaibráramo": "dessaibrar",
    "dessaibráramos": "dessaibrar",
    "dessaibrárei": "dessaibrar",
    "dessaibráreis": "dessaibrar",
    "dessaibrásseis": "dessaibrar",
    "dessaibrássemos": "dessaibrar",
    "dessaibrávamo": "dessaibrar",
    "dessaibrávamos": "dessaibrar",
    "dessaibrávei": "dessaibrar",
    "dessaibráveis": "dessaibrar",
    "dessais": "dessar",
    "dessala": "dessalar",
    "dessalada": "dessalar",
    "dessaladas": "dessalar",
    "dessalado": "dessalar",
    "dessalados": "dessalar",
    "dessalai": "dessalar",
    "dessalais": "dessalar",
    "dessalam": "dessalar",
    "dessalamo": "dessalar",
    "dessalamos": "dessalar",
    "dessalando": "dessalar",
    "dessalara": "dessalar",
    "dessalaram": "dessalar",
    "dessalaras": "dessalar",
    "dessalarde": "dessalar",
    "dessalardes": "dessalar",
    "dessalare": "dessalar",
    "dessalarei": "dessalar",
    "dessalareis": "dessalar",
    "dessalarem": "dessalar",
    "dessalaremos": "dessalar",
    "dessalares": "dessalar",
    "dessalaria": "dessalar",
    "dessalariam": "dessalar",
    "dessalarias": "dessalar",
    "dessalarmo": "dessalar",
    "dessalarmos": "dessalar",
    "dessalará": "dessalar",
    "dessalarás": "dessalar",
    "dessalarão": "dessalar",
    "dessalaríamos": "dessalar",
    "dessalaríeis": "dessalar",
    "dessalas": "dessalar",
    "dessalasse": "dessalar",
    "dessalassem": "dessalar",
    "dessalasses": "dessalar",
    "dessalaste": "dessalar",
    "dessalastes": "dessalar",
    "dessalava": "dessalar",
    "dessalavam": "dessalar",
    "dessalavas": "dessalar",
    "dessale": "dessalar",
    "dessalei": "dessalar",
    "dessaleis": "dessalar",
    "dessalem": "dessalar",
    "dessalemo": "dessalar",
    "dessalemos": "dessalar",
    "dessales": "dessalar",
    "dessalga": "dessalgar",
    "dessalgada": "dessalgar",
    "dessalgadas": "dessalgar",
    "dessalgado": "dessalgar",
    "dessalgados": "dessalgar",
    "dessalgai": "dessalgar",
    "dessalgais": "dessalgar",
    "dessalgam": "dessalgar",
    "dessalgamentos": "dessalgamento",
    "dessalgamo": "dessalgar",
    "dessalgamos": "dessalgar",
    "dessalgando": "dessalgar",
    "dessalgara": "dessalgar",
    "dessalgaram": "dessalgar",
    "dessalgaras": "dessalgar",
    "dessalgarde": "dessalgar",
    "dessalgardes": "dessalgar",
    "dessalgare": "dessalgar",
    "dessalgarei": "dessalgar",
    "dessalgareis": "dessalgar",
    "dessalgarem": "dessalgar",
    "dessalgaremos": "dessalgar",
    "dessalgares": "dessalgar",
    "dessalgaria": "dessalgar",
    "dessalgariam": "dessalgar",
    "dessalgarias": "dessalgar",
    "dessalgarmo": "dessalgar",
    "dessalgarmos": "dessalgar",
    "dessalgará": "dessalgar",
    "dessalgarás": "dessalgar",
    "dessalgarão": "dessalgar",
    "dessalgaríamos": "dessalgar",
    "dessalgaríeis": "dessalgar",
    "dessalgas": "dessalgar",
    "dessalgasse": "dessalgar",
    "dessalgassem": "dessalgar",
    "dessalgasses": "dessalgar",
    "dessalgaste": "dessalgar",
    "dessalgastes": "dessalgar",
    "dessalgava": "dessalgar",
    "dessalgavam": "dessalgar",
    "dessalgavas": "dessalgar",
    "dessalgações": "dessalgação",
    "dessalgo": "dessalgar",
    "dessalgou": "dessalgar",
    "dessalgue": "dessalgar",
    "dessalguei": "dessalgar",
    "dessalgueis": "dessalgar",
    "dessalguem": "dessalgar",
    "dessalguemo": "dessalgar",
    "dessalguemos": "dessalgar",
    "dessalgues": "dessalgar",
    "dessalgá": "dessalgar",
    "dessalgámo": "dessalgar",
    "dessalgámos": "dessalgar",
    "dessalgáramo": "dessalgar",
    "dessalgáramos": "dessalgar",
    "dessalgárei": "dessalgar",
    "dessalgáreis": "dessalgar",
    "dessalgásseis": "dessalgar",
    "dessalgássemos": "dessalgar",
    "dessalgávamo": "dessalgar",
    "dessalgávamos": "dessalgar",
    "dessalgávei": "dessalgar",
    "dessalgáveis": "dessalgar",
    "dessalinizações": "dessalinização",
    "dessalo": "dessalar",
    "dessalou": "dessalar",
    "dessalá": "dessalar",
    "dessalámo": "dessalar",
    "dessalámos": "dessalar",
    "dessaláramo": "dessalar",
    "dessaláramos": "dessalar",
    "dessalárei": "dessalar",
    "dessaláreis": "dessalar",
    "dessalásseis": "dessalar",
    "dessalássemos": "dessalar",
    "dessalávamo": "dessalar",
    "dessalávamos": "dessalar",
    "dessalávei": "dessalar",
    "dessaláveis": "dessalar",
    "dessam": "dessar",
    "dessamo": "dessar",
    "dessamos": "dessar",
    "dessando": "dessar",
    "dessangra": "dessangrar",
    "dessangrada": "dessangrar",
    "dessangradas": "dessangrar",
    "dessangrado": "dessangrar",
    "dessangrados": "dessangrar",
    "dessangrai": "dessangrar",
    "dessangrais": "dessangrar",
    "dessangram": "dessangrar",
    "dessangramo": "dessangrar",
    "dessangramos": "dessangrar",
    "dessangrando": "dessangrar",
    "dessangrara": "dessangrar",
    "dessangraram": "dessangrar",
    "dessangraras": "dessangrar",
    "dessangrarde": "dessangrar",
    "dessangrardes": "dessangrar",
    "dessangrare": "dessangrar",
    "dessangrarei": "dessangrar",
    "dessangrareis": "dessangrar",
    "dessangrarem": "dessangrar",
    "dessangraremos": "dessangrar",
    "dessangrares": "dessangrar",
    "dessangraria": "dessangrar",
    "dessangrariam": "dessangrar",
    "dessangrarias": "dessangrar",
    "dessangrarmo": "dessangrar",
    "dessangrarmos": "dessangrar",
    "dessangrará": "dessangrar",
    "dessangrarás": "dessangrar",
    "dessangrarão": "dessangrar",
    "dessangraríamos": "dessangrar",
    "dessangraríeis": "dessangrar",
    "dessangras": "dessangrar",
    "dessangrasse": "dessangrar",
    "dessangrassem": "dessangrar",
    "dessangrasses": "dessangrar",
    "dessangraste": "dessangrar",
    "dessangrastes": "dessangrar",
    "dessangrava": "dessangrar",
    "dessangravam": "dessangrar",
    "dessangravas": "dessangrar",
    "dessangre": "dessangrar",
    "dessangrei": "dessangrar",
    "dessangreis": "dessangrar",
    "dessangrem": "dessangrar",
    "dessangremo": "dessangrar",
    "dessangremos": "dessangrar",
    "dessangres": "dessangrar",
    "dessangro": "dessangrar",
    "dessangrou": "dessangrar",
    "dessangrá": "dessangrar",
    "dessangrámo": "dessangrar",
    "dessangrámos": "dessangrar",
    "dessangráramo": "dessangrar",
    "dessangráramos": "dessangrar",
    "dessangrárei": "dessangrar",
    "dessangráreis": "dessangrar",
    "dessangrásseis": "dessangrar",
    "dessangrássemos": "dessangrar",
    "dessangrávamo": "dessangrar",
    "dessangrávamos": "dessangrar",
    "dessangrávei": "dessangrar",
    "dessangráveis": "dessangrar",
    "dessara": "dessar",
    "dessaram": "dessar",
    "dessaras": "dessar",
    "dessarde": "dessar",
    "dessardes": "dessar",
    "dessare": "dessar",
    "dessarei": "dessar",
    "dessareis": "dessar",
    "dessarem": "dessar",
    "dessaremos": "dessar",
    "dessares": "dessar",
    "dessaria": "dessar",
    "dessariam": "dessar",
    "dessarias": "dessar",
    "dessarmo": "dessar",
    "dessarmos": "dessar",
    "dessaroa": "dessaroar",
    "dessaroada": "dessaroar",
    "dessaroadas": "dessaroar",
    "dessaroado": "dessaroar",
    "dessaroados": "dessaroar",
    "dessaroai": "dessaroar",
    "dessaroais": "dessaroar",
    "dessaroam": "dessaroar",
    "dessaroamo": "dessaroar",
    "dessaroamos": "dessaroar",
    "dessaroando": "dessaroar",
    "dessaroara": "dessaroar",
    "dessaroaram": "dessaroar",
    "dessaroaras": "dessaroar",
    "dessaroarde": "dessaroar",
    "dessaroardes": "dessaroar",
    "dessaroare": "dessaroar",
    "dessaroarei": "dessaroar",
    "dessaroareis": "dessaroar",
    "dessaroarem": "dessaroar",
    "dessaroaremos": "dessaroar",
    "dessaroares": "dessaroar",
    "dessaroaria": "dessaroar",
    "dessaroariam": "dessaroar",
    "dessaroarias": "dessaroar",
    "dessaroarmo": "dessaroar",
    "dessaroarmos": "dessaroar",
    "dessaroará": "dessaroar",
    "dessaroarás": "dessaroar",
    "dessaroarão": "dessaroar",
    "dessaroaríamos": "dessaroar",
    "dessaroaríeis": "dessaroar",
    "dessaroas": "dessaroar",
    "dessaroasse": "dessaroar",
    "dessaroassem": "dessaroar",
    "dessaroasses": "dessaroar",
    "dessaroaste": "dessaroar",
    "dessaroastes": "dessaroar",
    "dessaroava": "dessaroar",
    "dessaroavam": "dessaroar",
    "dessaroavas": "dessaroar",
    "dessaroe": "dessaroar",
    "dessaroei": "dessaroar",
    "dessaroeis": "dessaroar",
    "dessaroem": "dessaroar",
    "dessaroemo": "dessaroar",
    "dessaroemos": "dessaroar",
    "dessaroes": "dessaroar",
    "dessaroo": "dessaroar",
    "dessaroou": "dessaroar",
    "dessaroá": "dessaroar",
    "dessaroámo": "dessaroar",
    "dessaroámos": "dessaroar",
    "dessaroáramo": "dessaroar",
    "dessaroáramos": "dessaroar",
    "dessaroárei": "dessaroar",
    "dessaroáreis": "dessaroar",
    "dessaroásseis": "dessaroar",
    "dessaroássemos": "dessaroar",
    "dessaroávamo": "dessaroar",
    "dessaroávamos": "dessaroar",
    "dessaroávei": "dessaroar",
    "dessaroáveis": "dessaroar",
    "dessarroada": "dessarroado",
    "dessarroadas": "dessarroado",
    "dessarroados": "dessarroado",
    "dessará": "dessar",
    "dessarás": "dessar",
    "dessarão": "dessar",
    "dessaríamos": "dessar",
    "dessaríeis": "dessar",
    "dessas": "dessar",
    "dessasse": "dessar",
    "dessassem": "dessar",
    "dessasses": "dessar",
    "dessaste": "dessar",
    "dessastes": "dessar",
    "dessaudosa": "dessaudoso",
    "dessaudosas": "dessaudoso",
    "dessaudosos": "dessaudoso",
    "dessava": "dessar",
    "dessavam": "dessar",
    "dessavas": "dessar",
    "dessazona": "dessazonar",
    "dessazonada": "dessazonar",
    "dessazonadas": "dessazonar",
    "dessazonado": "dessazonar",
    "dessazonados": "dessazonar",
    "dessazonai": "dessazonar",
    "dessazonais": "dessazonar",
    "dessazonam": "dessazonar",
    "dessazonamo": "dessazonar",
    "dessazonamos": "dessazonar",
    "dessazonando": "dessazonar",
    "dessazonara": "dessazonar",
    "dessazonaram": "dessazonar",
    "dessazonaras": "dessazonar",
    "dessazonarde": "dessazonar",
    "dessazonardes": "dessazonar",
    "dessazonare": "dessazonar",
    "dessazonarei": "dessazonar",
    "dessazonareis": "dessazonar",
    "dessazonarem": "dessazonar",
    "dessazonaremos": "dessazonar",
    "dessazonares": "dessazonar",
    "dessazonaria": "dessazonar",
    "dessazonariam": "dessazonar",
    "dessazonarias": "dessazonar",
    "dessazonarmo": "dessazonar",
    "dessazonarmos": "dessazonar",
    "dessazonará": "dessazonar",
    "dessazonarás": "dessazonar",
    "dessazonarão": "dessazonar",
    "dessazonaríamos": "dessazonar",
    "dessazonaríeis": "dessazonar",
    "dessazonas": "dessazonar",
    "dessazonasse": "dessazonar",
    "dessazonassem": "dessazonar",
    "dessazonasses": "dessazonar",
    "dessazonaste": "dessazonar",
    "dessazonastes": "dessazonar",
    "dessazonava": "dessazonar",
    "dessazonavam": "dessazonar",
    "dessazonavas": "dessazonar",
    "dessazone": "dessazonar",
    "dessazonei": "dessazonar",
    "dessazoneis": "dessazonar",
    "dessazonem": "dessazonar",
    "dessazonemo": "dessazonar",
    "dessazonemos": "dessazonar",
    "dessazones": "dessazonar",
    "dessazono": "dessazonar",
    "dessazonou": "dessazonar",
    "dessazoná": "dessazonar",
    "dessazonámo": "dessazonar",
    "dessazonámos": "dessazonar",
    "dessazonáramo": "dessazonar",
    "dessazonáramos": "dessazonar",
    "dessazonárei": "dessazonar",
    "dessazonáreis": "dessazonar",
    "dessazonásseis": "dessazonar",
    "dessazonássemos": "dessazonar",
    "dessazonávamo": "dessazonar",
    "dessazonávamos": "dessazonar",
    "dessazonávei": "dessazonar",
    "dessazonáveis": "dessazonar",
    "desse": "dessar",
    "desseca": "dessecar",
    "dessecada": "dessecar",
    "dessecadas": "dessecar",
    "dessecado": "dessecar",
    "dessecadora": "dessecador",
    "dessecadoras": "dessecador",
    "dessecadores": "dessecador",
    "dessecados": "dessecar",
    "dessecagens": "dessecagem",
    "dessecai": "dessecar",
    "dessecais": "dessecar",
    "dessecam": "dessecar",
    "dessecamentos": "dessecamento",
    "dessecamo": "dessecar",
    "dessecamos": "dessecar",
    "dessecando": "dessecar",
    "dessecantes": "dessecante",
    "dessecara": "dessecar",
    "dessecaram": "dessecar",
    "dessecaras": "dessecar",
    "dessecarde": "dessecar",
    "dessecardes": "dessecar",
    "dessecare": "dessecar",
    "dessecarei": "dessecar",
    "dessecareis": "dessecar",
    "dessecarem": "dessecar",
    "dessecaremos": "dessecar",
    "dessecares": "dessecar",
    "dessecaria": "dessecar",
    "dessecariam": "dessecar",
    "dessecarias": "dessecar",
    "dessecarmo": "dessecar",
    "dessecarmos": "dessecar",
    "dessecará": "dessecar",
    "dessecarás": "dessecar",
    "dessecarão": "dessecar",
    "dessecaríamos": "dessecar",
    "dessecaríeis": "dessecar",
    "dessecas": "dessecar",
    "dessecasse": "dessecar",
    "dessecassem": "dessecar",
    "dessecasses": "dessecar",
    "dessecaste": "dessecar",
    "dessecastes": "dessecar",
    "dessecativa": "dessecativo",
    "dessecativas": "dessecativo",
    "dessecativos": "dessecativo",
    "dessecava": "dessecar",
    "dessecavam": "dessecar",
    "dessecavas": "dessecar",
    "dessecações": "dessecação",
    "desseco": "dessecar",
    "dessecou": "dessecar",
    "dessecá": "dessecar",
    "dessecámo": "dessecar",
    "dessecámos": "dessecar",
    "dessecáramo": "dessecar",
    "dessecáramos": "dessecar",
    "dessecárei": "dessecar",
    "dessecáreis": "dessecar",
    "dessecásseis": "dessecar",
    "dessecássemos": "dessecar",
    "dessecávamo": "dessecar",
    "dessecávamos": "dessecar",
    "dessecávei": "dessecar",
    "dessecáveis": "dessecar",
    "dessedenta": "dessedentar",
    "dessedentada": "dessedentar",
    "dessedentadas": "dessedentar",
    "dessedentado": "dessedentar",
    "dessedentados": "dessedentar",
    "dessedentai": "dessedentar",
    "dessedentais": "dessedentar",
    "dessedentam": "dessedentar",
    "dessedentamo": "dessedentar",
    "dessedentamos": "dessedentar",
    "dessedentando": "dessedentar",
    "dessedentara": "dessedentar",
    "dessedentaram": "dessedentar",
    "dessedentaras": "dessedentar",
    "dessedentarde": "dessedentar",
    "dessedentardes": "dessedentar",
    "dessedentare": "dessedentar",
    "dessedentarei": "dessedentar",
    "dessedentareis": "dessedentar",
    "dessedentarem": "dessedentar",
    "dessedentaremos": "dessedentar",
    "dessedentares": "dessedentar",
    "dessedentaria": "dessedentar",
    "dessedentariam": "dessedentar",
    "dessedentarias": "dessedentar",
    "dessedentarmo": "dessedentar",
    "dessedentarmos": "dessedentar",
    "dessedentará": "dessedentar",
    "dessedentarás": "dessedentar",
    "dessedentarão": "dessedentar",
    "dessedentaríamos": "dessedentar",
    "dessedentaríeis": "dessedentar",
    "dessedentas": "dessedentar",
    "dessedentasse": "dessedentar",
    "dessedentassem": "dessedentar",
    "dessedentasses": "dessedentar",
    "dessedentaste": "dessedentar",
    "dessedentastes": "dessedentar",
    "dessedentava": "dessedentar",
    "dessedentavam": "dessedentar",
    "dessedentavas": "dessedentar",
    "dessedente": "dessedentar",
    "dessedentei": "dessedentar",
    "dessedenteis": "dessedentar",
    "dessedentem": "dessedentar",
    "dessedentemo": "dessedentar",
    "dessedentemos": "dessedentar",
    "dessedentes": "dessedentar",
    "dessedento": "dessedentar",
    "dessedentou": "dessedentar",
    "dessedentá": "dessedentar",
    "dessedentámo": "dessedentar",
    "dessedentámos": "dessedentar",
    "dessedentáramo": "dessedentar",
    "dessedentáramos": "dessedentar",
    "dessedentárei": "dessedentar",
    "dessedentáreis": "dessedentar",
    "dessedentásseis": "dessedentar",
    "dessedentássemos": "dessedentar",
    "dessedentávamo": "dessedentar",
    "dessedentávamos": "dessedentar",
    "dessedentávei": "dessedentar",
    "dessedentáveis": "dessedentar",
    "dessegredos": "dessegredo",
    "dessegue": "desseguir",
    "desseguem": "desseguir",
    "dessegues": "desseguir",
    "dessegui": "desseguir",
    "desseguia": "desseguir",
    "desseguiam": "desseguir",
    "desseguias": "desseguir",
    "desseguida": "desseguir",
    "desseguidas": "desseguir",
    "desseguido": "desseguir",
    "desseguidos": "desseguir",
    "desseguimo": "desseguir",
    "desseguimos": "desseguir",
    "desseguindo": "desseguir",
    "desseguira": "desseguir",
    "desseguiram": "desseguir",
    "desseguiras": "desseguir",
    "desseguirde": "desseguir",
    "desseguirdes": "desseguir",
    "desseguire": "desseguir",
    "desseguirei": "desseguir",
    "desseguireis": "desseguir",
    "desseguirem": "desseguir",
    "desseguiremos": "desseguir",
    "desseguires": "desseguir",
    "desseguiria": "desseguir",
    "desseguiriam": "desseguir",
    "desseguirias": "desseguir",
    "desseguirmo": "desseguir",
    "desseguirmos": "desseguir",
    "desseguirá": "desseguir",
    "desseguirás": "desseguir",
    "desseguirão": "desseguir",
    "desseguiríamos": "desseguir",
    "desseguiríeis": "desseguir",
    "desseguis": "desseguir",
    "desseguisse": "desseguir",
    "desseguissem": "desseguir",
    "desseguisses": "desseguir",
    "desseguiste": "desseguir",
    "desseguistes": "desseguir",
    "desseguiu": "desseguir",
    "dessegura": "dessegurar",
    "dessegurada": "dessegurar",
    "desseguradas": "dessegurar",
    "dessegurado": "dessegurar",
    "dessegurados": "dessegurar",
    "dessegurai": "dessegurar",
    "dessegurais": "dessegurar",
    "desseguram": "dessegurar",
    "desseguramo": "dessegurar",
    "desseguramos": "dessegurar",
    "dessegurando": "dessegurar",
    "dessegurara": "dessegurar",
    "desseguraram": "dessegurar",
    "desseguraras": "dessegurar",
    "dessegurarde": "dessegurar",
    "dessegurardes": "dessegurar",
    "dessegurare": "dessegurar",
    "dessegurarei": "dessegurar",
    "dessegurareis": "dessegurar",
    "dessegurarem": "dessegurar",
    "desseguraremos": "dessegurar",
    "dessegurares": "dessegurar",
    "desseguraria": "dessegurar",
    "dessegurariam": "dessegurar",
    "dessegurarias": "dessegurar",
    "dessegurarmo": "dessegurar",
    "dessegurarmos": "dessegurar",
    "dessegurará": "dessegurar",
    "dessegurarás": "dessegurar",
    "dessegurarão": "dessegurar",
    "desseguraríamos": "dessegurar",
    "desseguraríeis": "dessegurar",
    "desseguras": "dessegurar",
    "dessegurasse": "dessegurar",
    "dessegurassem": "dessegurar",
    "dessegurasses": "dessegurar",
    "desseguraste": "dessegurar",
    "dessegurastes": "dessegurar",
    "dessegurava": "dessegurar",
    "desseguravam": "dessegurar",
    "desseguravas": "dessegurar",
    "dessegure": "dessegurar",
    "dessegurei": "dessegurar",
    "dessegureis": "dessegurar",
    "dessegurem": "dessegurar",
    "desseguremo": "dessegurar",
    "desseguremos": "dessegurar",
    "dessegures": "dessegurar",
    "desseguro": "dessegurar",
    "dessegurou": "dessegurar",
    "dessegurá": "dessegurar",
    "dessegurámo": "dessegurar",
    "dessegurámos": "dessegurar",
    "desseguráramo": "dessegurar",
    "desseguráramos": "dessegurar",
    "dessegurárei": "dessegurar",
    "desseguráreis": "dessegurar",
    "dessegurásseis": "dessegurar",
    "dessegurássemos": "dessegurar",
    "dessegurávamo": "dessegurar",
    "dessegurávamos": "dessegurar",
    "dessegurávei": "dessegurar",
    "desseguráveis": "dessegurar",
    "desseguíamo": "desseguir",
    "desseguíamos": "desseguir",
    "desseguíei": "desseguir",
    "desseguíeis": "desseguir",
    "desseguíramo": "desseguir",
    "desseguíramos": "desseguir",
    "desseguírei": "desseguir",
    "desseguíreis": "desseguir",
    "desseguísseis": "desseguir",
    "desseguíssemos": "desseguir",
    "dessei": "dessar",
    "desseis": "dessar",
    "desseiva": "desseivar",
    "desseivada": "desseivar",
    "desseivadas": "desseivar",
    "desseivado": "desseivar",
    "desseivados": "desseivar",
    "desseivagens": "desseivagem",
    "desseivai": "desseivar",
    "desseivais": "desseivar",
    "desseivam": "desseivar",
    "desseivamo": "desseivar",
    "desseivamos": "desseivar",
    "desseivando": "desseivar",
    "desseivara": "desseivar",
    "desseivaram": "desseivar",
    "desseivaras": "desseivar",
    "desseivarde": "desseivar",
    "desseivardes": "desseivar",
    "desseivare": "desseivar",
    "desseivarei": "desseivar",
    "desseivareis": "desseivar",
    "desseivarem": "desseivar",
    "desseivaremos": "desseivar",
    "desseivares": "desseivar",
    "desseivaria": "desseivar",
    "desseivariam": "desseivar",
    "desseivarias": "desseivar",
    "desseivarmo": "desseivar",
    "desseivarmos": "desseivar",
    "desseivará": "desseivar",
    "desseivarás": "desseivar",
    "desseivarão": "desseivar",
    "desseivaríamos": "desseivar",
    "desseivaríeis": "desseivar",
    "desseivas": "desseivar",
    "desseivasse": "desseivar",
    "desseivassem": "desseivar",
    "desseivasses": "desseivar",
    "desseivaste": "desseivar",
    "desseivastes": "desseivar",
    "desseivava": "desseivar",
    "desseivavam": "desseivar",
    "desseivavas": "desseivar",
    "desseive": "desseivar",
    "desseivei": "desseivar",
    "desseiveis": "desseivar",
    "desseivem": "desseivar",
    "desseivemo": "desseivar",
    "desseivemos": "desseivar",
    "desseives": "desseivar",
    "desseivo": "desseivar",
    "desseivou": "desseivar",
    "desseivá": "desseivar",
    "desseivámo": "desseivar",
    "desseivámos": "desseivar",
    "desseiváramo": "desseivar",
    "desseiváramos": "desseivar",
    "desseivárei": "desseivar",
    "desseiváreis": "desseivar",
    "desseivásseis": "desseivar",
    "desseivássemos": "desseivar",
    "desseivávamo": "desseivar",
    "desseivávamos": "desseivar",
    "desseivávei": "desseivar",
    "desseiváveis": "desseivar",
    "dessela": "desselar",
    "desselada": "desselar",
    "desseladas": "desselar",
    "desselado": "desselar",
    "desselados": "desselar",
    "desselai": "desselar",
    "desselais": "desselar",
    "desselam": "desselar",
    "desselamo": "desselar",
    "desselamos": "desselar",
    "desselando": "desselar",
    "desselara": "desselar",
    "desselaram": "desselar",
    "desselaras": "desselar",
    "desselarde": "desselar",
    "desselardes": "desselar",
    "desselare": "desselar",
    "desselarei": "desselar",
    "desselareis": "desselar",
    "desselarem": "desselar",
    "desselaremos": "desselar",
    "desselares": "desselar",
    "desselaria": "desselar",
    "desselariam": "desselar",
    "desselarias": "desselar",
    "desselarmo": "desselar",
    "desselarmos": "desselar",
    "desselará": "desselar",
    "desselarás": "desselar",
    "desselarão": "desselar",
    "desselaríamos": "desselar",
    "desselaríeis": "desselar",
    "desselas": "desselar",
    "desselasse": "desselar",
    "desselassem": "desselar",
    "desselasses": "desselar",
    "desselaste": "desselar",
    "desselastes": "desselar",
    "desselava": "desselar",
    "desselavam": "desselar",
    "desselavas": "desselar",
    "dessele": "desselar",
    "desselei": "desselar",
    "desseleis": "desselar",
    "desselem": "desselar",
    "desselemo": "desselar",
    "desselemos": "desselar",
    "desseles": "desselar",
    "desselo": "desselar",
    "desselou": "desselar",
    "desselá": "desselar",
    "desselámo": "desselar",
    "desselámos": "desselar",
    "desseláramo": "desselar",
    "desseláramos": "desselar",
    "desselárei": "desselar",
    "desseláreis": "desselar",
    "desselásseis": "desselar",
    "desselássemos": "desselar",
    "desselávamo": "desselar",
    "desselávamos": "desselar",
    "desselávei": "desselar",
    "desseláveis": "desselar",
    "dessem": "dessar",
    "dessemelha": "dessemelhar",
    "dessemelhada": "dessemelhar",
    "dessemelhadas": "dessemelhar",
    "dessemelhado": "dessemelhar",
    "dessemelhados": "dessemelhar",
    "dessemelhai": "dessemelhar",
    "dessemelhais": "dessemelhar",
    "dessemelham": "dessemelhar",
    "dessemelhamo": "dessemelhar",
    "dessemelhamos": "dessemelhar",
    "dessemelhando": "dessemelhar",
    "dessemelhantes": "dessemelhante",
    "dessemelhanças": "dessemelhança",
    "dessemelhara": "dessemelhar",
    "dessemelharam": "dessemelhar",
    "dessemelharas": "dessemelhar",
    "dessemelharde": "dessemelhar",
    "dessemelhardes": "dessemelhar",
    "dessemelhare": "dessemelhar",
    "dessemelharei": "dessemelhar",
    "dessemelhareis": "dessemelhar",
    "dessemelharem": "dessemelhar",
    "dessemelharemos": "dessemelhar",
    "dessemelhares": "dessemelhar",
    "dessemelharia": "dessemelhar",
    "dessemelhariam": "dessemelhar",
    "dessemelharias": "dessemelhar",
    "dessemelharmo": "dessemelhar",
    "dessemelharmos": "dessemelhar",
    "dessemelhará": "dessemelhar",
    "dessemelharás": "dessemelhar",
    "dessemelharão": "dessemelhar",
    "dessemelharíamos": "dessemelhar",
    "dessemelharíeis": "dessemelhar",
    "dessemelhas": "dessemelhar",
    "dessemelhasse": "dessemelhar",
    "dessemelhassem": "dessemelhar",
    "dessemelhasses": "dessemelhar",
    "dessemelhaste": "dessemelhar",
    "dessemelhastes": "dessemelhar",
    "dessemelhava": "dessemelhar",
    "dessemelhavam": "dessemelhar",
    "dessemelhavas": "dessemelhar",
    "dessemelhe": "dessemelhar",
    "dessemelhei": "dessemelhar",
    "dessemelheis": "dessemelhar",
    "dessemelhem": "dessemelhar",
    "dessemelhemo": "dessemelhar",
    "dessemelhemos": "dessemelhar",
    "dessemelhes": "dessemelhar",
    "dessemelho": "dessemelhar",
    "dessemelhou": "dessemelhar",
    "dessemelhá": "dessemelhar",
    "dessemelhámo": "dessemelhar",
    "dessemelhámos": "dessemelhar",
    "dessemelháramo": "dessemelhar",
    "dessemelháramos": "dessemelhar",
    "dessemelhárei": "dessemelhar",
    "dessemelháreis": "dessemelhar",
    "dessemelhásseis": "dessemelhar",
    "dessemelhássemos": "dessemelhar",
    "dessemelhávamo": "dessemelhar",
    "dessemelhávamos": "dessemelhar",
    "dessemelhávei": "dessemelhar",
    "dessemelháveis": "dessemelhar",
    "dessemo": "dessar",
    "dessemos": "dessar",
    "dessensibiliza": "dessensibilizar",
    "dessensibilizada": "dessensibilizar",
    "dessensibilizadas": "dessensibilizar",
    "dessensibilizado": "dessensibilizar",
    "dessensibilizadora": "dessensibilizador",
    "dessensibilizadoras": "dessensibilizador",
    "dessensibilizadores": "dessensibilizador",
    "dessensibilizados": "dessensibilizar",
    "dessensibilizai": "dessensibilizar",
    "dessensibilizais": "dessensibilizar",
    "dessensibilizam": "dessensibilizar",
    "dessensibilizamo": "dessensibilizar",
    "dessensibilizamos": "dessensibilizar",
    "dessensibilizando": "dessensibilizar",
    "dessensibilizantes": "dessensibilizante",
    "dessensibilizara": "dessensibilizar",
    "dessensibilizaram": "dessensibilizar",
    "dessensibilizaras": "dessensibilizar",
    "dessensibilizarde": "dessensibilizar",
    "dessensibilizardes": "dessensibilizar",
    "dessensibilizare": "dessensibilizar",
    "dessensibilizarei": "dessensibilizar",
    "dessensibilizareis": "dessensibilizar",
    "dessensibilizarem": "dessensibilizar",
    "dessensibilizaremos": "dessensibilizar",
    "dessensibilizares": "dessensibilizar",
    "dessensibilizaria": "dessensibilizar",
    "dessensibilizariam": "dessensibilizar",
    "dessensibilizarias": "dessensibilizar",
    "dessensibilizarmo": "dessensibilizar",
    "dessensibilizarmos": "dessensibilizar",
    "dessensibilizará": "dessensibilizar",
    "dessensibilizarás": "dessensibilizar",
    "dessensibilizarão": "dessensibilizar",
    "dessensibilizaríamos": "dessensibilizar",
    "dessensibilizaríeis": "dessensibilizar",
    "dessensibilizas": "dessensibilizar",
    "dessensibilizasse": "dessensibilizar",
    "dessensibilizassem": "dessensibilizar",
    "dessensibilizasses": "dessensibilizar",
    "dessensibilizaste": "dessensibilizar",
    "dessensibilizastes": "dessensibilizar",
    "dessensibilizava": "dessensibilizar",
    "dessensibilizavam": "dessensibilizar",
    "dessensibilizavas": "dessensibilizar",
    "dessensibilizações": "dessensibilização",
    "dessensibilize": "dessensibilizar",
    "dessensibilizei": "dessensibilizar",
    "dessensibilizeis": "dessensibilizar",
    "dessensibilizem": "dessensibilizar",
    "dessensibilizemo": "dessensibilizar",
    "dessensibilizemos": "dessensibilizar",
    "dessensibilizes": "dessensibilizar",
    "dessensibilizo": "dessensibilizar",
    "dessensibilizou": "dessensibilizar",
    "dessensibilizá": "dessensibilizar",
    "dessensibilizámo": "dessensibilizar",
    "dessensibilizámos": "dessensibilizar",
    "dessensibilizáramo": "dessensibilizar",
    "dessensibilizáramos": "dessensibilizar",
    "dessensibilizárei": "dessensibilizar",
    "dessensibilizáreis": "dessensibilizar",
    "dessensibilizásseis": "dessensibilizar",
    "dessensibilizássemos": "dessensibilizar",
    "dessensibilizávamo": "dessensibilizar",
    "dessensibilizávamos": "dessensibilizar",
    "dessensibilizávei": "dessensibilizar",
    "dessensibilizáveis": "dessensibilizar",
    "dessente": "dessentir",
    "dessentem": "dessentir",
    "dessentes": "dessentir",
    "dessenti": "dessentir",
    "dessentia": "dessentir",
    "dessentiam": "dessentir",
    "dessentias": "dessentir",
    "dessentida": "dessentir",
    "dessentidas": "dessentir",
    "dessentido": "dessentir",
    "dessentidos": "dessentir",
    "dessentimo": "dessentir",
    "dessentimos": "dessentir",
    "dessentindo": "dessentir",
    "dessentira": "dessentir",
    "dessentiram": "dessentir",
    "dessentiras": "dessentir",
    "dessentirde": "dessentir",
    "dessentirdes": "dessentir",
    "dessentire": "dessentir",
    "dessentirei": "dessentir",
    "dessentireis": "dessentir",
    "dessentirem": "dessentir",
    "dessentiremos": "dessentir",
    "dessentires": "dessentir",
    "dessentiria": "dessentir",
    "dessentiriam": "dessentir",
    "dessentirias": "dessentir",
    "dessentirmo": "dessentir",
    "dessentirmos": "dessentir",
    "dessentirá": "dessentir",
    "dessentirás": "dessentir",
    "dessentirão": "dessentir",
    "dessentiríamos": "dessentir",
    "dessentiríeis": "dessentir",
    "dessentis": "dessentir",
    "dessentisse": "dessentir",
    "dessentissem": "dessentir",
    "dessentisses": "dessentir",
    "dessentiste": "dessentir",
    "dessentistes": "dessentir",
    "dessentiu": "dessentir",
    "dessentíamo": "dessentir",
    "dessentíamos": "dessentir",
    "dessentíei": "dessentir",
    "dessentíeis": "dessentir",
    "dessentíramo": "dessentir",
    "dessentíramos": "dessentir",
    "dessentírei": "dessentir",
    "dessentíreis": "dessentir",
    "dessentísseis": "dessentir",
    "dessentíssemos": "dessentir",
    "dessepulta": "dessepultar",
    "dessepultada": "dessepultar",
    "dessepultadas": "dessepultar",
    "dessepultado": "dessepultar",
    "dessepultados": "dessepultar",
    "dessepultai": "dessepultar",
    "dessepultais": "dessepultar",
    "dessepultam": "dessepultar",
    "dessepultamo": "dessepultar",
    "dessepultamos": "dessepultar",
    "dessepultando": "dessepultar",
    "dessepultara": "dessepultar",
    "dessepultaram": "dessepultar",
    "dessepultaras": "dessepultar",
    "dessepultarde": "dessepultar",
    "dessepultardes": "dessepultar",
    "dessepultare": "dessepultar",
    "dessepultarei": "dessepultar",
    "dessepultareis": "dessepultar",
    "dessepultarem": "dessepultar",
    "dessepultaremos": "dessepultar",
    "dessepultares": "dessepultar",
    "dessepultaria": "dessepultar",
    "dessepultariam": "dessepultar",
    "dessepultarias": "dessepultar",
    "dessepultarmo": "dessepultar",
    "dessepultarmos": "dessepultar",
    "dessepultará": "dessepultar",
    "dessepultarás": "dessepultar",
    "dessepultarão": "dessepultar",
    "dessepultaríamos": "dessepultar",
    "dessepultaríeis": "dessepultar",
    "dessepultas": "dessepultar",
    "dessepultasse": "dessepultar",
    "dessepultassem": "dessepultar",
    "dessepultasses": "dessepultar",
    "dessepultaste": "dessepultar",
    "dessepultastes": "dessepultar",
    "dessepultava": "dessepultar",
    "dessepultavam": "dessepultar",
    "dessepultavas": "dessepultar",
    "dessepulte": "dessepultar",
    "dessepultei": "dessepultar",
    "dessepulteis": "dessepultar",
    "dessepultem": "dessepultar",
    "dessepultemo": "dessepultar",
    "dessepultemos": "dessepultar",
    "dessepultes": "dessepultar",
    "dessepulto": "dessepultar",
    "dessepultou": "dessepultar",
    "dessepultá": "dessepultar",
    "dessepultámo": "dessepultar",
    "dessepultámos": "dessepultar",
    "dessepultáramo": "dessepultar",
    "dessepultáramos": "dessepultar",
    "dessepultárei": "dessepultar",
    "dessepultáreis": "dessepultar",
    "dessepultásseis": "dessepultar",
    "dessepultássemos": "dessepultar",
    "dessepultávamo": "dessepultar",
    "dessepultávamos": "dessepultar",
    "dessepultávei": "dessepultar",
    "dessepultáveis": "dessepultar",
    "desseque": "dessecar",
    "dessequei": "dessecar",
    "dessequeis": "dessecar",
    "dessequem": "dessecar",
    "dessequemo": "dessecar",
    "dessequemos": "dessecar",
    "desseques": "dessecar",
    "desserve": "desservir",
    "desservem": "desservir",
    "desserves": "desservir",
    "desservi": "desservir",
    "desservia": "desservir",
    "desserviam": "desservir",
    "desservias": "desservir",
    "desservida": "desservir",
    "desservidas": "desservir",
    "desservido": "desservir",
    "desservidos": "desservir",
    "desservimo": "desservir",
    "desservimos": "desservir",
    "desservindo": "desservir",
    "desservira": "desservir",
    "desserviram": "desservir",
    "desserviras": "desservir",
    "desservirde": "desservir",
    "desservirdes": "desservir",
    "desservire": "desservir",
    "desservirei": "desservir",
    "desservireis": "desservir",
    "desservirem": "desservir",
    "desserviremos": "desservir",
    "desservires": "desservir",
    "desserviria": "desservir",
    "desserviriam": "desservir",
    "desservirias": "desservir",
    "desservirmo": "desservir",
    "desservirmos": "desservir",
    "desservirá": "desservir",
    "desservirás": "desservir",
    "desservirão": "desservir",
    "desserviríamos": "desservir",
    "desserviríeis": "desservir",
    "desservis": "desservir",
    "desservisse": "desservir",
    "desservissem": "desservir",
    "desservisses": "desservir",
    "desserviste": "desservir",
    "desservistes": "desservir",
    "desserviu": "desservir",
    "desserviçais": "desserviçal",
    "desserviços": "desserviço",
    "desservíamo": "desservir",
    "desservíamos": "desservir",
    "desservíei": "desservir",
    "desservíeis": "desservir",
    "desservíramo": "desservir",
    "desservíramos": "desservir",
    "desservírei": "desservir",
    "desservíreis": "desservir",
    "desservísseis": "desservir",
    "desservíssemos": "desservir",
    "desses": "dessar",
    "dessesma": "dessesmar",
    "dessesmada": "dessesmar",
    "dessesmadas": "dessesmar",
    "dessesmado": "dessesmar",
    "dessesmados": "dessesmar",
    "dessesmai": "dessesmar",
    "dessesmais": "dessesmar",
    "dessesmam": "dessesmar",
    "dessesmamo": "dessesmar",
    "dessesmamos": "dessesmar",
    "dessesmando": "dessesmar",
    "dessesmara": "dessesmar",
    "dessesmaram": "dessesmar",
    "dessesmaras": "dessesmar",
    "dessesmarde": "dessesmar",
    "dessesmardes": "dessesmar",
    "dessesmare": "dessesmar",
    "dessesmarei": "dessesmar",
    "dessesmareis": "dessesmar",
    "dessesmarem": "dessesmar",
    "dessesmaremos": "dessesmar",
    "dessesmares": "dessesmar",
    "dessesmaria": "dessesmar",
    "dessesmariam": "dessesmar",
    "dessesmarias": "dessesmar",
    "dessesmarmo": "dessesmar",
    "dessesmarmos": "dessesmar",
    "dessesmará": "dessesmar",
    "dessesmarás": "dessesmar",
    "dessesmarão": "dessesmar",
    "dessesmaríamos": "dessesmar",
    "dessesmaríeis": "dessesmar",
    "dessesmas": "dessesmar",
    "dessesmasse": "dessesmar",
    "dessesmassem": "dessesmar",
    "dessesmasses": "dessesmar",
    "dessesmaste": "dessesmar",
    "dessesmastes": "dessesmar",
    "dessesmava": "dessesmar",
    "dessesmavam": "dessesmar",
    "dessesmavas": "dessesmar",
    "dessesme": "dessesmar",
    "dessesmei": "dessesmar",
    "dessesmeis": "dessesmar",
    "dessesmem": "dessesmar",
    "dessesmemo": "dessesmar",
    "dessesmemos": "dessesmar",
    "dessesmes": "dessesmar",
    "dessesmo": "dessesmar",
    "dessesmou": "dessesmar",
    "dessesmá": "dessesmar",
    "dessesmámo": "dessesmar",
    "dessesmámos": "dessesmar",
    "dessesmáramo": "dessesmar",
    "dessesmáramos": "dessesmar",
    "dessesmárei": "dessesmar",
    "dessesmáreis": "dessesmar",
    "dessesmásseis": "dessesmar",
    "dessesmássemos": "dessesmar",
    "dessesmávamo": "dessesmar",
    "dessesmávamos": "dessesmar",
    "dessesmávei": "dessesmar",
    "dessesmáveis": "dessesmar",
    "dessexuada": "dessexuado",
    "dessexuadas": "dessexuado",
    "dessexuados": "dessexuado",
    "dessiga": "desseguir",
    "dessigais": "desseguir",
    "dessigam": "desseguir",
    "dessigamo": "desseguir",
    "dessigamos": "desseguir",
    "dessigas": "desseguir",
    "dessigo": "desseguir",
    "dessimetrias": "dessimetria",
    "dessinalada": "dessinalado",
    "dessinaladas": "dessinalado",
    "dessinalados": "dessinalado",
    "dessincroniza": "dessincronizar",
    "dessincronizada": "dessincronizar",
    "dessincronizadas": "dessincronizar",
    "dessincronizado": "dessincronizar",
    "dessincronizados": "dessincronizar",
    "dessincronizai": "dessincronizar",
    "dessincronizais": "dessincronizar",
    "dessincronizam": "dessincronizar",
    "dessincronizamo": "dessincronizar",
    "dessincronizamos": "dessincronizar",
    "dessincronizando": "dessincronizar",
    "dessincronizara": "dessincronizar",
    "dessincronizaram": "dessincronizar",
    "dessincronizaras": "dessincronizar",
    "dessincronizarde": "dessincronizar",
    "dessincronizardes": "dessincronizar",
    "dessincronizare": "dessincronizar",
    "dessincronizarei": "dessincronizar",
    "dessincronizareis": "dessincronizar",
    "dessincronizarem": "dessincronizar",
    "dessincronizaremos": "dessincronizar",
    "dessincronizares": "dessincronizar",
    "dessincronizaria": "dessincronizar",
    "dessincronizariam": "dessincronizar",
    "dessincronizarias": "dessincronizar",
    "dessincronizarmo": "dessincronizar",
    "dessincronizarmos": "dessincronizar",
    "dessincronizará": "dessincronizar",
    "dessincronizarás": "dessincronizar",
    "dessincronizarão": "dessincronizar",
    "dessincronizaríamos": "dessincronizar",
    "dessincronizaríeis": "dessincronizar",
    "dessincronizas": "dessincronizar",
    "dessincronizasse": "dessincronizar",
    "dessincronizassem": "dessincronizar",
    "dessincronizasses": "dessincronizar",
    "dessincronizaste": "dessincronizar",
    "dessincronizastes": "dessincronizar",
    "dessincronizava": "dessincronizar",
    "dessincronizavam": "dessincronizar",
    "dessincronizavas": "dessincronizar",
    "dessincronize": "dessincronizar",
    "dessincronizei": "dessincronizar",
    "dessincronizeis": "dessincronizar",
    "dessincronizem": "dessincronizar",
    "dessincronizemo": "dessincronizar",
    "dessincronizemos": "dessincronizar",
    "dessincronizes": "dessincronizar",
    "dessincronizo": "dessincronizar",
    "dessincronizou": "dessincronizar",
    "dessincronizá": "dessincronizar",
    "dessincronizámo": "dessincronizar",
    "dessincronizámos": "dessincronizar",
    "dessincronizáramo": "dessincronizar",
    "dessincronizáramos": "dessincronizar",
    "dessincronizárei": "dessincronizar",
    "dessincronizáreis": "dessincronizar",
    "dessincronizásseis": "dessincronizar",
    "dessincronizássemos": "dessincronizar",
    "dessincronizávamo": "dessincronizar",
    "dessincronizávamos": "dessincronizar",
    "dessincronizávei": "dessincronizar",
    "dessincronizáveis": "dessincronizar",
    "dessinta": "dessentir",
    "dessintais": "dessentir",
    "dessintam": "dessentir",
    "dessintamo": "dessentir",
    "dessintamos": "dessentir",
    "dessintas": "dessentir",
    "dessinto": "dessentir",
    "dessirva": "desservir",
    "dessirvais": "desservir",
    "dessirvam": "desservir",
    "dessirvamo": "desservir",
    "dessirvamos": "desservir",
    "dessirvas": "desservir",
    "dessirvo": "desservir",
    "dessisos": "dessiso",
    "dessistemas": "dessistema",
    "dessisuda": "dessisudo",
    "dessisudas": "dessisudo",
    "dessisudos": "dessisudo",
    "dessitia": "dessitiar",
    "dessitiada": "dessitiar",
    "dessitiadas": "dessitiar",
    "dessitiado": "dessitiar",
    "dessitiados": "dessitiar",
    "dessitiai": "dessitiar",
    "dessitiais": "dessitiar",
    "dessitiam": "dessitiar",
    "dessitiamo": "dessitiar",
    "dessitiamos": "dessitiar",
    "dessitiando": "dessitiar",
    "dessitiara": "dessitiar",
    "dessitiaram": "dessitiar",
    "dessitiaras": "dessitiar",
    "dessitiarde": "dessitiar",
    "dessitiardes": "dessitiar",
    "dessitiare": "dessitiar",
    "dessitiarei": "dessitiar",
    "dessitiareis": "dessitiar",
    "dessitiarem": "dessitiar",
    "dessitiaremos": "dessitiar",
    "dessitiares": "dessitiar",
    "dessitiaria": "dessitiar",
    "dessitiariam": "dessitiar",
    "dessitiarias": "dessitiar",
    "dessitiarmo": "dessitiar",
    "dessitiarmos": "dessitiar",
    "dessitiará": "dessitiar",
    "dessitiarás": "dessitiar",
    "dessitiarão": "dessitiar",
    "dessitiaríamos": "dessitiar",
    "dessitiaríeis": "dessitiar",
    "dessitias": "dessitiar",
    "dessitiasse": "dessitiar",
    "dessitiassem": "dessitiar",
    "dessitiasses": "dessitiar",
    "dessitiaste": "dessitiar",
    "dessitiastes": "dessitiar",
    "dessitiava": "dessitiar",
    "dessitiavam": "dessitiar",
    "dessitiavas": "dessitiar",
    "dessitie": "dessitiar",
    "dessitiei": "dessitiar",
    "dessitieis": "dessitiar",
    "dessitiem": "dessitiar",
    "dessitiemo": "dessitiar",
    "dessitiemos": "dessitiar",
    "dessities": "dessitiar",
    "dessitio": "dessitiar",
    "dessitiou": "dessitiar",
    "dessitiá": "dessitiar",
    "dessitiámo": "dessitiar",
    "dessitiámos": "dessitiar",
    "dessitiáramo": "dessitiar",
    "dessitiáramos": "dessitiar",
    "dessitiárei": "dessitiar",
    "dessitiáreis": "dessitiar",
    "dessitiásseis": "dessitiar",
    "dessitiássemos": "dessitiar",
    "dessitiávamo": "dessitiar",
    "dessitiávamos": "dessitiar",
    "dessitiávei": "dessitiar",
    "dessitiáveis": "dessitiar",
    "desso": "dessar",
    "dessoa": "dessoar",
    "dessoada": "dessoar",
    "dessoadas": "dessoar",
    "dessoado": "dessoar",
    "dessoados": "dessoar",
    "dessoai": "dessoar",
    "dessoais": "dessoar",
    "dessoam": "dessoar",
    "dessoamo": "dessoar",
    "dessoamos": "dessoar",
    "dessoando": "dessoar",
    "dessoantes": "dessoante",
    "dessoara": "dessoar",
    "dessoaram": "dessoar",
    "dessoaras": "dessoar",
    "dessoardes": "dessoar",
    "dessoarei": "dessoar",
    "dessoareis": "dessoar",
    "dessoarem": "dessoar",
    "dessoaremos": "dessoar",
    "dessoares": "dessoar",
    "dessoaria": "dessoar",
    "dessoariam": "dessoar",
    "dessoarias": "dessoar",
    "dessoarmo": "dessoar",
    "dessoarmos": "dessoar",
    "dessoará": "dessoar",
    "dessoarás": "dessoar",
    "dessoarão": "dessoar",
    "dessoaríamos": "dessoar",
    "dessoaríeis": "dessoar",
    "dessoas": "dessoar",
    "dessoasse": "dessoar",
    "dessoassem": "dessoar",
    "dessoasses": "dessoar",
    "dessoaste": "dessoar",
    "dessoastes": "dessoar",
    "dessoava": "dessoar",
    "dessoavam": "dessoar",
    "dessoavas": "dessoar",
    "dessobrace": "dessobraçar",
    "dessobracei": "dessobraçar",
    "dessobraceis": "dessobraçar",
    "dessobracem": "dessobraçar",
    "dessobracemo": "dessobraçar",
    "dessobracemos": "dessobraçar",
    "dessobraces": "dessobraçar",
    "dessobraça": "dessobraçar",
    "dessobraçada": "dessobraçar",
    "dessobraçadas": "dessobraçar",
    "dessobraçado": "dessobraçar",
    "dessobraçados": "dessobraçar",
    "dessobraçai": "dessobraçar",
    "dessobraçais": "dessobraçar",
    "dessobraçam": "dessobraçar",
    "dessobraçamo": "dessobraçar",
    "dessobraçamos": "dessobraçar",
    "dessobraçando": "dessobraçar",
    "dessobraçara": "dessobraçar",
    "dessobraçaram": "dessobraçar",
    "dessobraçaras": "dessobraçar",
    "dessobraçarde": "dessobraçar",
    "dessobraçardes": "dessobraçar",
    "dessobraçare": "dessobraçar",
    "dessobraçarei": "dessobraçar",
    "dessobraçareis": "dessobraçar",
    "dessobraçarem": "dessobraçar",
    "dessobraçaremos": "dessobraçar",
    "dessobraçares": "dessobraçar",
    "dessobraçaria": "dessobraçar",
    "dessobraçariam": "dessobraçar",
    "dessobraçarias": "dessobraçar",
    "dessobraçarmo": "dessobraçar",
    "dessobraçarmos": "dessobraçar",
    "dessobraçará": "dessobraçar",
    "dessobraçarás": "dessobraçar",
    "dessobraçarão": "dessobraçar",
    "dessobraçaríamos": "dessobraçar",
    "dessobraçaríeis": "dessobraçar",
    "dessobraças": "dessobraçar",
    "dessobraçasse": "dessobraçar",
    "dessobraçassem": "dessobraçar",
    "dessobraçasses": "dessobraçar",
    "dessobraçaste": "dessobraçar",
    "dessobraçastes": "dessobraçar",
    "dessobraçava": "dessobraçar",
    "dessobraçavam": "dessobraçar",
    "dessobraçavas": "dessobraçar",
    "dessobraço": "dessobraçar",
    "dessobraçou": "dessobraçar",
    "dessobraçá": "dessobraçar",
    "dessobraçámo": "dessobraçar",
    "dessobraçámos": "dessobraçar",
    "dessobraçáramo": "dessobraçar",
    "dessobraçáramos": "dessobraçar",
    "dessobraçárei": "dessobraçar",
    "dessobraçáreis": "dessobraçar",
    "dessobraçásseis": "dessobraçar",
    "dessobraçássemos": "dessobraçar",
    "dessobraçávamo": "dessobraçar",
    "dessobraçávamos": "dessobraçar",
    "dessobraçávei": "dessobraçar",
    "dessobraçáveis": "dessobraçar",
    "dessociáveis": "dessociável",
    "dessocorra": "dessocorrer",
    "dessocorrais": "dessocorrer",
    "dessocorram": "dessocorrer",
    "dessocorramo": "dessocorrer",
    "dessocorramos": "dessocorrer",
    "dessocorras": "dessocorrer",
    "dessocorre": "dessocorrer",
    "dessocorrei": "dessocorrer",
    "dessocorreis": "dessocorrer",
    "dessocorrem": "dessocorrer",
    "dessocorremo": "dessocorrer",
    "dessocorremos": "dessocorrer",
    "dessocorrendo": "dessocorrer",
    "dessocorrera": "dessocorrer",
    "dessocorreram": "dessocorrer",
    "dessocorreras": "dessocorrer",
    "dessocorrerde": "dessocorrer",
    "dessocorrerdes": "dessocorrer",
    "dessocorrere": "dessocorrer",
    "dessocorrerei": "dessocorrer",
    "dessocorrereis": "dessocorrer",
    "dessocorrerem": "dessocorrer",
    "dessocorreremos": "dessocorrer",
    "dessocorreres": "dessocorrer",
    "dessocorreria": "dessocorrer",
    "dessocorreriam": "dessocorrer",
    "dessocorrerias": "dessocorrer",
    "dessocorrermo": "dessocorrer",
    "dessocorrermos": "dessocorrer",
    "dessocorrerá": "dessocorrer",
    "dessocorrerás": "dessocorrer",
    "dessocorrerão": "dessocorrer",
    "dessocorreríamos": "dessocorrer",
    "dessocorreríeis": "dessocorrer",
    "dessocorres": "dessocorrer",
    "dessocorresse": "dessocorrer",
    "dessocorressem": "dessocorrer",
    "dessocorresses": "dessocorrer",
    "dessocorreste": "dessocorrer",
    "dessocorrestes": "dessocorrer",
    "dessocorreu": "dessocorrer",
    "dessocorri": "dessocorrer",
    "dessocorria": "dessocorrer",
    "dessocorriam": "dessocorrer",
    "dessocorrias": "dessocorrer",
    "dessocorrida": "dessocorrido",
    "dessocorridas": "dessocorrido",
    "dessocorrido": "dessocorrer",
    "dessocorridos": "dessocorrido",
    "dessocorro": "dessocorrer",
    "dessocorrê": "dessocorrer",
    "dessocorrêramo": "dessocorrer",
    "dessocorrêramos": "dessocorrer",
    "dessocorrêrei": "dessocorrer",
    "dessocorrêreis": "dessocorrer",
    "dessocorrêsseis": "dessocorrer",
    "dessocorrêssemos": "dessocorrer",
    "dessocorríamo": "dessocorrer",
    "dessocorríamos": "dessocorrer",
    "dessocorríei": "dessocorrer",
    "dessocorríeis": "dessocorrer",
    "dessoe": "dessoar",
    "dessoei": "dessoar",
    "dessoeis": "dessoar",
    "dessoem": "dessoar",
    "dessoemo": "dessoar",
    "dessoemos": "dessoar",
    "dessoes": "dessoar",
    "dessolada": "dessolado",
    "dessoladas": "dessolado",
    "dessolados": "dessolado",
    "dessoladíssima": "dessolado",
    "dessoladíssimas": "dessolado",
    "dessoladíssimo": "dessolado",
    "dessoladíssimos": "dessolado",
    "dessolda": "dessoldar",
    "dessoldada": "dessoldar",
    "dessoldadas": "dessoldar",
    "dessoldado": "dessoldar",
    "dessoldados": "dessoldar",
    "dessoldai": "dessoldar",
    "dessoldais": "dessoldar",
    "dessoldam": "dessoldar",
    "dessoldamo": "dessoldar",
    "dessoldamos": "dessoldar",
    "dessoldando": "dessoldar",
    "dessoldara": "dessoldar",
    "dessoldaram": "dessoldar",
    "dessoldaras": "dessoldar",
    "dessoldarde": "dessoldar",
    "dessoldardes": "dessoldar",
    "dessoldare": "dessoldar",
    "dessoldarei": "dessoldar",
    "dessoldareis": "dessoldar",
    "dessoldarem": "dessoldar",
    "dessoldaremos": "dessoldar",
    "dessoldares": "dessoldar",
    "dessoldaria": "dessoldar",
    "dessoldariam": "dessoldar",
    "dessoldarias": "dessoldar",
    "dessoldarmo": "dessoldar",
    "dessoldarmos": "dessoldar",
    "dessoldará": "dessoldar",
    "dessoldarás": "dessoldar",
    "dessoldarão": "dessoldar",
    "dessoldaríamos": "dessoldar",
    "dessoldaríeis": "dessoldar",
    "dessoldas": "dessoldar",
    "dessoldasse": "dessoldar",
    "dessoldassem": "dessoldar",
    "dessoldasses": "dessoldar",
    "dessoldaste": "dessoldar",
    "dessoldastes": "dessoldar",
    "dessoldava": "dessoldar",
    "dessoldavam": "dessoldar",
    "dessoldavas": "dessoldar",
    "dessolde": "dessoldar",
    "dessoldei": "dessoldar",
    "dessoldeis": "dessoldar",
    "dessoldem": "dessoldar",
    "dessoldemo": "dessoldar",
    "dessoldemos": "dessoldar",
    "dessoldes": "dessoldar",
    "dessoldo": "dessoldar",
    "dessoldou": "dessoldar",
    "dessoldá": "dessoldar",
    "dessoldámo": "dessoldar",
    "dessoldámos": "dessoldar",
    "dessoldáramo": "dessoldar",
    "dessoldáramos": "dessoldar",
    "dessoldárei": "dessoldar",
    "dessoldáreis": "dessoldar",
    "dessoldásseis": "dessoldar",
    "dessoldássemos": "dessoldar",
    "dessoldávamo": "dessoldar",
    "dessoldávamos": "dessoldar",
    "dessoldávei": "dessoldar",
    "dessoldáveis": "dessoldar",
    "dessolha": "dessolhar",
    "dessolhada": "dessolhar",
    "dessolhadas": "dessolhar",
    "dessolhado": "dessolhar",
    "dessolhados": "dessolhar",
    "dessolhai": "dessolhar",
    "dessolhais": "dessolhar",
    "dessolham": "dessolhar",
    "dessolhamo": "dessolhar",
    "dessolhamos": "dessolhar",
    "dessolhando": "dessolhar",
    "dessolhara": "dessolhar",
    "dessolharam": "dessolhar",
    "dessolharas": "dessolhar",
    "dessolharde": "dessolhar",
    "dessolhardes": "dessolhar",
    "dessolhare": "dessolhar",
    "dessolharei": "dessolhar",
    "dessolhareis": "dessolhar",
    "dessolharem": "dessolhar",
    "dessolharemos": "dessolhar",
    "dessolhares": "dessolhar",
    "dessolharia": "dessolhar",
    "dessolhariam": "dessolhar",
    "dessolharias": "dessolhar",
    "dessolharmo": "dessolhar",
    "dessolharmos": "dessolhar",
    "dessolhará": "dessolhar",
    "dessolharás": "dessolhar",
    "dessolharão": "dessolhar",
    "dessolharíamos": "dessolhar",
    "dessolharíeis": "dessolhar",
    "dessolhas": "dessolhar",
    "dessolhasse": "dessolhar",
    "dessolhassem": "dessolhar",
    "dessolhasses": "dessolhar",
    "dessolhaste": "dessolhar",
    "dessolhastes": "dessolhar",
    "dessolhava": "dessolhar",
    "dessolhavam": "dessolhar",
    "dessolhavas": "dessolhar",
    "dessolhe": "dessolhar",
    "dessolhei": "dessolhar",
    "dessolheis": "dessolhar",
    "dessolhem": "dessolhar",
    "dessolhemo": "dessolhar",
    "dessolhemos": "dessolhar",
    "dessolhes": "dessolhar",
    "dessolho": "dessolhar",
    "dessolhou": "dessolhar",
    "dessolhá": "dessolhar",
    "dessolhámo": "dessolhar",
    "dessolhámos": "dessolhar",
    "dessolháramo": "dessolhar",
    "dessolháramos": "dessolhar",
    "dessolhárei": "dessolhar",
    "dessolháreis": "dessolhar",
    "dessolhásseis": "dessolhar",
    "dessolhássemos": "dessolhar",
    "dessolhávamo": "dessolhar",
    "dessolhávamos": "dessolhar",
    "dessolhávei": "dessolhar",
    "dessolháveis": "dessolhar",
    "dessome": "dessumir",
    "dessomem": "dessumir",
    "dessomes": "dessumir",
    "dessoo": "dessoar",
    "dessoou": "dessoar",
    "dessora": "dessorar",
    "dessorada": "dessorar",
    "dessoradas": "dessorar",
    "dessorado": "dessorar",
    "dessorados": "dessorar",
    "dessorai": "dessorar",
    "dessorais": "dessorar",
    "dessoram": "dessorar",
    "dessoramentos": "dessoramento",
    "dessoramo": "dessorar",
    "dessoramos": "dessorar",
    "dessorando": "dessorar",
    "dessorara": "dessorar",
    "dessoraram": "dessorar",
    "dessoraras": "dessorar",
    "dessorarde": "dessorar",
    "dessorardes": "dessorar",
    "dessorare": "dessorar",
    "dessorarei": "dessorar",
    "dessorareis": "dessorar",
    "dessorarem": "dessorar",
    "dessoraremos": "dessorar",
    "dessorares": "dessorar",
    "dessoraria": "dessorar",
    "dessorariam": "dessorar",
    "dessorarias": "dessorar",
    "dessorarmo": "dessorar",
    "dessorarmos": "dessorar",
    "dessorará": "dessorar",
    "dessorarás": "dessorar",
    "dessorarão": "dessorar",
    "dessoraríamos": "dessorar",
    "dessoraríeis": "dessorar",
    "dessoras": "dessorar",
    "dessorasse": "dessorar",
    "dessorassem": "dessorar",
    "dessorasses": "dessorar",
    "dessoraste": "dessorar",
    "dessorastes": "dessorar",
    "dessorava": "dessorar",
    "dessoravam": "dessorar",
    "dessoravas": "dessorar",
    "dessore": "dessorar",
    "dessorei": "dessorar",
    "dessoreis": "dessorar",
    "dessorem": "dessorar",
    "dessoremo": "dessorar",
    "dessoremos": "dessorar",
    "dessores": "dessorar",
    "dessoro": "dessorar",
    "dessorou": "dessorar",
    "dessorá": "dessorar",
    "dessorámo": "dessorar",
    "dessorámos": "dessorar",
    "dessoráramo": "dessorar",
    "dessoráramos": "dessorar",
    "dessorárei": "dessorar",
    "dessoráreis": "dessorar",
    "dessorásseis": "dessorar",
    "dessorássemos": "dessorar",
    "dessorávamo": "dessorar",
    "dessorávamos": "dessorar",
    "dessorávei": "dessorar",
    "dessoráveis": "dessorar",
    "dessorções": "dessorção",
    "dessossega": "dessossegar",
    "dessossegada": "dessossegar",
    "dessossegadas": "dessossegar",
    "dessossegado": "dessossegar",
    "dessossegados": "dessossegar",
    "dessossegai": "dessossegar",
    "dessossegais": "dessossegar",
    "dessossegam": "dessossegar",
    "dessossegamo": "dessossegar",
    "dessossegamos": "dessossegar",
    "dessossegando": "dessossegar",
    "dessossegara": "dessossegar",
    "dessossegaram": "dessossegar",
    "dessossegaras": "dessossegar",
    "dessossegarde": "dessossegar",
    "dessossegardes": "dessossegar",
    "dessossegare": "dessossegar",
    "dessossegarei": "dessossegar",
    "dessossegareis": "dessossegar",
    "dessossegarem": "dessossegar",
    "dessossegaremos": "dessossegar",
    "dessossegares": "dessossegar",
    "dessossegaria": "dessossegar",
    "dessossegariam": "dessossegar",
    "dessossegarias": "dessossegar",
    "dessossegarmo": "dessossegar",
    "dessossegarmos": "dessossegar",
    "dessossegará": "dessossegar",
    "dessossegarás": "dessossegar",
    "dessossegarão": "dessossegar",
    "dessossegaríamos": "dessossegar",
    "dessossegaríeis": "dessossegar",
    "dessossegas": "dessossegar",
    "dessossegasse": "dessossegar",
    "dessossegassem": "dessossegar",
    "dessossegasses": "dessossegar",
    "dessossegaste": "dessossegar",
    "dessossegastes": "dessossegar",
    "dessossegava": "dessossegar",
    "dessossegavam": "dessossegar",
    "dessossegavas": "dessossegar",
    "dessossego": "dessossegar",
    "dessossegos": "dessossego",
    "dessossegou": "dessossegar",
    "dessossegue": "dessossegar",
    "dessosseguei": "dessossegar",
    "dessossegueis": "dessossegar",
    "dessosseguem": "dessossegar",
    "dessosseguemo": "dessossegar",
    "dessosseguemos": "dessossegar",
    "dessossegues": "dessossegar",
    "dessossegá": "dessossegar",
    "dessossegámo": "dessossegar",
    "dessossegámos": "dessossegar",
    "dessossegáramo": "dessossegar",
    "dessossegáramos": "dessossegar",
    "dessossegárei": "dessossegar",
    "dessossegáreis": "dessossegar",
    "dessossegásseis": "dessossegar",
    "dessossegássemos": "dessossegar",
    "dessossegávamo": "dessossegar",
    "dessossegávamos": "dessossegar",
    "dessossegávei": "dessossegar",
    "dessossegáveis": "dessossegar",
    "dessoterra": "dessoterrar",
    "dessoterrada": "dessoterrar",
    "dessoterradas": "dessoterrar",
    "dessoterrado": "dessoterrar",
    "dessoterrados": "dessoterrar",
    "dessoterrai": "dessoterrar",
    "dessoterrais": "dessoterrar",
    "dessoterram": "dessoterrar",
    "dessoterramo": "dessoterrar",
    "dessoterramos": "dessoterrar",
    "dessoterrando": "dessoterrar",
    "dessoterrara": "dessoterrar",
    "dessoterraram": "dessoterrar",
    "dessoterraras": "dessoterrar",
    "dessoterrarde": "dessoterrar",
    "dessoterrardes": "dessoterrar",
    "dessoterrare": "dessoterrar",
    "dessoterrarei": "dessoterrar",
    "dessoterrareis": "dessoterrar",
    "dessoterrarem": "dessoterrar",
    "dessoterraremos": "dessoterrar",
    "dessoterrares": "dessoterrar",
    "dessoterraria": "dessoterrar",
    "dessoterrariam": "dessoterrar",
    "dessoterrarias": "dessoterrar",
    "dessoterrarmo": "dessoterrar",
    "dessoterrarmos": "dessoterrar",
    "dessoterrará": "dessoterrar",
    "dessoterrarás": "dessoterrar",
    "dessoterrarão": "dessoterrar",
    "dessoterraríamos": "dessoterrar",
    "dessoterraríeis": "dessoterrar",
    "dessoterras": "dessoterrar",
    "dessoterrasse": "dessoterrar",
    "dessoterrassem": "dessoterrar",
    "dessoterrasses": "dessoterrar",
    "dessoterraste": "dessoterrar",
    "dessoterrastes": "dessoterrar",
    "dessoterrava": "dessoterrar",
    "dessoterravam": "dessoterrar",
    "dessoterravas": "dessoterrar",
    "dessoterre": "dessoterrar",
    "dessoterrei": "dessoterrar",
    "dessoterreis": "dessoterrar",
    "dessoterrem": "dessoterrar",
    "dessoterremo": "dessoterrar",
    "dessoterremos": "dessoterrar",
    "dessoterres": "dessoterrar",
    "dessoterro": "dessoterrar",
    "dessoterrou": "dessoterrar",
    "dessoterrá": "dessoterrar",
    "dessoterrámo": "dessoterrar",
    "dessoterrámos": "dessoterrar",
    "dessoterráramo": "dessoterrar",
    "dessoterráramos": "dessoterrar",
    "dessoterrárei": "dessoterrar",
    "dessoterráreis": "dessoterrar",
    "dessoterrásseis": "dessoterrar",
    "dessoterrássemos": "dessoterrar",
    "dessoterrávamo": "dessoterrar",
    "dessoterrávamos": "dessoterrar",
    "dessoterrávei": "dessoterrar",
    "dessoterráveis": "dessoterrar",
    "dessou": "dessar",
    "dessoube": "dessaber",
    "dessoubemo": "dessaber",
    "dessoubemos": "dessaber",
    "dessouber": "dessaber",
    "dessoubera": "dessaber",
    "dessouberam": "dessaber",
    "dessouberas": "dessaber",
    "dessouberdes": "dessaber",
    "dessouberem": "dessaber",
    "dessouberes": "dessaber",
    "dessoubermos": "dessaber",
    "dessoubesse": "dessaber",
    "dessoubessem": "dessaber",
    "dessoubesses": "dessaber",
    "dessoubeste": "dessaber",
    "dessoubestes": "dessaber",
    "dessoubéramo": "dessaber",
    "dessoubéramos": "dessaber",
    "dessoubérei": "dessaber",
    "dessoubéreis": "dessaber",
    "dessoubésseis": "dessaber",
    "dessoubéssemos": "dessaber",
    "dessoámo": "dessoar",
    "dessoámos": "dessoar",
    "dessoáramo": "dessoar",
    "dessoáramos": "dessoar",
    "dessoáreis": "dessoar",
    "dessoásseis": "dessoar",
    "dessoássemos": "dessoar",
    "dessoávamo": "dessoar",
    "dessoávamos": "dessoar",
    "dessoáveis": "dessoar",
    "dessoçobra": "obrar",
    "dessoçobrada": "dessoçobrar",
    "dessoçobradas": "dessoçobrar",
    "dessoçobrado": "dessoçobrar",
    "dessoçobrados": "dessoçobrar",
    "dessoçobrai": "dessoçobrar",
    "dessoçobrais": "dessoçobrar",
    "dessoçobram": "dessoçobrar",
    "dessoçobramo": "dessoçobrar",
    "dessoçobramos": "dessoçobrar",
    "dessoçobrando": "dessoçobrar",
    "dessoçobrar": "obrar",
    "dessoçobrara": "obrar",
    "dessoçobraram": "obrar",
    "dessoçobraras": "dessoçobrar",
    "dessoçobrarde": "dessoçobrar",
    "dessoçobrardes": "dessoçobrar",
    "dessoçobrare": "dessoçobrar",
    "dessoçobrarei": "dessoçobrar",
    "dessoçobrareis": "dessoçobrar",
    "dessoçobrarem": "obrar",
    "dessoçobraremos": "dessoçobrar",
    "dessoçobrares": "dessoçobrar",
    "dessoçobraria": "obrar",
    "dessoçobrariam": "dessoçobrar",
    "dessoçobrarias": "dessoçobrar",
    "dessoçobrarmo": "dessoçobrar",
    "dessoçobrarmos": "dessoçobrar",
    "dessoçobrará": "dessoçobrar",
    "dessoçobrarás": "dessoçobrar",
    "dessoçobrarão": "dessoçobrar",
    "dessoçobraríamos": "dessoçobrar",
    "dessoçobraríeis": "dessoçobrar",
    "dessoçobras": "dessoçobrar",
    "dessoçobrasse": "obrar",
    "dessoçobrassem": "dessoçobrar",
    "dessoçobrasses": "dessoçobrar",
    "dessoçobraste": "dessoçobrar",
    "dessoçobrastes": "dessoçobrar",
    "dessoçobrava": "obrar",
    "dessoçobravam": "dessoçobrar",
    "dessoçobravas": "dessoçobrar",
    "dessoçobre": "obrar",
    "dessoçobrei": "dessoçobrar",
    "dessoçobreis": "dessoçobrar",
    "dessoçobrem": "obrar",
    "dessoçobremo": "dessoçobrar",
    "dessoçobremos": "dessoçobrar",
    "dessoçobres": "dessoçobrar",
    "dessoçobro": "dessoçobrar",
    "dessoçobros": "dessoçobro",
    "dessoçobrou": "dessoçobrar",
    "dessoçobrá": "obrar",
    "dessoçobrámo": "dessoçobrar",
    "dessoçobrámos": "dessoçobrar",
    "dessoçobráramo": "dessoçobrar",
    "dessoçobráramos": "dessoçobrar",
    "dessoçobrárei": "dessoçobrar",
    "dessoçobráreis": "dessoçobrar",
    "dessoçobrásseis": "dessoçobrar",
    "dessoçobrássemos": "dessoçobrar",
    "dessoçobrávamo": "dessoçobrar",
    "dessoçobrávamos": "dessoçobrar",
    "dessoçobrávei": "dessoçobrar",
    "dessoçobráveis": "dessoçobrar",
    "dessua": "dessuar",
    "dessuada": "dessuar",
    "dessuadas": "dessuar",
    "dessuado": "dessuar",
    "dessuados": "dessuar",
    "dessuai": "dessuar",
    "dessuais": "dessuar",
    "dessuam": "dessuar",
    "dessuamo": "dessuar",
    "dessuamos": "dessuar",
    "dessuando": "dessuar",
    "dessuara": "dessuar",
    "dessuaram": "dessuar",
    "dessuaras": "dessuar",
    "dessuardes": "dessuar",
    "dessuarei": "dessuar",
    "dessuareis": "dessuar",
    "dessuarem": "dessuar",
    "dessuaremos": "dessuar",
    "dessuares": "dessuar",
    "dessuaria": "dessuar",
    "dessuariam": "dessuar",
    "dessuarias": "dessuar",
    "dessuarmo": "dessuar",
    "dessuarmos": "dessuar",
    "dessuará": "dessuar",
    "dessuarás": "dessuar",
    "dessuarão": "dessuar",
    "dessuaríamos": "dessuar",
    "dessuaríeis": "dessuar",
    "dessuas": "dessuar",
    "dessuasse": "dessuar",
    "dessuassem": "dessuar",
    "dessuasses": "dessuar",
    "dessuaste": "dessuar",
    "dessuastes": "dessuar",
    "dessuava": "dessuar",
    "dessuavam": "dessuar",
    "dessuavas": "dessuar",
    "dessubjuga": "dessubjugar",
    "dessubjugada": "dessubjugar",
    "dessubjugadas": "dessubjugar",
    "dessubjugado": "dessubjugar",
    "dessubjugados": "dessubjugar",
    "dessubjugai": "dessubjugar",
    "dessubjugais": "dessubjugar",
    "dessubjugam": "dessubjugar",
    "dessubjugamo": "dessubjugar",
    "dessubjugamos": "dessubjugar",
    "dessubjugando": "dessubjugar",
    "dessubjugara": "dessubjugar",
    "dessubjugaram": "dessubjugar",
    "dessubjugaras": "dessubjugar",
    "dessubjugarde": "dessubjugar",
    "dessubjugardes": "dessubjugar",
    "dessubjugare": "dessubjugar",
    "dessubjugarei": "dessubjugar",
    "dessubjugareis": "dessubjugar",
    "dessubjugarem": "dessubjugar",
    "dessubjugaremos": "dessubjugar",
    "dessubjugares": "dessubjugar",
    "dessubjugaria": "dessubjugar",
    "dessubjugariam": "dessubjugar",
    "dessubjugarias": "dessubjugar",
    "dessubjugarmo": "dessubjugar",
    "dessubjugarmos": "dessubjugar",
    "dessubjugará": "dessubjugar",
    "dessubjugarás": "dessubjugar",
    "dessubjugarão": "dessubjugar",
    "dessubjugaríamos": "dessubjugar",
    "dessubjugaríeis": "dessubjugar",
    "dessubjugas": "dessubjugar",
    "dessubjugasse": "dessubjugar",
    "dessubjugassem": "dessubjugar",
    "dessubjugasses": "dessubjugar",
    "dessubjugaste": "dessubjugar",
    "dessubjugastes": "dessubjugar",
    "dessubjugava": "dessubjugar",
    "dessubjugavam": "dessubjugar",
    "dessubjugavas": "dessubjugar",
    "dessubjugo": "dessubjugar",
    "dessubjugou": "dessubjugar",
    "dessubjugue": "dessubjugar",
    "dessubjuguei": "dessubjugar",
    "dessubjugueis": "dessubjugar",
    "dessubjuguem": "dessubjugar",
    "dessubjuguemo": "dessubjugar",
    "dessubjuguemos": "dessubjugar",
    "dessubjugues": "dessubjugar",
    "dessubjugá": "dessubjugar",
    "dessubjugámo": "dessubjugar",
    "dessubjugámos": "dessubjugar",
    "dessubjugáramo": "dessubjugar",
    "dessubjugáramos": "dessubjugar",
    "dessubjugárei": "dessubjugar",
    "dessubjugáreis": "dessubjugar",
    "dessubjugásseis": "dessubjugar",
    "dessubjugássemos": "dessubjugar",
    "dessubjugávamo": "dessubjugar",
    "dessubjugávamos": "dessubjugar",
    "dessubjugávei": "dessubjugar",
    "dessubjugáveis": "dessubjugar",
    "dessubstancia": "dessubstanciar",
    "dessubstanciada": "dessubstanciar",
    "dessubstanciadas": "dessubstanciar",
    "dessubstanciado": "dessubstanciar",
    "dessubstanciados": "dessubstanciar",
    "dessubstanciai": "dessubstanciar",
    "dessubstanciais": "dessubstanciar",
    "dessubstanciam": "dessubstanciar",
    "dessubstanciamo": "dessubstanciar",
    "dessubstanciamos": "dessubstanciar",
    "dessubstanciando": "dessubstanciar",
    "dessubstanciara": "dessubstanciar",
    "dessubstanciaram": "dessubstanciar",
    "dessubstanciaras": "dessubstanciar",
    "dessubstanciarde": "dessubstanciar",
    "dessubstanciardes": "dessubstanciar",
    "dessubstanciare": "dessubstanciar",
    "dessubstanciarei": "dessubstanciar",
    "dessubstanciareis": "dessubstanciar",
    "dessubstanciarem": "dessubstanciar",
    "dessubstanciaremos": "dessubstanciar",
    "dessubstanciares": "dessubstanciar",
    "dessubstanciaria": "dessubstanciar",
    "dessubstanciariam": "dessubstanciar",
    "dessubstanciarias": "dessubstanciar",
    "dessubstanciarmo": "dessubstanciar",
    "dessubstanciarmos": "dessubstanciar",
    "dessubstanciará": "dessubstanciar",
    "dessubstanciarás": "dessubstanciar",
    "dessubstanciarão": "dessubstanciar",
    "dessubstanciaríamos": "dessubstanciar",
    "dessubstanciaríeis": "dessubstanciar",
    "dessubstancias": "dessubstanciar",
    "dessubstanciasse": "dessubstanciar",
    "dessubstanciassem": "dessubstanciar",
    "dessubstanciasses": "dessubstanciar",
    "dessubstanciaste": "dessubstanciar",
    "dessubstanciastes": "dessubstanciar",
    "dessubstanciava": "dessubstanciar",
    "dessubstanciavam": "dessubstanciar",
    "dessubstanciavas": "dessubstanciar",
    "dessubstancie": "dessubstanciar",
    "dessubstanciei": "dessubstanciar",
    "dessubstancieis": "dessubstanciar",
    "dessubstanciem": "dessubstanciar",
    "dessubstanciemo": "dessubstanciar",
    "dessubstanciemos": "dessubstanciar",
    "dessubstancies": "dessubstanciar",
    "dessubstancio": "dessubstanciar",
    "dessubstanciou": "dessubstanciar",
    "dessubstanciá": "dessubstanciar",
    "dessubstanciámo": "dessubstanciar",
    "dessubstanciámos": "dessubstanciar",
    "dessubstanciáramo": "dessubstanciar",
    "dessubstanciáramos": "dessubstanciar",
    "dessubstanciárei": "dessubstanciar",
    "dessubstanciáreis": "dessubstanciar",
    "dessubstanciásseis": "dessubstanciar",
    "dessubstanciássemos": "dessubstanciar",
    "dessubstanciávamo": "dessubstanciar",
    "dessubstanciávamos": "dessubstanciar",
    "dessubstanciávei": "dessubstanciar",
    "dessubstanciáveis": "dessubstanciar",
    "dessudações": "dessudação",
    "dessue": "dessuar",
    "dessuei": "dessuar",
    "dessueis": "dessuar",
    "dessuem": "dessuar",
    "dessuemo": "dessuar",
    "dessuemos": "dessuar",
    "dessues": "dessuar",
    "dessuetudes": "dessuetude",
    "dessuja": "dessujar",
    "dessujada": "dessujar",
    "dessujadas": "dessujar",
    "dessujado": "dessujar",
    "dessujados": "dessujar",
    "dessujai": "dessujar",
    "dessujais": "dessujar",
    "dessujam": "dessujar",
    "dessujamo": "dessujar",
    "dessujamos": "dessujar",
    "dessujando": "dessujar",
    "dessujara": "dessujar",
    "dessujaram": "dessujar",
    "dessujaras": "dessujar",
    "dessujarde": "dessujar",
    "dessujardes": "dessujar",
    "dessujare": "dessujar",
    "dessujarei": "dessujar",
    "dessujareis": "dessujar",
    "dessujarem": "dessujar",
    "dessujaremos": "dessujar",
    "dessujares": "dessujar",
    "dessujaria": "dessujar",
    "dessujariam": "dessujar",
    "dessujarias": "dessujar",
    "dessujarmo": "dessujar",
    "dessujarmos": "dessujar",
    "dessujará": "dessujar",
    "dessujarás": "dessujar",
    "dessujarão": "dessujar",
    "dessujaríamos": "dessujar",
    "dessujaríeis": "dessujar",
    "dessujas": "dessujar",
    "dessujasse": "dessujar",
    "dessujassem": "dessujar",
    "dessujasses": "dessujar",
    "dessujaste": "dessujar",
    "dessujastes": "dessujar",
    "dessujava": "dessujar",
    "dessujavam": "dessujar",
    "dessujavas": "dessujar",
    "dessuje": "dessujar",
    "dessujei": "dessujar",
    "dessujeis": "dessujar",
    "dessujeita": "dessujeito",
    "dessujeitas": "dessujeito",
    "dessujeitos": "dessujeito",
    "dessujem": "dessujar",
    "dessujemo": "dessujar",
    "dessujemos": "dessujar",
    "dessujes": "dessujar",
    "dessujo": "dessujar",
    "dessujou": "dessujar",
    "dessujá": "dessujar",
    "dessujámo": "dessujar",
    "dessujámos": "dessujar",
    "dessujáramo": "dessujar",
    "dessujáramos": "dessujar",
    "dessujárei": "dessujar",
    "dessujáreis": "dessujar",
    "dessujásseis": "dessujar",
    "dessujássemos": "dessujar",
    "dessujávamo": "dessujar",
    "dessujávamos": "dessujar",
    "dessujávei": "dessujar",
    "dessujáveis": "dessujar",
    "dessulfurada": "dessulfurado",
    "dessulfuradas": "dessulfurado",
    "dessulfurados": "dessulfurado",
    "dessulfurações": "dessulfuração",
    "dessulfurizações": "dessulfurização",
    "dessulfurra": "dessulfurrar",
    "dessulfurrada": "dessulfurrar",
    "dessulfurradas": "dessulfurrar",
    "dessulfurrado": "dessulfurrar",
    "dessulfurrados": "dessulfurrar",
    "dessulfurrai": "dessulfurrar",
    "dessulfurrais": "dessulfurrar",
    "dessulfurram": "dessulfurrar",
    "dessulfurramo": "dessulfurrar",
    "dessulfurramos": "dessulfurrar",
    "dessulfurrando": "dessulfurrar",
    "dessulfurrara": "dessulfurrar",
    "dessulfurraram": "dessulfurrar",
    "dessulfurraras": "dessulfurrar",
    "dessulfurrarde": "dessulfurrar",
    "dessulfurrardes": "dessulfurrar",
    "dessulfurrare": "dessulfurrar",
    "dessulfurrarei": "dessulfurrar",
    "dessulfurrareis": "dessulfurrar",
    "dessulfurrarem": "dessulfurrar",
    "dessulfurraremos": "dessulfurrar",
    "dessulfurrares": "dessulfurrar",
    "dessulfurraria": "dessulfurrar",
    "dessulfurrariam": "dessulfurrar",
    "dessulfurrarias": "dessulfurrar",
    "dessulfurrarmo": "dessulfurrar",
    "dessulfurrarmos": "dessulfurrar",
    "dessulfurrará": "dessulfurrar",
    "dessulfurrarás": "dessulfurrar",
    "dessulfurrarão": "dessulfurrar",
    "dessulfurraríamos": "dessulfurrar",
    "dessulfurraríeis": "dessulfurrar",
    "dessulfurras": "dessulfurrar",
    "dessulfurrasse": "dessulfurrar",
    "dessulfurrassem": "dessulfurrar",
    "dessulfurrasses": "dessulfurrar",
    "dessulfurraste": "dessulfurrar",
    "dessulfurrastes": "dessulfurrar",
    "dessulfurrava": "dessulfurrar",
    "dessulfurravam": "dessulfurrar",
    "dessulfurravas": "dessulfurrar",
    "dessulfurre": "dessulfurrar",
    "dessulfurrei": "dessulfurrar",
    "dessulfurreis": "dessulfurrar",
    "dessulfurrem": "dessulfurrar",
    "dessulfurremo": "dessulfurrar",
    "dessulfurremos": "dessulfurrar",
    "dessulfurres": "dessulfurrar",
    "dessulfurro": "dessulfurrar",
    "dessulfurrou": "dessulfurrar",
    "dessulfurrá": "dessulfurrar",
    "dessulfurrámo": "dessulfurrar",
    "dessulfurrámos": "dessulfurrar",
    "dessulfurráramo": "dessulfurrar",
    "dessulfurráramos": "dessulfurrar",
    "dessulfurrárei": "dessulfurrar",
    "dessulfurráreis": "dessulfurrar",
    "dessulfurrásseis": "dessulfurrar",
    "dessulfurrássemos": "dessulfurrar",
    "dessulfurrávamo": "dessulfurrar",
    "dessulfurrávamos": "dessulfurrar",
    "dessulfurrávei": "dessulfurrar",
    "dessulfurráveis": "dessulfurrar",
    "dessultores": "dessultor",
    "dessultória": "dessultório",
    "dessultórias": "dessultório",
    "dessultórios": "dessultório",
    "dessuma": "dessumir",
    "dessumais": "dessumir",
    "dessumam": "dessumir",
    "dessumamo": "dessumir",
    "dessumamos": "dessumir",
    "dessumas": "dessumir",
    "dessumi": "dessumir",
    "dessumia": "dessumir",
    "dessumiam": "dessumir",
    "dessumias": "dessumir",
    "dessumida": "dessumir",
    "dessumidas": "dessumir",
    "dessumido": "dessumir",
    "dessumidos": "dessumir",
    "dessumimo": "dessumir",
    "dessumimos": "dessumir",
    "dessumindo": "dessumir",
    "dessumira": "dessumir",
    "dessumiram": "dessumir",
    "dessumiras": "dessumir",
    "dessumirdes": "dessumir",
    "dessumirei": "dessumir",
    "dessumireis": "dessumir",
    "dessumirem": "dessumir",
    "dessumiremos": "dessumir",
    "dessumires": "dessumir",
    "dessumiria": "dessumir",
    "dessumiriam": "dessumir",
    "dessumirias": "dessumir",
    "dessumirmo": "dessumir",
    "dessumirmos": "dessumir",
    "dessumirá": "dessumir",
    "dessumirás": "dessumir",
    "dessumirão": "dessumir",
    "dessumiríamos": "dessumir",
    "dessumiríeis": "dessumir",
    "dessumis": "dessumir",
    "dessumisse": "dessumir",
    "dessumissem": "dessumir",
    "dessumisses": "dessumir",
    "dessumiste": "dessumir",
    "dessumistes": "dessumir",
    "dessumiu": "dessumir",
    "dessumo": "dessumir",
    "dessumíamo": "dessumir",
    "dessumíamos": "dessumir",
    "dessumíeis": "dessumir",
    "dessumíramo": "dessumir",
    "dessumíramos": "dessumir",
    "dessumíreis": "dessumir",
    "dessumísseis": "dessumir",
    "dessumíssemos": "dessumir",
    "dessuo": "dessuar",
    "dessuou": "dessuar",
    "dessuspeitosa": "dessuspeitoso",
    "dessuspeitosas": "dessuspeitoso",
    "dessuspeitosos": "dessuspeitoso",
    "dessuámo": "dessuar",
    "dessuámos": "dessuar",
    "dessuáramo": "dessuar",
    "dessuáramos": "dessuar",
    "dessuáreis": "dessuar",
    "dessuásseis": "dessuar",
    "dessuássemos": "dessuar",
    "dessuávamo": "dessuar",
    "dessuávamos": "dessuar",
    "dessuáveis": "dessuar",
    "dessá": "dessar",
    "dessámo": "dessar",
    "dessámos": "dessar",
    "dessáramo": "dessar",
    "dessáramos": "dessar",
    "dessárei": "dessar",
    "dessáreis": "dessar",
    "dessásseis": "dessar",
    "dessássemos": "dessar",
    "dessávamo": "dessar",
    "dessávamos": "dessar",
    "dessávei": "dessar",
    "dessáveis": "dessar",
    "destaca": "destacar",
    "destacada": "destacar",
    "destacadas": "destacar",
    "destacado": "destacar",
    "destacados": "destacar",
    "destacai": "destacar",
    "destacais": "destacar",
    "destacam": "destacar",
    "destacamentos": "destacamento",
    "destacamo": "destacar",
    "destacamos": "destacar",
    "destacando": "destacar",
    "destacara": "destacar",
    "destacaram": "destacar",
    "destacaras": "destacar",
    "destacarde": "destacar",
    "destacardes": "destacar",
    "destacare": "destacar",
    "destacarei": "destacar",
    "destacareis": "destacar",
    "destacarem": "destacar",
    "destacaremos": "destacar",
    "destacares": "destacar",
    "destacaria": "destacar",
    "destacariam": "destacar",
    "destacarias": "destacar",
    "destacarmo": "destacar",
    "destacarmos": "destacar",
    "destacará": "destacar",
    "destacarás": "destacar",
    "destacarão": "destacar",
    "destacaríamos": "destacar",
    "destacaríeis": "destacar",
    "destacas": "destacar",
    "destacasse": "destacar",
    "destacassem": "destacar",
    "destacasses": "destacar",
    "destacaste": "destacar",
    "destacastes": "destacar",
    "destacava": "destacar",
    "destacavam": "destacar",
    "destacavas": "destacar",
    "destaco": "destacar",
    "destacou": "destacar",
    "destacá": "destacar",
    "destacámo": "destacar",
    "destacámos": "destacar",
    "destacáramo": "destacar",
    "destacáramos": "destacar",
    "destacárei": "destacar",
    "destacáreis": "destacar",
    "destacásseis": "destacar",
    "destacássemos": "destacar",
    "destacávamo": "destacar",
    "destacávamos": "destacar",
    "destacávei": "destacar",
    "destacáveis": "destacável",
    "destala": "destalar",
    "destalada": "destalar",
    "destaladas": "destalar",
    "destalado": "destalar",
    "destalados": "destalar",
    "destalai": "destalar",
    "destalais": "destalar",
    "destalam": "destalar",
    "destalamo": "destalar",
    "destalamos": "destalar",
    "destalando": "destalar",
    "destalara": "destalar",
    "destalaram": "destalar",
    "destalaras": "destalar",
    "destalarde": "destalar",
    "destalardes": "destalar",
    "destalare": "destalar",
    "destalarei": "destalar",
    "destalareis": "destalar",
    "destalarem": "destalar",
    "destalaremos": "destalar",
    "destalares": "destalar",
    "destalaria": "destalar",
    "destalariam": "destalar",
    "destalarias": "destalar",
    "destalarmo": "destalar",
    "destalarmos": "destalar",
    "destalará": "destalar",
    "destalarás": "destalar",
    "destalarão": "destalar",
    "destalaríamos": "destalar",
    "destalaríeis": "destalar",
    "destalas": "destalar",
    "destalasse": "destalar",
    "destalassem": "destalar",
    "destalasses": "destalar",
    "destalaste": "destalar",
    "destalastes": "destalar",
    "destalava": "destalar",
    "destalavam": "destalar",
    "destalavas": "destalar",
    "destale": "destalar",
    "destalei": "destalar",
    "destaleis": "destalar",
    "destalem": "destalar",
    "destalemo": "destalar",
    "destalemos": "destalar",
    "destales": "destalar",
    "destalo": "destalar",
    "destalou": "destalar",
    "destalá": "destalar",
    "destalámo": "destalar",
    "destalámos": "destalar",
    "destaláramo": "destalar",
    "destaláramos": "destalar",
    "destalárei": "destalar",
    "destaláreis": "destalar",
    "destalásseis": "destalar",
    "destalássemos": "destalar",
    "destalávamo": "destalar",
    "destalávamos": "destalar",
    "destalávei": "destalar",
    "destaláveis": "destalar",
    "destampa": "destampar",
    "destampada": "destampar",
    "destampadas": "destampar",
    "destampado": "destampar",
    "destampados": "destampar",
    "destampai": "destampar",
    "destampais": "destampar",
    "destampam": "destampar",
    "destampamo": "destampar",
    "destampamos": "destampar",
    "destampando": "destampar",
    "destampara": "destampar",
    "destamparam": "destampar",
    "destamparas": "destampar",
    "destamparde": "destampar",
    "destampardes": "destampar",
    "destampare": "destampar",
    "destamparei": "destampar",
    "destampareis": "destampar",
    "destamparem": "destampar",
    "destamparemos": "destampar",
    "destampares": "destampar",
    "destamparia": "destampar",
    "destampariam": "destampar",
    "destamparias": "destampar",
    "destamparmo": "destampar",
    "destamparmos": "destampar",
    "destampará": "destampar",
    "destamparás": "destampar",
    "destamparão": "destampar",
    "destamparíamos": "destampar",
    "destamparíeis": "destampar",
    "destampas": "destampar",
    "destampasse": "destampar",
    "destampassem": "destampar",
    "destampasses": "destampar",
    "destampaste": "destampar",
    "destampastes": "destampar",
    "destampatórias": "destampatória",
    "destampatórios": "destampatório",
    "destampava": "destampar",
    "destampavam": "destampar",
    "destampavas": "destampar",
    "destampe": "destampar",
    "destampei": "destampar",
    "destampeis": "destampar",
    "destampem": "destampar",
    "destampemo": "destampar",
    "destampemos": "destampar",
    "destampes": "destampar",
    "destampo": "destampar",
    "destampou": "destampar",
    "destampá": "destampar",
    "destampámo": "destampar",
    "destampámos": "destampar",
    "destampáramo": "destampar",
    "destampáramos": "destampar",
    "destampárei": "destampar",
    "destampáreis": "destampar",
    "destampásseis": "destampar",
    "destampássemos": "destampar",
    "destampávamo": "destampar",
    "destampávamos": "destampar",
    "destampávei": "destampar",
    "destampáveis": "destampar",
    "destaniniza": "destaninizar",
    "destaninizada": "destaninizar",
    "destaninizadas": "destaninizar",
    "destaninizado": "destaninizar",
    "destaninizados": "destaninizar",
    "destaninizai": "destaninizar",
    "destaninizais": "destaninizar",
    "destaninizam": "destaninizar",
    "destaninizamo": "destaninizar",
    "destaninizamos": "destaninizar",
    "destaninizando": "destaninizar",
    "destaninizara": "destaninizar",
    "destaninizaram": "destaninizar",
    "destaninizaras": "destaninizar",
    "destaninizarde": "destaninizar",
    "destaninizardes": "destaninizar",
    "destaninizare": "destaninizar",
    "destaninizarei": "destaninizar",
    "destaninizareis": "destaninizar",
    "destaninizarem": "destaninizar",
    "destaninizaremos": "destaninizar",
    "destaninizares": "destaninizar",
    "destaninizaria": "destaninizar",
    "destaninizariam": "destaninizar",
    "destaninizarias": "destaninizar",
    "destaninizarmo": "destaninizar",
    "destaninizarmos": "destaninizar",
    "destaninizará": "destaninizar",
    "destaninizarás": "destaninizar",
    "destaninizarão": "destaninizar",
    "destaninizaríamos": "destaninizar",
    "destaninizaríeis": "destaninizar",
    "destaninizas": "destaninizar",
    "destaninizasse": "destaninizar",
    "destaninizassem": "destaninizar",
    "destaninizasses": "destaninizar",
    "destaninizaste": "destaninizar",
    "destaninizastes": "destaninizar",
    "destaninizava": "destaninizar",
    "destaninizavam": "destaninizar",
    "destaninizavas": "destaninizar",
    "destaninize": "destaninizar",
    "destaninizei": "destaninizar",
    "destaninizeis": "destaninizar",
    "destaninizem": "destaninizar",
    "destaninizemo": "destaninizar",
    "destaninizemos": "destaninizar",
    "destaninizes": "destaninizar",
    "destaninizo": "destaninizar",
    "destaninizou": "destaninizar",
    "destaninizá": "destaninizar",
    "destaninizámo": "destaninizar",
    "destaninizámos": "destaninizar",
    "destaninizáramo": "destaninizar",
    "destaninizáramos": "destaninizar",
    "destaninizárei": "destaninizar",
    "destaninizáreis": "destaninizar",
    "destaninizásseis": "destaninizar",
    "destaninizássemos": "destaninizar",
    "destaninizávamo": "destaninizar",
    "destaninizávamos": "destaninizar",
    "destaninizávei": "destaninizar",
    "destaninizáveis": "destaninizar",
    "destaniza": "destanizar",
    "destanizada": "destanizar",
    "destanizadas": "destanizar",
    "destanizado": "destanizar",
    "destanizados": "destanizar",
    "destanizai": "destanizar",
    "destanizais": "destanizar",
    "destanizam": "destanizar",
    "destanizamo": "destanizar",
    "destanizamos": "destanizar",
    "destanizando": "destanizar",
    "destanizara": "destanizar",
    "destanizaram": "destanizar",
    "destanizaras": "destanizar",
    "destanizarde": "destanizar",
    "destanizardes": "destanizar",
    "destanizare": "destanizar",
    "destanizarei": "destanizar",
    "destanizareis": "destanizar",
    "destanizarem": "destanizar",
    "destanizaremos": "destanizar",
    "destanizares": "destanizar",
    "destanizaria": "destanizar",
    "destanizariam": "destanizar",
    "destanizarias": "destanizar",
    "destanizarmo": "destanizar",
    "destanizarmos": "destanizar",
    "destanizará": "destanizar",
    "destanizarás": "destanizar",
    "destanizarão": "destanizar",
    "destanizaríamos": "destanizar",
    "destanizaríeis": "destanizar",
    "destanizas": "destanizar",
    "destanizasse": "destanizar",
    "destanizassem": "destanizar",
    "destanizasses": "destanizar",
    "destanizaste": "destanizar",
    "destanizastes": "destanizar",
    "destanizava": "destanizar",
    "destanizavam": "destanizar",
    "destanizavas": "destanizar",
    "destanize": "destanizar",
    "destanizei": "destanizar",
    "destanizeis": "destanizar",
    "destanizem": "destanizar",
    "destanizemo": "destanizar",
    "destanizemos": "destanizar",
    "destanizes": "destanizar",
    "destanizo": "destanizar",
    "destanizou": "destanizar",
    "destanizá": "destanizar",
    "destanizámo": "destanizar",
    "destanizámos": "destanizar",
    "destanizáramo": "destanizar",
    "destanizáramos": "destanizar",
    "destanizárei": "destanizar",
    "destanizáreis": "destanizar",
    "destanizásseis": "destanizar",
    "destanizássemos": "destanizar",
    "destanizávamo": "destanizar",
    "destanizávamos": "destanizar",
    "destanizávei": "destanizar",
    "destanizáveis": "destanizar",
    "destapa": "destapar",
    "destapada": "destapar",
    "destapadas": "destapar",
    "destapado": "destapar",
    "destapados": "destapar",
    "destapai": "destapar",
    "destapais": "destapar",
    "destapam": "destapar",
    "destapamentos": "destapamento",
    "destapamo": "destapar",
    "destapamos": "destapar",
    "destapando": "destapar",
    "destapara": "destapar",
    "destaparam": "destapar",
    "destaparas": "destapar",
    "destaparde": "destapar",
    "destapardes": "destapar",
    "destapare": "destapar",
    "destaparei": "destapar",
    "destapareis": "destapar",
    "destaparem": "destapar",
    "destaparemos": "destapar",
    "destapares": "destapar",
    "destaparia": "destapar",
    "destapariam": "destapar",
    "destaparias": "destapar",
    "destaparmo": "destapar",
    "destaparmos": "destapar",
    "destapará": "destapar",
    "destaparás": "destapar",
    "destaparão": "destapar",
    "destaparíamos": "destapar",
    "destaparíeis": "destapar",
    "destapas": "destapar",
    "destapasse": "destapar",
    "destapassem": "destapar",
    "destapasses": "destapar",
    "destapaste": "destapar",
    "destapastes": "destapar",
    "destapava": "destapar",
    "destapavam": "destapar",
    "destapavas": "destapar",
    "destape": "destapar",
    "destapei": "destapar",
    "destapeis": "destapar",
    "destapem": "destapar",
    "destapemo": "destapar",
    "destapemos": "destapar",
    "destapes": "destapar",
    "destapo": "destapar",
    "destapou": "destapar",
    "destapá": "destapar",
    "destapámo": "destapar",
    "destapámos": "destapar",
    "destapáramo": "destapar",
    "destapáramos": "destapar",
    "destapárei": "destapar",
    "destapáreis": "destapar",
    "destapásseis": "destapar",
    "destapássemos": "destapar",
    "destapávamo": "destapar",
    "destapávamos": "destapar",
    "destapávei": "destapar",
    "destapáveis": "destapar",
    "destaque": "destacar",
    "destaquei": "destacar",
    "destaqueis": "destacar",
    "destaquem": "destacar",
    "destaquemo": "destacar",
    "destaquemos": "destacar",
    "destaques": "destaque",
    "deste": "dar",
    "destece": "destecer",
    "desteceduras": "destecedura",
    "destecei": "destecer",
    "desteceis": "destecer",
    "destecem": "destecer",
    "destecemo": "destecer",
    "destecemos": "destecer",
    "destecendo": "destecer",
    "destecera": "destecer",
    "desteceram": "destecer",
    "desteceras": "destecer",
    "destecerde": "destecer",
    "destecerdes": "destecer",
    "destecere": "destecer",
    "destecerei": "destecer",
    "destecereis": "destecer",
    "destecerem": "destecer",
    "desteceremos": "destecer",
    "desteceres": "destecer",
    "desteceria": "destecer",
    "desteceriam": "destecer",
    "destecerias": "destecer",
    "destecermo": "destecer",
    "destecermos": "destecer",
    "destecerá": "destecer",
    "destecerás": "destecer",
    "destecerão": "destecer",
    "desteceríamos": "destecer",
    "desteceríeis": "destecer",
    "desteces": "destecer",
    "destecesse": "destecer",
    "destecessem": "destecer",
    "destecesses": "destecer",
    "desteceste": "destecer",
    "destecestes": "destecer",
    "desteceu": "destecer",
    "desteci": "destecer",
    "destecia": "destecer",
    "desteciam": "destecer",
    "destecias": "destecer",
    "destecida": "destecido",
    "destecidas": "destecido",
    "destecido": "destecer",
    "destecidos": "destecido",
    "destecê": "destecer",
    "destecêramo": "destecer",
    "destecêramos": "destecer",
    "destecêrei": "destecer",
    "destecêreis": "destecer",
    "destecêsseis": "destecer",
    "destecêssemos": "destecer",
    "destecíamo": "destecer",
    "destecíamos": "destecer",
    "destecíei": "destecer",
    "destecíeis": "destecer",
    "destela": "destelar",
    "destelada": "destelar",
    "desteladas": "destelar",
    "destelado": "destelar",
    "destelados": "destelar",
    "destelai": "destelar",
    "destelais": "destelar",
    "destelam": "destelar",
    "destelamo": "destelar",
    "destelamos": "destelar",
    "destelando": "destelar",
    "destelara": "destelar",
    "destelaram": "destelar",
    "destelaras": "destelar",
    "destelarde": "destelar",
    "destelardes": "destelar",
    "destelare": "destelar",
    "destelarei": "destelar",
    "destelareis": "destelar",
    "destelarem": "destelar",
    "destelaremos": "destelar",
    "destelares": "destelar",
    "destelaria": "destelar",
    "destelariam": "destelar",
    "destelarias": "destelar",
    "destelarmo": "destelar",
    "destelarmos": "destelar",
    "destelará": "destelar",
    "destelarás": "destelar",
    "destelarão": "destelar",
    "destelaríamos": "destelar",
    "destelaríeis": "destelar",
    "destelas": "destelar",
    "destelasse": "destelar",
    "destelassem": "destelar",
    "destelasses": "destelar",
    "destelaste": "destelar",
    "destelastes": "destelar",
    "destelava": "destelar",
    "destelavam": "destelar",
    "destelavas": "destelar",
    "destele": "destelar",
    "destelei": "destelar",
    "desteleis": "destelar",
    "destelem": "destelar",
    "destelemo": "destelar",
    "destelemos": "destelar",
    "desteles": "destelar",
    "destelha": "destelhar",
    "destelhada": "destelhar",
    "destelhadas": "destelhar",
    "destelhado": "destelhar",
    "destelhados": "destelhar",
    "destelhai": "destelhar",
    "destelhais": "destelhar",
    "destelham": "destelhar",
    "destelhamentos": "destelhamento",
    "destelhamo": "destelhar",
    "destelhamos": "destelhar",
    "destelhando": "destelhar",
    "destelhara": "destelhar",
    "destelharam": "destelhar",
    "destelharas": "destelhar",
    "destelharde": "destelhar",
    "destelhardes": "destelhar",
    "destelhare": "destelhar",
    "destelharei": "destelhar",
    "destelhareis": "destelhar",
    "destelharem": "destelhar",
    "destelharemos": "destelhar",
    "destelhares": "destelhar",
    "destelharia": "destelhar",
    "destelhariam": "destelhar",
    "destelharias": "destelhar",
    "destelharmo": "destelhar",
    "destelharmos": "destelhar",
    "destelhará": "destelhar",
    "destelharás": "destelhar",
    "destelharão": "destelhar",
    "destelharíamos": "destelhar",
    "destelharíeis": "destelhar",
    "destelhas": "destelhar",
    "destelhasse": "destelhar",
    "destelhassem": "destelhar",
    "destelhasses": "destelhar",
    "destelhaste": "destelhar",
    "destelhastes": "destelhar",
    "destelhava": "destelhar",
    "destelhavam": "destelhar",
    "destelhavas": "destelhar",
    "destelhe": "destelhar",
    "destelhei": "destelhar",
    "destelheis": "destelhar",
    "destelhem": "destelhar",
    "destelhemo": "destelhar",
    "destelhemos": "destelhar",
    "destelhes": "destelhar",
    "destelho": "destelhar",
    "destelhos": "destelho",
    "destelhou": "destelhar",
    "destelhá": "destelhar",
    "destelhámo": "destelhar",
    "destelhámos": "destelhar",
    "destelháramo": "destelhar",
    "destelháramos": "destelhar",
    "destelhárei": "destelhar",
    "destelháreis": "destelhar",
    "destelhásseis": "destelhar",
    "destelhássemos": "destelhar",
    "destelhávamo": "destelhar",
    "destelhávamos": "destelhar",
    "destelhávei": "destelhar",
    "destelháveis": "destelhar",
    "destelo": "destelar",
    "destelou": "destelar",
    "destelá": "destelar",
    "destelámo": "destelar",
    "destelámos": "destelar",
    "desteláramo": "destelar",
    "desteláramos": "destelar",
    "destelárei": "destelar",
    "desteláreis": "destelar",
    "destelásseis": "destelar",
    "destelássemos": "destelar",
    "destelávamo": "destelar",
    "destelávamos": "destelar",
    "destelávei": "destelar",
    "desteláveis": "destelar",
    "destema": "destemer",
    "destemais": "destemer",
    "destemam": "destemer",
    "destemamo": "destemer",
    "destemamos": "destemer",
    "destemas": "destemer",
    "desteme": "destemer",
    "destemei": "destemer",
    "destemeis": "destemer",
    "destemem": "destemer",
    "destememo": "destemer",
    "destememos": "destemer",
    "destemendo": "destemer",
    "destemera": "destemer",
    "destemeram": "destemer",
    "destemeras": "destemer",
    "destemerde": "destemer",
    "destemerdes": "destemer",
    "destemere": "destemer",
    "destemerei": "destemer",
    "destemereis": "destemer",
    "destemerem": "destemer",
    "destemeremos": "destemer",
    "destemeres": "destemer",
    "destemeria": "destemer",
    "destemeriam": "destemer",
    "destemerias": "destemer",
    "destemermo": "destemer",
    "destemermos": "destemer",
    "destemerosa": "destemeroso",
    "destemerosas": "destemeroso",
    "destemerosos": "destemeroso",
    "destemerá": "destemer",
    "destemerás": "destemer",
    "destemerão": "destemer",
    "destemeríamos": "destemer",
    "destemeríeis": "destemer",
    "destemes": "destemer",
    "destemesse": "destemer",
    "destemessem": "destemer",
    "destemesses": "destemer",
    "destemeste": "destemer",
    "destemestes": "destemer",
    "destemeu": "destemer",
    "destemi": "destemer",
    "destemia": "destemer",
    "destemiam": "destemer",
    "destemias": "destemer",
    "destemida": "destemido",
    "destemidas": "destemido",
    "destemidezes": "destemidez",
    "destemido": "destemer",
    "destemidos": "destemido",
    "destemidíssima": "destemido",
    "destemidíssimas": "destemido",
    "destemidíssimo": "destemido",
    "destemidíssimos": "destemido",
    "destemo": "destemer",
    "destemores": "destemor",
    "destempera": "destemperar",
    "destemperada": "destemperar",
    "destemperadas": "destemperar",
    "destemperado": "destemperar",
    "destemperados": "destemperar",
    "destemperai": "destemperar",
    "destemperais": "destemperar",
    "destemperam": "destemperar",
    "destemperamo": "destemperar",
    "destemperamos": "destemperar",
    "destemperando": "destemperar",
    "destemperanças": "destemperança",
    "destemperara": "destemperar",
    "destemperaram": "destemperar",
    "destemperaras": "destemperar",
    "destemperarde": "destemperar",
    "destemperardes": "destemperar",
    "destemperare": "destemperar",
    "destemperarei": "destemperar",
    "destemperareis": "destemperar",
    "destemperarem": "destemperar",
    "destemperaremos": "destemperar",
    "destemperares": "destemperar",
    "destemperaria": "destemperar",
    "destemperariam": "destemperar",
    "destemperarias": "destemperar",
    "destemperarmo": "destemperar",
    "destemperarmos": "destemperar",
    "destemperará": "destemperar",
    "destemperarás": "destemperar",
    "destemperarão": "destemperar",
    "destemperaríamos": "destemperar",
    "destemperaríeis": "destemperar",
    "destemperas": "destemperar",
    "destemperasse": "destemperar",
    "destemperassem": "destemperar",
    "destemperasses": "destemperar",
    "destemperaste": "destemperar",
    "destemperastes": "destemperar",
    "destemperava": "destemperar",
    "destemperavam": "destemperar",
    "destemperavas": "destemperar",
    "destempere": "destemperar",
    "destemperei": "destemperar",
    "destempereis": "destemperar",
    "destemperem": "destemperar",
    "destemperemo": "destemperar",
    "destemperemos": "destemperar",
    "destemperes": "destemperar",
    "destempero": "destemperar",
    "destemperos": "destempero",
    "destemperou": "destemperar",
    "destemperá": "destemperar",
    "destemperámo": "destemperar",
    "destemperámos": "destemperar",
    "destemperáramo": "destemperar",
    "destemperáramos": "destemperar",
    "destemperárei": "destemperar",
    "destemperáreis": "destemperar",
    "destemperásseis": "destemperar",
    "destemperássemos": "destemperar",
    "destemperávamo": "destemperar",
    "destemperávamos": "destemperar",
    "destemperávei": "destemperar",
    "destemperáveis": "destemperar",
    "destempos": "destempo",
    "destemê": "destemer",
    "destemêramo": "destemer",
    "destemêramos": "destemer",
    "destemêrei": "destemer",
    "destemêreis": "destemer",
    "destemêsseis": "destemer",
    "destemêssemos": "destemer",
    "destemíamo": "destemer",
    "destemíamos": "destemer",
    "destemíei": "destemer",
    "destemíeis": "destemer",
    "desteridades": "desteridade",
    "desterra": "desterrar",
    "desterrada": "desterrar",
    "desterradas": "desterrar",
    "desterrado": "desterrar",
    "desterrados": "desterrar",
    "desterrai": "desterrar",
    "desterrais": "desterrar",
    "desterram": "desterrar",
    "desterramo": "desterrar",
    "desterramos": "desterrar",
    "desterrando": "desterrar",
    "desterrara": "desterrar",
    "desterraram": "desterrar",
    "desterraras": "desterrar",
    "desterrarde": "desterrar",
    "desterrardes": "desterrar",
    "desterrare": "desterrar",
    "desterrarei": "desterrar",
    "desterrareis": "desterrar",
    "desterrarem": "desterrar",
    "desterraremos": "desterrar",
    "desterrares": "desterrar",
    "desterraria": "desterrar",
    "desterrariam": "desterrar",
    "desterrarias": "desterrar",
    "desterrarmo": "desterrar",
    "desterrarmos": "desterrar",
    "desterrará": "desterrar",
    "desterrarás": "desterrar",
    "desterrarão": "desterrar",
    "desterraríamos": "desterrar",
    "desterraríeis": "desterrar",
    "desterras": "desterrar",
    "desterrasse": "desterrar",
    "desterrassem": "desterrar",
    "desterrasses": "desterrar",
    "desterraste": "desterrar",
    "desterrastes": "desterrar",
    "desterrava": "desterrar",
    "desterravam": "desterrar",
    "desterravas": "desterrar",
    "desterre": "desterrar",
    "desterrei": "desterrar",
    "desterreis": "desterrar",
    "desterrem": "desterrar",
    "desterremo": "desterrar",
    "desterremos": "desterrar",
    "desterres": "desterrar",
    "desterro": "desterrar",
    "desterroa": "desterroar",
    "desterroada": "desterroar",
    "desterroadas": "desterroar",
    "desterroado": "desterroar",
    "desterroadora": "desterroador",
    "desterroadoras": "desterroador",
    "desterroadores": "desterroador",
    "desterroados": "desterroar",
    "desterroai": "desterroar",
    "desterroais": "desterroar",
    "desterroam": "desterroar",
    "desterroamentos": "desterroamento",
    "desterroamo": "desterroar",
    "desterroamos": "desterroar",
    "desterroando": "desterroar",
    "desterroara": "desterroar",
    "desterroaram": "desterroar",
    "desterroaras": "desterroar",
    "desterroarde": "desterroar",
    "desterroardes": "desterroar",
    "desterroare": "desterroar",
    "desterroarei": "desterroar",
    "desterroareis": "desterroar",
    "desterroarem": "desterroar",
    "desterroaremos": "desterroar",
    "desterroares": "desterroar",
    "desterroaria": "desterroar",
    "desterroariam": "desterroar",
    "desterroarias": "desterroar",
    "desterroarmo": "desterroar",
    "desterroarmos": "desterroar",
    "desterroará": "desterroar",
    "desterroarás": "desterroar",
    "desterroarão": "desterroar",
    "desterroaríamos": "desterroar",
    "desterroaríeis": "desterroar",
    "desterroas": "desterroar",
    "desterroasse": "desterroar",
    "desterroassem": "desterroar",
    "desterroasses": "desterroar",
    "desterroaste": "desterroar",
    "desterroastes": "desterroar",
    "desterroava": "desterroar",
    "desterroavam": "desterroar",
    "desterroavas": "desterroar",
    "desterroe": "desterroar",
    "desterroei": "desterroar",
    "desterroeis": "desterroar",
    "desterroem": "desterroar",
    "desterroemo": "desterroar",
    "desterroemos": "desterroar",
    "desterroes": "desterroar",
    "desterroo": "desterroar",
    "desterroou": "desterroar",
    "desterros": "desterro",
    "desterrou": "desterrar",
    "desterroá": "desterroar",
    "desterroámo": "desterroar",
    "desterroámos": "desterroar",
    "desterroáramo": "desterroar",
    "desterroáramos": "desterroar",
    "desterroárei": "desterroar",
    "desterroáreis": "desterroar",
    "desterroásseis": "desterroar",
    "desterroássemos": "desterroar",
    "desterroávamo": "desterroar",
    "desterroávamos": "desterroar",
    "desterroávei": "desterroar",
    "desterroáveis": "desterroar",
    "desterrá": "desterrar",
    "desterrámo": "desterrar",
    "desterrámos": "desterrar",
    "desterráramo": "desterrar",
    "desterráramos": "desterrar",
    "desterrárei": "desterrar",
    "desterráreis": "desterrar",
    "desterrásseis": "desterrar",
    "desterrássemos": "desterrar",
    "desterrávamo": "desterrar",
    "desterrávamos": "desterrar",
    "desterrávei": "desterrar",
    "desterráveis": "desterrável",
    "destes": "dar",
    "desteta": "destetar",
    "destetada": "destetar",
    "destetadas": "destetar",
    "destetado": "destetar",
    "destetados": "destetar",
    "destetai": "destetar",
    "destetais": "destetar",
    "destetam": "destetar",
    "destetamo": "destetar",
    "destetamos": "destetar",
    "destetando": "destetar",
    "destetara": "destetar",
    "destetaram": "destetar",
    "destetaras": "destetar",
    "destetarde": "destetar",
    "destetardes": "destetar",
    "destetare": "destetar",
    "destetarei": "destetar",
    "destetareis": "destetar",
    "destetarem": "destetar",
    "destetaremos": "destetar",
    "destetares": "destetar",
    "destetaria": "destetar",
    "destetariam": "destetar",
    "destetarias": "destetar",
    "destetarmo": "destetar",
    "destetarmos": "destetar",
    "destetará": "destetar",
    "destetarás": "destetar",
    "destetarão": "destetar",
    "destetaríamos": "destetar",
    "destetaríeis": "destetar",
    "destetas": "destetar",
    "destetasse": "destetar",
    "destetassem": "destetar",
    "destetasses": "destetar",
    "destetaste": "destetar",
    "destetastes": "destetar",
    "destetava": "destetar",
    "destetavam": "destetar",
    "destetavas": "destetar",
    "destete": "destetar",
    "destetei": "destetar",
    "desteteis": "destetar",
    "destetem": "destetar",
    "destetemo": "destetar",
    "destetemos": "destetar",
    "destetes": "destetar",
    "desteto": "destetar",
    "destetou": "destetar",
    "destetá": "destetar",
    "destetámo": "destetar",
    "destetámos": "destetar",
    "destetáramo": "destetar",
    "destetáramos": "destetar",
    "destetárei": "destetar",
    "destetáreis": "destetar",
    "destetásseis": "destetar",
    "destetássemos": "destetar",
    "destetávamo": "destetar",
    "destetávamos": "destetar",
    "destetávei": "destetar",
    "destetáveis": "destetar",
    "desteça": "destecer",
    "desteçais": "destecer",
    "desteçam": "destecer",
    "desteçamo": "destecer",
    "desteçamos": "destecer",
    "desteças": "destecer",
    "desteço": "destecer",
    "destila": "destilar",
    "destilada": "destilar",
    "destiladas": "destilar",
    "destilado": "destilar",
    "destiladores": "destilador",
    "destilados": "destilar",
    "destilai": "destilar",
    "destilais": "destilar",
    "destilam": "destilar",
    "destilamo": "destilar",
    "destilamos": "destilar",
    "destilando": "destilar",
    "destilara": "destilar",
    "destilaram": "destilar",
    "destilaras": "destilar",
    "destilarde": "destilar",
    "destilardes": "destilar",
    "destilare": "destilar",
    "destilarei": "destilar",
    "destilareis": "destilar",
    "destilarem": "destilar",
    "destilaremos": "destilar",
    "destilares": "destilar",
    "destilaria": "destilar",
    "destilariam": "destilar",
    "destilarias": "destilaria",
    "destilarmo": "destilar",
    "destilarmos": "destilar",
    "destilará": "destilar",
    "destilarás": "destilar",
    "destilarão": "destilar",
    "destilaríamos": "destilar",
    "destilaríeis": "destilar",
    "destilas": "destilar",
    "destilasse": "destilar",
    "destilassem": "destilar",
    "destilasses": "destilar",
    "destilaste": "destilar",
    "destilastes": "destilar",
    "destilatória": "destilatório",
    "destilatórias": "destilatório",
    "destilatórios": "destilatório",
    "destilava": "destilar",
    "destilavam": "destilar",
    "destilavas": "destilar",
    "destilações": "destilação",
    "destile": "destilar",
    "destilei": "destilar",
    "destileis": "destilar",
    "destilem": "destilar",
    "destilemo": "destilar",
    "destilemos": "destilar",
    "destiles": "destilar",
    "destilo": "destilar",
    "destilou": "destilar",
    "destilá": "destilar",
    "destilámo": "destilar",
    "destilámos": "destilar",
    "destiláramo": "destilar",
    "destiláramos": "destilar",
    "destilárei": "destilar",
    "destiláreis": "destilar",
    "destilásseis": "destilar",
    "destilássemos": "destilar",
    "destilávamo": "destilar",
    "destilávamos": "destilar",
    "destilávei": "destilar",
    "destiláveis": "destilável",
    "destimidezes": "destimidez",
    "destina": "destinar",
    "destinada": "destinar",
    "destinadas": "destinar",
    "destinado": "destinar",
    "destinadores": "destinador",
    "destinados": "destinar",
    "destinai": "destinar",
    "destinais": "destinar",
    "destinam": "destinar",
    "destinamo": "destinar",
    "destinamos": "destinar",
    "destinando": "destinar",
    "destinara": "destinar",
    "destinaram": "destinar",
    "destinaras": "destinar",
    "destinarde": "destinar",
    "destinardes": "destinar",
    "destinare": "destinar",
    "destinarei": "destinar",
    "destinareis": "destinar",
    "destinarem": "destinar",
    "destinaremos": "destinar",
    "destinares": "destinar",
    "destinaria": "destinar",
    "destinariam": "destinar",
    "destinarias": "destinar",
    "destinarmo": "destinar",
    "destinarmos": "destinar",
    "destinará": "destinar",
    "destinarás": "destinar",
    "destinarão": "destinar",
    "destinaríamos": "destinar",
    "destinaríeis": "destinar",
    "destinas": "destinar",
    "destinasse": "destinar",
    "destinassem": "destinar",
    "destinasses": "destinar",
    "destinaste": "destinar",
    "destinastes": "destinar",
    "destinatária": "destinatário",
    "destinatárias": "destinatário",
    "destinatários": "destinatário",
    "destinava": "destinar",
    "destinavam": "destinar",
    "destinavas": "destinar",
    "destinações": "destinação",
    "destine": "destinar",
    "destinei": "destinar",
    "destineis": "destinar",
    "destinem": "destinar",
    "destinemo": "destinar",
    "destinemos": "destinar",
    "destines": "destinar",
    "destinge": "destingir",
    "destingem": "destingir",
    "destinges": "destingir",
    "destingi": "destingir",
    "destingia": "destingir",
    "destingiam": "destingir",
    "destingias": "destingir",
    "destingida": "destingir",
    "destingidas": "destingir",
    "destingido": "destingir",
    "destingidos": "destingir",
    "destingimo": "destingir",
    "destingimos": "destingir",
    "destingindo": "destingir",
    "destingira": "destingir",
    "destingiram": "destingir",
    "destingiras": "destingir",
    "destingirde": "destingir",
    "destingirdes": "destingir",
    "destingire": "destingir",
    "destingirei": "destingir",
    "destingireis": "destingir",
    "destingirem": "destingir",
    "destingiremos": "destingir",
    "destingires": "destingir",
    "destingiria": "destingir",
    "destingiriam": "destingir",
    "destingirias": "destingir",
    "destingirmo": "destingir",
    "destingirmos": "destingir",
    "destingirá": "destingir",
    "destingirás": "destingir",
    "destingirão": "destingir",
    "destingiríamos": "destingir",
    "destingiríeis": "destingir",
    "destingis": "destingir",
    "destingisse": "destingir",
    "destingissem": "destingir",
    "destingisses": "destingir",
    "destingiste": "destingir",
    "destingistes": "destingir",
    "destingiu": "destingir",
    "destinguida": "destinguido",
    "destinguidas": "destinguido",
    "destinguidos": "destinguido",
    "destinguidíssima": "destinguido",
    "destinguidíssimas": "destinguido",
    "destinguidíssimo": "destinguido",
    "destinguidíssimos": "destinguido",
    "destingíamo": "destingir",
    "destingíamos": "destingir",
    "destingíei": "destingir",
    "destingíeis": "destingir",
    "destingíramo": "destingir",
    "destingíramos": "destingir",
    "destingírei": "destingir",
    "destingíreis": "destingir",
    "destingísseis": "destingir",
    "destingíssemos": "destingir",
    "destinja": "destingir",
    "destinjais": "destingir",
    "destinjam": "destingir",
    "destinjamo": "destingir",
    "destinjamos": "destingir",
    "destinjas": "destingir",
    "destinjo": "destingir",
    "destino": "destinar",
    "destinos": "destino",
    "destinou": "destinar",
    "destinta": "destinto",
    "destintagens": "destintagem",
    "destintas": "destinto",
    "destintos": "destinto",
    "destintíssima": "destinto",
    "destintíssimas": "destinto",
    "destintíssimo": "destinto",
    "destintíssimos": "destinto",
    "destiná": "destinar",
    "destinámo": "destinar",
    "destinámos": "destinar",
    "destináramo": "destinar",
    "destináramos": "destinar",
    "destinárei": "destinar",
    "destináreis": "destinar",
    "destinásseis": "destinar",
    "destinássemos": "destinar",
    "destinávamo": "destinar",
    "destinávamos": "destinar",
    "destinávei": "destinar",
    "destináveis": "destinável",
    "destitua": "destituir",
    "destituais": "destituir",
    "destituam": "destituir",
    "destituamo": "destituir",
    "destituamos": "destituir",
    "destituas": "destituir",
    "destituem": "destituir",
    "destitui": "destituir",
    "destituindo": "destituir",
    "destituirde": "destituir",
    "destituirdes": "destituir",
    "destituirei": "destituir",
    "destituireis": "destituir",
    "destituiremos": "destituir",
    "destituiria": "destituir",
    "destituiriam": "destituir",
    "destituirias": "destituir",
    "destituirmo": "destituir",
    "destituirmos": "destituir",
    "destituirá": "destituir",
    "destituirás": "destituir",
    "destituirão": "destituir",
    "destituiríamos": "destituir",
    "destituiríeis": "destituir",
    "destituis": "destituir",
    "destituiu": "destituir",
    "destituições": "destituição",
    "destituo": "destituir",
    "destituí": "destituir",
    "destituía": "destituir",
    "destituíam": "destituir",
    "destituíamo": "destituir",
    "destituíamos": "destituir",
    "destituías": "destituir",
    "destituída": "destituir",
    "destituídas": "destituir",
    "destituído": "destituir",
    "destituídos": "destituir",
    "destituíei": "destituir",
    "destituíeis": "destituir",
    "destituímo": "destituir",
    "destituímos": "destituir",
    "destituíra": "destituir",
    "destituíram": "destituir",
    "destituíramo": "destituir",
    "destituíramos": "destituir",
    "destituíras": "destituir",
    "destituíre": "destituir",
    "destituírei": "destituir",
    "destituíreis": "destituir",
    "destituírem": "destituir",
    "destituíres": "destituir",
    "destituís": "destituir",
    "destituísse": "destituir",
    "destituísseis": "destituir",
    "destituíssem": "destituir",
    "destituíssemos": "destituir",
    "destituísses": "destituir",
    "destituíste": "destituir",
    "destituístes": "destituir",
    "destituíveis": "destituível",
    "destoa": "destoar",
    "destoada": "destoar",
    "destoadas": "destoar",
    "destoado": "destoar",
    "destoados": "destoar",
    "destoai": "destoar",
    "destoais": "destoar",
    "destoam": "destoar",
    "destoamo": "destoar",
    "destoamos": "destoar",
    "destoando": "destoar",
    "destoantes": "destoante",
    "destoara": "destoar",
    "destoaram": "destoar",
    "destoaras": "destoar",
    "destoarde": "destoar",
    "destoardes": "destoar",
    "destoare": "destoar",
    "destoarei": "destoar",
    "destoareis": "destoar",
    "destoarem": "destoar",
    "destoaremos": "destoar",
    "destoares": "destoar",
    "destoaria": "destoar",
    "destoariam": "destoar",
    "destoarias": "destoar",
    "destoarmo": "destoar",
    "destoarmos": "destoar",
    "destoará": "destoar",
    "destoarás": "destoar",
    "destoarão": "destoar",
    "destoaríamos": "destoar",
    "destoaríeis": "destoar",
    "destoas": "destoar",
    "destoasse": "destoar",
    "destoassem": "destoar",
    "destoasses": "destoar",
    "destoaste": "destoar",
    "destoastes": "destoar",
    "destoava": "destoar",
    "destoavam": "destoar",
    "destoavas": "destoar",
    "destoca": "destocar",
    "destocada": "destocar",
    "destocadas": "destocar",
    "destocado": "destocar",
    "destocadores": "destocador",
    "destocados": "destocar",
    "destocai": "destocar",
    "destocais": "destocar",
    "destocam": "destocar",
    "destocamentos": "destocamento",
    "destocamo": "destocar",
    "destocamos": "destocar",
    "destocando": "destocar",
    "destocara": "destocar",
    "destocaram": "destocar",
    "destocaras": "destocar",
    "destocarde": "destocar",
    "destocardes": "destocar",
    "destocare": "destocar",
    "destocarei": "destocar",
    "destocareis": "destocar",
    "destocarem": "destocar",
    "destocaremos": "destocar",
    "destocares": "destocar",
    "destocaria": "destocar",
    "destocariam": "destocar",
    "destocarias": "destocar",
    "destocarmo": "destocar",
    "destocarmos": "destocar",
    "destocará": "destocar",
    "destocarás": "destocar",
    "destocarão": "destocar",
    "destocaríamos": "destocar",
    "destocaríeis": "destocar",
    "destocas": "destocar",
    "destocasse": "destocar",
    "destocassem": "destocar",
    "destocasses": "destocar",
    "destocaste": "destocar",
    "destocastes": "destocar",
    "destocava": "destocar",
    "destocavam": "destocar",
    "destocavas": "destocar",
    "destoco": "destocar",
    "destocou": "destocar",
    "destocá": "destocar",
    "destocámo": "destocar",
    "destocámos": "destocar",
    "destocáramo": "destocar",
    "destocáramos": "destocar",
    "destocárei": "destocar",
    "destocáreis": "destocar",
    "destocásseis": "destocar",
    "destocássemos": "destocar",
    "destocávamo": "destocar",
    "destocávamos": "destocar",
    "destocávei": "destocar",
    "destocáveis": "destocar",
    "destoe": "destoar",
    "destoei": "destoar",
    "destoeis": "destoar",
    "destoem": "destoar",
    "destoemo": "destoar",
    "destoemos": "destoar",
    "destoes": "destoar",
    "destolda": "destoldar",
    "destoldada": "destoldar",
    "destoldadas": "destoldar",
    "destoldado": "destoldar",
    "destoldados": "destoldar",
    "destoldai": "destoldar",
    "destoldais": "destoldar",
    "destoldam": "destoldar",
    "destoldamo": "destoldar",
    "destoldamos": "destoldar",
    "destoldando": "destoldar",
    "destoldara": "destoldar",
    "destoldaram": "destoldar",
    "destoldaras": "destoldar",
    "destoldarde": "destoldar",
    "destoldardes": "destoldar",
    "destoldare": "destoldar",
    "destoldarei": "destoldar",
    "destoldareis": "destoldar",
    "destoldarem": "destoldar",
    "destoldaremos": "destoldar",
    "destoldares": "destoldar",
    "destoldaria": "destoldar",
    "destoldariam": "destoldar",
    "destoldarias": "destoldar",
    "destoldarmo": "destoldar",
    "destoldarmos": "destoldar",
    "destoldará": "destoldar",
    "destoldarás": "destoldar",
    "destoldarão": "destoldar",
    "destoldaríamos": "destoldar",
    "destoldaríeis": "destoldar",
    "destoldas": "destoldar",
    "destoldasse": "destoldar",
    "destoldassem": "destoldar",
    "destoldasses": "destoldar",
    "destoldaste": "destoldar",
    "destoldastes": "destoldar",
    "destoldava": "destoldar",
    "destoldavam": "destoldar",
    "destoldavas": "destoldar",
    "destolde": "destoldar",
    "destoldei": "destoldar",
    "destoldeis": "destoldar",
    "destoldem": "destoldar",
    "destoldemo": "destoldar",
    "destoldemos": "destoldar",
    "destoldes": "destoldar",
    "destoldo": "destoldar",
    "destoldou": "destoldar",
    "destoldá": "destoldar",
    "destoldámo": "destoldar",
    "destoldámos": "destoldar",
    "destoldáramo": "destoldar",
    "destoldáramos": "destoldar",
    "destoldárei": "destoldar",
    "destoldáreis": "destoldar",
    "destoldásseis": "destoldar",
    "destoldássemos": "destoldar",
    "destoldávamo": "destoldar",
    "destoldávamos": "destoldar",
    "destoldávei": "destoldar",
    "destoldáveis": "destoldar",
    "destolha": "destolher",
    "destolhais": "destolher",
    "destolham": "destolher",
    "destolhamo": "destolher",
    "destolhamos": "destolher",
    "destolhas": "destolher",
    "destolhe": "destolher",
    "destolhei": "destolher",
    "destolheis": "destolher",
    "destolhem": "destolher",
    "destolhemo": "destolher",
    "destolhemos": "destolher",
    "destolhendo": "destolher",
    "destolhera": "destolher",
    "destolheram": "destolher",
    "destolheras": "destolher",
    "destolherde": "destolher",
    "destolherdes": "destolher",
    "destolhere": "destolher",
    "destolherei": "destolher",
    "destolhereis": "destolher",
    "destolherem": "destolher",
    "destolheremos": "destolher",
    "destolheres": "destolher",
    "destolheria": "destolher",
    "destolheriam": "destolher",
    "destolherias": "destolher",
    "destolhermo": "destolher",
    "destolhermos": "destolher",
    "destolherá": "destolher",
    "destolherás": "destolher",
    "destolherão": "destolher",
    "destolheríamos": "destolher",
    "destolheríeis": "destolher",
    "destolhes": "destolher",
    "destolhesse": "destolher",
    "destolhessem": "destolher",
    "destolhesses": "destolher",
    "destolheste": "destolher",
    "destolhestes": "destolher",
    "destolheu": "destolher",
    "destolhi": "destolher",
    "destolhia": "destolher",
    "destolhiam": "destolher",
    "destolhias": "destolher",
    "destolhida": "destolhido",
    "destolhidas": "destolhido",
    "destolhido": "destolher",
    "destolhidos": "destolhido",
    "destolho": "destolher",
    "destolhê": "destolher",
    "destolhêramo": "destolher",
    "destolhêramos": "destolher",
    "destolhêrei": "destolher",
    "destolhêreis": "destolher",
    "destolhêsseis": "destolher",
    "destolhêssemos": "destolher",
    "destolhíamo": "destolher",
    "destolhíamos": "destolher",
    "destolhíei": "destolher",
    "destolhíeis": "destolher",
    "destombamentos": "destombamento",
    "destona": "destonar",
    "destonada": "destonar",
    "destonadas": "destonar",
    "destonado": "destonar",
    "destonados": "destonar",
    "destonai": "destonar",
    "destonais": "destonar",
    "destonam": "destonar",
    "destonamo": "destonar",
    "destonamos": "destonar",
    "destonando": "destonar",
    "destonara": "destonar",
    "destonaram": "destonar",
    "destonaras": "destonar",
    "destonarde": "destonar",
    "destonardes": "destonar",
    "destonare": "destonar",
    "destonarei": "destonar",
    "destonareis": "destonar",
    "destonarem": "destonar",
    "destonaremos": "destonar",
    "destonares": "destonar",
    "destonaria": "destonar",
    "destonariam": "destonar",
    "destonarias": "destonar",
    "destonarmo": "destonar",
    "destonarmos": "destonar",
    "destonará": "destonar",
    "destonarás": "destonar",
    "destonarão": "destonar",
    "destonaríamos": "destonar",
    "destonaríeis": "destonar",
    "destonas": "destonar",
    "destonasse": "destonar",
    "destonassem": "destonar",
    "destonasses": "destonar",
    "destonaste": "destonar",
    "destonastes": "destonar",
    "destonava": "destonar",
    "destonavam": "destonar",
    "destonavas": "destonar",
    "destone": "destonar",
    "destonei": "destonar",
    "destoneis": "destonar",
    "destonem": "destonar",
    "destonemo": "destonar",
    "destonemos": "destonar",
    "destones": "destonar",
    "destono": "destonar",
    "destonou": "destonar",
    "destons": "destom",
    "destoná": "destonar",
    "destonámo": "destonar",
    "destonámos": "destonar",
    "destonáramo": "destonar",
    "destonáramos": "destonar",
    "destonárei": "destonar",
    "destonáreis": "destonar",
    "destonásseis": "destonar",
    "destonássemos": "destonar",
    "destonávamo": "destonar",
    "destonávamos": "destonar",
    "destonávei": "destonar",
    "destonáveis": "destonar",
    "destoo": "destoar",
    "destoou": "destoar",
    "destoque": "destocar",
    "destoquei": "destocar",
    "destoqueis": "destocar",
    "destoquem": "destocar",
    "destoquemo": "destocar",
    "destoquemos": "destocar",
    "destoques": "destocar",
    "destora": "destorar",
    "destorada": "destorar",
    "destoradas": "destorar",
    "destorado": "destorar",
    "destorados": "destorar",
    "destorai": "destorar",
    "destorais": "destorar",
    "destoram": "destorar",
    "destoramo": "destorar",
    "destoramos": "destorar",
    "destorando": "destorar",
    "destorara": "destorar",
    "destoraram": "destorar",
    "destoraras": "destorar",
    "destorarde": "destorar",
    "destorardes": "destorar",
    "destorare": "destorar",
    "destorarei": "destorar",
    "destorareis": "destorar",
    "destorarem": "destorar",
    "destoraremos": "destorar",
    "destorares": "destorar",
    "destoraria": "destorar",
    "destorariam": "destorar",
    "destorarias": "destorar",
    "destorarmo": "destorar",
    "destorarmos": "destorar",
    "destorará": "destorar",
    "destorarás": "destorar",
    "destorarão": "destorar",
    "destoraríamos": "destorar",
    "destoraríeis": "destorar",
    "destoras": "destorar",
    "destorasse": "destorar",
    "destorassem": "destorar",
    "destorasses": "destorar",
    "destoraste": "destorar",
    "destorastes": "destorar",
    "destorava": "destorar",
    "destoravam": "destorar",
    "destoravas": "destorar",
    "destorce": "destorcer",
    "destorcei": "destorcer",
    "destorceis": "destorcer",
    "destorcem": "destorcer",
    "destorcemo": "destorcer",
    "destorcemos": "destorcer",
    "destorcendo": "destorcer",
    "destorcera": "destorcer",
    "destorceram": "destorcer",
    "destorceras": "destorcer",
    "destorcerde": "destorcer",
    "destorcerdes": "destorcer",
    "destorcere": "destorcer",
    "destorcerei": "destorcer",
    "destorcereis": "destorcer",
    "destorcerem": "destorcer",
    "destorceremos": "destorcer",
    "destorceres": "destorcer",
    "destorceria": "destorcer",
    "destorceriam": "destorcer",
    "destorcerias": "destorcer",
    "destorcermo": "destorcer",
    "destorcermos": "destorcer",
    "destorcerá": "destorcer",
    "destorcerás": "destorcer",
    "destorcerão": "destorcer",
    "destorceríamos": "destorcer",
    "destorceríeis": "destorcer",
    "destorces": "destorcer",
    "destorcesse": "destorcer",
    "destorcessem": "destorcer",
    "destorcesses": "destorcer",
    "destorceste": "destorcer",
    "destorcestes": "destorcer",
    "destorceu": "destorcer",
    "destorci": "destorcer",
    "destorcia": "destorcer",
    "destorciam": "destorcer",
    "destorcias": "destorcer",
    "destorcida": "destorcido",
    "destorcidas": "destorcido",
    "destorcido": "destorcer",
    "destorcidos": "destorcido",
    "destorcimentos": "destorcimento",
    "destorcê": "destorcer",
    "destorcêramo": "destorcer",
    "destorcêramos": "destorcer",
    "destorcêrei": "destorcer",
    "destorcêreis": "destorcer",
    "destorcêsseis": "destorcer",
    "destorcêssemos": "destorcer",
    "destorcíamo": "destorcer",
    "destorcíamos": "destorcer",
    "destorcíei": "destorcer",
    "destorcíeis": "destorcer",
    "destore": "destorar",
    "destorei": "destorar",
    "destoreis": "destorar",
    "destorem": "destorar",
    "destoremo": "destorar",
    "destoremos": "destorar",
    "destores": "destorar",
    "destoro": "destorar",
    "destorou": "destorar",
    "destorpece": "destorpecer",
    "destorpecei": "destorpecer",
    "destorpeceis": "destorpecer",
    "destorpecem": "destorpecer",
    "destorpecemo": "destorpecer",
    "destorpecemos": "destorpecer",
    "destorpecendo": "destorpecer",
    "destorpecera": "destorpecer",
    "destorpeceram": "destorpecer",
    "destorpeceras": "destorpecer",
    "destorpecerde": "destorpecer",
    "destorpecerdes": "destorpecer",
    "destorpecere": "destorpecer",
    "destorpecerei": "destorpecer",
    "destorpecereis": "destorpecer",
    "destorpecerem": "destorpecer",
    "destorpeceremos": "destorpecer",
    "destorpeceres": "destorpecer",
    "destorpeceria": "destorpecer",
    "destorpeceriam": "destorpecer",
    "destorpecerias": "destorpecer",
    "destorpecermo": "destorpecer",
    "destorpecermos": "destorpecer",
    "destorpecerá": "destorpecer",
    "destorpecerás": "destorpecer",
    "destorpecerão": "destorpecer",
    "destorpeceríamos": "destorpecer",
    "destorpeceríeis": "destorpecer",
    "destorpeces": "destorpecer",
    "destorpecesse": "destorpecer",
    "destorpecessem": "destorpecer",
    "destorpecesses": "destorpecer",
    "destorpeceste": "destorpecer",
    "destorpecestes": "destorpecer",
    "destorpeceu": "destorpecer",
    "destorpeci": "destorpecer",
    "destorpecia": "destorpecer",
    "destorpeciam": "destorpecer",
    "destorpecias": "destorpecer",
    "destorpecida": "destorpecido",
    "destorpecidas": "destorpecido",
    "destorpecido": "destorpecer",
    "destorpecidos": "destorpecido",
    "destorpecê": "destorpecer",
    "destorpecêramo": "destorpecer",
    "destorpecêramos": "destorpecer",
    "destorpecêrei": "destorpecer",
    "destorpecêreis": "destorpecer",
    "destorpecêsseis": "destorpecer",
    "destorpecêssemos": "destorpecer",
    "destorpecíamo": "destorpecer",
    "destorpecíamos": "destorpecer",
    "destorpecíei": "destorpecer",
    "destorpecíeis": "destorpecer",
    "destorpeça": "destorpecer",
    "destorpeçais": "destorpecer",
    "destorpeçam": "destorpecer",
    "destorpeçamo": "destorpecer",
    "destorpeçamos": "destorpecer",
    "destorpeças": "destorpecer",
    "destorpeço": "destorpecer",
    "destorroa": "destorroar",
    "destorroada": "destorroar",
    "destorroadas": "destorroar",
    "destorroado": "destorroar",
    "destorroadores": "destorroador",
    "destorroados": "destorroar",
    "destorroai": "destorroar",
    "destorroais": "destorroar",
    "destorroam": "destorroar",
    "destorroamentos": "destorroamento",
    "destorroamo": "destorroar",
    "destorroamos": "destorroar",
    "destorroando": "destorroar",
    "destorroara": "destorroar",
    "destorroaram": "destorroar",
    "destorroaras": "destorroar",
    "destorroarde": "destorroar",
    "destorroardes": "destorroar",
    "destorroare": "destorroar",
    "destorroarei": "destorroar",
    "destorroareis": "destorroar",
    "destorroarem": "destorroar",
    "destorroaremos": "destorroar",
    "destorroares": "destorroar",
    "destorroaria": "destorroar",
    "destorroariam": "destorroar",
    "destorroarias": "destorroar",
    "destorroarmo": "destorroar",
    "destorroarmos": "destorroar",
    "destorroará": "destorroar",
    "destorroarás": "destorroar",
    "destorroarão": "destorroar",
    "destorroaríamos": "destorroar",
    "destorroaríeis": "destorroar",
    "destorroas": "destorroar",
    "destorroasse": "destorroar",
    "destorroassem": "destorroar",
    "destorroasses": "destorroar",
    "destorroaste": "destorroar",
    "destorroastes": "destorroar",
    "destorroava": "destorroar",
    "destorroavam": "destorroar",
    "destorroavas": "destorroar",
    "destorroe": "destorroar",
    "destorroei": "destorroar",
    "destorroeis": "destorroar",
    "destorroem": "destorroar",
    "destorroemo": "destorroar",
    "destorroemos": "destorroar",
    "destorroes": "destorroar",
    "destorroo": "destorroar",
    "destorroou": "destorroar",
    "destorroá": "destorroar",
    "destorroámo": "destorroar",
    "destorroámos": "destorroar",
    "destorroáramo": "destorroar",
    "destorroáramos": "destorroar",
    "destorroárei": "destorroar",
    "destorroáreis": "destorroar",
    "destorroásseis": "destorroar",
    "destorroássemos": "destorroar",
    "destorroávamo": "destorroar",
    "destorroávamos": "destorroar",
    "destorroávei": "destorroar",
    "destorroáveis": "destorroar",
    "destorá": "destorar",
    "destorámo": "destorar",
    "destorámos": "destorar",
    "destoráramo": "destorar",
    "destoráramos": "destorar",
    "destorárei": "destorar",
    "destoráreis": "destorar",
    "destorásseis": "destorar",
    "destorássemos": "destorar",
    "destorávamo": "destorar",
    "destorávamos": "destorar",
    "destorávei": "destorar",
    "destoráveis": "destorar",
    "destorça": "destorcer",
    "destorçais": "destorcer",
    "destorçam": "destorcer",
    "destorçamo": "destorcer",
    "destorçamos": "destorcer",
    "destorças": "destorcer",
    "destorço": "destorcer",
    "destouca": "destoucar",
    "destoucada": "destoucar",
    "destoucadas": "destoucar",
    "destoucado": "destoucar",
    "destoucados": "destoucar",
    "destoucai": "destoucar",
    "destoucais": "destoucar",
    "destoucam": "destoucar",
    "destoucamo": "destoucar",
    "destoucamos": "destoucar",
    "destoucando": "destoucar",
    "destoucara": "destoucar",
    "destoucaram": "destoucar",
    "destoucaras": "destoucar",
    "destoucarde": "destoucar",
    "destoucardes": "destoucar",
    "destoucare": "destoucar",
    "destoucarei": "destoucar",
    "destoucareis": "destoucar",
    "destoucarem": "destoucar",
    "destoucaremos": "destoucar",
    "destoucares": "destoucar",
    "destoucaria": "destoucar",
    "destoucariam": "destoucar",
    "destoucarias": "destoucar",
    "destoucarmo": "destoucar",
    "destoucarmos": "destoucar",
    "destoucará": "destoucar",
    "destoucarás": "destoucar",
    "destoucarão": "destoucar",
    "destoucaríamos": "destoucar",
    "destoucaríeis": "destoucar",
    "destoucas": "destoucar",
    "destoucasse": "destoucar",
    "destoucassem": "destoucar",
    "destoucasses": "destoucar",
    "destoucaste": "destoucar",
    "destoucastes": "destoucar",
    "destoucava": "destoucar",
    "destoucavam": "destoucar",
    "destoucavas": "destoucar",
    "destouco": "destoucar",
    "destoucou": "destoucar",
    "destoucá": "destoucar",
    "destoucámo": "destoucar",
    "destoucámos": "destoucar",
    "destoucáramo": "destoucar",
    "destoucáramos": "destoucar",
    "destoucárei": "destoucar",
    "destoucáreis": "destoucar",
    "destoucásseis": "destoucar",
    "destoucássemos": "destoucar",
    "destoucávamo": "destoucar",
    "destoucávamos": "destoucar",
    "destoucávei": "destoucar",
    "destoucáveis": "destoucar",
    "destouque": "destoucar",
    "destouquei": "destoucar",
    "destouqueis": "destoucar",
    "destouquem": "destoucar",
    "destouquemo": "destoucar",
    "destouquemos": "destoucar",
    "destouques": "destoucar",
    "destoutiçada": "destoutiçado",
    "destoutiçadas": "destoutiçado",
    "destoutiçados": "destoutiçado",
    "destoá": "destoar",
    "destoámo": "destoar",
    "destoámos": "destoar",
    "destoáramo": "destoar",
    "destoáramos": "destoar",
    "destoárei": "destoar",
    "destoáreis": "destoar",
    "destoásseis": "destoar",
    "destoássemos": "destoar",
    "destoávamo": "destoar",
    "destoávamos": "destoar",
    "destoávei": "destoar",
    "destoáveis": "destoar",
    "destra": "destro",
    "destrama": "destramar",
    "destramada": "destramar",
    "destramadas": "destramar",
    "destramado": "destramar",
    "destramados": "destramar",
    "destramai": "destramar",
    "destramais": "destramar",
    "destramam": "destramar",
    "destramamo": "destramar",
    "destramamos": "destramar",
    "destramando": "destramar",
    "destramara": "destramar",
    "destramaram": "destramar",
    "destramaras": "destramar",
    "destramarde": "destramar",
    "destramardes": "destramar",
    "destramare": "destramar",
    "destramarei": "destramar",
    "destramareis": "destramar",
    "destramarem": "destramar",
    "destramaremos": "destramar",
    "destramares": "destramar",
    "destramaria": "destramar",
    "destramariam": "destramar",
    "destramarias": "destramar",
    "destramarmo": "destramar",
    "destramarmos": "destramar",
    "destramará": "destramar",
    "destramarás": "destramar",
    "destramarão": "destramar",
    "destramaríamos": "destramar",
    "destramaríeis": "destramar",
    "destramas": "destramar",
    "destramasse": "destramar",
    "destramassem": "destramar",
    "destramasses": "destramar",
    "destramaste": "destramar",
    "destramastes": "destramar",
    "destramava": "destramar",
    "destramavam": "destramar",
    "destramavas": "destramar",
    "destrambela": "destrambelar",
    "destrambelada": "destrambelar",
    "destrambeladas": "destrambelar",
    "destrambelado": "destrambelar",
    "destrambelados": "destrambelar",
    "destrambelai": "destrambelar",
    "destrambelais": "destrambelar",
    "destrambelam": "destrambelar",
    "destrambelamo": "destrambelar",
    "destrambelamos": "destrambelar",
    "destrambelando": "destrambelar",
    "destrambelara": "destrambelar",
    "destrambelaram": "destrambelar",
    "destrambelaras": "destrambelar",
    "destrambelarde": "destrambelar",
    "destrambelardes": "destrambelar",
    "destrambelare": "destrambelar",
    "destrambelarei": "destrambelar",
    "destrambelareis": "destrambelar",
    "destrambelarem": "destrambelar",
    "destrambelaremos": "destrambelar",
    "destrambelares": "destrambelar",
    "destrambelaria": "destrambelar",
    "destrambelariam": "destrambelar",
    "destrambelarias": "destrambelar",
    "destrambelarmo": "destrambelar",
    "destrambelarmos": "destrambelar",
    "destrambelará": "destrambelar",
    "destrambelarás": "destrambelar",
    "destrambelarão": "destrambelar",
    "destrambelaríamos": "destrambelar",
    "destrambelaríeis": "destrambelar",
    "destrambelas": "destrambelar",
    "destrambelasse": "destrambelar",
    "destrambelassem": "destrambelar",
    "destrambelasses": "destrambelar",
    "destrambelaste": "destrambelar",
    "destrambelastes": "destrambelar",
    "destrambelava": "destrambelar",
    "destrambelavam": "destrambelar",
    "destrambelavas": "destrambelar",
    "destrambele": "destrambelar",
    "destrambelei": "destrambelar",
    "destrambeleis": "destrambelar",
    "destrambelem": "destrambelar",
    "destrambelemo": "destrambelar",
    "destrambelemos": "destrambelar",
    "destrambeles": "destrambelar",
    "destrambelhada": "destrambelhado",
    "destrambelhadas": "destrambelhado",
    "destrambelhados": "destrambelhado",
    "destrambelhadíssima": "destrambelhado",
    "destrambelhadíssimas": "destrambelhado",
    "destrambelhadíssimo": "destrambelhado",
    "destrambelhadíssimos": "destrambelhado",
    "destrambelhamentos": "destrambelhamento",
    "destrambelhos": "destrambelho",
    "destrambelo": "destrambelar",
    "destrambelou": "destrambelar",
    "destrambelá": "destrambelar",
    "destrambelámo": "destrambelar",
    "destrambelámos": "destrambelar",
    "destrambeláramo": "destrambelar",
    "destrambeláramos": "destrambelar",
    "destrambelárei": "destrambelar",
    "destrambeláreis": "destrambelar",
    "destrambelásseis": "destrambelar",
    "destrambelássemos": "destrambelar",
    "destrambelávamo": "destrambelar",
    "destrambelávamos": "destrambelar",
    "destrambelávei": "destrambelar",
    "destrambeláveis": "destrambelar",
    "destrame": "destramar",
    "destramei": "destramar",
    "destrameis": "destramar",
    "destramem": "destramar",
    "destramemo": "destramar",
    "destramemos": "destramar",
    "destrames": "destramar",
    "destramo": "destramar",
    "destramou": "destramar",
    "destramá": "destramar",
    "destramámo": "destramar",
    "destramámos": "destramar",
    "destramáramo": "destramar",
    "destramáramos": "destramar",
    "destramárei": "destramar",
    "destramáreis": "destramar",
    "destramásseis": "destramar",
    "destramássemos": "destramar",
    "destramávamo": "destramar",
    "destramávamos": "destramar",
    "destramávei": "destramar",
    "destramáveis": "destramar",
    "destranca": "destrancar",
    "destrancada": "destrancar",
    "destrancadas": "destrancar",
    "destrancado": "destrancar",
    "destrancados": "destrancar",
    "destrancai": "destrancar",
    "destrancais": "destrancar",
    "destrancam": "destrancar",
    "destrancamo": "destrancar",
    "destrancamos": "destrancar",
    "destrancando": "destrancar",
    "destrancara": "destrancar",
    "destrancaram": "destrancar",
    "destrancaras": "destrancar",
    "destrancarde": "destrancar",
    "destrancardes": "destrancar",
    "destrancare": "destrancar",
    "destrancarei": "destrancar",
    "destrancareis": "destrancar",
    "destrancarem": "destrancar",
    "destrancaremos": "destrancar",
    "destrancares": "destrancar",
    "destrancaria": "destrancar",
    "destrancariam": "destrancar",
    "destrancarias": "destrancar",
    "destrancarmo": "destrancar",
    "destrancarmos": "destrancar",
    "destrancará": "destrancar",
    "destrancarás": "destrancar",
    "destrancarão": "destrancar",
    "destrancaríamos": "destrancar",
    "destrancaríeis": "destrancar",
    "destrancas": "destrancar",
    "destrancasse": "destrancar",
    "destrancassem": "destrancar",
    "destrancasses": "destrancar",
    "destrancaste": "destrancar",
    "destrancastes": "destrancar",
    "destrancava": "destrancar",
    "destrancavam": "destrancar",
    "destrancavas": "destrancar",
    "destrance": "destrançar",
    "destrancei": "destrançar",
    "destranceis": "destrançar",
    "destrancem": "destrançar",
    "destrancemo": "destrançar",
    "destrancemos": "destrançar",
    "destrances": "destrançar",
    "destranco": "destrancar",
    "destrancou": "destrancar",
    "destrancá": "destrancar",
    "destrancámo": "destrancar",
    "destrancámos": "destrancar",
    "destrancáramo": "destrancar",
    "destrancáramos": "destrancar",
    "destrancárei": "destrancar",
    "destrancáreis": "destrancar",
    "destrancásseis": "destrancar",
    "destrancássemos": "destrancar",
    "destrancávamo": "destrancar",
    "destrancávamos": "destrancar",
    "destrancávei": "destrancar",
    "destrancáveis": "destrancar",
    "destranque": "destrancar",
    "destranquei": "destrancar",
    "destranqueis": "destrancar",
    "destranquem": "destrancar",
    "destranquemo": "destrancar",
    "destranquemos": "destrancar",
    "destranques": "destrancar",
    "destrança": "destrançar",
    "destrançada": "destrançar",
    "destrançadas": "destrançar",
    "destrançado": "destrançar",
    "destrançados": "destrançar",
    "destrançai": "destrançar",
    "destrançais": "destrançar",
    "destrançam": "destrançar",
    "destrançamo": "destrançar",
    "destrançamos": "destrançar",
    "destrançando": "destrançar",
    "destrançara": "destrançar",
    "destrançaram": "destrançar",
    "destrançaras": "destrançar",
    "destrançarde": "destrançar",
    "destrançardes": "destrançar",
    "destrançare": "destrançar",
    "destrançarei": "destrançar",
    "destrançareis": "destrançar",
    "destrançarem": "destrançar",
    "destrançaremos": "destrançar",
    "destrançares": "destrançar",
    "destrançaria": "destrançar",
    "destrançariam": "destrançar",
    "destrançarias": "destrançar",
    "destrançarmo": "destrançar",
    "destrançarmos": "destrançar",
    "destrançará": "destrançar",
    "destrançarás": "destrançar",
    "destrançarão": "destrançar",
    "destrançaríamos": "destrançar",
    "destrançaríeis": "destrançar",
    "destranças": "destrançar",
    "destrançasse": "destrançar",
    "destrançassem": "destrançar",
    "destrançasses": "destrançar",
    "destrançaste": "destrançar",
    "destrançastes": "destrançar",
    "destrançava": "destrançar",
    "destrançavam": "destrançar",
    "destrançavas": "destrançar",
    "destranço": "destrançar",
    "destrançou": "destrançar",
    "destrançá": "destrançar",
    "destrançámo": "destrançar",
    "destrançámos": "destrançar",
    "destrançáramo": "destrançar",
    "destrançáramos": "destrançar",
    "destrançárei": "destrançar",
    "destrançáreis": "destrançar",
    "destrançásseis": "destrançar",
    "destrançássemos": "destrançar",
    "destrançávamo": "destrançar",
    "destrançávamos": "destrançar",
    "destrançávei": "destrançar",
    "destrançáveis": "destrançar",
    "destras": "destro",
    "destrata": "destratar",
    "destratada": "destratar",
    "destratadas": "destratar",
    "destratado": "destratar",
    "destratados": "destratar",
    "destratai": "destratar",
    "destratais": "destratar",
    "destratam": "destratar",
    "destratamo": "destratar",
    "destratamos": "destratar",
    "destratando": "destratar",
    "destratara": "destratar",
    "destrataram": "destratar",
    "destrataras": "destratar",
    "destratarde": "destratar",
    "destratardes": "destratar",
    "destratare": "destratar",
    "destratarei": "destratar",
    "destratareis": "destratar",
    "destratarem": "destratar",
    "destrataremos": "destratar",
    "destratares": "destratar",
    "destrataria": "destratar",
    "destratariam": "destratar",
    "destratarias": "destratar",
    "destratarmo": "destratar",
    "destratarmos": "destratar",
    "destratará": "destratar",
    "destratarás": "destratar",
    "destratarão": "destratar",
    "destrataríamos": "destratar",
    "destrataríeis": "destratar",
    "destratas": "destratar",
    "destratasse": "destratar",
    "destratassem": "destratar",
    "destratasses": "destratar",
    "destrataste": "destratar",
    "destratastes": "destratar",
    "destratava": "destratar",
    "destratavam": "destratar",
    "destratavas": "destratar",
    "destrate": "destratar",
    "destratei": "destratar",
    "destrateis": "destratar",
    "destratem": "destratar",
    "destratemo": "destratar",
    "destratemos": "destratar",
    "destrates": "destratar",
    "destrato": "destratar",
    "destratou": "destratar",
    "destratá": "destratar",
    "destratámo": "destratar",
    "destratámos": "destratar",
    "destratáramo": "destratar",
    "destratáramos": "destratar",
    "destratárei": "destratar",
    "destratáreis": "destratar",
    "destratásseis": "destratar",
    "destratássemos": "destratar",
    "destratávamo": "destratar",
    "destratávamos": "destratar",
    "destratávei": "destratar",
    "destratáveis": "destratar",
    "destrava": "destravar",
    "destravada": "destravar",
    "destravadas": "destravar",
    "destravado": "destravar",
    "destravados": "destravar",
    "destravadíssima": "destravado",
    "destravadíssimas": "destravado",
    "destravadíssimo": "destravado",
    "destravadíssimos": "destravado",
    "destravai": "destravar",
    "destravais": "destravar",
    "destravam": "destravar",
    "destravamo": "destravar",
    "destravamos": "destravar",
    "destravando": "destravar",
    "destravara": "destravar",
    "destravaram": "destravar",
    "destravaras": "destravar",
    "destravarde": "destravar",
    "destravardes": "destravar",
    "destravare": "destravar",
    "destravarei": "destravar",
    "destravareis": "destravar",
    "destravarem": "destravar",
    "destravaremos": "destravar",
    "destravares": "destravar",
    "destravaria": "destravar",
    "destravariam": "destravar",
    "destravarias": "destravar",
    "destravarmo": "destravar",
    "destravarmos": "destravar",
    "destravará": "destravar",
    "destravarás": "destravar",
    "destravarão": "destravar",
    "destravaríamos": "destravar",
    "destravaríeis": "destravar",
    "destravas": "destravar",
    "destravasse": "destravar",
    "destravassem": "destravar",
    "destravasses": "destravar",
    "destravaste": "destravar",
    "destravastes": "destravar",
    "destravava": "destravar",
    "destravavam": "destravar",
    "destravavas": "destravar",
    "destrave": "destravar",
    "destravei": "destravar",
    "destraveis": "destravar",
    "destravem": "destravar",
    "destravemo": "destravar",
    "destravemos": "destravar",
    "destraves": "destravar",
    "destravo": "destravar",
    "destravou": "destravar",
    "destravá": "destravar",
    "destravámo": "destravar",
    "destravámos": "destravar",
    "destraváramo": "destravar",
    "destraváramos": "destravar",
    "destravárei": "destravar",
    "destraváreis": "destravar",
    "destravásseis": "destravar",
    "destravássemos": "destravar",
    "destravávamo": "destravar",
    "destravávamos": "destravar",
    "destravávei": "destravar",
    "destraváveis": "destravar",
    "destraçada": "destraçado",
    "destraçadas": "destraçado",
    "destraçados": "destraçado",
    "destreina": "destreinar",
    "destreinada": "destreinar",
    "destreinadas": "destreinar",
    "destreinado": "destreinar",
    "destreinados": "destreinar",
    "destreinai": "destreinar",
    "destreinais": "destreinar",
    "destreinam": "destreinar",
    "destreinamo": "destreinar",
    "destreinamos": "destreinar",
    "destreinando": "destreinar",
    "destreinara": "destreinar",
    "destreinaram": "destreinar",
    "destreinaras": "destreinar",
    "destreinarde": "destreinar",
    "destreinardes": "destreinar",
    "destreinare": "destreinar",
    "destreinarei": "destreinar",
    "destreinareis": "destreinar",
    "destreinarem": "destreinar",
    "destreinaremos": "destreinar",
    "destreinares": "destreinar",
    "destreinaria": "destreinar",
    "destreinariam": "destreinar",
    "destreinarias": "destreinar",
    "destreinarmo": "destreinar",
    "destreinarmos": "destreinar",
    "destreinará": "destreinar",
    "destreinarás": "destreinar",
    "destreinarão": "destreinar",
    "destreinaríamos": "destreinar",
    "destreinaríeis": "destreinar",
    "destreinas": "destreinar",
    "destreinasse": "destreinar",
    "destreinassem": "destreinar",
    "destreinasses": "destreinar",
    "destreinaste": "destreinar",
    "destreinastes": "destreinar",
    "destreinava": "destreinar",
    "destreinavam": "destreinar",
    "destreinavas": "destreinar",
    "destreine": "destreinar",
    "destreinei": "destreinar",
    "destreineis": "destreinar",
    "destreinem": "destreinar",
    "destreinemo": "destreinar",
    "destreinemos": "destreinar",
    "destreines": "destreinar",
    "destreino": "destreinar",
    "destreinou": "destreinar",
    "destreiná": "destreinar",
    "destreinámo": "destreinar",
    "destreinámos": "destreinar",
    "destreináramo": "destreinar",
    "destreináramos": "destreinar",
    "destreinárei": "destreinar",
    "destreináreis": "destreinar",
    "destreinásseis": "destreinar",
    "destreinássemos": "destreinar",
    "destreinávamo": "destreinar",
    "destreinávamos": "destreinar",
    "destreinávei": "destreinar",
    "destreináveis": "destreinar",
    "destrela": "destrelar",
    "destrelada": "destrelar",
    "destreladas": "destrelar",
    "destrelado": "destrelar",
    "destrelados": "destrelar",
    "destrelai": "destrelar",
    "destrelais": "destrelar",
    "destrelam": "destrelar",
    "destrelamo": "destrelar",
    "destrelamos": "destrelar",
    "destrelando": "destrelar",
    "destrelara": "destrelar",
    "destrelaram": "destrelar",
    "destrelaras": "destrelar",
    "destrelardes": "destrelar",
    "destrelarei": "destrelar",
    "destrelareis": "destrelar",
    "destrelarem": "destrelar",
    "destrelaremos": "destrelar",
    "destrelares": "destrelar",
    "destrelaria": "destrelar",
    "destrelariam": "destrelar",
    "destrelarias": "destrelar",
    "destrelarmo": "destrelar",
    "destrelarmos": "destrelar",
    "destrelará": "destrelar",
    "destrelarás": "destrelar",
    "destrelarão": "destrelar",
    "destrelaríamos": "destrelar",
    "destrelaríeis": "destrelar",
    "destrelas": "destrelar",
    "destrelasse": "destrelar",
    "destrelassem": "destrelar",
    "destrelasses": "destrelar",
    "destrelaste": "destrelar",
    "destrelastes": "destrelar",
    "destrelava": "destrelar",
    "destrelavam": "destrelar",
    "destrelavas": "destrelar",
    "destrele": "destrelar",
    "destrelei": "destrelar",
    "destreleis": "destrelar",
    "destrelem": "destrelar",
    "destrelemo": "destrelar",
    "destrelemos": "destrelar",
    "destreles": "destrelar",
    "destrelo": "destrelar",
    "destrelou": "destrelar",
    "destrelámo": "destrelar",
    "destrelámos": "destrelar",
    "destreláramo": "destrelar",
    "destreláramos": "destrelar",
    "destreláreis": "destrelar",
    "destrelásseis": "destrelar",
    "destrelássemos": "destrelar",
    "destrelávamo": "destrelar",
    "destrelávamos": "destrelar",
    "destreláveis": "destrelar",
    "destrezas": "destreza",
    "destri": "destruir",
    "destriba": "destribar",
    "destribada": "destribar",
    "destribadas": "destribar",
    "destribado": "destribar",
    "destribados": "destribar",
    "destribai": "destribar",
    "destribais": "destribar",
    "destribalizações": "destribalização",
    "destribam": "destribar",
    "destribamo": "destribar",
    "destribamos": "destribar",
    "destribando": "destribar",
    "destribara": "destribar",
    "destribaram": "destribar",
    "destribaras": "destribar",
    "destribarde": "destribar",
    "destribardes": "destribar",
    "destribare": "destribar",
    "destribarei": "destribar",
    "destribareis": "destribar",
    "destribarem": "destribar",
    "destribaremos": "destribar",
    "destribares": "destribar",
    "destribaria": "destribar",
    "destribariam": "destribar",
    "destribarias": "destribar",
    "destribarmo": "destribar",
    "destribarmos": "destribar",
    "destribará": "destribar",
    "destribarás": "destribar",
    "destribarão": "destribar",
    "destribaríamos": "destribar",
    "destribaríeis": "destribar",
    "destribas": "destribar",
    "destribasse": "destribar",
    "destribassem": "destribar",
    "destribasses": "destribar",
    "destribaste": "destribar",
    "destribastes": "destribar",
    "destribava": "destribar",
    "destribavam": "destribar",
    "destribavas": "destribar",
    "destribe": "destribar",
    "destribei": "destribar",
    "destribeis": "destribar",
    "destribem": "destribar",
    "destribemo": "destribar",
    "destribemos": "destribar",
    "destribes": "destribar",
    "destribo": "destribar",
    "destribou": "destribar",
    "destribá": "destribar",
    "destribámo": "destribar",
    "destribámos": "destribar",
    "destribáramo": "destribar",
    "destribáramos": "destribar",
    "destribárei": "destribar",
    "destribáreis": "destribar",
    "destribásseis": "destribar",
    "destribássemos": "destribar",
    "destribávamo": "destribar",
    "destribávamos": "destribar",
    "destribávei": "destribar",
    "destribáveis": "destribar",
    "destrimanismos": "destrimanismo",
    "destrinca": "destrincar",
    "destrincada": "destrincar",
    "destrincadas": "destrincar",
    "destrincado": "destrincar",
    "destrincados": "destrincar",
    "destrincai": "destrincar",
    "destrincais": "destrincar",
    "destrincam": "destrincar",
    "destrincamo": "destrincar",
    "destrincamos": "destrincar",
    "destrincando": "destrincar",
    "destrincara": "destrincar",
    "destrincaram": "destrincar",
    "destrincaras": "destrincar",
    "destrincarde": "destrincar",
    "destrincardes": "destrincar",
    "destrincare": "destrincar",
    "destrincarei": "destrincar",
    "destrincareis": "destrincar",
    "destrincarem": "destrincar",
    "destrincaremos": "destrincar",
    "destrincares": "destrincar",
    "destrincaria": "destrincar",
    "destrincariam": "destrincar",
    "destrincarias": "destrincar",
    "destrincarmo": "destrincar",
    "destrincarmos": "destrincar",
    "destrincará": "destrincar",
    "destrincarás": "destrincar",
    "destrincarão": "destrincar",
    "destrincaríamos": "destrincar",
    "destrincaríeis": "destrincar",
    "destrincas": "destrincar",
    "destrincasse": "destrincar",
    "destrincassem": "destrincar",
    "destrincasses": "destrincar",
    "destrincaste": "destrincar",
    "destrincastes": "destrincar",
    "destrincava": "destrincar",
    "destrincavam": "destrincar",
    "destrincavas": "destrincar",
    "destrince": "destrinçar",
    "destrincei": "destrinçar",
    "destrinceis": "destrinçar",
    "destrincem": "destrinçar",
    "destrincemo": "destrinçar",
    "destrincemos": "destrinçar",
    "destrinces": "destrinçar",
    "destrinco": "destrincar",
    "destrincou": "destrincar",
    "destrincá": "destrincar",
    "destrincámo": "destrincar",
    "destrincámos": "destrincar",
    "destrincáramo": "destrincar",
    "destrincáramos": "destrincar",
    "destrincárei": "destrincar",
    "destrincáreis": "destrincar",
    "destrincásseis": "destrincar",
    "destrincássemos": "destrincar",
    "destrincávamo": "destrincar",
    "destrincávamos": "destrincar",
    "destrincávei": "destrincar",
    "destrincáveis": "destrincar",
    "destrinque": "destrincar",
    "destrinquei": "destrincar",
    "destrinqueis": "destrincar",
    "destrinquem": "destrincar",
    "destrinquemo": "destrincar",
    "destrinquemos": "destrincar",
    "destrinques": "destrincar",
    "destrinça": "destrinçar",
    "destrinçada": "destrinçar",
    "destrinçadas": "destrinçar",
    "destrinçado": "destrinçar",
    "destrinçadora": "destrinçador",
    "destrinçadoras": "destrinçador",
    "destrinçadores": "destrinçador",
    "destrinçados": "destrinçar",
    "destrinçai": "destrinçar",
    "destrinçais": "destrinçar",
    "destrinçam": "destrinçar",
    "destrinçamo": "destrinçar",
    "destrinçamos": "destrinçar",
    "destrinçando": "destrinçar",
    "destrinçara": "destrinçar",
    "destrinçaram": "destrinçar",
    "destrinçaras": "destrinçar",
    "destrinçarde": "destrinçar",
    "destrinçardes": "destrinçar",
    "destrinçare": "destrinçar",
    "destrinçarei": "destrinçar",
    "destrinçareis": "destrinçar",
    "destrinçarem": "destrinçar",
    "destrinçaremos": "destrinçar",
    "destrinçares": "destrinçar",
    "destrinçaria": "destrinçar",
    "destrinçariam": "destrinçar",
    "destrinçarias": "destrinçar",
    "destrinçarmo": "destrinçar",
    "destrinçarmos": "destrinçar",
    "destrinçará": "destrinçar",
    "destrinçarás": "destrinçar",
    "destrinçarão": "destrinçar",
    "destrinçaríamos": "destrinçar",
    "destrinçaríeis": "destrinçar",
    "destrinças": "destrinçar",
    "destrinçasse": "destrinçar",
    "destrinçassem": "destrinçar",
    "destrinçasses": "destrinçar",
    "destrinçaste": "destrinçar",
    "destrinçastes": "destrinçar",
    "destrinçava": "destrinçar",
    "destrinçavam": "destrinçar",
    "destrinçavas": "destrinçar",
    "destrinçaveis": "destrinçavel",
    "destrinço": "destrinçar",
    "destrinçou": "destrinçar",
    "destrinçá": "destrinçar",
    "destrinçámo": "destrinçar",
    "destrinçámos": "destrinçar",
    "destrinçáramo": "destrinçar",
    "destrinçáramos": "destrinçar",
    "destrinçárei": "destrinçar",
    "destrinçáreis": "destrinçar",
    "destrinçásseis": "destrinçar",
    "destrinçássemos": "destrinçar",
    "destrinçávamo": "destrinçar",
    "destrinçávamos": "destrinçar",
    "destrinçávei": "destrinçar",
    "destrinçáveis": "destrinçável",
    "destripa": "destripar",
    "destripada": "destripar",
    "destripadas": "destripar",
    "destripado": "destripar",
    "destripados": "destripar",
    "destripai": "destripar",
    "destripais": "destripar",
    "destripam": "destripar",
    "destripamo": "destripar",
    "destripamos": "destripar",
    "destripando": "destripar",
    "destripara": "destripar",
    "destriparam": "destripar",
    "destriparas": "destripar",
    "destriparde": "destripar",
    "destripardes": "destripar",
    "destripare": "destripar",
    "destriparei": "destripar",
    "destripareis": "destripar",
    "destriparem": "destripar",
    "destriparemos": "destripar",
    "destripares": "destripar",
    "destriparia": "destripar",
    "destripariam": "destripar",
    "destriparias": "destripar",
    "destriparmo": "destripar",
    "destriparmos": "destripar",
    "destripará": "destripar",
    "destriparás": "destripar",
    "destriparão": "destripar",
    "destriparíamos": "destripar",
    "destriparíeis": "destripar",
    "destripas": "destripar",
    "destripasse": "destripar",
    "destripassem": "destripar",
    "destripasses": "destripar",
    "destripaste": "destripar",
    "destripastes": "destripar",
    "destripava": "destripar",
    "destripavam": "destripar",
    "destripavas": "destripar",
    "destripe": "destripar",
    "destripei": "destripar",
    "destripeis": "destripar",
    "destripem": "destripar",
    "destripemo": "destripar",
    "destripemos": "destripar",
    "destripes": "destripar",
    "destripo": "destripar",
    "destripou": "destripar",
    "destripulada": "destripulado",
    "destripuladas": "destripulado",
    "destripulados": "destripulado",
    "destripá": "destripar",
    "destripámo": "destripar",
    "destripámos": "destripar",
    "destripáramo": "destripar",
    "destripáramos": "destripar",
    "destripárei": "destripar",
    "destripáreis": "destripar",
    "destripásseis": "destripar",
    "destripássemos": "destripar",
    "destripávamo": "destripar",
    "destripávamos": "destripar",
    "destripávei": "destripar",
    "destripáveis": "destripar",
    "destroca": "destrocar",
    "destrocada": "destrocar",
    "destrocadas": "destrocar",
    "destrocado": "destrocar",
    "destrocados": "destrocar",
    "destrocai": "destrocar",
    "destrocais": "destrocar",
    "destrocam": "destrocar",
    "destrocamo": "destrocar",
    "destrocamos": "destrocar",
    "destrocando": "destrocar",
    "destrocara": "destrocar",
    "destrocaram": "destrocar",
    "destrocaras": "destrocar",
    "destrocarde": "destrocar",
    "destrocardes": "destrocar",
    "destrocare": "destrocar",
    "destrocarei": "destrocar",
    "destrocareis": "destrocar",
    "destrocarem": "destrocar",
    "destrocaremos": "destrocar",
    "destrocares": "destrocar",
    "destrocaria": "destrocar",
    "destrocariam": "destrocar",
    "destrocarias": "destrocar",
    "destrocarmo": "destrocar",
    "destrocarmos": "destrocar",
    "destrocará": "destrocar",
    "destrocarás": "destrocar",
    "destrocarão": "destrocar",
    "destrocaríamos": "destrocar",
    "destrocaríeis": "destrocar",
    "destrocas": "destrocar",
    "destrocasse": "destrocar",
    "destrocassem": "destrocar",
    "destrocasses": "destrocar",
    "destrocaste": "destrocar",
    "destrocastes": "destrocar",
    "destrocava": "destrocar",
    "destrocavam": "destrocar",
    "destrocavas": "destrocar",
    "destroce": "destroçar",
    "destrocei": "destroçar",
    "destroceis": "destroçar",
    "destrocem": "destroçar",
    "destrocemo": "destroçar",
    "destrocemos": "destroçar",
    "destroces": "destroçar",
    "destroco": "destrocar",
    "destrocou": "destrocar",
    "destrocá": "destrocar",
    "destrocámo": "destrocar",
    "destrocámos": "destrocar",
    "destrocáramo": "destrocar",
    "destrocáramos": "destrocar",
    "destrocárei": "destrocar",
    "destrocáreis": "destrocar",
    "destrocásseis": "destrocar",
    "destrocássemos": "destrocar",
    "destrocávamo": "destrocar",
    "destrocávamos": "destrocar",
    "destrocávei": "destrocar",
    "destrocáveis": "destrocar",
    "destroem": "destruir",
    "destrona": "destronar",
    "destronada": "destronar",
    "destronadas": "destronar",
    "destronado": "destronar",
    "destronados": "destronar",
    "destronai": "destronar",
    "destronais": "destronar",
    "destronam": "destronar",
    "destronamentos": "destronamento",
    "destronamo": "destronar",
    "destronamos": "destronar",
    "destronando": "destronar",
    "destronara": "destronar",
    "destronaram": "destronar",
    "destronaras": "destronar",
    "destronarde": "destronar",
    "destronardes": "destronar",
    "destronare": "destronar",
    "destronarei": "destronar",
    "destronareis": "destronar",
    "destronarem": "destronar",
    "destronaremos": "destronar",
    "destronares": "destronar",
    "destronaria": "destronar",
    "destronariam": "destronar",
    "destronarias": "destronar",
    "destronarmo": "destronar",
    "destronarmos": "destronar",
    "destronará": "destronar",
    "destronarás": "destronar",
    "destronarão": "destronar",
    "destronaríamos": "destronar",
    "destronaríeis": "destronar",
    "destronas": "destronar",
    "destronasse": "destronar",
    "destronassem": "destronar",
    "destronasses": "destronar",
    "destronaste": "destronar",
    "destronastes": "destronar",
    "destronava": "destronar",
    "destronavam": "destronar",
    "destronavas": "destronar",
    "destronações": "destronação",
    "destronca": "destroncar",
    "destroncada": "destroncar",
    "destroncadas": "destroncar",
    "destroncado": "destroncar",
    "destroncados": "destroncar",
    "destroncai": "destroncar",
    "destroncais": "destroncar",
    "destroncam": "destroncar",
    "destroncamo": "destroncar",
    "destroncamos": "destroncar",
    "destroncando": "destroncar",
    "destroncara": "destroncar",
    "destroncaram": "destroncar",
    "destroncaras": "destroncar",
    "destroncarde": "destroncar",
    "destroncardes": "destroncar",
    "destroncare": "destroncar",
    "destroncarei": "destroncar",
    "destroncareis": "destroncar",
    "destroncarem": "destroncar",
    "destroncaremos": "destroncar",
    "destroncares": "destroncar",
    "destroncaria": "destroncar",
    "destroncariam": "destroncar",
    "destroncarias": "destroncar",
    "destroncarmo": "destroncar",
    "destroncarmos": "destroncar",
    "destroncará": "destroncar",
    "destroncarás": "destroncar",
    "destroncarão": "destroncar",
    "destroncaríamos": "destroncar",
    "destroncaríeis": "destroncar",
    "destroncas": "destroncar",
    "destroncasse": "destroncar",
    "destroncassem": "destroncar",
    "destroncasses": "destroncar",
    "destroncaste": "destroncar",
    "destroncastes": "destroncar",
    "destroncava": "destroncar",
    "destroncavam": "destroncar",
    "destroncavas": "destroncar",
    "destronco": "destroncar",
    "destroncou": "destroncar",
    "destroncá": "destroncar",
    "destroncámo": "destroncar",
    "destroncámos": "destroncar",
    "destroncáramo": "destroncar",
    "destroncáramos": "destroncar",
    "destroncárei": "destroncar",
    "destroncáreis": "destroncar",
    "destroncásseis": "destroncar",
    "destroncássemos": "destroncar",
    "destroncávamo": "destroncar",
    "destroncávamos": "destroncar",
    "destroncávei": "destroncar",
    "destroncáveis": "destroncar",
    "destrone": "destronar",
    "destronei": "destronar",
    "destroneis": "destronar",
    "destronem": "destronar",
    "destronemo": "destronar",
    "destronemos": "destronar",
    "destrones": "destronar",
    "destroniza": "destronizar",
    "destronizada": "destronizar",
    "destronizadas": "destronizar",
    "destronizado": "destronizar",
    "destronizados": "destronizar",
    "destronizai": "destronizar",
    "destronizais": "destronizar",
    "destronizam": "destronizar",
    "destronizamo": "destronizar",
    "destronizamos": "destronizar",
    "destronizando": "destronizar",
    "destronizara": "destronizar",
    "destronizaram": "destronizar",
    "destronizaras": "destronizar",
    "destronizarde": "destronizar",
    "destronizardes": "destronizar",
    "destronizare": "destronizar",
    "destronizarei": "destronizar",
    "destronizareis": "destronizar",
    "destronizarem": "destronizar",
    "destronizaremos": "destronizar",
    "destronizares": "destronizar",
    "destronizaria": "destronizar",
    "destronizariam": "destronizar",
    "destronizarias": "destronizar",
    "destronizarmo": "destronizar",
    "destronizarmos": "destronizar",
    "destronizará": "destronizar",
    "destronizarás": "destronizar",
    "destronizarão": "destronizar",
    "destronizaríamos": "destronizar",
    "destronizaríeis": "destronizar",
    "destronizas": "destronizar",
    "destronizasse": "destronizar",
    "destronizassem": "destronizar",
    "destronizasses": "destronizar",
    "destronizaste": "destronizar",
    "destronizastes": "destronizar",
    "destronizava": "destronizar",
    "destronizavam": "destronizar",
    "destronizavas": "destronizar",
    "destronizações": "destronização",
    "destronize": "destronizar",
    "destronizei": "destronizar",
    "destronizeis": "destronizar",
    "destronizem": "destronizar",
    "destronizemo": "destronizar",
    "destronizemos": "destronizar",
    "destronizes": "destronizar",
    "destronizo": "destronizar",
    "destronizou": "destronizar",
    "destronizá": "destronizar",
    "destronizámo": "destronizar",
    "destronizámos": "destronizar",
    "destronizáramo": "destronizar",
    "destronizáramos": "destronizar",
    "destronizárei": "destronizar",
    "destronizáreis": "destronizar",
    "destronizásseis": "destronizar",
    "destronizássemos": "destronizar",
    "destronizávamo": "destronizar",
    "destronizávamos": "destronizar",
    "destronizávei": "destronizar",
    "destronizáveis": "destronizar",
    "destrono": "destronar",
    "destronou": "destronar",
    "destronque": "destroncar",
    "destronquei": "destroncar",
    "destronqueis": "destroncar",
    "destronquem": "destroncar",
    "destronquemo": "destroncar",
    "destronquemos": "destroncar",
    "destronques": "destroncar",
    "destroná": "destronar",
    "destronámo": "destronar",
    "destronámos": "destronar",
    "destronáramo": "destronar",
    "destronáramos": "destronar",
    "destronárei": "destronar",
    "destronáreis": "destronar",
    "destronásseis": "destronar",
    "destronássemos": "destronar",
    "destronávamo": "destronar",
    "destronávamos": "destronar",
    "destronávei": "destronar",
    "destronáveis": "destronável",
    "destroque": "destrocar",
    "destroquei": "destrocar",
    "destroqueis": "destrocar",
    "destroquem": "destrocar",
    "destroquemo": "destrocar",
    "destroquemos": "destrocar",
    "destroques": "destrocar",
    "destros": "destro",
    "destroça": "destroçar",
    "destroçada": "destroçar",
    "destroçadas": "destroçar",
    "destroçado": "destroçar",
    "destroçadora": "destroçador",
    "destroçadoras": "destroçador",
    "destroçadores": "destroçador",
    "destroçados": "destroçar",
    "destroçadíssima": "destroçado",
    "destroçadíssimas": "destroçado",
    "destroçadíssimo": "destroçado",
    "destroçadíssimos": "destroçado",
    "destroçai": "destroçar",
    "destroçais": "destroçar",
    "destroçam": "destroçar",
    "destroçamo": "destroçar",
    "destroçamos": "destroçar",
    "destroçando": "destroçar",
    "destroçara": "destroçar",
    "destroçaram": "destroçar",
    "destroçaras": "destroçar",
    "destroçarde": "destroçar",
    "destroçardes": "destroçar",
    "destroçare": "destroçar",
    "destroçarei": "destroçar",
    "destroçareis": "destroçar",
    "destroçarem": "destroçar",
    "destroçaremos": "destroçar",
    "destroçares": "destroçar",
    "destroçaria": "destroçar",
    "destroçariam": "destroçar",
    "destroçarias": "destroçar",
    "destroçarmo": "destroçar",
    "destroçarmos": "destroçar",
    "destroçará": "destroçar",
    "destroçarás": "destroçar",
    "destroçarão": "destroçar",
    "destroçaríamos": "destroçar",
    "destroçaríeis": "destroçar",
    "destroças": "destroçar",
    "destroçasse": "destroçar",
    "destroçassem": "destroçar",
    "destroçasses": "destroçar",
    "destroçaste": "destroçar",
    "destroçastes": "destroçar",
    "destroçava": "destroçar",
    "destroçavam": "destroçar",
    "destroçavas": "destroçar",
    "destroço": "destroçar",
    "destroços": "destroço",
    "destroçou": "destroçar",
    "destroçá": "destroçar",
    "destroçámo": "destroçar",
    "destroçámos": "destroçar",
    "destroçáramo": "destroçar",
    "destroçáramos": "destroçar",
    "destroçárei": "destroçar",
    "destroçáreis": "destroçar",
    "destroçásseis": "destroçar",
    "destroçássemos": "destroçar",
    "destroçávamo": "destroçar",
    "destroçávamos": "destroçar",
    "destroçávei": "destroçar",
    "destroçáveis": "destroçar",
    "destrua": "destruir",
    "destruais": "destruir",
    "destruam": "destruir",
    "destruamo": "destruir",
    "destruamos": "destruir",
    "destruas": "destruir",
    "destruem": "destruir",
    "destrui": "destruir",
    "destruidora": "destruidor",
    "destruidoras": "destruidor",
    "destruidores": "destruidor",
    "destruindo": "destruir",
    "destruirde": "destruir",
    "destruirdes": "destruir",
    "destruirei": "destruir",
    "destruireis": "destruir",
    "destruiremos": "destruir",
    "destruiria": "destruir",
    "destruiriam": "destruir",
    "destruirias": "destruir",
    "destruirmo": "destruir",
    "destruirmos": "destruir",
    "destruirá": "destruir",
    "destruirás": "destruir",
    "destruirão": "destruir",
    "destruiríamos": "destruir",
    "destruiríeis": "destruir",
    "destruis": "destruir",
    "destruiu": "destruir",
    "destruições": "destruição",
    "destrunfa": "destrunfar",
    "destrunfada": "destrunfar",
    "destrunfadas": "destrunfar",
    "destrunfado": "destrunfar",
    "destrunfados": "destrunfar",
    "destrunfai": "destrunfar",
    "destrunfais": "destrunfar",
    "destrunfam": "destrunfar",
    "destrunfamo": "destrunfar",
    "destrunfamos": "destrunfar",
    "destrunfando": "destrunfar",
    "destrunfara": "destrunfar",
    "destrunfaram": "destrunfar",
    "destrunfaras": "destrunfar",
    "destrunfarde": "destrunfar",
    "destrunfardes": "destrunfar",
    "destrunfare": "destrunfar",
    "destrunfarei": "destrunfar",
    "destrunfareis": "destrunfar",
    "destrunfarem": "destrunfar",
    "destrunfaremos": "destrunfar",
    "destrunfares": "destrunfar",
    "destrunfaria": "destrunfar",
    "destrunfariam": "destrunfar",
    "destrunfarias": "destrunfar",
    "destrunfarmo": "destrunfar",
    "destrunfarmos": "destrunfar",
    "destrunfará": "destrunfar",
    "destrunfarás": "destrunfar",
    "destrunfarão": "destrunfar",
    "destrunfaríamos": "destrunfar",
    "destrunfaríeis": "destrunfar",
    "destrunfas": "destrunfar",
    "destrunfasse": "destrunfar",
    "destrunfassem": "destrunfar",
    "destrunfasses": "destrunfar",
    "destrunfaste": "destrunfar",
    "destrunfastes": "destrunfar",
    "destrunfava": "destrunfar",
    "destrunfavam": "destrunfar",
    "destrunfavas": "destrunfar",
    "destrunfe": "destrunfar",
    "destrunfei": "destrunfar",
    "destrunfeis": "destrunfar",
    "destrunfem": "destrunfar",
    "destrunfemo": "destrunfar",
    "destrunfemos": "destrunfar",
    "destrunfes": "destrunfar",
    "destrunfo": "destrunfar",
    "destrunfou": "destrunfar",
    "destrunfá": "destrunfar",
    "destrunfámo": "destrunfar",
    "destrunfámos": "destrunfar",
    "destrunfáramo": "destrunfar",
    "destrunfáramos": "destrunfar",
    "destrunfárei": "destrunfar",
    "destrunfáreis": "destrunfar",
    "destrunfásseis": "destrunfar",
    "destrunfássemos": "destrunfar",
    "destrunfávamo": "destrunfar",
    "destrunfávamos": "destrunfar",
    "destrunfávei": "destrunfar",
    "destrunfáveis": "destrunfar",
    "destruo": "destruir",
    "destrutibilidades": "destrutibilidade",
    "destrutiva": "destrutivo",
    "destrutivas": "destrutivo",
    "destrutividades": "destrutividade",
    "destrutivos": "destrutivo",
    "destrutora": "destrutor",
    "destrutoras": "destrutor",
    "destrutores": "destrutor",
    "destrutíveis": "destrutível",
    "destruvada": "destruvado",
    "destruvadas": "destruvado",
    "destruvados": "destruvado",
    "destruí": "destruir",
    "destruía": "destruir",
    "destruíam": "destruir",
    "destruíamo": "destruir",
    "destruíamos": "destruir",
    "destruías": "destruir",
    "destruída": "destruir",
    "destruídas": "destruir",
    "destruído": "destruir",
    "destruídos": "destruir",
    "destruíei": "destruir",
    "destruíeis": "destruir",
    "destruímo": "destruir",
    "destruímos": "destruir",
    "destruíra": "destruir",
    "destruíram": "destruir",
    "destruíramo": "destruir",
    "destruíramos": "destruir",
    "destruíras": "destruir",
    "destruíre": "destruir",
    "destruírei": "destruir",
    "destruíreis": "destruir",
    "destruírem": "destruir",
    "destruíres": "destruir",
    "destruís": "destruir",
    "destruísse": "destruir",
    "destruísseis": "destruir",
    "destruíssem": "destruir",
    "destruíssemos": "destruir",
    "destruísses": "destruir",
    "destruíste": "destruir",
    "destruístes": "destruir",
    "destruíveis": "destruível",
    "destrímana": "destrímano",
    "destrímanas": "destrímano",
    "destrímanos": "destrímano",
    "destrói": "destruir",
    "destróieres": "destróier",
    "destróis": "destruir",
    "desturva": "desturvar",
    "desturvada": "desturvar",
    "desturvadas": "desturvar",
    "desturvado": "desturvar",
    "desturvados": "desturvar",
    "desturvai": "desturvar",
    "desturvais": "desturvar",
    "desturvam": "desturvar",
    "desturvamo": "desturvar",
    "desturvamos": "desturvar",
    "desturvando": "desturvar",
    "desturvara": "desturvar",
    "desturvaram": "desturvar",
    "desturvaras": "desturvar",
    "desturvarde": "desturvar",
    "desturvardes": "desturvar",
    "desturvare": "desturvar",
    "desturvarei": "desturvar",
    "desturvareis": "desturvar",
    "desturvarem": "desturvar",
    "desturvaremos": "desturvar",
    "desturvares": "desturvar",
    "desturvaria": "desturvar",
    "desturvariam": "desturvar",
    "desturvarias": "desturvar",
    "desturvarmo": "desturvar",
    "desturvarmos": "desturvar",
    "desturvará": "desturvar",
    "desturvarás": "desturvar",
    "desturvarão": "desturvar",
    "desturvaríamos": "desturvar",
    "desturvaríeis": "desturvar",
    "desturvas": "desturvar",
    "desturvasse": "desturvar",
    "desturvassem": "desturvar",
    "desturvasses": "desturvar",
    "desturvaste": "desturvar",
    "desturvastes": "desturvar",
    "desturvava": "desturvar",
    "desturvavam": "desturvar",
    "desturvavas": "desturvar",
    "desturve": "desturvar",
    "desturvei": "desturvar",
    "desturveis": "desturvar",
    "desturvem": "desturvar",
    "desturvemo": "desturvar",
    "desturvemos": "desturvar",
    "desturves": "desturvar",
    "desturvo": "desturvar",
    "desturvou": "desturvar",
    "desturvá": "desturvar",
    "desturvámo": "desturvar",
    "desturvámos": "desturvar",
    "desturváramo": "desturvar",
    "desturváramos": "desturvar",
    "desturvárei": "desturvar",
    "desturváreis": "desturvar",
    "desturvásseis": "desturvar",
    "desturvássemos": "desturvar",
    "desturvávamo": "desturvar",
    "desturvávamos": "desturvar",
    "desturvávei": "desturvar",
    "desturváveis": "desturvar",
    "destêmperas": "destêmpera",
    "destímida": "destímido",
    "destímidas": "destímido",
    "destímidos": "destímido",
    "desultraja": "desultrajar",
    "desultrajada": "desultrajar",
    "desultrajadas": "desultrajar",
    "desultrajado": "desultrajar",
    "desultrajados": "desultrajar",
    "desultrajai": "desultrajar",
    "desultrajais": "desultrajar",
    "desultrajam": "desultrajar",
    "desultrajamo": "desultrajar",
    "desultrajamos": "desultrajar",
    "desultrajando": "desultrajar",
    "desultrajara": "desultrajar",
    "desultrajaram": "desultrajar",
    "desultrajaras": "desultrajar",
    "desultrajarde": "desultrajar",
    "desultrajardes": "desultrajar",
    "desultrajare": "desultrajar",
    "desultrajarei": "desultrajar",
    "desultrajareis": "desultrajar",
    "desultrajarem": "desultrajar",
    "desultrajaremos": "desultrajar",
    "desultrajares": "desultrajar",
    "desultrajaria": "desultrajar",
    "desultrajariam": "desultrajar",
    "desultrajarias": "desultrajar",
    "desultrajarmo": "desultrajar",
    "desultrajarmos": "desultrajar",
    "desultrajará": "desultrajar",
    "desultrajarás": "desultrajar",
    "desultrajarão": "desultrajar",
    "desultrajaríamos": "desultrajar",
    "desultrajaríeis": "desultrajar",
    "desultrajas": "desultrajar",
    "desultrajasse": "desultrajar",
    "desultrajassem": "desultrajar",
    "desultrajasses": "desultrajar",
    "desultrajaste": "desultrajar",
    "desultrajastes": "desultrajar",
    "desultrajava": "desultrajar",
    "desultrajavam": "desultrajar",
    "desultrajavas": "desultrajar",
    "desultraje": "desultrajar",
    "desultrajei": "desultrajar",
    "desultrajeis": "desultrajar",
    "desultrajem": "desultrajar",
    "desultrajemo": "desultrajar",
    "desultrajemos": "desultrajar",
    "desultrajes": "desultrajar",
    "desultrajo": "desultrajar",
    "desultrajou": "desultrajar",
    "desultrajá": "desultrajar",
    "desultrajámo": "desultrajar",
    "desultrajámos": "desultrajar",
    "desultrajáramo": "desultrajar",
    "desultrajáramos": "desultrajar",
    "desultrajárei": "desultrajar",
    "desultrajáreis": "desultrajar",
    "desultrajásseis": "desultrajar",
    "desultrajássemos": "desultrajar",
    "desultrajávamo": "desultrajar",
    "desultrajávamos": "desultrajar",
    "desultrajávei": "desultrajar",
    "desultrajáveis": "desultrajar",
    "desumana": "desumano",
    "desumanas": "desumano",
    "desumanidades": "desumanidade",
    "desumaniza": "desumanizar",
    "desumanizada": "desumanizar",
    "desumanizadas": "desumanizar",
    "desumanizado": "desumanizar",
    "desumanizados": "desumanizar",
    "desumanizai": "desumanizar",
    "desumanizais": "desumanizar",
    "desumanizam": "desumanizar",
    "desumanizamo": "desumanizar",
    "desumanizamos": "desumanizar",
    "desumanizando": "desumanizar",
    "desumanizara": "desumanizar",
    "desumanizaram": "desumanizar",
    "desumanizaras": "desumanizar",
    "desumanizarde": "desumanizar",
    "desumanizardes": "desumanizar",
    "desumanizare": "desumanizar",
    "desumanizarei": "desumanizar",
    "desumanizareis": "desumanizar",
    "desumanizarem": "desumanizar",
    "desumanizaremos": "desumanizar",
    "desumanizares": "desumanizar",
    "desumanizaria": "desumanizar",
    "desumanizariam": "desumanizar",
    "desumanizarias": "desumanizar",
    "desumanizarmo": "desumanizar",
    "desumanizarmos": "desumanizar",
    "desumanizará": "desumanizar",
    "desumanizarás": "desumanizar",
    "desumanizarão": "desumanizar",
    "desumanizaríamos": "desumanizar",
    "desumanizaríeis": "desumanizar",
    "desumanizas": "desumanizar",
    "desumanizasse": "desumanizar",
    "desumanizassem": "desumanizar",
    "desumanizasses": "desumanizar",
    "desumanizaste": "desumanizar",
    "desumanizastes": "desumanizar",
    "desumanizava": "desumanizar",
    "desumanizavam": "desumanizar",
    "desumanizavas": "desumanizar",
    "desumanizações": "desumanização",
    "desumanize": "desumanizar",
    "desumanizei": "desumanizar",
    "desumanizeis": "desumanizar",
    "desumanizem": "desumanizar",
    "desumanizemo": "desumanizar",
    "desumanizemos": "desumanizar",
    "desumanizes": "desumanizar",
    "desumanizo": "desumanizar",
    "desumanizou": "desumanizar",
    "desumanizá": "desumanizar",
    "desumanizámo": "desumanizar",
    "desumanizámos": "desumanizar",
    "desumanizáramo": "desumanizar",
    "desumanizáramos": "desumanizar",
    "desumanizárei": "desumanizar",
    "desumanizáreis": "desumanizar",
    "desumanizásseis": "desumanizar",
    "desumanizássemos": "desumanizar",
    "desumanizávamo": "desumanizar",
    "desumanizávamos": "desumanizar",
    "desumanizávei": "desumanizar",
    "desumanizáveis": "desumanizar",
    "desumanos": "desumano",
    "desumedecida": "desumedecido",
    "desumedecidas": "desumedecido",
    "desumedecidos": "desumedecido",
    "desumidifica": "desumidificar",
    "desumidificada": "desumidificar",
    "desumidificadas": "desumidificar",
    "desumidificado": "desumidificar",
    "desumidificadora": "desumidificador",
    "desumidificadoras": "desumidificador",
    "desumidificadores": "desumidificador",
    "desumidificados": "desumidificar",
    "desumidificais": "desumidificar",
    "desumidificam": "desumidificar",
    "desumidificamo": "desumidificar",
    "desumidificamos": "desumidificar",
    "desumidificando": "desumidificar",
    "desumidificara": "desumidificar",
    "desumidificaram": "desumidificar",
    "desumidificaras": "desumidificar",
    "desumidificardes": "desumidificar",
    "desumidificarei": "desumidificar",
    "desumidificareis": "desumidificar",
    "desumidificarem": "desumidificar",
    "desumidificaremos": "desumidificar",
    "desumidificares": "desumidificar",
    "desumidificaria": "desumidificar",
    "desumidificariam": "desumidificar",
    "desumidificarias": "desumidificar",
    "desumidificarmo": "desumidificar",
    "desumidificarmos": "desumidificar",
    "desumidificará": "desumidificar",
    "desumidificarás": "desumidificar",
    "desumidificarão": "desumidificar",
    "desumidificaríamos": "desumidificar",
    "desumidificaríeis": "desumidificar",
    "desumidificas": "desumidificar",
    "desumidificasse": "desumidificar",
    "desumidificassem": "desumidificar",
    "desumidificasses": "desumidificar",
    "desumidificaste": "desumidificar",
    "desumidificastes": "desumidificar",
    "desumidificava": "desumidificar",
    "desumidificavam": "desumidificar",
    "desumidificavas": "desumidificar",
    "desumidificações": "desumidificação",
    "desumidifico": "desumidificar",
    "desumidificou": "desumidificar",
    "desumidificámo": "desumidificar",
    "desumidificámos": "desumidificar",
    "desumidificáramo": "desumidificar",
    "desumidificáramos": "desumidificar",
    "desumidificáreis": "desumidificar",
    "desumidificásseis": "desumidificar",
    "desumidificássemos": "desumidificar",
    "desumidificávamo": "desumidificar",
    "desumidificávamos": "desumidificar",
    "desumidificáveis": "desumidificar",
    "desumidifique": "desumidificar",
    "desumidifiquei": "desumidificar",
    "desumidifiqueis": "desumidificar",
    "desumidifiquem": "desumidificar",
    "desumidifiquemos": "desumidificar",
    "desumidifiques": "desumidificar",
    "desumildes": "desumilde",
    "desuna": "desunir",
    "desunais": "desunir",
    "desunam": "desunir",
    "desunamo": "desunir",
    "desunamos": "desunir",
    "desunas": "desunir",
    "desune": "desunir",
    "desunem": "desunir",
    "desunes": "desunir",
    "desunha": "desunhar",
    "desunhada": "desunhar",
    "desunhadas": "desunhar",
    "desunhado": "desunhar",
    "desunhados": "desunhar",
    "desunhai": "desunhar",
    "desunhais": "desunhar",
    "desunham": "desunhar",
    "desunhamo": "desunhar",
    "desunhamos": "desunhar",
    "desunhando": "desunhar",
    "desunhara": "desunhar",
    "desunharam": "desunhar",
    "desunharas": "desunhar",
    "desunharde": "desunhar",
    "desunhardes": "desunhar",
    "desunhare": "desunhar",
    "desunharei": "desunhar",
    "desunhareis": "desunhar",
    "desunharem": "desunhar",
    "desunharemos": "desunhar",
    "desunhares": "desunhar",
    "desunharia": "desunhar",
    "desunhariam": "desunhar",
    "desunharias": "desunhar",
    "desunharmo": "desunhar",
    "desunharmos": "desunhar",
    "desunhará": "desunhar",
    "desunharás": "desunhar",
    "desunharão": "desunhar",
    "desunharíamos": "desunhar",
    "desunharíeis": "desunhar",
    "desunhas": "desunhar",
    "desunhasse": "desunhar",
    "desunhassem": "desunhar",
    "desunhasses": "desunhar",
    "desunhaste": "desunhar",
    "desunhastes": "desunhar",
    "desunhava": "desunhar",
    "desunhavam": "desunhar",
    "desunhavas": "desunhar",
    "desunhe": "desunhar",
    "desunhei": "desunhar",
    "desunheis": "desunhar",
    "desunhem": "desunhar",
    "desunhemo": "desunhar",
    "desunhemos": "desunhar",
    "desunhes": "desunhar",
    "desunho": "desunhar",
    "desunhou": "desunhar",
    "desunhá": "desunhar",
    "desunhámo": "desunhar",
    "desunhámos": "desunhar",
    "desunháramo": "desunhar",
    "desunháramos": "desunhar",
    "desunhárei": "desunhar",
    "desunháreis": "desunhar",
    "desunhásseis": "desunhar",
    "desunhássemos": "desunhar",
    "desunhávamo": "desunhar",
    "desunhávamos": "desunhar",
    "desunhávei": "desunhar",
    "desunháveis": "desunhar",
    "desuni": "desunir",
    "desunia": "desunir",
    "desuniam": "desunir",
    "desunias": "desunir",
    "desunida": "desunir",
    "desunidas": "desunir",
    "desunido": "desunir",
    "desunidos": "desunir",
    "desunifica": "desunificar",
    "desunificada": "desunificar",
    "desunificadas": "desunificar",
    "desunificado": "desunificar",
    "desunificados": "desunificar",
    "desunificai": "desunificar",
    "desunificais": "desunificar",
    "desunificam": "desunificar",
    "desunificamo": "desunificar",
    "desunificamos": "desunificar",
    "desunificando": "desunificar",
    "desunificara": "desunificar",
    "desunificaram": "desunificar",
    "desunificaras": "desunificar",
    "desunificarde": "desunificar",
    "desunificardes": "desunificar",
    "desunificare": "desunificar",
    "desunificarei": "desunificar",
    "desunificareis": "desunificar",
    "desunificarem": "desunificar",
    "desunificaremos": "desunificar",
    "desunificares": "desunificar",
    "desunificaria": "desunificar",
    "desunificariam": "desunificar",
    "desunificarias": "desunificar",
    "desunificarmo": "desunificar",
    "desunificarmos": "desunificar",
    "desunificará": "desunificar",
    "desunificarás": "desunificar",
    "desunificarão": "desunificar",
    "desunificaríamos": "desunificar",
    "desunificaríeis": "desunificar",
    "desunificas": "desunificar",
    "desunificasse": "desunificar",
    "desunificassem": "desunificar",
    "desunificasses": "desunificar",
    "desunificaste": "desunificar",
    "desunificastes": "desunificar",
    "desunificava": "desunificar",
    "desunificavam": "desunificar",
    "desunificavas": "desunificar",
    "desunificações": "desunificação",
    "desunifico": "desunificar",
    "desunificou": "desunificar",
    "desunificá": "desunificar",
    "desunificámo": "desunificar",
    "desunificámos": "desunificar",
    "desunificáramo": "desunificar",
    "desunificáramos": "desunificar",
    "desunificárei": "desunificar",
    "desunificáreis": "desunificar",
    "desunificásseis": "desunificar",
    "desunificássemos": "desunificar",
    "desunificávamo": "desunificar",
    "desunificávamos": "desunificar",
    "desunificávei": "desunificar",
    "desunificáveis": "desunificar",
    "desunifique": "desunificar",
    "desunifiquei": "desunificar",
    "desunifiqueis": "desunificar",
    "desunifiquem": "desunificar",
    "desunifiquemo": "desunificar",
    "desunifiquemos": "desunificar",
    "desunifiques": "desunificar",
    "desunimo": "desunir",
    "desunimos": "desunir",
    "desunindo": "desunir",
    "desunira": "desunir",
    "desuniram": "desunir",
    "desuniras": "desunir",
    "desunirde": "desunir",
    "desunirdes": "desunir",
    "desunire": "desunir",
    "desunirei": "desunir",
    "desunireis": "desunir",
    "desunirem": "desunir",
    "desuniremos": "desunir",
    "desunires": "desunir",
    "desuniria": "desunir",
    "desuniriam": "desunir",
    "desunirias": "desunir",
    "desunirmo": "desunir",
    "desunirmos": "desunir",
    "desunirá": "desunir",
    "desunirás": "desunir",
    "desunirão": "desunir",
    "desuniríamos": "desunir",
    "desuniríeis": "desunir",
    "desunis": "desunir",
    "desunisse": "desunir",
    "desunissem": "desunir",
    "desunisses": "desunir",
    "desuniste": "desunir",
    "desunistes": "desunir",
    "desuniu": "desunir",
    "desuniões": "desunião",
    "desuno": "desunir",
    "desuníamo": "desunir",
    "desuníamos": "desunir",
    "desuníei": "desunir",
    "desuníeis": "desunir",
    "desuníramo": "desunir",
    "desuníramos": "desunir",
    "desunírei": "desunir",
    "desuníreis": "desunir",
    "desunísseis": "desunir",
    "desuníssemos": "desunir",
    "desuníssona": "desuníssono",
    "desuníssonas": "desuníssono",
    "desuníssonos": "desuníssono",
    "desuníveis": "desunível",
    "desurda": "desurdir",
    "desurdais": "desurdir",
    "desurdam": "desurdir",
    "desurdamo": "desurdir",
    "desurdamos": "desurdir",
    "desurdas": "desurdir",
    "desurde": "desurdir",
    "desurdem": "desurdir",
    "desurdes": "desurdir",
    "desurdi": "desurdir",
    "desurdia": "desurdir",
    "desurdiam": "desurdir",
    "desurdias": "desurdir",
    "desurdida": "desurdir",
    "desurdidas": "desurdir",
    "desurdido": "desurdir",
    "desurdidos": "desurdir",
    "desurdimo": "desurdir",
    "desurdimos": "desurdir",
    "desurdindo": "desurdir",
    "desurdira": "desurdir",
    "desurdiram": "desurdir",
    "desurdiras": "desurdir",
    "desurdirde": "desurdir",
    "desurdirdes": "desurdir",
    "desurdire": "desurdir",
    "desurdirei": "desurdir",
    "desurdireis": "desurdir",
    "desurdirem": "desurdir",
    "desurdiremos": "desurdir",
    "desurdires": "desurdir",
    "desurdiria": "desurdir",
    "desurdiriam": "desurdir",
    "desurdirias": "desurdir",
    "desurdirmo": "desurdir",
    "desurdirmos": "desurdir",
    "desurdirá": "desurdir",
    "desurdirás": "desurdir",
    "desurdirão": "desurdir",
    "desurdiríamos": "desurdir",
    "desurdiríeis": "desurdir",
    "desurdis": "desurdir",
    "desurdisse": "desurdir",
    "desurdissem": "desurdir",
    "desurdisses": "desurdir",
    "desurdiste": "desurdir",
    "desurdistes": "desurdir",
    "desurdiu": "desurdir",
    "desurdo": "desurdir",
    "desurdíamo": "desurdir",
    "desurdíamos": "desurdir",
    "desurdíei": "desurdir",
    "desurdíeis": "desurdir",
    "desurdíramo": "desurdir",
    "desurdíramos": "desurdir",
    "desurdírei": "desurdir",
    "desurdíreis": "desurdir",
    "desurdísseis": "desurdir",
    "desurdíssemos": "desurdir",
    "desusa": "desusar",
    "desusada": "desusar",
    "desusadas": "desusar",
    "desusado": "desusar",
    "desusados": "desusar",
    "desusai": "desusar",
    "desusais": "desusar",
    "desusam": "desusar",
    "desusamo": "desusar",
    "desusamos": "desusar",
    "desusando": "desusar",
    "desusara": "desusar",
    "desusaram": "desusar",
    "desusaras": "desusar",
    "desusarde": "desusar",
    "desusardes": "desusar",
    "desusare": "desusar",
    "desusarei": "desusar",
    "desusareis": "desusar",
    "desusarem": "desusar",
    "desusaremos": "desusar",
    "desusares": "desusar",
    "desusaria": "desusar",
    "desusariam": "desusar",
    "desusarias": "desusar",
    "desusarmo": "desusar",
    "desusarmos": "desusar",
    "desusará": "desusar",
    "desusarás": "desusar",
    "desusarão": "desusar",
    "desusaríamos": "desusar",
    "desusaríeis": "desusar",
    "desusas": "desusar",
    "desusasse": "desusar",
    "desusassem": "desusar",
    "desusasses": "desusar",
    "desusaste": "desusar",
    "desusastes": "desusar",
    "desusava": "desusar",
    "desusavam": "desusar",
    "desusavas": "desusar",
    "desuse": "desusar",
    "desusei": "desusar",
    "desuseis": "desusar",
    "desusem": "desusar",
    "desusemo": "desusar",
    "desusemos": "desusar",
    "desuses": "desusar",
    "desuso": "desusar",
    "desusos": "desuso",
    "desusou": "desusar",
    "desusuais": "desusual",
    "desusá": "desusar",
    "desusámo": "desusar",
    "desusámos": "desusar",
    "desusáramo": "desusar",
    "desusáramos": "desusar",
    "desusárei": "desusar",
    "desusáreis": "desusar",
    "desusásseis": "desusar",
    "desusássemos": "desusar",
    "desusávamo": "desusar",
    "desusávamos": "desusar",
    "desusávei": "desusar",
    "desusáveis": "desusar",
    "desutilidades": "desutilidade",
    "desvaece": "desvaecer",
    "desvaecei": "desvaecer",
    "desvaeceis": "desvaecer",
    "desvaecem": "desvaecer",
    "desvaecemo": "desvaecer",
    "desvaecemos": "desvaecer",
    "desvaecendo": "desvaecer",
    "desvaecera": "desvaecer",
    "desvaeceram": "desvaecer",
    "desvaeceras": "desvaecer",
    "desvaecerdes": "desvaecer",
    "desvaecerei": "desvaecer",
    "desvaecereis": "desvaecer",
    "desvaecerem": "desvaecer",
    "desvaeceremos": "desvaecer",
    "desvaeceres": "desvaecer",
    "desvaeceria": "desvaecer",
    "desvaeceriam": "desvaecer",
    "desvaecerias": "desvaecer",
    "desvaecermo": "desvaecer",
    "desvaecermos": "desvaecer",
    "desvaecerá": "desvaecer",
    "desvaecerás": "desvaecer",
    "desvaecerão": "desvaecer",
    "desvaeceríamos": "desvaecer",
    "desvaeceríeis": "desvaecer",
    "desvaeces": "desvaecer",
    "desvaecesse": "desvaecer",
    "desvaecessem": "desvaecer",
    "desvaecesses": "desvaecer",
    "desvaeceste": "desvaecer",
    "desvaecestes": "desvaecer",
    "desvaeceu": "desvaecer",
    "desvaeci": "desvaecer",
    "desvaecia": "desvaecer",
    "desvaeciam": "desvaecer",
    "desvaecias": "desvaecer",
    "desvaecida": "desvaecer",
    "desvaecidas": "desvaecer",
    "desvaecido": "desvaecer",
    "desvaecidos": "desvaecer",
    "desvaecêramo": "desvaecer",
    "desvaecêramos": "desvaecer",
    "desvaecêreis": "desvaecer",
    "desvaecêsseis": "desvaecer",
    "desvaecêssemos": "desvaecer",
    "desvaecíamo": "desvaecer",
    "desvaecíamos": "desvaecer",
    "desvaecíeis": "desvaecer",
    "desvaem": "desvair",
    "desvaeça": "desvaecer",
    "desvaeçais": "desvaecer",
    "desvaeçam": "desvaecer",
    "desvaeçamo": "desvaecer",
    "desvaeçamos": "desvaecer",
    "desvaeças": "desvaecer",
    "desvaeço": "desvaecer",
    "desvai": "desvair",
    "desvaia": "desvair",
    "desvaiais": "desvair",
    "desvaiam": "desvair",
    "desvaiamo": "desvair",
    "desvaiamos": "desvair",
    "desvaias": "desvair",
    "desvaidades": "desvaidade",
    "desvaidosa": "desvaidoso",
    "desvaidosas": "desvaidoso",
    "desvaidosos": "desvaidoso",
    "desvaindo": "desvair",
    "desvaio": "desvair",
    "desvaira": "desvairar",
    "desvairada": "desvairar",
    "desvairadas": "desvairar",
    "desvairado": "desvairar",
    "desvairados": "desvairar",
    "desvairadíssima": "desvairado",
    "desvairadíssimas": "desvairado",
    "desvairadíssimo": "desvairado",
    "desvairadíssimos": "desvairado",
    "desvairai": "desvairar",
    "desvairais": "desvairar",
    "desvairam": "desvairar",
    "desvairamentos": "desvairamento",
    "desvairamo": "desvairar",
    "desvairamos": "desvairar",
    "desvairando": "desvairar",
    "desvairara": "desvairar",
    "desvairaram": "desvairar",
    "desvairaras": "desvairar",
    "desvairarde": "desvairar",
    "desvairardes": "desvairar",
    "desvairare": "desvairar",
    "desvairarei": "desvairar",
    "desvairareis": "desvairar",
    "desvairarem": "desvairar",
    "desvairaremos": "desvairar",
    "desvairares": "desvairar",
    "desvairaria": "desvairar",
    "desvairariam": "desvairar",
    "desvairarias": "desvairar",
    "desvairarmo": "desvairar",
    "desvairarmos": "desvairar",
    "desvairará": "desvairar",
    "desvairarás": "desvairar",
    "desvairarão": "desvairar",
    "desvairaríamos": "desvairar",
    "desvairaríeis": "desvairar",
    "desvairas": "desvairar",
    "desvairasse": "desvairar",
    "desvairassem": "desvairar",
    "desvairasses": "desvairar",
    "desvairaste": "desvairar",
    "desvairastes": "desvairar",
    "desvairava": "desvairar",
    "desvairavam": "desvairar",
    "desvairavas": "desvairar",
    "desvairdes": "desvair",
    "desvaire": "desvairar",
    "desvairei": "desvairar",
    "desvaireis": "desvairar",
    "desvairem": "desvairar",
    "desvairemo": "desvairar",
    "desvairemos": "desvairar",
    "desvaires": "desvairar",
    "desvairia": "desvair",
    "desvairiam": "desvair",
    "desvairias": "desvair",
    "desvairmo": "desvair",
    "desvairmos": "desvair",
    "desvairo": "desvairar",
    "desvairos": "desvairo",
    "desvairou": "desvairar",
    "desvairá": "desvairar",
    "desvairámo": "desvairar",
    "desvairámos": "desvairar",
    "desvairáramo": "desvairar",
    "desvairáramos": "desvairar",
    "desvairárei": "desvairar",
    "desvairáreis": "desvairar",
    "desvairás": "desvair",
    "desvairásseis": "desvairar",
    "desvairássemos": "desvairar",
    "desvairávamo": "desvairar",
    "desvairávamos": "desvairar",
    "desvairávei": "desvairar",
    "desvairáveis": "desvairar",
    "desvairão": "desvair",
    "desvairíamos": "desvair",
    "desvairíeis": "desvair",
    "desvais": "desvair",
    "desvaiu": "desvair",
    "desvala": "desvaler",
    "desvalais": "desvaler",
    "desvalam": "desvaler",
    "desvalamo": "desvaler",
    "desvalamos": "desvaler",
    "desvalas": "desvaler",
    "desvale": "desvaler",
    "desvalei": "desvaler",
    "desvaleis": "desvaler",
    "desvalem": "desvaler",
    "desvalemo": "desvaler",
    "desvalemos": "desvaler",
    "desvalendo": "desvaler",
    "desvalera": "desvaler",
    "desvaleram": "desvaler",
    "desvaleras": "desvaler",
    "desvalerde": "desvaler",
    "desvalerdes": "desvaler",
    "desvalere": "desvaler",
    "desvalerei": "desvaler",
    "desvalereis": "desvaler",
    "desvalerem": "desvaler",
    "desvaleremos": "desvaler",
    "desvaleres": "desvaler",
    "desvaleria": "desvaler",
    "desvaleriam": "desvaler",
    "desvalerias": "desvaler",
    "desvalermo": "desvaler",
    "desvalermos": "desvaler",
    "desvalerá": "desvaler",
    "desvalerás": "desvaler",
    "desvalerão": "desvaler",
    "desvaleríamos": "desvaler",
    "desvaleríeis": "desvaler",
    "desvales": "desvaler",
    "desvalesse": "desvaler",
    "desvalessem": "desvaler",
    "desvalesses": "desvaler",
    "desvaleste": "desvaler",
    "desvalestes": "desvaler",
    "desvaleu": "desvaler",
    "desvali": "desvaler",
    "desvalia": "desvaliar",
    "desvaliada": "desvaliar",
    "desvaliadas": "desvaliar",
    "desvaliado": "desvaliar",
    "desvaliados": "desvaliar",
    "desvaliai": "desvaliar",
    "desvaliais": "desvaliar",
    "desvaliam": "desvaliar",
    "desvaliamo": "desvaliar",
    "desvaliamos": "desvaliar",
    "desvaliando": "desvaliar",
    "desvaliara": "desvaliar",
    "desvaliaram": "desvaliar",
    "desvaliaras": "desvaliar",
    "desvaliarde": "desvaliar",
    "desvaliardes": "desvaliar",
    "desvaliare": "desvaliar",
    "desvaliarei": "desvaliar",
    "desvaliareis": "desvaliar",
    "desvaliarem": "desvaliar",
    "desvaliaremos": "desvaliar",
    "desvaliares": "desvaliar",
    "desvaliaria": "desvaliar",
    "desvaliariam": "desvaliar",
    "desvaliarias": "desvaliar",
    "desvaliarmo": "desvaliar",
    "desvaliarmos": "desvaliar",
    "desvaliará": "desvaliar",
    "desvaliarás": "desvaliar",
    "desvaliarão": "desvaliar",
    "desvaliaríamos": "desvaliar",
    "desvaliaríeis": "desvaliar",
    "desvalias": "desvaliar",
    "desvaliasse": "desvaliar",
    "desvaliassem": "desvaliar",
    "desvaliasses": "desvaliar",
    "desvaliaste": "desvaliar",
    "desvaliastes": "desvaliar",
    "desvaliava": "desvaliar",
    "desvaliavam": "desvaliar",
    "desvaliavas": "desvaliar",
    "desvaliações": "desvaliação",
    "desvalida": "desvalido",
    "desvalidada": "desvalidar",
    "desvalidadas": "desvalidar",
    "desvalidado": "desvalidar",
    "desvalidados": "desvalidar",
    "desvalidai": "desvalidar",
    "desvalidais": "desvalidar",
    "desvalidam": "desvalidar",
    "desvalidamo": "desvalidar",
    "desvalidamos": "desvalidar",
    "desvalidando": "desvalidar",
    "desvalidara": "desvalidar",
    "desvalidaram": "desvalidar",
    "desvalidaras": "desvalidar",
    "desvalidarde": "desvalidar",
    "desvalidardes": "desvalidar",
    "desvalidare": "desvalidar",
    "desvalidarei": "desvalidar",
    "desvalidareis": "desvalidar",
    "desvalidarem": "desvalidar",
    "desvalidaremos": "desvalidar",
    "desvalidares": "desvalidar",
    "desvalidaria": "desvalidar",
    "desvalidariam": "desvalidar",
    "desvalidarias": "desvalidar",
    "desvalidarmo": "desvalidar",
    "desvalidarmos": "desvalidar",
    "desvalidará": "desvalidar",
    "desvalidarás": "desvalidar",
    "desvalidarão": "desvalidar",
    "desvalidaríamos": "desvalidar",
    "desvalidaríeis": "desvalidar",
    "desvalidas": "desvalido",
    "desvalidasse": "desvalidar",
    "desvalidassem": "desvalidar",
    "desvalidasses": "desvalidar",
    "desvalidaste": "desvalidar",
    "desvalidastes": "desvalidar",
    "desvalidava": "desvalidar",
    "desvalidavam": "desvalidar",
    "desvalidavas": "desvalidar",
    "desvalide": "desvalidar",
    "desvalidei": "desvalidar",
    "desvalideis": "desvalidar",
    "desvalidem": "desvalidar",
    "desvalidemo": "desvalidar",
    "desvalidemos": "desvalidar",
    "desvalides": "desvalidar",
    "desvalido": "desvalidar",
    "desvalidos": "desvalido",
    "desvalidou": "desvalidar",
    "desvalidá": "desvalidar",
    "desvalidámo": "desvalidar",
    "desvalidámos": "desvalidar",
    "desvalidáramo": "desvalidar",
    "desvalidáramos": "desvalidar",
    "desvalidárei": "desvalidar",
    "desvalidáreis": "desvalidar",
    "desvalidásseis": "desvalidar",
    "desvalidássemos": "desvalidar",
    "desvalidávamo": "desvalidar",
    "desvalidávamos": "desvalidar",
    "desvalidávei": "desvalidar",
    "desvalidáveis": "desvalidar",
    "desvalie": "desvaliar",
    "desvaliei": "desvaliar",
    "desvalieis": "desvaliar",
    "desvaliem": "desvaliar",
    "desvaliemo": "desvaliar",
    "desvaliemos": "desvaliar",
    "desvalies": "desvaliar",
    "desvalija": "desvalijar",
    "desvalijada": "desvalijar",
    "desvalijadas": "desvalijar",
    "desvalijado": "desvalijar",
    "desvalijados": "desvalijar",
    "desvalijai": "desvalijar",
    "desvalijais": "desvalijar",
    "desvalijam": "desvalijar",
    "desvalijamo": "desvalijar",
    "desvalijamos": "desvalijar",
    "desvalijando": "desvalijar",
    "desvalijara": "desvalijar",
    "desvalijaram": "desvalijar",
    "desvalijaras": "desvalijar",
    "desvalijarde": "desvalijar",
    "desvalijardes": "desvalijar",
    "desvalijare": "desvalijar",
    "desvalijarei": "desvalijar",
    "desvalijareis": "desvalijar",
    "desvalijarem": "desvalijar",
    "desvalijaremos": "desvalijar",
    "desvalijares": "desvalijar",
    "desvalijaria": "desvalijar",
    "desvalijariam": "desvalijar",
    "desvalijarias": "desvalijar",
    "desvalijarmo": "desvalijar",
    "desvalijarmos": "desvalijar",
    "desvalijará": "desvalijar",
    "desvalijarás": "desvalijar",
    "desvalijarão": "desvalijar",
    "desvalijaríamos": "desvalijar",
    "desvalijaríeis": "desvalijar",
    "desvalijas": "desvalijar",
    "desvalijasse": "desvalijar",
    "desvalijassem": "desvalijar",
    "desvalijasses": "desvalijar",
    "desvalijaste": "desvalijar",
    "desvalijastes": "desvalijar",
    "desvalijava": "desvalijar",
    "desvalijavam": "desvalijar",
    "desvalijavas": "desvalijar",
    "desvalije": "desvalijar",
    "desvalijei": "desvalijar",
    "desvalijeis": "desvalijar",
    "desvalijem": "desvalijar",
    "desvalijemo": "desvalijar",
    "desvalijemos": "desvalijar",
    "desvalijes": "desvalijar",
    "desvalijo": "desvalijar",
    "desvalijou": "desvalijar",
    "desvalijá": "desvalijar",
    "desvalijámo": "desvalijar",
    "desvalijámos": "desvalijar",
    "desvalijáramo": "desvalijar",
    "desvalijáramos": "desvalijar",
    "desvalijárei": "desvalijar",
    "desvalijáreis": "desvalijar",
    "desvalijásseis": "desvalijar",
    "desvalijássemos": "desvalijar",
    "desvalijávamo": "desvalijar",
    "desvalijávamos": "desvalijar",
    "desvalijávei": "desvalijar",
    "desvalijáveis": "desvalijar",
    "desvalimentos": "desvalimento",
    "desvalio": "desvaliar",
    "desvaliosa": "desvalioso",
    "desvaliosas": "desvalioso",
    "desvaliosos": "desvalioso",
    "desvaliou": "desvaliar",
    "desvaliá": "desvaliar",
    "desvaliámo": "desvaliar",
    "desvaliámos": "desvaliar",
    "desvaliáramo": "desvaliar",
    "desvaliáramos": "desvaliar",
    "desvaliárei": "desvaliar",
    "desvaliáreis": "desvaliar",
    "desvaliásseis": "desvaliar",
    "desvaliássemos": "desvaliar",
    "desvaliávamo": "desvaliar",
    "desvaliávamos": "desvaliar",
    "desvaliávei": "desvaliar",
    "desvaliáveis": "desvaliar",
    "desvalo": "desvaler",
    "desvalora": "desvalorar",
    "desvalorada": "desvalorar",
    "desvaloradas": "desvalorar",
    "desvalorado": "desvalorar",
    "desvalorados": "desvalorar",
    "desvalorai": "desvalorar",
    "desvalorais": "desvalorar",
    "desvaloram": "desvalorar",
    "desvaloramo": "desvalorar",
    "desvaloramos": "desvalorar",
    "desvalorando": "desvalorar",
    "desvalorara": "desvalorar",
    "desvaloraram": "desvalorar",
    "desvaloraras": "desvalorar",
    "desvalorarde": "desvalorar",
    "desvalorardes": "desvalorar",
    "desvalorare": "desvalorar",
    "desvalorarei": "desvalorar",
    "desvalorareis": "desvalorar",
    "desvalorarem": "desvalorar",
    "desvaloraremos": "desvalorar",
    "desvalorares": "desvalorar",
    "desvaloraria": "desvalorar",
    "desvalorariam": "desvalorar",
    "desvalorarias": "desvalorar",
    "desvalorarmo": "desvalorar",
    "desvalorarmos": "desvalorar",
    "desvalorará": "desvalorar",
    "desvalorarás": "desvalorar",
    "desvalorarão": "desvalorar",
    "desvaloraríamos": "desvalorar",
    "desvaloraríeis": "desvalorar",
    "desvaloras": "desvalorar",
    "desvalorasse": "desvalorar",
    "desvalorassem": "desvalorar",
    "desvalorasses": "desvalorar",
    "desvaloraste": "desvalorar",
    "desvalorastes": "desvalorar",
    "desvalorava": "desvalorar",
    "desvaloravam": "desvalorar",
    "desvaloravas": "desvalorar",
    "desvalore": "desvalorar",
    "desvalorei": "desvalorar",
    "desvaloreis": "desvalorar",
    "desvalorem": "desvalorar",
    "desvaloremo": "desvalorar",
    "desvaloremos": "desvalorar",
    "desvalores": "desvalorar",
    "desvaloriza": "desvalorizar",
    "desvalorizada": "desvalorizar",
    "desvalorizadas": "desvalorizar",
    "desvalorizado": "desvalorizar",
    "desvalorizadora": "desvalorizador",
    "desvalorizadoras": "desvalorizador",
    "desvalorizadores": "desvalorizador",
    "desvalorizados": "desvalorizar",
    "desvalorizai": "desvalorizar",
    "desvalorizais": "desvalorizar",
    "desvalorizam": "desvalorizar",
    "desvalorizamo": "desvalorizar",
    "desvalorizamos": "desvalorizar",
    "desvalorizando": "desvalorizar",
    "desvalorizara": "desvalorizar",
    "desvalorizaram": "desvalorizar",
    "desvalorizaras": "desvalorizar",
    "desvalorizarde": "desvalorizar",
    "desvalorizardes": "desvalorizar",
    "desvalorizare": "desvalorizar",
    "desvalorizarei": "desvalorizar",
    "desvalorizareis": "desvalorizar",
    "desvalorizarem": "desvalorizar",
    "desvalorizaremos": "desvalorizar",
    "desvalorizares": "desvalorizar",
    "desvalorizaria": "desvalorizar",
    "desvalorizariam": "desvalorizar",
    "desvalorizarias": "desvalorizar",
    "desvalorizarmo": "desvalorizar",
    "desvalorizarmos": "desvalorizar",
    "desvalorizará": "desvalorizar",
    "desvalorizarás": "desvalorizar",
    "desvalorizarão": "desvalorizar",
    "desvalorizaríamos": "desvalorizar",
    "desvalorizaríeis": "desvalorizar",
    "desvalorizas": "desvalorizar",
    "desvalorizasse": "desvalorizar",
    "desvalorizassem": "desvalorizar",
    "desvalorizasses": "desvalorizar",
    "desvalorizaste": "desvalorizar",
    "desvalorizastes": "desvalorizar",
    "desvalorizava": "desvalorizar",
    "desvalorizavam": "desvalorizar",
    "desvalorizavas": "desvalorizar",
    "desvalorizações": "desvalorização",
    "desvalorize": "desvalorizar",
    "desvalorizei": "desvalorizar",
    "desvalorizeis": "desvalorizar",
    "desvalorizem": "desvalorizar",
    "desvalorizemo": "desvalorizar",
    "desvalorizemos": "desvalorizar",
    "desvalorizes": "desvalorizar",
    "desvalorizo": "desvalorizar",
    "desvalorizou": "desvalorizar",
    "desvalorizá": "desvalorizar",
    "desvalorizámo": "desvalorizar",
    "desvalorizámos": "desvalorizar",
    "desvalorizáramo": "desvalorizar",
    "desvalorizáramos": "desvalorizar",
    "desvalorizárei": "desvalorizar",
    "desvalorizáreis": "desvalorizar",
    "desvalorizásseis": "desvalorizar",
    "desvalorizássemos": "desvalorizar",
    "desvalorizávamo": "desvalorizar",
    "desvalorizávamos": "desvalorizar",
    "desvalorizávei": "desvalorizar",
    "desvalorizáveis": "desvalorizável",
    "desvaloro": "desvalorar",
    "desvalorou": "desvalorar",
    "desvalorá": "desvalorar",
    "desvalorámo": "desvalorar",
    "desvalorámos": "desvalorar",
    "desvaloráramo": "desvalorar",
    "desvaloráramos": "desvalorar",
    "desvalorárei": "desvalorar",
    "desvaloráreis": "desvalorar",
    "desvalorásseis": "desvalorar",
    "desvalorássemos": "desvalorar",
    "desvalorávamo": "desvalorar",
    "desvalorávamos": "desvalorar",
    "desvalorávei": "desvalorar",
    "desvaloráveis": "desvalorar",
    "desvalvulada": "desvalvulado",
    "desvalvuladas": "desvalvulado",
    "desvalvulados": "desvalvulado",
    "desvalê": "desvaler",
    "desvalêramo": "desvaler",
    "desvalêramos": "desvaler",
    "desvalêrei": "desvaler",
    "desvalêreis": "desvaler",
    "desvalêsseis": "desvaler",
    "desvalêssemos": "desvaler",
    "desvalíamo": "desvaler",
    "desvalíamos": "desvaler",
    "desvalíei": "desvaler",
    "desvalíeis": "desvaler",
    "desvanece": "desvanecer",
    "desvanecedora": "desvanecedor",
    "desvanecedoras": "desvanecedor",
    "desvanecedores": "desvanecedor",
    "desvanecei": "desvanecer",
    "desvaneceis": "desvanecer",
    "desvanecem": "desvanecer",
    "desvanecemo": "desvanecer",
    "desvanecemos": "desvanecer",
    "desvanecendo": "desvanecer",
    "desvanecera": "desvanecer",
    "desvaneceram": "desvanecer",
    "desvaneceras": "desvanecer",
    "desvanecerdes": "desvanecer",
    "desvanecerei": "desvanecer",
    "desvanecereis": "desvanecer",
    "desvanecerem": "desvanecer",
    "desvaneceremos": "desvanecer",
    "desvaneceres": "desvanecer",
    "desvaneceria": "desvanecer",
    "desvaneceriam": "desvanecer",
    "desvanecerias": "desvanecer",
    "desvanecermo": "desvanecer",
    "desvanecermos": "desvanecer",
    "desvanecerá": "desvanecer",
    "desvanecerás": "desvanecer",
    "desvanecerão": "desvanecer",
    "desvaneceríamos": "desvanecer",
    "desvaneceríeis": "desvanecer",
    "desvaneces": "desvanecer",
    "desvanecesse": "desvanecer",
    "desvanecessem": "desvanecer",
    "desvanecesses": "desvanecer",
    "desvaneceste": "desvanecer",
    "desvanecestes": "desvanecer",
    "desvaneceu": "desvanecer",
    "desvaneci": "desvanecer",
    "desvanecia": "desvanecer",
    "desvaneciam": "desvanecer",
    "desvanecias": "desvanecer",
    "desvanecida": "desvanecido",
    "desvanecidas": "desvanecido",
    "desvanecido": "desvanecer",
    "desvanecidos": "desvanecido",
    "desvanecidíssima": "desvanecido",
    "desvanecidíssimas": "desvanecido",
    "desvanecidíssimo": "desvanecido",
    "desvanecidíssimos": "desvanecido",
    "desvanecimentos": "desvanecimento",
    "desvanecêramo": "desvanecer",
    "desvanecêramos": "desvanecer",
    "desvanecêreis": "desvanecer",
    "desvanecêsseis": "desvanecer",
    "desvanecêssemos": "desvanecer",
    "desvanecíamo": "desvanecer",
    "desvanecíamos": "desvanecer",
    "desvanecíeis": "desvanecer",
    "desvanecíveis": "desvanecível",
    "desvaneça": "desvanecer",
    "desvaneçais": "desvanecer",
    "desvaneçam": "desvanecer",
    "desvaneçamo": "desvanecer",
    "desvaneçamos": "desvanecer",
    "desvaneças": "desvanecer",
    "desvaneço": "desvanecer",
    "desvantagens": "desvantagem",
    "desvantajosa": "desvantajoso",
    "desvantajosas": "desvantajoso",
    "desvantajosos": "desvantajoso",
    "desvariada": "desvariado",
    "desvariadas": "desvariado",
    "desvariados": "desvariado",
    "desvarios": "desvario",
    "desvaí": "desvair",
    "desvaía": "desvair",
    "desvaíam": "desvair",
    "desvaíamo": "desvair",
    "desvaíamos": "desvair",
    "desvaías": "desvair",
    "desvaída": "desvair",
    "desvaídas": "desvair",
    "desvaído": "desvair",
    "desvaídos": "desvair",
    "desvaíeis": "desvair",
    "desvaímo": "desvair",
    "desvaímos": "desvair",
    "desvaíra": "desvair",
    "desvaíram": "desvair",
    "desvaíramo": "desvair",
    "desvaíramos": "desvair",
    "desvaíras": "desvair",
    "desvaíreis": "desvair",
    "desvaírem": "desvair",
    "desvaíres": "desvair",
    "desvaís": "desvair",
    "desvaísse": "desvair",
    "desvaísseis": "desvair",
    "desvaíssem": "desvair",
    "desvaíssemos": "desvair",
    "desvaísses": "desvair",
    "desvaíste": "desvair",
    "desvaístes": "desvair",
    "desvela": "desvelar",
    "desvelada": "desvelar",
    "desveladas": "desvelar",
    "desvelado": "desvelar",
    "desvelados": "desvelar",
    "desvelai": "desvelar",
    "desvelais": "desvelar",
    "desvelam": "desvelar",
    "desvelamentos": "desvelamento",
    "desvelamo": "desvelar",
    "desvelamos": "desvelar",
    "desvelando": "desvelar",
    "desvelara": "desvelar",
    "desvelaram": "desvelar",
    "desvelaras": "desvelar",
    "desvelarde": "desvelar",
    "desvelardes": "desvelar",
    "desvelare": "desvelar",
    "desvelarei": "desvelar",
    "desvelareis": "desvelar",
    "desvelarem": "desvelar",
    "desvelaremos": "desvelar",
    "desvelares": "desvelar",
    "desvelaria": "desvelar",
    "desvelariam": "desvelar",
    "desvelarias": "desvelar",
    "desvelarmo": "desvelar",
    "desvelarmos": "desvelar",
    "desvelará": "desvelar",
    "desvelarás": "desvelar",
    "desvelarão": "desvelar",
    "desvelaríamos": "desvelar",
    "desvelaríeis": "desvelar",
    "desvelas": "desvelar",
    "desvelasse": "desvelar",
    "desvelassem": "desvelar",
    "desvelasses": "desvelar",
    "desvelaste": "desvelar",
    "desvelastes": "desvelar",
    "desvelava": "desvelar",
    "desvelavam": "desvelar",
    "desvelavas": "desvelar",
    "desvele": "desvelar",
    "desvelei": "desvelar",
    "desveleis": "desvelar",
    "desveleja": "desvelejar",
    "desvelejada": "desvelejar",
    "desvelejadas": "desvelejar",
    "desvelejado": "desvelejar",
    "desvelejados": "desvelejar",
    "desvelejai": "desvelejar",
    "desvelejais": "desvelejar",
    "desvelejam": "desvelejar",
    "desvelejamo": "desvelejar",
    "desvelejamos": "desvelejar",
    "desvelejando": "desvelejar",
    "desvelejara": "desvelejar",
    "desvelejaram": "desvelejar",
    "desvelejaras": "desvelejar",
    "desvelejarde": "desvelejar",
    "desvelejardes": "desvelejar",
    "desvelejare": "desvelejar",
    "desvelejarei": "desvelejar",
    "desvelejareis": "desvelejar",
    "desvelejarem": "desvelejar",
    "desvelejaremos": "desvelejar",
    "desvelejares": "desvelejar",
    "desvelejaria": "desvelejar",
    "desvelejariam": "desvelejar",
    "desvelejarias": "desvelejar",
    "desvelejarmo": "desvelejar",
    "desvelejarmos": "desvelejar",
    "desvelejará": "desvelejar",
    "desvelejarás": "desvelejar",
    "desvelejarão": "desvelejar",
    "desvelejaríamos": "desvelejar",
    "desvelejaríeis": "desvelejar",
    "desvelejas": "desvelejar",
    "desvelejasse": "desvelejar",
    "desvelejassem": "desvelejar",
    "desvelejasses": "desvelejar",
    "desvelejaste": "desvelejar",
    "desvelejastes": "desvelejar",
    "desvelejava": "desvelejar",
    "desvelejavam": "desvelejar",
    "desvelejavas": "desvelejar",
    "desveleje": "desvelejar",
    "desvelejei": "desvelejar",
    "desvelejeis": "desvelejar",
    "desvelejem": "desvelejar",
    "desvelejemo": "desvelejar",
    "desvelejemos": "desvelejar",
    "desvelejes": "desvelejar",
    "desvelejo": "desvelejar",
    "desvelejou": "desvelejar",
    "desvelejá": "desvelejar",
    "desvelejámo": "desvelejar",
    "desvelejámos": "desvelejar",
    "desvelejáramo": "desvelejar",
    "desvelejáramos": "desvelejar",
    "desvelejárei": "desvelejar",
    "desvelejáreis": "desvelejar",
    "desvelejásseis": "desvelejar",
    "desvelejássemos": "desvelejar",
    "desvelejávamo": "desvelejar",
    "desvelejávamos": "desvelejar",
    "desvelejávei": "desvelejar",
    "desvelejáveis": "desvelejar",
    "desvelem": "desvelar",
    "desvelemo": "desvelar",
    "desvelemos": "desvelar",
    "desveles": "desvelar",
    "desvelo": "desvelar",
    "desvelos": "desvelo",
    "desvelou": "desvelar",
    "desvelá": "desvelar",
    "desvelámo": "desvelar",
    "desvelámos": "desvelar",
    "desveláramo": "desvelar",
    "desveláramos": "desvelar",
    "desvelárei": "desvelar",
    "desveláreis": "desvelar",
    "desvelásseis": "desvelar",
    "desvelássemos": "desvelar",
    "desvelávamo": "desvelar",
    "desvelávamos": "desvelar",
    "desvelávei": "desvelar",
    "desveláveis": "desvelar",
    "desvencelha": "desvencelhar",
    "desvencelhada": "desvencelhar",
    "desvencelhadas": "desvencelhar",
    "desvencelhado": "desvencelhar",
    "desvencelhados": "desvencelhar",
    "desvencelhai": "desvencelhar",
    "desvencelhais": "desvencelhar",
    "desvencelham": "desvencelhar",
    "desvencelhamo": "desvencelhar",
    "desvencelhamos": "desvencelhar",
    "desvencelhando": "desvencelhar",
    "desvencelhara": "desvencelhar",
    "desvencelharam": "desvencelhar",
    "desvencelharas": "desvencelhar",
    "desvencelharde": "desvencelhar",
    "desvencelhardes": "desvencelhar",
    "desvencelhare": "desvencelhar",
    "desvencelharei": "desvencelhar",
    "desvencelhareis": "desvencelhar",
    "desvencelharem": "desvencelhar",
    "desvencelharemos": "desvencelhar",
    "desvencelhares": "desvencelhar",
    "desvencelharia": "desvencelhar",
    "desvencelhariam": "desvencelhar",
    "desvencelharias": "desvencelhar",
    "desvencelharmo": "desvencelhar",
    "desvencelharmos": "desvencelhar",
    "desvencelhará": "desvencelhar",
    "desvencelharás": "desvencelhar",
    "desvencelharão": "desvencelhar",
    "desvencelharíamos": "desvencelhar",
    "desvencelharíeis": "desvencelhar",
    "desvencelhas": "desvencelhar",
    "desvencelhasse": "desvencelhar",
    "desvencelhassem": "desvencelhar",
    "desvencelhasses": "desvencelhar",
    "desvencelhaste": "desvencelhar",
    "desvencelhastes": "desvencelhar",
    "desvencelhava": "desvencelhar",
    "desvencelhavam": "desvencelhar",
    "desvencelhavas": "desvencelhar",
    "desvencelhe": "desvencelhar",
    "desvencelhei": "desvencelhar",
    "desvencelheis": "desvencelhar",
    "desvencelhem": "desvencelhar",
    "desvencelhemo": "desvencelhar",
    "desvencelhemos": "desvencelhar",
    "desvencelhes": "desvencelhar",
    "desvencelho": "desvencelhar",
    "desvencelhou": "desvencelhar",
    "desvencelhá": "desvencelhar",
    "desvencelhámo": "desvencelhar",
    "desvencelhámos": "desvencelhar",
    "desvencelháramo": "desvencelhar",
    "desvencelháramos": "desvencelhar",
    "desvencelhárei": "desvencelhar",
    "desvencelháreis": "desvencelhar",
    "desvencelhásseis": "desvencelhar",
    "desvencelhássemos": "desvencelhar",
    "desvencelhávamo": "desvencelhar",
    "desvencelhávamos": "desvencelhar",
    "desvencelhávei": "desvencelhar",
    "desvencelháveis": "desvencelhar",
    "desvencilha": "desvencilhar",
    "desvencilhada": "desvencilhar",
    "desvencilhadas": "desvencilhar",
    "desvencilhado": "desvencilhar",
    "desvencilhados": "desvencilhar",
    "desvencilhai": "desvencilhar",
    "desvencilhais": "desvencilhar",
    "desvencilham": "desvencilhar",
    "desvencilhamo": "desvencilhar",
    "desvencilhamos": "desvencilhar",
    "desvencilhando": "desvencilhar",
    "desvencilhara": "desvencilhar",
    "desvencilharam": "desvencilhar",
    "desvencilharas": "desvencilhar",
    "desvencilharde": "desvencilhar",
    "desvencilhardes": "desvencilhar",
    "desvencilhare": "desvencilhar",
    "desvencilharei": "desvencilhar",
    "desvencilhareis": "desvencilhar",
    "desvencilharem": "desvencilhar",
    "desvencilharemos": "desvencilhar",
    "desvencilhares": "desvencilhar",
    "desvencilharia": "desvencilhar",
    "desvencilhariam": "desvencilhar",
    "desvencilharias": "desvencilhar",
    "desvencilharmo": "desvencilhar",
    "desvencilharmos": "desvencilhar",
    "desvencilhará": "desvencilhar",
    "desvencilharás": "desvencilhar",
    "desvencilharão": "desvencilhar",
    "desvencilharíamos": "desvencilhar",
    "desvencilharíeis": "desvencilhar",
    "desvencilhas": "desvencilhar",
    "desvencilhasse": "desvencilhar",
    "desvencilhassem": "desvencilhar",
    "desvencilhasses": "desvencilhar",
    "desvencilhaste": "desvencilhar",
    "desvencilhastes": "desvencilhar",
    "desvencilhava": "desvencilhar",
    "desvencilhavam": "desvencilhar",
    "desvencilhavas": "desvencilhar",
    "desvencilhe": "desvencilhar",
    "desvencilhei": "desvencilhar",
    "desvencilheis": "desvencilhar",
    "desvencilhem": "desvencilhar",
    "desvencilhemo": "desvencilhar",
    "desvencilhemos": "desvencilhar",
    "desvencilhes": "desvencilhar",
    "desvencilho": "desvencilhar",
    "desvencilhou": "desvencilhar",
    "desvencilhá": "desvencilhar",
    "desvencilhámo": "desvencilhar",
    "desvencilhámos": "desvencilhar",
    "desvencilháramo": "desvencilhar",
    "desvencilháramos": "desvencilhar",
    "desvencilhárei": "desvencilhar",
    "desvencilháreis": "desvencilhar",
    "desvencilhásseis": "desvencilhar",
    "desvencilhássemos": "desvencilhar",
    "desvencilhávamo": "desvencilhar",
    "desvencilhávamos": "desvencilhar",
    "desvencilhávei": "desvencilhar",
    "desvencilháveis": "desvencilhar",
    "desvenda": "desvendar",
    "desvendada": "desvendar",
    "desvendadas": "desvendar",
    "desvendado": "desvendar",
    "desvendados": "desvendar",
    "desvendai": "desvendar",
    "desvendais": "desvendar",
    "desvendam": "desvendar",
    "desvendamo": "desvendar",
    "desvendamos": "desvendar",
    "desvendando": "desvendar",
    "desvendara": "desvendar",
    "desvendaram": "desvendar",
    "desvendaras": "desvendar",
    "desvendarde": "desvendar",
    "desvendardes": "desvendar",
    "desvendare": "desvendar",
    "desvendarei": "desvendar",
    "desvendareis": "desvendar",
    "desvendarem": "desvendar",
    "desvendaremos": "desvendar",
    "desvendares": "desvendar",
    "desvendaria": "desvendar",
    "desvendariam": "desvendar",
    "desvendarias": "desvendar",
    "desvendarmo": "desvendar",
    "desvendarmos": "desvendar",
    "desvendará": "desvendar",
    "desvendarás": "desvendar",
    "desvendarão": "desvendar",
    "desvendaríamos": "desvendar",
    "desvendaríeis": "desvendar",
    "desvendas": "desvendar",
    "desvendasse": "desvendar",
    "desvendassem": "desvendar",
    "desvendasses": "desvendar",
    "desvendaste": "desvendar",
    "desvendastes": "desvendar",
    "desvendava": "desvendar",
    "desvendavam": "desvendar",
    "desvendavas": "desvendar",
    "desvende": "desvendar",
    "desvendei": "desvendar",
    "desvendeis": "desvendar",
    "desvendem": "desvendar",
    "desvendemo": "desvendar",
    "desvendemos": "desvendar",
    "desvendes": "desvendar",
    "desvendo": "desvendar",
    "desvendou": "desvendar",
    "desvendá": "desvendar",
    "desvendámo": "desvendar",
    "desvendámos": "desvendar",
    "desvendáramo": "desvendar",
    "desvendáramos": "desvendar",
    "desvendárei": "desvendar",
    "desvendáreis": "desvendar",
    "desvendásseis": "desvendar",
    "desvendássemos": "desvendar",
    "desvendávamo": "desvendar",
    "desvendávamos": "desvendar",
    "desvendávei": "desvendar",
    "desvendáveis": "desvendável",
    "desvenera": "desvenerar",
    "desvenerada": "desvenerar",
    "desveneradas": "desvenerar",
    "desvenerado": "desvenerar",
    "desvenerados": "desvenerar",
    "desvenerai": "desvenerar",
    "desvenerais": "desvenerar",
    "desveneram": "desvenerar",
    "desveneramo": "desvenerar",
    "desveneramos": "desvenerar",
    "desvenerando": "desvenerar",
    "desvenerara": "desvenerar",
    "desveneraram": "desvenerar",
    "desveneraras": "desvenerar",
    "desvenerarde": "desvenerar",
    "desvenerardes": "desvenerar",
    "desvenerare": "desvenerar",
    "desvenerarei": "desvenerar",
    "desvenerareis": "desvenerar",
    "desvenerarem": "desvenerar",
    "desveneraremos": "desvenerar",
    "desvenerares": "desvenerar",
    "desveneraria": "desvenerar",
    "desvenerariam": "desvenerar",
    "desvenerarias": "desvenerar",
    "desvenerarmo": "desvenerar",
    "desvenerarmos": "desvenerar",
    "desvenerará": "desvenerar",
    "desvenerarás": "desvenerar",
    "desvenerarão": "desvenerar",
    "desveneraríamos": "desvenerar",
    "desveneraríeis": "desvenerar",
    "desveneras": "desvenerar",
    "desvenerasse": "desvenerar",
    "desvenerassem": "desvenerar",
    "desvenerasses": "desvenerar",
    "desveneraste": "desvenerar",
    "desvenerastes": "desvenerar",
    "desvenerava": "desvenerar",
    "desveneravam": "desvenerar",
    "desveneravas": "desvenerar",
    "desvenerações": "desveneração",
    "desvenere": "desvenerar",
    "desvenerei": "desvenerar",
    "desvenereis": "desvenerar",
    "desvenerem": "desvenerar",
    "desveneremo": "desvenerar",
    "desveneremos": "desvenerar",
    "desveneres": "desvenerar",
    "desvenero": "desvenerar",
    "desvenerou": "desvenerar",
    "desvenerá": "desvenerar",
    "desvenerámo": "desvenerar",
    "desvenerámos": "desvenerar",
    "desveneráramo": "desvenerar",
    "desveneráramos": "desvenerar",
    "desvenerárei": "desvenerar",
    "desveneráreis": "desvenerar",
    "desvenerásseis": "desvenerar",
    "desvenerássemos": "desvenerar",
    "desvenerávamo": "desvenerar",
    "desvenerávamos": "desvenerar",
    "desvenerávei": "desvenerar",
    "desveneráveis": "desvenerar",
    "desventra": "desventrar",
    "desventrada": "desventrar",
    "desventradas": "desventrar",
    "desventrado": "desventrar",
    "desventrados": "desventrar",
    "desventrai": "desventrar",
    "desventrais": "desventrar",
    "desventram": "desventrar",
    "desventramo": "desventrar",
    "desventramos": "desventrar",
    "desventrando": "desventrar",
    "desventrara": "desventrar",
    "desventraram": "desventrar",
    "desventraras": "desventrar",
    "desventrarde": "desventrar",
    "desventrardes": "desventrar",
    "desventrare": "desventrar",
    "desventrarei": "desventrar",
    "desventrareis": "desventrar",
    "desventrarem": "desventrar",
    "desventraremos": "desventrar",
    "desventrares": "desventrar",
    "desventraria": "desventrar",
    "desventrariam": "desventrar",
    "desventrarias": "desventrar",
    "desventrarmo": "desventrar",
    "desventrarmos": "desventrar",
    "desventrará": "desventrar",
    "desventrarás": "desventrar",
    "desventrarão": "desventrar",
    "desventraríamos": "desventrar",
    "desventraríeis": "desventrar",
    "desventras": "desventrar",
    "desventrasse": "desventrar",
    "desventrassem": "desventrar",
    "desventrasses": "desventrar",
    "desventraste": "desventrar",
    "desventrastes": "desventrar",
    "desventrava": "desventrar",
    "desventravam": "desventrar",
    "desventravas": "desventrar",
    "desventrações": "desventração",
    "desventre": "desventrar",
    "desventrei": "desventrar",
    "desventreis": "desventrar",
    "desventrem": "desventrar",
    "desventremo": "desventrar",
    "desventremos": "desventrar",
    "desventres": "desventrar",
    "desventro": "desventrar",
    "desventrou": "desventrar",
    "desventrá": "desventrar",
    "desventrámo": "desventrar",
    "desventrámos": "desventrar",
    "desventráramo": "desventrar",
    "desventráramos": "desventrar",
    "desventrárei": "desventrar",
    "desventráreis": "desventrar",
    "desventrásseis": "desventrar",
    "desventrássemos": "desventrar",
    "desventrávamo": "desventrar",
    "desventrávamos": "desventrar",
    "desventrávei": "desventrar",
    "desventráveis": "desventrar",
    "desventura": "desventurar",
    "desventurada": "desventurar",
    "desventuradas": "desventurar",
    "desventurado": "desventurar",
    "desventurados": "desventurar",
    "desventurai": "desventurar",
    "desventurais": "desventurar",
    "desventuram": "desventurar",
    "desventuramo": "desventurar",
    "desventuramos": "desventurar",
    "desventurando": "desventurar",
    "desventurara": "desventurar",
    "desventuraram": "desventurar",
    "desventuraras": "desventurar",
    "desventurarde": "desventurar",
    "desventurardes": "desventurar",
    "desventurare": "desventurar",
    "desventurarei": "desventurar",
    "desventurareis": "desventurar",
    "desventurarem": "desventurar",
    "desventuraremos": "desventurar",
    "desventurares": "desventurar",
    "desventuraria": "desventurar",
    "desventurariam": "desventurar",
    "desventurarias": "desventurar",
    "desventurarmo": "desventurar",
    "desventurarmos": "desventurar",
    "desventurará": "desventurar",
    "desventurarás": "desventurar",
    "desventurarão": "desventurar",
    "desventuraríamos": "desventurar",
    "desventuraríeis": "desventurar",
    "desventuras": "desventurar",
    "desventurasse": "desventurar",
    "desventurassem": "desventurar",
    "desventurasses": "desventurar",
    "desventuraste": "desventurar",
    "desventurastes": "desventurar",
    "desventurava": "desventurar",
    "desventuravam": "desventurar",
    "desventuravas": "desventurar",
    "desventure": "desventurar",
    "desventurei": "desventurar",
    "desventureis": "desventurar",
    "desventurem": "desventurar",
    "desventuremo": "desventurar",
    "desventuremos": "desventurar",
    "desventures": "desventurar",
    "desventuro": "desventurar",
    "desventurosa": "desventuroso",
    "desventurosas": "desventuroso",
    "desventurosos": "desventuroso",
    "desventurou": "desventurar",
    "desventurá": "desventurar",
    "desventurámo": "desventurar",
    "desventurámos": "desventurar",
    "desventuráramo": "desventurar",
    "desventuráramos": "desventurar",
    "desventurárei": "desventurar",
    "desventuráreis": "desventurar",
    "desventurásseis": "desventurar",
    "desventurássemos": "desventurar",
    "desventurávamo": "desventurar",
    "desventurávamos": "desventurar",
    "desventurávei": "desventurar",
    "desventuráveis": "desventurar",
    "desverdece": "desverdecer",
    "desverdecei": "desverdecer",
    "desverdeceis": "desverdecer",
    "desverdecem": "desverdecer",
    "desverdecemo": "desverdecer",
    "desverdecemos": "desverdecer",
    "desverdecendo": "desverdecer",
    "desverdecera": "desverdecer",
    "desverdeceram": "desverdecer",
    "desverdeceras": "desverdecer",
    "desverdecerdes": "desverdecer",
    "desverdecerei": "desverdecer",
    "desverdecereis": "desverdecer",
    "desverdecerem": "desverdecer",
    "desverdeceremos": "desverdecer",
    "desverdeceres": "desverdecer",
    "desverdeceria": "desverdecer",
    "desverdeceriam": "desverdecer",
    "desverdecerias": "desverdecer",
    "desverdecermo": "desverdecer",
    "desverdecermos": "desverdecer",
    "desverdecerá": "desverdecer",
    "desverdecerás": "desverdecer",
    "desverdecerão": "desverdecer",
    "desverdeceríamos": "desverdecer",
    "desverdeceríeis": "desverdecer",
    "desverdeces": "desverdecer",
    "desverdecesse": "desverdecer",
    "desverdecessem": "desverdecer",
    "desverdecesses": "desverdecer",
    "desverdeceste": "desverdecer",
    "desverdecestes": "desverdecer",
    "desverdeceu": "desverdecer",
    "desverdeci": "desverdecer",
    "desverdecia": "desverdecer",
    "desverdeciam": "desverdecer",
    "desverdecias": "desverdecer",
    "desverdecida": "desverdecer",
    "desverdecidas": "desverdecer",
    "desverdecido": "desverdecer",
    "desverdecidos": "desverdecer",
    "desverdecêramo": "desverdecer",
    "desverdecêramos": "desverdecer",
    "desverdecêreis": "desverdecer",
    "desverdecêsseis": "desverdecer",
    "desverdecêssemos": "desverdecer",
    "desverdecíamo": "desverdecer",
    "desverdecíamos": "desverdecer",
    "desverdecíeis": "desverdecer",
    "desverdeça": "desverdecer",
    "desverdeçais": "desverdecer",
    "desverdeçam": "desverdecer",
    "desverdeçamo": "desverdecer",
    "desverdeçamos": "desverdecer",
    "desverdeças": "desverdecer",
    "desverdeço": "desverdecer",
    "desvergonha": "desvergonhar",
    "desvergonhada": "desvergonhar",
    "desvergonhadas": "desvergonhar",
    "desvergonhado": "desvergonhar",
    "desvergonhados": "desvergonhar",
    "desvergonhai": "desvergonhar",
    "desvergonhais": "desvergonhar",
    "desvergonham": "desvergonhar",
    "desvergonhamentos": "desvergonhamento",
    "desvergonhamo": "desvergonhar",
    "desvergonhamos": "desvergonhar",
    "desvergonhando": "desvergonhar",
    "desvergonhara": "desvergonhar",
    "desvergonharam": "desvergonhar",
    "desvergonharas": "desvergonhar",
    "desvergonharde": "desvergonhar",
    "desvergonhardes": "desvergonhar",
    "desvergonhare": "desvergonhar",
    "desvergonharei": "desvergonhar",
    "desvergonhareis": "desvergonhar",
    "desvergonharem": "desvergonhar",
    "desvergonharemos": "desvergonhar",
    "desvergonhares": "desvergonhar",
    "desvergonharia": "desvergonhar",
    "desvergonhariam": "desvergonhar",
    "desvergonharias": "desvergonhar",
    "desvergonharmo": "desvergonhar",
    "desvergonharmos": "desvergonhar",
    "desvergonhará": "desvergonhar",
    "desvergonharás": "desvergonhar",
    "desvergonharão": "desvergonhar",
    "desvergonharíamos": "desvergonhar",
    "desvergonharíeis": "desvergonhar",
    "desvergonhas": "desvergonhar",
    "desvergonhasse": "desvergonhar",
    "desvergonhassem": "desvergonhar",
    "desvergonhasses": "desvergonhar",
    "desvergonhaste": "desvergonhar",
    "desvergonhastes": "desvergonhar",
    "desvergonhava": "desvergonhar",
    "desvergonhavam": "desvergonhar",
    "desvergonhavas": "desvergonhar",
    "desvergonhe": "desvergonhar",
    "desvergonhei": "desvergonhar",
    "desvergonheis": "desvergonhar",
    "desvergonhem": "desvergonhar",
    "desvergonhemo": "desvergonhar",
    "desvergonhemos": "desvergonhar",
    "desvergonhes": "desvergonhar",
    "desvergonho": "desvergonhar",
    "desvergonhou": "desvergonhar",
    "desvergonhá": "desvergonhar",
    "desvergonhámo": "desvergonhar",
    "desvergonhámos": "desvergonhar",
    "desvergonháramo": "desvergonhar",
    "desvergonháramos": "desvergonhar",
    "desvergonhárei": "desvergonhar",
    "desvergonháreis": "desvergonhar",
    "desvergonhásseis": "desvergonhar",
    "desvergonhássemos": "desvergonhar",
    "desvergonhávamo": "desvergonhar",
    "desvergonhávamos": "desvergonhar",
    "desvergonhávei": "desvergonhar",
    "desvergonháveis": "desvergonhar",
    "desverminações": "desverminação",
    "desvertebra": "desvertebrar",
    "desvertebrada": "desvertebrar",
    "desvertebradas": "desvertebrar",
    "desvertebrado": "desvertebrar",
    "desvertebrados": "desvertebrar",
    "desvertebrai": "desvertebrar",
    "desvertebrais": "desvertebrar",
    "desvertebram": "desvertebrar",
    "desvertebramo": "desvertebrar",
    "desvertebramos": "desvertebrar",
    "desvertebrando": "desvertebrar",
    "desvertebrara": "desvertebrar",
    "desvertebraram": "desvertebrar",
    "desvertebraras": "desvertebrar",
    "desvertebrarde": "desvertebrar",
    "desvertebrardes": "desvertebrar",
    "desvertebrare": "desvertebrar",
    "desvertebrarei": "desvertebrar",
    "desvertebrareis": "desvertebrar",
    "desvertebrarem": "desvertebrar",
    "desvertebraremos": "desvertebrar",
    "desvertebrares": "desvertebrar",
    "desvertebraria": "desvertebrar",
    "desvertebrariam": "desvertebrar",
    "desvertebrarias": "desvertebrar",
    "desvertebrarmo": "desvertebrar",
    "desvertebrarmos": "desvertebrar",
    "desvertebrará": "desvertebrar",
    "desvertebrarás": "desvertebrar",
    "desvertebrarão": "desvertebrar",
    "desvertebraríamos": "desvertebrar",
    "desvertebraríeis": "desvertebrar",
    "desvertebras": "desvertebrar",
    "desvertebrasse": "desvertebrar",
    "desvertebrassem": "desvertebrar",
    "desvertebrasses": "desvertebrar",
    "desvertebraste": "desvertebrar",
    "desvertebrastes": "desvertebrar",
    "desvertebrava": "desvertebrar",
    "desvertebravam": "desvertebrar",
    "desvertebravas": "desvertebrar",
    "desvertebre": "desvertebrar",
    "desvertebrei": "desvertebrar",
    "desvertebreis": "desvertebrar",
    "desvertebrem": "desvertebrar",
    "desvertebremo": "desvertebrar",
    "desvertebremos": "desvertebrar",
    "desvertebres": "desvertebrar",
    "desvertebro": "desvertebrar",
    "desvertebrou": "desvertebrar",
    "desvertebrá": "desvertebrar",
    "desvertebrámo": "desvertebrar",
    "desvertebrámos": "desvertebrar",
    "desvertebráramo": "desvertebrar",
    "desvertebráramos": "desvertebrar",
    "desvertebrárei": "desvertebrar",
    "desvertebráreis": "desvertebrar",
    "desvertebrásseis": "desvertebrar",
    "desvertebrássemos": "desvertebrar",
    "desvertebrávamo": "desvertebrar",
    "desvertebrávamos": "desvertebrar",
    "desvertebrávei": "desvertebrar",
    "desvertebráveis": "desvertebrar",
    "desveste": "desvestir",
    "desvestem": "desvestir",
    "desvestes": "desvestir",
    "desvesti": "desvestir",
    "desvestia": "desvestir",
    "desvestiam": "desvestir",
    "desvestias": "desvestir",
    "desvestida": "desvestir",
    "desvestidas": "desvestir",
    "desvestido": "desvestir",
    "desvestidos": "desvestir",
    "desvestimo": "desvestir",
    "desvestimos": "desvestir",
    "desvestindo": "desvestir",
    "desvestira": "desvestir",
    "desvestiram": "desvestir",
    "desvestiras": "desvestir",
    "desvestirde": "desvestir",
    "desvestirdes": "desvestir",
    "desvestire": "desvestir",
    "desvestirei": "desvestir",
    "desvestireis": "desvestir",
    "desvestirem": "desvestir",
    "desvestiremos": "desvestir",
    "desvestires": "desvestir",
    "desvestiria": "desvestir",
    "desvestiriam": "desvestir",
    "desvestirias": "desvestir",
    "desvestirmo": "desvestir",
    "desvestirmos": "desvestir",
    "desvestirá": "desvestir",
    "desvestirás": "desvestir",
    "desvestirão": "desvestir",
    "desvestiríamos": "desvestir",
    "desvestiríeis": "desvestir",
    "desvestis": "desvestir",
    "desvestisse": "desvestir",
    "desvestissem": "desvestir",
    "desvestisses": "desvestir",
    "desvestiste": "desvestir",
    "desvestistes": "desvestir",
    "desvestiu": "desvestir",
    "desvestíamo": "desvestir",
    "desvestíamos": "desvestir",
    "desvestíei": "desvestir",
    "desvestíeis": "desvestir",
    "desvestíramo": "desvestir",
    "desvestíramos": "desvestir",
    "desvestírei": "desvestir",
    "desvestíreis": "desvestir",
    "desvestísseis": "desvestir",
    "desvestíssemos": "desvestir",
    "desvezada": "desvezado",
    "desvezadas": "desvezado",
    "desvezados": "desvezado",
    "desvia": "desviar",
    "desviada": "desviar",
    "desviadas": "desviar",
    "desviado": "desviar",
    "desviadora": "desviador",
    "desviadoras": "desviador",
    "desviadores": "desviador",
    "desviados": "desviar",
    "desviai": "desviar",
    "desviais": "desviar",
    "desviam": "desviar",
    "desviamo": "desviar",
    "desviamos": "desviar",
    "desviando": "desviar",
    "desviantes": "desviante",
    "desviara": "desviar",
    "desviaram": "desviar",
    "desviaras": "desviar",
    "desviarde": "desviar",
    "desviardes": "desviar",
    "desviare": "desviar",
    "desviarei": "desviar",
    "desviareis": "desviar",
    "desviarem": "desviar",
    "desviaremos": "desviar",
    "desviares": "desviar",
    "desviaria": "desviar",
    "desviariam": "desviar",
    "desviarias": "desviar",
    "desviarmo": "desviar",
    "desviarmos": "desviar",
    "desviará": "desviar",
    "desviarás": "desviar",
    "desviarão": "desviar",
    "desviaríamos": "desviar",
    "desviaríeis": "desviar",
    "desvias": "desviar",
    "desviasse": "desviar",
    "desviassem": "desviar",
    "desviasses": "desviar",
    "desviaste": "desviar",
    "desviastes": "desviar",
    "desviava": "desviar",
    "desviavam": "desviar",
    "desviavas": "desviar",
    "desvidra": "desvidrar",
    "desvidrada": "desvidrar",
    "desvidradas": "desvidrar",
    "desvidrado": "desvidrar",
    "desvidrados": "desvidrar",
    "desvidrai": "desvidrar",
    "desvidrais": "desvidrar",
    "desvidram": "desvidrar",
    "desvidramo": "desvidrar",
    "desvidramos": "desvidrar",
    "desvidrando": "desvidrar",
    "desvidrara": "desvidrar",
    "desvidraram": "desvidrar",
    "desvidraras": "desvidrar",
    "desvidrarde": "desvidrar",
    "desvidrardes": "desvidrar",
    "desvidrare": "desvidrar",
    "desvidrarei": "desvidrar",
    "desvidrareis": "desvidrar",
    "desvidrarem": "desvidrar",
    "desvidraremos": "desvidrar",
    "desvidrares": "desvidrar",
    "desvidraria": "desvidrar",
    "desvidrariam": "desvidrar",
    "desvidrarias": "desvidrar",
    "desvidrarmo": "desvidrar",
    "desvidrarmos": "desvidrar",
    "desvidrará": "desvidrar",
    "desvidrarás": "desvidrar",
    "desvidrarão": "desvidrar",
    "desvidraríamos": "desvidrar",
    "desvidraríeis": "desvidrar",
    "desvidras": "desvidrar",
    "desvidrasse": "desvidrar",
    "desvidrassem": "desvidrar",
    "desvidrasses": "desvidrar",
    "desvidraste": "desvidrar",
    "desvidrastes": "desvidrar",
    "desvidrava": "desvidrar",
    "desvidravam": "desvidrar",
    "desvidravas": "desvidrar",
    "desvidraçada": "desvidraçado",
    "desvidraçadas": "desvidraçado",
    "desvidraçados": "desvidraçado",
    "desvidre": "desvidrar",
    "desvidrei": "desvidrar",
    "desvidreis": "desvidrar",
    "desvidrem": "desvidrar",
    "desvidremo": "desvidrar",
    "desvidremos": "desvidrar",
    "desvidres": "desvidrar",
    "desvidro": "desvidrar",
    "desvidrou": "desvidrar",
    "desvidrá": "desvidrar",
    "desvidrámo": "desvidrar",
    "desvidrámos": "desvidrar",
    "desvidráramo": "desvidrar",
    "desvidráramos": "desvidrar",
    "desvidrárei": "desvidrar",
    "desvidráreis": "desvidrar",
    "desvidrásseis": "desvidrar",
    "desvidrássemos": "desvidrar",
    "desvidrávamo": "desvidrar",
    "desvidrávamos": "desvidrar",
    "desvidrávei": "desvidrar",
    "desvidráveis": "desvidrar",
    "desvie": "desviar",
    "desviei": "desviar",
    "desvieis": "desviar",
    "desviem": "desviar",
    "desviemo": "desviar",
    "desviemos": "desviar",
    "desvies": "desviar",
    "desviga": "desvigar",
    "desvigada": "desvigar",
    "desvigadas": "desvigar",
    "desvigado": "desvigar",
    "desvigados": "desvigar",
    "desvigai": "desvigar",
    "desvigais": "desvigar",
    "desvigam": "desvigar",
    "desvigamo": "desvigar",
    "desvigamos": "desvigar",
    "desvigando": "desvigar",
    "desvigara": "desvigar",
    "desvigaram": "desvigar",
    "desvigaras": "desvigar",
    "desvigarde": "desvigar",
    "desvigardes": "desvigar",
    "desvigare": "desvigar",
    "desvigarei": "desvigar",
    "desvigareis": "desvigar",
    "desvigarem": "desvigar",
    "desvigaremos": "desvigar",
    "desvigares": "desvigar",
    "desvigaria": "desvigar",
    "desvigariam": "desvigar",
    "desvigarias": "desvigar",
    "desvigarmo": "desvigar",
    "desvigarmos": "desvigar",
    "desvigará": "desvigar",
    "desvigarás": "desvigar",
    "desvigarão": "desvigar",
    "desvigaríamos": "desvigar",
    "desvigaríeis": "desvigar",
    "desvigas": "desvigar",
    "desvigasse": "desvigar",
    "desvigassem": "desvigar",
    "desvigasses": "desvigar",
    "desvigaste": "desvigar",
    "desvigastes": "desvigar",
    "desvigava": "desvigar",
    "desvigavam": "desvigar",
    "desvigavas": "desvigar",
    "desvigia": "desvigiar",
    "desvigiada": "desvigiar",
    "desvigiadas": "desvigiar",
    "desvigiado": "desvigiar",
    "desvigiados": "desvigiar",
    "desvigiai": "desvigiar",
    "desvigiais": "desvigiar",
    "desvigiam": "desvigiar",
    "desvigiamo": "desvigiar",
    "desvigiamos": "desvigiar",
    "desvigiando": "desvigiar",
    "desvigiara": "desvigiar",
    "desvigiaram": "desvigiar",
    "desvigiaras": "desvigiar",
    "desvigiarde": "desvigiar",
    "desvigiardes": "desvigiar",
    "desvigiare": "desvigiar",
    "desvigiarei": "desvigiar",
    "desvigiareis": "desvigiar",
    "desvigiarem": "desvigiar",
    "desvigiaremos": "desvigiar",
    "desvigiares": "desvigiar",
    "desvigiaria": "desvigiar",
    "desvigiariam": "desvigiar",
    "desvigiarias": "desvigiar",
    "desvigiarmo": "desvigiar",
    "desvigiarmos": "desvigiar",
    "desvigiará": "desvigiar",
    "desvigiarás": "desvigiar",
    "desvigiarão": "desvigiar",
    "desvigiaríamos": "desvigiar",
    "desvigiaríeis": "desvigiar",
    "desvigias": "desvigiar",
    "desvigiasse": "desvigiar",
    "desvigiassem": "desvigiar",
    "desvigiasses": "desvigiar",
    "desvigiaste": "desvigiar",
    "desvigiastes": "desvigiar",
    "desvigiava": "desvigiar",
    "desvigiavam": "desvigiar",
    "desvigiavas": "desvigiar",
    "desvigie": "desvigiar",
    "desvigiei": "desvigiar",
    "desvigieis": "desvigiar",
    "desvigiem": "desvigiar",
    "desvigiemo": "desvigiar",
    "desvigiemos": "desvigiar",
    "desvigies": "desvigiar",
    "desvigio": "desvigiar",
    "desvigiou": "desvigiar",
    "desvigiá": "desvigiar",
    "desvigiámo": "desvigiar",
    "desvigiámos": "desvigiar",
    "desvigiáramo": "desvigiar",
    "desvigiáramos": "desvigiar",
    "desvigiárei": "desvigiar",
    "desvigiáreis": "desvigiar",
    "desvigiásseis": "desvigiar",
    "desvigiássemos": "desvigiar",
    "desvigiávamo": "desvigiar",
    "desvigiávamos": "desvigiar",
    "desvigiávei": "desvigiar",
    "desvigiáveis": "desvigiar",
    "desvigo": "desvigar",
    "desvigora": "desvigorar",
    "desvigorada": "desvigorar",
    "desvigoradas": "desvigorar",
    "desvigorado": "desvigorar",
    "desvigorados": "desvigorar",
    "desvigorai": "desvigorar",
    "desvigorais": "desvigorar",
    "desvigoram": "desvigorar",
    "desvigoramo": "desvigorar",
    "desvigoramos": "desvigorar",
    "desvigorando": "desvigorar",
    "desvigorara": "desvigorar",
    "desvigoraram": "desvigorar",
    "desvigoraras": "desvigorar",
    "desvigorarde": "desvigorar",
    "desvigorardes": "desvigorar",
    "desvigorare": "desvigorar",
    "desvigorarei": "desvigorar",
    "desvigorareis": "desvigorar",
    "desvigorarem": "desvigorar",
    "desvigoraremos": "desvigorar",
    "desvigorares": "desvigorar",
    "desvigoraria": "desvigorar",
    "desvigorariam": "desvigorar",
    "desvigorarias": "desvigorar",
    "desvigorarmo": "desvigorar",
    "desvigorarmos": "desvigorar",
    "desvigorará": "desvigorar",
    "desvigorarás": "desvigorar",
    "desvigorarão": "desvigorar",
    "desvigoraríamos": "desvigorar",
    "desvigoraríeis": "desvigorar",
    "desvigoras": "desvigorar",
    "desvigorasse": "desvigorar",
    "desvigorassem": "desvigorar",
    "desvigorasses": "desvigorar",
    "desvigoraste": "desvigorar",
    "desvigorastes": "desvigorar",
    "desvigorava": "desvigorar",
    "desvigoravam": "desvigorar",
    "desvigoravas": "desvigorar",
    "desvigore": "desvigorar",
    "desvigorei": "desvigorar",
    "desvigoreis": "desvigorar",
    "desvigorem": "desvigorar",
    "desvigoremo": "desvigorar",
    "desvigoremos": "desvigorar",
    "desvigores": "desvigorar",
    "desvigoro": "desvigorar",
    "desvigorou": "desvigorar",
    "desvigorá": "desvigorar",
    "desvigorámo": "desvigorar",
    "desvigorámos": "desvigorar",
    "desvigoráramo": "desvigorar",
    "desvigoráramos": "desvigorar",
    "desvigorárei": "desvigorar",
    "desvigoráreis": "desvigorar",
    "desvigorásseis": "desvigorar",
    "desvigorássemos": "desvigorar",
    "desvigorávamo": "desvigorar",
    "desvigorávamos": "desvigorar",
    "desvigorávei": "desvigorar",
    "desvigoráveis": "desvigorar",
    "desvigou": "desvigar",
    "desvigue": "desvigar",
    "desviguei": "desvigar",
    "desvigueis": "desvigar",
    "desviguem": "desvigar",
    "desviguemo": "desvigar",
    "desviguemos": "desvigar",
    "desvigues": "desvigar",
    "desvigá": "desvigar",
    "desvigámo": "desvigar",
    "desvigámos": "desvigar",
    "desvigáramo": "desvigar",
    "desvigáramos": "desvigar",
    "desvigárei": "desvigar",
    "desvigáreis": "desvigar",
    "desvigásseis": "desvigar",
    "desvigássemos": "desvigar",
    "desvigávamo": "desvigar",
    "desvigávamos": "desvigar",
    "desvigávei": "desvigar",
    "desvigáveis": "desvigar",
    "desvinca": "desvincar",
    "desvincada": "desvincar",
    "desvincadas": "desvincar",
    "desvincado": "desvincar",
    "desvincados": "desvincar",
    "desvincai": "desvincar",
    "desvincais": "desvincar",
    "desvincam": "desvincar",
    "desvincamo": "desvincar",
    "desvincamos": "desvincar",
    "desvincando": "desvincar",
    "desvincara": "desvincar",
    "desvincaram": "desvincar",
    "desvincaras": "desvincar",
    "desvincarde": "desvincar",
    "desvincardes": "desvincar",
    "desvincare": "desvincar",
    "desvincarei": "desvincar",
    "desvincareis": "desvincar",
    "desvincarem": "desvincar",
    "desvincaremos": "desvincar",
    "desvincares": "desvincar",
    "desvincaria": "desvincar",
    "desvincariam": "desvincar",
    "desvincarias": "desvincar",
    "desvincarmo": "desvincar",
    "desvincarmos": "desvincar",
    "desvincará": "desvincar",
    "desvincarás": "desvincar",
    "desvincarão": "desvincar",
    "desvincaríamos": "desvincar",
    "desvincaríeis": "desvincar",
    "desvincas": "desvincar",
    "desvincasse": "desvincar",
    "desvincassem": "desvincar",
    "desvincasses": "desvincar",
    "desvincaste": "desvincar",
    "desvincastes": "desvincar",
    "desvincava": "desvincar",
    "desvincavam": "desvincar",
    "desvincavas": "desvincar",
    "desvinco": "desvincar",
    "desvincou": "desvincar",
    "desvincula": "desvincular",
    "desvinculada": "desvincular",
    "desvinculadas": "desvincular",
    "desvinculado": "desvincular",
    "desvinculados": "desvincular",
    "desvinculai": "desvincular",
    "desvinculais": "desvincular",
    "desvinculam": "desvincular",
    "desvinculamo": "desvincular",
    "desvinculamos": "desvincular",
    "desvinculando": "desvincular",
    "desvinculara": "desvincular",
    "desvincularam": "desvincular",
    "desvincularas": "desvincular",
    "desvincularde": "desvincular",
    "desvinculardes": "desvincular",
    "desvinculare": "desvincular",
    "desvincularei": "desvincular",
    "desvinculareis": "desvincular",
    "desvincularem": "desvincular",
    "desvincularemos": "desvincular",
    "desvinculares": "desvincular",
    "desvincularia": "desvincular",
    "desvinculariam": "desvincular",
    "desvincularias": "desvincular",
    "desvincularmo": "desvincular",
    "desvincularmos": "desvincular",
    "desvinculará": "desvincular",
    "desvincularás": "desvincular",
    "desvincularão": "desvincular",
    "desvincularíamos": "desvincular",
    "desvincularíeis": "desvincular",
    "desvinculas": "desvincular",
    "desvinculasse": "desvincular",
    "desvinculassem": "desvincular",
    "desvinculasses": "desvincular",
    "desvinculaste": "desvincular",
    "desvinculastes": "desvincular",
    "desvinculava": "desvincular",
    "desvinculavam": "desvincular",
    "desvinculavas": "desvincular",
    "desvinculações": "desvinculação",
    "desvincule": "desvincular",
    "desvinculei": "desvincular",
    "desvinculeis": "desvincular",
    "desvinculem": "desvincular",
    "desvinculemo": "desvincular",
    "desvinculemos": "desvincular",
    "desvincules": "desvincular",
    "desvinculo": "desvincular",
    "desvinculou": "desvincular",
    "desvinculá": "desvincular",
    "desvinculámo": "desvincular",
    "desvinculámos": "desvincular",
    "desvinculáramo": "desvincular",
    "desvinculáramos": "desvincular",
    "desvinculárei": "desvincular",
    "desvinculáreis": "desvincular",
    "desvinculásseis": "desvincular",
    "desvinculássemos": "desvincular",
    "desvinculávamo": "desvincular",
    "desvinculávamos": "desvincular",
    "desvinculávei": "desvincular",
    "desvinculáveis": "desvinculável",
    "desvincá": "desvincar",
    "desvincámo": "desvincar",
    "desvincámos": "desvincar",
    "desvincáramo": "desvincar",
    "desvincáramos": "desvincar",
    "desvincárei": "desvincar",
    "desvincáreis": "desvincar",
    "desvincásseis": "desvincar",
    "desvincássemos": "desvincar",
    "desvincávamo": "desvincar",
    "desvincávamos": "desvincar",
    "desvincávei": "desvincar",
    "desvincáveis": "desvincar",
    "desvinque": "desvincar",
    "desvinquei": "desvincar",
    "desvinqueis": "desvincar",
    "desvinquem": "desvincar",
    "desvinquemo": "desvincar",
    "desvinquemos": "desvincar",
    "desvinques": "desvincar",
    "desvio": "desviar",
    "desvios": "desvio",
    "desviou": "desviar",
    "desvira": "desvirar",
    "desvirada": "desvirar",
    "desviradas": "desvirar",
    "desvirado": "desvirar",
    "desvirados": "desvirar",
    "desvirai": "desvirar",
    "desvirais": "desvirar",
    "desviram": "desvirar",
    "desviramo": "desvirar",
    "desviramos": "desvirar",
    "desvirando": "desvirar",
    "desvirara": "desvirar",
    "desviraram": "desvirar",
    "desviraras": "desvirar",
    "desvirarde": "desvirar",
    "desvirardes": "desvirar",
    "desvirare": "desvirar",
    "desvirarei": "desvirar",
    "desvirareis": "desvirar",
    "desvirarem": "desvirar",
    "desviraremos": "desvirar",
    "desvirares": "desvirar",
    "desviraria": "desvirar",
    "desvirariam": "desvirar",
    "desvirarias": "desvirar",
    "desvirarmo": "desvirar",
    "desvirarmos": "desvirar",
    "desvirará": "desvirar",
    "desvirarás": "desvirar",
    "desvirarão": "desvirar",
    "desviraríamos": "desvirar",
    "desviraríeis": "desvirar",
    "desviras": "desvirar",
    "desvirasse": "desvirar",
    "desvirassem": "desvirar",
    "desvirasses": "desvirar",
    "desviraste": "desvirar",
    "desvirastes": "desvirar",
    "desvirava": "desvirar",
    "desviravam": "desvirar",
    "desviravas": "desvirar",
    "desvire": "desvirar",
    "desvirei": "desvirar",
    "desvireis": "desvirar",
    "desvirem": "desvirar",
    "desviremo": "desvirar",
    "desviremos": "desvirar",
    "desvires": "desvirar",
    "desvirgina": "desvirginar",
    "desvirginada": "desvirginar",
    "desvirginadas": "desvirginar",
    "desvirginado": "desvirginar",
    "desvirginados": "desvirginar",
    "desvirginai": "desvirginar",
    "desvirginais": "desvirginar",
    "desvirginam": "desvirginar",
    "desvirginamentos": "desvirginamento",
    "desvirginamo": "desvirginar",
    "desvirginamos": "desvirginar",
    "desvirginando": "desvirginar",
    "desvirginara": "desvirginar",
    "desvirginaram": "desvirginar",
    "desvirginaras": "desvirginar",
    "desvirginarde": "desvirginar",
    "desvirginardes": "desvirginar",
    "desvirginare": "desvirginar",
    "desvirginarei": "desvirginar",
    "desvirginareis": "desvirginar",
    "desvirginarem": "desvirginar",
    "desvirginaremos": "desvirginar",
    "desvirginares": "desvirginar",
    "desvirginaria": "desvirginar",
    "desvirginariam": "desvirginar",
    "desvirginarias": "desvirginar",
    "desvirginarmo": "desvirginar",
    "desvirginarmos": "desvirginar",
    "desvirginará": "desvirginar",
    "desvirginarás": "desvirginar",
    "desvirginarão": "desvirginar",
    "desvirginaríamos": "desvirginar",
    "desvirginaríeis": "desvirginar",
    "desvirginas": "desvirginar",
    "desvirginasse": "desvirginar",
    "desvirginassem": "desvirginar",
    "desvirginasses": "desvirginar",
    "desvirginaste": "desvirginar",
    "desvirginastes": "desvirginar",
    "desvirginava": "desvirginar",
    "desvirginavam": "desvirginar",
    "desvirginavas": "desvirginar",
    "desvirgine": "desvirginar",
    "desvirginei": "desvirginar",
    "desvirgineis": "desvirginar",
    "desvirginem": "desvirginar",
    "desvirginemo": "desvirginar",
    "desvirginemos": "desvirginar",
    "desvirgines": "desvirginar",
    "desvirgino": "desvirginar",
    "desvirginou": "desvirginar",
    "desvirginá": "desvirginar",
    "desvirginámo": "desvirginar",
    "desvirginámos": "desvirginar",
    "desvirgináramo": "desvirginar",
    "desvirgináramos": "desvirginar",
    "desvirginárei": "desvirginar",
    "desvirgináreis": "desvirginar",
    "desvirginásseis": "desvirginar",
    "desvirginássemos": "desvirginar",
    "desvirginávamo": "desvirginar",
    "desvirginávamos": "desvirginar",
    "desvirginávei": "desvirginar",
    "desvirgináveis": "desvirginar",
    "desvirgulada": "desvirgulado",
    "desvirguladas": "desvirgulado",
    "desvirgulados": "desvirgulado",
    "desviriliza": "desvirilizar",
    "desvirilizada": "desvirilizar",
    "desvirilizadas": "desvirilizar",
    "desvirilizado": "desvirilizar",
    "desvirilizados": "desvirilizar",
    "desvirilizai": "desvirilizar",
    "desvirilizais": "desvirilizar",
    "desvirilizam": "desvirilizar",
    "desvirilizamo": "desvirilizar",
    "desvirilizamos": "desvirilizar",
    "desvirilizando": "desvirilizar",
    "desvirilizara": "desvirilizar",
    "desvirilizaram": "desvirilizar",
    "desvirilizaras": "desvirilizar",
    "desvirilizarde": "desvirilizar",
    "desvirilizardes": "desvirilizar",
    "desvirilizare": "desvirilizar",
    "desvirilizarei": "desvirilizar",
    "desvirilizareis": "desvirilizar",
    "desvirilizarem": "desvirilizar",
    "desvirilizaremos": "desvirilizar",
    "desvirilizares": "desvirilizar",
    "desvirilizaria": "desvirilizar",
    "desvirilizariam": "desvirilizar",
    "desvirilizarias": "desvirilizar",
    "desvirilizarmo": "desvirilizar",
    "desvirilizarmos": "desvirilizar",
    "desvirilizará": "desvirilizar",
    "desvirilizarás": "desvirilizar",
    "desvirilizarão": "desvirilizar",
    "desvirilizaríamos": "desvirilizar",
    "desvirilizaríeis": "desvirilizar",
    "desvirilizas": "desvirilizar",
    "desvirilizasse": "desvirilizar",
    "desvirilizassem": "desvirilizar",
    "desvirilizasses": "desvirilizar",
    "desvirilizaste": "desvirilizar",
    "desvirilizastes": "desvirilizar",
    "desvirilizava": "desvirilizar",
    "desvirilizavam": "desvirilizar",
    "desvirilizavas": "desvirilizar",
    "desvirilize": "desvirilizar",
    "desvirilizei": "desvirilizar",
    "desvirilizeis": "desvirilizar",
    "desvirilizem": "desvirilizar",
    "desvirilizemo": "desvirilizar",
    "desvirilizemos": "desvirilizar",
    "desvirilizes": "desvirilizar",
    "desvirilizo": "desvirilizar",
    "desvirilizou": "desvirilizar",
    "desvirilizá": "desvirilizar",
    "desvirilizámo": "desvirilizar",
    "desvirilizámos": "desvirilizar",
    "desvirilizáramo": "desvirilizar",
    "desvirilizáramos": "desvirilizar",
    "desvirilizárei": "desvirilizar",
    "desvirilizáreis": "desvirilizar",
    "desvirilizásseis": "desvirilizar",
    "desvirilizássemos": "desvirilizar",
    "desvirilizávamo": "desvirilizar",
    "desvirilizávamos": "desvirilizar",
    "desvirilizávei": "desvirilizar",
    "desvirilizáveis": "desvirilizar",
    "desviro": "desvirar",
    "desvirou": "desvirar",
    "desvirtua": "desvirtuar",
    "desvirtuada": "desvirtuar",
    "desvirtuadas": "desvirtuar",
    "desvirtuado": "desvirtuar",
    "desvirtuados": "desvirtuar",
    "desvirtuai": "desvirtuar",
    "desvirtuais": "desvirtuar",
    "desvirtualizada": "desvirtualizado",
    "desvirtualizadas": "desvirtualizado",
    "desvirtualizados": "desvirtualizado",
    "desvirtuam": "desvirtuar",
    "desvirtuamentos": "desvirtuamento",
    "desvirtuamo": "desvirtuar",
    "desvirtuamos": "desvirtuar",
    "desvirtuando": "desvirtuar",
    "desvirtuara": "desvirtuar",
    "desvirtuaram": "desvirtuar",
    "desvirtuaras": "desvirtuar",
    "desvirtuarde": "desvirtuar",
    "desvirtuardes": "desvirtuar",
    "desvirtuare": "desvirtuar",
    "desvirtuarei": "desvirtuar",
    "desvirtuareis": "desvirtuar",
    "desvirtuarem": "desvirtuar",
    "desvirtuaremos": "desvirtuar",
    "desvirtuares": "desvirtuar",
    "desvirtuaria": "desvirtuar",
    "desvirtuariam": "desvirtuar",
    "desvirtuarias": "desvirtuar",
    "desvirtuarmo": "desvirtuar",
    "desvirtuarmos": "desvirtuar",
    "desvirtuará": "desvirtuar",
    "desvirtuarás": "desvirtuar",
    "desvirtuarão": "desvirtuar",
    "desvirtuaríamos": "desvirtuar",
    "desvirtuaríeis": "desvirtuar",
    "desvirtuas": "desvirtuar",
    "desvirtuasse": "desvirtuar",
    "desvirtuassem": "desvirtuar",
    "desvirtuasses": "desvirtuar",
    "desvirtuaste": "desvirtuar",
    "desvirtuastes": "desvirtuar",
    "desvirtuava": "desvirtuar",
    "desvirtuavam": "desvirtuar",
    "desvirtuavas": "desvirtuar",
    "desvirtuações": "desvirtuação",
    "desvirtudes": "desvirtude",
    "desvirtue": "desvirtuar",
    "desvirtuei": "desvirtuar",
    "desvirtueis": "desvirtuar",
    "desvirtuem": "desvirtuar",
    "desvirtuemo": "desvirtuar",
    "desvirtuemos": "desvirtuar",
    "desvirtues": "desvirtuar",
    "desvirtuo": "desvirtuar",
    "desvirtuosa": "desvirtuoso",
    "desvirtuosas": "desvirtuoso",
    "desvirtuosos": "desvirtuoso",
    "desvirtuou": "desvirtuar",
    "desvirtuá": "desvirtuar",
    "desvirtuámo": "desvirtuar",
    "desvirtuámos": "desvirtuar",
    "desvirtuáramo": "desvirtuar",
    "desvirtuáramos": "desvirtuar",
    "desvirtuárei": "desvirtuar",
    "desvirtuáreis": "desvirtuar",
    "desvirtuásseis": "desvirtuar",
    "desvirtuássemos": "desvirtuar",
    "desvirtuávamo": "desvirtuar",
    "desvirtuávamos": "desvirtuar",
    "desvirtuávei": "desvirtuar",
    "desvirtuáveis": "desvirtuar",
    "desvirá": "desvirar",
    "desvirámo": "desvirar",
    "desvirámos": "desvirar",
    "desviráramo": "desvirar",
    "desviráramos": "desvirar",
    "desvirárei": "desvirar",
    "desviráreis": "desvirar",
    "desvirásseis": "desvirar",
    "desvirássemos": "desvirar",
    "desvirávamo": "desvirar",
    "desvirávamos": "desvirar",
    "desvirávei": "desvirar",
    "desviráveis": "desvirar",
    "desviscera": "desviscerar",
    "desviscerada": "desviscerar",
    "desvisceradas": "desviscerar",
    "desviscerado": "desviscerar",
    "desviscerados": "desviscerar",
    "desviscerai": "desviscerar",
    "desviscerais": "desviscerar",
    "desvisceram": "desviscerar",
    "desvisceramo": "desviscerar",
    "desvisceramos": "desviscerar",
    "desviscerando": "desviscerar",
    "desviscerara": "desviscerar",
    "desvisceraram": "desviscerar",
    "desvisceraras": "desviscerar",
    "desviscerarde": "desviscerar",
    "desviscerardes": "desviscerar",
    "desviscerare": "desviscerar",
    "desviscerarei": "desviscerar",
    "desviscerareis": "desviscerar",
    "desviscerarem": "desviscerar",
    "desvisceraremos": "desviscerar",
    "desviscerares": "desviscerar",
    "desvisceraria": "desviscerar",
    "desviscerariam": "desviscerar",
    "desviscerarias": "desviscerar",
    "desviscerarmo": "desviscerar",
    "desviscerarmos": "desviscerar",
    "desviscerará": "desviscerar",
    "desviscerarás": "desviscerar",
    "desviscerarão": "desviscerar",
    "desvisceraríamos": "desviscerar",
    "desvisceraríeis": "desviscerar",
    "desvisceras": "desviscerar",
    "desviscerasse": "desviscerar",
    "desviscerassem": "desviscerar",
    "desviscerasses": "desviscerar",
    "desvisceraste": "desviscerar",
    "desviscerastes": "desviscerar",
    "desviscerava": "desviscerar",
    "desvisceravam": "desviscerar",
    "desvisceravas": "desviscerar",
    "desviscere": "desviscerar",
    "desviscerei": "desviscerar",
    "desviscereis": "desviscerar",
    "desviscerem": "desviscerar",
    "desvisceremo": "desviscerar",
    "desvisceremos": "desviscerar",
    "desvisceres": "desviscerar",
    "desviscero": "desviscerar",
    "desviscerou": "desviscerar",
    "desviscerá": "desviscerar",
    "desviscerámo": "desviscerar",
    "desviscerámos": "desviscerar",
    "desvisceráramo": "desviscerar",
    "desvisceráramos": "desviscerar",
    "desviscerárei": "desviscerar",
    "desvisceráreis": "desviscerar",
    "desviscerásseis": "desviscerar",
    "desviscerássemos": "desviscerar",
    "desviscerávamo": "desviscerar",
    "desviscerávamos": "desviscerar",
    "desviscerávei": "desviscerar",
    "desvisceráveis": "desviscerar",
    "desvisga": "desvisgar",
    "desvisgada": "desvisgar",
    "desvisgadas": "desvisgar",
    "desvisgado": "desvisgar",
    "desvisgados": "desvisgar",
    "desvisgai": "desvisgar",
    "desvisgais": "desvisgar",
    "desvisgam": "desvisgar",
    "desvisgamo": "desvisgar",
    "desvisgamos": "desvisgar",
    "desvisgando": "desvisgar",
    "desvisgara": "desvisgar",
    "desvisgaram": "desvisgar",
    "desvisgaras": "desvisgar",
    "desvisgarde": "desvisgar",
    "desvisgardes": "desvisgar",
    "desvisgare": "desvisgar",
    "desvisgarei": "desvisgar",
    "desvisgareis": "desvisgar",
    "desvisgarem": "desvisgar",
    "desvisgaremos": "desvisgar",
    "desvisgares": "desvisgar",
    "desvisgaria": "desvisgar",
    "desvisgariam": "desvisgar",
    "desvisgarias": "desvisgar",
    "desvisgarmo": "desvisgar",
    "desvisgarmos": "desvisgar",
    "desvisgará": "desvisgar",
    "desvisgarás": "desvisgar",
    "desvisgarão": "desvisgar",
    "desvisgaríamos": "desvisgar",
    "desvisgaríeis": "desvisgar",
    "desvisgas": "desvisgar",
    "desvisgasse": "desvisgar",
    "desvisgassem": "desvisgar",
    "desvisgasses": "desvisgar",
    "desvisgaste": "desvisgar",
    "desvisgastes": "desvisgar",
    "desvisgava": "desvisgar",
    "desvisgavam": "desvisgar",
    "desvisgavas": "desvisgar",
    "desvisgo": "desvisgar",
    "desvisgou": "desvisgar",
    "desvisgue": "desvisgar",
    "desvisguei": "desvisgar",
    "desvisgueis": "desvisgar",
    "desvisguem": "desvisgar",
    "desvisguemo": "desvisgar",
    "desvisguemos": "desvisgar",
    "desvisgues": "desvisgar",
    "desvisgá": "desvisgar",
    "desvisgámo": "desvisgar",
    "desvisgámos": "desvisgar",
    "desvisgáramo": "desvisgar",
    "desvisgáramos": "desvisgar",
    "desvisgárei": "desvisgar",
    "desvisgáreis": "desvisgar",
    "desvisgásseis": "desvisgar",
    "desvisgássemos": "desvisgar",
    "desvisgávamo": "desvisgar",
    "desvisgávamos": "desvisgar",
    "desvisgávei": "desvisgar",
    "desvisgáveis": "desvisgar",
    "desvista": "desvestir",
    "desvistais": "desvestir",
    "desvistam": "desvestir",
    "desvistamo": "desvestir",
    "desvistamos": "desvestir",
    "desvistas": "desvestir",
    "desvisto": "desvestir",
    "desvitaliza": "desvitalizar",
    "desvitalizada": "desvitalizar",
    "desvitalizadas": "desvitalizar",
    "desvitalizado": "desvitalizar",
    "desvitalizados": "desvitalizar",
    "desvitalizai": "desvitalizar",
    "desvitalizais": "desvitalizar",
    "desvitalizam": "desvitalizar",
    "desvitalizamo": "desvitalizar",
    "desvitalizamos": "desvitalizar",
    "desvitalizando": "desvitalizar",
    "desvitalizara": "desvitalizar",
    "desvitalizaram": "desvitalizar",
    "desvitalizaras": "desvitalizar",
    "desvitalizarde": "desvitalizar",
    "desvitalizardes": "desvitalizar",
    "desvitalizare": "desvitalizar",
    "desvitalizarei": "desvitalizar",
    "desvitalizareis": "desvitalizar",
    "desvitalizarem": "desvitalizar",
    "desvitalizaremos": "desvitalizar",
    "desvitalizares": "desvitalizar",
    "desvitalizaria": "desvitalizar",
    "desvitalizariam": "desvitalizar",
    "desvitalizarias": "desvitalizar",
    "desvitalizarmo": "desvitalizar",
    "desvitalizarmos": "desvitalizar",
    "desvitalizará": "desvitalizar",
    "desvitalizarás": "desvitalizar",
    "desvitalizarão": "desvitalizar",
    "desvitalizaríamos": "desvitalizar",
    "desvitalizaríeis": "desvitalizar",
    "desvitalizas": "desvitalizar",
    "desvitalizasse": "desvitalizar",
    "desvitalizassem": "desvitalizar",
    "desvitalizasses": "desvitalizar",
    "desvitalizaste": "desvitalizar",
    "desvitalizastes": "desvitalizar",
    "desvitalizava": "desvitalizar",
    "desvitalizavam": "desvitalizar",
    "desvitalizavas": "desvitalizar",
    "desvitalize": "desvitalizar",
    "desvitalizei": "desvitalizar",
    "desvitalizeis": "desvitalizar",
    "desvitalizem": "desvitalizar",
    "desvitalizemo": "desvitalizar",
    "desvitalizemos": "desvitalizar",
    "desvitalizes": "desvitalizar",
    "desvitalizo": "desvitalizar",
    "desvitalizou": "desvitalizar",
    "desvitalizá": "desvitalizar",
    "desvitalizámo": "desvitalizar",
    "desvitalizámos": "desvitalizar",
    "desvitalizáramo": "desvitalizar",
    "desvitalizáramos": "desvitalizar",
    "desvitalizárei": "desvitalizar",
    "desvitalizáreis": "desvitalizar",
    "desvitalizásseis": "desvitalizar",
    "desvitalizássemos": "desvitalizar",
    "desvitalizávamo": "desvitalizar",
    "desvitalizávamos": "desvitalizar",
    "desvitalizávei": "desvitalizar",
    "desvitalizáveis": "desvitalizável",
    "desvitamina": "desvitaminar",
    "desvitaminada": "desvitaminar",
    "desvitaminadas": "desvitaminar",
    "desvitaminado": "desvitaminar",
    "desvitaminados": "desvitaminar",
    "desvitaminai": "desvitaminar",
    "desvitaminais": "desvitaminar",
    "desvitaminam": "desvitaminar",
    "desvitaminamo": "desvitaminar",
    "desvitaminamos": "desvitaminar",
    "desvitaminando": "desvitaminar",
    "desvitaminara": "desvitaminar",
    "desvitaminaram": "desvitaminar",
    "desvitaminaras": "desvitaminar",
    "desvitaminarde": "desvitaminar",
    "desvitaminardes": "desvitaminar",
    "desvitaminare": "desvitaminar",
    "desvitaminarei": "desvitaminar",
    "desvitaminareis": "desvitaminar",
    "desvitaminarem": "desvitaminar",
    "desvitaminaremos": "desvitaminar",
    "desvitaminares": "desvitaminar",
    "desvitaminaria": "desvitaminar",
    "desvitaminariam": "desvitaminar",
    "desvitaminarias": "desvitaminar",
    "desvitaminarmo": "desvitaminar",
    "desvitaminarmos": "desvitaminar",
    "desvitaminará": "desvitaminar",
    "desvitaminarás": "desvitaminar",
    "desvitaminarão": "desvitaminar",
    "desvitaminaríamos": "desvitaminar",
    "desvitaminaríeis": "desvitaminar",
    "desvitaminas": "desvitaminar",
    "desvitaminasse": "desvitaminar",
    "desvitaminassem": "desvitaminar",
    "desvitaminasses": "desvitaminar",
    "desvitaminaste": "desvitaminar",
    "desvitaminastes": "desvitaminar",
    "desvitaminava": "desvitaminar",
    "desvitaminavam": "desvitaminar",
    "desvitaminavas": "desvitaminar",
    "desvitamine": "desvitaminar",
    "desvitaminei": "desvitaminar",
    "desvitamineis": "desvitaminar",
    "desvitaminem": "desvitaminar",
    "desvitaminemo": "desvitaminar",
    "desvitaminemos": "desvitaminar",
    "desvitamines": "desvitaminar",
    "desvitamino": "desvitaminar",
    "desvitaminou": "desvitaminar",
    "desvitaminá": "desvitaminar",
    "desvitaminámo": "desvitaminar",
    "desvitaminámos": "desvitaminar",
    "desvitamináramo": "desvitaminar",
    "desvitamináramos": "desvitaminar",
    "desvitaminárei": "desvitaminar",
    "desvitamináreis": "desvitaminar",
    "desvitaminásseis": "desvitaminar",
    "desvitaminássemos": "desvitaminar",
    "desvitaminávamo": "desvitaminar",
    "desvitaminávamos": "desvitaminar",
    "desvitaminávei": "desvitaminar",
    "desvitamináveis": "desvitaminar",
    "desvitrificações": "desvitrificação",
    "desviva": "desviver",
    "desvivais": "desviver",
    "desvivam": "desviver",
    "desvivamo": "desviver",
    "desvivamos": "desviver",
    "desvivas": "desviver",
    "desvive": "desviver",
    "desvivei": "desviver",
    "desviveis": "desviver",
    "desvivem": "desviver",
    "desvivemo": "desviver",
    "desvivemos": "desviver",
    "desvivendo": "desviver",
    "desvivera": "desviver",
    "desviveram": "desviver",
    "desviveras": "desviver",
    "desviverdes": "desviver",
    "desviverei": "desviver",
    "desvivereis": "desviver",
    "desviverem": "desviver",
    "desviveremos": "desviver",
    "desviveres": "desviver",
    "desviveria": "desviver",
    "desviveriam": "desviver",
    "desviverias": "desviver",
    "desvivermo": "desviver",
    "desvivermos": "desviver",
    "desviverá": "desviver",
    "desviverás": "desviver",
    "desviverão": "desviver",
    "desviveríamos": "desviver",
    "desviveríeis": "desviver",
    "desvives": "desviver",
    "desvivesse": "desviver",
    "desvivessem": "desviver",
    "desvivesses": "desviver",
    "desviveste": "desviver",
    "desvivestes": "desviver",
    "desviveu": "desviver",
    "desvivi": "desviver",
    "desvivia": "desviver",
    "desviviam": "desviver",
    "desvivias": "desviver",
    "desvivida": "desviver",
    "desvividas": "desviver",
    "desvivido": "desviver",
    "desvividos": "desviver",
    "desvivo": "desviver",
    "desvivêramo": "desviver",
    "desvivêramos": "desviver",
    "desvivêreis": "desviver",
    "desvivêsseis": "desviver",
    "desvivêssemos": "desviver",
    "desvivíamo": "desviver",
    "desvivíamos": "desviver",
    "desvivíeis": "desviver",
    "desvizinha": "desvizinhar",
    "desvizinhada": "desvizinhar",
    "desvizinhadas": "desvizinhar",
    "desvizinhado": "desvizinhar",
    "desvizinhados": "desvizinhar",
    "desvizinhai": "desvizinhar",
    "desvizinhais": "desvizinhar",
    "desvizinham": "desvizinhar",
    "desvizinhamo": "desvizinhar",
    "desvizinhamos": "desvizinhar",
    "desvizinhando": "desvizinhar",
    "desvizinhanças": "desvizinhança",
    "desvizinhara": "desvizinhar",
    "desvizinharam": "desvizinhar",
    "desvizinharas": "desvizinhar",
    "desvizinharde": "desvizinhar",
    "desvizinhardes": "desvizinhar",
    "desvizinhare": "desvizinhar",
    "desvizinharei": "desvizinhar",
    "desvizinhareis": "desvizinhar",
    "desvizinharem": "desvizinhar",
    "desvizinharemos": "desvizinhar",
    "desvizinhares": "desvizinhar",
    "desvizinharia": "desvizinhar",
    "desvizinhariam": "desvizinhar",
    "desvizinharias": "desvizinhar",
    "desvizinharmo": "desvizinhar",
    "desvizinharmos": "desvizinhar",
    "desvizinhará": "desvizinhar",
    "desvizinharás": "desvizinhar",
    "desvizinharão": "desvizinhar",
    "desvizinharíamos": "desvizinhar",
    "desvizinharíeis": "desvizinhar",
    "desvizinhas": "desvizinhar",
    "desvizinhasse": "desvizinhar",
    "desvizinhassem": "desvizinhar",
    "desvizinhasses": "desvizinhar",
    "desvizinhaste": "desvizinhar",
    "desvizinhastes": "desvizinhar",
    "desvizinhava": "desvizinhar",
    "desvizinhavam": "desvizinhar",
    "desvizinhavas": "desvizinhar",
    "desvizinhe": "desvizinhar",
    "desvizinhei": "desvizinhar",
    "desvizinheis": "desvizinhar",
    "desvizinhem": "desvizinhar",
    "desvizinhemo": "desvizinhar",
    "desvizinhemos": "desvizinhar",
    "desvizinhes": "desvizinhar",
    "desvizinho": "desvizinhar",
    "desvizinhou": "desvizinhar",
    "desvizinhá": "desvizinhar",
    "desvizinhámo": "desvizinhar",
    "desvizinhámos": "desvizinhar",
    "desvizinháramo": "desvizinhar",
    "desvizinháramos": "desvizinhar",
    "desvizinhárei": "desvizinhar",
    "desvizinháreis": "desvizinhar",
    "desvizinhásseis": "desvizinhar",
    "desvizinhássemos": "desvizinhar",
    "desvizinhávamo": "desvizinhar",
    "desvizinhávamos": "desvizinhar",
    "desvizinhávei": "desvizinhar",
    "desvizinháveis": "desvizinhar",
    "desviá": "desviar",
    "desviámo": "desviar",
    "desviámos": "desviar",
    "desviáramo": "desviar",
    "desviáramos": "desviar",
    "desviárei": "desviar",
    "desviáreis": "desviar",
    "desviásseis": "desviar",
    "desviássemos": "desviar",
    "desviávamo": "desviar",
    "desviávamos": "desviar",
    "desviávei": "desviar",
    "desviáveis": "desviável",
    "desvocaliza": "desvocalizar",
    "desvocalizada": "desvocalizar",
    "desvocalizadas": "desvocalizar",
    "desvocalizado": "desvocalizar",
    "desvocalizados": "desvocalizar",
    "desvocalizai": "desvocalizar",
    "desvocalizais": "desvocalizar",
    "desvocalizam": "desvocalizar",
    "desvocalizamo": "desvocalizar",
    "desvocalizamos": "desvocalizar",
    "desvocalizando": "desvocalizar",
    "desvocalizara": "desvocalizar",
    "desvocalizaram": "desvocalizar",
    "desvocalizaras": "desvocalizar",
    "desvocalizarde": "desvocalizar",
    "desvocalizardes": "desvocalizar",
    "desvocalizare": "desvocalizar",
    "desvocalizarei": "desvocalizar",
    "desvocalizareis": "desvocalizar",
    "desvocalizarem": "desvocalizar",
    "desvocalizaremos": "desvocalizar",
    "desvocalizares": "desvocalizar",
    "desvocalizaria": "desvocalizar",
    "desvocalizariam": "desvocalizar",
    "desvocalizarias": "desvocalizar",
    "desvocalizarmo": "desvocalizar",
    "desvocalizarmos": "desvocalizar",
    "desvocalizará": "desvocalizar",
    "desvocalizarás": "desvocalizar",
    "desvocalizarão": "desvocalizar",
    "desvocalizaríamos": "desvocalizar",
    "desvocalizaríeis": "desvocalizar",
    "desvocalizas": "desvocalizar",
    "desvocalizasse": "desvocalizar",
    "desvocalizassem": "desvocalizar",
    "desvocalizasses": "desvocalizar",
    "desvocalizaste": "desvocalizar",
    "desvocalizastes": "desvocalizar",
    "desvocalizava": "desvocalizar",
    "desvocalizavam": "desvocalizar",
    "desvocalizavas": "desvocalizar",
    "desvocalizações": "desvocalização",
    "desvocalize": "desvocalizar",
    "desvocalizei": "desvocalizar",
    "desvocalizeis": "desvocalizar",
    "desvocalizem": "desvocalizar",
    "desvocalizemo": "desvocalizar",
    "desvocalizemos": "desvocalizar",
    "desvocalizes": "desvocalizar",
    "desvocalizo": "desvocalizar",
    "desvocalizou": "desvocalizar",
    "desvocalizá": "desvocalizar",
    "desvocalizámo": "desvocalizar",
    "desvocalizámos": "desvocalizar",
    "desvocalizáramo": "desvocalizar",
    "desvocalizáramos": "desvocalizar",
    "desvocalizárei": "desvocalizar",
    "desvocalizáreis": "desvocalizar",
    "desvocalizásseis": "desvocalizar",
    "desvocalizássemos": "desvocalizar",
    "desvocalizávamo": "desvocalizar",
    "desvocalizávamos": "desvocalizar",
    "desvocalizávei": "desvocalizar",
    "desvocalizáveis": "desvocalizar",
    "desvoluma": "desvolumar",
    "desvolumada": "desvolumar",
    "desvolumadas": "desvolumar",
    "desvolumado": "desvolumar",
    "desvolumados": "desvolumar",
    "desvolumai": "desvolumar",
    "desvolumais": "desvolumar",
    "desvolumam": "desvolumar",
    "desvolumamo": "desvolumar",
    "desvolumamos": "desvolumar",
    "desvolumando": "desvolumar",
    "desvolumara": "desvolumar",
    "desvolumaram": "desvolumar",
    "desvolumaras": "desvolumar",
    "desvolumarde": "desvolumar",
    "desvolumardes": "desvolumar",
    "desvolumare": "desvolumar",
    "desvolumarei": "desvolumar",
    "desvolumareis": "desvolumar",
    "desvolumarem": "desvolumar",
    "desvolumaremos": "desvolumar",
    "desvolumares": "desvolumar",
    "desvolumaria": "desvolumar",
    "desvolumariam": "desvolumar",
    "desvolumarias": "desvolumar",
    "desvolumarmo": "desvolumar",
    "desvolumarmos": "desvolumar",
    "desvolumará": "desvolumar",
    "desvolumarás": "desvolumar",
    "desvolumarão": "desvolumar",
    "desvolumaríamos": "desvolumar",
    "desvolumaríeis": "desvolumar",
    "desvolumas": "desvolumar",
    "desvolumasse": "desvolumar",
    "desvolumassem": "desvolumar",
    "desvolumasses": "desvolumar",
    "desvolumaste": "desvolumar",
    "desvolumastes": "desvolumar",
    "desvolumava": "desvolumar",
    "desvolumavam": "desvolumar",
    "desvolumavas": "desvolumar",
    "desvolume": "desvolumar",
    "desvolumei": "desvolumar",
    "desvolumeis": "desvolumar",
    "desvolumem": "desvolumar",
    "desvolumemo": "desvolumar",
    "desvolumemos": "desvolumar",
    "desvolumes": "desvolumar",
    "desvolumo": "desvolumar",
    "desvolumou": "desvolumar",
    "desvolumá": "desvolumar",
    "desvolumámo": "desvolumar",
    "desvolumámos": "desvolumar",
    "desvolumáramo": "desvolumar",
    "desvolumáramos": "desvolumar",
    "desvolumárei": "desvolumar",
    "desvolumáreis": "desvolumar",
    "desvolumásseis": "desvolumar",
    "desvolumássemos": "desvolumar",
    "desvolumávamo": "desvolumar",
    "desvolumávamos": "desvolumar",
    "desvolumávei": "desvolumar",
    "desvolumáveis": "desvolumar",
    "desvolvida": "desvolvido",
    "desvolvidas": "desvolvido",
    "desvolvidos": "desvolvido",
    "desvãos": "desvão",
    "desxadrezada": "desxadrezado",
    "desxadrezadas": "desxadrezado",
    "desxadrezados": "desxadrezado",
    "deszela": "deszelar",
    "deszelada": "deszelar",
    "deszeladas": "deszelar",
    "deszelado": "deszelar",
    "deszelados": "deszelar",
    "deszelai": "deszelar",
    "deszelais": "deszelar",
    "deszelam": "deszelar",
    "deszelamo": "deszelar",
    "deszelamos": "deszelar",
    "deszelando": "deszelar",
    "deszelara": "deszelar",
    "deszelaram": "deszelar",
    "deszelaras": "deszelar",
    "deszelarde": "deszelar",
    "deszelardes": "deszelar",
    "deszelare": "deszelar",
    "deszelarei": "deszelar",
    "deszelareis": "deszelar",
    "deszelarem": "deszelar",
    "deszelaremos": "deszelar",
    "deszelares": "deszelar",
    "deszelaria": "deszelar",
    "deszelariam": "deszelar",
    "deszelarias": "deszelar",
    "deszelarmo": "deszelar",
    "deszelarmos": "deszelar",
    "deszelará": "deszelar",
    "deszelarás": "deszelar",
    "deszelarão": "deszelar",
    "deszelaríamos": "deszelar",
    "deszelaríeis": "deszelar",
    "deszelas": "deszelar",
    "deszelasse": "deszelar",
    "deszelassem": "deszelar",
    "deszelasses": "deszelar",
    "deszelaste": "deszelar",
    "deszelastes": "deszelar",
    "deszelava": "deszelar",
    "deszelavam": "deszelar",
    "deszelavas": "deszelar",
    "deszele": "deszelar",
    "deszelei": "deszelar",
    "deszeleis": "deszelar",
    "deszelem": "deszelar",
    "deszelemo": "deszelar",
    "deszelemos": "deszelar",
    "deszeles": "deszelar",
    "deszelo": "deszelar",
    "deszelou": "deszelar",
    "deszelá": "deszelar",
    "deszelámo": "deszelar",
    "deszelámos": "deszelar",
    "deszeláramo": "deszelar",
    "deszeláramos": "deszelar",
    "deszelárei": "deszelar",
    "deszeláreis": "deszelar",
    "deszelásseis": "deszelar",
    "deszelássemos": "deszelar",
    "deszelávamo": "deszelar",
    "deszelávamos": "deszelar",
    "deszelávei": "deszelar",
    "deszeláveis": "deszelar",
    "deszincicações": "deszincicação",
    "deszincificações": "deszincificação",
    "desábitos": "desábito",
    "desânimos": "desânimo",
    "desça": "descer",
    "desçais": "descer",
    "desçam": "descer",
    "desçamo": "descer",
    "desçamos": "descer",
    "desças": "descer",
    "desço": "descer",
    "desértica": "desértico",
    "desérticas": "desértico",
    "desérticos": "desértico",
    "desídias": "desídia",
    "desígnios": "desígnio",
    "detalha": "detalhar",
    "detalhada": "detalhar",
    "detalhadas": "detalhar",
    "detalhado": "detalhar",
    "detalhados": "detalhar",
    "detalhadíssima": "detalhado",
    "detalhadíssimas": "detalhado",
    "detalhadíssimo": "detalhado",
    "detalhadíssimos": "detalhado",
    "detalhai": "detalhar",
    "detalhais": "detalhar",
    "detalham": "detalhar",
    "detalhamo": "detalhar",
    "detalhamos": "detalhar",
    "detalhando": "detalhar",
    "detalhara": "detalhar",
    "detalharam": "detalhar",
    "detalharas": "detalhar",
    "detalharde": "detalhar",
    "detalhardes": "detalhar",
    "detalhare": "detalhar",
    "detalharei": "detalhar",
    "detalhareis": "detalhar",
    "detalharem": "detalhar",
    "detalharemos": "detalhar",
    "detalhares": "detalhar",
    "detalharia": "detalhar",
    "detalhariam": "detalhar",
    "detalharias": "detalhar",
    "detalharmo": "detalhar",
    "detalharmos": "detalhar",
    "detalhará": "detalhar",
    "detalharás": "detalhar",
    "detalharão": "detalhar",
    "detalharíamos": "detalhar",
    "detalharíeis": "detalhar",
    "detalhas": "detalhar",
    "detalhasse": "detalhar",
    "detalhassem": "detalhar",
    "detalhasses": "detalhar",
    "detalhaste": "detalhar",
    "detalhastes": "detalhar",
    "detalhava": "detalhar",
    "detalhavam": "detalhar",
    "detalhavas": "detalhar",
    "detalhe": "detalhar",
    "detalhei": "detalhar",
    "detalheis": "detalhar",
    "detalhem": "detalhar",
    "detalhemo": "detalhar",
    "detalhemos": "detalhar",
    "detalhes": "detalhe",
    "detalho": "detalhar",
    "detalhou": "detalhar",
    "detalhá": "detalhar",
    "detalhámo": "detalhar",
    "detalhámos": "detalhar",
    "detalháramo": "detalhar",
    "detalháramos": "detalhar",
    "detalhárei": "detalhar",
    "detalháreis": "detalhar",
    "detalhásseis": "detalhar",
    "detalhássemos": "detalhar",
    "detalhávamo": "detalhar",
    "detalhávamos": "detalhar",
    "detalhávei": "detalhar",
    "detalháveis": "detalhável",
    "detecta": "detectar",
    "detectada": "detectar",
    "detectadas": "detectar",
    "detectado": "detectar",
    "detectados": "detectar",
    "detectai": "detectar",
    "detectais": "detectar",
    "detectam": "detectar",
    "detectamo": "detectar",
    "detectamos": "detectar",
    "detectando": "detectar",
    "detectara": "detectar",
    "detectaram": "detectar",
    "detectaras": "detectar",
    "detectarde": "detectar",
    "detectardes": "detectar",
    "detectare": "detectar",
    "detectarei": "detectar",
    "detectareis": "detectar",
    "detectarem": "detectar",
    "detectaremos": "detectar",
    "detectares": "detectar",
    "detectaria": "detectar",
    "detectariam": "detectar",
    "detectarias": "detectar",
    "detectarmo": "detectar",
    "detectarmos": "detectar",
    "detectará": "detectar",
    "detectarás": "detectar",
    "detectarão": "detectar",
    "detectaríamos": "detectar",
    "detectaríeis": "detectar",
    "detectas": "detectar",
    "detectasse": "detectar",
    "detectassem": "detectar",
    "detectasses": "detectar",
    "detectaste": "detectar",
    "detectastes": "detectar",
    "detectava": "detectar",
    "detectavam": "detectar",
    "detectavas": "detectar",
    "detecte": "detectar",
    "detectei": "detectar",
    "detecteis": "detectar",
    "detectem": "detectar",
    "detectemo": "detectar",
    "detectemos": "detectar",
    "detectes": "detectar",
    "detectiva": "detective",
    "detectivas": "detective",
    "detectives": "detective",
    "detecto": "detectar",
    "detectores": "detector",
    "detectou": "detectar",
    "detectá": "detectar",
    "detectámo": "detectar",
    "detectámos": "detectar",
    "detectáramo": "detectar",
    "detectáramos": "detectar",
    "detectárei": "detectar",
    "detectáreis": "detectar",
    "detectásseis": "detectar",
    "detectássemos": "detectar",
    "detectávamo": "detectar",
    "detectávamos": "detectar",
    "detectávei": "detectar",
    "detectáveis": "detectável",
    "detecções": "detecção",
    "detemo": "deter",
    "detemos": "deter",
    "detende": "deter",
    "detendes": "deter",
    "detendo": "deter",
    "detenha": "deter",
    "detenhais": "deter",
    "detenham": "deter",
    "detenhamo": "deter",
    "detenhamos": "deter",
    "detenhas": "deter",
    "detenho": "deter",
    "detentea": "detente",
    "detenteas": "detente",
    "detentees": "detente",
    "detentora": "detentor",
    "detentoras": "detentor",
    "detentores": "detentor",
    "detenças": "detença",
    "detenções": "detenção",
    "deterde": "deter",
    "deterdes": "deter",
    "detere": "deter",
    "deterei": "deter",
    "detereis": "deter",
    "deterem": "deter",
    "deteremos": "deter",
    "deteres": "deter",
    "deterge": "detergir",
    "detergem": "detergir",
    "detergentes": "detergente",
    "deterges": "detergir",
    "detergi": "detergir",
    "detergia": "detergir",
    "detergiam": "detergir",
    "detergias": "detergir",
    "detergida": "detergir",
    "detergidas": "detergir",
    "detergido": "detergir",
    "detergidos": "detergir",
    "detergimo": "detergir",
    "detergimos": "detergir",
    "detergindo": "detergir",
    "detergira": "detergir",
    "detergiram": "detergir",
    "detergiras": "detergir",
    "detergirde": "detergir",
    "detergirdes": "detergir",
    "detergire": "detergir",
    "detergirei": "detergir",
    "detergireis": "detergir",
    "detergirem": "detergir",
    "detergiremos": "detergir",
    "detergires": "detergir",
    "detergiria": "detergir",
    "detergiriam": "detergir",
    "detergirias": "detergir",
    "detergirmo": "detergir",
    "detergirmos": "detergir",
    "detergirá": "detergir",
    "detergirás": "detergir",
    "detergirão": "detergir",
    "detergiríamos": "detergir",
    "detergiríeis": "detergir",
    "detergis": "detergir",
    "detergisse": "detergir",
    "detergissem": "detergir",
    "detergisses": "detergir",
    "detergiste": "detergir",
    "detergistes": "detergir",
    "detergiu": "detergir",
    "detergíamo": "detergir",
    "detergíamos": "detergir",
    "detergíei": "detergir",
    "detergíeis": "detergir",
    "detergíramo": "detergir",
    "detergíramos": "detergir",
    "detergírei": "detergir",
    "detergíreis": "detergir",
    "detergísseis": "detergir",
    "detergíssemos": "detergir",
    "deteria": "deter",
    "deteriam": "deter",
    "deterias": "deter",
    "deteriora": "deteriorar",
    "deteriorada": "deteriorar",
    "deterioradas": "deteriorar",
    "deteriorado": "deteriorar",
    "deteriorados": "deteriorar",
    "deteriorai": "deteriorar",
    "deteriorais": "deteriorar",
    "deterioram": "deteriorar",
    "deterioramentos": "deterioramento",
    "deterioramo": "deteriorar",
    "deterioramos": "deteriorar",
    "deteriorando": "deteriorar",
    "deteriorantes": "deteriorante",
    "deteriorara": "deteriorar",
    "deterioraram": "deteriorar",
    "deterioraras": "deteriorar",
    "deteriorarde": "deteriorar",
    "deteriorardes": "deteriorar",
    "deteriorare": "deteriorar",
    "deteriorarei": "deteriorar",
    "deteriorareis": "deteriorar",
    "deteriorarem": "deteriorar",
    "deterioraremos": "deteriorar",
    "deteriorares": "deteriorar",
    "deterioraria": "deteriorar",
    "deteriorariam": "deteriorar",
    "deteriorarias": "deteriorar",
    "deteriorarmo": "deteriorar",
    "deteriorarmos": "deteriorar",
    "deteriorará": "deteriorar",
    "deteriorarás": "deteriorar",
    "deteriorarão": "deteriorar",
    "deterioraríamos": "deteriorar",
    "deterioraríeis": "deteriorar",
    "deterioras": "deteriorar",
    "deteriorasse": "deteriorar",
    "deteriorassem": "deteriorar",
    "deteriorasses": "deteriorar",
    "deterioraste": "deteriorar",
    "deteriorastes": "deteriorar",
    "deteriorava": "deteriorar",
    "deterioravam": "deteriorar",
    "deterioravas": "deteriorar",
    "deteriorações": "deterioração",
    "deteriore": "deteriorar",
    "deteriorei": "deteriorar",
    "deterioreis": "deteriorar",
    "deteriorem": "deteriorar",
    "deterioremo": "deteriorar",
    "deterioremos": "deteriorar",
    "deteriores": "deteriorar",
    "deterioro": "deteriorar",
    "deteriorou": "deteriorar",
    "deteriorá": "deteriorar",
    "deteriorámo": "deteriorar",
    "deteriorámos": "deteriorar",
    "deterioráramo": "deteriorar",
    "deterioráramos": "deteriorar",
    "deteriorárei": "deteriorar",
    "deterioráreis": "deteriorar",
    "deteriorásseis": "deteriorar",
    "deteriorássemos": "deteriorar",
    "deteriorávamo": "deteriorar",
    "deteriorávamos": "deteriorar",
    "deteriorávei": "deteriorar",
    "deterioráveis": "deteriorável",
    "determina": "determinar",
    "determinada": "determinar",
    "determinadas": "determinar",
    "determinado": "determinar",
    "determinadora": "determinador",
    "determinadoras": "determinador",
    "determinadores": "determinador",
    "determinados": "determinar",
    "determinadíssima": "determinado",
    "determinadíssimas": "determinado",
    "determinadíssimo": "determinado",
    "determinadíssimos": "determinado",
    "determinai": "determinar",
    "determinais": "determinar",
    "determinam": "determinar",
    "determinamo": "determinar",
    "determinamos": "determinar",
    "determinando": "determinar",
    "determinantes": "determinante",
    "determinara": "determinar",
    "determinaram": "determinar",
    "determinaras": "determinar",
    "determinarde": "determinar",
    "determinardes": "determinar",
    "determinare": "determinar",
    "determinarei": "determinar",
    "determinareis": "determinar",
    "determinarem": "determinar",
    "determinaremos": "determinar",
    "determinares": "determinar",
    "determinaria": "determinar",
    "determinariam": "determinar",
    "determinarias": "determinar",
    "determinarmo": "determinar",
    "determinarmos": "determinar",
    "determinará": "determinar",
    "determinarás": "determinar",
    "determinarão": "determinar",
    "determinaríamos": "determinar",
    "determinaríeis": "determinar",
    "determinas": "determinar",
    "determinasse": "determinar",
    "determinassem": "determinar",
    "determinasses": "determinar",
    "determinaste": "determinar",
    "determinastes": "determinar",
    "determinativa": "determinativo",
    "determinativas": "determinativo",
    "determinativos": "determinativo",
    "determinava": "determinar",
    "determinavam": "determinar",
    "determinavas": "determinar",
    "determinações": "determinação",
    "determine": "determinar",
    "determinei": "determinar",
    "determineis": "determinar",
    "determinem": "determinar",
    "determinemo": "determinar",
    "determinemos": "determinar",
    "determines": "determinar",
    "determinismos": "determinismo",
    "deterministas": "determinista",
    "determino": "determinar",
    "determinou": "determinar",
    "determiná": "determinar",
    "determinámo": "determinar",
    "determinámos": "determinar",
    "determináramo": "determinar",
    "determináramos": "determinar",
    "determinárei": "determinar",
    "determináreis": "determinar",
    "determinásseis": "determinar",
    "determinássemos": "determinar",
    "determinávamo": "determinar",
    "determinávamos": "determinar",
    "determinávei": "determinar",
    "determináveis": "determinável",
    "determinística": "determinístico",
    "determinísticas": "determinístico",
    "determinísticos": "determinístico",
    "determo": "deter",
    "determos": "deter",
    "detersiva": "detersivo",
    "detersivas": "detersivo",
    "detersivos": "detersivo",
    "detersória": "detersório",
    "detersórias": "detersório",
    "detersórios": "detersório",
    "detersões": "detersão",
    "deterá": "deter",
    "deterás": "deter",
    "deterão": "deter",
    "deteríamos": "deter",
    "deteríeis": "deter",
    "detesta": "detestar",
    "detestada": "detestar",
    "detestadas": "detestar",
    "detestado": "detestar",
    "detestados": "detestar",
    "detestadíssima": "detestado",
    "detestadíssimas": "detestado",
    "detestadíssimo": "detestado",
    "detestadíssimos": "detestado",
    "detestai": "detestar",
    "detestais": "detestar",
    "detestam": "detestar",
    "detestamo": "detestar",
    "detestamos": "detestar",
    "detestanda": "detestando",
    "detestandas": "detestando",
    "detestando": "detestar",
    "detestandos": "detestando",
    "detestara": "detestar",
    "detestaram": "detestar",
    "detestaras": "detestar",
    "detestarde": "detestar",
    "detestardes": "detestar",
    "detestare": "detestar",
    "detestarei": "detestar",
    "detestareis": "detestar",
    "detestarem": "detestar",
    "detestaremos": "detestar",
    "detestares": "detestar",
    "detestaria": "detestar",
    "detestariam": "detestar",
    "detestarias": "detestar",
    "detestarmo": "detestar",
    "detestarmos": "detestar",
    "detestará": "detestar",
    "detestarás": "detestar",
    "detestarão": "detestar",
    "detestaríamos": "detestar",
    "detestaríeis": "detestar",
    "detestas": "detestar",
    "detestasse": "detestar",
    "detestassem": "detestar",
    "detestasses": "detestar",
    "detestaste": "detestar",
    "detestastes": "detestar",
    "detestava": "detestar",
    "detestavam": "detestar",
    "detestavas": "detestar",
    "detestações": "detestação",
    "deteste": "detestar",
    "detestei": "detestar",
    "detesteis": "detestar",
    "detestem": "detestar",
    "detestemo": "detestar",
    "detestemos": "detestar",
    "detestes": "detestar",
    "detesto": "detestar",
    "detestou": "detestar",
    "detestá": "detestar",
    "detestámo": "detestar",
    "detestámos": "detestar",
    "detestáramo": "detestar",
    "detestáramos": "detestar",
    "detestárei": "detestar",
    "detestáreis": "detestar",
    "detestásseis": "detestar",
    "detestássemos": "detestar",
    "detestávamo": "detestar",
    "detestávamos": "detestar",
    "detestávei": "detestar",
    "detestáveis": "detestável",
    "deteve": "deter",
    "detida": "detido",
    "detidas": "detido",
    "detido": "deter",
    "detidos": "detido",
    "detinha": "deter",
    "detinham": "deter",
    "detinhas": "deter",
    "detiora": "detiorar",
    "detiorada": "detiorar",
    "detioradas": "detiorar",
    "detiorado": "detiorar",
    "detiorados": "detiorar",
    "detiorai": "detiorar",
    "detiorais": "detiorar",
    "detioram": "detiorar",
    "detioramo": "detiorar",
    "detioramos": "detiorar",
    "detiorando": "detiorar",
    "detiorara": "detiorar",
    "detioraram": "detiorar",
    "detioraras": "detiorar",
    "detiorarde": "detiorar",
    "detiorardes": "detiorar",
    "detiorare": "detiorar",
    "detiorarei": "detiorar",
    "detiorareis": "detiorar",
    "detiorarem": "detiorar",
    "detioraremos": "detiorar",
    "detiorares": "detiorar",
    "detioraria": "detiorar",
    "detiorariam": "detiorar",
    "detiorarias": "detiorar",
    "detiorarmo": "detiorar",
    "detiorarmos": "detiorar",
    "detiorará": "detiorar",
    "detiorarás": "detiorar",
    "detiorarão": "detiorar",
    "detioraríamos": "detiorar",
    "detioraríeis": "detiorar",
    "detioras": "detiorar",
    "detiorasse": "detiorar",
    "detiorassem": "detiorar",
    "detiorasses": "detiorar",
    "detioraste": "detiorar",
    "detiorastes": "detiorar",
    "detiorava": "detiorar",
    "detioravam": "detiorar",
    "detioravas": "detiorar",
    "detiore": "detiorar",
    "detiorei": "detiorar",
    "detioreis": "detiorar",
    "detiorem": "detiorar",
    "detioremo": "detiorar",
    "detioremos": "detiorar",
    "detiores": "detiorar",
    "detioro": "detiorar",
    "detiorou": "detiorar",
    "detiorá": "detiorar",
    "detiorámo": "detiorar",
    "detiorámos": "detiorar",
    "detioráramo": "detiorar",
    "detioráramos": "detiorar",
    "detiorárei": "detiorar",
    "detioráreis": "detiorar",
    "detiorásseis": "detiorar",
    "detiorássemos": "detiorar",
    "detiorávamo": "detiorar",
    "detiorávamos": "detiorar",
    "detiorávei": "detiorar",
    "detioráveis": "detiorar",
    "detirja": "detergir",
    "detirjais": "detergir",
    "detirjam": "detergir",
    "detirjamo": "detergir",
    "detirjamos": "detergir",
    "detirjas": "detergir",
    "detirjo": "detergir",
    "detive": "deter",
    "detivemo": "deter",
    "detivemos": "deter",
    "detiver": "deter",
    "detivera": "deter",
    "detiveram": "deter",
    "detiveras": "deter",
    "detiverdes": "deter",
    "detiverem": "deter",
    "detiveres": "deter",
    "detivermos": "deter",
    "detivesse": "deter",
    "detivessem": "deter",
    "detivesses": "deter",
    "detiveste": "deter",
    "detivestes": "deter",
    "detivéramo": "deter",
    "detivéramos": "deter",
    "detivérei": "deter",
    "detivéreis": "deter",
    "detivésseis": "deter",
    "detivéssemos": "deter",
    "detona": "detonar",
    "detonada": "detonar",
    "detonadas": "detonar",
    "detonado": "detonar",
    "detonadora": "detonador",
    "detonadoras": "detonador",
    "detonadores": "detonador",
    "detonados": "detonar",
    "detonai": "detonar",
    "detonais": "detonar",
    "detonam": "detonar",
    "detonamo": "detonar",
    "detonamos": "detonar",
    "detonando": "detonar",
    "detonantes": "detonante",
    "detonara": "detonar",
    "detonaram": "detonar",
    "detonaras": "detonar",
    "detonarde": "detonar",
    "detonardes": "detonar",
    "detonare": "detonar",
    "detonarei": "detonar",
    "detonareis": "detonar",
    "detonarem": "detonar",
    "detonaremos": "detonar",
    "detonares": "detonar",
    "detonaria": "detonar",
    "detonariam": "detonar",
    "detonarias": "detonar",
    "detonarmo": "detonar",
    "detonarmos": "detonar",
    "detonará": "detonar",
    "detonarás": "detonar",
    "detonarão": "detonar",
    "detonaríamos": "detonar",
    "detonaríeis": "detonar",
    "detonas": "detonar",
    "detonasse": "detonar",
    "detonassem": "detonar",
    "detonasses": "detonar",
    "detonaste": "detonar",
    "detonastes": "detonar",
    "detonava": "detonar",
    "detonavam": "detonar",
    "detonavas": "detonar",
    "detonações": "detonação",
    "detone": "detonar",
    "detonei": "detonar",
    "detoneis": "detonar",
    "detonem": "detonar",
    "detonemo": "detonar",
    "detonemos": "detonar",
    "detones": "detonar",
    "detono": "detonar",
    "detonou": "detonar",
    "detoná": "detonar",
    "detonámo": "detonar",
    "detonámos": "detonar",
    "detonáramo": "detonar",
    "detonáramos": "detonar",
    "detonárei": "detonar",
    "detonáreis": "detonar",
    "detonásseis": "detonar",
    "detonássemos": "detonar",
    "detonávamo": "detonar",
    "detonávamos": "detonar",
    "detonávei": "detonar",
    "detonáveis": "detonar",
    "detractiva": "detractivo",
    "detractivas": "detractivo",
    "detractivos": "detractivo",
    "detractora": "detractor",
    "detractoras": "detractor",
    "detractores": "detractor",
    "detracções": "detracção",
    "detraem": "detrair",
    "detraentes": "detraente",
    "detrai": "detrair",
    "detraia": "detrair",
    "detraiais": "detrair",
    "detraiam": "detrair",
    "detraiamo": "detrair",
    "detraiamos": "detrair",
    "detraias": "detrair",
    "detraida": "detraido",
    "detraidas": "detraido",
    "detraidora": "detraidor",
    "detraidoras": "detraidor",
    "detraidores": "detraidor",
    "detraidos": "detraido",
    "detraindo": "detrair",
    "detraio": "detrair",
    "detrairde": "detrair",
    "detrairdes": "detrair",
    "detrairei": "detrair",
    "detraireis": "detrair",
    "detrairemos": "detrair",
    "detrairia": "detrair",
    "detrairiam": "detrair",
    "detrairias": "detrair",
    "detrairmo": "detrair",
    "detrairmos": "detrair",
    "detrairá": "detrair",
    "detrairás": "detrair",
    "detrairão": "detrair",
    "detrairíamos": "detrair",
    "detrairíeis": "detrair",
    "detrais": "detrair",
    "detraiu": "detrair",
    "detraí": "detrair",
    "detraía": "detrair",
    "detraíam": "detrair",
    "detraíamo": "detrair",
    "detraíamos": "detrair",
    "detraías": "detrair",
    "detraída": "detrair",
    "detraídas": "detrair",
    "detraído": "detrair",
    "detraídos": "detrair",
    "detraíei": "detrair",
    "detraíeis": "detrair",
    "detraímo": "detrair",
    "detraímos": "detrair",
    "detraíra": "detrair",
    "detraíram": "detrair",
    "detraíramo": "detrair",
    "detraíramos": "detrair",
    "detraíras": "detrair",
    "detraíre": "detrair",
    "detraírei": "detrair",
    "detraíreis": "detrair",
    "detraírem": "detrair",
    "detraíres": "detrair",
    "detraís": "detrair",
    "detraísse": "detrair",
    "detraísseis": "detrair",
    "detraíssem": "detrair",
    "detraíssemos": "detrair",
    "detraísses": "detrair",
    "detraíste": "detrair",
    "detraístes": "detrair",
    "detrimentos": "detrimento",
    "detritica": "detritico",
    "detriticas": "detritico",
    "detriticos": "detritico",
    "detritos": "detrito",
    "detrições": "detrição",
    "detumescentes": "detumescente",
    "detumescências": "detumescência",
    "deturba": "deturbar",
    "deturbada": "deturbar",
    "deturbadas": "deturbar",
    "deturbado": "deturbar",
    "deturbados": "deturbar",
    "deturbai": "deturbar",
    "deturbais": "deturbar",
    "deturbam": "deturbar",
    "deturbamo": "deturbar",
    "deturbamos": "deturbar",
    "deturbando": "deturbar",
    "deturbara": "deturbar",
    "deturbaram": "deturbar",
    "deturbaras": "deturbar",
    "deturbarde": "deturbar",
    "deturbardes": "deturbar",
    "deturbare": "deturbar",
    "deturbarei": "deturbar",
    "deturbareis": "deturbar",
    "deturbarem": "deturbar",
    "deturbaremos": "deturbar",
    "deturbares": "deturbar",
    "deturbaria": "deturbar",
    "deturbariam": "deturbar",
    "deturbarias": "deturbar",
    "deturbarmo": "deturbar",
    "deturbarmos": "deturbar",
    "deturbará": "deturbar",
    "deturbarás": "deturbar",
    "deturbarão": "deturbar",
    "deturbaríamos": "deturbar",
    "deturbaríeis": "deturbar",
    "deturbas": "deturbar",
    "deturbasse": "deturbar",
    "deturbassem": "deturbar",
    "deturbasses": "deturbar",
    "deturbaste": "deturbar",
    "deturbastes": "deturbar",
    "deturbava": "deturbar",
    "deturbavam": "deturbar",
    "deturbavas": "deturbar",
    "deturbações": "deturbação",
    "deturbe": "deturbar",
    "deturbei": "deturbar",
    "deturbeis": "deturbar",
    "deturbem": "deturbar",
    "deturbemo": "deturbar",
    "deturbemos": "deturbar",
    "deturbes": "deturbar",
    "deturbo": "deturbar",
    "deturbou": "deturbar",
    "deturbá": "deturbar",
    "deturbámo": "deturbar",
    "deturbámos": "deturbar",
    "deturbáramo": "deturbar",
    "deturbáramos": "deturbar",
    "deturbárei": "deturbar",
    "deturbáreis": "deturbar",
    "deturbásseis": "deturbar",
    "deturbássemos": "deturbar",
    "deturbávamo": "deturbar",
    "deturbávamos": "deturbar",
    "deturbávei": "deturbar",
    "deturbáveis": "deturbar",
    "deturpa": "deturpar",
    "deturpada": "deturpar",
    "deturpadas": "deturpar",
    "deturpado": "deturpar",
    "deturpadora": "deturpador",
    "deturpadoras": "deturpador",
    "deturpadores": "deturpador",
    "deturpados": "deturpar",
    "deturpai": "deturpar",
    "deturpais": "deturpar",
    "deturpam": "deturpar",
    "deturpamo": "deturpar",
    "deturpamos": "deturpar",
    "deturpando": "deturpar",
    "deturpara": "deturpar",
    "deturparam": "deturpar",
    "deturparas": "deturpar",
    "deturparde": "deturpar",
    "deturpardes": "deturpar",
    "deturpare": "deturpar",
    "deturparei": "deturpar",
    "deturpareis": "deturpar",
    "deturparem": "deturpar",
    "deturparemos": "deturpar",
    "deturpares": "deturpar",
    "deturparia": "deturpar",
    "deturpariam": "deturpar",
    "deturparias": "deturpar",
    "deturparmo": "deturpar",
    "deturparmos": "deturpar",
    "deturpará": "deturpar",
    "deturparás": "deturpar",
    "deturparão": "deturpar",
    "deturparíamos": "deturpar",
    "deturparíeis": "deturpar",
    "deturpas": "deturpar",
    "deturpasse": "deturpar",
    "deturpassem": "deturpar",
    "deturpasses": "deturpar",
    "deturpaste": "deturpar",
    "deturpastes": "deturpar",
    "deturpava": "deturpar",
    "deturpavam": "deturpar",
    "deturpavas": "deturpar",
    "deturpações": "deturpação",
    "deturpe": "deturpar",
    "deturpei": "deturpar",
    "deturpeis": "deturpar",
    "deturpem": "deturpar",
    "deturpemo": "deturpar",
    "deturpemos": "deturpar",
    "deturpes": "deturpar",
    "deturpo": "deturpar",
    "deturpou": "deturpar",
    "deturpá": "deturpar",
    "deturpámo": "deturpar",
    "deturpámos": "deturpar",
    "deturpáramo": "deturpar",
    "deturpáramos": "deturpar",
    "deturpárei": "deturpar",
    "deturpáreis": "deturpar",
    "deturpásseis": "deturpar",
    "deturpássemos": "deturpar",
    "deturpávamo": "deturpar",
    "deturpávamos": "deturpar",
    "deturpávei": "deturpar",
    "deturpáveis": "deturpável",
    "detém": "deter",
    "deténs": "deter",
    "detê": "deter",
    "detêm": "deter",
    "detínhamo": "deter",
    "detínhamos": "deter",
    "detínhei": "deter",
    "detínheis": "deter",
    "deu": "dar",
    "deucaliana": "deucaliano",
    "deucalianas": "deucaliano",
    "deucalianos": "deucaliano",
    "deunida": "deunido",
    "deunidas": "deunido",
    "deunidos": "deunido",
    "deusa": "deus",
    "deusas": "deus",
    "deuses": "deus",
    "deutergias": "deutergia",
    "deuterogamias": "deuterogamia",
    "deuterologias": "deuterologia",
    "deuteronómios": "deuteronómio",
    "deuteropirâmides": "deuteropirâmide",
    "deuteroprismas": "deuteroprisma",
    "deuteroscopias": "deuteroscopia",
    "deuteroses": "deuterose",
    "deuterógamos": "deuterógamo",
    "deuterões": "deuterão",
    "deutolécitos": "deutolécito",
    "deutoplasmas": "deutoplasma",
    "deutérica": "deutérico",
    "deutéricas": "deutérico",
    "deutéricos": "deutérico",
    "deutérios": "deutério",
    "deva": "dever",
    "devagarinho": "devagar",
    "devagarito": "devagar",
    "devagaríssimo": "devagar",
    "devais": "dever",
    "devam": "dever",
    "devamo": "dever",
    "devamos": "dever",
    "devaneada": "devanear",
    "devaneadas": "devanear",
    "devaneado": "devanear",
    "devaneadora": "devaneador",
    "devaneadoras": "devaneador",
    "devaneadores": "devaneador",
    "devaneados": "devanear",
    "devaneai": "devanear",
    "devaneais": "devanear",
    "devaneamo": "devanear",
    "devaneamos": "devanear",
    "devaneando": "devanear",
    "devaneara": "devanear",
    "devanearam": "devanear",
    "devanearas": "devanear",
    "devaneardes": "devanear",
    "devanearei": "devanear",
    "devaneareis": "devanear",
    "devanearem": "devanear",
    "devanearemos": "devanear",
    "devaneares": "devanear",
    "devanearia": "devanear",
    "devaneariam": "devanear",
    "devanearias": "devanear",
    "devanearmo": "devanear",
    "devanearmos": "devanear",
    "devaneará": "devanear",
    "devanearás": "devanear",
    "devanearão": "devanear",
    "devanearíamos": "devanear",
    "devanearíeis": "devanear",
    "devaneasse": "devanear",
    "devaneassem": "devanear",
    "devaneasses": "devanear",
    "devaneaste": "devanear",
    "devaneastes": "devanear",
    "devaneava": "devanear",
    "devaneavam": "devanear",
    "devaneavas": "devanear",
    "devaneações": "devaneação",
    "devaneei": "devanear",
    "devaneeis": "devanear",
    "devaneemo": "devanear",
    "devaneemos": "devanear",
    "devaneia": "devanear",
    "devaneiam": "devanear",
    "devaneias": "devanear",
    "devaneie": "devanear",
    "devaneiem": "devanear",
    "devaneies": "devanear",
    "devaneio": "devanear",
    "devaneios": "devaneio",
    "devaneou": "devanear",
    "devaneámo": "devanear",
    "devaneámos": "devanear",
    "devaneáramo": "devanear",
    "devaneáramos": "devanear",
    "devaneáreis": "devanear",
    "devaneásseis": "devanear",
    "devaneássemos": "devanear",
    "devaneávamo": "devanear",
    "devaneávamos": "devanear",
    "devaneáveis": "devanear",
    "devas": "dever",
    "devassa": "devasso",
    "devassada": "devassar",
    "devassadas": "devassar",
    "devassado": "devassar",
    "devassadora": "devassador",
    "devassadoras": "devassador",
    "devassadores": "devassador",
    "devassados": "devassar",
    "devassai": "devassar",
    "devassais": "devassar",
    "devassam": "devassar",
    "devassamentos": "devassamento",
    "devassamo": "devassar",
    "devassamos": "devassar",
    "devassando": "devassar",
    "devassara": "devassar",
    "devassaram": "devassar",
    "devassaras": "devassar",
    "devassarde": "devassar",
    "devassardes": "devassar",
    "devassare": "devassar",
    "devassarei": "devassar",
    "devassareis": "devassar",
    "devassarem": "devassar",
    "devassaremos": "devassar",
    "devassares": "devassar",
    "devassaria": "devassar",
    "devassariam": "devassar",
    "devassarias": "devassar",
    "devassarmo": "devassar",
    "devassarmos": "devassar",
    "devassará": "devassar",
    "devassarás": "devassar",
    "devassarão": "devassar",
    "devassaríamos": "devassar",
    "devassaríeis": "devassar",
    "devassas": "devasso",
    "devassasse": "devassar",
    "devassassem": "devassar",
    "devassasses": "devassar",
    "devassaste": "devassar",
    "devassastes": "devassar",
    "devassava": "devassar",
    "devassavam": "devassar",
    "devassavas": "devassar",
    "devasse": "devassar",
    "devassei": "devassar",
    "devasseis": "devassar",
    "devassem": "devassar",
    "devassemo": "devassar",
    "devassemos": "devassar",
    "devasses": "devassar",
    "devassidões": "devassidão",
    "devasso": "devassar",
    "devassos": "devasso",
    "devassou": "devassar",
    "devassá": "devassar",
    "devassámo": "devassar",
    "devassámos": "devassar",
    "devassáramo": "devassar",
    "devassáramos": "devassar",
    "devassárei": "devassar",
    "devassáreis": "devassar",
    "devassásseis": "devassar",
    "devassássemos": "devassar",
    "devassávamo": "devassar",
    "devassávamos": "devassar",
    "devassávei": "devassar",
    "devassáveis": "devassável",
    "devasta": "devastar",
    "devastada": "devastar",
    "devastadas": "devastar",
    "devastado": "devastar",
    "devastadora": "devastador",
    "devastadoras": "devastador",
    "devastadores": "devastador",
    "devastados": "devastar",
    "devastai": "devastar",
    "devastais": "devastar",
    "devastam": "devastar",
    "devastamo": "devastar",
    "devastamos": "devastar",
    "devastando": "devastar",
    "devastara": "devastar",
    "devastaram": "devastar",
    "devastaras": "devastar",
    "devastarde": "devastar",
    "devastardes": "devastar",
    "devastare": "devastar",
    "devastarei": "devastar",
    "devastareis": "devastar",
    "devastarem": "devastar",
    "devastaremos": "devastar",
    "devastares": "devastar",
    "devastaria": "devastar",
    "devastariam": "devastar",
    "devastarias": "devastar",
    "devastarmo": "devastar",
    "devastarmos": "devastar",
    "devastará": "devastar",
    "devastarás": "devastar",
    "devastarão": "devastar",
    "devastaríamos": "devastar",
    "devastaríeis": "devastar",
    "devastas": "devastar",
    "devastasse": "devastar",
    "devastassem": "devastar",
    "devastasses": "devastar",
    "devastaste": "devastar",
    "devastastes": "devastar",
    "devastava": "devastar",
    "devastavam": "devastar",
    "devastavas": "devastar",
    "devastações": "devastação",
    "devaste": "devastar",
    "devastei": "devastar",
    "devasteis": "devastar",
    "devastem": "devastar",
    "devastemo": "devastar",
    "devastemos": "devastar",
    "devastes": "devastar",
    "devasto": "devastar",
    "devastou": "devastar",
    "devastá": "devastar",
    "devastámo": "devastar",
    "devastámos": "devastar",
    "devastáramo": "devastar",
    "devastáramos": "devastar",
    "devastárei": "devastar",
    "devastáreis": "devastar",
    "devastásseis": "devastar",
    "devastássemos": "devastar",
    "devastávamo": "devastar",
    "devastávamos": "devastar",
    "devastávei": "devastar",
    "devastáveis": "devastar",
    "deve": "dever",
    "devedora": "devedor",
    "devedoras": "devedor",
    "devedores": "devedor",
    "devei": "dever",
    "deveio": "devir",
    "deveis": "dever",
    "devem": "devir",
    "devemo": "dever",
    "devemos": "dever",
    "devendo": "dever",
    "devenha": "devir",
    "devenhais": "devir",
    "devenham": "devir",
    "devenhamo": "devir",
    "devenhamos": "devir",
    "devenhas": "devir",
    "devenho": "devir",
    "deventra": "deventrar",
    "deventrada": "deventrar",
    "deventradas": "deventrar",
    "deventrado": "deventrar",
    "deventrados": "deventrar",
    "deventrai": "deventrar",
    "deventrais": "deventrar",
    "deventram": "deventrar",
    "deventramo": "deventrar",
    "deventramos": "deventrar",
    "deventrando": "deventrar",
    "deventrara": "deventrar",
    "deventraram": "deventrar",
    "deventraras": "deventrar",
    "deventrarde": "deventrar",
    "deventrardes": "deventrar",
    "deventrare": "deventrar",
    "deventrarei": "deventrar",
    "deventrareis": "deventrar",
    "deventrarem": "deventrar",
    "deventraremos": "deventrar",
    "deventrares": "deventrar",
    "deventraria": "deventrar",
    "deventrariam": "deventrar",
    "deventrarias": "deventrar",
    "deventrarmo": "deventrar",
    "deventrarmos": "deventrar",
    "deventrará": "deventrar",
    "deventrarás": "deventrar",
    "deventrarão": "deventrar",
    "deventraríamos": "deventrar",
    "deventraríeis": "deventrar",
    "deventras": "deventrar",
    "deventrasse": "deventrar",
    "deventrassem": "deventrar",
    "deventrasses": "deventrar",
    "deventraste": "deventrar",
    "deventrastes": "deventrar",
    "deventrava": "deventrar",
    "deventravam": "deventrar",
    "deventravas": "deventrar",
    "deventre": "deventrar",
    "deventrei": "deventrar",
    "deventreis": "deventrar",
    "deventrem": "deventrar",
    "deventremo": "deventrar",
    "deventremos": "deventrar",
    "deventres": "deventre",
    "deventro": "deventrar",
    "deventrou": "deventrar",
    "deventrá": "deventrar",
    "deventrámo": "deventrar",
    "deventrámos": "deventrar",
    "deventráramo": "deventrar",
    "deventráramos": "deventrar",
    "deventrárei": "deventrar",
    "deventráreis": "deventrar",
    "deventrásseis": "deventrar",
    "deventrássemos": "deventrar",
    "deventrávamo": "deventrar",
    "deventrávamos": "deventrar",
    "deventrávei": "deventrar",
    "deventráveis": "deventrar",
    "devera": "dever",
    "deveram": "dever",
    "deveras": "dever",
    "deverbais": "deverbal",
    "deverde": "dever",
    "deverdes": "dever",
    "devere": "dever",
    "deverei": "dever",
    "devereis": "dever",
    "deverem": "dever",
    "deveremos": "dever",
    "deveres": "dever",
    "deveria": "dever",
    "deveriam": "dever",
    "deverias": "dever",
    "devermo": "dever",
    "devermos": "dever",
    "deverá": "dever",
    "deverás": "dever",
    "deverão": "dever",
    "deveríamos": "dever",
    "deveríeis": "dever",
    "deves": "dever",
    "devesas": "devesa",
    "devesse": "dever",
    "devessem": "dever",
    "devesses": "dever",
    "deveste": "dever",
    "devestes": "dever",
    "deveu": "dever",
    "devi": "dever",
    "devia": "dever",
    "deviam": "dever",
    "devias": "dever",
    "deviações": "deviação",
    "devida": "devido",
    "devidas": "devido",
    "devido": "dever",
    "devidos": "devido",
    "deviemo": "devir",
    "deviemos": "devir",
    "devier": "devir",
    "deviera": "devir",
    "devieram": "devir",
    "devieras": "devir",
    "devierdes": "devir",
    "devierem": "devir",
    "devieres": "devir",
    "deviermos": "devir",
    "deviesse": "devir",
    "deviessem": "devir",
    "deviesses": "devir",
    "devieste": "devir",
    "deviestes": "devir",
    "devim": "devir",
    "devimo": "devir",
    "devimos": "devir",
    "devinda": "devir",
    "devindas": "devir",
    "devinde": "devir",
    "devindes": "devir",
    "devindo": "devir",
    "devindos": "devir",
    "devinha": "devir",
    "devinham": "devir",
    "devinhas": "devir",
    "devirdes": "devir",
    "devirei": "devir",
    "devireis": "devir",
    "devirem": "devir",
    "deviremos": "devir",
    "devires": "devir",
    "deviria": "devir",
    "deviriam": "devir",
    "devirias": "devir",
    "devirmo": "devir",
    "devirmos": "devir",
    "devirá": "devir",
    "devirás": "devir",
    "devirão": "devir",
    "deviríamos": "devir",
    "deviríeis": "devir",
    "devitrifica": "devitrificar",
    "devitrificada": "devitrificar",
    "devitrificadas": "devitrificar",
    "devitrificado": "devitrificar",
    "devitrificados": "devitrificar",
    "devitrificai": "devitrificar",
    "devitrificais": "devitrificar",
    "devitrificam": "devitrificar",
    "devitrificamo": "devitrificar",
    "devitrificamos": "devitrificar",
    "devitrificando": "devitrificar",
    "devitrificara": "devitrificar",
    "devitrificaram": "devitrificar",
    "devitrificaras": "devitrificar",
    "devitrificarde": "devitrificar",
    "devitrificardes": "devitrificar",
    "devitrificare": "devitrificar",
    "devitrificarei": "devitrificar",
    "devitrificareis": "devitrificar",
    "devitrificarem": "devitrificar",
    "devitrificaremos": "devitrificar",
    "devitrificares": "devitrificar",
    "devitrificaria": "devitrificar",
    "devitrificariam": "devitrificar",
    "devitrificarias": "devitrificar",
    "devitrificarmo": "devitrificar",
    "devitrificarmos": "devitrificar",
    "devitrificará": "devitrificar",
    "devitrificarás": "devitrificar",
    "devitrificarão": "devitrificar",
    "devitrificaríamos": "devitrificar",
    "devitrificaríeis": "devitrificar",
    "devitrificas": "devitrificar",
    "devitrificasse": "devitrificar",
    "devitrificassem": "devitrificar",
    "devitrificasses": "devitrificar",
    "devitrificaste": "devitrificar",
    "devitrificastes": "devitrificar",
    "devitrificava": "devitrificar",
    "devitrificavam": "devitrificar",
    "devitrificavas": "devitrificar",
    "devitrificações": "devitrificação",
    "devitrifico": "devitrificar",
    "devitrificou": "devitrificar",
    "devitrificá": "devitrificar",
    "devitrificámo": "devitrificar",
    "devitrificámos": "devitrificar",
    "devitrificáramo": "devitrificar",
    "devitrificáramos": "devitrificar",
    "devitrificárei": "devitrificar",
    "devitrificáreis": "devitrificar",
    "devitrificásseis": "devitrificar",
    "devitrificássemos": "devitrificar",
    "devitrificávamo": "devitrificar",
    "devitrificávamos": "devitrificar",
    "devitrificávei": "devitrificar",
    "devitrificáveis": "devitrificar",
    "devitrifique": "devitrificar",
    "devitrifiquei": "devitrificar",
    "devitrifiqueis": "devitrificar",
    "devitrifiquem": "devitrificar",
    "devitrifiquemo": "devitrificar",
    "devitrifiquemos": "devitrificar",
    "devitrifiques": "devitrificar",
    "deviéramo": "devir",
    "deviéramos": "devir",
    "deviéreis": "devir",
    "deviésseis": "devir",
    "deviéssemos": "devir",
    "devo": "dever",
    "devocioneira": "devocioneiro",
    "devocioneiras": "devocioneiro",
    "devocioneiros": "devocioneiro",
    "devocionismos": "devocionismo",
    "devocionistas": "devocionista",
    "devocionários": "devocionário",
    "devoluta": "devoluto",
    "devolutas": "devoluto",
    "devolutiva": "devolutivo",
    "devolutivas": "devolutivo",
    "devolutivos": "devolutivo",
    "devolutos": "devoluto",
    "devolutória": "devolutório",
    "devolutórias": "devolutório",
    "devolutórios": "devolutório",
    "devoluções": "devolução",
    "devolva": "devolver",
    "devolvais": "devolver",
    "devolvam": "devolver",
    "devolvamo": "devolver",
    "devolvamos": "devolver",
    "devolvas": "devolver",
    "devolve": "devolver",
    "devolvei": "devolver",
    "devolveis": "devolver",
    "devolvem": "devolver",
    "devolvemo": "devolver",
    "devolvemos": "devolver",
    "devolvendo": "devolver",
    "devolvera": "devolver",
    "devolveram": "devolver",
    "devolveras": "devolver",
    "devolverdes": "devolver",
    "devolverei": "devolver",
    "devolvereis": "devolver",
    "devolverem": "devolver",
    "devolveremos": "devolver",
    "devolveres": "devolver",
    "devolveria": "devolver",
    "devolveriam": "devolver",
    "devolverias": "devolver",
    "devolvermo": "devolver",
    "devolvermos": "devolver",
    "devolverá": "devolver",
    "devolverás": "devolver",
    "devolverão": "devolver",
    "devolveríamos": "devolver",
    "devolveríeis": "devolver",
    "devolves": "devolver",
    "devolvesse": "devolver",
    "devolvessem": "devolver",
    "devolvesses": "devolver",
    "devolveste": "devolver",
    "devolvestes": "devolver",
    "devolveu": "devolver",
    "devolvi": "devolver",
    "devolvia": "devolver",
    "devolviam": "devolver",
    "devolvias": "devolver",
    "devolvida": "devolvido",
    "devolvidas": "devolvido",
    "devolvido": "devolver",
    "devolvidos": "devolvido",
    "devolvo": "devolver",
    "devolvêramo": "devolver",
    "devolvêramos": "devolver",
    "devolvêreis": "devolver",
    "devolvêsseis": "devolver",
    "devolvêssemos": "devolver",
    "devolvíamo": "devolver",
    "devolvíamos": "devolver",
    "devolvíeis": "devolver",
    "devoniana": "devoniano",
    "devonianas": "devoniano",
    "devonianos": "devoniano",
    "devora": "devorar",
    "devorada": "devorar",
    "devoradas": "devorar",
    "devorado": "devorar",
    "devoradora": "devorador",
    "devoradoras": "devorador",
    "devoradores": "devorador",
    "devorados": "devorar",
    "devorai": "devorar",
    "devorais": "devorar",
    "devoram": "devorar",
    "devoramo": "devorar",
    "devoramos": "devorar",
    "devorando": "devorar",
    "devorantes": "devorante",
    "devorara": "devorar",
    "devoraram": "devorar",
    "devoraras": "devorar",
    "devorarde": "devorar",
    "devorardes": "devorar",
    "devorare": "devorar",
    "devorarei": "devorar",
    "devorareis": "devorar",
    "devorarem": "devorar",
    "devoraremos": "devorar",
    "devorares": "devorar",
    "devoraria": "devorar",
    "devorariam": "devorar",
    "devorarias": "devorar",
    "devorarmo": "devorar",
    "devorarmos": "devorar",
    "devorará": "devorar",
    "devorarás": "devorar",
    "devorarão": "devorar",
    "devoraríamos": "devorar",
    "devoraríeis": "devorar",
    "devoras": "devorar",
    "devorasse": "devorar",
    "devorassem": "devorar",
    "devorasses": "devorar",
    "devoraste": "devorar",
    "devorastes": "devorar",
    "devorava": "devorar",
    "devoravam": "devorar",
    "devoravas": "devorar",
    "devorações": "devoração",
    "devore": "devorar",
    "devorei": "devorar",
    "devoreis": "devorar",
    "devorem": "devorar",
    "devoremo": "devorar",
    "devoremos": "devorar",
    "devores": "devorar",
    "devorismos": "devorismo",
    "devoristas": "devorista",
    "devoro": "devorar",
    "devorou": "devorar",
    "devorá": "devorar",
    "devorámo": "devorar",
    "devorámos": "devorar",
    "devoráramo": "devorar",
    "devoráramos": "devorar",
    "devorárei": "devorar",
    "devoráreis": "devorar",
    "devorásseis": "devorar",
    "devorássemos": "devorar",
    "devorávamo": "devorar",
    "devorávamos": "devorar",
    "devorávei": "devorar",
    "devoráveis": "devorar",
    "devota": "devoto",
    "devotada": "devotar",
    "devotadas": "devotar",
    "devotado": "devotar",
    "devotados": "devotar",
    "devotai": "devotar",
    "devotais": "devotar",
    "devotam": "devotar",
    "devotamentos": "devotamento",
    "devotamo": "devotar",
    "devotamos": "devotar",
    "devotando": "devotar",
    "devotara": "devotar",
    "devotaram": "devotar",
    "devotaras": "devotar",
    "devotarde": "devotar",
    "devotardes": "devotar",
    "devotare": "devotar",
    "devotarei": "devotar",
    "devotareis": "devotar",
    "devotarem": "devotar",
    "devotaremos": "devotar",
    "devotares": "devotar",
    "devotaria": "devotar",
    "devotariam": "devotar",
    "devotarias": "devotar",
    "devotarmo": "devotar",
    "devotarmos": "devotar",
    "devotará": "devotar",
    "devotarás": "devotar",
    "devotarão": "devotar",
    "devotaríamos": "devotar",
    "devotaríeis": "devotar",
    "devotas": "devoto",
    "devotasse": "devotar",
    "devotassem": "devotar",
    "devotasses": "devotar",
    "devotaste": "devotar",
    "devotastes": "devotar",
    "devotava": "devotar",
    "devotavam": "devotar",
    "devotavas": "devotar",
    "devotações": "devotação",
    "devote": "devotar",
    "devotei": "devotar",
    "devoteis": "devotar",
    "devotem": "devotar",
    "devotemo": "devotar",
    "devotemos": "devotar",
    "devotes": "devotar",
    "devoto": "devotar",
    "devotos": "devoto",
    "devotou": "devotar",
    "devotá": "devotar",
    "devotámo": "devotar",
    "devotámos": "devotar",
    "devotáramo": "devotar",
    "devotáramos": "devotar",
    "devotárei": "devotar",
    "devotáreis": "devotar",
    "devotásseis": "devotar",
    "devotássemos": "devotar",
    "devotávamo": "devotar",
    "devotávamos": "devotar",
    "devotávei": "devotar",
    "devotáveis": "devotar",
    "devoções": "devoção",
    "devém": "devir",
    "devéns": "devir",
    "devê": "dever",
    "devêm": "devir",
    "devêramo": "dever",
    "devêramos": "dever",
    "devêrei": "dever",
    "devêreis": "dever",
    "devêsseis": "dever",
    "devêssemos": "dever",
    "devíamo": "dever",
    "devíamos": "dever",
    "devíei": "dever",
    "devíeis": "dever",
    "devínhamo": "devir",
    "devínhamos": "devir",
    "devínheis": "devir",
    "devónica": "devónico",
    "devónicas": "devónico",
    "devónicos": "devónico",
    "dexteridades": "dexteridade",
    "dextra": "dextro",
    "dextralidades": "dextralidade",
    "dextras": "dextro",
    "dextrações": "dextração",
    "dextrinas": "dextrina",
    "dextrivolúveis": "dextrivolúvel",
    "dextrocardias": "dextrocardia",
    "dextrocardíaca": "dextrocardíaco",
    "dextrocardíacas": "dextrocardíaco",
    "dextrocardíacos": "dextrocardíaco",
    "dextrogira": "dextrogiro",
    "dextrogiras": "dextrogiro",
    "dextrogiros": "dextrogiro",
    "dextrorsa": "dextrorso",
    "dextrorsas": "dextrorso",
    "dextrorsos": "dextrorso",
    "dextros": "dextro",
    "dextroses": "dextrose",
    "dextrossinistra": "dextrossinistro",
    "dextrossinistras": "dextrossinistro",
    "dextrossinistros": "dextrossinistro",
    "dextrosurias": "dextrosuria",
    "dextrosúrias": "dextrosúria",
    "dextrímana": "dextrímano",
    "dextrímanas": "dextrímano",
    "dextrímanos": "dextrímano",
    "dezembradas": "dezembrada",
    "dezembrina": "dezembrino",
    "dezembrinas": "dezembrino",
    "dezembrinos": "dezembrino",
    "dezembrismos": "dezembrismo",
    "dezenas": "dezena",
    "deã": "deão",
    "deãos": "deão",
    "deãs": "deão",
    "deículas": "deícula",
    "deífica": "deífico",
    "deíficas": "deífico",
    "deíficos": "deífico",
    "deíparas": "deípara",
    "deísmos": "deísmo",
    "deístas": "deísta",
    "diabas": "diaba",
    "diabelhas": "diabelha",
    "diabetes": "diabete",
    "diabinho": "diabo",
    "diabinhos": "diabo",
    "diabito": "diabo",
    "diabitos": "diabo",
    "diabolismos": "diabolismo",
    "diabos": "diabo",
    "diabretes": "diabrete",
    "diabriis": "diabril",
    "diabrina": "diabrino",
    "diabrinas": "diabrino",
    "diabrinos": "diabrino",
    "diabruras": "diabrura",
    "diabásios": "diabásio",
    "diabética": "diabético",
    "diabéticas": "diabético",
    "diabéticos": "diabético",
    "diabólica": "diabólico",
    "diabólicas": "diabólico",
    "diabólicos": "diabólico",
    "diacetinas": "diacetina",
    "diachos": "diacho",
    "diacidrões": "diacidrão",
    "diacomáticas": "diacomática",
    "diaconados": "diaconado",
    "diaconais": "diaconal",
    "diaconatos": "diaconato",
    "diaconias": "diaconia",
    "diaconisas": "diaconisa",
    "diacritismos": "diacritismo",
    "diacronias": "diacronia",
    "diacronismos": "diacronismo",
    "diacrítica": "diacrítico",
    "diacríticas": "diacrítico",
    "diacríticos": "diacrítico",
    "diacrónica": "diacrónico",
    "diacrónicas": "diacrónico",
    "diacrónicos": "diacrónico",
    "diacética": "diacético",
    "diacéticas": "diacético",
    "diacéticos": "diacético",
    "diacústica": "diacústico",
    "diacústicas": "diacústico",
    "diacústicos": "diacústico",
    "diadelfa": "diadelfo",
    "diadelfas": "diadelfo",
    "diadelfias": "diadelfia",
    "diadelfos": "diadelfo",
    "diadema": "diademar",
    "diademada": "diademar",
    "diademadas": "diademar",
    "diademado": "diademar",
    "diademados": "diademar",
    "diademai": "diademar",
    "diademais": "diademar",
    "diademam": "diademar",
    "diademamo": "diademar",
    "diademamos": "diademar",
    "diademando": "diademar",
    "diademara": "diademar",
    "diademaram": "diademar",
    "diademaras": "diademar",
    "diademarde": "diademar",
    "diademardes": "diademar",
    "diademare": "diademar",
    "diademarei": "diademar",
    "diademareis": "diademar",
    "diademarem": "diademar",
    "diademaremos": "diademar",
    "diademares": "diademar",
    "diademaria": "diademar",
    "diademariam": "diademar",
    "diademarias": "diademar",
    "diademarmo": "diademar",
    "diademarmos": "diademar",
    "diademará": "diademar",
    "diademarás": "diademar",
    "diademarão": "diademar",
    "diademaríamos": "diademar",
    "diademaríeis": "diademar",
    "diademas": "diademar",
    "diademasse": "diademar",
    "diademassem": "diademar",
    "diademasses": "diademar",
    "diademaste": "diademar",
    "diademastes": "diademar",
    "diademava": "diademar",
    "diademavam": "diademar",
    "diademavas": "diademar",
    "diademe": "diademar",
    "diademei": "diademar",
    "diademeis": "diademar",
    "diademem": "diademar",
    "diadememo": "diademar",
    "diadememos": "diademar",
    "diademes": "diademar",
    "diademo": "diademar",
    "diademou": "diademar",
    "diademá": "diademar",
    "diademámo": "diademar",
    "diademámos": "diademar",
    "diademáramo": "diademar",
    "diademáramos": "diademar",
    "diademárei": "diademar",
    "diademáreis": "diademar",
    "diademásseis": "diademar",
    "diademássemos": "diademar",
    "diademávamo": "diademar",
    "diademávamos": "diademar",
    "diademávei": "diademar",
    "diademáveis": "diademar",
    "diadexias": "diadexia",
    "diadra": "diadro",
    "diadras": "diadro",
    "diadros": "diadro",
    "diafaneidades": "diafaneidade",
    "diafaniza": "diafanizar",
    "diafanizada": "diafanizar",
    "diafanizadas": "diafanizar",
    "diafanizado": "diafanizar",
    "diafanizados": "diafanizar",
    "diafanizai": "diafanizar",
    "diafanizais": "diafanizar",
    "diafanizam": "diafanizar",
    "diafanizamo": "diafanizar",
    "diafanizamos": "diafanizar",
    "diafanizando": "diafanizar",
    "diafanizara": "diafanizar",
    "diafanizaram": "diafanizar",
    "diafanizaras": "diafanizar",
    "diafanizarde": "diafanizar",
    "diafanizardes": "diafanizar",
    "diafanizare": "diafanizar",
    "diafanizarei": "diafanizar",
    "diafanizareis": "diafanizar",
    "diafanizarem": "diafanizar",
    "diafanizaremos": "diafanizar",
    "diafanizares": "diafanizar",
    "diafanizaria": "diafanizar",
    "diafanizariam": "diafanizar",
    "diafanizarias": "diafanizar",
    "diafanizarmo": "diafanizar",
    "diafanizarmos": "diafanizar",
    "diafanizará": "diafanizar",
    "diafanizarás": "diafanizar",
    "diafanizarão": "diafanizar",
    "diafanizaríamos": "diafanizar",
    "diafanizaríeis": "diafanizar",
    "diafanizas": "diafanizar",
    "diafanizasse": "diafanizar",
    "diafanizassem": "diafanizar",
    "diafanizasses": "diafanizar",
    "diafanizaste": "diafanizar",
    "diafanizastes": "diafanizar",
    "diafanizava": "diafanizar",
    "diafanizavam": "diafanizar",
    "diafanizavas": "diafanizar",
    "diafanizações": "diafanização",
    "diafanize": "diafanizar",
    "diafanizei": "diafanizar",
    "diafanizeis": "diafanizar",
    "diafanizem": "diafanizar",
    "diafanizemo": "diafanizar",
    "diafanizemos": "diafanizar",
    "diafanizes": "diafanizar",
    "diafanizo": "diafanizar",
    "diafanizou": "diafanizar",
    "diafanizá": "diafanizar",
    "diafanizámo": "diafanizar",
    "diafanizámos": "diafanizar",
    "diafanizáramo": "diafanizar",
    "diafanizáramos": "diafanizar",
    "diafanizárei": "diafanizar",
    "diafanizáreis": "diafanizar",
    "diafanizásseis": "diafanizar",
    "diafanizássemos": "diafanizar",
    "diafanizávamo": "diafanizar",
    "diafanizávamos": "diafanizar",
    "diafanizávei": "diafanizar",
    "diafanizáveis": "diafanizar",
    "diafanometrias": "diafanometria",
    "diafanoscopias": "diafanoscopia",
    "diafanoscópios": "diafanoscópio",
    "diafanógena": "diafanógeno",
    "diafanógenas": "diafanógeno",
    "diafanógenos": "diafanógeno",
    "diafanómetros": "diafanómetro",
    "diafas": "diafa",
    "diafonias": "diafonia",
    "diaforeses": "diaforese",
    "diaforética": "diaforético",
    "diaforéticas": "diaforético",
    "diaforéticos": "diaforético",
    "diafragma": "diafragmar",
    "diafragmada": "diafragmar",
    "diafragmadas": "diafragmar",
    "diafragmado": "diafragmar",
    "diafragmados": "diafragmar",
    "diafragmai": "diafragmar",
    "diafragmais": "diafragmar",
    "diafragmam": "diafragmar",
    "diafragmamo": "diafragmar",
    "diafragmamos": "diafragmar",
    "diafragmando": "diafragmar",
    "diafragmara": "diafragmar",
    "diafragmaram": "diafragmar",
    "diafragmaras": "diafragmar",
    "diafragmarde": "diafragmar",
    "diafragmardes": "diafragmar",
    "diafragmare": "diafragmar",
    "diafragmarei": "diafragmar",
    "diafragmareis": "diafragmar",
    "diafragmarem": "diafragmar",
    "diafragmaremos": "diafragmar",
    "diafragmares": "diafragmar",
    "diafragmaria": "diafragmar",
    "diafragmariam": "diafragmar",
    "diafragmarias": "diafragmar",
    "diafragmarmo": "diafragmar",
    "diafragmarmos": "diafragmar",
    "diafragmará": "diafragmar",
    "diafragmarás": "diafragmar",
    "diafragmarão": "diafragmar",
    "diafragmaríamos": "diafragmar",
    "diafragmaríeis": "diafragmar",
    "diafragmas": "diafragmar",
    "diafragmasse": "diafragmar",
    "diafragmassem": "diafragmar",
    "diafragmasses": "diafragmar",
    "diafragmaste": "diafragmar",
    "diafragmastes": "diafragmar",
    "diafragmava": "diafragmar",
    "diafragmavam": "diafragmar",
    "diafragmavas": "diafragmar",
    "diafragme": "diafragmar",
    "diafragmei": "diafragmar",
    "diafragmeis": "diafragmar",
    "diafragmem": "diafragmar",
    "diafragmemo": "diafragmar",
    "diafragmemos": "diafragmar",
    "diafragmes": "diafragmar",
    "diafragmites": "diafragmite",
    "diafragmo": "diafragmar",
    "diafragmou": "diafragmar",
    "diafragmá": "diafragmar",
    "diafragmámo": "diafragmar",
    "diafragmámos": "diafragmar",
    "diafragmáramo": "diafragmar",
    "diafragmáramos": "diafragmar",
    "diafragmárei": "diafragmar",
    "diafragmáreis": "diafragmar",
    "diafragmásseis": "diafragmar",
    "diafragmássemos": "diafragmar",
    "diafragmática": "diafragmático",
    "diafragmáticas": "diafragmático",
    "diafragmáticos": "diafragmático",
    "diafragmávamo": "diafragmar",
    "diafragmávamos": "diafragmar",
    "diafragmávei": "diafragmar",
    "diafragmáveis": "diafragmar",
    "diagais": "diagal",
    "diagnoses": "diagnose",
    "diagnostica": "diagnosticar",
    "diagnosticada": "diagnosticar",
    "diagnosticadas": "diagnosticar",
    "diagnosticado": "diagnosticar",
    "diagnosticados": "diagnosticar",
    "diagnosticai": "diagnosticar",
    "diagnosticais": "diagnosticar",
    "diagnosticam": "diagnosticar",
    "diagnosticamo": "diagnosticar",
    "diagnosticamos": "diagnosticar",
    "diagnosticando": "diagnosticar",
    "diagnosticara": "diagnosticar",
    "diagnosticaram": "diagnosticar",
    "diagnosticaras": "diagnosticar",
    "diagnosticarde": "diagnosticar",
    "diagnosticardes": "diagnosticar",
    "diagnosticare": "diagnosticar",
    "diagnosticarei": "diagnosticar",
    "diagnosticareis": "diagnosticar",
    "diagnosticarem": "diagnosticar",
    "diagnosticaremos": "diagnosticar",
    "diagnosticares": "diagnosticar",
    "diagnosticaria": "diagnosticar",
    "diagnosticariam": "diagnosticar",
    "diagnosticarias": "diagnosticar",
    "diagnosticarmo": "diagnosticar",
    "diagnosticarmos": "diagnosticar",
    "diagnosticará": "diagnosticar",
    "diagnosticarás": "diagnosticar",
    "diagnosticarão": "diagnosticar",
    "diagnosticaríamos": "diagnosticar",
    "diagnosticaríeis": "diagnosticar",
    "diagnosticas": "diagnosticar",
    "diagnosticasse": "diagnosticar",
    "diagnosticassem": "diagnosticar",
    "diagnosticasses": "diagnosticar",
    "diagnosticaste": "diagnosticar",
    "diagnosticastes": "diagnosticar",
    "diagnosticava": "diagnosticar",
    "diagnosticavam": "diagnosticar",
    "diagnosticavas": "diagnosticar",
    "diagnostico": "diagnosticar",
    "diagnosticou": "diagnosticar",
    "diagnosticá": "diagnosticar",
    "diagnosticámo": "diagnosticar",
    "diagnosticámos": "diagnosticar",
    "diagnosticáramo": "diagnosticar",
    "diagnosticáramos": "diagnosticar",
    "diagnosticárei": "diagnosticar",
    "diagnosticáreis": "diagnosticar",
    "diagnosticásseis": "diagnosticar",
    "diagnosticássemos": "diagnosticar",
    "diagnosticávamo": "diagnosticar",
    "diagnosticávamos": "diagnosticar",
    "diagnosticávei": "diagnosticar",
    "diagnosticáveis": "diagnosticável",
    "diagnostique": "diagnosticar",
    "diagnostiquei": "diagnosticar",
    "diagnostiqueis": "diagnosticar",
    "diagnostiquem": "diagnosticar",
    "diagnostiquemo": "diagnosticar",
    "diagnostiquemos": "diagnosticar",
    "diagnostiques": "diagnosticar",
    "diagnósticos": "diagnóstico",
    "diagonais": "diagonal",
    "diagrafias": "diagrafia",
    "diagramas": "diagrama",
    "diagéneses": "diagénese",
    "diais": "dial",
    "dialectais": "dialectal",
    "dialectologias": "dialectologia",
    "dialectologistas": "dialectologista",
    "dialectológica": "dialectológico",
    "dialectológicas": "dialectológico",
    "dialectológicos": "dialectológico",
    "dialectos": "dialecto",
    "dialectóloga": "dialectólogo",
    "dialectólogas": "dialectólogo",
    "dialectólogos": "dialectólogo",
    "dialelos": "dialelo",
    "dialhos": "dialho",
    "dialipétala": "dialipétalo",
    "dialipétalas": "dialipétalo",
    "dialipétalos": "dialipétalo",
    "dialisa": "dialisar",
    "dialisada": "dialisar",
    "dialisadas": "dialisar",
    "dialisado": "dialisar",
    "dialisadores": "dialisador",
    "dialisados": "dialisar",
    "dialisai": "dialisar",
    "dialisais": "dialisar",
    "dialisam": "dialisar",
    "dialisamo": "dialisar",
    "dialisamos": "dialisar",
    "dialisando": "dialisar",
    "dialisara": "dialisar",
    "dialisaram": "dialisar",
    "dialisaras": "dialisar",
    "dialisarde": "dialisar",
    "dialisardes": "dialisar",
    "dialisare": "dialisar",
    "dialisarei": "dialisar",
    "dialisareis": "dialisar",
    "dialisarem": "dialisar",
    "dialisaremos": "dialisar",
    "dialisares": "dialisar",
    "dialisaria": "dialisar",
    "dialisariam": "dialisar",
    "dialisarias": "dialisar",
    "dialisarmo": "dialisar",
    "dialisarmos": "dialisar",
    "dialisará": "dialisar",
    "dialisarás": "dialisar",
    "dialisarão": "dialisar",
    "dialisaríamos": "dialisar",
    "dialisaríeis": "dialisar",
    "dialisas": "dialisar",
    "dialisasse": "dialisar",
    "dialisassem": "dialisar",
    "dialisasses": "dialisar",
    "dialisaste": "dialisar",
    "dialisastes": "dialisar",
    "dialisava": "dialisar",
    "dialisavam": "dialisar",
    "dialisavas": "dialisar",
    "dialise": "dialisar",
    "dialisei": "dialisar",
    "dialiseis": "dialisar",
    "dialisem": "dialisar",
    "dialisemo": "dialisar",
    "dialisemos": "dialisar",
    "dialises": "dialisar",
    "dialiso": "dialisar",
    "dialisou": "dialisar",
    "dialissépala": "dialissépalo",
    "dialissépalas": "dialissépalo",
    "dialissépalos": "dialissépalo",
    "dialisá": "dialisar",
    "dialisámo": "dialisar",
    "dialisámos": "dialisar",
    "dialisáramo": "dialisar",
    "dialisáramos": "dialisar",
    "dialisárei": "dialisar",
    "dialisáreis": "dialisar",
    "dialisásseis": "dialisar",
    "dialisássemos": "dialisar",
    "dialisávamo": "dialisar",
    "dialisávamos": "dialisar",
    "dialisávei": "dialisar",
    "dialisáveis": "dialisar",
    "dialitépala": "dialitépalo",
    "dialitépalas": "dialitépalo",
    "dialitépalos": "dialitépalo",
    "dialoga": "dialogar",
    "dialogada": "dialogar",
    "dialogadas": "dialogar",
    "dialogado": "dialogar",
    "dialogadora": "dialogador",
    "dialogadoras": "dialogador",
    "dialogadores": "dialogador",
    "dialogados": "dialogar",
    "dialogai": "dialogar",
    "dialogais": "dialogar",
    "dialogam": "dialogar",
    "dialogamo": "dialogar",
    "dialogamos": "dialogar",
    "dialogando": "dialogar",
    "dialogantes": "dialogante",
    "dialogara": "dialogar",
    "dialogaram": "dialogar",
    "dialogaras": "dialogar",
    "dialogarde": "dialogar",
    "dialogardes": "dialogar",
    "dialogare": "dialogar",
    "dialogarei": "dialogar",
    "dialogareis": "dialogar",
    "dialogarem": "dialogar",
    "dialogaremos": "dialogar",
    "dialogares": "dialogar",
    "dialogaria": "dialogar",
    "dialogariam": "dialogar",
    "dialogarias": "dialogar",
    "dialogarmo": "dialogar",
    "dialogarmos": "dialogar",
    "dialogará": "dialogar",
    "dialogarás": "dialogar",
    "dialogarão": "dialogar",
    "dialogaríamos": "dialogar",
    "dialogaríeis": "dialogar",
    "dialogas": "dialogar",
    "dialogasse": "dialogar",
    "dialogassem": "dialogar",
    "dialogasses": "dialogar",
    "dialogaste": "dialogar",
    "dialogastes": "dialogar",
    "dialogava": "dialogar",
    "dialogavam": "dialogar",
    "dialogavas": "dialogar",
    "dialogações": "dialogação",
    "dialogias": "dialogia",
    "dialogismos": "dialogismo",
    "dialogistas": "dialogista",
    "dialogo": "dialogar",
    "dialogou": "dialogar",
    "dialogue": "dialogar",
    "dialoguei": "dialogar",
    "dialogueis": "dialogar",
    "dialoguem": "dialogar",
    "dialoguemo": "dialogar",
    "dialoguemos": "dialogar",
    "dialogues": "dialogar",
    "dialogá": "dialogar",
    "dialogámo": "dialogar",
    "dialogámos": "dialogar",
    "dialogáramo": "dialogar",
    "dialogáramos": "dialogar",
    "dialogárei": "dialogar",
    "dialogáreis": "dialogar",
    "dialogásseis": "dialogar",
    "dialogássemos": "dialogar",
    "dialogávamo": "dialogar",
    "dialogávamos": "dialogar",
    "dialogávei": "dialogar",
    "dialogáveis": "dialogar",
    "dialogística": "dialogístico",
    "dialogísticas": "dialogístico",
    "dialogísticos": "dialogístico",
    "dialéctica": "dialéctico",
    "dialécticas": "dialéctico",
    "dialécticos": "dialéctico",
    "dialógica": "dialógico",
    "dialógicas": "dialógico",
    "dialógicos": "dialógico",
    "diamagnetismos": "diamagnetismo",
    "diamagnética": "diamagnético",
    "diamagnéticas": "diamagnético",
    "diamagnéticos": "diamagnético",
    "diamantes": "diamante",
    "diamantina": "diamantino",
    "diamantinas": "diamantino",
    "diamantinos": "diamantino",
    "diamantistas": "diamantista",
    "diamantizada": "diamantizado",
    "diamantizadas": "diamantizado",
    "diamantizados": "diamantizado",
    "diamantífera": "diamantífero",
    "diamantíferas": "diamantífero",
    "diamantíferos": "diamantífero",
    "diamantóides": "diamantóide",
    "diambas": "diamba",
    "diametrais": "diametral",
    "diaminas": "diamina",
    "diaminúrias": "diaminúria",
    "dianas": "diana",
    "diandrias": "diandria",
    "dianhos": "dianho",
    "dianta": "dianto",
    "diantas": "dianto",
    "dianteira": "dianteiro",
    "dianteiras": "dianteiro",
    "dianteiros": "dianteiro",
    "diantos": "dianto",
    "diapasões": "diapasão",
    "diapedeses": "diapedese",
    "diapnóica": "diapnóico",
    "diapnóicas": "diapnóico",
    "diapnóicos": "diapnóico",
    "diaporamas": "diaporama",
    "diaporeses": "diaporese",
    "diapositivos": "diapositivo",
    "diaquilões": "diaquilão",
    "diaquénios": "diaquénio",
    "diarcas": "diarca",
    "diarismos": "diarismo",
    "diaristas": "diarista",
    "diarquias": "diarquia",
    "diarreias": "diarreia",
    "diarreica": "diarreico",
    "diarreicas": "diarreico",
    "diarreicos": "diarreico",
    "diartroses": "diartrose",
    "dias": "dia",
    "diaspros": "diaspro",
    "diaspórios": "diaspório",
    "diastemas": "diastema",
    "diastilos": "diastilo",
    "diastrofismos": "diastrofismo",
    "diastropias": "diastropia",
    "diatermias": "diatermia",
    "diatermâncias": "diatermância",
    "diatomitos": "diatomito",
    "diatomáceas": "diatomácea",
    "diatonismos": "diatonismo",
    "diatribes": "diatribe",
    "diatérmana": "diatérmano",
    "diatérmanas": "diatérmano",
    "diatérmanos": "diatérmano",
    "diatérmica": "diatérmico",
    "diatérmicas": "diatérmico",
    "diatérmicos": "diatérmico",
    "diatómica": "diatómico",
    "diatómicas": "diatómico",
    "diatómicos": "diatómico",
    "diatónica": "diatónico",
    "diatónicas": "diatónico",
    "diatónicos": "diatónico",
    "diazomas": "diazoma",
    "dibranquiada": "dibranquiado",
    "dibranquiadas": "dibranquiado",
    "dibranquiados": "dibranquiado",
    "dibranquiais": "dibranquial",
    "dibrânquios": "dibrânquio",
    "dicacidades": "dicacidade",
    "dicafalias": "dicafalia",
    "dicarpa": "dicarpo",
    "dicarpas": "dicarpo",
    "dicarpelares": "dicarpelar",
    "dicarpos": "dicarpo",
    "dicas": "dica",
    "dicastérios": "dicastério",
    "dicazes": "dicaz",
    "diceratídeos": "diceratídeo",
    "dichotes": "dichote",
    "dicionaristas": "dicionarista",
    "dicionariza": "dicionarizar",
    "dicionarizada": "dicionarizar",
    "dicionarizadas": "dicionarizar",
    "dicionarizado": "dicionarizar",
    "dicionarizados": "dicionarizar",
    "dicionarizai": "dicionarizar",
    "dicionarizais": "dicionarizar",
    "dicionarizam": "dicionarizar",
    "dicionarizamo": "dicionarizar",
    "dicionarizamos": "dicionarizar",
    "dicionarizando": "dicionarizar",
    "dicionarizara": "dicionarizar",
    "dicionarizaram": "dicionarizar",
    "dicionarizaras": "dicionarizar",
    "dicionarizarde": "dicionarizar",
    "dicionarizardes": "dicionarizar",
    "dicionarizare": "dicionarizar",
    "dicionarizarei": "dicionarizar",
    "dicionarizareis": "dicionarizar",
    "dicionarizarem": "dicionarizar",
    "dicionarizaremos": "dicionarizar",
    "dicionarizares": "dicionarizar",
    "dicionarizaria": "dicionarizar",
    "dicionarizariam": "dicionarizar",
    "dicionarizarias": "dicionarizar",
    "dicionarizarmo": "dicionarizar",
    "dicionarizarmos": "dicionarizar",
    "dicionarizará": "dicionarizar",
    "dicionarizarás": "dicionarizar",
    "dicionarizarão": "dicionarizar",
    "dicionarizaríamos": "dicionarizar",
    "dicionarizaríeis": "dicionarizar",
    "dicionarizas": "dicionarizar",
    "dicionarizasse": "dicionarizar",
    "dicionarizassem": "dicionarizar",
    "dicionarizasses": "dicionarizar",
    "dicionarizaste": "dicionarizar",
    "dicionarizastes": "dicionarizar",
    "dicionarizava": "dicionarizar",
    "dicionarizavam": "dicionarizar",
    "dicionarizavas": "dicionarizar",
    "dicionarizações": "dicionarização",
    "dicionarize": "dicionarizar",
    "dicionarizei": "dicionarizar",
    "dicionarizeis": "dicionarizar",
    "dicionarizem": "dicionarizar",
    "dicionarizemo": "dicionarizar",
    "dicionarizemos": "dicionarizar",
    "dicionarizes": "dicionarizar",
    "dicionarizo": "dicionarizar",
    "dicionarizou": "dicionarizar",
    "dicionarizá": "dicionarizar",
    "dicionarizámo": "dicionarizar",
    "dicionarizámos": "dicionarizar",
    "dicionarizáramo": "dicionarizar",
    "dicionarizáramos": "dicionarizar",
    "dicionarizárei": "dicionarizar",
    "dicionarizáreis": "dicionarizar",
    "dicionarizásseis": "dicionarizar",
    "dicionarizássemos": "dicionarizar",
    "dicionarizávamo": "dicionarizar",
    "dicionarizávamos": "dicionarizar",
    "dicionarizávei": "dicionarizar",
    "dicionarizáveis": "dicionarizável",
    "dicionários": "dicionário",
    "diclinais": "diclinal",
    "diclinismos": "diclinismo",
    "dicogamias": "dicogamia",
    "dicogâmica": "dicogâmico",
    "dicogâmicas": "dicogâmico",
    "dicogâmicos": "dicogâmico",
    "dicongos": "dicongo",
    "dicotiledónea": "dicotiledóneo",
    "dicotiledóneas": "dicotiledóneo",
    "dicotiledóneos": "dicotiledóneo",
    "dicotomias": "dicotomia",
    "dicotomismos": "dicotomismo",
    "dicotíleas": "dicotílea",
    "dicotómica": "dicotómico",
    "dicotómicas": "dicotómico",
    "dicotómicos": "dicotómico",
    "dicromatismos": "dicromatismo",
    "dicromática": "dicromático",
    "dicromáticas": "dicromático",
    "dicromáticos": "dicromático",
    "dicroísmos": "dicroísmo",
    "dicróica": "dicróico",
    "dicróicas": "dicróico",
    "dicróicos": "dicróico",
    "dictafones": "dictafone",
    "dicções": "dicção",
    "dicéfala": "dicéfalo",
    "dicéfalas": "dicéfalo",
    "dicéfalos": "dicéfalo",
    "dicélias": "dicélia",
    "dicórdios": "dicórdio",
    "dicótoma": "dicótomo",
    "dicótomas": "dicótomo",
    "dicótomos": "dicótomo",
    "didactas": "didacta",
    "didactismos": "didactismo",
    "didactologias": "didactologia",
    "didactológica": "didactológico",
    "didactológicas": "didactológico",
    "didactológicos": "didactológico",
    "didascálias": "didascália",
    "didascálica": "didascálico",
    "didascálicas": "didascálico",
    "didascálicos": "didascálico",
    "didelfa": "didelfo",
    "didelfas": "didelfo",
    "didelfidas": "didelfida",
    "didelfos": "didelfo",
    "didelfídeos": "didelfídeo",
    "didinâmica": "didinâmico",
    "didinâmicas": "didinâmico",
    "didinâmicos": "didinâmico",
    "didodecaedros": "didodecaedro",
    "didáctica": "didáctico",
    "didácticas": "didáctico",
    "didácticos": "didáctico",
    "didáctila": "didáctilo",
    "didáctilas": "didáctilo",
    "didáctilos": "didáctilo",
    "didélfida": "didélfido",
    "didélfidas": "didélfido",
    "didélfidos": "didélfido",
    "didímios": "didímio",
    "diedra": "diedro",
    "diedras": "diedro",
    "diedros": "diedro",
    "dieléctrica": "dieléctrico",
    "dieléctricas": "dieléctrico",
    "dieléctricos": "dieléctrico",
    "diencéfalos": "diencéfalo",
    "dienses": "diense",
    "dieseis": "diesel",
    "dietas": "dieta",
    "dietistas": "dietista",
    "dietoterapias": "dietoterapia",
    "dietética": "dietético",
    "dietéticas": "dietético",
    "dietéticos": "dietético",
    "difama": "difamar",
    "difamada": "difamar",
    "difamadas": "difamar",
    "difamado": "difamar",
    "difamadora": "difamador",
    "difamadoras": "difamador",
    "difamadores": "difamador",
    "difamados": "difamar",
    "difamadíssima": "difamado",
    "difamadíssimas": "difamado",
    "difamadíssimo": "difamado",
    "difamadíssimos": "difamado",
    "difamai": "difamar",
    "difamais": "difamar",
    "difamam": "difamar",
    "difamamo": "difamar",
    "difamamos": "difamar",
    "difamando": "difamar",
    "difamantes": "difamante",
    "difamara": "difamar",
    "difamaram": "difamar",
    "difamaras": "difamar",
    "difamarde": "difamar",
    "difamardes": "difamar",
    "difamare": "difamar",
    "difamarei": "difamar",
    "difamareis": "difamar",
    "difamarem": "difamar",
    "difamaremos": "difamar",
    "difamares": "difamar",
    "difamaria": "difamar",
    "difamariam": "difamar",
    "difamarias": "difamar",
    "difamarmo": "difamar",
    "difamarmos": "difamar",
    "difamará": "difamar",
    "difamarás": "difamar",
    "difamarão": "difamar",
    "difamaríamos": "difamar",
    "difamaríeis": "difamar",
    "difamas": "difamar",
    "difamasse": "difamar",
    "difamassem": "difamar",
    "difamasses": "difamar",
    "difamaste": "difamar",
    "difamastes": "difamar",
    "difamatória": "difamatório",
    "difamatórias": "difamatório",
    "difamatórios": "difamatório",
    "difamava": "difamar",
    "difamavam": "difamar",
    "difamavas": "difamar",
    "difamações": "difamação",
    "difame": "difamar",
    "difamei": "difamar",
    "difameis": "difamar",
    "difamem": "difamar",
    "difamemo": "difamar",
    "difamemos": "difamar",
    "difames": "difamar",
    "difamo": "difamar",
    "difamou": "difamar",
    "difamá": "difamar",
    "difamámo": "difamar",
    "difamámos": "difamar",
    "difamáramo": "difamar",
    "difamáramos": "difamar",
    "difamárei": "difamar",
    "difamáreis": "difamar",
    "difamásseis": "difamar",
    "difamássemos": "difamar",
    "difamávamo": "difamar",
    "difamávamos": "difamar",
    "difamávei": "difamar",
    "difamáveis": "difamável",
    "difarreações": "difarreação",
    "difere": "diferir",
    "diferem": "diferir",
    "diference": "diferençar",
    "diferencei": "diferençar",
    "diferenceis": "diferençar",
    "diferencem": "diferençar",
    "diferencemo": "diferençar",
    "diferencemos": "diferençar",
    "diferences": "diferençar",
    "diferencia": "diferenciar",
    "diferenciada": "diferenciar",
    "diferenciadas": "diferenciar",
    "diferenciado": "diferenciar",
    "diferenciadora": "diferenciador",
    "diferenciadoras": "diferenciador",
    "diferenciadores": "diferenciador",
    "diferenciados": "diferenciar",
    "diferenciai": "diferenciar",
    "diferenciais": "diferenciar",
    "diferenciam": "diferenciar",
    "diferenciamo": "diferenciar",
    "diferenciamos": "diferenciar",
    "diferenciando": "diferenciar",
    "diferenciara": "diferenciar",
    "diferenciaram": "diferenciar",
    "diferenciaras": "diferenciar",
    "diferenciarde": "diferenciar",
    "diferenciardes": "diferenciar",
    "diferenciare": "diferenciar",
    "diferenciarei": "diferenciar",
    "diferenciareis": "diferenciar",
    "diferenciarem": "diferenciar",
    "diferenciaremos": "diferenciar",
    "diferenciares": "diferenciar",
    "diferenciaria": "diferenciar",
    "diferenciariam": "diferenciar",
    "diferenciarias": "diferenciar",
    "diferenciarmo": "diferenciar",
    "diferenciarmos": "diferenciar",
    "diferenciará": "diferenciar",
    "diferenciarás": "diferenciar",
    "diferenciarão": "diferenciar",
    "diferenciaríamos": "diferenciar",
    "diferenciaríeis": "diferenciar",
    "diferencias": "diferenciar",
    "diferenciasse": "diferenciar",
    "diferenciassem": "diferenciar",
    "diferenciasses": "diferenciar",
    "diferenciaste": "diferenciar",
    "diferenciastes": "diferenciar",
    "diferenciava": "diferenciar",
    "diferenciavam": "diferenciar",
    "diferenciavas": "diferenciar",
    "diferenciações": "diferenciação",
    "diferencie": "diferenciar",
    "diferenciei": "diferenciar",
    "diferencieis": "diferenciar",
    "diferenciem": "diferenciar",
    "diferenciemo": "diferenciar",
    "diferenciemos": "diferenciar",
    "diferencies": "diferenciar",
    "diferencio": "diferenciar",
    "diferenciou": "diferenciar",
    "diferenciá": "diferenciar",
    "diferenciámo": "diferenciar",
    "diferenciámos": "diferenciar",
    "diferenciáramo": "diferenciar",
    "diferenciáramos": "diferenciar",
    "diferenciárei": "diferenciar",
    "diferenciáreis": "diferenciar",
    "diferenciásseis": "diferenciar",
    "diferenciássemos": "diferenciar",
    "diferenciávamo": "diferenciar",
    "diferenciávamos": "diferenciar",
    "diferenciávei": "diferenciar",
    "diferenciáveis": "diferenciável",
    "diferendos": "diferendo",
    "diferentes": "diferente",
    "diferença": "diferençar",
    "diferençada": "diferençar",
    "diferençadas": "diferençar",
    "diferençado": "diferençar",
    "diferençados": "diferençar",
    "diferençai": "diferençar",
    "diferençais": "diferençar",
    "diferençam": "diferençar",
    "diferençamo": "diferençar",
    "diferençamos": "diferençar",
    "diferençando": "diferençar",
    "diferençara": "diferençar",
    "diferençaram": "diferençar",
    "diferençaras": "diferençar",
    "diferençarde": "diferençar",
    "diferençardes": "diferençar",
    "diferençare": "diferençar",
    "diferençarei": "diferençar",
    "diferençareis": "diferençar",
    "diferençarem": "diferençar",
    "diferençaremos": "diferençar",
    "diferençares": "diferençar",
    "diferençaria": "diferençar",
    "diferençariam": "diferençar",
    "diferençarias": "diferençar",
    "diferençarmo": "diferençar",
    "diferençarmos": "diferençar",
    "diferençará": "diferençar",
    "diferençarás": "diferençar",
    "diferençarão": "diferençar",
    "diferençaríamos": "diferençar",
    "diferençaríeis": "diferençar",
    "diferenças": "diferençar",
    "diferençasse": "diferençar",
    "diferençassem": "diferençar",
    "diferençasses": "diferençar",
    "diferençaste": "diferençar",
    "diferençastes": "diferençar",
    "diferençava": "diferençar",
    "diferençavam": "diferençar",
    "diferençavas": "diferençar",
    "diferenço": "diferençar",
    "diferençou": "diferençar",
    "diferençá": "diferençar",
    "diferençámo": "diferençar",
    "diferençámos": "diferençar",
    "diferençáramo": "diferençar",
    "diferençáramos": "diferençar",
    "diferençárei": "diferençar",
    "diferençáreis": "diferençar",
    "diferençásseis": "diferençar",
    "diferençássemos": "diferençar",
    "diferençávamo": "diferençar",
    "diferençávamos": "diferençar",
    "diferençávei": "diferençar",
    "diferençáveis": "diferençável",
    "diferes": "diferir",
    "diferi": "diferir",
    "diferia": "diferir",
    "diferiam": "diferir",
    "diferias": "diferir",
    "diferida": "diferir",
    "diferidas": "diferir",
    "diferido": "diferir",
    "diferidos": "diferir",
    "diferimentos": "diferimento",
    "diferimo": "diferir",
    "diferimos": "diferir",
    "diferindo": "diferir",
    "diferira": "diferir",
    "diferiram": "diferir",
    "diferiras": "diferir",
    "diferirde": "diferir",
    "diferirdes": "diferir",
    "diferire": "diferir",
    "diferirei": "diferir",
    "diferireis": "diferir",
    "diferirem": "diferir",
    "diferiremos": "diferir",
    "diferires": "diferir",
    "diferiria": "diferir",
    "difeririam": "diferir",
    "diferirias": "diferir",
    "diferirmo": "diferir",
    "diferirmos": "diferir",
    "diferirá": "diferir",
    "diferirás": "diferir",
    "diferirão": "diferir",
    "diferiríamos": "diferir",
    "diferiríeis": "diferir",
    "diferis": "diferir",
    "diferisse": "diferir",
    "diferissem": "diferir",
    "diferisses": "diferir",
    "diferiste": "diferir",
    "diferistes": "diferir",
    "diferiu": "diferir",
    "diferíamo": "diferir",
    "diferíamos": "diferir",
    "diferíei": "diferir",
    "diferíeis": "diferir",
    "diferíramo": "diferir",
    "diferíramos": "diferir",
    "diferírei": "diferir",
    "diferíreis": "diferir",
    "diferísseis": "diferir",
    "diferíssemos": "diferir",
    "dificercas": "dificerca",
    "dificuldades": "dificuldade",
    "dificulta": "dificultar",
    "dificultada": "dificultar",
    "dificultadas": "dificultar",
    "dificultado": "dificultar",
    "dificultados": "dificultar",
    "dificultai": "dificultar",
    "dificultais": "dificultar",
    "dificultam": "dificultar",
    "dificultamo": "dificultar",
    "dificultamos": "dificultar",
    "dificultando": "dificultar",
    "dificultara": "dificultar",
    "dificultaram": "dificultar",
    "dificultaras": "dificultar",
    "dificultarde": "dificultar",
    "dificultardes": "dificultar",
    "dificultare": "dificultar",
    "dificultarei": "dificultar",
    "dificultareis": "dificultar",
    "dificultarem": "dificultar",
    "dificultaremos": "dificultar",
    "dificultares": "dificultar",
    "dificultaria": "dificultar",
    "dificultariam": "dificultar",
    "dificultarias": "dificultar",
    "dificultarmo": "dificultar",
    "dificultarmos": "dificultar",
    "dificultará": "dificultar",
    "dificultarás": "dificultar",
    "dificultarão": "dificultar",
    "dificultaríamos": "dificultar",
    "dificultaríeis": "dificultar",
    "dificultas": "dificultar",
    "dificultasse": "dificultar",
    "dificultassem": "dificultar",
    "dificultasses": "dificultar",
    "dificultaste": "dificultar",
    "dificultastes": "dificultar",
    "dificultava": "dificultar",
    "dificultavam": "dificultar",
    "dificultavas": "dificultar",
    "dificultações": "dificultação",
    "dificulte": "dificultar",
    "dificultei": "dificultar",
    "dificulteis": "dificultar",
    "dificultem": "dificultar",
    "dificultemo": "dificultar",
    "dificultemos": "dificultar",
    "dificultes": "dificultar",
    "dificulto": "dificultar",
    "dificultosa": "dificultoso",
    "dificultosas": "dificultoso",
    "dificultosos": "dificultoso",
    "dificultou": "dificultar",
    "dificultá": "dificultar",
    "dificultámo": "dificultar",
    "dificultámos": "dificultar",
    "dificultáramo": "dificultar",
    "dificultáramos": "dificultar",
    "dificultárei": "dificultar",
    "dificultáreis": "dificultar",
    "dificultásseis": "dificultar",
    "dificultássemos": "dificultar",
    "dificultávamo": "dificultar",
    "dificultávamos": "dificultar",
    "dificultávei": "dificultar",
    "dificultáveis": "dificultar",
    "dificílima": "difícil",
    "dificílimas": "difícil",
    "dificílimo": "difícil",
    "dificílimos": "difícil",
    "difiodontes": "difiodonte",
    "difira": "diferir",
    "difirais": "diferir",
    "difiram": "diferir",
    "difiramo": "diferir",
    "difiramos": "diferir",
    "difiras": "diferir",
    "difiro": "diferir",
    "difirências": "difirência",
    "diflua": "difluir",
    "difluais": "difluir",
    "difluam": "difluir",
    "difluamo": "difluir",
    "difluamos": "difluir",
    "difluas": "difluir",
    "difluem": "difluir",
    "difluentes": "difluente",
    "diflui": "difluir",
    "difluindo": "difluir",
    "difluirdes": "difluir",
    "difluirei": "difluir",
    "difluireis": "difluir",
    "difluiremos": "difluir",
    "difluiria": "difluir",
    "difluiriam": "difluir",
    "difluirias": "difluir",
    "difluirmo": "difluir",
    "difluirmos": "difluir",
    "difluirá": "difluir",
    "difluirás": "difluir",
    "difluirão": "difluir",
    "difluiríamos": "difluir",
    "difluiríeis": "difluir",
    "difluis": "difluir",
    "difluiu": "difluir",
    "difluo": "difluir",
    "difluências": "difluência",
    "difluí": "difluir",
    "difluía": "difluir",
    "difluíam": "difluir",
    "difluíamo": "difluir",
    "difluíamos": "difluir",
    "difluías": "difluir",
    "difluída": "difluir",
    "difluídas": "difluir",
    "difluído": "difluir",
    "difluídos": "difluir",
    "difluíeis": "difluir",
    "difluímo": "difluir",
    "difluímos": "difluir",
    "difluíra": "difluir",
    "difluíram": "difluir",
    "difluíramo": "difluir",
    "difluíramos": "difluir",
    "difluíras": "difluir",
    "difluíreis": "difluir",
    "difluírem": "difluir",
    "difluíres": "difluir",
    "difluís": "difluir",
    "difluísse": "difluir",
    "difluísseis": "difluir",
    "difluíssem": "difluir",
    "difluíssemos": "difluir",
    "difluísses": "difluir",
    "difluíste": "difluir",
    "difluístes": "difluir",
    "difonias": "difonia",
    "difracta": "difractar",
    "difractada": "difractar",
    "difractadas": "difractar",
    "difractado": "difractar",
    "difractados": "difractar",
    "difractai": "difractar",
    "difractais": "difractar",
    "difractam": "difractar",
    "difractamo": "difractar",
    "difractamos": "difractar",
    "difractando": "difractar",
    "difractara": "difractar",
    "difractaram": "difractar",
    "difractaras": "difractar",
    "difractarde": "difractar",
    "difractardes": "difractar",
    "difractare": "difractar",
    "difractarei": "difractar",
    "difractareis": "difractar",
    "difractarem": "difractar",
    "difractaremos": "difractar",
    "difractares": "difractar",
    "difractaria": "difractar",
    "difractariam": "difractar",
    "difractarias": "difractar",
    "difractarmo": "difractar",
    "difractarmos": "difractar",
    "difractará": "difractar",
    "difractarás": "difractar",
    "difractarão": "difractar",
    "difractaríamos": "difractar",
    "difractaríeis": "difractar",
    "difractas": "difractar",
    "difractasse": "difractar",
    "difractassem": "difractar",
    "difractasses": "difractar",
    "difractaste": "difractar",
    "difractastes": "difractar",
    "difractava": "difractar",
    "difractavam": "difractar",
    "difractavas": "difractar",
    "difracte": "difractar",
    "difractei": "difractar",
    "difracteis": "difractar",
    "difractem": "difractar",
    "difractemo": "difractar",
    "difractemos": "difractar",
    "difractes": "difractar",
    "difractiva": "difractivo",
    "difractivas": "difractivo",
    "difractivos": "difractivo",
    "difracto": "difractar",
    "difractou": "difractar",
    "difractá": "difractar",
    "difractámo": "difractar",
    "difractámos": "difractar",
    "difractáramo": "difractar",
    "difractáramos": "difractar",
    "difractárei": "difractar",
    "difractáreis": "difractar",
    "difractásseis": "difractar",
    "difractássemos": "difractar",
    "difractávamo": "difractar",
    "difractávamos": "difractar",
    "difractávei": "difractar",
    "difractáveis": "difractar",
    "difractómetros": "difractómetro",
    "difracções": "difracção",
    "difringentes": "difringente",
    "difterias": "difteria",
    "diftérica": "diftérico",
    "diftéricas": "diftérico",
    "diftéricos": "diftérico",
    "difunda": "difundir",
    "difundais": "difundir",
    "difundam": "difundir",
    "difundamo": "difundir",
    "difundamos": "difundir",
    "difundas": "difundir",
    "difunde": "difundir",
    "difundem": "difundir",
    "difundes": "difundir",
    "difundi": "difundir",
    "difundia": "difundir",
    "difundiam": "difundir",
    "difundias": "difundir",
    "difundida": "difundir",
    "difundidas": "difundir",
    "difundido": "difundir",
    "difundidos": "difundir",
    "difundimo": "difundir",
    "difundimos": "difundir",
    "difundindo": "difundir",
    "difundira": "difundir",
    "difundiram": "difundir",
    "difundiras": "difundir",
    "difundirde": "difundir",
    "difundirdes": "difundir",
    "difundire": "difundir",
    "difundirei": "difundir",
    "difundireis": "difundir",
    "difundirem": "difundir",
    "difundiremos": "difundir",
    "difundires": "difundir",
    "difundiria": "difundir",
    "difundiriam": "difundir",
    "difundirias": "difundir",
    "difundirmo": "difundir",
    "difundirmos": "difundir",
    "difundirá": "difundir",
    "difundirás": "difundir",
    "difundirão": "difundir",
    "difundiríamos": "difundir",
    "difundiríeis": "difundir",
    "difundis": "difundir",
    "difundisse": "difundir",
    "difundissem": "difundir",
    "difundisses": "difundir",
    "difundiste": "difundir",
    "difundistes": "difundir",
    "difundiu": "difundir",
    "difundo": "difundir",
    "difundíamo": "difundir",
    "difundíamos": "difundir",
    "difundíei": "difundir",
    "difundíeis": "difundir",
    "difundíramo": "difundir",
    "difundíramos": "difundir",
    "difundírei": "difundir",
    "difundíreis": "difundir",
    "difundísseis": "difundir",
    "difundíssemos": "difundir",
    "difundíveis": "difundível",
    "difusa": "difuso",
    "difusas": "difuso",
    "difusibilidades": "difusibilidade",
    "difusiva": "difusivo",
    "difusivas": "difusivo",
    "difusivos": "difusivo",
    "difusora": "difusor",
    "difusoras": "difusor",
    "difusores": "difusor",
    "difusos": "difuso",
    "difusíveis": "difusível",
    "difusões": "difusão",
    "difásica": "difásico",
    "difásicas": "difásico",
    "difásicos": "difásico",
    "difíceis": "difícil",
    "diga": "dizer",
    "digais": "dizer",
    "digam": "dizer",
    "digamias": "digamia",
    "digamo": "dizer",
    "digamos": "dizer",
    "digas": "dizer",
    "digenias": "digenia",
    "digenética": "digenético",
    "digenéticas": "digenético",
    "digenéticos": "digenético",
    "digere": "digerir",
    "digerem": "digerir",
    "digeres": "digerir",
    "digeri": "digerir",
    "digeria": "digerir",
    "digeriam": "digerir",
    "digerias": "digerir",
    "digerida": "digerir",
    "digeridas": "digerir",
    "digerido": "digerir",
    "digeridos": "digerir",
    "digerimo": "digerir",
    "digerimos": "digerir",
    "digerindo": "digerir",
    "digerira": "digerir",
    "digeriram": "digerir",
    "digeriras": "digerir",
    "digerirde": "digerir",
    "digerirdes": "digerir",
    "digerire": "digerir",
    "digerirei": "digerir",
    "digerireis": "digerir",
    "digerirem": "digerir",
    "digeriremos": "digerir",
    "digerires": "digerir",
    "digeriria": "digerir",
    "digeririam": "digerir",
    "digeririas": "digerir",
    "digerirmo": "digerir",
    "digerirmos": "digerir",
    "digerirá": "digerir",
    "digerirás": "digerir",
    "digerirão": "digerir",
    "digeriríamos": "digerir",
    "digeriríeis": "digerir",
    "digeris": "digerir",
    "digerisse": "digerir",
    "digerissem": "digerir",
    "digerisses": "digerir",
    "digeriste": "digerir",
    "digeristes": "digerir",
    "digeriu": "digerir",
    "digeríamo": "digerir",
    "digeríamos": "digerir",
    "digeríei": "digerir",
    "digeríeis": "digerir",
    "digeríramo": "digerir",
    "digeríramos": "digerir",
    "digerírei": "digerir",
    "digeríreis": "digerir",
    "digerísseis": "digerir",
    "digeríssemos": "digerir",
    "digeríveis": "digerível",
    "digesta": "digesto",
    "digestas": "digesto",
    "digestililidades": "digestililidade",
    "digestiva": "digestivo",
    "digestivas": "digestivo",
    "digestivos": "digestivo",
    "digestora": "digestor",
    "digestoras": "digestor",
    "digestores": "digestor",
    "digestos": "digesto",
    "digestíveis": "digestível",
    "digestória": "digestório",
    "digestórias": "digestório",
    "digestórios": "digestório",
    "digestões": "digestão",
    "digira": "digerir",
    "digirais": "digerir",
    "digiram": "digerir",
    "digiramo": "digerir",
    "digiramos": "digerir",
    "digiras": "digerir",
    "digirida": "digirido",
    "digiridas": "digirido",
    "digiridos": "digirido",
    "digiro": "digerir",
    "digita": "digitar",
    "digitada": "digitar",
    "digitadas": "digitar",
    "digitado": "digitar",
    "digitados": "digitar",
    "digitai": "digitar",
    "digitais": "digitar",
    "digitaliformes": "digitaliforme",
    "digitalinas": "digitalina",
    "digitaliza": "digitalizar",
    "digitalizada": "digitalizar",
    "digitalizadas": "digitalizar",
    "digitalizado": "digitalizar",
    "digitalizados": "digitalizar",
    "digitalizai": "digitalizar",
    "digitalizais": "digitalizar",
    "digitalizam": "digitalizar",
    "digitalizamo": "digitalizar",
    "digitalizamos": "digitalizar",
    "digitalizando": "digitalizar",
    "digitalizara": "digitalizar",
    "digitalizaram": "digitalizar",
    "digitalizaras": "digitalizar",
    "digitalizarde": "digitalizar",
    "digitalizardes": "digitalizar",
    "digitalizare": "digitalizar",
    "digitalizarei": "digitalizar",
    "digitalizareis": "digitalizar",
    "digitalizarem": "digitalizar",
    "digitalizaremos": "digitalizar",
    "digitalizares": "digitalizar",
    "digitalizaria": "digitalizar",
    "digitalizariam": "digitalizar",
    "digitalizarias": "digitalizar",
    "digitalizarmo": "digitalizar",
    "digitalizarmos": "digitalizar",
    "digitalizará": "digitalizar",
    "digitalizarás": "digitalizar",
    "digitalizarão": "digitalizar",
    "digitalizaríamos": "digitalizar",
    "digitalizaríeis": "digitalizar",
    "digitalizas": "digitalizar",
    "digitalizasse": "digitalizar",
    "digitalizassem": "digitalizar",
    "digitalizasses": "digitalizar",
    "digitalizaste": "digitalizar",
    "digitalizastes": "digitalizar",
    "digitalizava": "digitalizar",
    "digitalizavam": "digitalizar",
    "digitalizavas": "digitalizar",
    "digitalizaçãos": "digitalização",
    "digitalize": "digitalizar",
    "digitalizei": "digitalizar",
    "digitalizeis": "digitalizar",
    "digitalizem": "digitalizar",
    "digitalizemo": "digitalizar",
    "digitalizemos": "digitalizar",
    "digitalizes": "digitalizar",
    "digitalizo": "digitalizar",
    "digitalizou": "digitalizar",
    "digitalizá": "digitalizar",
    "digitalizámo": "digitalizar",
    "digitalizámos": "digitalizar",
    "digitalizáramo": "digitalizar",
    "digitalizáramos": "digitalizar",
    "digitalizárei": "digitalizar",
    "digitalizáreis": "digitalizar",
    "digitalizásseis": "digitalizar",
    "digitalizássemos": "digitalizar",
    "digitalizávamo": "digitalizar",
    "digitalizávamos": "digitalizar",
    "digitalizávei": "digitalizar",
    "digitalizáveis": "digitalizar",
    "digitam": "digitar",
    "digitamo": "digitar",
    "digitamos": "digitar",
    "digitando": "digitar",
    "digitara": "digitar",
    "digitaram": "digitar",
    "digitaras": "digitar",
    "digitarde": "digitar",
    "digitardes": "digitar",
    "digitare": "digitar",
    "digitarei": "digitar",
    "digitareis": "digitar",
    "digitarem": "digitar",
    "digitaremos": "digitar",
    "digitares": "digitar",
    "digitaria": "digitar",
    "digitariam": "digitar",
    "digitarias": "digitar",
    "digitarmo": "digitar",
    "digitarmos": "digitar",
    "digitará": "digitar",
    "digitarás": "digitar",
    "digitarão": "digitar",
    "digitaríamos": "digitar",
    "digitaríeis": "digitar",
    "digitas": "digitar",
    "digitasse": "digitar",
    "digitassem": "digitar",
    "digitasses": "digitar",
    "digitaste": "digitar",
    "digitastes": "digitar",
    "digitava": "digitar",
    "digitavam": "digitar",
    "digitavas": "digitar",
    "digitações": "digitação",
    "digite": "digitar",
    "digitei": "digitar",
    "digiteis": "digitar",
    "digitem": "digitar",
    "digitemo": "digitar",
    "digitemos": "digitar",
    "digites": "digitar",
    "digitifoliada": "digitifoliado",
    "digitifoliadas": "digitifoliado",
    "digitifoliados": "digitifoliado",
    "digitiformes": "digitiforme",
    "digito": "digitar",
    "digitou": "digitar",
    "digitá": "digitar",
    "digitámo": "digitar",
    "digitámos": "digitar",
    "digitáramo": "digitar",
    "digitáramos": "digitar",
    "digitárei": "digitar",
    "digitáreis": "digitar",
    "digitásseis": "digitar",
    "digitássemos": "digitar",
    "digitávamo": "digitar",
    "digitávamos": "digitar",
    "digitávei": "digitar",
    "digitáveis": "digitável",
    "digitígrada": "digitígrado",
    "digitígradas": "digitígrado",
    "digitígrados": "digitígrado",
    "digladia": "digladiar",
    "digladiada": "digladiar",
    "digladiadas": "digladiar",
    "digladiado": "digladiar",
    "digladiadora": "digladiador",
    "digladiadoras": "digladiador",
    "digladiadores": "digladiador",
    "digladiados": "digladiar",
    "digladiai": "digladiar",
    "digladiais": "digladiar",
    "digladiam": "digladiar",
    "digladiamo": "digladiar",
    "digladiamos": "digladiar",
    "digladiando": "digladiar",
    "digladiara": "digladiar",
    "digladiaram": "digladiar",
    "digladiaras": "digladiar",
    "digladiarde": "digladiar",
    "digladiardes": "digladiar",
    "digladiare": "digladiar",
    "digladiarei": "digladiar",
    "digladiareis": "digladiar",
    "digladiarem": "digladiar",
    "digladiaremos": "digladiar",
    "digladiares": "digladiar",
    "digladiaria": "digladiar",
    "digladiariam": "digladiar",
    "digladiarias": "digladiar",
    "digladiarmo": "digladiar",
    "digladiarmos": "digladiar",
    "digladiará": "digladiar",
    "digladiarás": "digladiar",
    "digladiarão": "digladiar",
    "digladiaríamos": "digladiar",
    "digladiaríeis": "digladiar",
    "digladias": "digladiar",
    "digladiasse": "digladiar",
    "digladiassem": "digladiar",
    "digladiasses": "digladiar",
    "digladiaste": "digladiar",
    "digladiastes": "digladiar",
    "digladiava": "digladiar",
    "digladiavam": "digladiar",
    "digladiavas": "digladiar",
    "digladiações": "digladiação",
    "digladie": "digladiar",
    "digladiei": "digladiar",
    "digladieis": "digladiar",
    "digladiem": "digladiar",
    "digladiemo": "digladiar",
    "digladiemos": "digladiar",
    "digladies": "digladiar",
    "digladio": "digladiar",
    "digladiou": "digladiar",
    "digladiá": "digladiar",
    "digladiámo": "digladiar",
    "digladiámos": "digladiar",
    "digladiáramo": "digladiar",
    "digladiáramos": "digladiar",
    "digladiárei": "digladiar",
    "digladiáreis": "digladiar",
    "digladiásseis": "digladiar",
    "digladiássemos": "digladiar",
    "digladiávamo": "digladiar",
    "digladiávamos": "digladiar",
    "digladiávei": "digladiar",
    "digladiáveis": "digladiar",
    "diglossias": "diglossia",
    "digna": "digno",
    "dignada": "dignar",
    "dignadas": "dignar",
    "dignado": "dignar",
    "dignados": "dignar",
    "dignai": "dignar",
    "dignais": "dignar",
    "dignam": "dignar",
    "dignamo": "dignar",
    "dignamos": "dignar",
    "dignando": "dignar",
    "dignara": "dignar",
    "dignaram": "dignar",
    "dignaras": "dignar",
    "dignarde": "dignar",
    "dignardes": "dignar",
    "dignare": "dignar",
    "dignarei": "dignar",
    "dignareis": "dignar",
    "dignarem": "dignar",
    "dignaremos": "dignar",
    "dignares": "dignar",
    "dignaria": "dignar",
    "dignariam": "dignar",
    "dignarias": "dignar",
    "dignarmo": "dignar",
    "dignarmos": "dignar",
    "dignará": "dignar",
    "dignarás": "dignar",
    "dignarão": "dignar",
    "dignaríamos": "dignar",
    "dignaríeis": "dignar",
    "dignas": "digno",
    "dignasse": "dignar",
    "dignassem": "dignar",
    "dignasses": "dignar",
    "dignaste": "dignar",
    "dignastes": "dignar",
    "dignava": "dignar",
    "dignavam": "dignar",
    "dignavas": "dignar",
    "dignações": "dignação",
    "digne": "dignar",
    "dignei": "dignar",
    "digneis": "dignar",
    "dignem": "dignar",
    "dignemo": "dignar",
    "dignemos": "dignar",
    "dignes": "dignar",
    "dignidades": "dignidade",
    "dignifica": "dignificar",
    "dignificada": "dignificar",
    "dignificadas": "dignificar",
    "dignificado": "dignificar",
    "dignificadora": "dignificador",
    "dignificadoras": "dignificador",
    "dignificadores": "dignificador",
    "dignificados": "dignificar",
    "dignificai": "dignificar",
    "dignificais": "dignificar",
    "dignificam": "dignificar",
    "dignificamo": "dignificar",
    "dignificamos": "dignificar",
    "dignificando": "dignificar",
    "dignificantes": "dignificante",
    "dignificara": "dignificar",
    "dignificaram": "dignificar",
    "dignificaras": "dignificar",
    "dignificarde": "dignificar",
    "dignificardes": "dignificar",
    "dignificare": "dignificar",
    "dignificarei": "dignificar",
    "dignificareis": "dignificar",
    "dignificarem": "dignificar",
    "dignificaremos": "dignificar",
    "dignificares": "dignificar",
    "dignificaria": "dignificar",
    "dignificariam": "dignificar",
    "dignificarias": "dignificar",
    "dignificarmo": "dignificar",
    "dignificarmos": "dignificar",
    "dignificará": "dignificar",
    "dignificarás": "dignificar",
    "dignificarão": "dignificar",
    "dignificaríamos": "dignificar",
    "dignificaríeis": "dignificar",
    "dignificas": "dignificar",
    "dignificasse": "dignificar",
    "dignificassem": "dignificar",
    "dignificasses": "dignificar",
    "dignificaste": "dignificar",
    "dignificastes": "dignificar",
    "dignificava": "dignificar",
    "dignificavam": "dignificar",
    "dignificavas": "dignificar",
    "dignificações": "dignificação",
    "dignifico": "dignificar",
    "dignificou": "dignificar",
    "dignificá": "dignificar",
    "dignificámo": "dignificar",
    "dignificámos": "dignificar",
    "dignificáramo": "dignificar",
    "dignificáramos": "dignificar",
    "dignificárei": "dignificar",
    "dignificáreis": "dignificar",
    "dignificásseis": "dignificar",
    "dignificássemos": "dignificar",
    "dignificávamo": "dignificar",
    "dignificávamos": "dignificar",
    "dignificávei": "dignificar",
    "dignificáveis": "dignificar",
    "dignifique": "dignificar",
    "dignifiquei": "dignificar",
    "dignifiqueis": "dignificar",
    "dignifiquem": "dignificar",
    "dignifiquemo": "dignificar",
    "dignifiquemos": "dignificar",
    "dignifiques": "dignificar",
    "dignitária": "dignitário",
    "dignitárias": "dignitário",
    "dignitários": "dignitário",
    "digno": "dignar",
    "dignos": "digno",
    "dignou": "dignar",
    "digná": "dignar",
    "dignámo": "dignar",
    "dignámos": "dignar",
    "dignáramo": "dignar",
    "dignáramos": "dignar",
    "dignárei": "dignar",
    "dignáreis": "dignar",
    "dignásseis": "dignar",
    "dignássemos": "dignar",
    "dignávamo": "dignar",
    "dignávamos": "dignar",
    "dignávei": "dignar",
    "dignáveis": "dignar",
    "digníssima": "digno",
    "digníssimas": "digno",
    "digníssimo": "digno",
    "digníssimos": "digno",
    "digo": "dizer",
    "digramas": "digrama",
    "digramática": "digramático",
    "digramáticas": "digramático",
    "digramáticos": "digramático",
    "digressiona": "digressionar",
    "digressionada": "digressionar",
    "digressionadas": "digressionar",
    "digressionado": "digressionar",
    "digressionados": "digressionar",
    "digressionai": "digressionar",
    "digressionais": "digressionar",
    "digressionam": "digressionar",
    "digressionamo": "digressionar",
    "digressionamos": "digressionar",
    "digressionando": "digressionar",
    "digressionara": "digressionar",
    "digressionaram": "digressionar",
    "digressionaras": "digressionar",
    "digressionardes": "digressionar",
    "digressionarei": "digressionar",
    "digressionareis": "digressionar",
    "digressionarem": "digressionar",
    "digressionaremos": "digressionar",
    "digressionares": "digressionar",
    "digressionaria": "digressionar",
    "digressionariam": "digressionar",
    "digressionarias": "digressionar",
    "digressionarmo": "digressionar",
    "digressionarmos": "digressionar",
    "digressionará": "digressionar",
    "digressionarás": "digressionar",
    "digressionarão": "digressionar",
    "digressionaríamos": "digressionar",
    "digressionaríeis": "digressionar",
    "digressionas": "digressionar",
    "digressionasse": "digressionar",
    "digressionassem": "digressionar",
    "digressionasses": "digressionar",
    "digressionaste": "digressionar",
    "digressionastes": "digressionar",
    "digressionava": "digressionar",
    "digressionavam": "digressionar",
    "digressionavas": "digressionar",
    "digressione": "digressionar",
    "digressionei": "digressionar",
    "digressioneis": "digressionar",
    "digressionem": "digressionar",
    "digressionemo": "digressionar",
    "digressionemos": "digressionar",
    "digressiones": "digressionar",
    "digressionistas": "digressionista",
    "digressiono": "digressionar",
    "digressionou": "digressionar",
    "digressionámo": "digressionar",
    "digressionámos": "digressionar",
    "digressionáramo": "digressionar",
    "digressionáramos": "digressionar",
    "digressionáreis": "digressionar",
    "digressionásseis": "digressionar",
    "digressionássemos": "digressionar",
    "digressionávamo": "digressionar",
    "digressionávamos": "digressionar",
    "digressionáveis": "digressionar",
    "digressiva": "digressivo",
    "digressivas": "digressivo",
    "digressivos": "digressivo",
    "digressos": "digresso",
    "digressões": "digressão",
    "digástrica": "digástrico",
    "digástricas": "digástrico",
    "digástricos": "digástrico",
    "digéneses": "digénese",
    "digénies": "digénie",
    "digínias": "digínia",
    "dilacera": "dilacerar",
    "dilacerada": "dilacerar",
    "dilaceradas": "dilacerar",
    "dilacerado": "dilacerar",
    "dilaceradora": "dilacerador",
    "dilaceradoras": "dilacerador",
    "dilaceradores": "dilacerador",
    "dilacerados": "dilacerar",
    "dilacerai": "dilacerar",
    "dilacerais": "dilacerar",
    "dilaceram": "dilacerar",
    "dilaceramentos": "dilaceramento",
    "dilaceramo": "dilacerar",
    "dilaceramos": "dilacerar",
    "dilacerando": "dilacerar",
    "dilacerantes": "dilacerante",
    "dilacerara": "dilacerar",
    "dilaceraram": "dilacerar",
    "dilaceraras": "dilacerar",
    "dilacerarde": "dilacerar",
    "dilacerardes": "dilacerar",
    "dilacerare": "dilacerar",
    "dilacerarei": "dilacerar",
    "dilacerareis": "dilacerar",
    "dilacerarem": "dilacerar",
    "dilaceraremos": "dilacerar",
    "dilacerares": "dilacerar",
    "dilaceraria": "dilacerar",
    "dilacerariam": "dilacerar",
    "dilacerarias": "dilacerar",
    "dilacerarmo": "dilacerar",
    "dilacerarmos": "dilacerar",
    "dilacerará": "dilacerar",
    "dilacerarás": "dilacerar",
    "dilacerarão": "dilacerar",
    "dilaceraríamos": "dilacerar",
    "dilaceraríeis": "dilacerar",
    "dilaceras": "dilacerar",
    "dilacerasse": "dilacerar",
    "dilacerassem": "dilacerar",
    "dilacerasses": "dilacerar",
    "dilaceraste": "dilacerar",
    "dilacerastes": "dilacerar",
    "dilacerava": "dilacerar",
    "dilaceravam": "dilacerar",
    "dilaceravas": "dilacerar",
    "dilacerações": "dilaceração",
    "dilacere": "dilacerar",
    "dilacerei": "dilacerar",
    "dilacereis": "dilacerar",
    "dilacerem": "dilacerar",
    "dilaceremo": "dilacerar",
    "dilaceremos": "dilacerar",
    "dilaceres": "dilacerar",
    "dilacero": "dilacerar",
    "dilacerou": "dilacerar",
    "dilacerá": "dilacerar",
    "dilacerámo": "dilacerar",
    "dilacerámos": "dilacerar",
    "dilaceráramo": "dilacerar",
    "dilaceráramos": "dilacerar",
    "dilacerárei": "dilacerar",
    "dilaceráreis": "dilacerar",
    "dilacerásseis": "dilacerar",
    "dilacerássemos": "dilacerar",
    "dilacerávamo": "dilacerar",
    "dilacerávamos": "dilacerar",
    "dilacerávei": "dilacerar",
    "dilaceráveis": "dilacerável",
    "dilapida": "dilapidar",
    "dilapidada": "dilapidar",
    "dilapidadas": "dilapidar",
    "dilapidado": "dilapidar",
    "dilapidadora": "dilapidador",
    "dilapidadoras": "dilapidador",
    "dilapidadores": "dilapidador",
    "dilapidados": "dilapidar",
    "dilapidai": "dilapidar",
    "dilapidais": "dilapidar",
    "dilapidam": "dilapidar",
    "dilapidamo": "dilapidar",
    "dilapidamos": "dilapidar",
    "dilapidando": "dilapidar",
    "dilapidara": "dilapidar",
    "dilapidaram": "dilapidar",
    "dilapidaras": "dilapidar",
    "dilapidarde": "dilapidar",
    "dilapidardes": "dilapidar",
    "dilapidare": "dilapidar",
    "dilapidarei": "dilapidar",
    "dilapidareis": "dilapidar",
    "dilapidarem": "dilapidar",
    "dilapidaremos": "dilapidar",
    "dilapidares": "dilapidar",
    "dilapidaria": "dilapidar",
    "dilapidariam": "dilapidar",
    "dilapidarias": "dilapidar",
    "dilapidarmo": "dilapidar",
    "dilapidarmos": "dilapidar",
    "dilapidará": "dilapidar",
    "dilapidarás": "dilapidar",
    "dilapidarão": "dilapidar",
    "dilapidaríamos": "dilapidar",
    "dilapidaríeis": "dilapidar",
    "dilapidas": "dilapidar",
    "dilapidasse": "dilapidar",
    "dilapidassem": "dilapidar",
    "dilapidasses": "dilapidar",
    "dilapidaste": "dilapidar",
    "dilapidastes": "dilapidar",
    "dilapidatária": "dilapidatário",
    "dilapidatárias": "dilapidatário",
    "dilapidatários": "dilapidatário",
    "dilapidava": "dilapidar",
    "dilapidavam": "dilapidar",
    "dilapidavas": "dilapidar",
    "dilapidações": "dilapidação",
    "dilapide": "dilapidar",
    "dilapidei": "dilapidar",
    "dilapideis": "dilapidar",
    "dilapidem": "dilapidar",
    "dilapidemo": "dilapidar",
    "dilapidemos": "dilapidar",
    "dilapides": "dilapidar",
    "dilapido": "dilapidar",
    "dilapidou": "dilapidar",
    "dilapidá": "dilapidar",
    "dilapidámo": "dilapidar",
    "dilapidámos": "dilapidar",
    "dilapidáramo": "dilapidar",
    "dilapidáramos": "dilapidar",
    "dilapidárei": "dilapidar",
    "dilapidáreis": "dilapidar",
    "dilapidásseis": "dilapidar",
    "dilapidássemos": "dilapidar",
    "dilapidávamo": "dilapidar",
    "dilapidávamos": "dilapidar",
    "dilapidávei": "dilapidar",
    "dilapidáveis": "dilapidável",
    "dilata": "dilatar",
    "dilatabilidades": "dilatabilidade",
    "dilatada": "dilatar",
    "dilatadas": "dilatar",
    "dilatado": "dilatar",
    "dilatadora": "dilatador",
    "dilatadoras": "dilatador",
    "dilatadores": "dilatador",
    "dilatados": "dilatar",
    "dilatadíssima": "dilatado",
    "dilatadíssimas": "dilatado",
    "dilatadíssimo": "dilatado",
    "dilatadíssimos": "dilatado",
    "dilatai": "dilatar",
    "dilatais": "dilatar",
    "dilatam": "dilatar",
    "dilatamo": "dilatar",
    "dilatamos": "dilatar",
    "dilatando": "dilatar",
    "dilatantes": "dilatante",
    "dilatara": "dilatar",
    "dilataram": "dilatar",
    "dilataras": "dilatar",
    "dilatarde": "dilatar",
    "dilatardes": "dilatar",
    "dilatare": "dilatar",
    "dilatarei": "dilatar",
    "dilatareis": "dilatar",
    "dilatarem": "dilatar",
    "dilataremos": "dilatar",
    "dilatares": "dilatar",
    "dilataria": "dilatar",
    "dilatariam": "dilatar",
    "dilatarias": "dilatar",
    "dilatarmo": "dilatar",
    "dilatarmos": "dilatar",
    "dilatará": "dilatar",
    "dilatarás": "dilatar",
    "dilatarão": "dilatar",
    "dilataríamos": "dilatar",
    "dilataríeis": "dilatar",
    "dilatas": "dilatar",
    "dilatasse": "dilatar",
    "dilatassem": "dilatar",
    "dilatasses": "dilatar",
    "dilataste": "dilatar",
    "dilatastes": "dilatar",
    "dilatava": "dilatar",
    "dilatavam": "dilatar",
    "dilatavas": "dilatar",
    "dilatações": "dilatação",
    "dilate": "dilatar",
    "dilatei": "dilatar",
    "dilateis": "dilatar",
    "dilatem": "dilatar",
    "dilatemo": "dilatar",
    "dilatemos": "dilatar",
    "dilates": "dilatar",
    "dilato": "dilatar",
    "dilatometrias": "dilatometria",
    "dilatou": "dilatar",
    "dilatá": "dilatar",
    "dilatámo": "dilatar",
    "dilatámos": "dilatar",
    "dilatáramo": "dilatar",
    "dilatáramos": "dilatar",
    "dilatárei": "dilatar",
    "dilatáreis": "dilatar",
    "dilatásseis": "dilatar",
    "dilatássemos": "dilatar",
    "dilatávamo": "dilatar",
    "dilatávamos": "dilatar",
    "dilatávei": "dilatar",
    "dilatáveis": "dilatável",
    "dilatómetros": "dilatómetro",
    "dilatória": "dilatório",
    "dilatórias": "dilatório",
    "dilatórios": "dilatório",
    "dilações": "dilação",
    "dilecta": "dilecto",
    "dilectas": "dilecto",
    "dilectos": "dilecto",
    "dilecções": "dilecção",
    "dilemas": "dilema",
    "dilemática": "dilemático",
    "dilemáticas": "dilemático",
    "dilemáticos": "dilemático",
    "diletantes": "diletante",
    "diletantismos": "diletantismo",
    "diligencia": "diligenciar",
    "diligenciada": "diligenciar",
    "diligenciadas": "diligenciar",
    "diligenciado": "diligenciar",
    "diligenciadora": "diligenciador",
    "diligenciadoras": "diligenciador",
    "diligenciadores": "diligenciador",
    "diligenciados": "diligenciar",
    "diligenciai": "diligenciar",
    "diligenciais": "diligenciar",
    "diligenciam": "diligenciar",
    "diligenciamo": "diligenciar",
    "diligenciamos": "diligenciar",
    "diligenciando": "diligenciar",
    "diligenciara": "diligenciar",
    "diligenciaram": "diligenciar",
    "diligenciaras": "diligenciar",
    "diligenciardes": "diligenciar",
    "diligenciarei": "diligenciar",
    "diligenciareis": "diligenciar",
    "diligenciarem": "diligenciar",
    "diligenciaremos": "diligenciar",
    "diligenciares": "diligenciar",
    "diligenciaria": "diligenciar",
    "diligenciariam": "diligenciar",
    "diligenciarias": "diligenciar",
    "diligenciarmo": "diligenciar",
    "diligenciarmos": "diligenciar",
    "diligenciará": "diligenciar",
    "diligenciarás": "diligenciar",
    "diligenciarão": "diligenciar",
    "diligenciaríamos": "diligenciar",
    "diligenciaríeis": "diligenciar",
    "diligencias": "diligenciar",
    "diligenciasse": "diligenciar",
    "diligenciassem": "diligenciar",
    "diligenciasses": "diligenciar",
    "diligenciaste": "diligenciar",
    "diligenciastes": "diligenciar",
    "diligenciava": "diligenciar",
    "diligenciavam": "diligenciar",
    "diligenciavas": "diligenciar",
    "diligencie": "diligenciar",
    "diligenciei": "diligenciar",
    "diligencieis": "diligenciar",
    "diligenciem": "diligenciar",
    "diligenciemo": "diligenciar",
    "diligenciemos": "diligenciar",
    "diligencies": "diligenciar",
    "diligencio": "diligenciar",
    "diligenciou": "diligenciar",
    "diligenciámo": "diligenciar",
    "diligenciámos": "diligenciar",
    "diligenciáramo": "diligenciar",
    "diligenciáramos": "diligenciar",
    "diligenciáreis": "diligenciar",
    "diligenciásseis": "diligenciar",
    "diligenciássemos": "diligenciar",
    "diligenciávamo": "diligenciar",
    "diligenciávamos": "diligenciar",
    "diligenciáveis": "diligenciar",
    "diligentes": "diligente",
    "diligências": "diligência",
    "dilobulada": "dilobulado",
    "dilobuladas": "dilobulado",
    "dilobulados": "dilobulado",
    "dilua": "diluir",
    "diluais": "diluir",
    "diluam": "diluir",
    "diluamo": "diluir",
    "diluamos": "diluir",
    "diluas": "diluir",
    "dilucida": "dilucidar",
    "dilucidada": "dilucidar",
    "dilucidadas": "dilucidar",
    "dilucidado": "dilucidar",
    "dilucidados": "dilucidar",
    "dilucidai": "dilucidar",
    "dilucidais": "dilucidar",
    "dilucidam": "dilucidar",
    "dilucidamentos": "dilucidamento",
    "dilucidamo": "dilucidar",
    "dilucidamos": "dilucidar",
    "dilucidando": "dilucidar",
    "dilucidara": "dilucidar",
    "dilucidaram": "dilucidar",
    "dilucidaras": "dilucidar",
    "dilucidarde": "dilucidar",
    "dilucidardes": "dilucidar",
    "dilucidare": "dilucidar",
    "dilucidarei": "dilucidar",
    "dilucidareis": "dilucidar",
    "dilucidarem": "dilucidar",
    "dilucidaremos": "dilucidar",
    "dilucidares": "dilucidar",
    "dilucidaria": "dilucidar",
    "dilucidariam": "dilucidar",
    "dilucidarias": "dilucidar",
    "dilucidarmo": "dilucidar",
    "dilucidarmos": "dilucidar",
    "dilucidará": "dilucidar",
    "dilucidarás": "dilucidar",
    "dilucidarão": "dilucidar",
    "dilucidaríamos": "dilucidar",
    "dilucidaríeis": "dilucidar",
    "dilucidas": "dilucidar",
    "dilucidasse": "dilucidar",
    "dilucidassem": "dilucidar",
    "dilucidasses": "dilucidar",
    "dilucidaste": "dilucidar",
    "dilucidastes": "dilucidar",
    "dilucidava": "dilucidar",
    "dilucidavam": "dilucidar",
    "dilucidavas": "dilucidar",
    "dilucidações": "dilucidação",
    "dilucide": "dilucidar",
    "dilucidei": "dilucidar",
    "dilucideis": "dilucidar",
    "dilucidem": "dilucidar",
    "dilucidemo": "dilucidar",
    "dilucidemos": "dilucidar",
    "dilucides": "dilucidar",
    "dilucido": "dilucidar",
    "dilucidou": "dilucidar",
    "dilucidá": "dilucidar",
    "dilucidámo": "dilucidar",
    "dilucidámos": "dilucidar",
    "dilucidáramo": "dilucidar",
    "dilucidáramos": "dilucidar",
    "dilucidárei": "dilucidar",
    "dilucidáreis": "dilucidar",
    "dilucidásseis": "dilucidar",
    "dilucidássemos": "dilucidar",
    "dilucidávamo": "dilucidar",
    "dilucidávamos": "dilucidar",
    "dilucidávei": "dilucidar",
    "dilucidáveis": "dilucidar",
    "diluculares": "dilucular",
    "diluem": "diluir",
    "diluentes": "diluente",
    "dilui": "diluir",
    "diluimentos": "diluimento",
    "diluindo": "diluir",
    "diluirde": "diluir",
    "diluirdes": "diluir",
    "diluirei": "diluir",
    "diluireis": "diluir",
    "diluiremos": "diluir",
    "diluiria": "diluir",
    "diluiriam": "diluir",
    "diluirias": "diluir",
    "diluirmo": "diluir",
    "diluirmos": "diluir",
    "diluirá": "diluir",
    "diluirás": "diluir",
    "diluirão": "diluir",
    "diluiríamos": "diluir",
    "diluiríeis": "diluir",
    "diluis": "diluir",
    "diluiu": "diluir",
    "diluições": "diluição",
    "diluo": "diluir",
    "diluta": "diluto",
    "dilutas": "diluto",
    "dilutos": "diluto",
    "diluvia": "diluviar",
    "diluviada": "diluviar",
    "diluviadas": "diluviar",
    "diluviado": "diluviar",
    "diluviados": "diluviar",
    "diluviai": "diluviar",
    "diluviais": "diluviar",
    "diluviam": "diluviar",
    "diluviamo": "diluviar",
    "diluviamos": "diluviar",
    "diluviana": "diluviano",
    "diluvianas": "diluviano",
    "diluviando": "diluviar",
    "diluvianos": "diluviano",
    "diluviara": "diluviar",
    "diluviaram": "diluviar",
    "diluviaras": "diluviar",
    "diluviarde": "diluviar",
    "diluviardes": "diluviar",
    "diluviare": "diluviar",
    "diluviarei": "diluviar",
    "diluviareis": "diluviar",
    "diluviarem": "diluviar",
    "diluviaremos": "diluviar",
    "diluviares": "diluviar",
    "diluviaria": "diluviar",
    "diluviariam": "diluviar",
    "diluviarias": "diluviar",
    "diluviarmo": "diluviar",
    "diluviarmos": "diluviar",
    "diluviará": "diluviar",
    "diluviarás": "diluviar",
    "diluviarão": "diluviar",
    "diluviaríamos": "diluviar",
    "diluviaríeis": "diluviar",
    "diluvias": "diluviar",
    "diluviasse": "diluviar",
    "diluviassem": "diluviar",
    "diluviasses": "diluviar",
    "diluviaste": "diluviar",
    "diluviastes": "diluviar",
    "diluviava": "diluviar",
    "diluviavam": "diluviar",
    "diluviavas": "diluviar",
    "diluvie": "diluviar",
    "diluviei": "diluviar",
    "diluvieis": "diluviar",
    "diluviem": "diluviar",
    "diluviemo": "diluviar",
    "diluviemos": "diluviar",
    "diluvies": "diluviar",
    "diluvio": "diluviar",
    "diluviosa": "diluvioso",
    "diluviosas": "diluvioso",
    "diluviosos": "diluvioso",
    "diluviou": "diluviar",
    "diluviá": "diluviar",
    "diluviámo": "diluviar",
    "diluviámos": "diluviar",
    "diluviáramo": "diluviar",
    "diluviáramos": "diluviar",
    "diluviárei": "diluviar",
    "diluviáreis": "diluviar",
    "diluviásseis": "diluviar",
    "diluviássemos": "diluviar",
    "diluviávamo": "diluviar",
    "diluviávamos": "diluviar",
    "diluviávei": "diluviar",
    "diluviáveis": "diluviar",
    "diluviões": "diluvião",
    "diluí": "diluir",
    "diluía": "diluir",
    "diluíam": "diluir",
    "diluíamo": "diluir",
    "diluíamos": "diluir",
    "diluías": "diluir",
    "diluída": "diluir",
    "diluídas": "diluir",
    "diluído": "diluir",
    "diluídos": "diluir",
    "diluíei": "diluir",
    "diluíeis": "diluir",
    "diluímo": "diluir",
    "diluímos": "diluir",
    "diluíra": "diluir",
    "diluíram": "diluir",
    "diluíramo": "diluir",
    "diluíramos": "diluir",
    "diluíras": "diluir",
    "diluíre": "diluir",
    "diluírei": "diluir",
    "diluíreis": "diluir",
    "diluírem": "diluir",
    "diluíres": "diluir",
    "diluís": "diluir",
    "diluísse": "diluir",
    "diluísseis": "diluir",
    "diluíssem": "diluir",
    "diluíssemos": "diluir",
    "diluísses": "diluir",
    "diluíste": "diluir",
    "diluístes": "diluir",
    "diluíveis": "diluível",
    "dilúcida": "dilúcido",
    "dilúcidas": "dilúcido",
    "dilúcidos": "dilúcido",
    "dilúculos": "dilúculo",
    "dilúvios": "dilúvio",
    "dimana": "dimanar",
    "dimanada": "dimanar",
    "dimanadas": "dimanar",
    "dimanado": "dimanar",
    "dimanados": "dimanar",
    "dimanai": "dimanar",
    "dimanais": "dimanar",
    "dimanam": "dimanar",
    "dimanamo": "dimanar",
    "dimanamos": "dimanar",
    "dimanando": "dimanar",
    "dimanantes": "dimanante",
    "dimanara": "dimanar",
    "dimanaram": "dimanar",
    "dimanaras": "dimanar",
    "dimanarde": "dimanar",
    "dimanardes": "dimanar",
    "dimanare": "dimanar",
    "dimanarei": "dimanar",
    "dimanareis": "dimanar",
    "dimanarem": "dimanar",
    "dimanaremos": "dimanar",
    "dimanares": "dimanar",
    "dimanaria": "dimanar",
    "dimanariam": "dimanar",
    "dimanarias": "dimanar",
    "dimanarmo": "dimanar",
    "dimanarmos": "dimanar",
    "dimanará": "dimanar",
    "dimanarás": "dimanar",
    "dimanarão": "dimanar",
    "dimanaríamos": "dimanar",
    "dimanaríeis": "dimanar",
    "dimanas": "dimanar",
    "dimanasse": "dimanar",
    "dimanassem": "dimanar",
    "dimanasses": "dimanar",
    "dimanaste": "dimanar",
    "dimanastes": "dimanar",
    "dimanava": "dimanar",
    "dimanavam": "dimanar",
    "dimanavas": "dimanar",
    "dimanações": "dimanação",
    "dimane": "dimanar",
    "dimanei": "dimanar",
    "dimaneis": "dimanar",
    "dimanem": "dimanar",
    "dimanemo": "dimanar",
    "dimanemos": "dimanar",
    "dimanes": "dimanar",
    "dimano": "dimanar",
    "dimanou": "dimanar",
    "dimaná": "dimanar",
    "dimanámo": "dimanar",
    "dimanámos": "dimanar",
    "dimanáramo": "dimanar",
    "dimanáramos": "dimanar",
    "dimanárei": "dimanar",
    "dimanáreis": "dimanar",
    "dimanásseis": "dimanar",
    "dimanássemos": "dimanar",
    "dimanávamo": "dimanar",
    "dimanávamos": "dimanar",
    "dimanávei": "dimanar",
    "dimanáveis": "dimanar",
    "dimensiona": "dimensionar",
    "dimensionada": "dimensionar",
    "dimensionadas": "dimensionar",
    "dimensionado": "dimensionar",
    "dimensionados": "dimensionar",
    "dimensionai": "dimensionar",
    "dimensionais": "dimensionar",
    "dimensionalidades": "dimensionalidade",
    "dimensionam": "dimensionar",
    "dimensionamentos": "dimensionamento",
    "dimensionamo": "dimensionar",
    "dimensionamos": "dimensionar",
    "dimensionando": "dimensionar",
    "dimensionara": "dimensionar",
    "dimensionaram": "dimensionar",
    "dimensionaras": "dimensionar",
    "dimensionarde": "dimensionar",
    "dimensionardes": "dimensionar",
    "dimensionare": "dimensionar",
    "dimensionarei": "dimensionar",
    "dimensionareis": "dimensionar",
    "dimensionarem": "dimensionar",
    "dimensionaremos": "dimensionar",
    "dimensionares": "dimensionar",
    "dimensionaria": "dimensionar",
    "dimensionariam": "dimensionar",
    "dimensionarias": "dimensionar",
    "dimensionarmo": "dimensionar",
    "dimensionarmos": "dimensionar",
    "dimensionará": "dimensionar",
    "dimensionarás": "dimensionar",
    "dimensionarão": "dimensionar",
    "dimensionaríamos": "dimensionar",
    "dimensionaríeis": "dimensionar",
    "dimensionas": "dimensionar",
    "dimensionasse": "dimensionar",
    "dimensionassem": "dimensionar",
    "dimensionasses": "dimensionar",
    "dimensionaste": "dimensionar",
    "dimensionastes": "dimensionar",
    "dimensionava": "dimensionar",
    "dimensionavam": "dimensionar",
    "dimensionavas": "dimensionar",
    "dimensione": "dimensionar",
    "dimensionei": "dimensionar",
    "dimensioneis": "dimensionar",
    "dimensionem": "dimensionar",
    "dimensionemo": "dimensionar",
    "dimensionemos": "dimensionar",
    "dimensiones": "dimensionar",
    "dimensiono": "dimensionar",
    "dimensionou": "dimensionar",
    "dimensioná": "dimensionar",
    "dimensionámo": "dimensionar",
    "dimensionámos": "dimensionar",
    "dimensionáramo": "dimensionar",
    "dimensionáramos": "dimensionar",
    "dimensionárei": "dimensionar",
    "dimensionáreis": "dimensionar",
    "dimensionásseis": "dimensionar",
    "dimensionássemos": "dimensionar",
    "dimensionávamo": "dimensionar",
    "dimensionávamos": "dimensionar",
    "dimensionávei": "dimensionar",
    "dimensionáveis": "dimensionável",
    "dimensíveis": "dimensível",
    "dimensória": "dimensório",
    "dimensórias": "dimensório",
    "dimensórios": "dimensório",
    "dimensões": "dimensão",
    "dimidia": "dimidiar",
    "dimidiada": "dimidiar",
    "dimidiadas": "dimidiar",
    "dimidiado": "dimidiar",
    "dimidiados": "dimidiar",
    "dimidiai": "dimidiar",
    "dimidiais": "dimidiar",
    "dimidiam": "dimidiar",
    "dimidiamo": "dimidiar",
    "dimidiamos": "dimidiar",
    "dimidiando": "dimidiar",
    "dimidiara": "dimidiar",
    "dimidiaram": "dimidiar",
    "dimidiaras": "dimidiar",
    "dimidiarde": "dimidiar",
    "dimidiardes": "dimidiar",
    "dimidiare": "dimidiar",
    "dimidiarei": "dimidiar",
    "dimidiareis": "dimidiar",
    "dimidiarem": "dimidiar",
    "dimidiaremos": "dimidiar",
    "dimidiares": "dimidiar",
    "dimidiaria": "dimidiar",
    "dimidiariam": "dimidiar",
    "dimidiarias": "dimidiar",
    "dimidiarmo": "dimidiar",
    "dimidiarmos": "dimidiar",
    "dimidiará": "dimidiar",
    "dimidiarás": "dimidiar",
    "dimidiarão": "dimidiar",
    "dimidiaríamos": "dimidiar",
    "dimidiaríeis": "dimidiar",
    "dimidias": "dimidiar",
    "dimidiasse": "dimidiar",
    "dimidiassem": "dimidiar",
    "dimidiasses": "dimidiar",
    "dimidiaste": "dimidiar",
    "dimidiastes": "dimidiar",
    "dimidiava": "dimidiar",
    "dimidiavam": "dimidiar",
    "dimidiavas": "dimidiar",
    "dimidiações": "dimidiação",
    "dimidie": "dimidiar",
    "dimidiei": "dimidiar",
    "dimidieis": "dimidiar",
    "dimidiem": "dimidiar",
    "dimidiemo": "dimidiar",
    "dimidiemos": "dimidiar",
    "dimidies": "dimidiar",
    "dimidio": "dimidiar",
    "dimidiou": "dimidiar",
    "dimidiá": "dimidiar",
    "dimidiámo": "dimidiar",
    "dimidiámos": "dimidiar",
    "dimidiáramo": "dimidiar",
    "dimidiáramos": "dimidiar",
    "dimidiárei": "dimidiar",
    "dimidiáreis": "dimidiar",
    "dimidiásseis": "dimidiar",
    "dimidiássemos": "dimidiar",
    "dimidiávamo": "dimidiar",
    "dimidiávamos": "dimidiar",
    "dimidiávei": "dimidiar",
    "dimidiáveis": "dimidiar",
    "diminua": "diminuir",
    "diminuais": "diminuir",
    "diminuam": "diminuir",
    "diminuamo": "diminuir",
    "diminuamos": "diminuir",
    "diminuas": "diminuir",
    "diminuem": "diminuir",
    "diminuendos": "diminuendo",
    "diminui": "diminuir",
    "diminuidores": "diminuidor",
    "diminuidíssima": "diminuído",
    "diminuidíssimas": "diminuído",
    "diminuidíssimo": "diminuído",
    "diminuidíssimos": "diminuído",
    "diminuindo": "diminuir",
    "diminuirde": "diminuir",
    "diminuirdes": "diminuir",
    "diminuirei": "diminuir",
    "diminuireis": "diminuir",
    "diminuiremos": "diminuir",
    "diminuiria": "diminuir",
    "diminuiriam": "diminuir",
    "diminuirias": "diminuir",
    "diminuirmo": "diminuir",
    "diminuirmos": "diminuir",
    "diminuirá": "diminuir",
    "diminuirás": "diminuir",
    "diminuirão": "diminuir",
    "diminuiríamos": "diminuir",
    "diminuiríeis": "diminuir",
    "diminuis": "diminuir",
    "diminuiu": "diminuir",
    "diminuições": "diminuição",
    "diminuo": "diminuir",
    "diminuta": "diminuto",
    "diminutas": "diminuto",
    "diminutiva": "diminutivo",
    "diminutivas": "diminutivo",
    "diminutivos": "diminutivo",
    "diminutos": "diminuto",
    "diminuí": "diminuir",
    "diminuía": "diminuir",
    "diminuíam": "diminuir",
    "diminuíamo": "diminuir",
    "diminuíamos": "diminuir",
    "diminuías": "diminuir",
    "diminuída": "diminuir",
    "diminuídas": "diminuir",
    "diminuído": "diminuir",
    "diminuídos": "diminuir",
    "diminuíei": "diminuir",
    "diminuíeis": "diminuir",
    "diminuímo": "diminuir",
    "diminuímos": "diminuir",
    "diminuíra": "diminuir",
    "diminuíram": "diminuir",
    "diminuíramo": "diminuir",
    "diminuíramos": "diminuir",
    "diminuíras": "diminuir",
    "diminuíre": "diminuir",
    "diminuírei": "diminuir",
    "diminuíreis": "diminuir",
    "diminuírem": "diminuir",
    "diminuíres": "diminuir",
    "diminuís": "diminuir",
    "diminuísse": "diminuir",
    "diminuísseis": "diminuir",
    "diminuíssem": "diminuir",
    "diminuíssemos": "diminuir",
    "diminuísses": "diminuir",
    "diminuíste": "diminuir",
    "diminuístes": "diminuir",
    "diminuíveis": "diminuível",
    "dimiurgos": "dimiurgo",
    "dimorfa": "dimorfo",
    "dimorfas": "dimorfo",
    "dimorfias": "dimorfia",
    "dimorfismos": "dimorfismo",
    "dimorfos": "dimorfo",
    "dina": "dino",
    "dinamarquesa": "dinamarquês",
    "dinamarquesas": "dinamarquês",
    "dinamarqueses": "dinamarquês",
    "dinamias": "dinamia",
    "dinamismos": "dinamismo",
    "dinamistas": "dinamista",
    "dinamita": "dinamitar",
    "dinamitada": "dinamitar",
    "dinamitadas": "dinamitar",
    "dinamitado": "dinamitar",
    "dinamitados": "dinamitar",
    "dinamitai": "dinamitar",
    "dinamitais": "dinamitar",
    "dinamitam": "dinamitar",
    "dinamitamo": "dinamitar",
    "dinamitamos": "dinamitar",
    "dinamitando": "dinamitar",
    "dinamitara": "dinamitar",
    "dinamitaram": "dinamitar",
    "dinamitaras": "dinamitar",
    "dinamitarde": "dinamitar",
    "dinamitardes": "dinamitar",
    "dinamitare": "dinamitar",
    "dinamitarei": "dinamitar",
    "dinamitareis": "dinamitar",
    "dinamitarem": "dinamitar",
    "dinamitaremos": "dinamitar",
    "dinamitares": "dinamitar",
    "dinamitaria": "dinamitar",
    "dinamitariam": "dinamitar",
    "dinamitarias": "dinamitar",
    "dinamitarmo": "dinamitar",
    "dinamitarmos": "dinamitar",
    "dinamitará": "dinamitar",
    "dinamitarás": "dinamitar",
    "dinamitarão": "dinamitar",
    "dinamitaríamos": "dinamitar",
    "dinamitaríeis": "dinamitar",
    "dinamitas": "dinamitar",
    "dinamitasse": "dinamitar",
    "dinamitassem": "dinamitar",
    "dinamitasses": "dinamitar",
    "dinamitaste": "dinamitar",
    "dinamitastes": "dinamitar",
    "dinamitava": "dinamitar",
    "dinamitavam": "dinamitar",
    "dinamitavas": "dinamitar",
    "dinamite": "dinamitar",
    "dinamitei": "dinamitar",
    "dinamiteira": "dinamiteiro",
    "dinamiteiras": "dinamiteiro",
    "dinamiteiros": "dinamiteiro",
    "dinamiteis": "dinamitar",
    "dinamitem": "dinamitar",
    "dinamitemo": "dinamitar",
    "dinamitemos": "dinamitar",
    "dinamites": "dinamite",
    "dinamito": "dinamitar",
    "dinamitou": "dinamitar",
    "dinamitá": "dinamitar",
    "dinamitámo": "dinamitar",
    "dinamitámos": "dinamitar",
    "dinamitáramo": "dinamitar",
    "dinamitáramos": "dinamitar",
    "dinamitárei": "dinamitar",
    "dinamitáreis": "dinamitar",
    "dinamitásseis": "dinamitar",
    "dinamitássemos": "dinamitar",
    "dinamitávamo": "dinamitar",
    "dinamitávamos": "dinamitar",
    "dinamitávei": "dinamitar",
    "dinamitáveis": "dinamitável",
    "dinamiza": "dinamizar",
    "dinamizada": "dinamizar",
    "dinamizadas": "dinamizar",
    "dinamizado": "dinamizar",
    "dinamizadora": "dinamizador",
    "dinamizadoras": "dinamizador",
    "dinamizadores": "dinamizador",
    "dinamizados": "dinamizar",
    "dinamizai": "dinamizar",
    "dinamizais": "dinamizar",
    "dinamizam": "dinamizar",
    "dinamizamo": "dinamizar",
    "dinamizamos": "dinamizar",
    "dinamizando": "dinamizar",
    "dinamizara": "dinamizar",
    "dinamizaram": "dinamizar",
    "dinamizaras": "dinamizar",
    "dinamizarde": "dinamizar",
    "dinamizardes": "dinamizar",
    "dinamizare": "dinamizar",
    "dinamizarei": "dinamizar",
    "dinamizareis": "dinamizar",
    "dinamizarem": "dinamizar",
    "dinamizaremos": "dinamizar",
    "dinamizares": "dinamizar",
    "dinamizaria": "dinamizar",
    "dinamizariam": "dinamizar",
    "dinamizarias": "dinamizar",
    "dinamizarmo": "dinamizar",
    "dinamizarmos": "dinamizar",
    "dinamizará": "dinamizar",
    "dinamizarás": "dinamizar",
    "dinamizarão": "dinamizar",
    "dinamizaríamos": "dinamizar",
    "dinamizaríeis": "dinamizar",
    "dinamizas": "dinamizar",
    "dinamizasse": "dinamizar",
    "dinamizassem": "dinamizar",
    "dinamizasses": "dinamizar",
    "dinamizaste": "dinamizar",
    "dinamizastes": "dinamizar",
    "dinamizava": "dinamizar",
    "dinamizavam": "dinamizar",
    "dinamizavas": "dinamizar",
    "dinamizações": "dinamização",
    "dinamize": "dinamizar",
    "dinamizei": "dinamizar",
    "dinamizeis": "dinamizar",
    "dinamizem": "dinamizar",
    "dinamizemo": "dinamizar",
    "dinamizemos": "dinamizar",
    "dinamizes": "dinamizar",
    "dinamizo": "dinamizar",
    "dinamizou": "dinamizar",
    "dinamizá": "dinamizar",
    "dinamizámo": "dinamizar",
    "dinamizámos": "dinamizar",
    "dinamizáramo": "dinamizar",
    "dinamizáramos": "dinamizar",
    "dinamizárei": "dinamizar",
    "dinamizáreis": "dinamizar",
    "dinamizásseis": "dinamizar",
    "dinamizássemos": "dinamizar",
    "dinamizávamo": "dinamizar",
    "dinamizávamos": "dinamizar",
    "dinamizávei": "dinamizar",
    "dinamizáveis": "dinamizável",
    "dinamogenias": "dinamogenia",
    "dinamogénica": "dinamogénico",
    "dinamogénicas": "dinamogénico",
    "dinamogénicos": "dinamogénico",
    "dinamometamorfismos": "dinamometamorfismo",
    "dinamometrias": "dinamometria",
    "dinamométrica": "dinamométrico",
    "dinamométricas": "dinamométrico",
    "dinamométricos": "dinamométrico",
    "dinamoscopias": "dinamoscopia",
    "dinamoscópios": "dinamoscópio",
    "dinamógrafos": "dinamógrafo",
    "dinamómetros": "dinamómetro",
    "dinancianos": "dinanciano",
    "dinares": "dinar",
    "dinas": "dino",
    "dinastas": "dinasta",
    "dinastias": "dinastia",
    "dinatrões": "dinatrão",
    "dines": "dine",
    "dinheiradas": "dinheirada",
    "dinheiramas": "dinheirama",
    "dinheirames": "dinheirame",
    "dinheirecos": "dinheireco",
    "dinheirinho": "dinheiro",
    "dinheirinhos": "dinheiro",
    "dinheirito": "dinheiro",
    "dinheiritos": "dinheiro",
    "dinheiros": "dinheiro",
    "dinheirosa": "dinheiroso",
    "dinheirosas": "dinheiroso",
    "dinheirosos": "dinheiroso",
    "dinheirões": "dinheirão",
    "dinoflageladas": "dinoflagelada",
    "dinoflagelados": "dinoflagelado",
    "dinos": "dino",
    "dinossauros": "dinossauro",
    "dinotérios": "dinotério",
    "dinteis": "dintel",
    "dintornos": "dintorno",
    "dinumera": "dinumerar",
    "dinumerada": "dinumerar",
    "dinumeradas": "dinumerar",
    "dinumerado": "dinumerar",
    "dinumerados": "dinumerar",
    "dinumerai": "dinumerar",
    "dinumerais": "dinumerar",
    "dinumeram": "dinumerar",
    "dinumeramo": "dinumerar",
    "dinumeramos": "dinumerar",
    "dinumerando": "dinumerar",
    "dinumerara": "dinumerar",
    "dinumeraram": "dinumerar",
    "dinumeraras": "dinumerar",
    "dinumerarde": "dinumerar",
    "dinumerardes": "dinumerar",
    "dinumerare": "dinumerar",
    "dinumerarei": "dinumerar",
    "dinumerareis": "dinumerar",
    "dinumerarem": "dinumerar",
    "dinumeraremos": "dinumerar",
    "dinumerares": "dinumerar",
    "dinumeraria": "dinumerar",
    "dinumerariam": "dinumerar",
    "dinumerarias": "dinumerar",
    "dinumerarmo": "dinumerar",
    "dinumerarmos": "dinumerar",
    "dinumerará": "dinumerar",
    "dinumerarás": "dinumerar",
    "dinumerarão": "dinumerar",
    "dinumeraríamos": "dinumerar",
    "dinumeraríeis": "dinumerar",
    "dinumeras": "dinumerar",
    "dinumerasse": "dinumerar",
    "dinumerassem": "dinumerar",
    "dinumerasses": "dinumerar",
    "dinumeraste": "dinumerar",
    "dinumerastes": "dinumerar",
    "dinumerava": "dinumerar",
    "dinumeravam": "dinumerar",
    "dinumeravas": "dinumerar",
    "dinumere": "dinumerar",
    "dinumerei": "dinumerar",
    "dinumereis": "dinumerar",
    "dinumerem": "dinumerar",
    "dinumeremo": "dinumerar",
    "dinumeremos": "dinumerar",
    "dinumeres": "dinumerar",
    "dinumero": "dinumerar",
    "dinumerou": "dinumerar",
    "dinumerá": "dinumerar",
    "dinumerámo": "dinumerar",
    "dinumerámos": "dinumerar",
    "dinumeráramo": "dinumerar",
    "dinumeráramos": "dinumerar",
    "dinumerárei": "dinumerar",
    "dinumeráreis": "dinumerar",
    "dinumerásseis": "dinumerar",
    "dinumerássemos": "dinumerar",
    "dinumerávamo": "dinumerar",
    "dinumerávamos": "dinumerar",
    "dinumerávei": "dinumerar",
    "dinumeráveis": "dinumerar",
    "dinástica": "dinástico",
    "dinásticas": "dinástico",
    "dinásticos": "dinástico",
    "dinâmica": "dinâmico",
    "dinâmicas": "dinâmico",
    "dinâmicos": "dinâmico",
    "diocesana": "diocesano",
    "diocesanas": "diocesano",
    "diocesanos": "diocesano",
    "dioceses": "diocese",
    "dionisiarcas": "dionisiarca",
    "dionisíaca": "dionisíaco",
    "dionisíacas": "dionisíaco",
    "dionisíacos": "dionisíaco",
    "dioptases": "dioptase",
    "dioptrias": "dioptria",
    "dioptros": "dioptro",
    "dioramas": "diorama",
    "dioramática": "dioramático",
    "dioramáticas": "dioramático",
    "dioramáticos": "dioramático",
    "dioritos": "diorito",
    "diorâmica": "diorâmico",
    "diorâmicas": "diorâmico",
    "diorâmicos": "diorâmico",
    "diorítica": "diorítico",
    "dioríticas": "diorítico",
    "dioríticos": "diorítico",
    "dioscoreáceas": "dioscoreácea",
    "diospireiros": "diospireiro",
    "diostilos": "diostilo",
    "diotias": "diotia",
    "dioxinas": "dioxina",
    "diplasiasmos": "diplasiasmo",
    "diplegias": "diplegia",
    "dipleicópios": "dipleicópio",
    "diples": "diple",
    "diplidoscópios": "diplidoscópio",
    "diplobiontes": "diplobionte",
    "diplocardíaca": "diplocardíaco",
    "diplocardíacas": "diplocardíaco",
    "diplocardíacos": "diplocardíaco",
    "diplococos": "diplococo",
    "diplocéfalos": "diplocéfalo",
    "diploedros": "diploedro",
    "diplofases": "diplofase",
    "diplofonias": "diplofonia",
    "diplogastrias": "diplogastria",
    "diplogéneses": "diplogénese",
    "diploidias": "diploidia",
    "diploma": "diplomar",
    "diplomacias": "diplomacia",
    "diplomada": "diplomar",
    "diplomadas": "diplomar",
    "diplomado": "diplomar",
    "diplomados": "diplomar",
    "diplomai": "diplomar",
    "diplomais": "diplomar",
    "diplomam": "diplomar",
    "diplomamo": "diplomar",
    "diplomamos": "diplomar",
    "diplomando": "diplomar",
    "diplomara": "diplomar",
    "diplomaram": "diplomar",
    "diplomaras": "diplomar",
    "diplomarde": "diplomar",
    "diplomardes": "diplomar",
    "diplomare": "diplomar",
    "diplomarei": "diplomar",
    "diplomareis": "diplomar",
    "diplomarem": "diplomar",
    "diplomaremos": "diplomar",
    "diplomares": "diplomar",
    "diplomaria": "diplomar",
    "diplomariam": "diplomar",
    "diplomarias": "diplomar",
    "diplomarmo": "diplomar",
    "diplomarmos": "diplomar",
    "diplomará": "diplomar",
    "diplomarás": "diplomar",
    "diplomarão": "diplomar",
    "diplomaríamos": "diplomar",
    "diplomaríeis": "diplomar",
    "diplomas": "diplomar",
    "diplomasse": "diplomar",
    "diplomassem": "diplomar",
    "diplomasses": "diplomar",
    "diplomaste": "diplomar",
    "diplomastes": "diplomar",
    "diplomatas": "diplomata",
    "diplomatistas": "diplomatista",
    "diplomava": "diplomar",
    "diplomavam": "diplomar",
    "diplomavas": "diplomar",
    "diplome": "diplomar",
    "diplomei": "diplomar",
    "diplomeis": "diplomar",
    "diplomem": "diplomar",
    "diplomemo": "diplomar",
    "diplomemos": "diplomar",
    "diplomes": "diplomar",
    "diplomo": "diplomar",
    "diplomou": "diplomar",
    "diplomá": "diplomar",
    "diplomámo": "diplomar",
    "diplomámos": "diplomar",
    "diplomáramo": "diplomar",
    "diplomáramos": "diplomar",
    "diplomárei": "diplomar",
    "diplomáreis": "diplomar",
    "diplomásseis": "diplomar",
    "diplomássemos": "diplomar",
    "diplomática": "diplomático",
    "diplomáticas": "diplomático",
    "diplomáticos": "diplomático",
    "diplomávamo": "diplomar",
    "diplomávamos": "diplomar",
    "diplomávei": "diplomar",
    "diplomáveis": "diplomável",
    "diplonemas": "diplonema",
    "diplontes": "diplonte",
    "diplopias": "diplopia",
    "diploscópios": "diploscópio",
    "diplostémones": "diplostémone",
    "diplotenos": "diploteno",
    "diplódes": "diplóde",
    "diplóides": "diplóide",
    "diplópodes": "diplópode",
    "diplóptera": "diplóptero",
    "diplópteras": "diplóptero",
    "diplópteros": "diplóptero",
    "dipneumónea": "dipneumóneo",
    "dipneumóneas": "dipneumóneo",
    "dipneumóneos": "dipneumóneo",
    "dipneustas": "dipneusta",
    "dipnêumones": "dipnêumone",
    "dipnóica": "dipnóico",
    "dipnóicas": "dipnóico",
    "dipnóicos": "dipnóico",
    "dipodias": "dipodia",
    "dipolares": "dipolar",
    "dipolos": "dipolo",
    "dipomaníaca": "dipomaníaco",
    "dipomaníacas": "dipomaníaco",
    "dipomaníacos": "dipomaníaco",
    "diprerígia": "diprerígio",
    "diprerígias": "diprerígio",
    "diprerígios": "diprerígio",
    "diprosopa": "diprosopo",
    "diprosopas": "diprosopo",
    "diprosopias": "diprosopia",
    "diprosopos": "diprosopo",
    "diprotodontes": "diprotodonte",
    "dipsacáceas": "dipsacácea",
    "dipsomanias": "dipsomania",
    "dipsomaníaca": "dipsomaníaco",
    "dipsomaníacas": "dipsomaníaco",
    "dipsomaníacos": "dipsomaníaco",
    "dipsáceas": "dipsácea",
    "dipsética": "dipsético",
    "dipséticas": "dipsético",
    "dipséticos": "dipsético",
    "dipsómana": "dipsómano",
    "dipsómanas": "dipsómano",
    "dipsómanos": "dipsómano",
    "dipterologias": "dipterologia",
    "dipterácea": "dipteráceo",
    "dipteráceas": "dipteráceo",
    "dipteráceos": "dipteráceo",
    "diptérica": "diptérico",
    "diptéricas": "diptérico",
    "diptéricos": "diptérico",
    "dipétala": "dipétalo",
    "dipétalas": "dipétalo",
    "dipétalos": "dipétalo",
    "diques": "dique",
    "direcciona": "direccionar",
    "direccionada": "direccionar",
    "direccionadas": "direccionar",
    "direccionado": "direccionar",
    "direccionados": "direccionar",
    "direccionai": "direccionar",
    "direccionais": "direccionar",
    "direccionalidades": "direccionalidade",
    "direccionam": "direccionar",
    "direccionamo": "direccionar",
    "direccionamos": "direccionar",
    "direccionando": "direccionar",
    "direccionara": "direccionar",
    "direccionaram": "direccionar",
    "direccionaras": "direccionar",
    "direccionarde": "direccionar",
    "direccionardes": "direccionar",
    "direccionare": "direccionar",
    "direccionarei": "direccionar",
    "direccionareis": "direccionar",
    "direccionarem": "direccionar",
    "direccionaremos": "direccionar",
    "direccionares": "direccionar",
    "direccionaria": "direccionar",
    "direccionariam": "direccionar",
    "direccionarias": "direccionar",
    "direccionarmo": "direccionar",
    "direccionarmos": "direccionar",
    "direccionará": "direccionar",
    "direccionarás": "direccionar",
    "direccionarão": "direccionar",
    "direccionaríamos": "direccionar",
    "direccionaríeis": "direccionar",
    "direccionas": "direccionar",
    "direccionasse": "direccionar",
    "direccionassem": "direccionar",
    "direccionasses": "direccionar",
    "direccionaste": "direccionar",
    "direccionastes": "direccionar",
    "direccionava": "direccionar",
    "direccionavam": "direccionar",
    "direccionavas": "direccionar",
    "direccione": "direccionar",
    "direccionei": "direccionar",
    "direccioneis": "direccionar",
    "direccionem": "direccionar",
    "direccionemo": "direccionar",
    "direccionemos": "direccionar",
    "direcciones": "direccionar",
    "direcciono": "direccionar",
    "direccionou": "direccionar",
    "direccioná": "direccionar",
    "direccionámo": "direccionar",
    "direccionámos": "direccionar",
    "direccionáramo": "direccionar",
    "direccionáramos": "direccionar",
    "direccionárei": "direccionar",
    "direccionáreis": "direccionar",
    "direccionásseis": "direccionar",
    "direccionássemos": "direccionar",
    "direccionávamo": "direccionar",
    "direccionávamos": "direccionar",
    "direccionávei": "direccionar",
    "direccionáveis": "direccionar",
    "directa": "directo",
    "directas": "directo",
    "directinha": "directo",
    "directinhas": "directo",
    "directinho": "directo",
    "directinhos": "directo",
    "directita": "directo",
    "directitas": "directo",
    "directito": "directo",
    "directitos": "directo",
    "directiva": "directivo",
    "directivas": "directivo",
    "directivos": "directivo",
    "directora": "director",
    "directoras": "director",
    "directorazinha": "director",
    "directorazinhas": "director",
    "directorazita": "director",
    "directorazitas": "director",
    "directores": "director",
    "directoriais": "directorial",
    "directorias": "directoria",
    "directorzinho": "director",
    "directorzinhos": "director",
    "directorzito": "director",
    "directorzitos": "director",
    "directos": "directo",
    "directrizes": "directriz",
    "directíssima": "directo",
    "directíssimas": "directo",
    "directíssimo": "directo",
    "directíssimos": "directo",
    "directória": "directório",
    "directórias": "directório",
    "directórios": "directório",
    "direcções": "direcção",
    "direi": "dizer",
    "direis": "dizer",
    "direita": "direito",
    "direitas": "direito",
    "direitinha": "direito",
    "direitinhas": "direito",
    "direitinho": "direito",
    "direitinhos": "direito",
    "direitismos": "direitismo",
    "direitistas": "direitista",
    "direitita": "direito",
    "direititas": "direito",
    "direitito": "direito",
    "direititos": "direito",
    "direitos": "direito",
    "direituras": "direitura",
    "direitíssima": "direito",
    "direitíssimas": "direito",
    "direitíssimo": "direito",
    "direitíssimos": "direito",
    "diremos": "dizer",
    "diria": "dizer",
    "diriam": "dizer",
    "dirias": "dizer",
    "diribitores": "diribitor",
    "diribitórios": "diribitório",
    "dirige": "dirigir",
    "dirigem": "dirigir",
    "dirigentes": "dirigente",
    "diriges": "dirigir",
    "dirigi": "dirigir",
    "dirigia": "dirigir",
    "dirigiam": "dirigir",
    "dirigias": "dirigir",
    "dirigibilidades": "dirigibilidade",
    "dirigida": "dirigir",
    "dirigidas": "dirigir",
    "dirigido": "dirigir",
    "dirigidos": "dirigir",
    "dirigimo": "dirigir",
    "dirigimos": "dirigir",
    "dirigindo": "dirigir",
    "dirigira": "dirigir",
    "dirigiram": "dirigir",
    "dirigiras": "dirigir",
    "dirigirde": "dirigir",
    "dirigirdes": "dirigir",
    "dirigire": "dirigir",
    "dirigirei": "dirigir",
    "dirigireis": "dirigir",
    "dirigirem": "dirigir",
    "dirigiremos": "dirigir",
    "dirigires": "dirigir",
    "dirigiria": "dirigir",
    "dirigiriam": "dirigir",
    "dirigirias": "dirigir",
    "dirigirmo": "dirigir",
    "dirigirmos": "dirigir",
    "dirigirá": "dirigir",
    "dirigirás": "dirigir",
    "dirigirão": "dirigir",
    "dirigiríamos": "dirigir",
    "dirigiríeis": "dirigir",
    "dirigis": "dirigir",
    "dirigismos": "dirigismo",
    "dirigisse": "dirigir",
    "dirigissem": "dirigir",
    "dirigisses": "dirigir",
    "dirigistas": "dirigista",
    "dirigiste": "dirigir",
    "dirigistes": "dirigir",
    "dirigiu": "dirigir",
    "dirigíamo": "dirigir",
    "dirigíamos": "dirigir",
    "dirigíei": "dirigir",
    "dirigíeis": "dirigir",
    "dirigíramo": "dirigir",
    "dirigíramos": "dirigir",
    "dirigírei": "dirigir",
    "dirigíreis": "dirigir",
    "dirigísseis": "dirigir",
    "dirigíssemos": "dirigir",
    "dirigíveis": "dirigível",
    "dirija": "dirigir",
    "dirijais": "dirigir",
    "dirijam": "dirigir",
    "dirijamo": "dirigir",
    "dirijamos": "dirigir",
    "dirijas": "dirigir",
    "dirijo": "dirigir",
    "dirima": "dirimir",
    "dirimais": "dirimir",
    "dirimam": "dirimir",
    "dirimamo": "dirimir",
    "dirimamos": "dirimir",
    "dirimas": "dirimir",
    "dirime": "dirimir",
    "dirimem": "dirimir",
    "dirimentes": "dirimente",
    "dirimes": "dirimir",
    "dirimi": "dirimir",
    "dirimia": "dirimir",
    "dirimiam": "dirimir",
    "dirimias": "dirimir",
    "dirimida": "dirimir",
    "dirimidas": "dirimir",
    "dirimido": "dirimir",
    "dirimidos": "dirimir",
    "dirimimo": "dirimir",
    "dirimimos": "dirimir",
    "dirimindo": "dirimir",
    "dirimira": "dirimir",
    "dirimiram": "dirimir",
    "dirimiras": "dirimir",
    "dirimirde": "dirimir",
    "dirimirdes": "dirimir",
    "dirimire": "dirimir",
    "dirimirei": "dirimir",
    "dirimireis": "dirimir",
    "dirimirem": "dirimir",
    "dirimiremos": "dirimir",
    "dirimires": "dirimir",
    "dirimiria": "dirimir",
    "dirimiriam": "dirimir",
    "dirimirias": "dirimir",
    "dirimirmo": "dirimir",
    "dirimirmos": "dirimir",
    "dirimirá": "dirimir",
    "dirimirás": "dirimir",
    "dirimirão": "dirimir",
    "dirimiríamos": "dirimir",
    "dirimiríeis": "dirimir",
    "dirimis": "dirimir",
    "dirimisse": "dirimir",
    "dirimissem": "dirimir",
    "dirimisses": "dirimir",
    "dirimiste": "dirimir",
    "dirimistes": "dirimir",
    "dirimiu": "dirimir",
    "dirimo": "dirimir",
    "dirimíamo": "dirimir",
    "dirimíamos": "dirimir",
    "dirimíei": "dirimir",
    "dirimíeis": "dirimir",
    "dirimíramo": "dirimir",
    "dirimíramos": "dirimir",
    "dirimírei": "dirimir",
    "dirimíreis": "dirimir",
    "dirimísseis": "dirimir",
    "dirimíssemos": "dirimir",
    "diruida": "diruido",
    "diruidas": "diruido",
    "diruidos": "diruido",
    "dirupções": "dirupção",
    "dirá": "dizer",
    "dirás": "dizer",
    "dirão": "dizer",
    "diríamos": "dizer",
    "diríeis": "dizer",
    "disartrias": "disartria",
    "disbasias": "disbasia",
    "disbulias": "disbulia",
    "disbúlica": "disbúlico",
    "disbúlicas": "disbúlico",
    "disbúlicos": "disbúlico",
    "disca": "discar",
    "discada": "discar",
    "discadas": "discar",
    "discado": "discar",
    "discados": "discar",
    "discagens": "discagem",
    "discai": "discar",
    "discais": "discar",
    "discam": "discar",
    "discamo": "discar",
    "discamos": "discar",
    "discando": "discar",
    "discara": "discar",
    "discaram": "discar",
    "discaras": "discar",
    "discarde": "discar",
    "discardes": "discar",
    "discare": "discar",
    "discarei": "discar",
    "discareis": "discar",
    "discarem": "discar",
    "discaremos": "discar",
    "discares": "discar",
    "discaria": "discar",
    "discariam": "discar",
    "discarias": "discar",
    "discarmo": "discar",
    "discarmos": "discar",
    "discará": "discar",
    "discarás": "discar",
    "discarão": "discar",
    "discaríamos": "discar",
    "discaríeis": "discar",
    "discas": "discar",
    "discasse": "discar",
    "discassem": "discar",
    "discasses": "discar",
    "discaste": "discar",
    "discastes": "discar",
    "discava": "discar",
    "discavam": "discar",
    "discavas": "discar",
    "discentes": "discente",
    "disceptações": "disceptação",
    "discerne": "discernir",
    "discernem": "discernir",
    "discernentes": "discernente",
    "discernes": "discernir",
    "discerni": "discernir",
    "discernia": "discernir",
    "discerniam": "discernir",
    "discernias": "discernir",
    "discernida": "discernir",
    "discernidas": "discernir",
    "discernido": "discernir",
    "discernidos": "discernir",
    "discernimentos": "discernimento",
    "discernimo": "discernir",
    "discernimos": "discernir",
    "discernindo": "discernir",
    "discernira": "discernir",
    "discerniram": "discernir",
    "discerniras": "discernir",
    "discernirde": "discernir",
    "discernirdes": "discernir",
    "discernire": "discernir",
    "discernirei": "discernir",
    "discernireis": "discernir",
    "discernirem": "discernir",
    "discerniremos": "discernir",
    "discernires": "discernir",
    "discerniria": "discernir",
    "discerniriam": "discernir",
    "discernirias": "discernir",
    "discernirmo": "discernir",
    "discernirmos": "discernir",
    "discernirá": "discernir",
    "discernirás": "discernir",
    "discernirão": "discernir",
    "discerniríamos": "discernir",
    "discerniríeis": "discernir",
    "discernis": "discernir",
    "discernisse": "discernir",
    "discernissem": "discernir",
    "discernisses": "discernir",
    "discerniste": "discernir",
    "discernistes": "discernir",
    "discerniu": "discernir",
    "discerníamo": "discernir",
    "discerníamos": "discernir",
    "discerníei": "discernir",
    "discerníeis": "discernir",
    "discerníramo": "discernir",
    "discerníramos": "discernir",
    "discernírei": "discernir",
    "discerníreis": "discernir",
    "discernísseis": "discernir",
    "discerníssemos": "discernir",
    "discerníveis": "discernível",
    "disciflora": "discifloro",
    "discifloras": "discifloro",
    "discifloros": "discifloro",
    "disciformes": "disciforme",
    "disciplina": "disciplinar",
    "disciplinada": "disciplinar",
    "disciplinadas": "disciplinar",
    "disciplinado": "disciplinar",
    "disciplinadora": "disciplinador",
    "disciplinadoras": "disciplinador",
    "disciplinadores": "disciplinador",
    "disciplinados": "disciplinar",
    "disciplinadíssima": "disciplinado",
    "disciplinadíssimas": "disciplinado",
    "disciplinadíssimo": "disciplinado",
    "disciplinadíssimos": "disciplinado",
    "disciplinai": "disciplinar",
    "disciplinais": "disciplinar",
    "disciplinam": "disciplinar",
    "disciplinamo": "disciplinar",
    "disciplinamos": "disciplinar",
    "disciplinando": "disciplinar",
    "disciplinantes": "disciplinante",
    "disciplinara": "disciplinar",
    "disciplinaram": "disciplinar",
    "disciplinaras": "disciplinar",
    "disciplinarde": "disciplinar",
    "disciplinardes": "disciplinar",
    "disciplinare": "disciplinar",
    "disciplinarei": "disciplinar",
    "disciplinareis": "disciplinar",
    "disciplinarem": "disciplinar",
    "disciplinaremos": "disciplinar",
    "disciplinares": "disciplinar",
    "disciplinaria": "disciplinar",
    "disciplinariam": "disciplinar",
    "disciplinarias": "disciplinar",
    "disciplinarmo": "disciplinar",
    "disciplinarmos": "disciplinar",
    "disciplinará": "disciplinar",
    "disciplinarás": "disciplinar",
    "disciplinarão": "disciplinar",
    "disciplinaríamos": "disciplinar",
    "disciplinaríeis": "disciplinar",
    "disciplinas": "disciplinar",
    "disciplinasse": "disciplinar",
    "disciplinassem": "disciplinar",
    "disciplinasses": "disciplinar",
    "disciplinaste": "disciplinar",
    "disciplinastes": "disciplinar",
    "disciplinava": "disciplinar",
    "disciplinavam": "disciplinar",
    "disciplinavas": "disciplinar",
    "disciplinações": "disciplinação",
    "discipline": "disciplinar",
    "disciplinei": "disciplinar",
    "disciplineis": "disciplinar",
    "disciplinem": "disciplinar",
    "disciplinemo": "disciplinar",
    "disciplinemos": "disciplinar",
    "disciplines": "disciplinar",
    "disciplino": "disciplinar",
    "disciplinou": "disciplinar",
    "discipliná": "disciplinar",
    "disciplinámo": "disciplinar",
    "disciplinámos": "disciplinar",
    "disciplináramo": "disciplinar",
    "disciplináramos": "disciplinar",
    "disciplinárei": "disciplinar",
    "disciplináreis": "disciplinar",
    "disciplinásseis": "disciplinar",
    "disciplinássemos": "disciplinar",
    "disciplinávamo": "disciplinar",
    "disciplinávamos": "disciplinar",
    "disciplinávei": "disciplinar",
    "disciplináveis": "disciplinável",
    "discipulados": "discipulado",
    "discipulatos": "discipulato",
    "discirna": "discernir",
    "discirnais": "discernir",
    "discirnam": "discernir",
    "discirnamo": "discernir",
    "discirnamos": "discernir",
    "discirnas": "discernir",
    "discirno": "discernir",
    "discissões": "discissão",
    "disco": "discar",
    "discografias": "discografia",
    "discográfica": "discográfico",
    "discográficas": "discográfico",
    "discográficos": "discográfico",
    "discorda": "discordar",
    "discordada": "discordar",
    "discordadas": "discordar",
    "discordado": "discordar",
    "discordados": "discordar",
    "discordai": "discordar",
    "discordais": "discordar",
    "discordam": "discordar",
    "discordamo": "discordar",
    "discordamos": "discordar",
    "discordando": "discordar",
    "discordantes": "discordante",
    "discordara": "discordar",
    "discordaram": "discordar",
    "discordaras": "discordar",
    "discordarde": "discordar",
    "discordardes": "discordar",
    "discordare": "discordar",
    "discordarei": "discordar",
    "discordareis": "discordar",
    "discordarem": "discordar",
    "discordaremos": "discordar",
    "discordares": "discordar",
    "discordaria": "discordar",
    "discordariam": "discordar",
    "discordarias": "discordar",
    "discordarmo": "discordar",
    "discordarmos": "discordar",
    "discordará": "discordar",
    "discordarás": "discordar",
    "discordarão": "discordar",
    "discordaríamos": "discordar",
    "discordaríeis": "discordar",
    "discordas": "discordar",
    "discordasse": "discordar",
    "discordassem": "discordar",
    "discordasses": "discordar",
    "discordaste": "discordar",
    "discordastes": "discordar",
    "discordava": "discordar",
    "discordavam": "discordar",
    "discordavas": "discordar",
    "discorde": "discordar",
    "discordei": "discordar",
    "discordeis": "discordar",
    "discordem": "discordar",
    "discordemo": "discordar",
    "discordemos": "discordar",
    "discordes": "discorde",
    "discordo": "discordar",
    "discordos": "discordo",
    "discordou": "discordar",
    "discordá": "discordar",
    "discordámo": "discordar",
    "discordámos": "discordar",
    "discordáramo": "discordar",
    "discordáramos": "discordar",
    "discordárei": "discordar",
    "discordáreis": "discordar",
    "discordásseis": "discordar",
    "discordássemos": "discordar",
    "discordávamo": "discordar",
    "discordávamos": "discordar",
    "discordávei": "discordar",
    "discordáveis": "discordável",
    "discordâncias": "discordância",
    "discorra": "discorrer",
    "discorrais": "discorrer",
    "discorram": "discorrer",
    "discorramo": "discorrer",
    "discorramos": "discorrer",
    "discorras": "discorrer",
    "discorre": "discorrer",
    "discorrei": "discorrer",
    "discorreis": "discorrer",
    "discorrem": "discorrer",
    "discorremo": "discorrer",
    "discorremos": "discorrer",
    "discorrendo": "discorrer",
    "discorrera": "discorrer",
    "discorreram": "discorrer",
    "discorreras": "discorrer",
    "discorrerdes": "discorrer",
    "discorrerei": "discorrer",
    "discorrereis": "discorrer",
    "discorrerem": "discorrer",
    "discorreremos": "discorrer",
    "discorreres": "discorrer",
    "discorreria": "discorrer",
    "discorreriam": "discorrer",
    "discorrerias": "discorrer",
    "discorrermo": "discorrer",
    "discorrermos": "discorrer",
    "discorrerá": "discorrer",
    "discorrerás": "discorrer",
    "discorrerão": "discorrer",
    "discorreríamos": "discorrer",
    "discorreríeis": "discorrer",
    "discorres": "discorrer",
    "discorresse": "discorrer",
    "discorressem": "discorrer",
    "discorresses": "discorrer",
    "discorreste": "discorrer",
    "discorrestes": "discorrer",
    "discorreu": "discorrer",
    "discorri": "discorrer",
    "discorria": "discorrer",
    "discorriam": "discorrer",
    "discorrias": "discorrer",
    "discorrida": "discorrer",
    "discorridas": "discorrer",
    "discorrido": "discorrer",
    "discorridos": "discorrer",
    "discorrimentos": "discorrimento",
    "discorro": "discorrer",
    "discorrências": "discorrência",
    "discorrêramo": "discorrer",
    "discorrêramos": "discorrer",
    "discorrêreis": "discorrer",
    "discorrêsseis": "discorrer",
    "discorrêssemos": "discorrer",
    "discorríamo": "discorrer",
    "discorríamos": "discorrer",
    "discorríeis": "discorrer",
    "discos": "disco",
    "discotecas": "discoteca",
    "discou": "discar",
    "discrasias": "discrasia",
    "discrepa": "discrepar",
    "discrepada": "discrepar",
    "discrepadas": "discrepar",
    "discrepado": "discrepar",
    "discrepados": "discrepar",
    "discrepai": "discrepar",
    "discrepais": "discrepar",
    "discrepam": "discrepar",
    "discrepamo": "discrepar",
    "discrepamos": "discrepar",
    "discrepando": "discrepar",
    "discrepantes": "discrepante",
    "discrepara": "discrepar",
    "discreparam": "discrepar",
    "discreparas": "discrepar",
    "discreparde": "discrepar",
    "discrepardes": "discrepar",
    "discrepare": "discrepar",
    "discreparei": "discrepar",
    "discrepareis": "discrepar",
    "discreparem": "discrepar",
    "discreparemos": "discrepar",
    "discrepares": "discrepar",
    "discreparia": "discrepar",
    "discrepariam": "discrepar",
    "discreparias": "discrepar",
    "discreparmo": "discrepar",
    "discreparmos": "discrepar",
    "discrepará": "discrepar",
    "discreparás": "discrepar",
    "discreparão": "discrepar",
    "discreparíamos": "discrepar",
    "discreparíeis": "discrepar",
    "discrepas": "discrepar",
    "discrepasse": "discrepar",
    "discrepassem": "discrepar",
    "discrepasses": "discrepar",
    "discrepaste": "discrepar",
    "discrepastes": "discrepar",
    "discrepava": "discrepar",
    "discrepavam": "discrepar",
    "discrepavas": "discrepar",
    "discrepe": "discrepar",
    "discrepei": "discrepar",
    "discrepeis": "discrepar",
    "discrepem": "discrepar",
    "discrepemo": "discrepar",
    "discrepemos": "discrepar",
    "discrepes": "discrepar",
    "discrepo": "discrepar",
    "discrepou": "discrepar",
    "discrepá": "discrepar",
    "discrepámo": "discrepar",
    "discrepámos": "discrepar",
    "discrepáramo": "discrepar",
    "discrepáramos": "discrepar",
    "discrepárei": "discrepar",
    "discrepáreis": "discrepar",
    "discrepásseis": "discrepar",
    "discrepássemos": "discrepar",
    "discrepávamo": "discrepar",
    "discrepávamos": "discrepar",
    "discrepávei": "discrepar",
    "discrepáveis": "discrepar",
    "discrepâncias": "discrepância",
    "discreta": "discreto",
    "discretas": "discreto",
    "discreteada": "discretear",
    "discreteadas": "discretear",
    "discreteado": "discretear",
    "discreteadora": "discreteador",
    "discreteadoras": "discreteador",
    "discreteadores": "discreteador",
    "discreteados": "discretear",
    "discreteai": "discretear",
    "discreteais": "discretear",
    "discreteamo": "discretear",
    "discreteamos": "discretear",
    "discreteando": "discretear",
    "discreteara": "discretear",
    "discretearam": "discretear",
    "discretearas": "discretear",
    "discretearde": "discretear",
    "discreteardes": "discretear",
    "discreteare": "discretear",
    "discretearei": "discretear",
    "discreteareis": "discretear",
    "discretearem": "discretear",
    "discretearemos": "discretear",
    "discreteares": "discretear",
    "discretearia": "discretear",
    "discreteariam": "discretear",
    "discretearias": "discretear",
    "discretearmo": "discretear",
    "discretearmos": "discretear",
    "discreteará": "discretear",
    "discretearás": "discretear",
    "discretearão": "discretear",
    "discretearíamos": "discretear",
    "discretearíeis": "discretear",
    "discreteasse": "discretear",
    "discreteassem": "discretear",
    "discreteasses": "discretear",
    "discreteaste": "discretear",
    "discreteastes": "discretear",
    "discreteava": "discretear",
    "discreteavam": "discretear",
    "discreteavas": "discretear",
    "discreteei": "discretear",
    "discreteeis": "discretear",
    "discreteemo": "discretear",
    "discreteemos": "discretear",
    "discreteia": "discretear",
    "discreteiam": "discretear",
    "discreteias": "discretear",
    "discreteie": "discretear",
    "discreteiem": "discretear",
    "discreteies": "discretear",
    "discreteio": "discretear",
    "discreteou": "discretear",
    "discreteá": "discretear",
    "discreteámo": "discretear",
    "discreteámos": "discretear",
    "discreteáramo": "discretear",
    "discreteáramos": "discretear",
    "discreteárei": "discretear",
    "discreteáreis": "discretear",
    "discreteásseis": "discretear",
    "discreteássemos": "discretear",
    "discreteávamo": "discretear",
    "discreteávamos": "discretear",
    "discreteávei": "discretear",
    "discreteáveis": "discretear",
    "discretiva": "discretivo",
    "discretivas": "discretivo",
    "discretivos": "discretivo",
    "discretos": "discreto",
    "discretíssima": "discreto",
    "discretíssimas": "discreto",
    "discretíssimo": "discreto",
    "discretíssimos": "discreto",
    "discretórios": "discretório",
    "discricionais": "discricional",
    "discricionariedades": "discricionariedade",
    "discricionária": "discricionário",
    "discricionárias": "discricionário",
    "discricionários": "discricionário",
    "discrimes": "discrime",
    "discrimina": "discriminar",
    "discriminada": "discriminar",
    "discriminadas": "discriminar",
    "discriminado": "discriminar",
    "discriminadora": "discriminador",
    "discriminadoras": "discriminador",
    "discriminadores": "discriminador",
    "discriminados": "discriminar",
    "discriminai": "discriminar",
    "discriminais": "discriminar",
    "discriminam": "discriminar",
    "discriminamo": "discriminar",
    "discriminamos": "discriminar",
    "discriminando": "discriminar",
    "discriminantes": "discriminante",
    "discriminara": "discriminar",
    "discriminaram": "discriminar",
    "discriminaras": "discriminar",
    "discriminarde": "discriminar",
    "discriminardes": "discriminar",
    "discriminare": "discriminar",
    "discriminarei": "discriminar",
    "discriminareis": "discriminar",
    "discriminarem": "discriminar",
    "discriminaremos": "discriminar",
    "discriminares": "discriminar",
    "discriminaria": "discriminar",
    "discriminariam": "discriminar",
    "discriminarias": "discriminar",
    "discriminarmo": "discriminar",
    "discriminarmos": "discriminar",
    "discriminará": "discriminar",
    "discriminarás": "discriminar",
    "discriminarão": "discriminar",
    "discriminaríamos": "discriminar",
    "discriminaríeis": "discriminar",
    "discriminas": "discriminar",
    "discriminasse": "discriminar",
    "discriminassem": "discriminar",
    "discriminasses": "discriminar",
    "discriminaste": "discriminar",
    "discriminastes": "discriminar",
    "discriminativa": "discriminativo",
    "discriminativas": "discriminativo",
    "discriminativos": "discriminativo",
    "discriminatória": "discriminatório",
    "discriminatórias": "discriminatório",
    "discriminatórios": "discriminatório",
    "discriminava": "discriminar",
    "discriminavam": "discriminar",
    "discriminavas": "discriminar",
    "discriminações": "discriminação",
    "discrimine": "discriminar",
    "discriminei": "discriminar",
    "discrimineis": "discriminar",
    "discriminem": "discriminar",
    "discriminemo": "discriminar",
    "discriminemos": "discriminar",
    "discrimines": "discriminar",
    "discrimino": "discriminar",
    "discriminou": "discriminar",
    "discriminá": "discriminar",
    "discriminámo": "discriminar",
    "discriminámos": "discriminar",
    "discrimináramo": "discriminar",
    "discrimináramos": "discriminar",
    "discriminárei": "discriminar",
    "discrimináreis": "discriminar",
    "discriminásseis": "discriminar",
    "discriminássemos": "discriminar",
    "discriminávamo": "discriminar",
    "discriminávamos": "discriminar",
    "discriminávei": "discriminar",
    "discrimináveis": "discriminável",
    "discrições": "discrição",
    "discriões": "discrião",
    "discromatismos": "discromatismo",
    "discromatopsias": "discromatopsia",
    "discromias": "discromia",
    "discromática": "discromático",
    "discromáticas": "discromático",
    "discromáticos": "discromático",
    "discrásica": "discrásico",
    "discrásicas": "discrásico",
    "discrásicos": "discrásico",
    "discrímenes": "discrímen",
    "discursa": "discursar",
    "discursada": "discursar",
    "discursadas": "discursar",
    "discursado": "discursar",
    "discursadora": "discursador",
    "discursadoras": "discursador",
    "discursadores": "discursador",
    "discursados": "discursar",
    "discursai": "discursar",
    "discursais": "discursar",
    "discursam": "discursar",
    "discursamo": "discursar",
    "discursamos": "discursar",
    "discursando": "discursar",
    "discursara": "discursar",
    "discursaram": "discursar",
    "discursaras": "discursar",
    "discursardes": "discursar",
    "discursarei": "discursar",
    "discursareis": "discursar",
    "discursarem": "discursar",
    "discursaremos": "discursar",
    "discursares": "discursar",
    "discursaria": "discursar",
    "discursariam": "discursar",
    "discursarias": "discursar",
    "discursarmo": "discursar",
    "discursarmos": "discursar",
    "discursará": "discursar",
    "discursarás": "discursar",
    "discursarão": "discursar",
    "discursaríamos": "discursar",
    "discursaríeis": "discursar",
    "discursas": "discursar",
    "discursasse": "discursar",
    "discursassem": "discursar",
    "discursasses": "discursar",
    "discursaste": "discursar",
    "discursastes": "discursar",
    "discursatas": "discursata",
    "discursava": "discursar",
    "discursavam": "discursar",
    "discursavas": "discursar",
    "discurse": "discursar",
    "discursei": "discursar",
    "discurseis": "discursar",
    "discursem": "discursar",
    "discursemo": "discursar",
    "discursemos": "discursar",
    "discurses": "discursar",
    "discursistas": "discursista",
    "discursiva": "discursivo",
    "discursivas": "discursivo",
    "discursivos": "discursivo",
    "discurso": "discursar",
    "discursos": "discurso",
    "discursou": "discursar",
    "discursámo": "discursar",
    "discursámos": "discursar",
    "discursáramo": "discursar",
    "discursáramos": "discursar",
    "discursáreis": "discursar",
    "discursásseis": "discursar",
    "discursássemos": "discursar",
    "discursávamo": "discursar",
    "discursávamos": "discursar",
    "discursáveis": "discursar",
    "discussões": "discussão",
    "discuta": "discutir",
    "discutais": "discutir",
    "discutam": "discutir",
    "discutamo": "discutir",
    "discutamos": "discutir",
    "discutas": "discutir",
    "discute": "discutir",
    "discutem": "discutir",
    "discutes": "discutir",
    "discuti": "discutir",
    "discutia": "discutir",
    "discutiam": "discutir",
    "discutias": "discutir",
    "discutida": "discutir",
    "discutidas": "discutir",
    "discutido": "discutir",
    "discutidora": "discutidor",
    "discutidoras": "discutidor",
    "discutidores": "discutidor",
    "discutidos": "discutir",
    "discutidíssima": "discutido",
    "discutidíssimas": "discutido",
    "discutidíssimo": "discutido",
    "discutidíssimos": "discutido",
    "discutimo": "discutir",
    "discutimos": "discutir",
    "discutindo": "discutir",
    "discutira": "discutir",
    "discutiram": "discutir",
    "discutiras": "discutir",
    "discutirde": "discutir",
    "discutirdes": "discutir",
    "discutire": "discutir",
    "discutirei": "discutir",
    "discutireis": "discutir",
    "discutirem": "discutir",
    "discutiremos": "discutir",
    "discutires": "discutir",
    "discutiria": "discutir",
    "discutiriam": "discutir",
    "discutirias": "discutir",
    "discutirmo": "discutir",
    "discutirmos": "discutir",
    "discutirá": "discutir",
    "discutirás": "discutir",
    "discutirão": "discutir",
    "discutiríamos": "discutir",
    "discutiríeis": "discutir",
    "discutis": "discutir",
    "discutisse": "discutir",
    "discutissem": "discutir",
    "discutisses": "discutir",
    "discutiste": "discutir",
    "discutistes": "discutir",
    "discutiu": "discutir",
    "discuto": "discutir",
    "discutíamo": "discutir",
    "discutíamos": "discutir",
    "discutíei": "discutir",
    "discutíeis": "discutir",
    "discutíramo": "discutir",
    "discutíramos": "discutir",
    "discutírei": "discutir",
    "discutíreis": "discutir",
    "discutísseis": "discutir",
    "discutíssemos": "discutir",
    "discutíveis": "discutível",
    "discá": "discar",
    "discámo": "discar",
    "discámos": "discar",
    "discáramo": "discar",
    "discáramos": "discar",
    "discárei": "discar",
    "discáreis": "discar",
    "discásseis": "discar",
    "discássemos": "discar",
    "discávamo": "discar",
    "discávamos": "discar",
    "discávei": "discar",
    "discáveis": "discável",
    "discências": "discência",
    "discífera": "discífero",
    "discíferas": "discífero",
    "discíferos": "discífero",
    "discípula": "discípulo",
    "discípulas": "discípulo",
    "discípulos": "discípulo",
    "discóbolos": "discóbolo",
    "discófila": "discófilo",
    "discófilas": "discófilo",
    "discófilos": "discófilo",
    "discóides": "discóide",
    "discórdias": "discórdia",
    "disemias": "disemia",
    "disenterias": "disenteria",
    "disentérica": "disentérico",
    "disentéricas": "disentérico",
    "disentéricos": "disentérico",
    "diserta": "diserto",
    "disertas": "diserto",
    "disertos": "diserto",
    "disestesias": "disestesia",
    "disfagias": "disfagia",
    "disfarce": "disfarçar",
    "disfarcei": "disfarçar",
    "disfarceis": "disfarçar",
    "disfarcem": "disfarçar",
    "disfarcemo": "disfarçar",
    "disfarcemos": "disfarçar",
    "disfarces": "disfarce",
    "disfarça": "disfarçar",
    "disfarçada": "disfarçar",
    "disfarçadas": "disfarçar",
    "disfarçado": "disfarçar",
    "disfarçados": "disfarçar",
    "disfarçadíssima": "disfarçado",
    "disfarçadíssimas": "disfarçado",
    "disfarçadíssimo": "disfarçado",
    "disfarçadíssimos": "disfarçado",
    "disfarçai": "disfarçar",
    "disfarçais": "disfarçar",
    "disfarçam": "disfarçar",
    "disfarçamo": "disfarçar",
    "disfarçamos": "disfarçar",
    "disfarçando": "disfarçar",
    "disfarçara": "disfarçar",
    "disfarçaram": "disfarçar",
    "disfarçaras": "disfarçar",
    "disfarçarde": "disfarçar",
    "disfarçardes": "disfarçar",
    "disfarçare": "disfarçar",
    "disfarçarei": "disfarçar",
    "disfarçareis": "disfarçar",
    "disfarçarem": "disfarçar",
    "disfarçaremos": "disfarçar",
    "disfarçares": "disfarçar",
    "disfarçaria": "disfarçar",
    "disfarçariam": "disfarçar",
    "disfarçarias": "disfarçar",
    "disfarçarmo": "disfarçar",
    "disfarçarmos": "disfarçar",
    "disfarçará": "disfarçar",
    "disfarçarás": "disfarçar",
    "disfarçarão": "disfarçar",
    "disfarçaríamos": "disfarçar",
    "disfarçaríeis": "disfarçar",
    "disfarças": "disfarçar",
    "disfarçasse": "disfarçar",
    "disfarçassem": "disfarçar",
    "disfarçasses": "disfarçar",
    "disfarçaste": "disfarçar",
    "disfarçastes": "disfarçar",
    "disfarçava": "disfarçar",
    "disfarçavam": "disfarçar",
    "disfarçavas": "disfarçar",
    "disfarço": "disfarçar",
    "disfarçou": "disfarçar",
    "disfarçá": "disfarçar",
    "disfarçámo": "disfarçar",
    "disfarçámos": "disfarçar",
    "disfarçáramo": "disfarçar",
    "disfarçáramos": "disfarçar",
    "disfarçárei": "disfarçar",
    "disfarçáreis": "disfarçar",
    "disfarçásseis": "disfarçar",
    "disfarçássemos": "disfarçar",
    "disfarçávamo": "disfarçar",
    "disfarçávamos": "disfarçar",
    "disfarçávei": "disfarçar",
    "disfarçáveis": "disfarçável",
    "disfasias": "disfasia",
    "disfere": "disferir",
    "disferem": "disferir",
    "disferes": "disferir",
    "disferi": "disferir",
    "disferia": "disferir",
    "disferiam": "disferir",
    "disferias": "disferir",
    "disferida": "disferir",
    "disferidas": "disferir",
    "disferido": "disferir",
    "disferidos": "disferir",
    "disferimo": "disferir",
    "disferimos": "disferir",
    "disferindo": "disferir",
    "disferira": "disferir",
    "disferiram": "disferir",
    "disferiras": "disferir",
    "disferirde": "disferir",
    "disferirdes": "disferir",
    "disferire": "disferir",
    "disferirei": "disferir",
    "disferireis": "disferir",
    "disferirem": "disferir",
    "disferiremos": "disferir",
    "disferires": "disferir",
    "disferiria": "disferir",
    "disfeririam": "disferir",
    "disferirias": "disferir",
    "disferirmo": "disferir",
    "disferirmos": "disferir",
    "disferirá": "disferir",
    "disferirás": "disferir",
    "disferirão": "disferir",
    "disferiríamos": "disferir",
    "disferiríeis": "disferir",
    "disferis": "disferir",
    "disferisse": "disferir",
    "disferissem": "disferir",
    "disferisses": "disferir",
    "disferiste": "disferir",
    "disferistes": "disferir",
    "disferiu": "disferir",
    "disferíamo": "disferir",
    "disferíamos": "disferir",
    "disferíei": "disferir",
    "disferíeis": "disferir",
    "disferíramo": "disferir",
    "disferíramos": "disferir",
    "disferírei": "disferir",
    "disferíreis": "disferir",
    "disferísseis": "disferir",
    "disferíssemos": "disferir",
    "disferíveis": "disferível",
    "disfira": "disferir",
    "disfirais": "disferir",
    "disfiram": "disferir",
    "disfiramo": "disferir",
    "disfiramos": "disferir",
    "disfiras": "disferir",
    "disfiro": "disferir",
    "disfonias": "disfonia",
    "disforias": "disforia",
    "disforma": "disformar",
    "disformada": "disformar",
    "disformadas": "disformar",
    "disformado": "disformar",
    "disformados": "disformar",
    "disformai": "disformar",
    "disformais": "disformar",
    "disformam": "disformar",
    "disformamo": "disformar",
    "disformamos": "disformar",
    "disformando": "disformar",
    "disformara": "disformar",
    "disformaram": "disformar",
    "disformaras": "disformar",
    "disformarde": "disformar",
    "disformardes": "disformar",
    "disformare": "disformar",
    "disformarei": "disformar",
    "disformareis": "disformar",
    "disformarem": "disformar",
    "disformaremos": "disformar",
    "disformares": "disformar",
    "disformaria": "disformar",
    "disformariam": "disformar",
    "disformarias": "disformar",
    "disformarmo": "disformar",
    "disformarmos": "disformar",
    "disformará": "disformar",
    "disformarás": "disformar",
    "disformarão": "disformar",
    "disformaríamos": "disformar",
    "disformaríeis": "disformar",
    "disformas": "disformar",
    "disformasse": "disformar",
    "disformassem": "disformar",
    "disformasses": "disformar",
    "disformaste": "disformar",
    "disformastes": "disformar",
    "disformava": "disformar",
    "disformavam": "disformar",
    "disformavas": "disformar",
    "disforme": "disformar",
    "disformei": "disformar",
    "disformeis": "disformar",
    "disformem": "disformar",
    "disformemo": "disformar",
    "disformemos": "disformar",
    "disformes": "disforme",
    "disformidades": "disformidade",
    "disformo": "disformar",
    "disformou": "disformar",
    "disformá": "disformar",
    "disformámo": "disformar",
    "disformámos": "disformar",
    "disformáramo": "disformar",
    "disformáramos": "disformar",
    "disformárei": "disformar",
    "disformáreis": "disformar",
    "disformásseis": "disformar",
    "disformássemos": "disformar",
    "disformávamo": "disformar",
    "disformávamos": "disformar",
    "disformávei": "disformar",
    "disformáveis": "disformar",
    "disfruta": "disfrutar",
    "disfrutada": "disfrutar",
    "disfrutadas": "disfrutar",
    "disfrutado": "disfrutar",
    "disfrutados": "disfrutar",
    "disfrutai": "disfrutar",
    "disfrutais": "disfrutar",
    "disfrutam": "disfrutar",
    "disfrutamo": "disfrutar",
    "disfrutamos": "disfrutar",
    "disfrutando": "disfrutar",
    "disfrutara": "disfrutar",
    "disfrutaram": "disfrutar",
    "disfrutaras": "disfrutar",
    "disfrutarde": "disfrutar",
    "disfrutardes": "disfrutar",
    "disfrutare": "disfrutar",
    "disfrutarei": "disfrutar",
    "disfrutareis": "disfrutar",
    "disfrutarem": "disfrutar",
    "disfrutaremos": "disfrutar",
    "disfrutares": "disfrutar",
    "disfrutaria": "disfrutar",
    "disfrutariam": "disfrutar",
    "disfrutarias": "disfrutar",
    "disfrutarmo": "disfrutar",
    "disfrutarmos": "disfrutar",
    "disfrutará": "disfrutar",
    "disfrutarás": "disfrutar",
    "disfrutarão": "disfrutar",
    "disfrutaríamos": "disfrutar",
    "disfrutaríeis": "disfrutar",
    "disfrutas": "disfrutar",
    "disfrutasse": "disfrutar",
    "disfrutassem": "disfrutar",
    "disfrutasses": "disfrutar",
    "disfrutaste": "disfrutar",
    "disfrutastes": "disfrutar",
    "disfrutava": "disfrutar",
    "disfrutavam": "disfrutar",
    "disfrutavas": "disfrutar",
    "disfrute": "disfrutar",
    "disfrutei": "disfrutar",
    "disfruteis": "disfrutar",
    "disfrutem": "disfrutar",
    "disfrutemo": "disfrutar",
    "disfrutemos": "disfrutar",
    "disfrutes": "disfrutar",
    "disfruto": "disfrutar",
    "disfrutou": "disfrutar",
    "disfrutá": "disfrutar",
    "disfrutámo": "disfrutar",
    "disfrutámos": "disfrutar",
    "disfrutáramo": "disfrutar",
    "disfrutáramos": "disfrutar",
    "disfrutárei": "disfrutar",
    "disfrutáreis": "disfrutar",
    "disfrutásseis": "disfrutar",
    "disfrutássemos": "disfrutar",
    "disfrutávamo": "disfrutar",
    "disfrutávamos": "disfrutar",
    "disfrutávei": "disfrutar",
    "disfrutáveis": "disfrutar",
    "disfuncionais": "disfuncional",
    "disfuncionalidades": "disfuncionalidade",
    "disfunções": "disfunção",
    "disfónica": "disfónico",
    "disfónicas": "disfónico",
    "disfónicos": "disfónico",
    "disgenesias": "disgenesia",
    "disgenética": "disgenético",
    "disgenéticas": "disgenético",
    "disgenéticos": "disgenético",
    "disgnosias": "disgnosia",
    "disgrafias": "disgrafia",
    "disidrias": "disidria",
    "disidroses": "disidrose",
    "disjunge": "disjungir",
    "disjungem": "disjungir",
    "disjunges": "disjungir",
    "disjungi": "disjungir",
    "disjungia": "disjungir",
    "disjungiam": "disjungir",
    "disjungias": "disjungir",
    "disjungida": "disjungir",
    "disjungidas": "disjungir",
    "disjungido": "disjungir",
    "disjungidos": "disjungir",
    "disjungimo": "disjungir",
    "disjungimos": "disjungir",
    "disjungindo": "disjungir",
    "disjungira": "disjungir",
    "disjungiram": "disjungir",
    "disjungiras": "disjungir",
    "disjungirde": "disjungir",
    "disjungirdes": "disjungir",
    "disjungire": "disjungir",
    "disjungirei": "disjungir",
    "disjungireis": "disjungir",
    "disjungirem": "disjungir",
    "disjungiremos": "disjungir",
    "disjungires": "disjungir",
    "disjungiria": "disjungir",
    "disjungiriam": "disjungir",
    "disjungirias": "disjungir",
    "disjungirmo": "disjungir",
    "disjungirmos": "disjungir",
    "disjungirá": "disjungir",
    "disjungirás": "disjungir",
    "disjungirão": "disjungir",
    "disjungiríamos": "disjungir",
    "disjungiríeis": "disjungir",
    "disjungis": "disjungir",
    "disjungisse": "disjungir",
    "disjungissem": "disjungir",
    "disjungisses": "disjungir",
    "disjungiste": "disjungir",
    "disjungistes": "disjungir",
    "disjungiu": "disjungir",
    "disjungíamo": "disjungir",
    "disjungíamos": "disjungir",
    "disjungíei": "disjungir",
    "disjungíeis": "disjungir",
    "disjungíramo": "disjungir",
    "disjungíramos": "disjungir",
    "disjungírei": "disjungir",
    "disjungíreis": "disjungir",
    "disjungísseis": "disjungir",
    "disjungíssemos": "disjungir",
    "disjunja": "disjungir",
    "disjunjais": "disjungir",
    "disjunjam": "disjungir",
    "disjunjamo": "disjungir",
    "disjunjamos": "disjungir",
    "disjunjas": "disjungir",
    "disjunjo": "disjungir",
    "disjunta": "disjunto",
    "disjuntada": "disjuntar",
    "disjuntadas": "disjuntar",
    "disjuntado": "disjuntar",
    "disjuntados": "disjuntar",
    "disjuntai": "disjuntar",
    "disjuntais": "disjuntar",
    "disjuntam": "disjuntar",
    "disjuntamo": "disjuntar",
    "disjuntamos": "disjuntar",
    "disjuntando": "disjuntar",
    "disjuntara": "disjuntar",
    "disjuntaram": "disjuntar",
    "disjuntaras": "disjuntar",
    "disjuntarde": "disjuntar",
    "disjuntardes": "disjuntar",
    "disjuntare": "disjuntar",
    "disjuntarei": "disjuntar",
    "disjuntareis": "disjuntar",
    "disjuntarem": "disjuntar",
    "disjuntaremos": "disjuntar",
    "disjuntares": "disjuntar",
    "disjuntaria": "disjuntar",
    "disjuntariam": "disjuntar",
    "disjuntarias": "disjuntar",
    "disjuntarmo": "disjuntar",
    "disjuntarmos": "disjuntar",
    "disjuntará": "disjuntar",
    "disjuntarás": "disjuntar",
    "disjuntarão": "disjuntar",
    "disjuntaríamos": "disjuntar",
    "disjuntaríeis": "disjuntar",
    "disjuntas": "disjunto",
    "disjuntasse": "disjuntar",
    "disjuntassem": "disjuntar",
    "disjuntasses": "disjuntar",
    "disjuntaste": "disjuntar",
    "disjuntastes": "disjuntar",
    "disjuntava": "disjuntar",
    "disjuntavam": "disjuntar",
    "disjuntavas": "disjuntar",
    "disjunte": "disjuntar",
    "disjuntei": "disjuntar",
    "disjunteis": "disjuntar",
    "disjuntem": "disjuntar",
    "disjuntemo": "disjuntar",
    "disjuntemos": "disjuntar",
    "disjuntes": "disjuntar",
    "disjuntiva": "disjuntivo",
    "disjuntivas": "disjuntivo",
    "disjuntivos": "disjuntivo",
    "disjunto": "disjuntar",
    "disjuntores": "disjuntor",
    "disjuntos": "disjunto",
    "disjuntou": "disjuntar",
    "disjuntá": "disjuntar",
    "disjuntámo": "disjuntar",
    "disjuntámos": "disjuntar",
    "disjuntáramo": "disjuntar",
    "disjuntáramos": "disjuntar",
    "disjuntárei": "disjuntar",
    "disjuntáreis": "disjuntar",
    "disjuntásseis": "disjuntar",
    "disjuntássemos": "disjuntar",
    "disjuntávamo": "disjuntar",
    "disjuntávamos": "disjuntar",
    "disjuntávei": "disjuntar",
    "disjuntáveis": "disjuntar",
    "disjunções": "disjunção",
    "dislalias": "dislalia",
    "dislates": "dislate",
    "dislexias": "dislexia",
    "dislogias": "dislogia",
    "disléxica": "disléxico",
    "disléxicas": "disléxico",
    "disléxicos": "disléxico",
    "dismenias": "dismenia",
    "dismenorreias": "dismenorreia",
    "dismenorreica": "dismenorreico",
    "dismenorreicas": "dismenorreico",
    "dismenorreicos": "dismenorreico",
    "dismetrias": "dismetria",
    "dismnésias": "dismnésia",
    "dismorfa": "dismorfo",
    "dismorfas": "dismorfo",
    "dismorfias": "dismorfia",
    "dismorfopsias": "dismorfopsia",
    "dismorfos": "dismorfo",
    "dismorfoses": "dismorfose",
    "disnas": "disna",
    "disnervada": "disnervado",
    "disnervadas": "disnervado",
    "disnervados": "disnervado",
    "disnusias": "disnusia",
    "disodias": "disodia",
    "disopias": "disopia",
    "disorexias": "disorexia",
    "disortografias": "disortografia",
    "disosmias": "disosmia",
    "dispa": "despir",
    "dispais": "despir",
    "dispam": "despir",
    "dispamo": "despir",
    "dispamos": "despir",
    "dispara": "disparar",
    "disparada": "disparar",
    "disparadas": "disparar",
    "disparado": "disparar",
    "disparadores": "disparador",
    "disparados": "disparar",
    "disparai": "disparar",
    "disparais": "disparar",
    "disparam": "disparar",
    "disparamo": "disparar",
    "disparamos": "disparar",
    "disparando": "disparar",
    "disparara": "disparar",
    "dispararam": "disparar",
    "dispararas": "disparar",
    "dispararde": "disparar",
    "disparardes": "disparar",
    "disparare": "disparar",
    "dispararei": "disparar",
    "disparareis": "disparar",
    "dispararem": "disparar",
    "dispararemos": "disparar",
    "disparares": "disparar",
    "dispararia": "disparar",
    "disparariam": "disparar",
    "dispararias": "disparar",
    "dispararmo": "disparar",
    "dispararmos": "disparar",
    "disparará": "disparar",
    "dispararás": "disparar",
    "dispararão": "disparar",
    "dispararíamos": "disparar",
    "dispararíeis": "disparar",
    "disparas": "disparar",
    "disparasse": "disparar",
    "disparassem": "disparar",
    "disparasses": "disparar",
    "disparaste": "disparar",
    "disparastes": "disparar",
    "disparata": "disparatar",
    "disparatada": "disparatar",
    "disparatadas": "disparatar",
    "disparatado": "disparatar",
    "disparatados": "disparatar",
    "disparatai": "disparatar",
    "disparatais": "disparatar",
    "disparatam": "disparatar",
    "disparatamo": "disparatar",
    "disparatamos": "disparatar",
    "disparatando": "disparatar",
    "disparatara": "disparatar",
    "disparataram": "disparatar",
    "disparataras": "disparatar",
    "disparatardes": "disparatar",
    "disparatarei": "disparatar",
    "disparatareis": "disparatar",
    "disparatarem": "disparatar",
    "disparataremos": "disparatar",
    "disparatares": "disparatar",
    "disparataria": "disparatar",
    "disparatariam": "disparatar",
    "disparatarias": "disparatar",
    "disparatarmo": "disparatar",
    "disparatarmos": "disparatar",
    "disparatará": "disparatar",
    "disparatarás": "disparatar",
    "disparatarão": "disparatar",
    "disparataríamos": "disparatar",
    "disparataríeis": "disparatar",
    "disparatas": "disparatar",
    "disparatasse": "disparatar",
    "disparatassem": "disparatar",
    "disparatasses": "disparatar",
    "disparataste": "disparatar",
    "disparatastes": "disparatar",
    "disparatava": "disparatar",
    "disparatavam": "disparatar",
    "disparatavas": "disparatar",
    "disparate": "disparatar",
    "disparatei": "disparatar",
    "disparateis": "disparatar",
    "disparatem": "disparatar",
    "disparatemo": "disparatar",
    "disparatemos": "disparatar",
    "disparates": "disparate",
    "disparato": "disparatar",
    "disparatou": "disparatar",
    "disparatámo": "disparatar",
    "disparatámos": "disparatar",
    "disparatáramo": "disparatar",
    "disparatáramos": "disparatar",
    "disparatáreis": "disparatar",
    "disparatásseis": "disparatar",
    "disparatássemos": "disparatar",
    "disparatávamo": "disparatar",
    "disparatávamos": "disparatar",
    "disparatáveis": "disparatar",
    "disparava": "disparar",
    "disparavam": "disparar",
    "disparavas": "disparar",
    "dispare": "disparar",
    "disparei": "disparar",
    "dispareis": "disparar",
    "disparem": "disparar",
    "disparemo": "disparar",
    "disparemos": "disparar",
    "dispares": "disparar",
    "disparidades": "disparidade",
    "disparo": "disparar",
    "disparos": "disparo",
    "disparou": "disparar",
    "disparta": "dispartir",
    "dispartais": "dispartir",
    "dispartam": "dispartir",
    "dispartamo": "dispartir",
    "dispartamos": "dispartir",
    "dispartas": "dispartir",
    "disparte": "dispartir",
    "dispartem": "dispartir",
    "dispartes": "dispartir",
    "disparti": "dispartir",
    "dispartia": "dispartir",
    "dispartiam": "dispartir",
    "dispartias": "dispartir",
    "dispartida": "dispartir",
    "dispartidas": "dispartir",
    "dispartido": "dispartir",
    "dispartidos": "dispartir",
    "dispartimo": "dispartir",
    "dispartimos": "dispartir",
    "dispartindo": "dispartir",
    "dispartira": "dispartir",
    "dispartiram": "dispartir",
    "dispartiras": "dispartir",
    "dispartirde": "dispartir",
    "dispartirdes": "dispartir",
    "dispartire": "dispartir",
    "dispartirei": "dispartir",
    "dispartireis": "dispartir",
    "dispartirem": "dispartir",
    "dispartiremos": "dispartir",
    "dispartires": "dispartir",
    "dispartiria": "dispartir",
    "dispartiriam": "dispartir",
    "dispartirias": "dispartir",
    "dispartirmo": "dispartir",
    "dispartirmos": "dispartir",
    "dispartirá": "dispartir",
    "dispartirás": "dispartir",
    "dispartirão": "dispartir",
    "dispartiríamos": "dispartir",
    "dispartiríeis": "dispartir",
    "dispartis": "dispartir",
    "dispartisse": "dispartir",
    "dispartissem": "dispartir",
    "dispartisses": "dispartir",
    "dispartiste": "dispartir",
    "dispartistes": "dispartir",
    "dispartiu": "dispartir",
    "disparto": "dispartir",
    "dispartíamo": "dispartir",
    "dispartíamos": "dispartir",
    "dispartíei": "dispartir",
    "dispartíeis": "dispartir",
    "dispartíramo": "dispartir",
    "dispartíramos": "dispartir",
    "dispartírei": "dispartir",
    "dispartíreis": "dispartir",
    "dispartísseis": "dispartir",
    "dispartíssemos": "dispartir",
    "dispará": "disparar",
    "disparámo": "disparar",
    "disparámos": "disparar",
    "disparáramo": "disparar",
    "disparáramos": "disparar",
    "disparárei": "disparar",
    "disparáreis": "disparar",
    "disparásseis": "disparar",
    "disparássemos": "disparar",
    "disparávamo": "disparar",
    "disparávamos": "disparar",
    "disparávei": "disparar",
    "disparáveis": "disparável",
    "dispas": "despir",
    "dispendida": "dispendido",
    "dispendidas": "dispendido",
    "dispendidos": "dispendido",
    "dispendiosa": "dispendioso",
    "dispendiosas": "dispendioso",
    "dispendiosos": "dispendioso",
    "dispensa": "dispensar",
    "dispensabilidades": "dispensabilidade",
    "dispensada": "dispensar",
    "dispensadas": "dispensar",
    "dispensado": "dispensar",
    "dispensadora": "dispensador",
    "dispensadoras": "dispensador",
    "dispensadores": "dispensador",
    "dispensados": "dispensar",
    "dispensai": "dispensar",
    "dispensais": "dispensar",
    "dispensam": "dispensar",
    "dispensamo": "dispensar",
    "dispensamos": "dispensar",
    "dispensando": "dispensar",
    "dispensara": "dispensar",
    "dispensaram": "dispensar",
    "dispensaras": "dispensar",
    "dispensarde": "dispensar",
    "dispensardes": "dispensar",
    "dispensare": "dispensar",
    "dispensarei": "dispensar",
    "dispensareis": "dispensar",
    "dispensarem": "dispensar",
    "dispensaremos": "dispensar",
    "dispensares": "dispensar",
    "dispensaria": "dispensar",
    "dispensariam": "dispensar",
    "dispensarias": "dispensar",
    "dispensarmo": "dispensar",
    "dispensarmos": "dispensar",
    "dispensará": "dispensar",
    "dispensarás": "dispensar",
    "dispensarão": "dispensar",
    "dispensaríamos": "dispensar",
    "dispensaríeis": "dispensar",
    "dispensas": "dispensar",
    "dispensasse": "dispensar",
    "dispensassem": "dispensar",
    "dispensasses": "dispensar",
    "dispensaste": "dispensar",
    "dispensastes": "dispensar",
    "dispensativa": "dispensativo",
    "dispensativas": "dispensativo",
    "dispensativos": "dispensativo",
    "dispensatária": "dispensatário",
    "dispensatárias": "dispensatário",
    "dispensatários": "dispensatário",
    "dispensatória": "dispensatório",
    "dispensatórias": "dispensatório",
    "dispensatórios": "dispensatório",
    "dispensava": "dispensar",
    "dispensavam": "dispensar",
    "dispensavas": "dispensar",
    "dispensações": "dispensação",
    "dispense": "dispensar",
    "dispensei": "dispensar",
    "dispenseis": "dispensar",
    "dispensem": "dispensar",
    "dispensemo": "dispensar",
    "dispensemos": "dispensar",
    "dispenses": "dispensar",
    "dispenso": "dispensar",
    "dispensou": "dispensar",
    "dispensá": "dispensar",
    "dispensámo": "dispensar",
    "dispensámos": "dispensar",
    "dispensáramo": "dispensar",
    "dispensáramos": "dispensar",
    "dispensárei": "dispensar",
    "dispensáreis": "dispensar",
    "dispensários": "dispensário",
    "dispensásseis": "dispensar",
    "dispensássemos": "dispensar",
    "dispensávamo": "dispensar",
    "dispensávamos": "dispensar",
    "dispensávei": "dispensar",
    "dispensáveis": "dispensável",
    "dispepsias": "dispepsia",
    "disperca": "disperder",
    "dispercais": "disperder",
    "dispercam": "disperder",
    "dispercamo": "disperder",
    "dispercamos": "disperder",
    "dispercas": "disperder",
    "disperco": "disperder",
    "disperde": "disperder",
    "disperdei": "disperder",
    "disperdeis": "disperder",
    "disperdem": "disperder",
    "disperdemo": "disperder",
    "disperdemos": "disperder",
    "disperdendo": "disperder",
    "disperdera": "disperder",
    "disperderam": "disperder",
    "disperderas": "disperder",
    "disperderde": "disperder",
    "disperderdes": "disperder",
    "disperdere": "disperder",
    "disperderei": "disperder",
    "disperdereis": "disperder",
    "disperderem": "disperder",
    "disperderemos": "disperder",
    "disperderes": "disperder",
    "disperderia": "disperder",
    "disperderiam": "disperder",
    "disperderias": "disperder",
    "disperdermo": "disperder",
    "disperdermos": "disperder",
    "disperderá": "disperder",
    "disperderás": "disperder",
    "disperderão": "disperder",
    "disperderíamos": "disperder",
    "disperderíeis": "disperder",
    "disperdes": "disperder",
    "disperdesse": "disperder",
    "disperdessem": "disperder",
    "disperdesses": "disperder",
    "disperdeste": "disperder",
    "disperdestes": "disperder",
    "disperdeu": "disperder",
    "disperdi": "disperder",
    "disperdia": "disperder",
    "disperdiam": "disperder",
    "disperdias": "disperder",
    "disperdida": "disperder",
    "disperdidas": "disperder",
    "disperdido": "disperder",
    "disperdidos": "disperder",
    "disperdê": "disperder",
    "disperdêramo": "disperder",
    "disperdêramos": "disperder",
    "disperdêrei": "disperder",
    "disperdêreis": "disperder",
    "disperdêsseis": "disperder",
    "disperdêssemos": "disperder",
    "disperdíamo": "disperder",
    "disperdíamos": "disperder",
    "disperdíei": "disperder",
    "disperdíeis": "disperder",
    "disperma": "dispermo",
    "dispermas": "dispermo",
    "dispermias": "dispermia",
    "dispermos": "dispermo",
    "dispermática": "dispermático",
    "dispermáticas": "dispermático",
    "dispermáticos": "dispermático",
    "dispersa": "disperso",
    "dispersada": "dispersar",
    "dispersadas": "dispersar",
    "dispersado": "dispersar",
    "dispersados": "dispersar",
    "dispersai": "dispersar",
    "dispersais": "dispersar",
    "dispersam": "dispersar",
    "dispersamo": "dispersar",
    "dispersamos": "dispersar",
    "dispersando": "dispersar",
    "dispersara": "dispersar",
    "dispersaram": "dispersar",
    "dispersaras": "dispersar",
    "dispersarde": "dispersar",
    "dispersardes": "dispersar",
    "dispersare": "dispersar",
    "dispersarei": "dispersar",
    "dispersareis": "dispersar",
    "dispersarem": "dispersar",
    "dispersaremos": "dispersar",
    "dispersares": "dispersar",
    "dispersaria": "dispersar",
    "dispersariam": "dispersar",
    "dispersarias": "dispersar",
    "dispersarmo": "dispersar",
    "dispersarmos": "dispersar",
    "dispersará": "dispersar",
    "dispersarás": "dispersar",
    "dispersarão": "dispersar",
    "dispersaríamos": "dispersar",
    "dispersaríeis": "dispersar",
    "dispersas": "disperso",
    "dispersasse": "dispersar",
    "dispersassem": "dispersar",
    "dispersasses": "dispersar",
    "dispersaste": "dispersar",
    "dispersastes": "dispersar",
    "dispersava": "dispersar",
    "dispersavam": "dispersar",
    "dispersavas": "dispersar",
    "disperse": "dispersar",
    "dispersei": "dispersar",
    "disperseis": "dispersar",
    "dispersem": "dispersar",
    "dispersemo": "dispersar",
    "dispersemos": "dispersar",
    "disperses": "dispersar",
    "dispersiva": "dispersivo",
    "dispersivas": "dispersivo",
    "dispersivos": "dispersivo",
    "disperso": "dispersar",
    "dispersos": "disperso",
    "dispersou": "dispersar",
    "dispersá": "dispersar",
    "dispersámo": "dispersar",
    "dispersámos": "dispersar",
    "dispersáramo": "dispersar",
    "dispersáramos": "dispersar",
    "dispersárei": "dispersar",
    "dispersáreis": "dispersar",
    "dispersásseis": "dispersar",
    "dispersássemos": "dispersar",
    "dispersávamo": "dispersar",
    "dispersávamos": "dispersar",
    "dispersávei": "dispersar",
    "dispersáveis": "dispersável",
    "dispersões": "dispersão",
    "displicentes": "displicente",
    "displicências": "displicência",
    "dispneias": "dispneia",
    "dispo": "despir",
    "dispomo": "dispor",
    "dispomos": "dispor",
    "disponde": "dispor",
    "dispondes": "dispor",
    "dispondo": "dispor",
    "disponentes": "disponente",
    "disponha": "dispor",
    "disponhais": "dispor",
    "disponham": "dispor",
    "disponhamo": "dispor",
    "disponhamos": "dispor",
    "disponhas": "dispor",
    "disponho": "dispor",
    "disponibilidades": "disponibilidade",
    "disponibiliza": "disponibilizar",
    "disponibilizada": "disponibilizar",
    "disponibilizadas": "disponibilizar",
    "disponibilizado": "disponibilizar",
    "disponibilizados": "disponibilizar",
    "disponibilizai": "disponibilizar",
    "disponibilizais": "disponibilizar",
    "disponibilizam": "disponibilizar",
    "disponibilizamo": "disponibilizar",
    "disponibilizamos": "disponibilizar",
    "disponibilizando": "disponibilizar",
    "disponibilizara": "disponibilizar",
    "disponibilizaram": "disponibilizar",
    "disponibilizaras": "disponibilizar",
    "disponibilizarde": "disponibilizar",
    "disponibilizardes": "disponibilizar",
    "disponibilizare": "disponibilizar",
    "disponibilizarei": "disponibilizar",
    "disponibilizareis": "disponibilizar",
    "disponibilizarem": "disponibilizar",
    "disponibilizaremos": "disponibilizar",
    "disponibilizares": "disponibilizar",
    "disponibilizaria": "disponibilizar",
    "disponibilizariam": "disponibilizar",
    "disponibilizarias": "disponibilizar",
    "disponibilizarmo": "disponibilizar",
    "disponibilizarmos": "disponibilizar",
    "disponibilizará": "disponibilizar",
    "disponibilizarás": "disponibilizar",
    "disponibilizarão": "disponibilizar",
    "disponibilizaríamos": "disponibilizar",
    "disponibilizaríeis": "disponibilizar",
    "disponibilizas": "disponibilizar",
    "disponibilizasse": "disponibilizar",
    "disponibilizassem": "disponibilizar",
    "disponibilizasses": "disponibilizar",
    "disponibilizaste": "disponibilizar",
    "disponibilizastes": "disponibilizar",
    "disponibilizava": "disponibilizar",
    "disponibilizavam": "disponibilizar",
    "disponibilizavas": "disponibilizar",
    "disponibilizações": "disponibilização",
    "disponibilize": "disponibilizar",
    "disponibilizei": "disponibilizar",
    "disponibilizeis": "disponibilizar",
    "disponibilizem": "disponibilizar",
    "disponibilizemo": "disponibilizar",
    "disponibilizemos": "disponibilizar",
    "disponibilizes": "disponibilizar",
    "disponibilizo": "disponibilizar",
    "disponibilizou": "disponibilizar",
    "disponibilizá": "disponibilizar",
    "disponibilizámo": "disponibilizar",
    "disponibilizámos": "disponibilizar",
    "disponibilizáramo": "disponibilizar",
    "disponibilizáramos": "disponibilizar",
    "disponibilizárei": "disponibilizar",
    "disponibilizáreis": "disponibilizar",
    "disponibilizásseis": "disponibilizar",
    "disponibilizássemos": "disponibilizar",
    "disponibilizávamo": "disponibilizar",
    "disponibilizávamos": "disponibilizar",
    "disponibilizávei": "disponibilizar",
    "disponibilizáveis": "disponibilizar",
    "disponíveis": "disponível",
    "disporde": "dispor",
    "dispordes": "dispor",
    "dispore": "dispor",
    "disporei": "dispor",
    "disporeis": "dispor",
    "disporem": "dispor",
    "disporemos": "dispor",
    "dispores": "dispor",
    "disporia": "dispor",
    "disporiam": "dispor",
    "disporias": "dispor",
    "dispormo": "dispor",
    "dispormos": "dispor",
    "disporá": "dispor",
    "disporás": "dispor",
    "disporão": "dispor",
    "disporíamos": "dispor",
    "disporíeis": "dispor",
    "dispositiva": "dispositivo",
    "dispositivas": "dispositivo",
    "dispositivos": "dispositivo",
    "dispositora": "dispositor",
    "dispositoras": "dispositor",
    "dispositores": "dispositor",
    "dispositos": "disposito",
    "disposições": "disposição",
    "disposta": "disposto",
    "dispostas": "disposto",
    "disposto": "dispor",
    "dispostos": "disposto",
    "disprósios": "disprósio",
    "dispunha": "dispor",
    "dispunham": "dispor",
    "dispunhas": "dispor",
    "dispus": "dispor",
    "dispusemo": "dispor",
    "dispusemos": "dispor",
    "dispuser": "dispor",
    "dispusera": "dispor",
    "dispuseram": "dispor",
    "dispuseras": "dispor",
    "dispuserdes": "dispor",
    "dispuserem": "dispor",
    "dispuseres": "dispor",
    "dispusermos": "dispor",
    "dispusesse": "dispor",
    "dispusessem": "dispor",
    "dispusesses": "dispor",
    "dispuseste": "dispor",
    "dispusestes": "dispor",
    "dispuséramo": "dispor",
    "dispuséramos": "dispor",
    "dispusérei": "dispor",
    "dispuséreis": "dispor",
    "dispusésseis": "dispor",
    "dispuséssemos": "dispor",
    "disputa": "disputar",
    "disputada": "disputar",
    "disputadas": "disputar",
    "disputado": "disputar",
    "disputadora": "disputador",
    "disputadoras": "disputador",
    "disputadores": "disputador",
    "disputados": "disputar",
    "disputadíssima": "disputado",
    "disputadíssimas": "disputado",
    "disputadíssimo": "disputado",
    "disputadíssimos": "disputado",
    "disputai": "disputar",
    "disputais": "disputar",
    "disputam": "disputar",
    "disputamo": "disputar",
    "disputamos": "disputar",
    "disputando": "disputar",
    "disputantes": "disputante",
    "disputara": "disputar",
    "disputaram": "disputar",
    "disputaras": "disputar",
    "disputarde": "disputar",
    "disputardes": "disputar",
    "disputare": "disputar",
    "disputarei": "disputar",
    "disputareis": "disputar",
    "disputarem": "disputar",
    "disputaremos": "disputar",
    "disputares": "disputar",
    "disputaria": "disputar",
    "disputariam": "disputar",
    "disputarias": "disputar",
    "disputarmo": "disputar",
    "disputarmos": "disputar",
    "disputará": "disputar",
    "disputarás": "disputar",
    "disputarão": "disputar",
    "disputaríamos": "disputar",
    "disputaríeis": "disputar",
    "disputas": "disputar",
    "disputasse": "disputar",
    "disputassem": "disputar",
    "disputasses": "disputar",
    "disputaste": "disputar",
    "disputastes": "disputar",
    "disputativa": "disputativo",
    "disputativas": "disputativo",
    "disputativos": "disputativo",
    "disputatória": "disputatório",
    "disputatórias": "disputatório",
    "disputatórios": "disputatório",
    "disputava": "disputar",
    "disputavam": "disputar",
    "disputavas": "disputar",
    "dispute": "disputar",
    "disputei": "disputar",
    "disputeis": "disputar",
    "disputem": "disputar",
    "disputemo": "disputar",
    "disputemos": "disputar",
    "disputes": "disputar",
    "disputo": "disputar",
    "disputou": "disputar",
    "disputá": "disputar",
    "disputámo": "disputar",
    "disputámos": "disputar",
    "disputáramo": "disputar",
    "disputáramos": "disputar",
    "disputárei": "disputar",
    "disputáreis": "disputar",
    "disputásseis": "disputar",
    "disputássemos": "disputar",
    "disputávamo": "disputar",
    "disputávamos": "disputar",
    "disputávei": "disputar",
    "disputáveis": "disputável",
    "dispéptica": "dispéptico",
    "dispépticas": "dispéptico",
    "dispépticos": "dispéptico",
    "dispérmica": "dispérmico",
    "dispérmicas": "dispérmico",
    "dispérmicos": "dispérmico",
    "dispêndios": "dispêndio",
    "dispô": "dispor",
    "dispôs": "dispor",
    "dispõe": "dispor",
    "dispõem": "dispor",
    "dispões": "dispor",
    "dispúnhamo": "dispor",
    "dispúnhamos": "dispor",
    "dispúnhei": "dispor",
    "dispúnheis": "dispor",
    "disque": "discar",
    "disquei": "discar",
    "disqueis": "discar",
    "disquem": "discar",
    "disquemo": "discar",
    "disquemos": "discar",
    "disques": "discar",
    "disquetes": "disquete",
    "disquisições": "disquisição",
    "disrupções": "disrupção",
    "dissaboreada": "dissaborear",
    "dissaboreadas": "dissaborear",
    "dissaboreado": "dissaborear",
    "dissaboreados": "dissaborear",
    "dissaboreai": "dissaborear",
    "dissaboreais": "dissaborear",
    "dissaboreamo": "dissaborear",
    "dissaboreamos": "dissaborear",
    "dissaboreando": "dissaborear",
    "dissaboreara": "dissaborear",
    "dissaborearam": "dissaborear",
    "dissaborearas": "dissaborear",
    "dissaborearde": "dissaborear",
    "dissaboreardes": "dissaborear",
    "dissaboreare": "dissaborear",
    "dissaborearei": "dissaborear",
    "dissaboreareis": "dissaborear",
    "dissaborearem": "dissaborear",
    "dissaborearemos": "dissaborear",
    "dissaboreares": "dissaborear",
    "dissaborearia": "dissaborear",
    "dissaboreariam": "dissaborear",
    "dissaborearias": "dissaborear",
    "dissaborearmo": "dissaborear",
    "dissaborearmos": "dissaborear",
    "dissaboreará": "dissaborear",
    "dissaborearás": "dissaborear",
    "dissaborearão": "dissaborear",
    "dissaborearíamos": "dissaborear",
    "dissaborearíeis": "dissaborear",
    "dissaboreasse": "dissaborear",
    "dissaboreassem": "dissaborear",
    "dissaboreasses": "dissaborear",
    "dissaboreaste": "dissaborear",
    "dissaboreastes": "dissaborear",
    "dissaboreava": "dissaborear",
    "dissaboreavam": "dissaborear",
    "dissaboreavas": "dissaborear",
    "dissaboreei": "dissaborear",
    "dissaboreeis": "dissaborear",
    "dissaboreemo": "dissaborear",
    "dissaboreemos": "dissaborear",
    "dissaboreia": "dissaborear",
    "dissaboreiam": "dissaborear",
    "dissaboreias": "dissaborear",
    "dissaboreie": "dissaborear",
    "dissaboreiem": "dissaborear",
    "dissaboreies": "dissaborear",
    "dissaboreio": "dissaborear",
    "dissaboreou": "dissaborear",
    "dissabores": "dissabor",
    "dissaboreá": "dissaborear",
    "dissaboreámo": "dissaborear",
    "dissaboreámos": "dissaborear",
    "dissaboreáramo": "dissaborear",
    "dissaboreáramos": "dissaborear",
    "dissaboreárei": "dissaborear",
    "dissaboreáreis": "dissaborear",
    "dissaboreásseis": "dissaborear",
    "dissaboreássemos": "dissaborear",
    "dissaboreávamo": "dissaborear",
    "dissaboreávamos": "dissaborear",
    "dissaboreávei": "dissaborear",
    "dissaboreáveis": "dissaborear",
    "dissaborida": "dissaborido",
    "dissaboridas": "dissaborido",
    "dissaboridos": "dissaborido",
    "dissaborosa": "dissaboroso",
    "dissaborosas": "dissaboroso",
    "dissaborosos": "dissaboroso",
    "disse": "dizer",
    "disseca": "dissecar",
    "dissecada": "dissecar",
    "dissecadas": "dissecar",
    "dissecado": "dissecar",
    "dissecadora": "dissecador",
    "dissecadoras": "dissecador",
    "dissecadores": "dissecador",
    "dissecados": "dissecar",
    "dissecai": "dissecar",
    "dissecais": "dissecar",
    "dissecam": "dissecar",
    "dissecamo": "dissecar",
    "dissecamos": "dissecar",
    "dissecando": "dissecar",
    "dissecantes": "dissecante",
    "dissecara": "dissecar",
    "dissecaram": "dissecar",
    "dissecaras": "dissecar",
    "dissecarde": "dissecar",
    "dissecardes": "dissecar",
    "dissecare": "dissecar",
    "dissecarei": "dissecar",
    "dissecareis": "dissecar",
    "dissecarem": "dissecar",
    "dissecaremos": "dissecar",
    "dissecares": "dissecar",
    "dissecaria": "dissecar",
    "dissecariam": "dissecar",
    "dissecarias": "dissecar",
    "dissecarmo": "dissecar",
    "dissecarmos": "dissecar",
    "dissecará": "dissecar",
    "dissecarás": "dissecar",
    "dissecarão": "dissecar",
    "dissecaríamos": "dissecar",
    "dissecaríeis": "dissecar",
    "dissecas": "dissecar",
    "dissecasse": "dissecar",
    "dissecassem": "dissecar",
    "dissecasses": "dissecar",
    "dissecaste": "dissecar",
    "dissecastes": "dissecar",
    "dissecativa": "dissecativo",
    "dissecativas": "dissecativo",
    "dissecativos": "dissecativo",
    "dissecava": "dissecar",
    "dissecavam": "dissecar",
    "dissecavas": "dissecar",
    "dissecações": "dissecação",
    "disseco": "dissecar",
    "dissecou": "dissecar",
    "dissectora": "dissector",
    "dissectoras": "dissector",
    "dissectores": "dissector",
    "dissecá": "dissecar",
    "dissecámo": "dissecar",
    "dissecámos": "dissecar",
    "dissecáramo": "dissecar",
    "dissecáramos": "dissecar",
    "dissecárei": "dissecar",
    "dissecáreis": "dissecar",
    "dissecásseis": "dissecar",
    "dissecássemos": "dissecar",
    "dissecávamo": "dissecar",
    "dissecávamos": "dissecar",
    "dissecávei": "dissecar",
    "dissecáveis": "dissecável",
    "dissemelha": "dissemelhar",
    "dissemelhada": "dissemelhar",
    "dissemelhadas": "dissemelhar",
    "dissemelhado": "dissemelhar",
    "dissemelhados": "dissemelhar",
    "dissemelhai": "dissemelhar",
    "dissemelhais": "dissemelhar",
    "dissemelham": "dissemelhar",
    "dissemelhamo": "dissemelhar",
    "dissemelhamos": "dissemelhar",
    "dissemelhando": "dissemelhar",
    "dissemelhantes": "dissemelhante",
    "dissemelhanças": "dissemelhança",
    "dissemelhara": "dissemelhar",
    "dissemelharam": "dissemelhar",
    "dissemelharas": "dissemelhar",
    "dissemelharde": "dissemelhar",
    "dissemelhardes": "dissemelhar",
    "dissemelhare": "dissemelhar",
    "dissemelharei": "dissemelhar",
    "dissemelhareis": "dissemelhar",
    "dissemelharem": "dissemelhar",
    "dissemelharemos": "dissemelhar",
    "dissemelhares": "dissemelhar",
    "dissemelharia": "dissemelhar",
    "dissemelhariam": "dissemelhar",
    "dissemelharias": "dissemelhar",
    "dissemelharmo": "dissemelhar",
    "dissemelharmos": "dissemelhar",
    "dissemelhará": "dissemelhar",
    "dissemelharás": "dissemelhar",
    "dissemelharão": "dissemelhar",
    "dissemelharíamos": "dissemelhar",
    "dissemelharíeis": "dissemelhar",
    "dissemelhas": "dissemelhar",
    "dissemelhasse": "dissemelhar",
    "dissemelhassem": "dissemelhar",
    "dissemelhasses": "dissemelhar",
    "dissemelhaste": "dissemelhar",
    "dissemelhastes": "dissemelhar",
    "dissemelhava": "dissemelhar",
    "dissemelhavam": "dissemelhar",
    "dissemelhavas": "dissemelhar",
    "dissemelhe": "dissemelhar",
    "dissemelhei": "dissemelhar",
    "dissemelheis": "dissemelhar",
    "dissemelhem": "dissemelhar",
    "dissemelhemo": "dissemelhar",
    "dissemelhemos": "dissemelhar",
    "dissemelhes": "dissemelhar",
    "dissemelho": "dissemelhar",
    "dissemelhou": "dissemelhar",
    "dissemelhá": "dissemelhar",
    "dissemelhámo": "dissemelhar",
    "dissemelhámos": "dissemelhar",
    "dissemelháramo": "dissemelhar",
    "dissemelháramos": "dissemelhar",
    "dissemelhárei": "dissemelhar",
    "dissemelháreis": "dissemelhar",
    "dissemelhásseis": "dissemelhar",
    "dissemelhássemos": "dissemelhar",
    "dissemelhávamo": "dissemelhar",
    "dissemelhávamos": "dissemelhar",
    "dissemelhávei": "dissemelhar",
    "dissemelháveis": "dissemelhar",
    "dissemias": "dissemia",
    "dissemina": "disseminar",
    "disseminada": "disseminar",
    "disseminadas": "disseminar",
    "disseminado": "disseminar",
    "disseminadora": "disseminador",
    "disseminadoras": "disseminador",
    "disseminadores": "disseminador",
    "disseminados": "disseminar",
    "disseminai": "disseminar",
    "disseminais": "disseminar",
    "disseminam": "disseminar",
    "disseminamo": "disseminar",
    "disseminamos": "disseminar",
    "disseminando": "disseminar",
    "disseminara": "disseminar",
    "disseminaram": "disseminar",
    "disseminaras": "disseminar",
    "disseminarde": "disseminar",
    "disseminardes": "disseminar",
    "disseminare": "disseminar",
    "disseminarei": "disseminar",
    "disseminareis": "disseminar",
    "disseminarem": "disseminar",
    "disseminaremos": "disseminar",
    "disseminares": "disseminar",
    "disseminaria": "disseminar",
    "disseminariam": "disseminar",
    "disseminarias": "disseminar",
    "disseminarmo": "disseminar",
    "disseminarmos": "disseminar",
    "disseminará": "disseminar",
    "disseminarás": "disseminar",
    "disseminarão": "disseminar",
    "disseminaríamos": "disseminar",
    "disseminaríeis": "disseminar",
    "disseminas": "disseminar",
    "disseminasse": "disseminar",
    "disseminassem": "disseminar",
    "disseminasses": "disseminar",
    "disseminaste": "disseminar",
    "disseminastes": "disseminar",
    "disseminava": "disseminar",
    "disseminavam": "disseminar",
    "disseminavas": "disseminar",
    "disseminações": "disseminação",
    "dissemine": "disseminar",
    "disseminei": "disseminar",
    "dissemineis": "disseminar",
    "disseminem": "disseminar",
    "disseminemo": "disseminar",
    "disseminemos": "disseminar",
    "dissemines": "disseminar",
    "dissemino": "disseminar",
    "disseminou": "disseminar",
    "disseminá": "disseminar",
    "disseminámo": "disseminar",
    "disseminámos": "disseminar",
    "dissemináramo": "disseminar",
    "dissemináramos": "disseminar",
    "disseminárei": "disseminar",
    "dissemináreis": "disseminar",
    "disseminásseis": "disseminar",
    "disseminássemos": "disseminar",
    "disseminávamo": "disseminar",
    "disseminávamos": "disseminar",
    "disseminávei": "disseminar",
    "dissemináveis": "disseminável",
    "dissemo": "dizer",
    "dissemos": "dizer",
    "dissensões": "dissensão",
    "dissente": "dissentir",
    "dissentem": "dissentir",
    "dissentes": "dissentir",
    "dissenti": "dissentir",
    "dissentia": "dissentir",
    "dissentiam": "dissentir",
    "dissentias": "dissentir",
    "dissentida": "dissentir",
    "dissentidas": "dissentir",
    "dissentido": "dissentir",
    "dissentidos": "dissentir",
    "dissentimentos": "dissentimento",
    "dissentimo": "dissentir",
    "dissentimos": "dissentir",
    "dissentindo": "dissentir",
    "dissentira": "dissentir",
    "dissentiram": "dissentir",
    "dissentiras": "dissentir",
    "dissentirde": "dissentir",
    "dissentirdes": "dissentir",
    "dissentire": "dissentir",
    "dissentirei": "dissentir",
    "dissentireis": "dissentir",
    "dissentirem": "dissentir",
    "dissentiremos": "dissentir",
    "dissentires": "dissentir",
    "dissentiria": "dissentir",
    "dissentiriam": "dissentir",
    "dissentirias": "dissentir",
    "dissentirmo": "dissentir",
    "dissentirmos": "dissentir",
    "dissentirá": "dissentir",
    "dissentirás": "dissentir",
    "dissentirão": "dissentir",
    "dissentiríamos": "dissentir",
    "dissentiríeis": "dissentir",
    "dissentis": "dissentir",
    "dissentisse": "dissentir",
    "dissentissem": "dissentir",
    "dissentisses": "dissentir",
    "dissentiste": "dissentir",
    "dissentistes": "dissentir",
    "dissentiu": "dissentir",
    "dissentânea": "dissentâneo",
    "dissentâneas": "dissentâneo",
    "dissentâneos": "dissentâneo",
    "dissentíamo": "dissentir",
    "dissentíamos": "dissentir",
    "dissentíei": "dissentir",
    "dissentíeis": "dissentir",
    "dissentíramo": "dissentir",
    "dissentíramos": "dissentir",
    "dissentírei": "dissentir",
    "dissentíreis": "dissentir",
    "dissentísseis": "dissentir",
    "dissentíssemos": "dissentir",
    "disseque": "dissecar",
    "dissequei": "dissecar",
    "dissequeis": "dissecar",
    "dissequem": "dissecar",
    "dissequemo": "dissecar",
    "dissequemos": "dissecar",
    "disseques": "dissecar",
    "disser": "dizer",
    "dissera": "dizer",
    "disseram": "dizer",
    "disseras": "dizer",
    "disserdes": "dizer",
    "disserem": "dizer",
    "disseres": "dizer",
    "dissermos": "dizer",
    "disserta": "dissertar",
    "dissertada": "dissertar",
    "dissertadas": "dissertar",
    "dissertado": "dissertar",
    "dissertadora": "dissertador",
    "dissertadoras": "dissertador",
    "dissertadores": "dissertador",
    "dissertados": "dissertar",
    "dissertai": "dissertar",
    "dissertais": "dissertar",
    "dissertam": "dissertar",
    "dissertamo": "dissertar",
    "dissertamos": "dissertar",
    "dissertando": "dissertar",
    "dissertara": "dissertar",
    "dissertaram": "dissertar",
    "dissertaras": "dissertar",
    "dissertardes": "dissertar",
    "dissertarei": "dissertar",
    "dissertareis": "dissertar",
    "dissertarem": "dissertar",
    "dissertaremos": "dissertar",
    "dissertares": "dissertar",
    "dissertaria": "dissertar",
    "dissertariam": "dissertar",
    "dissertarias": "dissertar",
    "dissertarmo": "dissertar",
    "dissertarmos": "dissertar",
    "dissertará": "dissertar",
    "dissertarás": "dissertar",
    "dissertarão": "dissertar",
    "dissertaríamos": "dissertar",
    "dissertaríeis": "dissertar",
    "dissertas": "dissertar",
    "dissertasse": "dissertar",
    "dissertassem": "dissertar",
    "dissertasses": "dissertar",
    "dissertaste": "dissertar",
    "dissertastes": "dissertar",
    "dissertava": "dissertar",
    "dissertavam": "dissertar",
    "dissertavas": "dissertar",
    "dissertações": "dissertação",
    "disserte": "dissertar",
    "dissertei": "dissertar",
    "disserteis": "dissertar",
    "dissertem": "dissertar",
    "dissertemo": "dissertar",
    "dissertemos": "dissertar",
    "dissertes": "dissertar",
    "disserto": "dissertar",
    "dissertou": "dissertar",
    "dissertámo": "dissertar",
    "dissertámos": "dissertar",
    "dissertáramo": "dissertar",
    "dissertáramos": "dissertar",
    "dissertáreis": "dissertar",
    "dissertásseis": "dissertar",
    "dissertássemos": "dissertar",
    "dissertávamo": "dissertar",
    "dissertávamos": "dissertar",
    "dissertáveis": "dissertar",
    "dissesse": "dizer",
    "dissessem": "dizer",
    "dissesses": "dizer",
    "disseste": "dizer",
    "dissestes": "dizer",
    "dissidentes": "dissidente",
    "dissidia": "dissidiar",
    "dissidiada": "dissidiar",
    "dissidiadas": "dissidiar",
    "dissidiado": "dissidiar",
    "dissidiados": "dissidiar",
    "dissidiai": "dissidiar",
    "dissidiais": "dissidiar",
    "dissidiam": "dissidiar",
    "dissidiamo": "dissidiar",
    "dissidiamos": "dissidiar",
    "dissidiando": "dissidiar",
    "dissidiara": "dissidiar",
    "dissidiaram": "dissidiar",
    "dissidiaras": "dissidiar",
    "dissidiarde": "dissidiar",
    "dissidiardes": "dissidiar",
    "dissidiare": "dissidiar",
    "dissidiarei": "dissidiar",
    "dissidiareis": "dissidiar",
    "dissidiarem": "dissidiar",
    "dissidiaremos": "dissidiar",
    "dissidiares": "dissidiar",
    "dissidiaria": "dissidiar",
    "dissidiariam": "dissidiar",
    "dissidiarias": "dissidiar",
    "dissidiarmo": "dissidiar",
    "dissidiarmos": "dissidiar",
    "dissidiará": "dissidiar",
    "dissidiarás": "dissidiar",
    "dissidiarão": "dissidiar",
    "dissidiaríamos": "dissidiar",
    "dissidiaríeis": "dissidiar",
    "dissidias": "dissidiar",
    "dissidiasse": "dissidiar",
    "dissidiassem": "dissidiar",
    "dissidiasses": "dissidiar",
    "dissidiaste": "dissidiar",
    "dissidiastes": "dissidiar",
    "dissidiava": "dissidiar",
    "dissidiavam": "dissidiar",
    "dissidiavas": "dissidiar",
    "dissidie": "dissidiar",
    "dissidiei": "dissidiar",
    "dissidieis": "dissidiar",
    "dissidiem": "dissidiar",
    "dissidiemo": "dissidiar",
    "dissidiemos": "dissidiar",
    "dissidies": "dissidiar",
    "dissidio": "dissidiar",
    "dissidiou": "dissidiar",
    "dissidiá": "dissidiar",
    "dissidiámo": "dissidiar",
    "dissidiámos": "dissidiar",
    "dissidiáramo": "dissidiar",
    "dissidiáramos": "dissidiar",
    "dissidiárei": "dissidiar",
    "dissidiáreis": "dissidiar",
    "dissidiásseis": "dissidiar",
    "dissidiássemos": "dissidiar",
    "dissidiávamo": "dissidiar",
    "dissidiávamos": "dissidiar",
    "dissidiávei": "dissidiar",
    "dissidiáveis": "dissidiar",
    "dissidências": "dissidência",
    "dissilaba": "dissilabo",
    "dissilabas": "dissilabo",
    "dissilabismos": "dissilabismo",
    "dissilabos": "dissilabo",
    "dissilábica": "dissilábico",
    "dissilábicas": "dissilábico",
    "dissilábicos": "dissilábico",
    "dissimetrias": "dissimetria",
    "dissimila": "dissimilar",
    "dissimilada": "dissimilar",
    "dissimiladas": "dissimilar",
    "dissimilado": "dissimilar",
    "dissimilados": "dissimilar",
    "dissimilai": "dissimilar",
    "dissimilais": "dissimilar",
    "dissimilam": "dissimilar",
    "dissimilamo": "dissimilar",
    "dissimilamos": "dissimilar",
    "dissimilando": "dissimilar",
    "dissimilantes": "dissimilante",
    "dissimilara": "dissimilar",
    "dissimilaram": "dissimilar",
    "dissimilaras": "dissimilar",
    "dissimilarde": "dissimilar",
    "dissimilardes": "dissimilar",
    "dissimilare": "dissimilar",
    "dissimilarei": "dissimilar",
    "dissimilareis": "dissimilar",
    "dissimilarem": "dissimilar",
    "dissimilaremos": "dissimilar",
    "dissimilares": "dissimilar",
    "dissimilaria": "dissimilar",
    "dissimilariam": "dissimilar",
    "dissimilarias": "dissimilar",
    "dissimilarmo": "dissimilar",
    "dissimilarmos": "dissimilar",
    "dissimilará": "dissimilar",
    "dissimilarás": "dissimilar",
    "dissimilarão": "dissimilar",
    "dissimilaríamos": "dissimilar",
    "dissimilaríeis": "dissimilar",
    "dissimilas": "dissimilar",
    "dissimilasse": "dissimilar",
    "dissimilassem": "dissimilar",
    "dissimilasses": "dissimilar",
    "dissimilaste": "dissimilar",
    "dissimilastes": "dissimilar",
    "dissimilava": "dissimilar",
    "dissimilavam": "dissimilar",
    "dissimilavas": "dissimilar",
    "dissimilações": "dissimilação",
    "dissimile": "dissimilar",
    "dissimilei": "dissimilar",
    "dissimileis": "dissimilar",
    "dissimilem": "dissimilar",
    "dissimilemo": "dissimilar",
    "dissimilemos": "dissimilar",
    "dissimiles": "dissimilar",
    "dissimilo": "dissimilar",
    "dissimilou": "dissimilar",
    "dissimilá": "dissimilar",
    "dissimilámo": "dissimilar",
    "dissimilámos": "dissimilar",
    "dissimiláramo": "dissimilar",
    "dissimiláramos": "dissimilar",
    "dissimilárei": "dissimilar",
    "dissimiláreis": "dissimilar",
    "dissimilásseis": "dissimilar",
    "dissimilássemos": "dissimilar",
    "dissimilávamo": "dissimilar",
    "dissimilávamos": "dissimilar",
    "dissimilávei": "dissimilar",
    "dissimiláveis": "dissimilável",
    "dissimula": "dissimular",
    "dissimulada": "dissimular",
    "dissimuladas": "dissimular",
    "dissimulado": "dissimular",
    "dissimuladora": "dissimulador",
    "dissimuladoras": "dissimulador",
    "dissimuladores": "dissimulador",
    "dissimulados": "dissimular",
    "dissimuladíssima": "dissimulado",
    "dissimuladíssimas": "dissimulado",
    "dissimuladíssimo": "dissimulado",
    "dissimuladíssimos": "dissimulado",
    "dissimulai": "dissimular",
    "dissimulais": "dissimular",
    "dissimulam": "dissimular",
    "dissimulamo": "dissimular",
    "dissimulamos": "dissimular",
    "dissimulando": "dissimular",
    "dissimulara": "dissimular",
    "dissimularam": "dissimular",
    "dissimularas": "dissimular",
    "dissimularde": "dissimular",
    "dissimulardes": "dissimular",
    "dissimulare": "dissimular",
    "dissimularei": "dissimular",
    "dissimulareis": "dissimular",
    "dissimularem": "dissimular",
    "dissimularemos": "dissimular",
    "dissimulares": "dissimular",
    "dissimularia": "dissimular",
    "dissimulariam": "dissimular",
    "dissimularias": "dissimular",
    "dissimularmo": "dissimular",
    "dissimularmos": "dissimular",
    "dissimulará": "dissimular",
    "dissimularás": "dissimular",
    "dissimularão": "dissimular",
    "dissimularíamos": "dissimular",
    "dissimularíeis": "dissimular",
    "dissimulas": "dissimular",
    "dissimulasse": "dissimular",
    "dissimulassem": "dissimular",
    "dissimulasses": "dissimular",
    "dissimulaste": "dissimular",
    "dissimulastes": "dissimular",
    "dissimulatória": "dissimulatório",
    "dissimulatórias": "dissimulatório",
    "dissimulatórios": "dissimulatório",
    "dissimulava": "dissimular",
    "dissimulavam": "dissimular",
    "dissimulavas": "dissimular",
    "dissimulações": "dissimulação",
    "dissimule": "dissimular",
    "dissimulei": "dissimular",
    "dissimuleis": "dissimular",
    "dissimulem": "dissimular",
    "dissimulemo": "dissimular",
    "dissimulemos": "dissimular",
    "dissimules": "dissimular",
    "dissimulo": "dissimular",
    "dissimulou": "dissimular",
    "dissimulá": "dissimular",
    "dissimulámo": "dissimular",
    "dissimulámos": "dissimular",
    "dissimuláramo": "dissimular",
    "dissimuláramos": "dissimular",
    "dissimulárei": "dissimular",
    "dissimuláreis": "dissimular",
    "dissimulásseis": "dissimular",
    "dissimulássemos": "dissimular",
    "dissimulávamo": "dissimular",
    "dissimulávamos": "dissimular",
    "dissimulávei": "dissimular",
    "dissimuláveis": "dissimulável",
    "dissimétrica": "dissimétrico",
    "dissimétricas": "dissimétrico",
    "dissimétricos": "dissimétrico",
    "dissinta": "dissentir",
    "dissintais": "dissentir",
    "dissintam": "dissentir",
    "dissintamo": "dissentir",
    "dissintamos": "dissentir",
    "dissintas": "dissentir",
    "dissinto": "dissentir",
    "dissipa": "dissipar",
    "dissipada": "dissipar",
    "dissipadas": "dissipar",
    "dissipado": "dissipar",
    "dissipadora": "dissipador",
    "dissipadoras": "dissipador",
    "dissipadores": "dissipador",
    "dissipados": "dissipar",
    "dissipai": "dissipar",
    "dissipais": "dissipar",
    "dissipam": "dissipar",
    "dissipamo": "dissipar",
    "dissipamos": "dissipar",
    "dissipando": "dissipar",
    "dissipara": "dissipar",
    "dissiparam": "dissipar",
    "dissiparas": "dissipar",
    "dissiparde": "dissipar",
    "dissipardes": "dissipar",
    "dissipare": "dissipar",
    "dissiparei": "dissipar",
    "dissipareis": "dissipar",
    "dissiparem": "dissipar",
    "dissiparemos": "dissipar",
    "dissipares": "dissipar",
    "dissiparia": "dissipar",
    "dissipariam": "dissipar",
    "dissiparias": "dissipar",
    "dissiparmo": "dissipar",
    "dissiparmos": "dissipar",
    "dissipará": "dissipar",
    "dissiparás": "dissipar",
    "dissiparão": "dissipar",
    "dissiparíamos": "dissipar",
    "dissiparíeis": "dissipar",
    "dissipas": "dissipar",
    "dissipasse": "dissipar",
    "dissipassem": "dissipar",
    "dissipasses": "dissipar",
    "dissipaste": "dissipar",
    "dissipastes": "dissipar",
    "dissipava": "dissipar",
    "dissipavam": "dissipar",
    "dissipavas": "dissipar",
    "dissipações": "dissipação",
    "dissipe": "dissipar",
    "dissipei": "dissipar",
    "dissipeis": "dissipar",
    "dissipem": "dissipar",
    "dissipemo": "dissipar",
    "dissipemos": "dissipar",
    "dissipes": "dissipar",
    "dissipo": "dissipar",
    "dissipou": "dissipar",
    "dissipá": "dissipar",
    "dissipámo": "dissipar",
    "dissipámos": "dissipar",
    "dissipáramo": "dissipar",
    "dissipáramos": "dissipar",
    "dissipárei": "dissipar",
    "dissipáreis": "dissipar",
    "dissipásseis": "dissipar",
    "dissipássemos": "dissipar",
    "dissipávamo": "dissipar",
    "dissipávamos": "dissipar",
    "dissipávei": "dissipar",
    "dissipáveis": "dissipável",
    "dissocia": "dissociar",
    "dissociabilidades": "dissociabilidade",
    "dissociada": "dissociar",
    "dissociadas": "dissociar",
    "dissociado": "dissociar",
    "dissociados": "dissociar",
    "dissociai": "dissociar",
    "dissociais": "dissociar",
    "dissociam": "dissociar",
    "dissociamo": "dissociar",
    "dissociamos": "dissociar",
    "dissociando": "dissociar",
    "dissociara": "dissociar",
    "dissociaram": "dissociar",
    "dissociaras": "dissociar",
    "dissociarde": "dissociar",
    "dissociardes": "dissociar",
    "dissociare": "dissociar",
    "dissociarei": "dissociar",
    "dissociareis": "dissociar",
    "dissociarem": "dissociar",
    "dissociaremos": "dissociar",
    "dissociares": "dissociar",
    "dissociaria": "dissociar",
    "dissociariam": "dissociar",
    "dissociarias": "dissociar",
    "dissociarmo": "dissociar",
    "dissociarmos": "dissociar",
    "dissociará": "dissociar",
    "dissociarás": "dissociar",
    "dissociarão": "dissociar",
    "dissociaríamos": "dissociar",
    "dissociaríeis": "dissociar",
    "dissocias": "dissociar",
    "dissociasse": "dissociar",
    "dissociassem": "dissociar",
    "dissociasses": "dissociar",
    "dissociaste": "dissociar",
    "dissociastes": "dissociar",
    "dissociativa": "dissociativo",
    "dissociativas": "dissociativo",
    "dissociativos": "dissociativo",
    "dissociava": "dissociar",
    "dissociavam": "dissociar",
    "dissociavas": "dissociar",
    "dissociações": "dissociação",
    "dissocie": "dissociar",
    "dissociei": "dissociar",
    "dissocieis": "dissociar",
    "dissociem": "dissociar",
    "dissociemo": "dissociar",
    "dissociemos": "dissociar",
    "dissocies": "dissociar",
    "dissocio": "dissociar",
    "dissociou": "dissociar",
    "dissociá": "dissociar",
    "dissociámo": "dissociar",
    "dissociámos": "dissociar",
    "dissociáramo": "dissociar",
    "dissociáramos": "dissociar",
    "dissociárei": "dissociar",
    "dissociáreis": "dissociar",
    "dissociásseis": "dissociar",
    "dissociássemos": "dissociar",
    "dissociávamo": "dissociar",
    "dissociávamos": "dissociar",
    "dissociávei": "dissociar",
    "dissociáveis": "dissociável",
    "dissolubilidades": "dissolubilidade",
    "dissoluta": "dissoluto",
    "dissolutas": "dissoluto",
    "dissolutiva": "dissolutivo",
    "dissolutivas": "dissolutivo",
    "dissolutivos": "dissolutivo",
    "dissolutos": "dissoluto",
    "dissoluções": "dissolução",
    "dissolva": "dissolver",
    "dissolvais": "dissolver",
    "dissolvam": "dissolver",
    "dissolvamo": "dissolver",
    "dissolvamos": "dissolver",
    "dissolvas": "dissolver",
    "dissolve": "dissolver",
    "dissolvei": "dissolver",
    "dissolveis": "dissolver",
    "dissolvem": "dissolver",
    "dissolvemo": "dissolver",
    "dissolvemos": "dissolver",
    "dissolvendo": "dissolver",
    "dissolventes": "dissolvente",
    "dissolvera": "dissolver",
    "dissolveram": "dissolver",
    "dissolveras": "dissolver",
    "dissolverde": "dissolver",
    "dissolverdes": "dissolver",
    "dissolvere": "dissolver",
    "dissolverei": "dissolver",
    "dissolvereis": "dissolver",
    "dissolverem": "dissolver",
    "dissolveremos": "dissolver",
    "dissolveres": "dissolver",
    "dissolveria": "dissolver",
    "dissolveriam": "dissolver",
    "dissolverias": "dissolver",
    "dissolvermo": "dissolver",
    "dissolvermos": "dissolver",
    "dissolverá": "dissolver",
    "dissolverás": "dissolver",
    "dissolverão": "dissolver",
    "dissolveríamos": "dissolver",
    "dissolveríeis": "dissolver",
    "dissolves": "dissolver",
    "dissolvesse": "dissolver",
    "dissolvessem": "dissolver",
    "dissolvesses": "dissolver",
    "dissolveste": "dissolver",
    "dissolvestes": "dissolver",
    "dissolveu": "dissolver",
    "dissolvi": "dissolver",
    "dissolvia": "dissolver",
    "dissolviam": "dissolver",
    "dissolvias": "dissolver",
    "dissolvida": "dissolvido",
    "dissolvidas": "dissolvido",
    "dissolvido": "dissolver",
    "dissolvidos": "dissolvido",
    "dissolvo": "dissolver",
    "dissolvê": "dissolver",
    "dissolvências": "dissolvência",
    "dissolvêramo": "dissolver",
    "dissolvêramos": "dissolver",
    "dissolvêrei": "dissolver",
    "dissolvêreis": "dissolver",
    "dissolvêsseis": "dissolver",
    "dissolvêssemos": "dissolver",
    "dissolvíamo": "dissolver",
    "dissolvíamos": "dissolver",
    "dissolvíei": "dissolver",
    "dissolvíeis": "dissolver",
    "dissolvíveis": "dissolvível",
    "dissolúveis": "dissolúvel",
    "dissonantes": "dissonante",
    "dissonora": "dissonoro",
    "dissonoras": "dissonoro",
    "dissonoros": "dissonoro",
    "dissonâncias": "dissonância",
    "dissuada": "dissuadir",
    "dissuadais": "dissuadir",
    "dissuadam": "dissuadir",
    "dissuadamo": "dissuadir",
    "dissuadamos": "dissuadir",
    "dissuadas": "dissuadir",
    "dissuade": "dissuadir",
    "dissuadem": "dissuadir",
    "dissuades": "dissuadir",
    "dissuadi": "dissuadir",
    "dissuadia": "dissuadir",
    "dissuadiam": "dissuadir",
    "dissuadias": "dissuadir",
    "dissuadida": "dissuadir",
    "dissuadidas": "dissuadir",
    "dissuadido": "dissuadir",
    "dissuadidos": "dissuadir",
    "dissuadimo": "dissuadir",
    "dissuadimos": "dissuadir",
    "dissuadindo": "dissuadir",
    "dissuadira": "dissuadir",
    "dissuadiram": "dissuadir",
    "dissuadiras": "dissuadir",
    "dissuadirde": "dissuadir",
    "dissuadirdes": "dissuadir",
    "dissuadire": "dissuadir",
    "dissuadirei": "dissuadir",
    "dissuadireis": "dissuadir",
    "dissuadirem": "dissuadir",
    "dissuadiremos": "dissuadir",
    "dissuadires": "dissuadir",
    "dissuadiria": "dissuadir",
    "dissuadiriam": "dissuadir",
    "dissuadirias": "dissuadir",
    "dissuadirmo": "dissuadir",
    "dissuadirmos": "dissuadir",
    "dissuadirá": "dissuadir",
    "dissuadirás": "dissuadir",
    "dissuadirão": "dissuadir",
    "dissuadiríamos": "dissuadir",
    "dissuadiríeis": "dissuadir",
    "dissuadis": "dissuadir",
    "dissuadisse": "dissuadir",
    "dissuadissem": "dissuadir",
    "dissuadisses": "dissuadir",
    "dissuadiste": "dissuadir",
    "dissuadistes": "dissuadir",
    "dissuadiu": "dissuadir",
    "dissuado": "dissuadir",
    "dissuadíamo": "dissuadir",
    "dissuadíamos": "dissuadir",
    "dissuadíei": "dissuadir",
    "dissuadíeis": "dissuadir",
    "dissuadíramo": "dissuadir",
    "dissuadíramos": "dissuadir",
    "dissuadírei": "dissuadir",
    "dissuadíreis": "dissuadir",
    "dissuadísseis": "dissuadir",
    "dissuadíssemos": "dissuadir",
    "dissuadíveis": "dissuadível",
    "dissuasiva": "dissuasivo",
    "dissuasivas": "dissuasivo",
    "dissuasivos": "dissuasivo",
    "dissuasora": "dissuasor",
    "dissuasoras": "dissuasor",
    "dissuasores": "dissuasor",
    "dissuasória": "dissuasório",
    "dissuasórias": "dissuasório",
    "dissuasórios": "dissuasório",
    "dissuasões": "dissuasão",
    "dissépala": "dissépalo",
    "dissépalas": "dissépalo",
    "dissépalos": "dissépalo",
    "disséramo": "dizer",
    "disséramos": "dizer",
    "dissérei": "dizer",
    "disséreis": "dizer",
    "dissésseis": "dizer",
    "disséssemos": "dizer",
    "dissídios": "dissídio",
    "dissílabos": "dissílabo",
    "dissímis": "dissímil",
    "dista": "distar",
    "distada": "distar",
    "distadas": "distar",
    "distado": "distar",
    "distados": "distar",
    "distai": "distar",
    "distais": "distar",
    "distam": "distar",
    "distamo": "distar",
    "distamos": "distar",
    "distancia": "distanciar",
    "distanciada": "distanciar",
    "distanciadas": "distanciar",
    "distanciado": "distanciar",
    "distanciados": "distanciar",
    "distanciai": "distanciar",
    "distanciais": "distanciar",
    "distanciam": "distanciar",
    "distanciamentos": "distanciamento",
    "distanciamo": "distanciar",
    "distanciamos": "distanciar",
    "distanciando": "distanciar",
    "distanciara": "distanciar",
    "distanciaram": "distanciar",
    "distanciaras": "distanciar",
    "distanciarde": "distanciar",
    "distanciardes": "distanciar",
    "distanciare": "distanciar",
    "distanciarei": "distanciar",
    "distanciareis": "distanciar",
    "distanciarem": "distanciar",
    "distanciaremos": "distanciar",
    "distanciares": "distanciar",
    "distanciaria": "distanciar",
    "distanciariam": "distanciar",
    "distanciarias": "distanciar",
    "distanciarmo": "distanciar",
    "distanciarmos": "distanciar",
    "distanciará": "distanciar",
    "distanciarás": "distanciar",
    "distanciarão": "distanciar",
    "distanciaríamos": "distanciar",
    "distanciaríeis": "distanciar",
    "distancias": "distanciar",
    "distanciasse": "distanciar",
    "distanciassem": "distanciar",
    "distanciasses": "distanciar",
    "distanciaste": "distanciar",
    "distanciastes": "distanciar",
    "distanciava": "distanciar",
    "distanciavam": "distanciar",
    "distanciavas": "distanciar",
    "distanciações": "distanciação",
    "distancie": "distanciar",
    "distanciei": "distanciar",
    "distancieis": "distanciar",
    "distanciem": "distanciar",
    "distanciemo": "distanciar",
    "distanciemos": "distanciar",
    "distancies": "distanciar",
    "distancio": "distanciar",
    "distanciou": "distanciar",
    "distanciá": "distanciar",
    "distanciámo": "distanciar",
    "distanciámos": "distanciar",
    "distanciáramo": "distanciar",
    "distanciáramos": "distanciar",
    "distanciárei": "distanciar",
    "distanciáreis": "distanciar",
    "distanciásseis": "distanciar",
    "distanciássemos": "distanciar",
    "distanciávamo": "distanciar",
    "distanciávamos": "distanciar",
    "distanciávei": "distanciar",
    "distanciáveis": "distanciável",
    "distanciómetros": "distanciómetro",
    "distando": "distar",
    "distantes": "distante",
    "distanásias": "distanásia",
    "distara": "distar",
    "distaram": "distar",
    "distaras": "distar",
    "distarde": "distar",
    "distardes": "distar",
    "distare": "distar",
    "distarei": "distar",
    "distareis": "distar",
    "distarem": "distar",
    "distaremos": "distar",
    "distares": "distar",
    "distaria": "distar",
    "distariam": "distar",
    "distarias": "distar",
    "distarmo": "distar",
    "distarmos": "distar",
    "distará": "distar",
    "distarás": "distar",
    "distarão": "distar",
    "distaríamos": "distar",
    "distaríeis": "distar",
    "distas": "distar",
    "distasse": "distar",
    "distassem": "distar",
    "distasses": "distar",
    "distaste": "distar",
    "distastes": "distar",
    "distava": "distar",
    "distavam": "distar",
    "distavas": "distar",
    "diste": "distar",
    "distei": "distar",
    "disteis": "distar",
    "distelazias": "distelazia",
    "disteleologias": "disteleologia",
    "distem": "distar",
    "distemo": "distar",
    "distemos": "distar",
    "distenas": "distena",
    "distenda": "distender",
    "distendais": "distender",
    "distendam": "distender",
    "distendamo": "distender",
    "distendamos": "distender",
    "distendas": "distender",
    "distende": "distender",
    "distendei": "distender",
    "distendeis": "distender",
    "distendem": "distender",
    "distendemo": "distender",
    "distendemos": "distender",
    "distendendo": "distender",
    "distendera": "distender",
    "distenderam": "distender",
    "distenderas": "distender",
    "distenderde": "distender",
    "distenderdes": "distender",
    "distendere": "distender",
    "distenderei": "distender",
    "distendereis": "distender",
    "distenderem": "distender",
    "distenderemos": "distender",
    "distenderes": "distender",
    "distenderia": "distender",
    "distenderiam": "distender",
    "distenderias": "distender",
    "distendermo": "distender",
    "distendermos": "distender",
    "distenderá": "distender",
    "distenderás": "distender",
    "distenderão": "distender",
    "distenderíamos": "distender",
    "distenderíeis": "distender",
    "distendes": "distender",
    "distendesse": "distender",
    "distendessem": "distender",
    "distendesses": "distender",
    "distendeste": "distender",
    "distendestes": "distender",
    "distendeu": "distender",
    "distendi": "distender",
    "distendia": "distender",
    "distendiam": "distender",
    "distendias": "distender",
    "distendida": "distendido",
    "distendidas": "distendido",
    "distendido": "distender",
    "distendidos": "distendido",
    "distendo": "distender",
    "distendê": "distender",
    "distendêramo": "distender",
    "distendêramos": "distender",
    "distendêrei": "distender",
    "distendêreis": "distender",
    "distendêsseis": "distender",
    "distendêssemos": "distender",
    "distendíamo": "distender",
    "distendíamos": "distender",
    "distendíei": "distender",
    "distendíeis": "distender",
    "distensa": "distenso",
    "distensas": "distenso",
    "distensibilidades": "distensibilidade",
    "distensora": "distensor",
    "distensoras": "distensor",
    "distensores": "distensor",
    "distensos": "distenso",
    "distensíveis": "distensível",
    "distensões": "distensão",
    "distes": "distar",
    "disticada": "disticado",
    "disticadas": "disticado",
    "disticados": "disticado",
    "distila": "distilo",
    "distilas": "distilo",
    "distilos": "distilo",
    "distimias": "distimia",
    "distinga": "distinguir",
    "distingais": "distinguir",
    "distingam": "distinguir",
    "distingamo": "distinguir",
    "distingamos": "distinguir",
    "distingas": "distinguir",
    "distingo": "distinguir",
    "distingue": "distinguir",
    "distinguem": "distinguir",
    "distingues": "distinguir",
    "distingui": "distinguir",
    "distinguia": "distinguir",
    "distinguiam": "distinguir",
    "distinguias": "distinguir",
    "distinguibilidades": "distinguibilidade",
    "distinguida": "distinguir",
    "distinguidas": "distinguir",
    "distinguido": "distinguir",
    "distinguidos": "distinguir",
    "distinguidíssima": "distinguido",
    "distinguidíssimas": "distinguido",
    "distinguidíssimo": "distinguido",
    "distinguidíssimos": "distinguido",
    "distinguimo": "distinguir",
    "distinguimos": "distinguir",
    "distinguindo": "distinguir",
    "distinguira": "distinguir",
    "distinguiram": "distinguir",
    "distinguiras": "distinguir",
    "distinguirde": "distinguir",
    "distinguirdes": "distinguir",
    "distinguire": "distinguir",
    "distinguirei": "distinguir",
    "distinguireis": "distinguir",
    "distinguirem": "distinguir",
    "distinguiremos": "distinguir",
    "distinguires": "distinguir",
    "distinguiria": "distinguir",
    "distinguiriam": "distinguir",
    "distinguirias": "distinguir",
    "distinguirmo": "distinguir",
    "distinguirmos": "distinguir",
    "distinguirá": "distinguir",
    "distinguirás": "distinguir",
    "distinguirão": "distinguir",
    "distinguiríamos": "distinguir",
    "distinguiríeis": "distinguir",
    "distinguis": "distinguir",
    "distinguisse": "distinguir",
    "distinguissem": "distinguir",
    "distinguisses": "distinguir",
    "distinguiste": "distinguir",
    "distinguistes": "distinguir",
    "distinguiu": "distinguir",
    "distinguíamo": "distinguir",
    "distinguíamos": "distinguir",
    "distinguíei": "distinguir",
    "distinguíeis": "distinguir",
    "distinguíramo": "distinguir",
    "distinguíramos": "distinguir",
    "distinguírei": "distinguir",
    "distinguíreis": "distinguir",
    "distinguísseis": "distinguir",
    "distinguíssemos": "distinguir",
    "distinguíveis": "distinguível",
    "distinta": "distinto",
    "distintas": "distinto",
    "distintiva": "distintivo",
    "distintivas": "distintivo",
    "distintivos": "distintivo",
    "distintos": "distinto",
    "distintíssima": "distinto",
    "distintíssimas": "distinto",
    "distintíssimo": "distinto",
    "distintíssimos": "distinto",
    "distinções": "distinção",
    "disto": "distar",
    "distocias": "distocia",
    "distocíaca": "distocíaco",
    "distocíacas": "distocíaco",
    "distocíacos": "distocíaco",
    "distomatoses": "distomatose",
    "distomíases": "distomíase",
    "distorce": "distorcer",
    "distorcei": "distorcer",
    "distorceis": "distorcer",
    "distorcem": "distorcer",
    "distorcemo": "distorcer",
    "distorcemos": "distorcer",
    "distorcendo": "distorcer",
    "distorcera": "distorcer",
    "distorceram": "distorcer",
    "distorceras": "distorcer",
    "distorcerde": "distorcer",
    "distorcerdes": "distorcer",
    "distorcere": "distorcer",
    "distorcerei": "distorcer",
    "distorcereis": "distorcer",
    "distorcerem": "distorcer",
    "distorceremos": "distorcer",
    "distorceres": "distorcer",
    "distorceria": "distorcer",
    "distorceriam": "distorcer",
    "distorcerias": "distorcer",
    "distorcermo": "distorcer",
    "distorcermos": "distorcer",
    "distorcerá": "distorcer",
    "distorcerás": "distorcer",
    "distorcerão": "distorcer",
    "distorceríamos": "distorcer",
    "distorceríeis": "distorcer",
    "distorces": "distorcer",
    "distorcesse": "distorcer",
    "distorcessem": "distorcer",
    "distorcesses": "distorcer",
    "distorceste": "distorcer",
    "distorcestes": "distorcer",
    "distorceu": "distorcer",
    "distorci": "distorcer",
    "distorcia": "distorcer",
    "distorciam": "distorcer",
    "distorcias": "distorcer",
    "distorcida": "distorcido",
    "distorcidas": "distorcido",
    "distorcido": "distorcer",
    "distorcidos": "distorcido",
    "distorcê": "distorcer",
    "distorcêramo": "distorcer",
    "distorcêramos": "distorcer",
    "distorcêrei": "distorcer",
    "distorcêreis": "distorcer",
    "distorcêsseis": "distorcer",
    "distorcêssemos": "distorcer",
    "distorcíamo": "distorcer",
    "distorcíamos": "distorcer",
    "distorcíei": "distorcer",
    "distorcíeis": "distorcer",
    "distorcíveis": "distorcível",
    "distorça": "distorcer",
    "distorçais": "distorcer",
    "distorçam": "distorcer",
    "distorçamo": "distorcer",
    "distorçamos": "distorcer",
    "distorças": "distorcer",
    "distorço": "distorcer",
    "distorções": "distorção",
    "distou": "distar",
    "distractiva": "distractivo",
    "distractivas": "distractivo",
    "distractivos": "distractivo",
    "distracções": "distracção",
    "distraem": "distrair",
    "distrai": "distrair",
    "distraia": "distrair",
    "distraiais": "distrair",
    "distraiam": "distrair",
    "distraiamo": "distrair",
    "distraiamos": "distrair",
    "distraias": "distrair",
    "distraidora": "distraidor",
    "distraidoras": "distraidor",
    "distraidores": "distraidor",
    "distraidíssima": "distraído",
    "distraidíssimas": "distraído",
    "distraidíssimo": "distraído",
    "distraidíssimos": "distraído",
    "distraimentos": "distraimento",
    "distraindo": "distrair",
    "distraio": "distrair",
    "distrairde": "distrair",
    "distrairdes": "distrair",
    "distrairei": "distrair",
    "distraireis": "distrair",
    "distrairemos": "distrair",
    "distrairia": "distrair",
    "distrairiam": "distrair",
    "distrairias": "distrair",
    "distrairmo": "distrair",
    "distrairmos": "distrair",
    "distrairá": "distrair",
    "distrairás": "distrair",
    "distrairão": "distrair",
    "distrairíamos": "distrair",
    "distrairíeis": "distrair",
    "distrais": "distrair",
    "distraiu": "distrair",
    "distrata": "distratar",
    "distratada": "distratar",
    "distratadas": "distratar",
    "distratado": "distratar",
    "distratados": "distratar",
    "distratai": "distratar",
    "distratais": "distratar",
    "distratam": "distratar",
    "distratamo": "distratar",
    "distratamos": "distratar",
    "distratando": "distratar",
    "distratara": "distratar",
    "distrataram": "distratar",
    "distrataras": "distratar",
    "distratarde": "distratar",
    "distratardes": "distratar",
    "distratare": "distratar",
    "distratarei": "distratar",
    "distratareis": "distratar",
    "distratarem": "distratar",
    "distrataremos": "distratar",
    "distratares": "distratar",
    "distrataria": "distratar",
    "distratariam": "distratar",
    "distratarias": "distratar",
    "distratarmo": "distratar",
    "distratarmos": "distratar",
    "distratará": "distratar",
    "distratarás": "distratar",
    "distratarão": "distratar",
    "distrataríamos": "distratar",
    "distrataríeis": "distratar",
    "distratas": "distratar",
    "distratasse": "distratar",
    "distratassem": "distratar",
    "distratasses": "distratar",
    "distrataste": "distratar",
    "distratastes": "distratar",
    "distratava": "distratar",
    "distratavam": "distratar",
    "distratavas": "distratar",
    "distrate": "distratar",
    "distratei": "distratar",
    "distrateis": "distratar",
    "distratem": "distratar",
    "distratemo": "distratar",
    "distratemos": "distratar",
    "distrates": "distrate",
    "distrato": "distratar",
    "distratos": "distrato",
    "distratou": "distratar",
    "distratá": "distratar",
    "distratámo": "distratar",
    "distratámos": "distratar",
    "distratáramo": "distratar",
    "distratáramos": "distratar",
    "distratárei": "distratar",
    "distratáreis": "distratar",
    "distratásseis": "distratar",
    "distratássemos": "distratar",
    "distratávamo": "distratar",
    "distratávamos": "distratar",
    "distratávei": "distratar",
    "distratáveis": "distratar",
    "distraí": "distrair",
    "distraía": "distrair",
    "distraíam": "distrair",
    "distraíamo": "distrair",
    "distraíamos": "distrair",
    "distraías": "distrair",
    "distraída": "distrair",
    "distraídas": "distrair",
    "distraído": "distrair",
    "distraídos": "distrair",
    "distraíei": "distrair",
    "distraíeis": "distrair",
    "distraímo": "distrair",
    "distraímos": "distrair",
    "distraíra": "distrair",
    "distraíram": "distrair",
    "distraíramo": "distrair",
    "distraíramos": "distrair",
    "distraíras": "distrair",
    "distraíre": "distrair",
    "distraírei": "distrair",
    "distraíreis": "distrair",
    "distraírem": "distrair",
    "distraíres": "distrair",
    "distraís": "distrair",
    "distraísse": "distrair",
    "distraísseis": "distrair",
    "distraíssem": "distrair",
    "distraíssemos": "distrair",
    "distraísses": "distrair",
    "distraíste": "distrair",
    "distraístes": "distrair",
    "distribua": "distribuir",
    "distribuais": "distribuir",
    "distribuam": "distribuir",
    "distribuamo": "distribuir",
    "distribuamos": "distribuir",
    "distribuas": "distribuir",
    "distribuem": "distribuir",
    "distribui": "distribuir",
    "distribuidora": "distribuidor",
    "distribuidoras": "distribuidor",
    "distribuidores": "distribuidor",
    "distribuindo": "distribuir",
    "distribuirde": "distribuir",
    "distribuirdes": "distribuir",
    "distribuirei": "distribuir",
    "distribuireis": "distribuir",
    "distribuiremos": "distribuir",
    "distribuiria": "distribuir",
    "distribuiriam": "distribuir",
    "distribuirias": "distribuir",
    "distribuirmo": "distribuir",
    "distribuirmos": "distribuir",
    "distribuirá": "distribuir",
    "distribuirás": "distribuir",
    "distribuirão": "distribuir",
    "distribuiríamos": "distribuir",
    "distribuiríeis": "distribuir",
    "distribuis": "distribuir",
    "distribuiu": "distribuir",
    "distribuições": "distribuição",
    "distribuo": "distribuir",
    "distributividades": "distributividade",
    "distribuí": "distribuir",
    "distribuía": "distribuir",
    "distribuíam": "distribuir",
    "distribuíamo": "distribuir",
    "distribuíamos": "distribuir",
    "distribuías": "distribuir",
    "distribuída": "distribuir",
    "distribuídas": "distribuir",
    "distribuído": "distribuir",
    "distribuídos": "distribuir",
    "distribuíei": "distribuir",
    "distribuíeis": "distribuir",
    "distribuímo": "distribuir",
    "distribuímos": "distribuir",
    "distribuíra": "distribuir",
    "distribuíram": "distribuir",
    "distribuíramo": "distribuir",
    "distribuíramos": "distribuir",
    "distribuíras": "distribuir",
    "distribuíre": "distribuir",
    "distribuírei": "distribuir",
    "distribuíreis": "distribuir",
    "distribuírem": "distribuir",
    "distribuíres": "distribuir",
    "distribuís": "distribuir",
    "distribuísse": "distribuir",
    "distribuísseis": "distribuir",
    "distribuíssem": "distribuir",
    "distribuíssemos": "distribuir",
    "distribuísses": "distribuir",
    "distribuíste": "distribuir",
    "distribuístes": "distribuir",
    "distribuíveis": "distribuível",
    "distritais": "distrital",
    "distritos": "distrito",
    "distrofias": "distrofia",
    "distrácteis": "distráctil",
    "distrófica": "distrófico",
    "distróficas": "distrófico",
    "distróficos": "distrófico",
    "disturba": "disturbar",
    "disturbada": "disturbar",
    "disturbadas": "disturbar",
    "disturbado": "disturbar",
    "disturbados": "disturbar",
    "disturbai": "disturbar",
    "disturbais": "disturbar",
    "disturbam": "disturbar",
    "disturbamo": "disturbar",
    "disturbamos": "disturbar",
    "disturbando": "disturbar",
    "disturbara": "disturbar",
    "disturbaram": "disturbar",
    "disturbaras": "disturbar",
    "disturbarde": "disturbar",
    "disturbardes": "disturbar",
    "disturbare": "disturbar",
    "disturbarei": "disturbar",
    "disturbareis": "disturbar",
    "disturbarem": "disturbar",
    "disturbaremos": "disturbar",
    "disturbares": "disturbar",
    "disturbaria": "disturbar",
    "disturbariam": "disturbar",
    "disturbarias": "disturbar",
    "disturbarmo": "disturbar",
    "disturbarmos": "disturbar",
    "disturbará": "disturbar",
    "disturbarás": "disturbar",
    "disturbarão": "disturbar",
    "disturbaríamos": "disturbar",
    "disturbaríeis": "disturbar",
    "disturbas": "disturbar",
    "disturbasse": "disturbar",
    "disturbassem": "disturbar",
    "disturbasses": "disturbar",
    "disturbaste": "disturbar",
    "disturbastes": "disturbar",
    "disturbava": "disturbar",
    "disturbavam": "disturbar",
    "disturbavas": "disturbar",
    "disturbe": "disturbar",
    "disturbei": "disturbar",
    "disturbeis": "disturbar",
    "disturbem": "disturbar",
    "disturbemo": "disturbar",
    "disturbemos": "disturbar",
    "disturbes": "disturbar",
    "disturbo": "disturbar",
    "disturbou": "disturbar",
    "disturbá": "disturbar",
    "disturbámo": "disturbar",
    "disturbámos": "disturbar",
    "disturbáramo": "disturbar",
    "disturbáramos": "disturbar",
    "disturbárei": "disturbar",
    "disturbáreis": "disturbar",
    "disturbásseis": "disturbar",
    "disturbássemos": "disturbar",
    "disturbávamo": "disturbar",
    "disturbávamos": "disturbar",
    "disturbávei": "disturbar",
    "disturbáveis": "disturbável",
    "distá": "distar",
    "distámo": "distar",
    "distámos": "distar",
    "distáramo": "distar",
    "distáramos": "distar",
    "distárei": "distar",
    "distáreis": "distar",
    "distásseis": "distar",
    "distássemos": "distar",
    "distávamo": "distar",
    "distávamos": "distar",
    "distávei": "distar",
    "distáveis": "distar",
    "distâncias": "distância",
    "distócica": "distócico",
    "distócicas": "distócico",
    "distócicos": "distócico",
    "distúrbios": "distúrbio",
    "disúrias": "disúria",
    "disúrica": "disúrico",
    "disúricas": "disúrico",
    "disúricos": "disúrico",
    "dita": "dizer",
    "ditada": "ditar",
    "ditadas": "ditar",
    "ditado": "ditar",
    "ditadora": "ditador",
    "ditadoras": "ditador",
    "ditadores": "ditador",
    "ditados": "ditar",
    "ditaduras": "ditadura",
    "ditai": "ditar",
    "ditais": "ditar",
    "ditam": "ditar",
    "ditames": "ditame",
    "ditamo": "ditar",
    "ditamos": "ditar",
    "ditando": "ditar",
    "ditara": "ditar",
    "ditaram": "ditar",
    "ditaras": "ditar",
    "ditarde": "ditar",
    "ditardes": "ditar",
    "ditare": "ditar",
    "ditarei": "ditar",
    "ditareis": "ditar",
    "ditarem": "ditar",
    "ditaremos": "ditar",
    "ditares": "ditar",
    "ditaria": "ditar",
    "ditariam": "ditar",
    "ditarias": "ditar",
    "ditarmo": "ditar",
    "ditarmos": "ditar",
    "ditará": "ditar",
    "ditarás": "ditar",
    "ditarão": "ditar",
    "ditaríamos": "ditar",
    "ditaríeis": "ditar",
    "ditas": "dizer",
    "ditasse": "ditar",
    "ditassem": "ditar",
    "ditasses": "ditar",
    "ditaste": "ditar",
    "ditastes": "ditar",
    "ditatoriais": "ditatorial",
    "ditaturialismos": "ditaturialismo",
    "ditava": "ditar",
    "ditavam": "ditar",
    "ditavas": "ditar",
    "dite": "ditar",
    "ditei": "ditar",
    "diteis": "ditar",
    "ditem": "ditar",
    "ditemo": "ditar",
    "ditemos": "ditar",
    "dites": "ditar",
    "diteísmos": "diteísmo",
    "ditirambos": "ditirambo",
    "ditirâmbica": "ditirâmbico",
    "ditirâmbicas": "ditirâmbico",
    "ditirâmbicos": "ditirâmbico",
    "dito": "dizer",
    "ditologias": "ditologia",
    "ditongais": "ditongal",
    "ditongações": "ditongação",
    "ditongos": "ditongo",
    "ditos": "dizer",
    "ditosa": "ditoso",
    "ditosas": "ditoso",
    "ditosos": "ditoso",
    "ditotes": "ditote",
    "ditou": "ditar",
    "ditroqueus": "ditroqueu",
    "ditríglifos": "ditríglifo",
    "ditá": "ditar",
    "ditámo": "ditar",
    "ditámos": "ditar",
    "ditáramo": "ditar",
    "ditáramos": "ditar",
    "ditárei": "ditar",
    "ditáreis": "ditar",
    "ditásseis": "ditar",
    "ditássemos": "ditar",
    "ditávamo": "ditar",
    "ditávamos": "ditar",
    "ditávei": "ditar",
    "ditáveis": "ditar",
    "ditérios": "ditério",
    "diuenses": "diuense",
    "diureses": "diurese",
    "diurna": "diurno",
    "diurnais": "diurnal",
    "diurnas": "diurno",
    "diurnos": "diurno",
    "diurécticos": "diuréctico",
    "diurética": "diurético",
    "diuréticas": "diurético",
    "diuréticos": "diurético",
    "diuturna": "diuturno",
    "diuturnas": "diuturno",
    "diuturnidades": "diuturnidade",
    "diuturnos": "diuturno",
    "diva": "divo",
    "divaga": "divagar",
    "divagada": "divagar",
    "divagadas": "divagar",
    "divagado": "divagar",
    "divagadora": "divagador",
    "divagadoras": "divagador",
    "divagadores": "divagador",
    "divagados": "divagar",
    "divagai": "divagar",
    "divagais": "divagar",
    "divagam": "divagar",
    "divagamo": "divagar",
    "divagamos": "divagar",
    "divagando": "divagar",
    "divagantes": "divagante",
    "divagara": "divagar",
    "divagaram": "divagar",
    "divagaras": "divagar",
    "divagardes": "divagar",
    "divagarei": "divagar",
    "divagareis": "divagar",
    "divagarem": "divagar",
    "divagaremos": "divagar",
    "divagares": "divagar",
    "divagaria": "divagar",
    "divagariam": "divagar",
    "divagarias": "divagar",
    "divagarmo": "divagar",
    "divagarmos": "divagar",
    "divagará": "divagar",
    "divagarás": "divagar",
    "divagarão": "divagar",
    "divagaríamos": "divagar",
    "divagaríeis": "divagar",
    "divagas": "divagar",
    "divagasse": "divagar",
    "divagassem": "divagar",
    "divagasses": "divagar",
    "divagaste": "divagar",
    "divagastes": "divagar",
    "divagava": "divagar",
    "divagavam": "divagar",
    "divagavas": "divagar",
    "divagações": "divagação",
    "divago": "divagar",
    "divagou": "divagar",
    "divague": "divagar",
    "divaguei": "divagar",
    "divagueis": "divagar",
    "divaguem": "divagar",
    "divaguemo": "divagar",
    "divaguemos": "divagar",
    "divagues": "divagar",
    "divagámo": "divagar",
    "divagámos": "divagar",
    "divagáramo": "divagar",
    "divagáramos": "divagar",
    "divagáreis": "divagar",
    "divagásseis": "divagar",
    "divagássemos": "divagar",
    "divagávamo": "divagar",
    "divagávamos": "divagar",
    "divagáveis": "divagar",
    "divarica": "divaricar",
    "divaricada": "divaricar",
    "divaricadas": "divaricar",
    "divaricado": "divaricar",
    "divaricados": "divaricar",
    "divaricai": "divaricar",
    "divaricais": "divaricar",
    "divaricam": "divaricar",
    "divaricamo": "divaricar",
    "divaricamos": "divaricar",
    "divaricando": "divaricar",
    "divaricara": "divaricar",
    "divaricaram": "divaricar",
    "divaricaras": "divaricar",
    "divaricarde": "divaricar",
    "divaricardes": "divaricar",
    "divaricare": "divaricar",
    "divaricarei": "divaricar",
    "divaricareis": "divaricar",
    "divaricarem": "divaricar",
    "divaricaremos": "divaricar",
    "divaricares": "divaricar",
    "divaricaria": "divaricar",
    "divaricariam": "divaricar",
    "divaricarias": "divaricar",
    "divaricarmo": "divaricar",
    "divaricarmos": "divaricar",
    "divaricará": "divaricar",
    "divaricarás": "divaricar",
    "divaricarão": "divaricar",
    "divaricaríamos": "divaricar",
    "divaricaríeis": "divaricar",
    "divaricas": "divaricar",
    "divaricasse": "divaricar",
    "divaricassem": "divaricar",
    "divaricasses": "divaricar",
    "divaricaste": "divaricar",
    "divaricastes": "divaricar",
    "divaricava": "divaricar",
    "divaricavam": "divaricar",
    "divaricavas": "divaricar",
    "divaricações": "divaricação",
    "divarico": "divaricar",
    "divaricou": "divaricar",
    "divaricá": "divaricar",
    "divaricámo": "divaricar",
    "divaricámos": "divaricar",
    "divaricáramo": "divaricar",
    "divaricáramos": "divaricar",
    "divaricárei": "divaricar",
    "divaricáreis": "divaricar",
    "divaricásseis": "divaricar",
    "divaricássemos": "divaricar",
    "divaricávamo": "divaricar",
    "divaricávamos": "divaricar",
    "divaricávei": "divaricar",
    "divaricáveis": "divaricar",
    "divarique": "divaricar",
    "divariquei": "divaricar",
    "divariqueis": "divaricar",
    "divariquem": "divaricar",
    "divariquemo": "divaricar",
    "divariquemos": "divaricar",
    "divariques": "divaricar",
    "divas": "divo",
    "diverge": "divergir",
    "divergem": "divergir",
    "divergentes": "divergente",
    "diverges": "divergir",
    "divergi": "divergir",
    "divergia": "divergir",
    "divergiam": "divergir",
    "divergias": "divergir",
    "divergida": "divergir",
    "divergidas": "divergir",
    "divergido": "divergir",
    "divergidos": "divergir",
    "divergimo": "divergir",
    "divergimos": "divergir",
    "divergindo": "divergir",
    "divergira": "divergir",
    "divergiram": "divergir",
    "divergiras": "divergir",
    "divergirde": "divergir",
    "divergirdes": "divergir",
    "divergire": "divergir",
    "divergirei": "divergir",
    "divergireis": "divergir",
    "divergirem": "divergir",
    "divergiremos": "divergir",
    "divergires": "divergir",
    "divergiria": "divergir",
    "divergiriam": "divergir",
    "divergirias": "divergir",
    "divergirmo": "divergir",
    "divergirmos": "divergir",
    "divergirá": "divergir",
    "divergirás": "divergir",
    "divergirão": "divergir",
    "divergiríamos": "divergir",
    "divergiríeis": "divergir",
    "divergis": "divergir",
    "divergisse": "divergir",
    "divergissem": "divergir",
    "divergisses": "divergir",
    "divergiste": "divergir",
    "divergistes": "divergir",
    "divergiu": "divergir",
    "divergências": "divergência",
    "divergíamo": "divergir",
    "divergíamos": "divergir",
    "divergíei": "divergir",
    "divergíeis": "divergir",
    "divergíramo": "divergir",
    "divergíramos": "divergir",
    "divergírei": "divergir",
    "divergíreis": "divergir",
    "divergísseis": "divergir",
    "divergíssemos": "divergir",
    "diversa": "diverso",
    "diversas": "diverso",
    "diversidades": "diversidade",
    "diversifica": "diversificar",
    "diversificada": "diversificar",
    "diversificadas": "diversificar",
    "diversificado": "diversificar",
    "diversificados": "diversificar",
    "diversificai": "diversificar",
    "diversificais": "diversificar",
    "diversificam": "diversificar",
    "diversificamo": "diversificar",
    "diversificamos": "diversificar",
    "diversificando": "diversificar",
    "diversificantes": "diversificante",
    "diversificara": "diversificar",
    "diversificaram": "diversificar",
    "diversificaras": "diversificar",
    "diversificarde": "diversificar",
    "diversificardes": "diversificar",
    "diversificare": "diversificar",
    "diversificarei": "diversificar",
    "diversificareis": "diversificar",
    "diversificarem": "diversificar",
    "diversificaremos": "diversificar",
    "diversificares": "diversificar",
    "diversificaria": "diversificar",
    "diversificariam": "diversificar",
    "diversificarias": "diversificar",
    "diversificarmo": "diversificar",
    "diversificarmos": "diversificar",
    "diversificará": "diversificar",
    "diversificarás": "diversificar",
    "diversificarão": "diversificar",
    "diversificaríamos": "diversificar",
    "diversificaríeis": "diversificar",
    "diversificas": "diversificar",
    "diversificasse": "diversificar",
    "diversificassem": "diversificar",
    "diversificasses": "diversificar",
    "diversificaste": "diversificar",
    "diversificastes": "diversificar",
    "diversificava": "diversificar",
    "diversificavam": "diversificar",
    "diversificavas": "diversificar",
    "diversificações": "diversificação",
    "diversifico": "diversificar",
    "diversificou": "diversificar",
    "diversificá": "diversificar",
    "diversificámo": "diversificar",
    "diversificámos": "diversificar",
    "diversificáramo": "diversificar",
    "diversificáramos": "diversificar",
    "diversificárei": "diversificar",
    "diversificáreis": "diversificar",
    "diversificásseis": "diversificar",
    "diversificássemos": "diversificar",
    "diversificávamo": "diversificar",
    "diversificávamos": "diversificar",
    "diversificávei": "diversificar",
    "diversificáveis": "diversificável",
    "diversifique": "diversificar",
    "diversifiquei": "diversificar",
    "diversifiqueis": "diversificar",
    "diversifiquem": "diversificar",
    "diversifiquemo": "diversificar",
    "diversifiquemos": "diversificar",
    "diversifiques": "diversificar",
    "diversiformes": "diversiforme",
    "diversiva": "diversivo",
    "diversivas": "diversivo",
    "diversivos": "diversivo",
    "diversos": "diverso",
    "diversória": "diversório",
    "diversórias": "diversório",
    "diversórios": "diversório",
    "diversões": "diversão",
    "diverte": "divertir",
    "divertem": "divertir",
    "divertes": "divertir",
    "diverti": "divertir",
    "divertia": "divertir",
    "divertiam": "divertir",
    "divertias": "divertir",
    "divertida": "divertir",
    "divertidas": "divertir",
    "divertido": "divertir",
    "divertidos": "divertir",
    "divertidíssima": "divertido",
    "divertidíssimas": "divertido",
    "divertidíssimo": "divertido",
    "divertidíssimos": "divertido",
    "divertimentos": "divertimento",
    "divertimo": "divertir",
    "divertimos": "divertir",
    "divertindo": "divertir",
    "divertira": "divertir",
    "divertiram": "divertir",
    "divertiras": "divertir",
    "divertirde": "divertir",
    "divertirdes": "divertir",
    "divertire": "divertir",
    "divertirei": "divertir",
    "divertireis": "divertir",
    "divertirem": "divertir",
    "divertiremos": "divertir",
    "divertires": "divertir",
    "divertiria": "divertir",
    "divertiriam": "divertir",
    "divertirias": "divertir",
    "divertirmo": "divertir",
    "divertirmos": "divertir",
    "divertirá": "divertir",
    "divertirás": "divertir",
    "divertirão": "divertir",
    "divertiríamos": "divertir",
    "divertiríeis": "divertir",
    "divertis": "divertir",
    "divertisse": "divertir",
    "divertissem": "divertir",
    "divertisses": "divertir",
    "divertiste": "divertir",
    "divertistes": "divertir",
    "divertiu": "divertir",
    "divertíamo": "divertir",
    "divertíamos": "divertir",
    "divertículos": "divertículo",
    "divertíei": "divertir",
    "divertíeis": "divertir",
    "divertíramo": "divertir",
    "divertíramos": "divertir",
    "divertírei": "divertir",
    "divertíreis": "divertir",
    "divertísseis": "divertir",
    "divertíssemos": "divertir",
    "divertíveis": "divertível",
    "diviciosa": "divicioso",
    "diviciosas": "divicioso",
    "diviciosos": "divicioso",
    "divida": "dividir",
    "dividais": "dividir",
    "dividam": "dividir",
    "dividamo": "dividir",
    "dividamos": "dividir",
    "dividas": "dividir",
    "divide": "dividir",
    "dividem": "dividir",
    "dividenda": "dividendo",
    "dividendas": "dividendo",
    "dividendos": "dividendo",
    "divides": "dividir",
    "dividi": "dividir",
    "dividia": "dividir",
    "dividiam": "dividir",
    "dividias": "dividir",
    "dividida": "dividir",
    "divididas": "dividir",
    "dividido": "dividir",
    "divididos": "dividir",
    "dividimo": "dividir",
    "dividimos": "dividir",
    "dividindo": "dividir",
    "dividira": "dividir",
    "dividiram": "dividir",
    "dividiras": "dividir",
    "dividirde": "dividir",
    "dividirdes": "dividir",
    "dividire": "dividir",
    "dividirei": "dividir",
    "dividireis": "dividir",
    "dividirem": "dividir",
    "dividiremos": "dividir",
    "dividires": "dividir",
    "dividiria": "dividir",
    "dividiriam": "dividir",
    "dividirias": "dividir",
    "dividirmo": "dividir",
    "dividirmos": "dividir",
    "dividirá": "dividir",
    "dividirás": "dividir",
    "dividirão": "dividir",
    "dividiríamos": "dividir",
    "dividiríeis": "dividir",
    "dividis": "dividir",
    "dividisse": "dividir",
    "dividissem": "dividir",
    "dividisses": "dividir",
    "dividiste": "dividir",
    "dividistes": "dividir",
    "dividiu": "dividir",
    "divido": "dividir",
    "dividíamo": "dividir",
    "dividíamos": "dividir",
    "dividíei": "dividir",
    "dividíeis": "dividir",
    "dividíramo": "dividir",
    "dividíramos": "dividir",
    "dividírei": "dividir",
    "dividíreis": "dividir",
    "dividísseis": "dividir",
    "dividíssemos": "dividir",
    "divina": "divino",
    "divinadora": "divinador",
    "divinadoras": "divinador",
    "divinadores": "divinador",
    "divinais": "divinal",
    "divinantes": "divinante",
    "divinas": "divino",
    "divinatrizes": "divinatriz",
    "divinatória": "divinatório",
    "divinatórias": "divinatório",
    "divinatórios": "divinatório",
    "divinações": "divinação",
    "divindades": "divindade",
    "diviniza": "divinizar",
    "divinizada": "divinizar",
    "divinizadas": "divinizar",
    "divinizado": "divinizar",
    "divinizados": "divinizar",
    "divinizai": "divinizar",
    "divinizais": "divinizar",
    "divinizam": "divinizar",
    "divinizamo": "divinizar",
    "divinizamos": "divinizar",
    "divinizando": "divinizar",
    "divinizara": "divinizar",
    "divinizaram": "divinizar",
    "divinizaras": "divinizar",
    "divinizarde": "divinizar",
    "divinizardes": "divinizar",
    "divinizare": "divinizar",
    "divinizarei": "divinizar",
    "divinizareis": "divinizar",
    "divinizarem": "divinizar",
    "divinizaremos": "divinizar",
    "divinizares": "divinizar",
    "divinizaria": "divinizar",
    "divinizariam": "divinizar",
    "divinizarias": "divinizar",
    "divinizarmo": "divinizar",
    "divinizarmos": "divinizar",
    "divinizará": "divinizar",
    "divinizarás": "divinizar",
    "divinizarão": "divinizar",
    "divinizaríamos": "divinizar",
    "divinizaríeis": "divinizar",
    "divinizas": "divinizar",
    "divinizasse": "divinizar",
    "divinizassem": "divinizar",
    "divinizasses": "divinizar",
    "divinizaste": "divinizar",
    "divinizastes": "divinizar",
    "divinizava": "divinizar",
    "divinizavam": "divinizar",
    "divinizavas": "divinizar",
    "divinizações": "divinização",
    "divinize": "divinizar",
    "divinizei": "divinizar",
    "divinizeis": "divinizar",
    "divinizem": "divinizar",
    "divinizemo": "divinizar",
    "divinizemos": "divinizar",
    "divinizes": "divinizar",
    "divinizo": "divinizar",
    "divinizou": "divinizar",
    "divinizá": "divinizar",
    "divinizámo": "divinizar",
    "divinizámos": "divinizar",
    "divinizáramo": "divinizar",
    "divinizáramos": "divinizar",
    "divinizárei": "divinizar",
    "divinizáreis": "divinizar",
    "divinizásseis": "divinizar",
    "divinizássemos": "divinizar",
    "divinizávamo": "divinizar",
    "divinizávamos": "divinizar",
    "divinizávei": "divinizar",
    "divinizáveis": "divinizável",
    "divinos": "divino",
    "divirja": "divergir",
    "divirjais": "divergir",
    "divirjam": "divergir",
    "divirjamo": "divergir",
    "divirjamos": "divergir",
    "divirjas": "divergir",
    "divirjo": "divergir",
    "divirta": "divertir",
    "divirtais": "divertir",
    "divirtam": "divertir",
    "divirtamo": "divertir",
    "divirtamos": "divertir",
    "divirtas": "divertir",
    "divirto": "divertir",
    "divisa": "diviso",
    "divisada": "divisar",
    "divisadas": "divisar",
    "divisado": "divisar",
    "divisados": "divisar",
    "divisai": "divisar",
    "divisais": "divisar",
    "divisam": "divisar",
    "divisamo": "divisar",
    "divisamos": "divisar",
    "divisando": "divisar",
    "divisara": "divisar",
    "divisaram": "divisar",
    "divisaras": "divisar",
    "divisarde": "divisar",
    "divisardes": "divisar",
    "divisare": "divisar",
    "divisarei": "divisar",
    "divisareis": "divisar",
    "divisarem": "divisar",
    "divisaremos": "divisar",
    "divisares": "divisar",
    "divisaria": "divisar",
    "divisariam": "divisar",
    "divisarias": "divisar",
    "divisarmo": "divisar",
    "divisarmos": "divisar",
    "divisará": "divisar",
    "divisarás": "divisar",
    "divisarão": "divisar",
    "divisaríamos": "divisar",
    "divisaríeis": "divisar",
    "divisas": "diviso",
    "divisasse": "divisar",
    "divisassem": "divisar",
    "divisasses": "divisar",
    "divisaste": "divisar",
    "divisastes": "divisar",
    "divisava": "divisar",
    "divisavam": "divisar",
    "divisavas": "divisar",
    "divise": "divisar",
    "divisei": "divisar",
    "diviseis": "divisar",
    "divisem": "divisar",
    "divisemo": "divisar",
    "divisemos": "divisar",
    "divises": "divisar",
    "divisibilidades": "divisibilidade",
    "divisionais": "divisional",
    "divisionismos": "divisionismo",
    "divisionistas": "divisionista",
    "divisionária": "divisionário",
    "divisionárias": "divisionário",
    "divisionários": "divisionário",
    "diviso": "divisar",
    "divisora": "divisor",
    "divisoras": "divisor",
    "divisores": "divisor",
    "divisos": "diviso",
    "divisou": "divisar",
    "divisá": "divisar",
    "divisámo": "divisar",
    "divisámos": "divisar",
    "divisáramo": "divisar",
    "divisáramos": "divisar",
    "divisárei": "divisar",
    "divisáreis": "divisar",
    "divisásseis": "divisar",
    "divisássemos": "divisar",
    "divisávamo": "divisar",
    "divisávamos": "divisar",
    "divisávei": "divisar",
    "divisáveis": "divisar",
    "divisíveis": "divisível",
    "divisória": "divisório",
    "divisórias": "divisório",
    "divisórios": "divisório",
    "divisões": "divisão",
    "divodignos": "divodigno",
    "divorcia": "divorciar",
    "divorciada": "divorciar",
    "divorciadas": "divorciar",
    "divorciado": "divorciar",
    "divorciados": "divorciar",
    "divorciai": "divorciar",
    "divorciais": "divorciar",
    "divorciam": "divorciar",
    "divorciamo": "divorciar",
    "divorciamos": "divorciar",
    "divorciando": "divorciar",
    "divorciara": "divorciar",
    "divorciaram": "divorciar",
    "divorciaras": "divorciar",
    "divorciarde": "divorciar",
    "divorciardes": "divorciar",
    "divorciare": "divorciar",
    "divorciarei": "divorciar",
    "divorciareis": "divorciar",
    "divorciarem": "divorciar",
    "divorciaremos": "divorciar",
    "divorciares": "divorciar",
    "divorciaria": "divorciar",
    "divorciariam": "divorciar",
    "divorciarias": "divorciar",
    "divorciarmo": "divorciar",
    "divorciarmos": "divorciar",
    "divorciará": "divorciar",
    "divorciarás": "divorciar",
    "divorciarão": "divorciar",
    "divorciaríamos": "divorciar",
    "divorciaríeis": "divorciar",
    "divorcias": "divorciar",
    "divorciasse": "divorciar",
    "divorciassem": "divorciar",
    "divorciasses": "divorciar",
    "divorciaste": "divorciar",
    "divorciastes": "divorciar",
    "divorciava": "divorciar",
    "divorciavam": "divorciar",
    "divorciavas": "divorciar",
    "divorcie": "divorciar",
    "divorciei": "divorciar",
    "divorcieis": "divorciar",
    "divorciem": "divorciar",
    "divorciemo": "divorciar",
    "divorciemos": "divorciar",
    "divorcies": "divorciar",
    "divorcio": "divorciar",
    "divorciou": "divorciar",
    "divorciá": "divorciar",
    "divorciámo": "divorciar",
    "divorciámos": "divorciar",
    "divorciáramo": "divorciar",
    "divorciáramos": "divorciar",
    "divorciárei": "divorciar",
    "divorciáreis": "divorciar",
    "divorciásseis": "divorciar",
    "divorciássemos": "divorciar",
    "divorciávamo": "divorciar",
    "divorciávamos": "divorciar",
    "divorciávei": "divorciar",
    "divorciáveis": "divorciável",
    "divos": "divo",
    "divulga": "divulgar",
    "divulgada": "divulgar",
    "divulgadas": "divulgar",
    "divulgado": "divulgar",
    "divulgadora": "divulgador",
    "divulgadoras": "divulgador",
    "divulgadores": "divulgador",
    "divulgados": "divulgar",
    "divulgai": "divulgar",
    "divulgais": "divulgar",
    "divulgam": "divulgar",
    "divulgamo": "divulgar",
    "divulgamos": "divulgar",
    "divulgando": "divulgar",
    "divulgara": "divulgar",
    "divulgaram": "divulgar",
    "divulgaras": "divulgar",
    "divulgarde": "divulgar",
    "divulgardes": "divulgar",
    "divulgare": "divulgar",
    "divulgarei": "divulgar",
    "divulgareis": "divulgar",
    "divulgarem": "divulgar",
    "divulgaremos": "divulgar",
    "divulgares": "divulgar",
    "divulgaria": "divulgar",
    "divulgariam": "divulgar",
    "divulgarias": "divulgar",
    "divulgarmo": "divulgar",
    "divulgarmos": "divulgar",
    "divulgará": "divulgar",
    "divulgarás": "divulgar",
    "divulgarão": "divulgar",
    "divulgaríamos": "divulgar",
    "divulgaríeis": "divulgar",
    "divulgas": "divulgar",
    "divulgasse": "divulgar",
    "divulgassem": "divulgar",
    "divulgasses": "divulgar",
    "divulgaste": "divulgar",
    "divulgastes": "divulgar",
    "divulgava": "divulgar",
    "divulgavam": "divulgar",
    "divulgavas": "divulgar",
    "divulgações": "divulgação",
    "divulgo": "divulgar",
    "divulgou": "divulgar",
    "divulgue": "divulgar",
    "divulguei": "divulgar",
    "divulgueis": "divulgar",
    "divulguem": "divulgar",
    "divulguemo": "divulgar",
    "divulguemos": "divulgar",
    "divulgues": "divulgar",
    "divulgá": "divulgar",
    "divulgámo": "divulgar",
    "divulgámos": "divulgar",
    "divulgáramo": "divulgar",
    "divulgáramos": "divulgar",
    "divulgárei": "divulgar",
    "divulgáreis": "divulgar",
    "divulgásseis": "divulgar",
    "divulgássemos": "divulgar",
    "divulgávamo": "divulgar",
    "divulgávamos": "divulgar",
    "divulgávei": "divulgar",
    "divulgáveis": "divulgável",
    "divulsões": "divulsão",
    "divãs": "divã",
    "divícias": "divícia",
    "divídua": "divíduo",
    "divíduas": "divíduo",
    "divíduos": "divíduo",
    "divórcios": "divórcio",
    "dixes": "dixe",
    "diz": "dizer",
    "dize": "dizer",
    "dizedelas": "dizedela",
    "dizedora": "dizedor",
    "dizedoras": "dizedor",
    "dizedores": "dizedor",
    "dizei": "dizer",
    "dizeis": "dizer",
    "dizem": "dizer",
    "dizemo": "dizer",
    "dizemos": "dizer",
    "dizendo": "dizer",
    "dizerde": "dizer",
    "dizerdes": "dizer",
    "dizere": "dizer",
    "dizerem": "dizer",
    "dizeres": "dizer",
    "dizermo": "dizer",
    "dizermos": "dizer",
    "dizes": "dizer",
    "dizia": "dizer",
    "diziam": "dizer",
    "dizias": "dizer",
    "dizima": "dizimar",
    "dizimada": "dizimar",
    "dizimadas": "dizimar",
    "dizimado": "dizimar",
    "dizimadora": "dizimador",
    "dizimadoras": "dizimador",
    "dizimadores": "dizimador",
    "dizimados": "dizimar",
    "dizimai": "dizimar",
    "dizimais": "dizimar",
    "dizimam": "dizimar",
    "dizimamo": "dizimar",
    "dizimamos": "dizimar",
    "dizimando": "dizimar",
    "dizimara": "dizimar",
    "dizimaram": "dizimar",
    "dizimaras": "dizimar",
    "dizimarde": "dizimar",
    "dizimardes": "dizimar",
    "dizimare": "dizimar",
    "dizimarei": "dizimar",
    "dizimareis": "dizimar",
    "dizimarem": "dizimar",
    "dizimaremos": "dizimar",
    "dizimares": "dizimar",
    "dizimaria": "dizimar",
    "dizimariam": "dizimar",
    "dizimarias": "dizimaria",
    "dizimarmo": "dizimar",
    "dizimarmos": "dizimar",
    "dizimará": "dizimar",
    "dizimarás": "dizimar",
    "dizimarão": "dizimar",
    "dizimaríamos": "dizimar",
    "dizimaríeis": "dizimar",
    "dizimas": "dizimar",
    "dizimasse": "dizimar",
    "dizimassem": "dizimar",
    "dizimasses": "dizimar",
    "dizimaste": "dizimar",
    "dizimastes": "dizimar",
    "dizimava": "dizimar",
    "dizimavam": "dizimar",
    "dizimavas": "dizimar",
    "dizimações": "dizimação",
    "dizime": "dizimar",
    "dizimei": "dizimar",
    "dizimeira": "dizimeiro",
    "dizimeiras": "dizimeiro",
    "dizimeiros": "dizimeiro",
    "dizimeis": "dizimar",
    "dizimem": "dizimar",
    "dizimemo": "dizimar",
    "dizimemos": "dizimar",
    "dizimes": "dizimar",
    "dizimo": "dizimar",
    "dizimou": "dizimar",
    "dizimá": "dizimar",
    "dizimámo": "dizimar",
    "dizimámos": "dizimar",
    "dizimáramo": "dizimar",
    "dizimáramos": "dizimar",
    "dizimárei": "dizimar",
    "dizimáreis": "dizimar",
    "dizimásseis": "dizimar",
    "dizimássemos": "dizimar",
    "dizimávamo": "dizimar",
    "dizimávamos": "dizimar",
    "dizimávei": "dizimar",
    "dizimáveis": "dizimável",
    "dizê": "dizer",
    "dizíamo": "dizer",
    "dizíamos": "dizer",
    "dizíei": "dizer",
    "dizíeis": "dizer",
    "dizíveis": "dizível",
    "diábases": "diábase",
    "diáclases": "diáclase",
    "diáconos": "diácono",
    "diácopes": "diácope",
    "diádicos": "diádico",
    "diáfana": "diáfano",
    "diáfanas": "diáfano",
    "diáfanos": "diáfano",
    "diáfises": "diáfise",
    "diáforas": "diáfora",
    "diágrafos": "diágrafo",
    "diálages": "diálage",
    "diálises": "diálise",
    "diálogos": "diálogo",
    "diápiros": "diápiro",
    "diária": "diário",
    "diárias": "diário",
    "diários": "diário",
    "diásporos": "diásporo",
    "diástases": "diástase",
    "diásteres": "diáster",
    "diástoles": "diástole",
    "diáteses": "diátese",
    "diâmetros": "diâmetro",
    "diândrias": "diândria",
    "dições": "dição",
    "diédrica": "diédrico",
    "diédricas": "diédrico",
    "diédricos": "diédrico",
    "diéreses": "diérese",
    "dióica": "dióico",
    "dióicas": "dióico",
    "dióicos": "dióico",
    "diópsidos": "diópsido",
    "dióptrica": "dióptrico",
    "dióptricas": "dióptrico",
    "dióptricos": "dióptrico",
    "dióspiros": "dióspiro",
    "dióxidos": "dióxido",
    "doa": "doer",
    "doada": "doar",
    "doadas": "doar",
    "doado": "doar",
    "doadora": "doador",
    "doadoras": "doador",
    "doadores": "doador",
    "doados": "doar",
    "doai": "doar",
    "doais": "doer",
    "doam": "doer",
    "doamo": "doer",
    "doamos": "doer",
    "doando": "doar",
    "doara": "doar",
    "doaram": "doar",
    "doaras": "doar",
    "doarde": "doar",
    "doardes": "doar",
    "doare": "doar",
    "doarei": "doar",
    "doareis": "doar",
    "doarem": "doar",
    "doaremos": "doar",
    "doares": "doar",
    "doaria": "doar",
    "doariam": "doar",
    "doarias": "doar",
    "doarmo": "doar",
    "doarmos": "doar",
    "doará": "doar",
    "doarás": "doar",
    "doarão": "doar",
    "doaríamos": "doar",
    "doaríeis": "doar",
    "doas": "doer",
    "doasse": "doar",
    "doassem": "doar",
    "doasses": "doar",
    "doaste": "doar",
    "doastes": "doar",
    "doava": "doar",
    "doavam": "doar",
    "doavas": "doar",
    "doações": "doação",
    "doba": "dobar",
    "dobada": "dobar",
    "dobadas": "dobar",
    "dobadeiras": "dobadeira",
    "dobado": "dobar",
    "dobadoiras": "dobadoira",
    "dobados": "dobar",
    "dobadouras": "dobadoura",
    "dobagens": "dobagem",
    "dobai": "dobar",
    "dobais": "dobar",
    "dobam": "dobar",
    "dobamo": "dobar",
    "dobamos": "dobar",
    "dobando": "dobar",
    "dobara": "dobar",
    "dobaram": "dobar",
    "dobaras": "dobar",
    "dobarde": "dobar",
    "dobardes": "dobar",
    "dobare": "dobar",
    "dobarei": "dobar",
    "dobareis": "dobar",
    "dobarem": "dobar",
    "dobaremos": "dobar",
    "dobares": "dobar",
    "dobaria": "dobar",
    "dobariam": "dobar",
    "dobarias": "dobar",
    "dobarmo": "dobar",
    "dobarmos": "dobar",
    "dobará": "dobar",
    "dobarás": "dobar",
    "dobarão": "dobar",
    "dobaríamos": "dobar",
    "dobaríeis": "dobar",
    "dobas": "dobar",
    "dobasse": "dobar",
    "dobassem": "dobar",
    "dobasses": "dobar",
    "dobaste": "dobar",
    "dobastes": "dobar",
    "dobava": "dobar",
    "dobavam": "dobar",
    "dobavas": "dobar",
    "dobe": "dobar",
    "dobei": "dobar",
    "dobeis": "dobar",
    "dobem": "dobar",
    "dobemo": "dobar",
    "dobemos": "dobar",
    "dobermanns": "dobermann",
    "dobes": "dobar",
    "doblas": "dobla",
    "dobles": "doble",
    "dobletes": "doblete",
    "doblezes": "doblez",
    "dobo": "dobar",
    "dobou": "dobar",
    "dobra": "dobrar",
    "dobrada": "dobrar",
    "dobradas": "dobrar",
    "dobradeira": "dobrador",
    "dobradeiras": "dobrador",
    "dobradinhas": "dobradinha",
    "dobradiça": "dobradiço",
    "dobradiças": "dobradiço",
    "dobradiços": "dobradiço",
    "dobrado": "dobrar",
    "dobradora": "dobrador",
    "dobradoras": "dobrador",
    "dobradores": "dobrador",
    "dobrados": "dobrar",
    "dobraduras": "dobradura",
    "dobragens": "dobragem",
    "dobrai": "dobrar",
    "dobrais": "dobrar",
    "dobram": "dobrar",
    "dobramentos": "dobramento",
    "dobramo": "dobrar",
    "dobramos": "dobrar",
    "dobrando": "dobrar",
    "dobrara": "dobrar",
    "dobraram": "dobrar",
    "dobraras": "dobrar",
    "dobrarde": "dobrar",
    "dobrardes": "dobrar",
    "dobrare": "dobrar",
    "dobrarei": "dobrar",
    "dobrareis": "dobrar",
    "dobrarem": "dobrar",
    "dobraremos": "dobrar",
    "dobrares": "dobrar",
    "dobraria": "dobrar",
    "dobrariam": "dobrar",
    "dobrarias": "dobrar",
    "dobrarmo": "dobrar",
    "dobrarmos": "dobrar",
    "dobrará": "dobrar",
    "dobrarás": "dobrar",
    "dobrarão": "dobrar",
    "dobraríamos": "dobrar",
    "dobraríeis": "dobrar",
    "dobras": "dobrar",
    "dobrasse": "dobrar",
    "dobrassem": "dobrar",
    "dobrasses": "dobrar",
    "dobraste": "dobrar",
    "dobrastes": "dobrar",
    "dobrava": "dobrar",
    "dobravam": "dobrar",
    "dobravas": "dobrar",
    "dobre": "dobrar",
    "dobrei": "dobrar",
    "dobreis": "dobrar",
    "dobrem": "dobrar",
    "dobremo": "dobrar",
    "dobremos": "dobrar",
    "dobres": "dobre",
    "dobrezes": "dobrez",
    "dobro": "dobrar",
    "dobros": "dobro",
    "dobrou": "dobrar",
    "dobrá": "dobrar",
    "dobrámo": "dobrar",
    "dobrámos": "dobrar",
    "dobráramo": "dobrar",
    "dobráramos": "dobrar",
    "dobrárei": "dobrar",
    "dobráreis": "dobrar",
    "dobrásseis": "dobrar",
    "dobrássemos": "dobrar",
    "dobrávamo": "dobrar",
    "dobrávamos": "dobrar",
    "dobrávei": "dobrar",
    "dobráveis": "dobrável",
    "dobrões": "dobrão",
    "dobá": "dobar",
    "dobámo": "dobar",
    "dobámos": "dobar",
    "dobáramo": "dobar",
    "dobáramos": "dobar",
    "dobárei": "dobar",
    "dobáreis": "dobar",
    "dobásseis": "dobar",
    "dobássemos": "dobar",
    "dobávamo": "dobar",
    "dobávamos": "dobar",
    "dobávei": "dobar",
    "dobáveis": "dobável",
    "docares": "docar",
    "docas": "doca",
    "doceira": "doceiro",
    "doceiras": "doceiro",
    "doceiros": "doceiro",
    "doceizinhas": "dócil",
    "doceizinhos": "dócil",
    "doceizitas": "dócil",
    "doceizitos": "dócil",
    "docentes": "docente",
    "doces": "doce",
    "docetismos": "docetismo",
    "docilidades": "docilidade",
    "docilzinha": "dócil",
    "docilzinho": "dócil",
    "docilzita": "dócil",
    "docilzito": "dócil",
    "docimasias": "docimasia",
    "docimologias": "docimologia",
    "docimástica": "docimástico",
    "docimásticas": "docimástico",
    "docimásticos": "docimástico",
    "docinha": "doce",
    "docinhas": "doce",
    "docinho": "doce",
    "docinhos": "docinho",
    "docistas": "docista",
    "docita": "doce",
    "docitas": "doce",
    "docito": "doce",
    "docitos": "doce",
    "doctíloqua": "doctíloquo",
    "doctíloquas": "doctíloquo",
    "doctíloquos": "doctíloquo",
    "documenta": "documentar",
    "documentada": "documentar",
    "documentadas": "documentar",
    "documentado": "documentar",
    "documentados": "documentar",
    "documentadíssima": "documentado",
    "documentadíssimas": "documentado",
    "documentadíssimo": "documentado",
    "documentadíssimos": "documentado",
    "documentai": "documentar",
    "documentais": "documentar",
    "documentam": "documentar",
    "documentamo": "documentar",
    "documentamos": "documentar",
    "documentando": "documentar",
    "documentara": "documentar",
    "documentaram": "documentar",
    "documentaras": "documentar",
    "documentarde": "documentar",
    "documentardes": "documentar",
    "documentare": "documentar",
    "documentarei": "documentar",
    "documentareis": "documentar",
    "documentarem": "documentar",
    "documentaremos": "documentar",
    "documentares": "documentar",
    "documentaria": "documentar",
    "documentariam": "documentar",
    "documentarias": "documentar",
    "documentaristas": "documentarista",
    "documentarmo": "documentar",
    "documentarmos": "documentar",
    "documentará": "documentar",
    "documentarás": "documentar",
    "documentarão": "documentar",
    "documentaríamos": "documentar",
    "documentaríeis": "documentar",
    "documentas": "documentar",
    "documentasse": "documentar",
    "documentassem": "documentar",
    "documentasses": "documentar",
    "documentaste": "documentar",
    "documentastes": "documentar",
    "documentativa": "documentativo",
    "documentativas": "documentativo",
    "documentativos": "documentativo",
    "documentava": "documentar",
    "documentavam": "documentar",
    "documentavas": "documentar",
    "documentações": "documentação",
    "documente": "documentar",
    "documentei": "documentar",
    "documenteis": "documentar",
    "documentem": "documentar",
    "documentemo": "documentar",
    "documentemos": "documentar",
    "documentes": "documentar",
    "documento": "documentar",
    "documentos": "documento",
    "documentou": "documentar",
    "documentá": "documentar",
    "documentámo": "documentar",
    "documentámos": "documentar",
    "documentáramo": "documentar",
    "documentáramos": "documentar",
    "documentárei": "documentar",
    "documentáreis": "documentar",
    "documentária": "documentário",
    "documentárias": "documentário",
    "documentários": "documentário",
    "documentásseis": "documentar",
    "documentássemos": "documentar",
    "documentávamo": "documentar",
    "documentávamos": "documentar",
    "documentávei": "documentar",
    "documentáveis": "documentável",
    "docências": "docência",
    "docílima": "dócil",
    "docílimas": "dócil",
    "docílimo": "dócil",
    "docílimos": "dócil",
    "dodecaedros": "dodecaedro",
    "dodecaginias": "dodecaginia",
    "dodecagonais": "dodecagonal",
    "dodecandra": "dodecandro",
    "dodecandras": "dodecandro",
    "dodecandrias": "dodecandria",
    "dodecandros": "dodecandro",
    "dodecassílaba": "dodecassílabo",
    "dodecassílabas": "dodecassílabo",
    "dodecassílabos": "dodecassílabo",
    "dodecágina": "dodecágino",
    "dodecáginas": "dodecágino",
    "dodecáginos": "dodecágino",
    "dodecágonos": "dodecágono",
    "dodecândrias": "dodecândria",
    "dodrantais": "dodrantal",
    "dodrantes": "dodrante",
    "dodóis": "dodói",
    "doe": "doar",
    "doei": "doer",
    "doeis": "doer",
    "doem": "doer",
    "doemo": "doer",
    "doemos": "doer",
    "doendo": "doer",
    "doentes": "doente",
    "doentezinha": "doente",
    "doentezinhas": "doente",
    "doentezinho": "doente",
    "doentezinhos": "doente",
    "doentezita": "doente",
    "doentezitas": "doente",
    "doentezito": "doente",
    "doentezitos": "doente",
    "doentia": "doentio",
    "doentias": "doentio",
    "doentinha": "doente",
    "doentinhas": "doente",
    "doentinho": "doente",
    "doentinhos": "doente",
    "doentios": "doentio",
    "doentita": "doente",
    "doentitas": "doente",
    "doentito": "doente",
    "doentitos": "doente",
    "doentíssima": "doente",
    "doentíssimas": "doente",
    "doentíssimo": "doente",
    "doentíssimos": "doente",
    "doençarias": "doençaria",
    "doenças": "doença",
    "doera": "doer",
    "doeram": "doer",
    "doeras": "doer",
    "doerdes": "doer",
    "doerei": "doer",
    "doereis": "doer",
    "doerem": "doer",
    "doeremos": "doer",
    "doeres": "doer",
    "doeria": "doer",
    "doeriam": "doer",
    "doerias": "doer",
    "doermo": "doer",
    "doermos": "doer",
    "doerá": "doer",
    "doerás": "doer",
    "doerão": "doer",
    "doeríamos": "doer",
    "doeríeis": "doer",
    "does": "doar",
    "doesse": "doer",
    "doessem": "doer",
    "doesses": "doer",
    "doesta": "doestar",
    "doestada": "doestar",
    "doestadas": "doestar",
    "doestado": "doestar",
    "doestadora": "doestador",
    "doestadoras": "doestador",
    "doestadores": "doestador",
    "doestados": "doestar",
    "doestai": "doestar",
    "doestais": "doestar",
    "doestam": "doestar",
    "doestamo": "doestar",
    "doestamos": "doestar",
    "doestando": "doestar",
    "doestara": "doestar",
    "doestaram": "doestar",
    "doestaras": "doestar",
    "doestarde": "doestar",
    "doestardes": "doestar",
    "doestare": "doestar",
    "doestarei": "doestar",
    "doestareis": "doestar",
    "doestarem": "doestar",
    "doestaremos": "doestar",
    "doestares": "doestar",
    "doestaria": "doestar",
    "doestariam": "doestar",
    "doestarias": "doestar",
    "doestarmo": "doestar",
    "doestarmos": "doestar",
    "doestará": "doestar",
    "doestarás": "doestar",
    "doestarão": "doestar",
    "doestaríamos": "doestar",
    "doestaríeis": "doestar",
    "doestas": "doestar",
    "doestasse": "doestar",
    "doestassem": "doestar",
    "doestasses": "doestar",
    "doestaste": "doestar",
    "doestastes": "doestar",
    "doestava": "doestar",
    "doestavam": "doestar",
    "doestavas": "doestar",
    "doeste": "doestar",
    "doestei": "doestar",
    "doesteis": "doestar",
    "doestem": "doestar",
    "doestemo": "doestar",
    "doestemos": "doestar",
    "doestes": "doestar",
    "doesto": "doestar",
    "doestos": "doesto",
    "doestou": "doestar",
    "doestrada": "doestrado",
    "doestradas": "doestrado",
    "doestradora": "doestrador",
    "doestradoras": "doestrador",
    "doestradores": "doestrador",
    "doestrados": "doestrado",
    "doestá": "doestar",
    "doestámo": "doestar",
    "doestámos": "doestar",
    "doestáramo": "doestar",
    "doestáramos": "doestar",
    "doestárei": "doestar",
    "doestáreis": "doestar",
    "doestásseis": "doestar",
    "doestássemos": "doestar",
    "doestávamo": "doestar",
    "doestávamos": "doestar",
    "doestávei": "doestar",
    "doestáveis": "doestar",
    "doeu": "doer",
    "dogados": "dogado",
    "dogais": "dogal",
    "doges": "doge",
    "dogesa": "doge",
    "dogesas": "doge",
    "doggeres": "dogger",
    "dogmas": "dogma",
    "dogmatismos": "dogmatismo",
    "dogmatistas": "dogmatista",
    "dogmatiza": "dogmatizar",
    "dogmatizada": "dogmatizar",
    "dogmatizadas": "dogmatizar",
    "dogmatizado": "dogmatizar",
    "dogmatizadora": "dogmatizador",
    "dogmatizadoras": "dogmatizador",
    "dogmatizadores": "dogmatizador",
    "dogmatizados": "dogmatizar",
    "dogmatizai": "dogmatizar",
    "dogmatizais": "dogmatizar",
    "dogmatizam": "dogmatizar",
    "dogmatizamo": "dogmatizar",
    "dogmatizamos": "dogmatizar",
    "dogmatizando": "dogmatizar",
    "dogmatizantes": "dogmatizante",
    "dogmatizara": "dogmatizar",
    "dogmatizaram": "dogmatizar",
    "dogmatizaras": "dogmatizar",
    "dogmatizarde": "dogmatizar",
    "dogmatizardes": "dogmatizar",
    "dogmatizare": "dogmatizar",
    "dogmatizarei": "dogmatizar",
    "dogmatizareis": "dogmatizar",
    "dogmatizarem": "dogmatizar",
    "dogmatizaremos": "dogmatizar",
    "dogmatizares": "dogmatizar",
    "dogmatizaria": "dogmatizar",
    "dogmatizariam": "dogmatizar",
    "dogmatizarias": "dogmatizar",
    "dogmatizarmo": "dogmatizar",
    "dogmatizarmos": "dogmatizar",
    "dogmatizará": "dogmatizar",
    "dogmatizarás": "dogmatizar",
    "dogmatizarão": "dogmatizar",
    "dogmatizaríamos": "dogmatizar",
    "dogmatizaríeis": "dogmatizar",
    "dogmatizas": "dogmatizar",
    "dogmatizasse": "dogmatizar",
    "dogmatizassem": "dogmatizar",
    "dogmatizasses": "dogmatizar",
    "dogmatizaste": "dogmatizar",
    "dogmatizastes": "dogmatizar",
    "dogmatizava": "dogmatizar",
    "dogmatizavam": "dogmatizar",
    "dogmatizavas": "dogmatizar",
    "dogmatizações": "dogmatização",
    "dogmatize": "dogmatizar",
    "dogmatizei": "dogmatizar",
    "dogmatizeis": "dogmatizar",
    "dogmatizem": "dogmatizar",
    "dogmatizemo": "dogmatizar",
    "dogmatizemos": "dogmatizar",
    "dogmatizes": "dogmatizar",
    "dogmatizo": "dogmatizar",
    "dogmatizou": "dogmatizar",
    "dogmatizá": "dogmatizar",
    "dogmatizámo": "dogmatizar",
    "dogmatizámos": "dogmatizar",
    "dogmatizáramo": "dogmatizar",
    "dogmatizáramos": "dogmatizar",
    "dogmatizárei": "dogmatizar",
    "dogmatizáreis": "dogmatizar",
    "dogmatizásseis": "dogmatizar",
    "dogmatizássemos": "dogmatizar",
    "dogmatizávamo": "dogmatizar",
    "dogmatizávamos": "dogmatizar",
    "dogmatizávei": "dogmatizar",
    "dogmatizáveis": "dogmatizar",
    "dogmatologias": "dogmatologia",
    "dogmática": "dogmático",
    "dogmáticas": "dogmático",
    "dogmáticos": "dogmático",
    "dogues": "dogue",
    "doida": "doido",
    "doidarias": "doidaria",
    "doidarona": "doidarão",
    "doidaronas": "doidarão",
    "doidarrazes": "doidarraz",
    "doidarrona": "doidarrão",
    "doidarronas": "doidarrão",
    "doidarrões": "doidarrão",
    "doidarões": "doidarão",
    "doidas": "doido",
    "doideiras": "doideira",
    "doideja": "doidejar",
    "doidejada": "doidejar",
    "doidejadas": "doidejar",
    "doidejado": "doidejar",
    "doidejados": "doidejar",
    "doidejai": "doidejar",
    "doidejais": "doidejar",
    "doidejam": "doidejar",
    "doidejamo": "doidejar",
    "doidejamos": "doidejar",
    "doidejando": "doidejar",
    "doidejantes": "doidejante",
    "doidejara": "doidejar",
    "doidejaram": "doidejar",
    "doidejaras": "doidejar",
    "doidejardes": "doidejar",
    "doidejarei": "doidejar",
    "doidejareis": "doidejar",
    "doidejarem": "doidejar",
    "doidejaremos": "doidejar",
    "doidejares": "doidejar",
    "doidejaria": "doidejar",
    "doidejariam": "doidejar",
    "doidejarias": "doidejar",
    "doidejarmo": "doidejar",
    "doidejarmos": "doidejar",
    "doidejará": "doidejar",
    "doidejarás": "doidejar",
    "doidejarão": "doidejar",
    "doidejaríamos": "doidejar",
    "doidejaríeis": "doidejar",
    "doidejas": "doidejar",
    "doidejasse": "doidejar",
    "doidejassem": "doidejar",
    "doidejasses": "doidejar",
    "doidejaste": "doidejar",
    "doidejastes": "doidejar",
    "doidejava": "doidejar",
    "doidejavam": "doidejar",
    "doidejavas": "doidejar",
    "doideje": "doidejar",
    "doidejei": "doidejar",
    "doidejeis": "doidejar",
    "doidejem": "doidejar",
    "doidejemo": "doidejar",
    "doidejemos": "doidejar",
    "doidejes": "doidejar",
    "doidejo": "doidejar",
    "doidejos": "doidejo",
    "doidejou": "doidejar",
    "doidejámo": "doidejar",
    "doidejámos": "doidejar",
    "doidejáramo": "doidejar",
    "doidejáramos": "doidejar",
    "doidejáreis": "doidejar",
    "doidejásseis": "doidejar",
    "doidejássemos": "doidejar",
    "doidejávamo": "doidejar",
    "doidejávamos": "doidejar",
    "doidejáveis": "doidejar",
    "doidices": "doidice",
    "doidinha": "doido",
    "doidinhas": "doido",
    "doidinho": "doido",
    "doidinhos": "doido",
    "doidita": "doido",
    "doiditas": "doido",
    "doidito": "doido",
    "doiditos": "doido",
    "doidona": "doidão",
    "doidonas": "doidão",
    "doidos": "doido",
    "doidões": "doidão",
    "doira": "doirar",
    "doirada": "doirar",
    "doiradas": "doirar",
    "doirado": "doirar",
    "doiradora": "doirador",
    "doiradoras": "doirador",
    "doiradores": "doirador",
    "doirados": "doirar",
    "doirai": "doirar",
    "doirais": "doirar",
    "doiram": "doirar",
    "doiramo": "doirar",
    "doiramos": "doirar",
    "doirando": "doirar",
    "doirara": "doirar",
    "doiraram": "doirar",
    "doiraras": "doirar",
    "doirarde": "doirar",
    "doirardes": "doirar",
    "doirare": "doirar",
    "doirarei": "doirar",
    "doirareis": "doirar",
    "doirarem": "doirar",
    "doiraremos": "doirar",
    "doirares": "doirar",
    "doiraria": "doirar",
    "doirariam": "doirar",
    "doirarias": "doirar",
    "doirarmo": "doirar",
    "doirarmos": "doirar",
    "doirará": "doirar",
    "doirarás": "doirar",
    "doirarão": "doirar",
    "doiraríamos": "doirar",
    "doiraríeis": "doirar",
    "doiras": "doirar",
    "doirasse": "doirar",
    "doirassem": "doirar",
    "doirasses": "doirar",
    "doiraste": "doirar",
    "doirastes": "doirar",
    "doirava": "doirar",
    "doiravam": "doirar",
    "doiravas": "doirar",
    "doire": "doirar",
    "doirei": "doirar",
    "doireis": "doirar",
    "doirem": "doirar",
    "doiremo": "doirar",
    "doiremos": "doirar",
    "doires": "doirar",
    "doiro": "doirar",
    "doirou": "doirar",
    "doirá": "doirar",
    "doirámo": "doirar",
    "doirámos": "doirar",
    "doiráramo": "doirar",
    "doiráramos": "doirar",
    "doirárei": "doirar",
    "doiráreis": "doirar",
    "doirásseis": "doirar",
    "doirássemos": "doirar",
    "doirávamo": "doirar",
    "doirávamos": "doirar",
    "doirávei": "doirar",
    "doiráveis": "doirar",
    "dolentes": "dolente",
    "doleritos": "dolerito",
    "dolicocefalias": "dolicocefalia",
    "dolicocéfala": "dolicocéfalo",
    "dolicocéfalas": "dolicocéfalo",
    "dolicocéfalos": "dolicocéfalo",
    "dolicoenterias": "dolicoenteria",
    "dolicócera": "dolicócero",
    "dolicóceras": "dolicócero",
    "dolicóceros": "dolicócero",
    "dolicóides": "dolicóide",
    "dolinas": "dolina",
    "dolmérica": "dolmérico",
    "dolméricas": "dolmérico",
    "dolméricos": "dolmérico",
    "dolomias": "dolomia",
    "dolomites": "dolomite",
    "dolomitos": "dolomito",
    "dolomítica": "dolomítico",
    "dolomíticas": "dolomítico",
    "dolomíticos": "dolomítico",
    "dolorida": "dolorido",
    "doloridas": "dolorido",
    "doloridos": "dolorido",
    "dolorismos": "dolorismo",
    "dolorosa": "doloroso",
    "dolorosas": "doloroso",
    "dolorosos": "doloroso",
    "dolos": "dolo",
    "dolosa": "doloso",
    "dolosas": "doloso",
    "dolosos": "doloso",
    "dolências": "dolência",
    "doma": "domar",
    "domabilidades": "domabilidade",
    "domada": "domar",
    "domadas": "domar",
    "domado": "domar",
    "domadora": "domador",
    "domadoras": "domador",
    "domadores": "domador",
    "domados": "domar",
    "domai": "domar",
    "domais": "domar",
    "domam": "domar",
    "domamo": "domar",
    "domamos": "domar",
    "domando": "domar",
    "domara": "domar",
    "domaram": "domar",
    "domaras": "domar",
    "domarde": "domar",
    "domardes": "domar",
    "domare": "domar",
    "domarei": "domar",
    "domareis": "domar",
    "domarem": "domar",
    "domaremos": "domar",
    "domares": "domar",
    "domaria": "domar",
    "domariam": "domar",
    "domarias": "domar",
    "domarmo": "domar",
    "domarmos": "domar",
    "domará": "domar",
    "domarás": "domar",
    "domarão": "domar",
    "domaríamos": "domar",
    "domaríeis": "domar",
    "domas": "domar",
    "domasse": "domar",
    "domassem": "domar",
    "domasses": "domar",
    "domaste": "domar",
    "domastes": "domar",
    "domava": "domar",
    "domavam": "domar",
    "domavas": "domar",
    "domações": "domação",
    "dombos": "dombo",
    "dome": "domar",
    "domei": "domar",
    "domeis": "domar",
    "domem": "domar",
    "domemo": "domar",
    "domemos": "domar",
    "domerianos": "domeriano",
    "domes": "domar",
    "domestica": "domesticar",
    "domesticada": "domesticar",
    "domesticadas": "domesticar",
    "domesticado": "domesticar",
    "domesticadora": "domesticador",
    "domesticadoras": "domesticador",
    "domesticadores": "domesticador",
    "domesticados": "domesticar",
    "domesticai": "domesticar",
    "domesticais": "domesticar",
    "domesticam": "domesticar",
    "domesticamo": "domesticar",
    "domesticamos": "domesticar",
    "domesticando": "domesticar",
    "domesticara": "domesticar",
    "domesticaram": "domesticar",
    "domesticaras": "domesticar",
    "domesticarde": "domesticar",
    "domesticardes": "domesticar",
    "domesticare": "domesticar",
    "domesticarei": "domesticar",
    "domesticareis": "domesticar",
    "domesticarem": "domesticar",
    "domesticaremos": "domesticar",
    "domesticares": "domesticar",
    "domesticaria": "domesticar",
    "domesticariam": "domesticar",
    "domesticarias": "domesticar",
    "domesticarmo": "domesticar",
    "domesticarmos": "domesticar",
    "domesticará": "domesticar",
    "domesticarás": "domesticar",
    "domesticarão": "domesticar",
    "domesticaríamos": "domesticar",
    "domesticaríeis": "domesticar",
    "domesticas": "domesticar",
    "domesticasse": "domesticar",
    "domesticassem": "domesticar",
    "domesticasses": "domesticar",
    "domesticaste": "domesticar",
    "domesticastes": "domesticar",
    "domesticava": "domesticar",
    "domesticavam": "domesticar",
    "domesticavas": "domesticar",
    "domesticações": "domesticação",
    "domesticidades": "domesticidade",
    "domestico": "domesticar",
    "domesticou": "domesticar",
    "domesticá": "domesticar",
    "domesticámo": "domesticar",
    "domesticámos": "domesticar",
    "domesticáramo": "domesticar",
    "domesticáramos": "domesticar",
    "domesticárei": "domesticar",
    "domesticáreis": "domesticar",
    "domesticásseis": "domesticar",
    "domesticássemos": "domesticar",
    "domesticávamo": "domesticar",
    "domesticávamos": "domesticar",
    "domesticávei": "domesticar",
    "domesticáveis": "domesticável",
    "domestique": "domesticar",
    "domestiquei": "domesticar",
    "domestiqueis": "domesticar",
    "domestiquem": "domesticar",
    "domestiquemo": "domesticar",
    "domestiquemos": "domesticar",
    "domestiques": "domesticar",
    "domicilia": "domiciliar",
    "domiciliada": "domiciliar",
    "domiciliadas": "domiciliar",
    "domiciliado": "domiciliar",
    "domiciliados": "domiciliar",
    "domiciliai": "domiciliar",
    "domiciliais": "domiciliar",
    "domiciliam": "domiciliar",
    "domiciliamo": "domiciliar",
    "domiciliamos": "domiciliar",
    "domiciliando": "domiciliar",
    "domiciliara": "domiciliar",
    "domiciliaram": "domiciliar",
    "domiciliaras": "domiciliar",
    "domiciliardes": "domiciliar",
    "domiciliarei": "domiciliar",
    "domiciliareis": "domiciliar",
    "domiciliarem": "domiciliar",
    "domiciliaremos": "domiciliar",
    "domiciliares": "domiciliar",
    "domiciliaria": "domiciliar",
    "domiciliariam": "domiciliar",
    "domiciliarias": "domiciliar",
    "domiciliarmo": "domiciliar",
    "domiciliarmos": "domiciliar",
    "domiciliará": "domiciliar",
    "domiciliarás": "domiciliar",
    "domiciliarão": "domiciliar",
    "domiciliaríamos": "domiciliar",
    "domiciliaríeis": "domiciliar",
    "domicilias": "domiciliar",
    "domiciliasse": "domiciliar",
    "domiciliassem": "domiciliar",
    "domiciliasses": "domiciliar",
    "domiciliaste": "domiciliar",
    "domiciliastes": "domiciliar",
    "domiciliava": "domiciliar",
    "domiciliavam": "domiciliar",
    "domiciliavas": "domiciliar",
    "domiciliações": "domiciliação",
    "domicilie": "domiciliar",
    "domiciliei": "domiciliar",
    "domicilieis": "domiciliar",
    "domiciliem": "domiciliar",
    "domiciliemo": "domiciliar",
    "domiciliemos": "domiciliar",
    "domicilies": "domiciliar",
    "domicilio": "domiciliar",
    "domiciliou": "domiciliar",
    "domiciliámo": "domiciliar",
    "domiciliámos": "domiciliar",
    "domiciliáramo": "domiciliar",
    "domiciliáramos": "domiciliar",
    "domiciliáreis": "domiciliar",
    "domiciliária": "domiciliário",
    "domiciliárias": "domiciliário",
    "domiciliários": "domiciliário",
    "domiciliásseis": "domiciliar",
    "domiciliássemos": "domiciliar",
    "domiciliávamo": "domiciliar",
    "domiciliávamos": "domiciliar",
    "domiciliáveis": "domiciliável",
    "domicílios": "domicílio",
    "domina": "dominar",
    "dominada": "dominar",
    "dominadas": "dominar",
    "dominado": "dominar",
    "dominadora": "dominador",
    "dominadoras": "dominador",
    "dominadores": "dominador",
    "dominados": "dominar",
    "dominai": "dominar",
    "dominais": "dominar",
    "dominam": "dominar",
    "dominamo": "dominar",
    "dominamos": "dominar",
    "dominando": "dominar",
    "dominantes": "dominante",
    "dominara": "dominar",
    "dominaram": "dominar",
    "dominaras": "dominar",
    "dominarde": "dominar",
    "dominardes": "dominar",
    "dominare": "dominar",
    "dominarei": "dominar",
    "dominareis": "dominar",
    "dominarem": "dominar",
    "dominaremos": "dominar",
    "dominares": "dominar",
    "dominaria": "dominar",
    "dominariam": "dominar",
    "dominarias": "dominar",
    "dominarmo": "dominar",
    "dominarmos": "dominar",
    "dominará": "dominar",
    "dominarás": "dominar",
    "dominarão": "dominar",
    "dominaríamos": "dominar",
    "dominaríeis": "dominar",
    "dominas": "dominar",
    "dominasse": "dominar",
    "dominassem": "dominar",
    "dominasses": "dominar",
    "dominaste": "dominar",
    "dominastes": "dominar",
    "dominativa": "dominativo",
    "dominativas": "dominativo",
    "dominativos": "dominativo",
    "dominava": "dominar",
    "dominavam": "dominar",
    "dominavas": "dominar",
    "dominações": "dominação",
    "domine": "dominar",
    "dominei": "dominar",
    "domineis": "dominar",
    "dominem": "dominar",
    "dominemo": "dominar",
    "dominemos": "dominar",
    "domines": "dominar",
    "domingais": "domingal",
    "domingas": "dominga",
    "domingos": "domingo",
    "domingueira": "domingueiro",
    "domingueiras": "domingueiro",
    "domingueiros": "domingueiro",
    "dominiais": "dominial",
    "dominicais": "dominical",
    "dominicana": "dominicano",
    "dominicanas": "dominicano",
    "dominicanos": "dominicano",
    "domino": "dominar",
    "dominou": "dominar",
    "dominá": "dominar",
    "dominámo": "dominar",
    "dominámos": "dominar",
    "domináramo": "dominar",
    "domináramos": "dominar",
    "dominárei": "dominar",
    "domináreis": "dominar",
    "dominásseis": "dominar",
    "dominássemos": "dominar",
    "dominávamo": "dominar",
    "dominávamos": "dominar",
    "dominávei": "dominar",
    "domináveis": "dominável",
    "dominâncias": "dominância",
    "dominós": "dominó",
    "domiváveis": "domivável",
    "domo": "domar",
    "domos": "domo",
    "domou": "domar",
    "domá": "domar",
    "domámo": "domar",
    "domámos": "domar",
    "domáramo": "domar",
    "domáramos": "domar",
    "domárei": "domar",
    "domáreis": "domar",
    "domásseis": "domar",
    "domássemos": "domar",
    "domávamo": "domar",
    "domávamos": "domar",
    "domávei": "domar",
    "domáveis": "domável",
    "doméstica": "doméstico",
    "domésticas": "doméstico",
    "domésticos": "doméstico",
    "domínica": "domínico",
    "domínicas": "domínico",
    "domínicos": "domínico",
    "domínios": "domínio",
    "dona": "dono",
    "donacídeos": "donacídeo",
    "donaireada": "donairear",
    "donaireadas": "donairear",
    "donaireado": "donairear",
    "donaireados": "donairear",
    "donaireai": "donairear",
    "donaireais": "donairear",
    "donaireamo": "donairear",
    "donaireamos": "donairear",
    "donaireando": "donairear",
    "donaireara": "donairear",
    "donairearam": "donairear",
    "donairearas": "donairear",
    "donaireardes": "donairear",
    "donairearei": "donairear",
    "donaireareis": "donairear",
    "donairearem": "donairear",
    "donairearemos": "donairear",
    "donaireares": "donairear",
    "donairearia": "donairear",
    "donaireariam": "donairear",
    "donairearias": "donairear",
    "donairearmo": "donairear",
    "donairearmos": "donairear",
    "donaireará": "donairear",
    "donairearás": "donairear",
    "donairearão": "donairear",
    "donairearíamos": "donairear",
    "donairearíeis": "donairear",
    "donaireasse": "donairear",
    "donaireassem": "donairear",
    "donaireasses": "donairear",
    "donaireaste": "donairear",
    "donaireastes": "donairear",
    "donaireava": "donairear",
    "donaireavam": "donairear",
    "donaireavas": "donairear",
    "donaireei": "donairear",
    "donaireeis": "donairear",
    "donaireemo": "donairear",
    "donaireemos": "donairear",
    "donaireia": "donairear",
    "donaireiam": "donairear",
    "donaireias": "donairear",
    "donaireie": "donairear",
    "donaireiem": "donairear",
    "donaireies": "donairear",
    "donaireio": "donairear",
    "donaireou": "donairear",
    "donaires": "donaire",
    "donaireámo": "donairear",
    "donaireámos": "donairear",
    "donaireáramo": "donairear",
    "donaireáramos": "donairear",
    "donaireáreis": "donairear",
    "donaireásseis": "donairear",
    "donaireássemos": "donairear",
    "donaireávamo": "donairear",
    "donaireávamos": "donairear",
    "donaireáveis": "donairear",
    "donairosa": "donairoso",
    "donairosas": "donairoso",
    "donairosos": "donairoso",
    "donas": "dono",
    "donatismos": "donatismo",
    "donatistas": "donatista",
    "donativos": "donativo",
    "donatos": "donato",
    "donatária": "donatário",
    "donatárias": "donatário",
    "donatários": "donatário",
    "donda": "dondo",
    "dondas": "dondo",
    "dondos": "dondo",
    "doneada": "donear",
    "doneadas": "donear",
    "doneado": "donear",
    "doneados": "donear",
    "doneai": "donear",
    "doneais": "donear",
    "doneamo": "donear",
    "doneamos": "donear",
    "doneando": "donear",
    "doneara": "donear",
    "donearam": "donear",
    "donearas": "donear",
    "donearde": "donear",
    "doneardes": "donear",
    "doneare": "donear",
    "donearei": "donear",
    "doneareis": "donear",
    "donearem": "donear",
    "donearemos": "donear",
    "doneares": "donear",
    "donearia": "donear",
    "doneariam": "donear",
    "donearias": "donear",
    "donearmo": "donear",
    "donearmos": "donear",
    "doneará": "donear",
    "donearás": "donear",
    "donearão": "donear",
    "donearíamos": "donear",
    "donearíeis": "donear",
    "doneasse": "donear",
    "doneassem": "donear",
    "doneasses": "donear",
    "doneaste": "donear",
    "doneastes": "donear",
    "doneava": "donear",
    "doneavam": "donear",
    "doneavas": "donear",
    "doneei": "donear",
    "doneeis": "donear",
    "doneemo": "donear",
    "doneemos": "donear",
    "doneia": "donear",
    "doneiam": "donear",
    "doneias": "donear",
    "doneie": "donear",
    "doneiem": "donear",
    "doneies": "donear",
    "doneio": "donear",
    "doneou": "donear",
    "doneá": "donear",
    "doneámo": "donear",
    "doneámos": "donear",
    "doneáramo": "donear",
    "doneáramos": "donear",
    "doneárei": "donear",
    "doneáreis": "donear",
    "doneásseis": "donear",
    "doneássemos": "donear",
    "doneávamo": "donear",
    "doneávamos": "donear",
    "doneávei": "donear",
    "doneáveis": "doneável",
    "dongos": "dongo",
    "doninhas": "doninha",
    "donjoanismos": "donjoanismo",
    "donos": "dono",
    "donosa": "donoso",
    "donosas": "donoso",
    "donosos": "donoso",
    "dons": "dom",
    "donzela": "donzel",
    "donzelarias": "donzelaria",
    "donzelas": "donzela",
    "donzelesca": "donzelesco",
    "donzelescas": "donzelesco",
    "donzelescos": "donzelesco",
    "donzelias": "donzelia",
    "donzelices": "donzelice",
    "donzelinhas": "donzelinha",
    "donzelonas": "donzelona",
    "donzéis": "donzel",
    "donácidas": "donácida",
    "doo": "doer",
    "doou": "doar",
    "dopa": "dopar",
    "dopada": "dopar",
    "dopadas": "dopar",
    "dopado": "dopar",
    "dopados": "dopar",
    "dopai": "dopar",
    "dopais": "dopar",
    "dopam": "dopar",
    "dopamo": "dopar",
    "dopamos": "dopar",
    "dopando": "dopar",
    "dopara": "dopar",
    "doparam": "dopar",
    "doparas": "dopar",
    "doparde": "dopar",
    "dopardes": "dopar",
    "dopare": "dopar",
    "doparei": "dopar",
    "dopareis": "dopar",
    "doparem": "dopar",
    "doparemos": "dopar",
    "dopares": "dopar",
    "doparia": "dopar",
    "dopariam": "dopar",
    "doparias": "dopar",
    "doparmo": "dopar",
    "doparmos": "dopar",
    "dopará": "dopar",
    "doparás": "dopar",
    "doparão": "dopar",
    "doparíamos": "dopar",
    "doparíeis": "dopar",
    "dopas": "dopar",
    "dopasse": "dopar",
    "dopassem": "dopar",
    "dopasses": "dopar",
    "dopaste": "dopar",
    "dopastes": "dopar",
    "dopava": "dopar",
    "dopavam": "dopar",
    "dopavas": "dopar",
    "dope": "dopar",
    "dopei": "dopar",
    "dopeis": "dopar",
    "dopem": "dopar",
    "dopemo": "dopar",
    "dopemos": "dopar",
    "dopes": "dope",
    "dopo": "dopar",
    "dopou": "dopar",
    "dopá": "dopar",
    "dopámo": "dopar",
    "dopámos": "dopar",
    "dopáramo": "dopar",
    "dopáramos": "dopar",
    "dopárei": "dopar",
    "dopáreis": "dopar",
    "dopásseis": "dopar",
    "dopássemos": "dopar",
    "dopávamo": "dopar",
    "dopávamos": "dopar",
    "dopávei": "dopar",
    "dopáveis": "dopar",
    "doras": "dora",
    "dores": "dor",
    "doriais": "dorial",
    "dorida": "dorido",
    "doridas": "dorido",
    "doridos": "dorido",
    "dorme": "dormir",
    "dormem": "dormir",
    "dormentes": "dormente",
    "dormes": "dormir",
    "dormi": "dormir",
    "dormia": "dormir",
    "dormiam": "dormir",
    "dormias": "dormir",
    "dormida": "dormir",
    "dormidas": "dormir",
    "dormideiras": "dormideira",
    "dormido": "dormir",
    "dormidoiros": "dormidoiro",
    "dormidora": "dormidor",
    "dormidoras": "dormidor",
    "dormidores": "dormidor",
    "dormidos": "dormir",
    "dormidouros": "dormidouro",
    "dormimo": "dormir",
    "dormimos": "dormir",
    "dormindo": "dormir",
    "dorminhoca": "dorminhoco",
    "dorminhocas": "dorminhoco",
    "dorminhocos": "dorminhoco",
    "dorminhona": "dorminhão",
    "dorminhonas": "dorminhão",
    "dorminhões": "dorminhão",
    "dormintes": "dorminte",
    "dormira": "dormir",
    "dormiram": "dormir",
    "dormiras": "dormir",
    "dormirde": "dormir",
    "dormirdes": "dormir",
    "dormire": "dormir",
    "dormirei": "dormir",
    "dormireis": "dormir",
    "dormirem": "dormir",
    "dormiremos": "dormir",
    "dormires": "dormir",
    "dormiria": "dormir",
    "dormiriam": "dormir",
    "dormirias": "dormir",
    "dormirmo": "dormir",
    "dormirmos": "dormir",
    "dormirá": "dormir",
    "dormirás": "dormir",
    "dormirão": "dormir",
    "dormiríamos": "dormir",
    "dormiríeis": "dormir",
    "dormis": "dormir",
    "dormisse": "dormir",
    "dormissem": "dormir",
    "dormisses": "dormir",
    "dormiste": "dormir",
    "dormistes": "dormir",
    "dormita": "dormitar",
    "dormitada": "dormitar",
    "dormitadas": "dormitar",
    "dormitado": "dormitar",
    "dormitados": "dormitar",
    "dormitai": "dormitar",
    "dormitais": "dormitar",
    "dormitam": "dormitar",
    "dormitamo": "dormitar",
    "dormitamos": "dormitar",
    "dormitando": "dormitar",
    "dormitara": "dormitar",
    "dormitaram": "dormitar",
    "dormitaras": "dormitar",
    "dormitardes": "dormitar",
    "dormitarei": "dormitar",
    "dormitareis": "dormitar",
    "dormitarem": "dormitar",
    "dormitaremos": "dormitar",
    "dormitares": "dormitar",
    "dormitaria": "dormitar",
    "dormitariam": "dormitar",
    "dormitarias": "dormitar",
    "dormitarmo": "dormitar",
    "dormitarmos": "dormitar",
    "dormitará": "dormitar",
    "dormitarás": "dormitar",
    "dormitarão": "dormitar",
    "dormitaríamos": "dormitar",
    "dormitaríeis": "dormitar",
    "dormitas": "dormitar",
    "dormitasse": "dormitar",
    "dormitassem": "dormitar",
    "dormitasses": "dormitar",
    "dormitaste": "dormitar",
    "dormitastes": "dormitar",
    "dormitava": "dormitar",
    "dormitavam": "dormitar",
    "dormitavas": "dormitar",
    "dormitações": "dormitação",
    "dormite": "dormitar",
    "dormitei": "dormitar",
    "dormiteis": "dormitar",
    "dormitem": "dormitar",
    "dormitemo": "dormitar",
    "dormitemos": "dormitar",
    "dormites": "dormitar",
    "dormitiva": "dormitivo",
    "dormitivas": "dormitivo",
    "dormitivos": "dormitivo",
    "dormito": "dormitar",
    "dormitou": "dormitar",
    "dormitámo": "dormitar",
    "dormitámos": "dormitar",
    "dormitáramo": "dormitar",
    "dormitáramos": "dormitar",
    "dormitáreis": "dormitar",
    "dormitásseis": "dormitar",
    "dormitássemos": "dormitar",
    "dormitávamo": "dormitar",
    "dormitávamos": "dormitar",
    "dormitáveis": "dormitar",
    "dormitórios": "dormitório",
    "dormiu": "dormir",
    "dormências": "dormência",
    "dormíamo": "dormir",
    "dormíamos": "dormir",
    "dormíei": "dormir",
    "dormíeis": "dormir",
    "dormíramo": "dormir",
    "dormíramos": "dormir",
    "dormírei": "dormir",
    "dormíreis": "dormir",
    "dormísseis": "dormir",
    "dormíssemos": "dormir",
    "dornachos": "dornacho",
    "dornadas": "dornada",
    "dornas": "dorna",
    "dorneiras": "dorneira",
    "doroteias": "doroteia",
    "dorsais": "dorsal",
    "dorsalgias": "dorsalgia",
    "dorsifixa": "dorsifixo",
    "dorsifixas": "dorsifixo",
    "dorsifixos": "dorsifixo",
    "dorsodinias": "dorsodinia",
    "dorsos": "dorso",
    "dorsífera": "dorsífero",
    "dorsíferas": "dorsífero",
    "dorsíferos": "dorsífero",
    "dorífora": "doríforo",
    "doríforas": "doríforo",
    "doríforos": "doríforo",
    "dosa": "dosar",
    "dosada": "dosar",
    "dosadas": "dosar",
    "dosado": "dosar",
    "dosados": "dosar",
    "dosagens": "dosagem",
    "dosai": "dosar",
    "dosais": "dosar",
    "dosam": "dosar",
    "dosamo": "dosar",
    "dosamos": "dosar",
    "dosando": "dosar",
    "dosara": "dosar",
    "dosaram": "dosar",
    "dosaras": "dosar",
    "dosarde": "dosar",
    "dosardes": "dosar",
    "dosare": "dosar",
    "dosarei": "dosar",
    "dosareis": "dosar",
    "dosarem": "dosar",
    "dosaremos": "dosar",
    "dosares": "dosar",
    "dosaria": "dosar",
    "dosariam": "dosar",
    "dosarias": "dosar",
    "dosarmo": "dosar",
    "dosarmos": "dosar",
    "dosará": "dosar",
    "dosarás": "dosar",
    "dosarão": "dosar",
    "dosaríamos": "dosar",
    "dosaríeis": "dosar",
    "dosas": "dosar",
    "dosasse": "dosar",
    "dosassem": "dosar",
    "dosasses": "dosar",
    "dosaste": "dosar",
    "dosastes": "dosar",
    "dosava": "dosar",
    "dosavam": "dosar",
    "dosavas": "dosar",
    "dose": "dosar",
    "doseada": "dosear",
    "doseadas": "dosear",
    "doseado": "dosear",
    "doseados": "dosear",
    "doseai": "dosear",
    "doseais": "dosear",
    "doseamentos": "doseamento",
    "doseamo": "dosear",
    "doseamos": "dosear",
    "doseando": "dosear",
    "doseara": "dosear",
    "dosearam": "dosear",
    "dosearas": "dosear",
    "dosearde": "dosear",
    "doseardes": "dosear",
    "doseare": "dosear",
    "dosearei": "dosear",
    "doseareis": "dosear",
    "dosearem": "dosear",
    "dosearemos": "dosear",
    "doseares": "dosear",
    "dosearia": "dosear",
    "doseariam": "dosear",
    "dosearias": "dosear",
    "dosearmo": "dosear",
    "dosearmos": "dosear",
    "doseará": "dosear",
    "dosearás": "dosear",
    "dosearão": "dosear",
    "dosearíamos": "dosear",
    "dosearíeis": "dosear",
    "doseasse": "dosear",
    "doseassem": "dosear",
    "doseasses": "dosear",
    "doseaste": "dosear",
    "doseastes": "dosear",
    "doseava": "dosear",
    "doseavam": "dosear",
    "doseavas": "dosear",
    "doseei": "dosear",
    "doseeis": "dosear",
    "doseemo": "dosear",
    "doseemos": "dosear",
    "dosei": "dosar",
    "doseia": "dosear",
    "doseiam": "dosear",
    "doseias": "dosear",
    "doseie": "dosear",
    "doseiem": "dosear",
    "doseies": "dosear",
    "doseio": "dosear",
    "doseis": "dosar",
    "dosem": "dosar",
    "dosemo": "dosar",
    "dosemos": "dosar",
    "doseou": "dosear",
    "doses": "dose",
    "doseá": "dosear",
    "doseámo": "dosear",
    "doseámos": "dosear",
    "doseáramo": "dosear",
    "doseáramos": "dosear",
    "doseárei": "dosear",
    "doseáreis": "dosear",
    "doseásseis": "dosear",
    "doseássemos": "dosear",
    "doseávamo": "dosear",
    "doseávamos": "dosear",
    "doseávei": "dosear",
    "doseáveis": "doseável",
    "dosificada": "dosificado",
    "dosificadas": "dosificado",
    "dosificados": "dosificado",
    "dosificáveis": "dosificável",
    "dosimetrias": "dosimetria",
    "dosimétrica": "dosimétrico",
    "dosimétricas": "dosimétrico",
    "dosimétricos": "dosimétrico",
    "doso": "dosar",
    "dosologias": "dosologia",
    "dosou": "dosar",
    "dosseis": "dossel",
    "dossela": "dosselar",
    "dosselada": "dosselar",
    "dosseladas": "dosselar",
    "dosselado": "dosselar",
    "dosselados": "dosselar",
    "dosselai": "dosselar",
    "dosselais": "dosselar",
    "dosselam": "dosselar",
    "dosselamo": "dosselar",
    "dosselamos": "dosselar",
    "dosselando": "dosselar",
    "dosselara": "dosselar",
    "dosselaram": "dosselar",
    "dosselaras": "dosselar",
    "dosselarde": "dosselar",
    "dosselardes": "dosselar",
    "dosselare": "dosselar",
    "dosselarei": "dosselar",
    "dosselareis": "dosselar",
    "dosselarem": "dosselar",
    "dosselaremos": "dosselar",
    "dosselares": "dosselar",
    "dosselaria": "dosselar",
    "dosselariam": "dosselar",
    "dosselarias": "dosselar",
    "dosselarmo": "dosselar",
    "dosselarmos": "dosselar",
    "dosselará": "dosselar",
    "dosselarás": "dosselar",
    "dosselarão": "dosselar",
    "dosselaríamos": "dosselar",
    "dosselaríeis": "dosselar",
    "dosselas": "dosselar",
    "dosselasse": "dosselar",
    "dosselassem": "dosselar",
    "dosselasses": "dosselar",
    "dosselaste": "dosselar",
    "dosselastes": "dosselar",
    "dosselava": "dosselar",
    "dosselavam": "dosselar",
    "dosselavas": "dosselar",
    "dossele": "dosselar",
    "dosselei": "dosselar",
    "dosseleis": "dosselar",
    "dosselem": "dosselar",
    "dosselemo": "dosselar",
    "dosselemos": "dosselar",
    "dosseles": "dosselar",
    "dosselo": "dosselar",
    "dosselou": "dosselar",
    "dosselá": "dosselar",
    "dosselámo": "dosselar",
    "dosselámos": "dosselar",
    "dosseláramo": "dosselar",
    "dosseláramos": "dosselar",
    "dosselárei": "dosselar",
    "dosseláreis": "dosselar",
    "dosselásseis": "dosselar",
    "dosselássemos": "dosselar",
    "dosselávamo": "dosselar",
    "dosselávamos": "dosselar",
    "dosselávei": "dosselar",
    "dosseláveis": "dosselável",
    "dossiers": "dossier",
    "dosá": "dosar",
    "dosámo": "dosar",
    "dosámos": "dosar",
    "dosáramo": "dosar",
    "dosáramos": "dosar",
    "dosárei": "dosar",
    "dosáreis": "dosar",
    "dosásseis": "dosar",
    "dosássemos": "dosar",
    "dosávamo": "dosar",
    "dosávamos": "dosar",
    "dosávei": "dosar",
    "dosáveis": "dosável",
    "dosímetros": "dosímetro",
    "dota": "dotar",
    "dotada": "dotar",
    "dotadas": "dotar",
    "dotado": "dotar",
    "dotadora": "dotador",
    "dotadoras": "dotador",
    "dotadores": "dotador",
    "dotados": "dotar",
    "dotadíssima": "dotado",
    "dotadíssimas": "dotado",
    "dotadíssimo": "dotado",
    "dotadíssimos": "dotado",
    "dotai": "dotar",
    "dotais": "dotar",
    "dotam": "dotar",
    "dotamo": "dotar",
    "dotamos": "dotar",
    "dotando": "dotar",
    "dotara": "dotar",
    "dotaram": "dotar",
    "dotaras": "dotar",
    "dotarde": "dotar",
    "dotardes": "dotar",
    "dotare": "dotar",
    "dotarei": "dotar",
    "dotareis": "dotar",
    "dotarem": "dotar",
    "dotaremos": "dotar",
    "dotares": "dotar",
    "dotaria": "dotar",
    "dotariam": "dotar",
    "dotarias": "dotar",
    "dotarmo": "dotar",
    "dotarmos": "dotar",
    "dotará": "dotar",
    "dotarás": "dotar",
    "dotarão": "dotar",
    "dotaríamos": "dotar",
    "dotaríeis": "dotar",
    "dotas": "dotar",
    "dotasse": "dotar",
    "dotassem": "dotar",
    "dotasses": "dotar",
    "dotaste": "dotar",
    "dotastes": "dotar",
    "dotava": "dotar",
    "dotavam": "dotar",
    "dotavas": "dotar",
    "dotações": "dotação",
    "dote": "dotar",
    "dotei": "dotar",
    "doteis": "dotar",
    "dotem": "dotar",
    "dotemo": "dotar",
    "dotemos": "dotar",
    "dotes": "dote",
    "doto": "dotar",
    "dotonga": "dotongar",
    "dotongada": "dotongar",
    "dotongadas": "dotongar",
    "dotongado": "dotongar",
    "dotongados": "dotongar",
    "dotongai": "dotongar",
    "dotongais": "dotongar",
    "dotongam": "dotongar",
    "dotongamo": "dotongar",
    "dotongamos": "dotongar",
    "dotongando": "dotongar",
    "dotongara": "dotongar",
    "dotongaram": "dotongar",
    "dotongaras": "dotongar",
    "dotongardes": "dotongar",
    "dotongarei": "dotongar",
    "dotongareis": "dotongar",
    "dotongarem": "dotongar",
    "dotongaremos": "dotongar",
    "dotongares": "dotongar",
    "dotongaria": "dotongar",
    "dotongariam": "dotongar",
    "dotongarias": "dotongar",
    "dotongarmo": "dotongar",
    "dotongarmos": "dotongar",
    "dotongará": "dotongar",
    "dotongarás": "dotongar",
    "dotongarão": "dotongar",
    "dotongaríamos": "dotongar",
    "dotongaríeis": "dotongar",
    "dotongas": "dotongar",
    "dotongasse": "dotongar",
    "dotongassem": "dotongar",
    "dotongasses": "dotongar",
    "dotongaste": "dotongar",
    "dotongastes": "dotongar",
    "dotongava": "dotongar",
    "dotongavam": "dotongar",
    "dotongavas": "dotongar",
    "dotongo": "dotongar",
    "dotongou": "dotongar",
    "dotongue": "dotongar",
    "dotonguei": "dotongar",
    "dotongueis": "dotongar",
    "dotonguem": "dotongar",
    "dotonguemo": "dotongar",
    "dotonguemos": "dotongar",
    "dotongues": "dotongar",
    "dotongámo": "dotongar",
    "dotongámos": "dotongar",
    "dotongáramo": "dotongar",
    "dotongáramos": "dotongar",
    "dotongáreis": "dotongar",
    "dotongásseis": "dotongar",
    "dotongássemos": "dotongar",
    "dotongávamo": "dotongar",
    "dotongávamos": "dotongar",
    "dotongáveis": "dotongar",
    "dotou": "dotar",
    "dotá": "dotar",
    "dotámo": "dotar",
    "dotámos": "dotar",
    "dotáramo": "dotar",
    "dotáramos": "dotar",
    "dotárei": "dotar",
    "dotáreis": "dotar",
    "dotásseis": "dotar",
    "dotássemos": "dotar",
    "dotávamo": "dotar",
    "dotávamos": "dotar",
    "dotávei": "dotar",
    "dotáveis": "dotável",
    "dou": "dar",
    "doudeja": "doudejar",
    "doudejada": "doudejar",
    "doudejadas": "doudejar",
    "doudejado": "doudejar",
    "doudejados": "doudejar",
    "doudejai": "doudejar",
    "doudejais": "doudejar",
    "doudejam": "doudejar",
    "doudejamo": "doudejar",
    "doudejamos": "doudejar",
    "doudejando": "doudejar",
    "doudejara": "doudejar",
    "doudejaram": "doudejar",
    "doudejaras": "doudejar",
    "doudejardes": "doudejar",
    "doudejarei": "doudejar",
    "doudejareis": "doudejar",
    "doudejarem": "doudejar",
    "doudejaremos": "doudejar",
    "doudejares": "doudejar",
    "doudejaria": "doudejar",
    "doudejariam": "doudejar",
    "doudejarias": "doudejar",
    "doudejarmo": "doudejar",
    "doudejarmos": "doudejar",
    "doudejará": "doudejar",
    "doudejarás": "doudejar",
    "doudejarão": "doudejar",
    "doudejaríamos": "doudejar",
    "doudejaríeis": "doudejar",
    "doudejas": "doudejar",
    "doudejasse": "doudejar",
    "doudejassem": "doudejar",
    "doudejasses": "doudejar",
    "doudejaste": "doudejar",
    "doudejastes": "doudejar",
    "doudejava": "doudejar",
    "doudejavam": "doudejar",
    "doudejavas": "doudejar",
    "doudeje": "doudejar",
    "doudejei": "doudejar",
    "doudejeis": "doudejar",
    "doudejem": "doudejar",
    "doudejemo": "doudejar",
    "doudejemos": "doudejar",
    "doudejes": "doudejar",
    "doudejo": "doudejar",
    "doudejou": "doudejar",
    "doudejámo": "doudejar",
    "doudejámos": "doudejar",
    "doudejáramo": "doudejar",
    "doudejáramos": "doudejar",
    "doudejáreis": "doudejar",
    "doudejásseis": "doudejar",
    "doudejássemos": "doudejar",
    "doudejávamo": "doudejar",
    "doudejávamos": "doudejar",
    "doudejáveis": "doudejar",
    "doura": "dourar",
    "dourada": "dourar",
    "douradas": "dourar",
    "douradilha": "douradilho",
    "douradilhas": "douradilho",
    "douradilhos": "douradilho",
    "douradinhas": "douradinha",
    "dourado": "dourar",
    "douradora": "dourador",
    "douradoras": "dourador",
    "douradores": "dourador",
    "dourados": "dourar",
    "douraduras": "douradura",
    "dourai": "dourar",
    "dourais": "dourar",
    "douram": "dourar",
    "douramentos": "douramento",
    "douramo": "dourar",
    "douramos": "dourar",
    "dourando": "dourar",
    "dourara": "dourar",
    "douraram": "dourar",
    "douraras": "dourar",
    "dourarde": "dourar",
    "dourardes": "dourar",
    "dourare": "dourar",
    "dourarei": "dourar",
    "dourareis": "dourar",
    "dourarem": "dourar",
    "douraremos": "dourar",
    "dourares": "dourar",
    "douraria": "dourar",
    "dourariam": "dourar",
    "dourarias": "dourar",
    "dourarmo": "dourar",
    "dourarmos": "dourar",
    "dourará": "dourar",
    "dourarás": "dourar",
    "dourarão": "dourar",
    "douraríamos": "dourar",
    "douraríeis": "dourar",
    "douras": "dourar",
    "dourasse": "dourar",
    "dourassem": "dourar",
    "dourasses": "dourar",
    "douraste": "dourar",
    "dourastes": "dourar",
    "dourava": "dourar",
    "douravam": "dourar",
    "douravas": "dourar",
    "dourações": "douração",
    "doure": "dourar",
    "dourei": "dourar",
    "doureis": "dourar",
    "dourem": "dourar",
    "douremo": "dourar",
    "douremos": "dourar",
    "doures": "dourar",
    "douro": "dourar",
    "dourou": "dourar",
    "dourá": "dourar",
    "dourámo": "dourar",
    "dourámos": "dourar",
    "douráramo": "dourar",
    "douráramos": "dourar",
    "dourárei": "dourar",
    "douráreis": "dourar",
    "dourásseis": "dourar",
    "dourássemos": "dourar",
    "dourávamo": "dourar",
    "dourávamos": "dourar",
    "dourávei": "dourar",
    "douráveis": "dourar",
    "dous": "dois",
    "douta": "douto",
    "doutas": "douto",
    "doutora": "doutorar",
    "doutorada": "doutorar",
    "doutoradas": "doutorar",
    "doutorado": "doutorar",
    "doutorados": "doutorar",
    "doutorai": "doutorar",
    "doutorais": "doutorar",
    "doutoram": "doutorar",
    "doutoramentos": "doutoramento",
    "doutoramo": "doutorar",
    "doutoramos": "doutorar",
    "doutoranda": "doutorando",
    "doutorandas": "doutorando",
    "doutorando": "doutorar",
    "doutorandos": "doutorando",
    "doutorara": "doutorar",
    "doutoraram": "doutorar",
    "doutoraras": "doutorar",
    "doutorarde": "doutorar",
    "doutorardes": "doutorar",
    "doutorare": "doutorar",
    "doutorarei": "doutorar",
    "doutorareis": "doutorar",
    "doutorarem": "doutorar",
    "doutoraremos": "doutorar",
    "doutorares": "doutorar",
    "doutoraria": "doutorar",
    "doutorariam": "doutorar",
    "doutorarias": "doutorar",
    "doutorarmo": "doutorar",
    "doutorarmos": "doutorar",
    "doutorará": "doutorar",
    "doutorarás": "doutorar",
    "doutorarão": "doutorar",
    "doutoraríamos": "doutorar",
    "doutoraríeis": "doutorar",
    "doutoras": "doutorar",
    "doutorasse": "doutorar",
    "doutorassem": "doutorar",
    "doutorasses": "doutorar",
    "doutoraste": "doutorar",
    "doutorastes": "doutorar",
    "doutorava": "doutorar",
    "doutoravam": "doutorar",
    "doutoravas": "doutorar",
    "doutoraça": "doutoraço",
    "doutoraças": "doutoraço",
    "doutoraços": "doutoraço",
    "doutore": "doutorar",
    "doutorei": "doutorar",
    "doutoreis": "doutorar",
    "doutorem": "doutorar",
    "doutoremo": "doutorar",
    "doutoremos": "doutorar",
    "doutores": "doutorar",
    "doutoresca": "doutoresco",
    "doutorescas": "doutoresco",
    "doutorescos": "doutoresco",
    "doutorices": "doutorice",
    "doutoro": "doutorar",
    "doutorou": "doutorar",
    "doutorá": "doutorar",
    "doutorámo": "doutorar",
    "doutorámos": "doutorar",
    "doutoráramo": "doutorar",
    "doutoráramos": "doutorar",
    "doutorárei": "doutorar",
    "doutoráreis": "doutorar",
    "doutorásseis": "doutorar",
    "doutorássemos": "doutorar",
    "doutorávamo": "doutorar",
    "doutorávamos": "doutorar",
    "doutorávei": "doutorar",
    "doutoráveis": "doutorável",
    "doutos": "douto",
    "doutrina": "doutrinar",
    "doutrinada": "doutrinar",
    "doutrinadas": "doutrinar",
    "doutrinado": "doutrinar",
    "doutrinadora": "doutrinador",
    "doutrinadoras": "doutrinador",
    "doutrinadores": "doutrinador",
    "doutrinados": "doutrinar",
    "doutrinai": "doutrinar",
    "doutrinais": "doutrinar",
    "doutrinam": "doutrinar",
    "doutrinamentos": "doutrinamento",
    "doutrinamo": "doutrinar",
    "doutrinamos": "doutrinar",
    "doutrinanda": "doutrinando",
    "doutrinandas": "doutrinando",
    "doutrinando": "doutrinar",
    "doutrinandos": "doutrinando",
    "doutrinantes": "doutrinante",
    "doutrinara": "doutrinar",
    "doutrinaram": "doutrinar",
    "doutrinaras": "doutrinar",
    "doutrinarde": "doutrinar",
    "doutrinardes": "doutrinar",
    "doutrinare": "doutrinar",
    "doutrinarei": "doutrinar",
    "doutrinareis": "doutrinar",
    "doutrinarem": "doutrinar",
    "doutrinaremos": "doutrinar",
    "doutrinares": "doutrinar",
    "doutrinaria": "doutrinar",
    "doutrinariam": "doutrinar",
    "doutrinarias": "doutrinar",
    "doutrinarismos": "doutrinarismo",
    "doutrinaristas": "doutrinarista",
    "doutrinarmo": "doutrinar",
    "doutrinarmos": "doutrinar",
    "doutrinará": "doutrinar",
    "doutrinarás": "doutrinar",
    "doutrinarão": "doutrinar",
    "doutrinaríamos": "doutrinar",
    "doutrinaríeis": "doutrinar",
    "doutrinas": "doutrinar",
    "doutrinasse": "doutrinar",
    "doutrinassem": "doutrinar",
    "doutrinasses": "doutrinar",
    "doutrinaste": "doutrinar",
    "doutrinastes": "doutrinar",
    "doutrinava": "doutrinar",
    "doutrinavam": "doutrinar",
    "doutrinavas": "doutrinar",
    "doutrinações": "doutrinação",
    "doutrine": "doutrinar",
    "doutrinei": "doutrinar",
    "doutrineira": "doutrineiro",
    "doutrineiras": "doutrineiro",
    "doutrineiros": "doutrineiro",
    "doutrineis": "doutrinar",
    "doutrinem": "doutrinar",
    "doutrinemo": "doutrinar",
    "doutrinemos": "doutrinar",
    "doutrines": "doutrinar",
    "doutrino": "doutrinar",
    "doutrinou": "doutrinar",
    "doutriná": "doutrinar",
    "doutrinámo": "doutrinar",
    "doutrinámos": "doutrinar",
    "doutrináramo": "doutrinar",
    "doutrináramos": "doutrinar",
    "doutrinárei": "doutrinar",
    "doutrináreis": "doutrinar",
    "doutrinária": "doutrinário",
    "doutrinárias": "doutrinário",
    "doutrinários": "doutrinário",
    "doutrinásseis": "doutrinar",
    "doutrinássemos": "doutrinar",
    "doutrinávamo": "doutrinar",
    "doutrinávamos": "doutrinar",
    "doutrinávei": "doutrinar",
    "doutrináveis": "doutrinável",
    "doutíloquos": "doutíloquo",
    "doutíssima": "douto",
    "doutíssimas": "douto",
    "doutíssimo": "douto",
    "doutíssimos": "douto",
    "dowtonianos": "dowtoniano",
    "doxografias": "doxografia",
    "doxologias": "doxologia",
    "doxomanias": "doxomania",
    "doxometrias": "doxometria",
    "dozenas": "dozena",
    "dozões": "dozão",
    "doá": "doar",
    "doámo": "doar",
    "doámos": "doar",
    "doáramo": "doar",
    "doáramos": "doar",
    "doárei": "doar",
    "doáreis": "doar",
    "doásseis": "doar",
    "doássemos": "doar",
    "doávamo": "doar",
    "doávamos": "doar",
    "doávei": "doar",
    "doáveis": "doável",
    "doçagens": "doçagem",
    "doçainas": "doçaina",
    "doçais": "doçal",
    "doçarias": "doçaria",
    "doçuras": "doçura",
    "doêramo": "doer",
    "doêramos": "doer",
    "doêreis": "doer",
    "doêsseis": "doer",
    "doêssemos": "doer",
    "doí": "doer",
    "doía": "doer",
    "doíam": "doer",
    "doíamo": "doer",
    "doíamos": "doer",
    "doías": "doer",
    "doída": "doer",
    "doídas": "doer",
    "doído": "doer",
    "doídos": "doer",
    "doíeis": "doer",
    "dra": "dr",
    "dracenas": "dracena",
    "dracinas": "dracina",
    "dracmas": "dracma",
    "draconiana": "draconiano",
    "draconianas": "draconiano",
    "draconianos": "draconiano",
    "dracontíases": "dracontíase",
    "dracunculoses": "dracunculose",
    "dracúnculos": "dracúnculo",
    "draga": "dragar",
    "dragada": "dragar",
    "dragadas": "dragar",
    "dragado": "dragar",
    "dragadora": "dragador",
    "dragadoras": "dragador",
    "dragadores": "dragador",
    "dragados": "dragar",
    "dragagens": "dragagem",
    "dragai": "dragar",
    "dragais": "dragar",
    "dragam": "dragar",
    "dragamo": "dragar",
    "dragamos": "dragar",
    "dragando": "dragar",
    "dragara": "dragar",
    "dragaram": "dragar",
    "dragaras": "dragar",
    "dragarde": "dragar",
    "dragardes": "dragar",
    "dragare": "dragar",
    "dragarei": "dragar",
    "dragareis": "dragar",
    "dragarem": "dragar",
    "dragaremos": "dragar",
    "dragares": "dragar",
    "dragaria": "dragar",
    "dragariam": "dragar",
    "dragarias": "dragar",
    "dragarmo": "dragar",
    "dragarmos": "dragar",
    "dragará": "dragar",
    "dragarás": "dragar",
    "dragarão": "dragar",
    "dragaríamos": "dragar",
    "dragaríeis": "dragar",
    "dragas": "dragar",
    "dragasse": "dragar",
    "dragassem": "dragar",
    "dragasses": "dragar",
    "dragaste": "dragar",
    "dragastes": "dragar",
    "dragava": "dragar",
    "dragavam": "dragar",
    "dragavas": "dragar",
    "drageias": "drageia",
    "drago": "dragar",
    "dragoeiros": "dragoeiro",
    "dragomanos": "dragomano",
    "dragonada": "dragonado",
    "dragonadas": "dragonado",
    "dragonados": "dragonado",
    "dragonas": "dragona",
    "dragonetes": "dragonete",
    "dragonteias": "dragonteia",
    "dragontina": "dragontino",
    "dragontinas": "dragontino",
    "dragontinos": "dragontino",
    "dragos": "drago",
    "dragou": "dragar",
    "drague": "dragar",
    "draguei": "dragar",
    "dragueis": "dragar",
    "draguem": "dragar",
    "draguemo": "dragar",
    "draguemos": "dragar",
    "dragues": "dragar",
    "dragá": "dragar",
    "dragámo": "dragar",
    "dragámos": "dragar",
    "dragáramo": "dragar",
    "dragáramos": "dragar",
    "dragárei": "dragar",
    "dragáreis": "dragar",
    "dragásseis": "dragar",
    "dragássemos": "dragar",
    "dragávamo": "dragar",
    "dragávamos": "dragar",
    "dragávei": "dragar",
    "dragáveis": "dragar",
    "dragões": "dragão",
    "draivas": "draiva",
    "dramadeiras": "dramadeira",
    "dramalhões": "dramalhão",
    "dramaminas": "dramamina",
    "dramas": "drama",
    "dramaticidades": "dramaticidade",
    "dramatismos": "dramatismo",
    "dramatiza": "dramatizar",
    "dramatizada": "dramatizar",
    "dramatizadas": "dramatizar",
    "dramatizado": "dramatizar",
    "dramatizados": "dramatizar",
    "dramatizai": "dramatizar",
    "dramatizais": "dramatizar",
    "dramatizam": "dramatizar",
    "dramatizamo": "dramatizar",
    "dramatizamos": "dramatizar",
    "dramatizando": "dramatizar",
    "dramatizara": "dramatizar",
    "dramatizaram": "dramatizar",
    "dramatizaras": "dramatizar",
    "dramatizarde": "dramatizar",
    "dramatizardes": "dramatizar",
    "dramatizare": "dramatizar",
    "dramatizarei": "dramatizar",
    "dramatizareis": "dramatizar",
    "dramatizarem": "dramatizar",
    "dramatizaremos": "dramatizar",
    "dramatizares": "dramatizar",
    "dramatizaria": "dramatizar",
    "dramatizariam": "dramatizar",
    "dramatizarias": "dramatizar",
    "dramatizarmo": "dramatizar",
    "dramatizarmos": "dramatizar",
    "dramatizará": "dramatizar",
    "dramatizarás": "dramatizar",
    "dramatizarão": "dramatizar",
    "dramatizaríamos": "dramatizar",
    "dramatizaríeis": "dramatizar",
    "dramatizas": "dramatizar",
    "dramatizasse": "dramatizar",
    "dramatizassem": "dramatizar",
    "dramatizasses": "dramatizar",
    "dramatizaste": "dramatizar",
    "dramatizastes": "dramatizar",
    "dramatizava": "dramatizar",
    "dramatizavam": "dramatizar",
    "dramatizavas": "dramatizar",
    "dramatizações": "dramatização",
    "dramatize": "dramatizar",
    "dramatizei": "dramatizar",
    "dramatizeis": "dramatizar",
    "dramatizem": "dramatizar",
    "dramatizemo": "dramatizar",
    "dramatizemos": "dramatizar",
    "dramatizes": "dramatizar",
    "dramatizo": "dramatizar",
    "dramatizou": "dramatizar",
    "dramatizá": "dramatizar",
    "dramatizámo": "dramatizar",
    "dramatizámos": "dramatizar",
    "dramatizáramo": "dramatizar",
    "dramatizáramos": "dramatizar",
    "dramatizárei": "dramatizar",
    "dramatizáreis": "dramatizar",
    "dramatizásseis": "dramatizar",
    "dramatizássemos": "dramatizar",
    "dramatizávamo": "dramatizar",
    "dramatizávamos": "dramatizar",
    "dramatizávei": "dramatizar",
    "dramatizáveis": "dramatizável",
    "dramatologias": "dramatologia",
    "dramatológica": "dramatológico",
    "dramatológicas": "dramatológico",
    "dramatológicos": "dramatológico",
    "dramaturga": "dramaturgo",
    "dramaturgas": "dramaturgo",
    "dramaturgias": "dramaturgia",
    "dramaturgistas": "dramaturgista",
    "dramaturgos": "dramaturgo",
    "dramatúrgica": "dramatúrgico",
    "dramatúrgicas": "dramatúrgico",
    "dramatúrgicos": "dramatúrgico",
    "dramática": "dramático",
    "dramáticas": "dramático",
    "dramáticos": "dramático",
    "drapeja": "drapejar",
    "drapejada": "drapejar",
    "drapejadas": "drapejar",
    "drapejado": "drapejar",
    "drapejados": "drapejar",
    "drapejai": "drapejar",
    "drapejais": "drapejar",
    "drapejam": "drapejar",
    "drapejamo": "drapejar",
    "drapejamos": "drapejar",
    "drapejando": "drapejar",
    "drapejara": "drapejar",
    "drapejaram": "drapejar",
    "drapejaras": "drapejar",
    "drapejarde": "drapejar",
    "drapejardes": "drapejar",
    "drapejare": "drapejar",
    "drapejarei": "drapejar",
    "drapejareis": "drapejar",
    "drapejarem": "drapejar",
    "drapejaremos": "drapejar",
    "drapejares": "drapejar",
    "drapejaria": "drapejar",
    "drapejariam": "drapejar",
    "drapejarias": "drapejar",
    "drapejarmo": "drapejar",
    "drapejarmos": "drapejar",
    "drapejará": "drapejar",
    "drapejarás": "drapejar",
    "drapejarão": "drapejar",
    "drapejaríamos": "drapejar",
    "drapejaríeis": "drapejar",
    "drapejas": "drapejar",
    "drapejasse": "drapejar",
    "drapejassem": "drapejar",
    "drapejasses": "drapejar",
    "drapejaste": "drapejar",
    "drapejastes": "drapejar",
    "drapejava": "drapejar",
    "drapejavam": "drapejar",
    "drapejavas": "drapejar",
    "drapeje": "drapejar",
    "drapejei": "drapejar",
    "drapejeis": "drapejar",
    "drapejem": "drapejar",
    "drapejemo": "drapejar",
    "drapejemos": "drapejar",
    "drapejes": "drapejar",
    "drapejo": "drapejar",
    "drapejou": "drapejar",
    "drapejá": "drapejar",
    "drapejámo": "drapejar",
    "drapejámos": "drapejar",
    "drapejáramo": "drapejar",
    "drapejáramos": "drapejar",
    "drapejárei": "drapejar",
    "drapejáreis": "drapejar",
    "drapejásseis": "drapejar",
    "drapejássemos": "drapejar",
    "drapejávamo": "drapejar",
    "drapejávamos": "drapejar",
    "drapejávei": "drapejar",
    "drapejáveis": "drapejar",
    "drapês": "drapê",
    "dras": "dr",
    "draspeados": "draspeado",
    "draspeamentos": "draspeamento",
    "draspejamentos": "draspejamento",
    "draubaques": "draubaque",
    "dravidianos": "dravidiano",
    "dravidistas": "dravidista",
    "drena": "drenar",
    "drenada": "drenar",
    "drenadas": "drenar",
    "drenado": "drenar",
    "drenadora": "drenador",
    "drenadoras": "drenador",
    "drenadores": "drenador",
    "drenados": "drenar",
    "drenagens": "drenagem",
    "drenai": "drenar",
    "drenais": "drenar",
    "drenam": "drenar",
    "drenamo": "drenar",
    "drenamos": "drenar",
    "drenando": "drenar",
    "drenara": "drenar",
    "drenaram": "drenar",
    "drenaras": "drenar",
    "drenarde": "drenar",
    "drenardes": "drenar",
    "drenare": "drenar",
    "drenarei": "drenar",
    "drenareis": "drenar",
    "drenarem": "drenar",
    "drenaremos": "drenar",
    "drenares": "drenar",
    "drenaria": "drenar",
    "drenariam": "drenar",
    "drenarias": "drenar",
    "drenarmo": "drenar",
    "drenarmos": "drenar",
    "drenará": "drenar",
    "drenarás": "drenar",
    "drenarão": "drenar",
    "drenaríamos": "drenar",
    "drenaríeis": "drenar",
    "drenas": "drenar",
    "drenasse": "drenar",
    "drenassem": "drenar",
    "drenasses": "drenar",
    "drenaste": "drenar",
    "drenastes": "drenar",
    "drenava": "drenar",
    "drenavam": "drenar",
    "drenavas": "drenar",
    "drene": "drenar",
    "drenei": "drenar",
    "dreneis": "drenar",
    "drenem": "drenar",
    "drenemo": "drenar",
    "drenemos": "drenar",
    "drenes": "drenar",
    "dreno": "drenar",
    "drenos": "dreno",
    "drenou": "drenar",
    "drená": "drenar",
    "drenámo": "drenar",
    "drenámos": "drenar",
    "drenáramo": "drenar",
    "drenáramos": "drenar",
    "drenárei": "drenar",
    "drenáreis": "drenar",
    "drenásseis": "drenar",
    "drenássemos": "drenar",
    "drenávamo": "drenar",
    "drenávamos": "drenar",
    "drenávei": "drenar",
    "drenáveis": "drenável",
    "dribla": "driblar",
    "driblada": "driblar",
    "dribladas": "driblar",
    "driblado": "driblar",
    "driblados": "driblar",
    "driblagens": "driblagem",
    "driblai": "driblar",
    "driblais": "driblar",
    "driblam": "driblar",
    "driblamo": "driblar",
    "driblamos": "driblar",
    "driblando": "driblar",
    "driblara": "driblar",
    "driblaram": "driblar",
    "driblaras": "driblar",
    "driblarde": "driblar",
    "driblardes": "driblar",
    "driblare": "driblar",
    "driblarei": "driblar",
    "driblareis": "driblar",
    "driblarem": "driblar",
    "driblaremos": "driblar",
    "driblares": "driblar",
    "driblaria": "driblar",
    "driblariam": "driblar",
    "driblarias": "driblar",
    "driblarmo": "driblar",
    "driblarmos": "driblar",
    "driblará": "driblar",
    "driblarás": "driblar",
    "driblarão": "driblar",
    "driblaríamos": "driblar",
    "driblaríeis": "driblar",
    "driblas": "driblar",
    "driblasse": "driblar",
    "driblassem": "driblar",
    "driblasses": "driblar",
    "driblaste": "driblar",
    "driblastes": "driblar",
    "driblava": "driblar",
    "driblavam": "driblar",
    "driblavas": "driblar",
    "drible": "driblar",
    "driblei": "driblar",
    "dribleis": "driblar",
    "driblem": "driblar",
    "driblemo": "driblar",
    "driblemos": "driblar",
    "dribles": "drible",
    "driblo": "driblar",
    "driblou": "driblar",
    "driblá": "driblar",
    "driblámo": "driblar",
    "driblámos": "driblar",
    "dribláramo": "driblar",
    "dribláramos": "driblar",
    "driblárei": "driblar",
    "dribláreis": "driblar",
    "driblásseis": "driblar",
    "driblássemos": "driblar",
    "driblávamo": "driblar",
    "driblávamos": "driblar",
    "driblávei": "driblar",
    "dribláveis": "driblável",
    "dribos": "dribo",
    "dris": "dril",
    "drives": "drive",
    "driças": "driça",
    "drofas": "drofa",
    "droga": "drogar",
    "drogada": "drogar",
    "drogadas": "drogar",
    "drogado": "drogar",
    "drogados": "drogar",
    "drogai": "drogar",
    "drogais": "drogar",
    "drogam": "drogar",
    "drogamo": "drogar",
    "drogamos": "drogar",
    "drogando": "drogar",
    "drogara": "drogar",
    "drogaram": "drogar",
    "drogaras": "drogar",
    "drogarde": "drogar",
    "drogardes": "drogar",
    "drogare": "drogar",
    "drogarei": "drogar",
    "drogareis": "drogar",
    "drogarem": "drogar",
    "drogaremos": "drogar",
    "drogares": "drogar",
    "drogaria": "drogar",
    "drogariam": "drogar",
    "drogarias": "drogaria",
    "drogarmo": "drogar",
    "drogarmos": "drogar",
    "drogará": "drogar",
    "drogarás": "drogar",
    "drogarão": "drogar",
    "drogaríamos": "drogar",
    "drogaríeis": "drogar",
    "drogas": "drogar",
    "drogasse": "drogar",
    "drogassem": "drogar",
    "drogasses": "drogar",
    "drogaste": "drogar",
    "drogastes": "drogar",
    "drogava": "drogar",
    "drogavam": "drogar",
    "drogavas": "drogar",
    "drogo": "drogar",
    "drogomanos": "drogomano",
    "drogou": "drogar",
    "drogue": "drogar",
    "drogueada": "droguear",
    "drogueadas": "droguear",
    "drogueado": "droguear",
    "drogueados": "droguear",
    "drogueai": "droguear",
    "drogueais": "droguear",
    "drogueamo": "droguear",
    "drogueamos": "droguear",
    "drogueando": "droguear",
    "drogueara": "droguear",
    "droguearam": "droguear",
    "droguearas": "droguear",
    "droguearde": "droguear",
    "drogueardes": "droguear",
    "drogueare": "droguear",
    "droguearei": "droguear",
    "drogueareis": "droguear",
    "droguearem": "droguear",
    "droguearemos": "droguear",
    "drogueares": "droguear",
    "droguearia": "droguear",
    "drogueariam": "droguear",
    "droguearias": "droguear",
    "droguearmo": "droguear",
    "droguearmos": "droguear",
    "drogueará": "droguear",
    "droguearás": "droguear",
    "droguearão": "droguear",
    "droguearíamos": "droguear",
    "droguearíeis": "droguear",
    "drogueasse": "droguear",
    "drogueassem": "droguear",
    "drogueasses": "droguear",
    "drogueaste": "droguear",
    "drogueastes": "droguear",
    "drogueava": "droguear",
    "drogueavam": "droguear",
    "drogueavas": "droguear",
    "drogueei": "droguear",
    "drogueeis": "droguear",
    "drogueemo": "droguear",
    "drogueemos": "droguear",
    "droguei": "drogar",
    "drogueia": "droguear",
    "drogueiam": "droguear",
    "drogueias": "droguear",
    "drogueie": "droguear",
    "drogueiem": "droguear",
    "drogueies": "droguear",
    "drogueio": "droguear",
    "drogueis": "drogar",
    "droguem": "drogar",
    "droguemo": "drogar",
    "droguemos": "drogar",
    "drogueou": "droguear",
    "drogues": "drogar",
    "droguetes": "droguete",
    "drogueá": "droguear",
    "drogueámo": "droguear",
    "drogueámos": "droguear",
    "drogueáramo": "droguear",
    "drogueáramos": "droguear",
    "drogueárei": "droguear",
    "drogueáreis": "droguear",
    "drogueásseis": "droguear",
    "drogueássemos": "droguear",
    "drogueávamo": "droguear",
    "drogueávamos": "droguear",
    "drogueávei": "droguear",
    "drogueáveis": "drogueável",
    "droguistas": "droguista",
    "drogá": "drogar",
    "drogámo": "drogar",
    "drogámos": "drogar",
    "drogáramo": "drogar",
    "drogáramos": "drogar",
    "drogárei": "drogar",
    "drogáreis": "drogar",
    "drogásseis": "drogar",
    "drogássemos": "drogar",
    "drogávamo": "drogar",
    "drogávamos": "drogar",
    "drogávei": "drogar",
    "drogáveis": "drogar",
    "dromedários": "dromedário",
    "dromomanias": "dromomania",
    "dromomaníaca": "dromomaníaco",
    "dromomaníacas": "dromomaníaco",
    "dromomaníacos": "dromomaníaco",
    "dromopatias": "dromopatia",
    "dromos": "dromo",
    "dromoscópios": "dromoscópio",
    "dromoterapias": "dromoterapia",
    "dromundas": "dromunda",
    "dromógrafos": "dromógrafo",
    "dromómetros": "dromómetro",
    "dromórnitos": "dromórnito",
    "dropes": "drope",
    "droseráceas": "droserácea",
    "drosometrias": "drosometria",
    "drosométrica": "drosométrico",
    "drosométricas": "drosométrico",
    "drosométricos": "drosométrico",
    "drosómetros": "drosómetro",
    "drs": "dr",
    "druidas": "druida",
    "druidesas": "druidesa",
    "druidisas": "druidisa",
    "druidismos": "druidismo",
    "drupas": "drupa",
    "drupeolada": "drupeolado",
    "drupeoladas": "drupeolado",
    "drupeolados": "drupeolado",
    "drupácea": "drupáceo",
    "drupáceas": "drupáceo",
    "drupáceos": "drupáceo",
    "drupéolas": "drupéola",
    "drupífera": "drupífero",
    "drupíferas": "drupífero",
    "drupíferos": "drupífero",
    "drusa": "druso",
    "drusas": "druso",
    "drusos": "druso",
    "druídica": "druídico",
    "druídicas": "druídico",
    "druídicos": "druídico",
    "drástica": "drástico",
    "drásticas": "drástico",
    "drásticos": "drástico",
    "drávidas": "drávida",
    "dríadas": "dríada",
    "dríades": "dríade",
    "dróseras": "drósera",
    "duais": "dual",
    "dualidades": "dualidade",
    "dualismos": "dualismo",
    "dualistas": "dualista",
    "dualiza": "dualizar",
    "dualizada": "dualizar",
    "dualizadas": "dualizar",
    "dualizado": "dualizar",
    "dualizadora": "dualizador",
    "dualizadoras": "dualizador",
    "dualizadores": "dualizador",
    "dualizados": "dualizar",
    "dualizai": "dualizar",
    "dualizais": "dualizar",
    "dualizam": "dualizar",
    "dualizamo": "dualizar",
    "dualizamos": "dualizar",
    "dualizando": "dualizar",
    "dualizara": "dualizar",
    "dualizaram": "dualizar",
    "dualizaras": "dualizar",
    "dualizarde": "dualizar",
    "dualizardes": "dualizar",
    "dualizare": "dualizar",
    "dualizarei": "dualizar",
    "dualizareis": "dualizar",
    "dualizarem": "dualizar",
    "dualizaremos": "dualizar",
    "dualizares": "dualizar",
    "dualizaria": "dualizar",
    "dualizariam": "dualizar",
    "dualizarias": "dualizar",
    "dualizarmo": "dualizar",
    "dualizarmos": "dualizar",
    "dualizará": "dualizar",
    "dualizarás": "dualizar",
    "dualizarão": "dualizar",
    "dualizaríamos": "dualizar",
    "dualizaríeis": "dualizar",
    "dualizas": "dualizar",
    "dualizasse": "dualizar",
    "dualizassem": "dualizar",
    "dualizasses": "dualizar",
    "dualizaste": "dualizar",
    "dualizastes": "dualizar",
    "dualizava": "dualizar",
    "dualizavam": "dualizar",
    "dualizavas": "dualizar",
    "dualize": "dualizar",
    "dualizei": "dualizar",
    "dualizeis": "dualizar",
    "dualizem": "dualizar",
    "dualizemo": "dualizar",
    "dualizemos": "dualizar",
    "dualizes": "dualizar",
    "dualizo": "dualizar",
    "dualizou": "dualizar",
    "dualizá": "dualizar",
    "dualizámo": "dualizar",
    "dualizámos": "dualizar",
    "dualizáramo": "dualizar",
    "dualizáramos": "dualizar",
    "dualizárei": "dualizar",
    "dualizáreis": "dualizar",
    "dualizásseis": "dualizar",
    "dualizássemos": "dualizar",
    "dualizávamo": "dualizar",
    "dualizávamos": "dualizar",
    "dualizávei": "dualizar",
    "dualizáveis": "dualizável",
    "dualística": "dualístico",
    "dualísticas": "dualístico",
    "dualísticos": "dualístico",
    "duas": "dois",
    "dubiedades": "dubiedade",
    "dubitabilidades": "dubitabilidade",
    "dubitativa": "dubitativo",
    "dubitativas": "dubitativo",
    "dubitativos": "dubitativo",
    "dubitações": "dubitação",
    "dubitáveis": "dubitável",
    "dubletos": "dubleto",
    "ducados": "ducado",
    "ducais": "ducal",
    "ducatões": "ducatão",
    "ducentésima": "ducentésimo",
    "ducentésimas": "ducentésimo",
    "ducentésimos": "ducentésimo",
    "duces": "duce",
    "ducha": "duchar",
    "duchada": "duchar",
    "duchadas": "duchar",
    "duchado": "duchar",
    "duchados": "duchar",
    "duchai": "duchar",
    "duchais": "duchar",
    "ducham": "duchar",
    "duchamo": "duchar",
    "duchamos": "duchar",
    "duchando": "duchar",
    "duchara": "duchar",
    "ducharam": "duchar",
    "ducharas": "duchar",
    "ducharde": "duchar",
    "duchardes": "duchar",
    "duchare": "duchar",
    "ducharei": "duchar",
    "duchareis": "duchar",
    "ducharem": "duchar",
    "ducharemos": "duchar",
    "duchares": "duchar",
    "ducharia": "duchar",
    "duchariam": "duchar",
    "ducharias": "duchar",
    "ducharmo": "duchar",
    "ducharmos": "duchar",
    "duchará": "duchar",
    "ducharás": "duchar",
    "ducharão": "duchar",
    "ducharíamos": "duchar",
    "ducharíeis": "duchar",
    "duchas": "duchar",
    "duchasse": "duchar",
    "duchassem": "duchar",
    "duchasses": "duchar",
    "duchaste": "duchar",
    "duchastes": "duchar",
    "duchava": "duchar",
    "duchavam": "duchar",
    "duchavas": "duchar",
    "duche": "duchar",
    "duchei": "duchar",
    "ducheis": "duchar",
    "duchem": "duchar",
    "duchemo": "duchar",
    "duchemos": "duchar",
    "duches": "duche",
    "duchistas": "duchista",
    "ducho": "duchar",
    "duchou": "duchar",
    "duchá": "duchar",
    "duchámo": "duchar",
    "duchámos": "duchar",
    "ducháramo": "duchar",
    "ducháramos": "duchar",
    "duchárei": "duchar",
    "ducháreis": "duchar",
    "duchásseis": "duchar",
    "duchássemos": "duchar",
    "duchávamo": "duchar",
    "duchávamos": "duchar",
    "duchávei": "duchar",
    "ducháveis": "duchar",
    "ducinas": "ducina",
    "ductilidades": "ductilidade",
    "ductiliza": "ductilizar",
    "ductilizada": "ductilizar",
    "ductilizadas": "ductilizar",
    "ductilizado": "ductilizar",
    "ductilizados": "ductilizar",
    "ductilizai": "ductilizar",
    "ductilizais": "ductilizar",
    "ductilizam": "ductilizar",
    "ductilizamo": "ductilizar",
    "ductilizamos": "ductilizar",
    "ductilizando": "ductilizar",
    "ductilizara": "ductilizar",
    "ductilizaram": "ductilizar",
    "ductilizaras": "ductilizar",
    "ductilizarde": "ductilizar",
    "ductilizardes": "ductilizar",
    "ductilizare": "ductilizar",
    "ductilizarei": "ductilizar",
    "ductilizareis": "ductilizar",
    "ductilizarem": "ductilizar",
    "ductilizaremos": "ductilizar",
    "ductilizares": "ductilizar",
    "ductilizaria": "ductilizar",
    "ductilizariam": "ductilizar",
    "ductilizarias": "ductilizar",
    "ductilizarmo": "ductilizar",
    "ductilizarmos": "ductilizar",
    "ductilizará": "ductilizar",
    "ductilizarás": "ductilizar",
    "ductilizarão": "ductilizar",
    "ductilizaríamos": "ductilizar",
    "ductilizaríeis": "ductilizar",
    "ductilizas": "ductilizar",
    "ductilizasse": "ductilizar",
    "ductilizassem": "ductilizar",
    "ductilizasses": "ductilizar",
    "ductilizaste": "ductilizar",
    "ductilizastes": "ductilizar",
    "ductilizava": "ductilizar",
    "ductilizavam": "ductilizar",
    "ductilizavas": "ductilizar",
    "ductilize": "ductilizar",
    "ductilizei": "ductilizar",
    "ductilizeis": "ductilizar",
    "ductilizem": "ductilizar",
    "ductilizemo": "ductilizar",
    "ductilizemos": "ductilizar",
    "ductilizes": "ductilizar",
    "ductilizo": "ductilizar",
    "ductilizou": "ductilizar",
    "ductilizá": "ductilizar",
    "ductilizámo": "ductilizar",
    "ductilizámos": "ductilizar",
    "ductilizáramo": "ductilizar",
    "ductilizáramos": "ductilizar",
    "ductilizárei": "ductilizar",
    "ductilizáreis": "ductilizar",
    "ductilizásseis": "ductilizar",
    "ductilizássemos": "ductilizar",
    "ductilizávamo": "ductilizar",
    "ductilizávamos": "ductilizar",
    "ductilizávei": "ductilizar",
    "ductilizáveis": "ductilizável",
    "ductos": "ducto",
    "duduidades": "duduidade",
    "duelares": "duelar",
    "duelistas": "duelista",
    "duelos": "duelo",
    "duendes": "duende",
    "duernos": "duerno",
    "duetistas": "duetista",
    "duetos": "dueto",
    "dugongos": "dugongo",
    "dugões": "dugão",
    "duidades": "duidade",
    "dulcamadas": "dulcamada",
    "dulcamaras": "dulcamara",
    "dulcamarinas": "dulcamarina",
    "dulcifica": "dulcificar",
    "dulcificada": "dulcificar",
    "dulcificadas": "dulcificar",
    "dulcificado": "dulcificar",
    "dulcificadora": "dulcificador",
    "dulcificadoras": "dulcificador",
    "dulcificadores": "dulcificador",
    "dulcificados": "dulcificar",
    "dulcificai": "dulcificar",
    "dulcificais": "dulcificar",
    "dulcificam": "dulcificar",
    "dulcificamo": "dulcificar",
    "dulcificamos": "dulcificar",
    "dulcificando": "dulcificar",
    "dulcificara": "dulcificar",
    "dulcificaram": "dulcificar",
    "dulcificaras": "dulcificar",
    "dulcificarde": "dulcificar",
    "dulcificardes": "dulcificar",
    "dulcificare": "dulcificar",
    "dulcificarei": "dulcificar",
    "dulcificareis": "dulcificar",
    "dulcificarem": "dulcificar",
    "dulcificaremos": "dulcificar",
    "dulcificares": "dulcificar",
    "dulcificaria": "dulcificar",
    "dulcificariam": "dulcificar",
    "dulcificarias": "dulcificar",
    "dulcificarmo": "dulcificar",
    "dulcificarmos": "dulcificar",
    "dulcificará": "dulcificar",
    "dulcificarás": "dulcificar",
    "dulcificarão": "dulcificar",
    "dulcificaríamos": "dulcificar",
    "dulcificaríeis": "dulcificar",
    "dulcificas": "dulcificar",
    "dulcificasse": "dulcificar",
    "dulcificassem": "dulcificar",
    "dulcificasses": "dulcificar",
    "dulcificaste": "dulcificar",
    "dulcificastes": "dulcificar",
    "dulcificava": "dulcificar",
    "dulcificavam": "dulcificar",
    "dulcificavas": "dulcificar",
    "dulcificações": "dulcificação",
    "dulcifico": "dulcificar",
    "dulcificou": "dulcificar",
    "dulcificá": "dulcificar",
    "dulcificámo": "dulcificar",
    "dulcificámos": "dulcificar",
    "dulcificáramo": "dulcificar",
    "dulcificáramos": "dulcificar",
    "dulcificárei": "dulcificar",
    "dulcificáreis": "dulcificar",
    "dulcificásseis": "dulcificar",
    "dulcificássemos": "dulcificar",
    "dulcificávamo": "dulcificar",
    "dulcificávamos": "dulcificar",
    "dulcificávei": "dulcificar",
    "dulcificáveis": "dulcificável",
    "dulcifique": "dulcificar",
    "dulcifiquei": "dulcificar",
    "dulcifiqueis": "dulcificar",
    "dulcifiquem": "dulcificar",
    "dulcifiquemo": "dulcificar",
    "dulcifiquemos": "dulcificar",
    "dulcifiques": "dulcificar",
    "dulcilucentes": "dulcilucente",
    "dulcineias": "dulcineia",
    "dulciolentes": "dulciolente",
    "dulcissonantes": "dulcissonante",
    "dulcífera": "dulcífero",
    "dulcíferas": "dulcífero",
    "dulcíferos": "dulcífero",
    "dulcífica": "dulcífico",
    "dulcíficas": "dulcífico",
    "dulcíficos": "dulcífico",
    "dulcíflua": "dulcífluo",
    "dulcífluas": "dulcífluo",
    "dulcífluos": "dulcífluo",
    "dulcíloqua": "dulcíloquo",
    "dulcíloquas": "dulcíloquo",
    "dulcíloquos": "dulcíloquo",
    "dulcíssima": "dócil",
    "dulcíssimas": "dócil",
    "dulcíssimo": "dócil",
    "dulcíssimos": "dócil",
    "dulcíssona": "dulcíssono",
    "dulcíssonas": "dulcíssono",
    "dulcíssonos": "dulcíssono",
    "dulias": "dulia",
    "dulocracias": "dulocracia",
    "dulçaínas": "dulçaína",
    "dulçores": "dulçor",
    "dulçorosa": "dulçoroso",
    "dulçorosas": "dulçoroso",
    "dulçorosos": "dulçoroso",
    "dumas": "duma",
    "dumos": "dumo",
    "dumpings": "dumping",
    "dunas": "duna",
    "dunduns": "dundum",
    "dunetas": "duneta",
    "dunfas": "dunfa",
    "dunitos": "dunito",
    "duodecenais": "duodecenal",
    "duodecimais": "duodecimal",
    "duodecénios": "duodecénio",
    "duodenais": "duodenal",
    "duodenites": "duodenite",
    "duodenos": "duodeno",
    "duodenoscopias": "duodenoscopia",
    "duodenária": "duodenário",
    "duodenárias": "duodenário",
    "duodenários": "duodenário",
    "duodécima": "duodécimo",
    "duodécimas": "duodécimo",
    "duodécimos": "duodécimo",
    "duodécupla": "duodécuplo",
    "duodécuplas": "duodécuplo",
    "duodécuplos": "duodécuplo",
    "duos": "duo",
    "dupla": "duplo",
    "duplas": "duplo",
    "duplexors": "duplexor",
    "duplexs": "duplex",
    "duplica": "duplicar",
    "duplicada": "duplicar",
    "duplicadas": "duplicar",
    "duplicado": "duplicar",
    "duplicadora": "duplicador",
    "duplicadoras": "duplicador",
    "duplicadores": "duplicador",
    "duplicados": "duplicar",
    "duplicai": "duplicar",
    "duplicais": "duplicar",
    "duplicam": "duplicar",
    "duplicamo": "duplicar",
    "duplicamos": "duplicar",
    "duplicando": "duplicar",
    "duplicantes": "duplicante",
    "duplicara": "duplicar",
    "duplicaram": "duplicar",
    "duplicaras": "duplicar",
    "duplicarde": "duplicar",
    "duplicardes": "duplicar",
    "duplicare": "duplicar",
    "duplicarei": "duplicar",
    "duplicareis": "duplicar",
    "duplicarem": "duplicar",
    "duplicaremos": "duplicar",
    "duplicares": "duplicar",
    "duplicaria": "duplicar",
    "duplicariam": "duplicar",
    "duplicarias": "duplicar",
    "duplicarmo": "duplicar",
    "duplicarmos": "duplicar",
    "duplicará": "duplicar",
    "duplicarás": "duplicar",
    "duplicarão": "duplicar",
    "duplicaríamos": "duplicar",
    "duplicaríeis": "duplicar",
    "duplicas": "duplicar",
    "duplicasse": "duplicar",
    "duplicassem": "duplicar",
    "duplicasses": "duplicar",
    "duplicaste": "duplicar",
    "duplicastes": "duplicar",
    "duplicatas": "duplicata",
    "duplicativa": "duplicativo",
    "duplicativas": "duplicativo",
    "duplicativos": "duplicativo",
    "duplicaturas": "duplicatura",
    "duplicava": "duplicar",
    "duplicavam": "duplicar",
    "duplicavas": "duplicar",
    "duplicações": "duplicação",
    "duplicidades": "duplicidade",
    "duplico": "duplicar",
    "duplicou": "duplicar",
    "duplicá": "duplicar",
    "duplicámo": "duplicar",
    "duplicámos": "duplicar",
    "duplicáramo": "duplicar",
    "duplicáramos": "duplicar",
    "duplicárei": "duplicar",
    "duplicáreis": "duplicar",
    "duplicásseis": "duplicar",
    "duplicássemos": "duplicar",
    "duplicávamo": "duplicar",
    "duplicávamos": "duplicar",
    "duplicávei": "duplicar",
    "duplicáveis": "duplicável",
    "duplique": "duplicar",
    "dupliquei": "duplicar",
    "dupliqueis": "duplicar",
    "dupliquem": "duplicar",
    "dupliquemo": "duplicar",
    "dupliquemos": "duplicar",
    "dupliques": "duplicar",
    "duplos": "duplo",
    "duques": "duque",
    "duquesa": "duque",
    "duquesas": "duquesa",
    "dura": "duro",
    "durabilidades": "durabilidade",
    "durada": "durar",
    "duradas": "durar",
    "durado": "durar",
    "duradoira": "duradoiro",
    "duradoiras": "duradoiro",
    "duradoiros": "duradoiro",
    "durados": "durar",
    "duradoura": "duradouro",
    "duradouras": "duradouro",
    "duradouros": "duradouro",
    "durai": "durar",
    "durais": "durar",
    "duralumínios": "duralumínio",
    "duram": "durar",
    "durames": "durame",
    "duramo": "durar",
    "duramos": "durar",
    "durando": "durar",
    "durantes": "durante",
    "duraques": "duraque",
    "durara": "durar",
    "duraram": "durar",
    "duraras": "durar",
    "durarde": "durar",
    "durardes": "durar",
    "durare": "durar",
    "durarei": "durar",
    "durareis": "durar",
    "durarem": "durar",
    "duraremos": "durar",
    "durares": "durar",
    "duraria": "durar",
    "durariam": "durar",
    "durarias": "durar",
    "durarmo": "durar",
    "durarmos": "durar",
    "durará": "durar",
    "durarás": "durar",
    "durarão": "durar",
    "duraríamos": "durar",
    "duraríeis": "durar",
    "duras": "duro",
    "durasse": "durar",
    "durassem": "durar",
    "durasses": "durar",
    "duraste": "durar",
    "durastes": "durar",
    "durativa": "durativo",
    "durativas": "durativo",
    "durativos": "durativo",
    "durava": "durar",
    "duravam": "durar",
    "duravas": "durar",
    "durazes": "duraz",
    "durações": "duração",
    "dure": "durar",
    "durei": "durar",
    "dureis": "durar",
    "durem": "durar",
    "duremo": "durar",
    "duremos": "durar",
    "dures": "durar",
    "durezas": "dureza",
    "duriangos": "duriango",
    "durienses": "duriense",
    "durimínia": "durimínio",
    "durimínias": "durimínio",
    "durimínios": "durimínio",
    "durindanas": "durindana",
    "duriões": "durião",
    "durma": "dormir",
    "durmais": "dormir",
    "durmam": "dormir",
    "durmamo": "dormir",
    "durmamos": "dormir",
    "durmas": "dormir",
    "durmo": "dormir",
    "duro": "durar",
    "duros": "duro",
    "durou": "durar",
    "durá": "durar",
    "durámo": "durar",
    "durámos": "durar",
    "duráramo": "durar",
    "duráramos": "durar",
    "durárei": "durar",
    "duráreis": "durar",
    "durásseis": "durar",
    "durássemos": "durar",
    "durávamo": "durar",
    "durávamos": "durar",
    "durávei": "durar",
    "duráveis": "durável",
    "durázia": "durázio",
    "durázias": "durázio",
    "durázios": "durázio",
    "durâmenes": "durâmen",
    "duríades": "duríade",
    "duríssima": "duro",
    "duríssimas": "duro",
    "duríssimo": "duro",
    "duríssimos": "duro",
    "durões": "durão",
    "duunvirados": "duunvirado",
    "duunvirais": "duunviral",
    "duunviratos": "duunvirato",
    "duvida": "duvidar",
    "duvidada": "duvidar",
    "duvidadas": "duvidar",
    "duvidado": "duvidar",
    "duvidadora": "duvidador",
    "duvidadoras": "duvidador",
    "duvidadores": "duvidador",
    "duvidados": "duvidar",
    "duvidai": "duvidar",
    "duvidais": "duvidar",
    "duvidam": "duvidar",
    "duvidamo": "duvidar",
    "duvidamos": "duvidar",
    "duvidando": "duvidar",
    "duvidara": "duvidar",
    "duvidaram": "duvidar",
    "duvidaras": "duvidar",
    "duvidardes": "duvidar",
    "duvidarei": "duvidar",
    "duvidareis": "duvidar",
    "duvidarem": "duvidar",
    "duvidaremos": "duvidar",
    "duvidares": "duvidar",
    "duvidaria": "duvidar",
    "duvidariam": "duvidar",
    "duvidarias": "duvidar",
    "duvidarmo": "duvidar",
    "duvidarmos": "duvidar",
    "duvidará": "duvidar",
    "duvidarás": "duvidar",
    "duvidarão": "duvidar",
    "duvidaríamos": "duvidar",
    "duvidaríeis": "duvidar",
    "duvidas": "duvidar",
    "duvidasse": "duvidar",
    "duvidassem": "duvidar",
    "duvidasses": "duvidar",
    "duvidaste": "duvidar",
    "duvidastes": "duvidar",
    "duvidava": "duvidar",
    "duvidavam": "duvidar",
    "duvidavas": "duvidar",
    "duvidazinha": "dúvida",
    "duvidazinhas": "dúvida",
    "duvidazita": "dúvida",
    "duvidazitas": "dúvida",
    "duvide": "duvidar",
    "duvidei": "duvidar",
    "duvideis": "duvidar",
    "duvidem": "duvidar",
    "duvidemo": "duvidar",
    "duvidemos": "duvidar",
    "duvides": "duvidar",
    "duvido": "duvidar",
    "duvidosa": "duvidoso",
    "duvidosas": "duvidoso",
    "duvidosos": "duvidoso",
    "duvidou": "duvidar",
    "duvidámo": "duvidar",
    "duvidámos": "duvidar",
    "duvidáramo": "duvidar",
    "duvidáramos": "duvidar",
    "duvidáreis": "duvidar",
    "duvidásseis": "duvidar",
    "duvidássemos": "duvidar",
    "duvidávamo": "duvidar",
    "duvidávamos": "duvidar",
    "duvidáveis": "duvidável",
    "duzentas": "duzentos",
    "duíparas": "duípara",
    "duúnvira": "duúnviro",
    "duúnviras": "duúnviro",
    "duúnviros": "duúnviro",
    "dz": "d",
    "dzetas": "dzeta",
    "dá": "dar",
    "dácia": "dácio",
    "dácias": "dácio",
    "dácios": "dácio",
    "dáctilos": "dáctilo",
    "dádivas": "dádiva",
    "dáfnias": "dáfnia",
    "dáimios": "dáimio",
    "dálias": "dália",
    "dálmatas": "dálmata",
    "dás": "dar",
    "dátis": "dátil",
    "dávamo": "dar",
    "dávamos": "dar",
    "dávei": "dar",
    "dáveis": "dar",
    "dâmares": "dâmar",
    "dânacas": "dânaca",
    "dândis": "dândi",
    "dântica": "dântico",
    "dânticas": "dântico",
    "dânticos": "dântico",
    "dão": "dar",
    "débeis": "débil",
    "débitos": "débito",
    "décadas": "década",
    "décima": "décimo",
    "décimas": "décimo",
    "décimos": "décimo",
    "décores": "décor",
    "décupla": "décuplo",
    "dédala": "dédalo",
    "dédalas": "dédalo",
    "dédalos": "dédalo",
    "défices": "défice",
    "délfica": "délfico",
    "délficas": "délfico",
    "délficos": "délfico",
    "démica": "démico",
    "démicas": "démico",
    "démicos": "démico",
    "déramo": "dar",
    "déramos": "dar",
    "dérei": "dar",
    "déreis": "dar",
    "dérmica": "dérmico",
    "dérmicas": "dérmico",
    "dérmicos": "dérmico",
    "déspotas": "déspota",
    "désseis": "dar",
    "déssemos": "dar",
    "déus": "déu",
    "dê": "dar",
    "dêem": "dar",
    "dêmo": "dar",
    "dêmos": "dar",
    "dês": "dê",
    "díadas": "díada",
    "díades": "díade",
    "dídima": "dídimo",
    "dídimas": "dídimo",
    "dídimos": "dídimo",
    "díeses": "díese",
    "dígama": "dígamo",
    "dígamas": "dígamo",
    "dígamos": "dígamo",
    "dígina": "dígino",
    "díginas": "dígino",
    "díginos": "dígino",
    "dígita": "dígito",
    "dígitas": "dígito",
    "dígitos": "dígito",
    "díglifos": "díglifo",
    "dígona": "dígono",
    "dígonas": "dígono",
    "dígonos": "dígono",
    "dígrafa": "dígrafo",
    "dígrafas": "dígrafo",
    "dígrafos": "dígrafo",
    "dímeres": "dímere",
    "dímetros": "dímetro",
    "dínamos": "dínamo",
    "dínodos": "dínodo",
    "díodos": "díodo",
    "díperos": "dípero",
    "dípodes": "dípode",
    "díptera": "díptero",
    "dípteras": "díptero",
    "dípteros": "díptero",
    "dípticos": "díptico",
    "díscola": "díscolo",
    "díscolas": "díscolo",
    "díscolos": "díscolo",
    "dísfona": "dísfono",
    "dísfonas": "dísfono",
    "dísfonos": "dísfono",
    "díspares": "díspar",
    "díssona": "díssono",
    "díssonas": "díssono",
    "díssonos": "díssono",
    "dísticos": "dístico",
    "dístoma": "dístomo",
    "dístomas": "dístomo",
    "dístomos": "dístomo",
    "dítonos": "dítono",
    "dívidas": "dívida",
    "dízima": "dízimo",
    "dízimas": "dízimo",
    "dízimos": "dízimo",
    "dóceis": "dócil",
    "dói": "doer",
    "dóis": "dói",
    "dólares": "dólar",
    "dólicos": "dólico",
    "dólmans": "dólman",
    "dólmens": "dólmen",
    "dólmins": "dólmin",
    "dólmãs": "dólmã",
    "dória": "dório",
    "dórias": "dório",
    "dórica": "dórico",
    "dóricas": "dórico",
    "dóricos": "dórico",
    "dórios": "dório",
    "dóris": "dóri",
    "dós": "dó",
    "dóxica": "dóxico",
    "dóxicas": "dóxico",
    "dóxicos": "dóxico",
    "dúbia": "dúbio",
    "dúbias": "dúbio",
    "dúbios": "dúbio",
    "dúcteis": "dúctil",
    "dúlcida": "dúlcido",
    "dúlcidas": "dúlcido",
    "dúlcidos": "dúlcido",
    "dúplexes": "dúplex",
    "dúplices": "dúplice",
    "dúrios": "dúrio",
    "dúvidas": "dúvida",
    "dúzias": "dúzia",
    "ebadanada": "ebadanado",
    "ebadanadas": "ebadanado",
    "ebadanados": "ebadanado",
    "ebanistas": "ebanista",
    "ebanites": "ebanite",
    "ebaniza": "ebanizar",
    "ebanizada": "ebanizar",
    "ebanizadas": "ebanizar",
    "ebanizado": "ebanizar",
    "ebanizados": "ebanizar",
    "ebanizai": "ebanizar",
    "ebanizais": "ebanizar",
    "ebanizam": "ebanizar",
    "ebanizamo": "ebanizar",
    "ebanizamos": "ebanizar",
    "ebanizando": "ebanizar",
    "ebanizara": "ebanizar",
    "ebanizaram": "ebanizar",
    "ebanizaras": "ebanizar",
    "ebanizarde": "ebanizar",
    "ebanizardes": "ebanizar",
    "ebanizare": "ebanizar",
    "ebanizarei": "ebanizar",
    "ebanizareis": "ebanizar",
    "ebanizarem": "ebanizar",
    "ebanizaremos": "ebanizar",
    "ebanizares": "ebanizar",
    "ebanizaria": "ebanizar",
    "ebanizariam": "ebanizar",
    "ebanizarias": "ebanizar",
    "ebanizarmo": "ebanizar",
    "ebanizarmos": "ebanizar",
    "ebanizará": "ebanizar",
    "ebanizarás": "ebanizar",
    "ebanizarão": "ebanizar",
    "ebanizaríamos": "ebanizar",
    "ebanizaríeis": "ebanizar",
    "ebanizas": "ebanizar",
    "ebanizasse": "ebanizar",
    "ebanizassem": "ebanizar",
    "ebanizasses": "ebanizar",
    "ebanizaste": "ebanizar",
    "ebanizastes": "ebanizar",
    "ebanizava": "ebanizar",
    "ebanizavam": "ebanizar",
    "ebanizavas": "ebanizar",
    "ebanize": "ebanizar",
    "ebanizei": "ebanizar",
    "ebanizeis": "ebanizar",
    "ebanizem": "ebanizar",
    "ebanizemo": "ebanizar",
    "ebanizemos": "ebanizar",
    "ebanizes": "ebanizar",
    "ebanizo": "ebanizar",
    "ebanizou": "ebanizar",
    "ebanizá": "ebanizar",
    "ebanizámo": "ebanizar",
    "ebanizámos": "ebanizar",
    "ebanizáramo": "ebanizar",
    "ebanizáramos": "ebanizar",
    "ebanizárei": "ebanizar",
    "ebanizáreis": "ebanizar",
    "ebanizásseis": "ebanizar",
    "ebanizássemos": "ebanizar",
    "ebanizávamo": "ebanizar",
    "ebanizávamos": "ebanizar",
    "ebanizávei": "ebanizar",
    "ebanizáveis": "ebanizar",
    "ebenácea": "ebenáceo",
    "ebenáceas": "ebenáceo",
    "ebenáceos": "ebenáceo",
    "ebeonitas": "ebeonita",
    "ebionismos": "ebionismo",
    "ebionitas": "ebionita",
    "ebionites": "ebionite",
    "eborenses": "eborense",
    "eborárias": "eborária",
    "eborários": "eborário",
    "ebriativa": "ebriativo",
    "ebriativas": "ebriativo",
    "ebriativos": "ebriativo",
    "ebriedades": "ebriedade",
    "ebriezes": "ebriez",
    "ebriosa": "ebrioso",
    "ebriosas": "ebrioso",
    "ebriosos": "ebrioso",
    "ebrirridentes": "ebrirridente",
    "ebriática": "ebriático",
    "ebriáticas": "ebriático",
    "ebriáticos": "ebriático",
    "ebulidora": "ebulidor",
    "ebulidoras": "ebulidor",
    "ebulidores": "ebulidor",
    "ebulientes": "ebuliente",
    "ebulinas": "ebulina",
    "ebuliometrias": "ebuliometria",
    "ebuliométrica": "ebuliométrico",
    "ebuliométricas": "ebuliométrico",
    "ebuliométricos": "ebuliométrico",
    "ebulioscopias": "ebulioscopia",
    "ebulioscópica": "ebulioscópico",
    "ebulioscópicas": "ebulioscópico",
    "ebulioscópicos": "ebulioscópico",
    "ebulioscópios": "ebulioscópio",
    "ebulições": "ebulição",
    "eburnações": "eburnação",
    "eburnites": "eburnite",
    "ebórea": "ebóreo",
    "ebóreas": "ebóreo",
    "ebóreos": "ebóreo",
    "ebúrnea": "ebúrneo",
    "ebúrneas": "ebúrneo",
    "ebúrneos": "ebúrneo",
    "ecaudada": "ecaudado",
    "ecaudadas": "ecaudado",
    "ecaudados": "ecaudado",
    "ecceidades": "ecceidade",
    "ecdémica": "ecdémico",
    "ecdémicas": "ecdémico",
    "ecdémicos": "ecdémico",
    "ecfonemas": "ecfonema",
    "ecfráctica": "ecfráctico",
    "ecfrácticas": "ecfráctico",
    "ecfrácticos": "ecfráctico",
    "echarpes": "echarpe",
    "eciclemas": "eciclema",
    "ecidósporos": "ecidósporo",
    "eclampses": "eclampse",
    "eclampsias": "eclampsia",
    "eclectismos": "eclectismo",
    "eclers": "ecler",
    "eclesiarcas": "eclesiarca",
    "eclesiofobias": "eclesiofobia",
    "eclesiologias": "eclesiologia",
    "eclesiástica": "eclesiástico",
    "eclesiásticas": "eclesiástico",
    "eclesiásticos": "eclesiástico",
    "eclesiófoba": "eclesiófobo",
    "eclesiófobas": "eclesiófobo",
    "eclesiófobos": "eclesiófobo",
    "ecletismos": "ecletismo",
    "eclimétrica": "eclimétrico",
    "eclimétricas": "eclimétrico",
    "eclimétricos": "eclimétrico",
    "eclinometrias": "eclinometria",
    "eclinométrica": "eclinométrico",
    "eclinométricas": "eclinométrico",
    "eclinométricos": "eclinométrico",
    "eclipsa": "eclipsar",
    "eclipsada": "eclipsar",
    "eclipsadas": "eclipsar",
    "eclipsado": "eclipsar",
    "eclipsados": "eclipsar",
    "eclipsai": "eclipsar",
    "eclipsais": "eclipsar",
    "eclipsam": "eclipsar",
    "eclipsamo": "eclipsar",
    "eclipsamos": "eclipsar",
    "eclipsando": "eclipsar",
    "eclipsara": "eclipsar",
    "eclipsaram": "eclipsar",
    "eclipsaras": "eclipsar",
    "eclipsarde": "eclipsar",
    "eclipsardes": "eclipsar",
    "eclipsare": "eclipsar",
    "eclipsarei": "eclipsar",
    "eclipsareis": "eclipsar",
    "eclipsarem": "eclipsar",
    "eclipsaremos": "eclipsar",
    "eclipsares": "eclipsar",
    "eclipsaria": "eclipsar",
    "eclipsariam": "eclipsar",
    "eclipsarias": "eclipsar",
    "eclipsarmo": "eclipsar",
    "eclipsarmos": "eclipsar",
    "eclipsará": "eclipsar",
    "eclipsarás": "eclipsar",
    "eclipsarão": "eclipsar",
    "eclipsaríamos": "eclipsar",
    "eclipsaríeis": "eclipsar",
    "eclipsas": "eclipsar",
    "eclipsasse": "eclipsar",
    "eclipsassem": "eclipsar",
    "eclipsasses": "eclipsar",
    "eclipsaste": "eclipsar",
    "eclipsastes": "eclipsar",
    "eclipsava": "eclipsar",
    "eclipsavam": "eclipsar",
    "eclipsavas": "eclipsar",
    "eclipse": "eclipsar",
    "eclipsei": "eclipsar",
    "eclipseis": "eclipsar",
    "eclipsem": "eclipsar",
    "eclipsemo": "eclipsar",
    "eclipsemos": "eclipsar",
    "eclipses": "eclipse",
    "eclipso": "eclipsar",
    "eclipsou": "eclipsar",
    "eclipsá": "eclipsar",
    "eclipsámo": "eclipsar",
    "eclipsámos": "eclipsar",
    "eclipsáramo": "eclipsar",
    "eclipsáramos": "eclipsar",
    "eclipsárei": "eclipsar",
    "eclipsáreis": "eclipsar",
    "eclipsásseis": "eclipsar",
    "eclipsássemos": "eclipsar",
    "eclipsávamo": "eclipsar",
    "eclipsávamos": "eclipsar",
    "eclipsávei": "eclipsar",
    "eclipsáveis": "eclipsar",
    "eclode": "eclodir",
    "eclodem": "eclodir",
    "eclodes": "eclodir",
    "eclodi": "eclodir",
    "eclodia": "eclodir",
    "eclodiam": "eclodir",
    "eclodias": "eclodir",
    "eclodida": "eclodir",
    "eclodidas": "eclodir",
    "eclodido": "eclodir",
    "eclodidos": "eclodir",
    "eclodimo": "eclodir",
    "eclodimos": "eclodir",
    "eclodindo": "eclodir",
    "eclodira": "eclodir",
    "eclodiram": "eclodir",
    "eclodiras": "eclodir",
    "eclodirdes": "eclodir",
    "eclodirei": "eclodir",
    "eclodireis": "eclodir",
    "eclodirem": "eclodir",
    "eclodiremos": "eclodir",
    "eclodires": "eclodir",
    "eclodiria": "eclodir",
    "eclodiriam": "eclodir",
    "eclodirias": "eclodir",
    "eclodirmo": "eclodir",
    "eclodirmos": "eclodir",
    "eclodirá": "eclodir",
    "eclodirás": "eclodir",
    "eclodirão": "eclodir",
    "eclodiríamos": "eclodir",
    "eclodiríeis": "eclodir",
    "eclodis": "eclodir",
    "eclodisse": "eclodir",
    "eclodissem": "eclodir",
    "eclodisses": "eclodir",
    "eclodiste": "eclodir",
    "eclodistes": "eclodir",
    "eclodiu": "eclodir",
    "eclodíamo": "eclodir",
    "eclodíamos": "eclodir",
    "eclodíeis": "eclodir",
    "eclodíramo": "eclodir",
    "eclodíramos": "eclodir",
    "eclodíreis": "eclodir",
    "eclodísseis": "eclodir",
    "eclodíssemos": "eclodir",
    "eclogais": "eclogal",
    "eclogitos": "eclogito",
    "ecloguistas": "ecloguista",
    "eclosões": "eclosão",
    "ecluda": "eclodir",
    "ecludais": "eclodir",
    "ecludam": "eclodir",
    "ecludamo": "eclodir",
    "ecludamos": "eclodir",
    "ecludas": "eclodir",
    "ecludo": "eclodir",
    "eclusas": "eclusa",
    "eclâmptica": "eclâmptico",
    "eclâmpticas": "eclâmptico",
    "eclâmpticos": "eclâmptico",
    "ecléctica": "ecléctico",
    "eclécticas": "ecléctico",
    "eclécticos": "ecléctico",
    "eclésias": "eclésia",
    "eclímetros": "eclímetro",
    "eclíptica": "eclíptico",
    "eclípticas": "eclíptico",
    "eclípticos": "eclíptico",
    "ecmnésias": "ecmnésia",
    "ecmnésica": "ecmnésico",
    "ecmnésicas": "ecmnésico",
    "ecmnésicos": "ecmnésico",
    "ecmofobias": "ecmofobia",
    "ecmofóbica": "ecmofóbico",
    "ecmofóbicas": "ecmofóbico",
    "ecmofóbicos": "ecmofóbico",
    "ecmófoba": "ecmófobo",
    "ecmófobas": "ecmófobo",
    "ecmófobos": "ecmófobo",
    "ecoa": "ecoar",
    "ecoada": "ecoar",
    "ecoadas": "ecoar",
    "ecoado": "ecoar",
    "ecoadora": "ecoador",
    "ecoadoras": "ecoador",
    "ecoadores": "ecoador",
    "ecoados": "ecoar",
    "ecoai": "ecoar",
    "ecoais": "ecoar",
    "ecoam": "ecoar",
    "ecoamo": "ecoar",
    "ecoamos": "ecoar",
    "ecoando": "ecoar",
    "ecoara": "ecoar",
    "ecoaram": "ecoar",
    "ecoaras": "ecoar",
    "ecoardes": "ecoar",
    "ecoarei": "ecoar",
    "ecoareis": "ecoar",
    "ecoarem": "ecoar",
    "ecoaremos": "ecoar",
    "ecoares": "ecoar",
    "ecoaria": "ecoar",
    "ecoariam": "ecoar",
    "ecoarias": "ecoar",
    "ecoarmo": "ecoar",
    "ecoarmos": "ecoar",
    "ecoará": "ecoar",
    "ecoarás": "ecoar",
    "ecoarão": "ecoar",
    "ecoaríamos": "ecoar",
    "ecoaríeis": "ecoar",
    "ecoas": "ecoar",
    "ecoasse": "ecoar",
    "ecoassem": "ecoar",
    "ecoasses": "ecoar",
    "ecoaste": "ecoar",
    "ecoastes": "ecoar",
    "ecoava": "ecoar",
    "ecoavam": "ecoar",
    "ecoavas": "ecoar",
    "ecocardiografias": "ecocardiografia",
    "ecocardiogramas": "ecocardiograma",
    "ecoe": "ecoar",
    "ecoei": "ecoar",
    "ecoeis": "ecoar",
    "ecoem": "ecoar",
    "ecoemo": "ecoar",
    "ecoemos": "ecoar",
    "ecoes": "ecoar",
    "ecografias": "ecografia",
    "ecográfica": "ecográfico",
    "ecográficas": "ecográfico",
    "ecográficos": "ecográfico",
    "ecolalias": "ecolalia",
    "ecologias": "ecologia",
    "ecologistas": "ecologista",
    "ecolálica": "ecolálico",
    "ecolálicas": "ecolálico",
    "ecolálicos": "ecolálico",
    "ecológica": "ecológico",
    "ecológicas": "ecológico",
    "ecológicos": "ecológico",
    "ecometrias": "ecometria",
    "ecomimias": "ecomimia",
    "ecométrica": "ecométrico",
    "ecométricas": "ecométrico",
    "ecométricos": "ecométrico",
    "ecomímica": "ecomímico",
    "ecomímicas": "ecomímico",
    "ecomímicos": "ecomímico",
    "economatos": "economato",
    "econometrias": "econometria",
    "economias": "economia",
    "economicistas": "economicista",
    "economistas": "economista",
    "economiza": "economizar",
    "economizada": "economizar",
    "economizadas": "economizar",
    "economizado": "economizar",
    "economizadora": "economizador",
    "economizadoras": "economizador",
    "economizadores": "economizador",
    "economizados": "economizar",
    "economizai": "economizar",
    "economizais": "economizar",
    "economizam": "economizar",
    "economizamo": "economizar",
    "economizamos": "economizar",
    "economizando": "economizar",
    "economizara": "economizar",
    "economizaram": "economizar",
    "economizaras": "economizar",
    "economizarde": "economizar",
    "economizardes": "economizar",
    "economizare": "economizar",
    "economizarei": "economizar",
    "economizareis": "economizar",
    "economizarem": "economizar",
    "economizaremos": "economizar",
    "economizares": "economizar",
    "economizaria": "economizar",
    "economizariam": "economizar",
    "economizarias": "economizar",
    "economizarmo": "economizar",
    "economizarmos": "economizar",
    "economizará": "economizar",
    "economizarás": "economizar",
    "economizarão": "economizar",
    "economizaríamos": "economizar",
    "economizaríeis": "economizar",
    "economizas": "economizar",
    "economizasse": "economizar",
    "economizassem": "economizar",
    "economizasses": "economizar",
    "economizaste": "economizar",
    "economizastes": "economizar",
    "economizava": "economizar",
    "economizavam": "economizar",
    "economizavas": "economizar",
    "economize": "economizar",
    "economizei": "economizar",
    "economizeis": "economizar",
    "economizem": "economizar",
    "economizemo": "economizar",
    "economizemos": "economizar",
    "economizes": "economizar",
    "economizo": "economizar",
    "economizou": "economizar",
    "economizá": "economizar",
    "economizámo": "economizar",
    "economizámos": "economizar",
    "economizáramo": "economizar",
    "economizáramos": "economizar",
    "economizárei": "economizar",
    "economizáreis": "economizar",
    "economizásseis": "economizar",
    "economizássemos": "economizar",
    "economizávamo": "economizar",
    "economizávamos": "economizar",
    "economizávei": "economizar",
    "economizáveis": "economizar",
    "econométrica": "econométrico",
    "econométricas": "econométrico",
    "econométricos": "econométrico",
    "económica": "económico",
    "económicas": "económico",
    "económicos": "económico",
    "ecoo": "ecoar",
    "ecoou": "ecoar",
    "ecopontos": "ecoponto",
    "ecopraxias": "ecopraxia",
    "ecopráctica": "ecopráctico",
    "ecoprácticas": "ecopráctico",
    "ecoprácticos": "ecopráctico",
    "ecos": "eco",
    "ecossistemas": "ecossistema",
    "ecoámo": "ecoar",
    "ecoámos": "ecoar",
    "ecoáramo": "ecoar",
    "ecoáramos": "ecoar",
    "ecoáreis": "ecoar",
    "ecoásseis": "ecoar",
    "ecoássemos": "ecoar",
    "ecoávamo": "ecoar",
    "ecoávamos": "ecoar",
    "ecoáveis": "ecoar",
    "ecplesias": "ecplesia",
    "ecpléxica": "ecpléxico",
    "ecpléxicas": "ecpléxico",
    "ecpléxicos": "ecpléxico",
    "ecrãs": "ecrã",
    "ectasias": "ectasia",
    "ectilótica": "ectilótico",
    "ectilóticas": "ectilótico",
    "ectilóticos": "ectilótico",
    "ectinitos": "ectinito",
    "ectipografias": "ectipografia",
    "ectipográfica": "ectipográfico",
    "ectipográficas": "ectipográfico",
    "ectipográficos": "ectipográfico",
    "ectipos": "ectipo",
    "ectlipses": "ectlipse",
    "ectoblastos": "ectoblasto",
    "ectodactilias": "ectodactilia",
    "ectodermes": "ectoderme",
    "ectoparasitas": "ectoparasita",
    "ectoparasitismos": "ectoparasitismo",
    "ectoparasitos": "ectoparasito",
    "ectopias": "ectopia",
    "ectoplasmas": "ectoplasma",
    "ectozoários": "ectozoário",
    "ectrópios": "ectrópio",
    "ectrótica": "ectrótico",
    "ectróticas": "ectrótico",
    "ectróticos": "ectrótico",
    "ectásica": "ectásico",
    "ectásicas": "ectásico",
    "ectásicos": "ectásico",
    "ectática": "ectático",
    "ectáticas": "ectático",
    "ectáticos": "ectático",
    "ectópica": "ectópico",
    "ectópicas": "ectópico",
    "ectópicos": "ectópico",
    "ecumenicidades": "ecumenicidade",
    "ecumenismos": "ecumenismo",
    "ecumenistas": "ecumenista",
    "ecumenística": "ecumenístico",
    "ecumenísticas": "ecumenístico",
    "ecumenísticos": "ecumenístico",
    "ecuménica": "ecuménico",
    "ecuménicas": "ecuménico",
    "ecuménicos": "ecuménico",
    "ecus": "ecu",
    "eczemas": "eczema",
    "eczematiformes": "eczematiforme",
    "eczematosa": "eczematoso",
    "eczematosas": "eczematoso",
    "eczematosos": "eczematoso",
    "ecóica": "ecóico",
    "ecóicas": "ecóico",
    "ecóicos": "ecóico",
    "ecóloga": "ecólogo",
    "ecólogas": "ecólogo",
    "ecólogos": "ecólogo",
    "ecómetros": "ecómetro",
    "ecónomos": "ecónomo",
    "ecúleos": "ecúleo",
    "edaces": "edace",
    "edacidades": "edacidade",
    "edafologias": "edafologia",
    "edafológica": "edafológico",
    "edafológicas": "edafológico",
    "edafológicos": "edafológico",
    "edafóloga": "edafólogo",
    "edafólogas": "edafólogo",
    "edafólogos": "edafólogo",
    "edazes": "edaz",
    "edemacia": "edemaciar",
    "edemaciada": "edemaciar",
    "edemaciadas": "edemaciar",
    "edemaciado": "edemaciar",
    "edemaciados": "edemaciar",
    "edemaciai": "edemaciar",
    "edemaciais": "edemaciar",
    "edemaciam": "edemaciar",
    "edemaciamo": "edemaciar",
    "edemaciamos": "edemaciar",
    "edemaciando": "edemaciar",
    "edemaciara": "edemaciar",
    "edemaciaram": "edemaciar",
    "edemaciaras": "edemaciar",
    "edemaciarde": "edemaciar",
    "edemaciardes": "edemaciar",
    "edemaciare": "edemaciar",
    "edemaciarei": "edemaciar",
    "edemaciareis": "edemaciar",
    "edemaciarem": "edemaciar",
    "edemaciaremos": "edemaciar",
    "edemaciares": "edemaciar",
    "edemaciaria": "edemaciar",
    "edemaciariam": "edemaciar",
    "edemaciarias": "edemaciar",
    "edemaciarmo": "edemaciar",
    "edemaciarmos": "edemaciar",
    "edemaciará": "edemaciar",
    "edemaciarás": "edemaciar",
    "edemaciarão": "edemaciar",
    "edemaciaríamos": "edemaciar",
    "edemaciaríeis": "edemaciar",
    "edemacias": "edemaciar",
    "edemaciasse": "edemaciar",
    "edemaciassem": "edemaciar",
    "edemaciasses": "edemaciar",
    "edemaciaste": "edemaciar",
    "edemaciastes": "edemaciar",
    "edemaciava": "edemaciar",
    "edemaciavam": "edemaciar",
    "edemaciavas": "edemaciar",
    "edemacie": "edemaciar",
    "edemaciei": "edemaciar",
    "edemacieis": "edemaciar",
    "edemaciem": "edemaciar",
    "edemaciemo": "edemaciar",
    "edemaciemos": "edemaciar",
    "edemacies": "edemaciar",
    "edemacio": "edemaciar",
    "edemaciou": "edemaciar",
    "edemaciá": "edemaciar",
    "edemaciámo": "edemaciar",
    "edemaciámos": "edemaciar",
    "edemaciáramo": "edemaciar",
    "edemaciáramos": "edemaciar",
    "edemaciárei": "edemaciar",
    "edemaciáreis": "edemaciar",
    "edemaciásseis": "edemaciar",
    "edemaciássemos": "edemaciar",
    "edemaciávamo": "edemaciar",
    "edemaciávamos": "edemaciar",
    "edemaciávei": "edemaciar",
    "edemaciáveis": "edemaciar",
    "edemas": "edema",
    "edematosa": "edematoso",
    "edematosas": "edematoso",
    "edematosos": "edematoso",
    "edemática": "edemático",
    "edemáticas": "edemático",
    "edemáticos": "edemático",
    "edenismos": "edenismo",
    "edenites": "edenite",
    "edenítica": "edenítico",
    "edeníticas": "edenítico",
    "edeníticos": "edenítico",
    "edeoblenorragias": "edeoblenorragia",
    "edeoblenorreias": "edeoblenorreia",
    "edeoblenorrágica": "edeoblenorrágico",
    "edeoblenorrágicas": "edeoblenorrágico",
    "edeoblenorrágicos": "edeoblenorrágico",
    "edeografias": "edeografia",
    "edeográfica": "edeográfico",
    "edeográficas": "edeográfico",
    "edeográficos": "edeográfico",
    "edeologias": "edeologia",
    "edeológica": "edeológico",
    "edeológicas": "edeológico",
    "edeológicos": "edeológico",
    "edeomanias": "edeomania",
    "edeomaníaca": "edeomaníaco",
    "edeomaníacas": "edeomaníaco",
    "edeomaníacos": "edeomaníaco",
    "edeoscopias": "edeoscopia",
    "edeoscópica": "edeoscópico",
    "edeoscópicas": "edeoscópico",
    "edeoscópicos": "edeoscópico",
    "edeoscópios": "edeoscópio",
    "edeotomias": "edeotomia",
    "edeotómica": "edeotómico",
    "edeotómicas": "edeotómico",
    "edeotómicos": "edeotómico",
    "edeóloga": "edeólogo",
    "edeólogas": "edeólogo",
    "edeólogos": "edeólogo",
    "edictais": "edictal",
    "edifica": "edificar",
    "edificabilidades": "edificabilidade",
    "edificada": "edificar",
    "edificadas": "edificar",
    "edificado": "edificar",
    "edificadora": "edificador",
    "edificadoras": "edificador",
    "edificadores": "edificador",
    "edificados": "edificar",
    "edificai": "edificar",
    "edificais": "edificar",
    "edificam": "edificar",
    "edificamo": "edificar",
    "edificamos": "edificar",
    "edificando": "edificar",
    "edificantes": "edificante",
    "edificara": "edificar",
    "edificaram": "edificar",
    "edificaras": "edificar",
    "edificarde": "edificar",
    "edificardes": "edificar",
    "edificare": "edificar",
    "edificarei": "edificar",
    "edificareis": "edificar",
    "edificarem": "edificar",
    "edificaremos": "edificar",
    "edificares": "edificar",
    "edificaria": "edificar",
    "edificariam": "edificar",
    "edificarias": "edificar",
    "edificarmo": "edificar",
    "edificarmos": "edificar",
    "edificará": "edificar",
    "edificarás": "edificar",
    "edificarão": "edificar",
    "edificaríamos": "edificar",
    "edificaríeis": "edificar",
    "edificas": "edificar",
    "edificasse": "edificar",
    "edificassem": "edificar",
    "edificasses": "edificar",
    "edificaste": "edificar",
    "edificastes": "edificar",
    "edificativa": "edificativo",
    "edificativas": "edificativo",
    "edificativos": "edificativo",
    "edificava": "edificar",
    "edificavam": "edificar",
    "edificavas": "edificar",
    "edificações": "edificação",
    "edifico": "edificar",
    "edificou": "edificar",
    "edificá": "edificar",
    "edificámo": "edificar",
    "edificámos": "edificar",
    "edificáramo": "edificar",
    "edificáramos": "edificar",
    "edificárei": "edificar",
    "edificáreis": "edificar",
    "edificásseis": "edificar",
    "edificássemos": "edificar",
    "edificávamo": "edificar",
    "edificávamos": "edificar",
    "edificávei": "edificar",
    "edificáveis": "edificar",
    "edifique": "edificar",
    "edifiquei": "edificar",
    "edifiqueis": "edificar",
    "edifiquem": "edificar",
    "edifiquemo": "edificar",
    "edifiquemos": "edificar",
    "edifiques": "edificar",
    "edifícios": "edifício",
    "edilidades": "edilidade",
    "edipiana": "edipiano",
    "edipianas": "edipiano",
    "edipianos": "edipiano",
    "edis": "edil",
    "edita": "editar",
    "editada": "editar",
    "editadas": "editar",
    "editado": "editar",
    "editados": "editar",
    "editai": "editar",
    "editais": "editar",
    "editam": "editar",
    "editamo": "editar",
    "editamos": "editar",
    "editando": "editar",
    "editara": "editar",
    "editaram": "editar",
    "editaras": "editar",
    "editarde": "editar",
    "editardes": "editar",
    "editare": "editar",
    "editarei": "editar",
    "editareis": "editar",
    "editarem": "editar",
    "editaremos": "editar",
    "editares": "editar",
    "editaria": "editar",
    "editariam": "editar",
    "editarias": "editar",
    "editarmo": "editar",
    "editarmos": "editar",
    "editará": "editar",
    "editarás": "editar",
    "editarão": "editar",
    "editaríamos": "editar",
    "editaríeis": "editar",
    "editas": "editar",
    "editasse": "editar",
    "editassem": "editar",
    "editasses": "editar",
    "editaste": "editar",
    "editastes": "editar",
    "editava": "editar",
    "editavam": "editar",
    "editavas": "editar",
    "editações": "editação",
    "edite": "editar",
    "editei": "editar",
    "editeis": "editar",
    "editem": "editar",
    "editemo": "editar",
    "editemos": "editar",
    "edites": "editar",
    "edito": "editar",
    "editora": "editorar",
    "editorada": "editorar",
    "editoradas": "editorar",
    "editorado": "editorar",
    "editorados": "editorar",
    "editorai": "editorar",
    "editorais": "editorar",
    "editoram": "editorar",
    "editoramo": "editorar",
    "editoramos": "editorar",
    "editorando": "editorar",
    "editorara": "editorar",
    "editoraram": "editorar",
    "editoraras": "editorar",
    "editorarde": "editorar",
    "editorardes": "editorar",
    "editorare": "editorar",
    "editorarei": "editorar",
    "editorareis": "editorar",
    "editorarem": "editorar",
    "editoraremos": "editorar",
    "editorares": "editorar",
    "editoraria": "editorar",
    "editorariam": "editorar",
    "editorarias": "editorar",
    "editorarmo": "editorar",
    "editorarmos": "editorar",
    "editorará": "editorar",
    "editorarás": "editorar",
    "editorarão": "editorar",
    "editoraríamos": "editorar",
    "editoraríeis": "editorar",
    "editoras": "editorar",
    "editorasse": "editorar",
    "editorassem": "editorar",
    "editorasses": "editorar",
    "editoraste": "editorar",
    "editorastes": "editorar",
    "editorava": "editorar",
    "editoravam": "editorar",
    "editoravas": "editorar",
    "editorações": "editoração",
    "editore": "editorar",
    "editorei": "editorar",
    "editoreis": "editorar",
    "editorem": "editorar",
    "editoremo": "editorar",
    "editoremos": "editorar",
    "editores": "editorar",
    "editoriais": "editorial",
    "editorialistas": "editorialista",
    "editoro": "editorar",
    "editorou": "editorar",
    "editorá": "editorar",
    "editorámo": "editorar",
    "editorámos": "editorar",
    "editoráramo": "editorar",
    "editoráramos": "editorar",
    "editorárei": "editorar",
    "editoráreis": "editorar",
    "editorásseis": "editorar",
    "editorássemos": "editorar",
    "editorávamo": "editorar",
    "editorávamos": "editorar",
    "editorávei": "editorar",
    "editoráveis": "editorar",
    "editou": "editar",
    "editá": "editar",
    "editámo": "editar",
    "editámos": "editar",
    "editáramo": "editar",
    "editáramos": "editar",
    "editárei": "editar",
    "editáreis": "editar",
    "editásseis": "editar",
    "editássemos": "editar",
    "editávamo": "editar",
    "editávamos": "editar",
    "editávei": "editar",
    "editáveis": "editável",
    "edições": "edição",
    "edredões": "edredão",
    "edrioasteróides": "edrioasteróide",
    "educa": "educar",
    "educabilidades": "educabilidade",
    "educacionais": "educacional",
    "educacionistas": "educacionista",
    "educada": "educar",
    "educadas": "educar",
    "educado": "educar",
    "educadora": "educador",
    "educadoras": "educador",
    "educadores": "educador",
    "educados": "educar",
    "educadíssima": "educado",
    "educadíssimas": "educado",
    "educadíssimo": "educado",
    "educadíssimos": "educado",
    "educai": "educar",
    "educais": "educar",
    "educam": "educar",
    "educamo": "educar",
    "educamos": "educar",
    "educanda": "educando",
    "educandas": "educando",
    "educando": "educar",
    "educandos": "educando",
    "educara": "educar",
    "educaram": "educar",
    "educaras": "educar",
    "educarde": "educar",
    "educardes": "educar",
    "educare": "educar",
    "educarei": "educar",
    "educareis": "educar",
    "educarem": "educar",
    "educaremos": "educar",
    "educares": "educar",
    "educaria": "educar",
    "educariam": "educar",
    "educarias": "educar",
    "educarmo": "educar",
    "educarmos": "educar",
    "educará": "educar",
    "educarás": "educar",
    "educarão": "educar",
    "educaríamos": "educar",
    "educaríeis": "educar",
    "educas": "educar",
    "educasse": "educar",
    "educassem": "educar",
    "educasses": "educar",
    "educaste": "educar",
    "educastes": "educar",
    "educativa": "educativo",
    "educativas": "educativo",
    "educativos": "educativo",
    "educava": "educar",
    "educavam": "educar",
    "educavas": "educar",
    "educações": "educação",
    "educo": "educar",
    "educou": "educar",
    "educá": "educar",
    "educámo": "educar",
    "educámos": "educar",
    "educáramo": "educar",
    "educáramos": "educar",
    "educárei": "educar",
    "educáreis": "educar",
    "educásseis": "educar",
    "educássemos": "educar",
    "educávamo": "educar",
    "educávamos": "educar",
    "educávei": "educar",
    "educáveis": "educável",
    "edulcora": "edulcorar",
    "edulcorada": "edulcorar",
    "edulcoradas": "edulcorar",
    "edulcorado": "edulcorar",
    "edulcorados": "edulcorar",
    "edulcorai": "edulcorar",
    "edulcorais": "edulcorar",
    "edulcoram": "edulcorar",
    "edulcoramo": "edulcorar",
    "edulcoramos": "edulcorar",
    "edulcorando": "edulcorar",
    "edulcorantes": "edulcorante",
    "edulcorara": "edulcorar",
    "edulcoraram": "edulcorar",
    "edulcoraras": "edulcorar",
    "edulcorarde": "edulcorar",
    "edulcorardes": "edulcorar",
    "edulcorare": "edulcorar",
    "edulcorarei": "edulcorar",
    "edulcorareis": "edulcorar",
    "edulcorarem": "edulcorar",
    "edulcoraremos": "edulcorar",
    "edulcorares": "edulcorar",
    "edulcoraria": "edulcorar",
    "edulcorariam": "edulcorar",
    "edulcorarias": "edulcorar",
    "edulcorarmo": "edulcorar",
    "edulcorarmos": "edulcorar",
    "edulcorará": "edulcorar",
    "edulcorarás": "edulcorar",
    "edulcorarão": "edulcorar",
    "edulcoraríamos": "edulcorar",
    "edulcoraríeis": "edulcorar",
    "edulcoras": "edulcorar",
    "edulcorasse": "edulcorar",
    "edulcorassem": "edulcorar",
    "edulcorasses": "edulcorar",
    "edulcoraste": "edulcorar",
    "edulcorastes": "edulcorar",
    "edulcorava": "edulcorar",
    "edulcoravam": "edulcorar",
    "edulcoravas": "edulcorar",
    "edulcorações": "edulcoração",
    "edulcore": "edulcorar",
    "edulcorei": "edulcorar",
    "edulcoreis": "edulcorar",
    "edulcorem": "edulcorar",
    "edulcoremo": "edulcorar",
    "edulcoremos": "edulcorar",
    "edulcores": "edulcorar",
    "edulcoro": "edulcorar",
    "edulcorou": "edulcorar",
    "edulcorá": "edulcorar",
    "edulcorámo": "edulcorar",
    "edulcorámos": "edulcorar",
    "edulcoráramo": "edulcorar",
    "edulcoráramos": "edulcorar",
    "edulcorárei": "edulcorar",
    "edulcoráreis": "edulcorar",
    "edulcorásseis": "edulcorar",
    "edulcorássemos": "edulcorar",
    "edulcorávamo": "edulcorar",
    "edulcorávamos": "edulcorar",
    "edulcorávei": "edulcorar",
    "edulcoráveis": "edulcorar",
    "edules": "edule",
    "eduque": "educar",
    "eduquei": "educar",
    "eduqueis": "educar",
    "eduquem": "educar",
    "eduquemo": "educar",
    "eduquemos": "educar",
    "eduques": "educar",
    "eduz": "eduzir",
    "eduza": "eduzir",
    "eduzais": "eduzir",
    "eduzam": "eduzir",
    "eduzamo": "eduzir",
    "eduzamos": "eduzir",
    "eduzas": "eduzir",
    "eduze": "eduzir",
    "eduzem": "eduzir",
    "eduzes": "eduzir",
    "eduzi": "eduzir",
    "eduzia": "eduzir",
    "eduziam": "eduzir",
    "eduzias": "eduzir",
    "eduzida": "eduzir",
    "eduzidas": "eduzir",
    "eduzido": "eduzir",
    "eduzidos": "eduzir",
    "eduzimo": "eduzir",
    "eduzimos": "eduzir",
    "eduzindo": "eduzir",
    "eduzira": "eduzir",
    "eduziram": "eduzir",
    "eduziras": "eduzir",
    "eduzirde": "eduzir",
    "eduzirdes": "eduzir",
    "eduzire": "eduzir",
    "eduzirei": "eduzir",
    "eduzireis": "eduzir",
    "eduzirem": "eduzir",
    "eduziremos": "eduzir",
    "eduzires": "eduzir",
    "eduziria": "eduzir",
    "eduziriam": "eduzir",
    "eduzirias": "eduzir",
    "eduzirmo": "eduzir",
    "eduzirmos": "eduzir",
    "eduzirá": "eduzir",
    "eduzirás": "eduzir",
    "eduzirão": "eduzir",
    "eduziríamos": "eduzir",
    "eduziríeis": "eduzir",
    "eduzis": "eduzir",
    "eduzisse": "eduzir",
    "eduzissem": "eduzir",
    "eduzisses": "eduzir",
    "eduziste": "eduzir",
    "eduzistes": "eduzir",
    "eduziu": "eduzir",
    "eduzo": "eduzir",
    "eduzíamo": "eduzir",
    "eduzíamos": "eduzir",
    "eduzíei": "eduzir",
    "eduzíeis": "eduzir",
    "eduzíramo": "eduzir",
    "eduzíramos": "eduzir",
    "eduzírei": "eduzir",
    "eduzíreis": "eduzir",
    "eduzísseis": "eduzir",
    "eduzíssemos": "eduzir",
    "eduções": "edução",
    "edáfica": "edáfico",
    "edáficas": "edáfico",
    "edáficos": "edáfico",
    "edénica": "edénico",
    "edénicas": "edénico",
    "edénicos": "edénico",
    "edículas": "edícula",
    "edílica": "edílico",
    "edílicas": "edílico",
    "edílicos": "edílico",
    "edíveis": "edível",
    "ee": "e",
    "efabulações": "efabulação",
    "efebismos": "efebismo",
    "efebos": "efebo",
    "efectiva": "efectivo",
    "efectivada": "efectivar",
    "efectivadas": "efectivar",
    "efectivado": "efectivar",
    "efectivados": "efectivar",
    "efectivai": "efectivar",
    "efectivais": "efectivar",
    "efectivam": "efectivar",
    "efectivamo": "efectivar",
    "efectivamos": "efectivar",
    "efectivando": "efectivar",
    "efectivara": "efectivar",
    "efectivaram": "efectivar",
    "efectivaras": "efectivar",
    "efectivarde": "efectivar",
    "efectivardes": "efectivar",
    "efectivare": "efectivar",
    "efectivarei": "efectivar",
    "efectivareis": "efectivar",
    "efectivarem": "efectivar",
    "efectivaremos": "efectivar",
    "efectivares": "efectivar",
    "efectivaria": "efectivar",
    "efectivariam": "efectivar",
    "efectivarias": "efectivar",
    "efectivarmo": "efectivar",
    "efectivarmos": "efectivar",
    "efectivará": "efectivar",
    "efectivarás": "efectivar",
    "efectivarão": "efectivar",
    "efectivaríamos": "efectivar",
    "efectivaríeis": "efectivar",
    "efectivas": "efectivo",
    "efectivasse": "efectivar",
    "efectivassem": "efectivar",
    "efectivasses": "efectivar",
    "efectivaste": "efectivar",
    "efectivastes": "efectivar",
    "efectivava": "efectivar",
    "efectivavam": "efectivar",
    "efectivavas": "efectivar",
    "efectivações": "efectivação",
    "efective": "efectivar",
    "efectivei": "efectivar",
    "efectiveis": "efectivar",
    "efectivem": "efectivar",
    "efectivemo": "efectivar",
    "efectivemos": "efectivar",
    "efectives": "efectivar",
    "efectividades": "efectividade",
    "efectivo": "efectivar",
    "efectivos": "efectivo",
    "efectivou": "efectivar",
    "efectivá": "efectivar",
    "efectivámo": "efectivar",
    "efectivámos": "efectivar",
    "efectiváramo": "efectivar",
    "efectiváramos": "efectivar",
    "efectivárei": "efectivar",
    "efectiváreis": "efectivar",
    "efectivásseis": "efectivar",
    "efectivássemos": "efectivar",
    "efectivávamo": "efectivar",
    "efectivávamos": "efectivar",
    "efectivávei": "efectivar",
    "efectiváveis": "efectivar",
    "efectua": "efectuar",
    "efectuada": "efectuar",
    "efectuadas": "efectuar",
    "efectuado": "efectuar",
    "efectuadora": "efectuador",
    "efectuadoras": "efectuador",
    "efectuadores": "efectuador",
    "efectuados": "efectuar",
    "efectuai": "efectuar",
    "efectuais": "efectuar",
    "efectuam": "efectuar",
    "efectuamo": "efectuar",
    "efectuamos": "efectuar",
    "efectuando": "efectuar",
    "efectuara": "efectuar",
    "efectuaram": "efectuar",
    "efectuaras": "efectuar",
    "efectuarde": "efectuar",
    "efectuardes": "efectuar",
    "efectuare": "efectuar",
    "efectuarei": "efectuar",
    "efectuareis": "efectuar",
    "efectuarem": "efectuar",
    "efectuaremos": "efectuar",
    "efectuares": "efectuar",
    "efectuaria": "efectuar",
    "efectuariam": "efectuar",
    "efectuarias": "efectuar",
    "efectuarmo": "efectuar",
    "efectuarmos": "efectuar",
    "efectuará": "efectuar",
    "efectuarás": "efectuar",
    "efectuarão": "efectuar",
    "efectuaríamos": "efectuar",
    "efectuaríeis": "efectuar",
    "efectuas": "efectuar",
    "efectuasse": "efectuar",
    "efectuassem": "efectuar",
    "efectuasses": "efectuar",
    "efectuaste": "efectuar",
    "efectuastes": "efectuar",
    "efectuava": "efectuar",
    "efectuavam": "efectuar",
    "efectuavas": "efectuar",
    "efectuações": "efectuação",
    "efectue": "efectuar",
    "efectuei": "efectuar",
    "efectueis": "efectuar",
    "efectuem": "efectuar",
    "efectuemo": "efectuar",
    "efectuemos": "efectuar",
    "efectues": "efectuar",
    "efectuo": "efectuar",
    "efectuou": "efectuar",
    "efectuá": "efectuar",
    "efectuámo": "efectuar",
    "efectuámos": "efectuar",
    "efectuáramo": "efectuar",
    "efectuáramos": "efectuar",
    "efectuárei": "efectuar",
    "efectuáreis": "efectuar",
    "efectuásseis": "efectuar",
    "efectuássemos": "efectuar",
    "efectuávamo": "efectuar",
    "efectuávamos": "efectuar",
    "efectuávei": "efectuar",
    "efectuáveis": "efectuável",
    "efectíveis": "efectível",
    "efedrinas": "efedrina",
    "efedráceas": "efedrácea",
    "efeitarrões": "efeitarrão",
    "efeitos": "efeito",
    "efeitua": "efeituar",
    "efeituada": "efeituar",
    "efeituadas": "efeituar",
    "efeituado": "efeituar",
    "efeituadora": "efeituador",
    "efeituadoras": "efeituador",
    "efeituadores": "efeituador",
    "efeituados": "efeituar",
    "efeituai": "efeituar",
    "efeituais": "efeituar",
    "efeituam": "efeituar",
    "efeituamo": "efeituar",
    "efeituamos": "efeituar",
    "efeituando": "efeituar",
    "efeituara": "efeituar",
    "efeituaram": "efeituar",
    "efeituaras": "efeituar",
    "efeituarde": "efeituar",
    "efeituardes": "efeituar",
    "efeituare": "efeituar",
    "efeituarei": "efeituar",
    "efeituareis": "efeituar",
    "efeituarem": "efeituar",
    "efeituaremos": "efeituar",
    "efeituares": "efeituar",
    "efeituaria": "efeituar",
    "efeituariam": "efeituar",
    "efeituarias": "efeituar",
    "efeituarmo": "efeituar",
    "efeituarmos": "efeituar",
    "efeituará": "efeituar",
    "efeituarás": "efeituar",
    "efeituarão": "efeituar",
    "efeituaríamos": "efeituar",
    "efeituaríeis": "efeituar",
    "efeituas": "efeituar",
    "efeituasse": "efeituar",
    "efeituassem": "efeituar",
    "efeituasses": "efeituar",
    "efeituaste": "efeituar",
    "efeituastes": "efeituar",
    "efeituava": "efeituar",
    "efeituavam": "efeituar",
    "efeituavas": "efeituar",
    "efeitue": "efeituar",
    "efeituei": "efeituar",
    "efeitueis": "efeituar",
    "efeituem": "efeituar",
    "efeituemo": "efeituar",
    "efeituemos": "efeituar",
    "efeitues": "efeituar",
    "efeituo": "efeituar",
    "efeituou": "efeituar",
    "efeituá": "efeituar",
    "efeituámo": "efeituar",
    "efeituámos": "efeituar",
    "efeituáramo": "efeituar",
    "efeituáramos": "efeituar",
    "efeituárei": "efeituar",
    "efeituáreis": "efeituar",
    "efeituásseis": "efeituar",
    "efeituássemos": "efeituar",
    "efeituávamo": "efeituar",
    "efeituávamos": "efeituar",
    "efeituávei": "efeituar",
    "efeituáveis": "efeituar",
    "efemeridades": "efemeridade",
    "efemeriza": "efemerizar",
    "efemerizada": "efemerizar",
    "efemerizadas": "efemerizar",
    "efemerizado": "efemerizar",
    "efemerizados": "efemerizar",
    "efemerizai": "efemerizar",
    "efemerizais": "efemerizar",
    "efemerizam": "efemerizar",
    "efemerizamo": "efemerizar",
    "efemerizamos": "efemerizar",
    "efemerizando": "efemerizar",
    "efemerizara": "efemerizar",
    "efemerizaram": "efemerizar",
    "efemerizaras": "efemerizar",
    "efemerizarde": "efemerizar",
    "efemerizardes": "efemerizar",
    "efemerizare": "efemerizar",
    "efemerizarei": "efemerizar",
    "efemerizareis": "efemerizar",
    "efemerizarem": "efemerizar",
    "efemerizaremos": "efemerizar",
    "efemerizares": "efemerizar",
    "efemerizaria": "efemerizar",
    "efemerizariam": "efemerizar",
    "efemerizarias": "efemerizar",
    "efemerizarmo": "efemerizar",
    "efemerizarmos": "efemerizar",
    "efemerizará": "efemerizar",
    "efemerizarás": "efemerizar",
    "efemerizarão": "efemerizar",
    "efemerizaríamos": "efemerizar",
    "efemerizaríeis": "efemerizar",
    "efemerizas": "efemerizar",
    "efemerizasse": "efemerizar",
    "efemerizassem": "efemerizar",
    "efemerizasses": "efemerizar",
    "efemerizaste": "efemerizar",
    "efemerizastes": "efemerizar",
    "efemerizava": "efemerizar",
    "efemerizavam": "efemerizar",
    "efemerizavas": "efemerizar",
    "efemerize": "efemerizar",
    "efemerizei": "efemerizar",
    "efemerizeis": "efemerizar",
    "efemerizem": "efemerizar",
    "efemerizemo": "efemerizar",
    "efemerizemos": "efemerizar",
    "efemerizes": "efemerizar",
    "efemerizo": "efemerizar",
    "efemerizou": "efemerizar",
    "efemerizá": "efemerizar",
    "efemerizámo": "efemerizar",
    "efemerizámos": "efemerizar",
    "efemerizáramo": "efemerizar",
    "efemerizáramos": "efemerizar",
    "efemerizárei": "efemerizar",
    "efemerizáreis": "efemerizar",
    "efemerizásseis": "efemerizar",
    "efemerizássemos": "efemerizar",
    "efemerizávamo": "efemerizar",
    "efemerizávamos": "efemerizar",
    "efemerizávei": "efemerizar",
    "efemerizáveis": "efemerizar",
    "efemerídeos": "efemerídeo",
    "efemina": "efeminar",
    "efeminada": "efeminar",
    "efeminadas": "efeminar",
    "efeminado": "efeminar",
    "efeminados": "efeminar",
    "efeminai": "efeminar",
    "efeminais": "efeminar",
    "efeminam": "efeminar",
    "efeminamo": "efeminar",
    "efeminamos": "efeminar",
    "efeminando": "efeminar",
    "efeminara": "efeminar",
    "efeminaram": "efeminar",
    "efeminaras": "efeminar",
    "efeminarde": "efeminar",
    "efeminardes": "efeminar",
    "efeminare": "efeminar",
    "efeminarei": "efeminar",
    "efeminareis": "efeminar",
    "efeminarem": "efeminar",
    "efeminaremos": "efeminar",
    "efeminares": "efeminar",
    "efeminaria": "efeminar",
    "efeminariam": "efeminar",
    "efeminarias": "efeminar",
    "efeminarmo": "efeminar",
    "efeminarmos": "efeminar",
    "efeminará": "efeminar",
    "efeminarás": "efeminar",
    "efeminarão": "efeminar",
    "efeminaríamos": "efeminar",
    "efeminaríeis": "efeminar",
    "efeminas": "efeminar",
    "efeminasse": "efeminar",
    "efeminassem": "efeminar",
    "efeminasses": "efeminar",
    "efeminaste": "efeminar",
    "efeminastes": "efeminar",
    "efeminava": "efeminar",
    "efeminavam": "efeminar",
    "efeminavas": "efeminar",
    "efeminações": "efeminação",
    "efemine": "efeminar",
    "efeminei": "efeminar",
    "efemineis": "efeminar",
    "efeminem": "efeminar",
    "efeminemo": "efeminar",
    "efeminemos": "efeminar",
    "efemines": "efeminar",
    "efeminiza": "efeminizar",
    "efeminizada": "efeminizar",
    "efeminizadas": "efeminizar",
    "efeminizado": "efeminizar",
    "efeminizados": "efeminizar",
    "efeminizai": "efeminizar",
    "efeminizais": "efeminizar",
    "efeminizam": "efeminizar",
    "efeminizamo": "efeminizar",
    "efeminizamos": "efeminizar",
    "efeminizando": "efeminizar",
    "efeminizara": "efeminizar",
    "efeminizaram": "efeminizar",
    "efeminizaras": "efeminizar",
    "efeminizarde": "efeminizar",
    "efeminizardes": "efeminizar",
    "efeminizare": "efeminizar",
    "efeminizarei": "efeminizar",
    "efeminizareis": "efeminizar",
    "efeminizarem": "efeminizar",
    "efeminizaremos": "efeminizar",
    "efeminizares": "efeminizar",
    "efeminizaria": "efeminizar",
    "efeminizariam": "efeminizar",
    "efeminizarias": "efeminizar",
    "efeminizarmo": "efeminizar",
    "efeminizarmos": "efeminizar",
    "efeminizará": "efeminizar",
    "efeminizarás": "efeminizar",
    "efeminizarão": "efeminizar",
    "efeminizaríamos": "efeminizar",
    "efeminizaríeis": "efeminizar",
    "efeminizas": "efeminizar",
    "efeminizasse": "efeminizar",
    "efeminizassem": "efeminizar",
    "efeminizasses": "efeminizar",
    "efeminizaste": "efeminizar",
    "efeminizastes": "efeminizar",
    "efeminizava": "efeminizar",
    "efeminizavam": "efeminizar",
    "efeminizavas": "efeminizar",
    "efeminize": "efeminizar",
    "efeminizei": "efeminizar",
    "efeminizeis": "efeminizar",
    "efeminizem": "efeminizar",
    "efeminizemo": "efeminizar",
    "efeminizemos": "efeminizar",
    "efeminizes": "efeminizar",
    "efeminizo": "efeminizar",
    "efeminizou": "efeminizar",
    "efeminizá": "efeminizar",
    "efeminizámo": "efeminizar",
    "efeminizámos": "efeminizar",
    "efeminizáramo": "efeminizar",
    "efeminizáramos": "efeminizar",
    "efeminizárei": "efeminizar",
    "efeminizáreis": "efeminizar",
    "efeminizásseis": "efeminizar",
    "efeminizássemos": "efeminizar",
    "efeminizávamo": "efeminizar",
    "efeminizávamos": "efeminizar",
    "efeminizávei": "efeminizar",
    "efeminizáveis": "efeminizar",
    "efemino": "efeminar",
    "efeminou": "efeminar",
    "efeminá": "efeminar",
    "efeminámo": "efeminar",
    "efeminámos": "efeminar",
    "efemináramo": "efeminar",
    "efemináramos": "efeminar",
    "efeminárei": "efeminar",
    "efemináreis": "efeminar",
    "efeminásseis": "efeminar",
    "efeminássemos": "efeminar",
    "efeminávamo": "efeminar",
    "efeminávamos": "efeminar",
    "efeminávei": "efeminar",
    "efemináveis": "efeminar",
    "efeméridas": "efemérida",
    "efemérides": "efeméride",
    "eferentes": "eferente",
    "efervesce": "efervescer",
    "efervescei": "efervescer",
    "efervesceis": "efervescer",
    "efervescem": "efervescer",
    "efervescemo": "efervescer",
    "efervescemos": "efervescer",
    "efervescendo": "efervescer",
    "efervescentes": "efervescente",
    "efervescera": "efervescer",
    "efervesceram": "efervescer",
    "efervesceras": "efervescer",
    "efervescerdes": "efervescer",
    "efervescerei": "efervescer",
    "efervescereis": "efervescer",
    "efervescerem": "efervescer",
    "efervesceremos": "efervescer",
    "efervesceres": "efervescer",
    "efervesceria": "efervescer",
    "efervesceriam": "efervescer",
    "efervescerias": "efervescer",
    "efervescermo": "efervescer",
    "efervescermos": "efervescer",
    "efervescerá": "efervescer",
    "efervescerás": "efervescer",
    "efervescerão": "efervescer",
    "efervesceríamos": "efervescer",
    "efervesceríeis": "efervescer",
    "efervesces": "efervescer",
    "efervescesse": "efervescer",
    "efervescessem": "efervescer",
    "efervescesses": "efervescer",
    "efervesceste": "efervescer",
    "efervescestes": "efervescer",
    "efervesceu": "efervescer",
    "efervesci": "efervescer",
    "efervescia": "efervescer",
    "efervesciam": "efervescer",
    "efervescias": "efervescer",
    "efervescida": "efervescer",
    "efervescidas": "efervescer",
    "efervescido": "efervescer",
    "efervescidos": "efervescer",
    "efervescências": "efervescência",
    "efervescêramo": "efervescer",
    "efervescêramos": "efervescer",
    "efervescêreis": "efervescer",
    "efervescêsseis": "efervescer",
    "efervescêssemos": "efervescer",
    "efervescíamo": "efervescer",
    "efervescíamos": "efervescer",
    "efervescíeis": "efervescer",
    "efervesça": "efervescer",
    "efervesçais": "efervescer",
    "efervesçam": "efervescer",
    "efervesçamo": "efervescer",
    "efervesçamos": "efervescer",
    "efervesças": "efervescer",
    "efervesço": "efervescer",
    "efes": "efe",
    "efesíaca": "efesíaco",
    "efesíacas": "efesíaco",
    "efesíacos": "efesíaco",
    "eficacíssima": "eficaz",
    "eficacíssimas": "eficaz",
    "eficacíssimo": "eficaz",
    "eficacíssimos": "eficaz",
    "eficazes": "eficaz",
    "eficientes": "eficiente",
    "eficiências": "eficiência",
    "eficácias": "eficácia",
    "efidroses": "efidrose",
    "efipídeos": "efipídeo",
    "efloresce": "eflorescer",
    "eflorescei": "eflorescer",
    "efloresceis": "eflorescer",
    "eflorescem": "eflorescer",
    "eflorescemo": "eflorescer",
    "eflorescemos": "eflorescer",
    "eflorescendo": "eflorescer",
    "eflorescentes": "eflorescente",
    "eflorescera": "eflorescer",
    "efloresceram": "eflorescer",
    "efloresceras": "eflorescer",
    "eflorescerdes": "eflorescer",
    "eflorescerei": "eflorescer",
    "eflorescereis": "eflorescer",
    "eflorescerem": "eflorescer",
    "efloresceremos": "eflorescer",
    "efloresceres": "eflorescer",
    "efloresceria": "eflorescer",
    "efloresceriam": "eflorescer",
    "eflorescerias": "eflorescer",
    "eflorescermo": "eflorescer",
    "eflorescermos": "eflorescer",
    "eflorescerá": "eflorescer",
    "eflorescerás": "eflorescer",
    "eflorescerão": "eflorescer",
    "efloresceríamos": "eflorescer",
    "efloresceríeis": "eflorescer",
    "efloresces": "eflorescer",
    "eflorescesse": "eflorescer",
    "eflorescessem": "eflorescer",
    "eflorescesses": "eflorescer",
    "efloresceste": "eflorescer",
    "eflorescestes": "eflorescer",
    "efloresceu": "eflorescer",
    "efloresci": "eflorescer",
    "eflorescia": "eflorescer",
    "efloresciam": "eflorescer",
    "eflorescias": "eflorescer",
    "eflorescida": "eflorescer",
    "eflorescidas": "eflorescer",
    "eflorescido": "eflorescer",
    "eflorescidos": "eflorescer",
    "eflorescências": "eflorescência",
    "eflorescêramo": "eflorescer",
    "eflorescêramos": "eflorescer",
    "eflorescêreis": "eflorescer",
    "eflorescêsseis": "eflorescer",
    "eflorescêssemos": "eflorescer",
    "eflorescíamo": "eflorescer",
    "eflorescíamos": "eflorescer",
    "eflorescíeis": "eflorescer",
    "efloresça": "eflorescer",
    "efloresçais": "eflorescer",
    "efloresçam": "eflorescer",
    "efloresçamo": "eflorescer",
    "efloresçamos": "eflorescer",
    "efloresças": "eflorescer",
    "efloresço": "eflorescer",
    "eflua": "efluir",
    "efluais": "efluir",
    "efluam": "efluir",
    "efluamo": "efluir",
    "efluamos": "efluir",
    "efluas": "efluir",
    "efluem": "efluir",
    "efluentes": "efluente",
    "eflui": "efluir",
    "efluindo": "efluir",
    "efluirdes": "efluir",
    "efluirei": "efluir",
    "efluireis": "efluir",
    "efluiremos": "efluir",
    "efluiria": "efluir",
    "efluiriam": "efluir",
    "efluirias": "efluir",
    "efluirmo": "efluir",
    "efluirmos": "efluir",
    "efluirá": "efluir",
    "efluirás": "efluir",
    "efluirão": "efluir",
    "efluiríamos": "efluir",
    "efluiríeis": "efluir",
    "efluis": "efluir",
    "efluiu": "efluir",
    "efluo": "efluir",
    "efluviosa": "efluvioso",
    "efluviosas": "efluvioso",
    "efluviosos": "efluvioso",
    "efluxos": "efluxo",
    "efluxões": "efluxão",
    "efluências": "efluência",
    "efluí": "efluir",
    "efluía": "efluir",
    "efluíam": "efluir",
    "efluíamo": "efluir",
    "efluíamos": "efluir",
    "efluías": "efluir",
    "efluída": "efluir",
    "efluídas": "efluir",
    "efluído": "efluir",
    "efluídos": "efluir",
    "efluíeis": "efluir",
    "efluímo": "efluir",
    "efluímos": "efluir",
    "efluíra": "efluir",
    "efluíram": "efluir",
    "efluíramo": "efluir",
    "efluíramos": "efluir",
    "efluíras": "efluir",
    "efluíreis": "efluir",
    "efluírem": "efluir",
    "efluíres": "efluir",
    "efluís": "efluir",
    "efluísse": "efluir",
    "efluísseis": "efluir",
    "efluíssem": "efluir",
    "efluíssemos": "efluir",
    "efluísses": "efluir",
    "efluíste": "efluir",
    "efluístes": "efluir",
    "eflúvios": "eflúvio",
    "efodiofobias": "efodiofobia",
    "efodiofóbica": "efodiofóbico",
    "efodiofóbicas": "efodiofóbico",
    "efodiofóbicos": "efodiofóbico",
    "efodiófoba": "efodiófobo",
    "efodiófobas": "efodiófobo",
    "efodiófobos": "efodiófobo",
    "eforatos": "eforato",
    "eforias": "eforia",
    "efracturas": "efractura",
    "efracções": "efracção",
    "efunda": "efundir",
    "efundais": "efundir",
    "efundam": "efundir",
    "efundamo": "efundir",
    "efundamos": "efundir",
    "efundas": "efundir",
    "efunde": "efundir",
    "efundem": "efundir",
    "efundes": "efundir",
    "efundi": "efundir",
    "efundia": "efundir",
    "efundiam": "efundir",
    "efundias": "efundir",
    "efundida": "efundir",
    "efundidas": "efundir",
    "efundido": "efundir",
    "efundidos": "efundir",
    "efundimo": "efundir",
    "efundimos": "efundir",
    "efundindo": "efundir",
    "efundira": "efundir",
    "efundiram": "efundir",
    "efundiras": "efundir",
    "efundirde": "efundir",
    "efundirdes": "efundir",
    "efundire": "efundir",
    "efundirei": "efundir",
    "efundireis": "efundir",
    "efundirem": "efundir",
    "efundiremos": "efundir",
    "efundires": "efundir",
    "efundiria": "efundir",
    "efundiriam": "efundir",
    "efundirias": "efundir",
    "efundirmo": "efundir",
    "efundirmos": "efundir",
    "efundirá": "efundir",
    "efundirás": "efundir",
    "efundirão": "efundir",
    "efundiríamos": "efundir",
    "efundiríeis": "efundir",
    "efundis": "efundir",
    "efundisse": "efundir",
    "efundissem": "efundir",
    "efundisses": "efundir",
    "efundiste": "efundir",
    "efundistes": "efundir",
    "efundiu": "efundir",
    "efundo": "efundir",
    "efundíamo": "efundir",
    "efundíamos": "efundir",
    "efundíei": "efundir",
    "efundíeis": "efundir",
    "efundíramo": "efundir",
    "efundíramos": "efundir",
    "efundírei": "efundir",
    "efundíreis": "efundir",
    "efundísseis": "efundir",
    "efundíssemos": "efundir",
    "efusa": "efuso",
    "efusas": "efuso",
    "efusiva": "efusivo",
    "efusivas": "efusivo",
    "efusivos": "efusivo",
    "efusores": "efusor",
    "efusos": "efuso",
    "efusões": "efusão",
    "efélides": "efélide",
    "efémera": "efémero",
    "efémeras": "efémero",
    "efémeros": "efémero",
    "efésia": "efésio",
    "efésias": "efésio",
    "efésios": "efésio",
    "efígies": "efígie",
    "efúgios": "efúgio",
    "egeia": "egeu",
    "egeias": "egeu",
    "egeus": "egeu",
    "egipciana": "egipciano",
    "egipcianas": "egipciano",
    "egipcianos": "egipciano",
    "egipcíaca": "egipcíaco",
    "egipcíacas": "egipcíaco",
    "egipcíacos": "egipcíaco",
    "egiptana": "egiptano",
    "egiptanas": "egiptano",
    "egiptanos": "egiptano",
    "egiptologias": "egiptologia",
    "egiptológica": "egiptológico",
    "egiptológicas": "egiptológico",
    "egiptológicos": "egiptológico",
    "egiptóloga": "egiptólogo",
    "egiptólogas": "egiptólogo",
    "egiptólogos": "egiptólogo",
    "egirinas": "egirina",
    "egitanenses": "egitanense",
    "egitanienses": "egitaniense",
    "egocentrismos": "egocentrismo",
    "egocentristas": "egocentrista",
    "egocêntrica": "egocêntrico",
    "egocêntricas": "egocêntrico",
    "egocêntricos": "egocêntrico",
    "egofagias": "egofagia",
    "egofonias": "egofonia",
    "egofágica": "egofágico",
    "egofágicas": "egofágico",
    "egofágicos": "egofágico",
    "egofónica": "egofónico",
    "egofónicas": "egofónico",
    "egofónicos": "egofónico",
    "egomanias": "egomania",
    "egos": "ego",
    "egotismos": "egotismo",
    "egotistas": "egotista",
    "egotística": "egotístico",
    "egotísticas": "egotístico",
    "egotísticos": "egotístico",
    "egoísmos": "egoísmo",
    "egoístas": "egoísta",
    "egoística": "egoístico",
    "egoísticas": "egoístico",
    "egoísticos": "egoístico",
    "egressa": "egresso",
    "egressas": "egresso",
    "egressos": "egresso",
    "egressões": "egressão",
    "egrégia": "egrégio",
    "egrégias": "egrégio",
    "egrégios": "egrégio",
    "eguadas": "eguada",
    "eguariça": "eguariço",
    "eguariças": "eguariço",
    "eguariços": "eguariço",
    "eguazinha": "égua",
    "eguazinhas": "égua",
    "eguazita": "égua",
    "eguazitas": "égua",
    "egérias": "egéria",
    "egípcia": "egípcio",
    "egípcias": "egípcio",
    "egípcios": "egípcio",
    "egófaga": "egófago",
    "egófagas": "egófago",
    "egófagos": "egófago",
    "ei": "eis",
    "eidetismos": "eidetismo",
    "eidos": "eido",
    "eidética": "eidético",
    "eidéticas": "eidético",
    "eidéticos": "eidético",
    "eifelianos": "eifeliano",
    "einsteiniana": "einsteiniano",
    "einsteinianas": "einsteiniano",
    "einsteinianos": "einsteiniano",
    "einsteins": "einstein",
    "einstêinios": "einstêinio",
    "eiradas": "eirada",
    "eirados": "eirado",
    "eiras": "eira",
    "eirogas": "eiroga",
    "eirós": "eiró",
    "eitos": "eito",
    "eiva": "eivar",
    "eivada": "eivar",
    "eivadas": "eivar",
    "eivado": "eivar",
    "eivados": "eivar",
    "eivai": "eivar",
    "eivais": "eivar",
    "eivam": "eivar",
    "eivamo": "eivar",
    "eivamos": "eivar",
    "eivando": "eivar",
    "eivara": "eivar",
    "eivaram": "eivar",
    "eivaras": "eivar",
    "eivarde": "eivar",
    "eivardes": "eivar",
    "eivare": "eivar",
    "eivarei": "eivar",
    "eivareis": "eivar",
    "eivarem": "eivar",
    "eivaremos": "eivar",
    "eivares": "eivar",
    "eivaria": "eivar",
    "eivariam": "eivar",
    "eivarias": "eivar",
    "eivarmo": "eivar",
    "eivarmos": "eivar",
    "eivará": "eivar",
    "eivarás": "eivar",
    "eivarão": "eivar",
    "eivaríamos": "eivar",
    "eivaríeis": "eivar",
    "eivas": "eivar",
    "eivasse": "eivar",
    "eivassem": "eivar",
    "eivasses": "eivar",
    "eivaste": "eivar",
    "eivastes": "eivar",
    "eivava": "eivar",
    "eivavam": "eivar",
    "eivavas": "eivar",
    "eive": "eivar",
    "eivei": "eivar",
    "eiveis": "eivar",
    "eivem": "eivar",
    "eivemo": "eivar",
    "eivemos": "eivar",
    "eives": "eivar",
    "eivo": "eivar",
    "eivou": "eivar",
    "eivá": "eivar",
    "eivámo": "eivar",
    "eivámos": "eivar",
    "eiváramo": "eivar",
    "eiváramos": "eivar",
    "eivárei": "eivar",
    "eiváreis": "eivar",
    "eivásseis": "eivar",
    "eivássemos": "eivar",
    "eivávamo": "eivar",
    "eivávamos": "eivar",
    "eivávei": "eivar",
    "eiváveis": "eivar",
    "eivões": "eivão",
    "eixas": "eixa",
    "eixos": "eixo",
    "ejacula": "ejacular",
    "ejaculada": "ejacular",
    "ejaculadas": "ejacular",
    "ejaculado": "ejacular",
    "ejaculadora": "ejaculador",
    "ejaculadoras": "ejaculador",
    "ejaculadores": "ejaculador",
    "ejaculados": "ejacular",
    "ejaculai": "ejacular",
    "ejaculais": "ejacular",
    "ejaculam": "ejacular",
    "ejaculamo": "ejacular",
    "ejaculamos": "ejacular",
    "ejaculando": "ejacular",
    "ejaculara": "ejacular",
    "ejacularam": "ejacular",
    "ejacularas": "ejacular",
    "ejacularde": "ejacular",
    "ejaculardes": "ejacular",
    "ejaculare": "ejacular",
    "ejacularei": "ejacular",
    "ejaculareis": "ejacular",
    "ejacularem": "ejacular",
    "ejacularemos": "ejacular",
    "ejaculares": "ejacular",
    "ejacularia": "ejacular",
    "ejaculariam": "ejacular",
    "ejacularias": "ejacular",
    "ejacularmo": "ejacular",
    "ejacularmos": "ejacular",
    "ejaculará": "ejacular",
    "ejacularás": "ejacular",
    "ejacularão": "ejacular",
    "ejacularíamos": "ejacular",
    "ejacularíeis": "ejacular",
    "ejaculas": "ejacular",
    "ejaculasse": "ejacular",
    "ejaculassem": "ejacular",
    "ejaculasses": "ejacular",
    "ejaculaste": "ejacular",
    "ejaculastes": "ejacular",
    "ejaculatória": "ejaculatório",
    "ejaculatórias": "ejaculatório",
    "ejaculatórios": "ejaculatório",
    "ejaculava": "ejacular",
    "ejaculavam": "ejacular",
    "ejaculavas": "ejacular",
    "ejaculações": "ejaculação",
    "ejacule": "ejacular",
    "ejaculei": "ejacular",
    "ejaculeis": "ejacular",
    "ejaculem": "ejacular",
    "ejaculemo": "ejacular",
    "ejaculemos": "ejacular",
    "ejacules": "ejacular",
    "ejaculo": "ejacular",
    "ejaculou": "ejacular",
    "ejaculá": "ejacular",
    "ejaculámo": "ejacular",
    "ejaculámos": "ejacular",
    "ejaculáramo": "ejacular",
    "ejaculáramos": "ejacular",
    "ejaculárei": "ejacular",
    "ejaculáreis": "ejacular",
    "ejaculásseis": "ejacular",
    "ejaculássemos": "ejacular",
    "ejaculávamo": "ejacular",
    "ejaculávamos": "ejacular",
    "ejaculávei": "ejacular",
    "ejaculáveis": "ejacular",
    "ejecta": "ejectar",
    "ejectada": "ejectar",
    "ejectadas": "ejectar",
    "ejectado": "ejectar",
    "ejectados": "ejectar",
    "ejectai": "ejectar",
    "ejectais": "ejectar",
    "ejectam": "ejectar",
    "ejectamo": "ejectar",
    "ejectamos": "ejectar",
    "ejectando": "ejectar",
    "ejectara": "ejectar",
    "ejectaram": "ejectar",
    "ejectaras": "ejectar",
    "ejectarde": "ejectar",
    "ejectardes": "ejectar",
    "ejectare": "ejectar",
    "ejectarei": "ejectar",
    "ejectareis": "ejectar",
    "ejectarem": "ejectar",
    "ejectaremos": "ejectar",
    "ejectares": "ejectar",
    "ejectaria": "ejectar",
    "ejectariam": "ejectar",
    "ejectarias": "ejectar",
    "ejectarmo": "ejectar",
    "ejectarmos": "ejectar",
    "ejectará": "ejectar",
    "ejectarás": "ejectar",
    "ejectarão": "ejectar",
    "ejectaríamos": "ejectar",
    "ejectaríeis": "ejectar",
    "ejectas": "ejectar",
    "ejectasse": "ejectar",
    "ejectassem": "ejectar",
    "ejectasses": "ejectar",
    "ejectaste": "ejectar",
    "ejectastes": "ejectar",
    "ejectava": "ejectar",
    "ejectavam": "ejectar",
    "ejectavas": "ejectar",
    "ejecte": "ejectar",
    "ejectei": "ejectar",
    "ejecteis": "ejectar",
    "ejectem": "ejectar",
    "ejectemo": "ejectar",
    "ejectemos": "ejectar",
    "ejectes": "ejectar",
    "ejecto": "ejectar",
    "ejectora": "ejector",
    "ejectoras": "ejector",
    "ejectores": "ejector",
    "ejectou": "ejectar",
    "ejectá": "ejectar",
    "ejectámo": "ejectar",
    "ejectámos": "ejectar",
    "ejectáramo": "ejectar",
    "ejectáramos": "ejectar",
    "ejectárei": "ejectar",
    "ejectáreis": "ejectar",
    "ejectásseis": "ejectar",
    "ejectássemos": "ejectar",
    "ejectávamo": "ejectar",
    "ejectávamos": "ejectar",
    "ejectávei": "ejectar",
    "ejectáveis": "ejectável",
    "ejectólitos": "ejectólito",
    "ejecutada": "ejecutado",
    "ejecutadas": "ejecutado",
    "ejecutados": "ejecutado",
    "ejecções": "ejecção",
    "ela": "ele",
    "elabora": "elaborar",
    "elaborada": "elaborar",
    "elaboradas": "elaborar",
    "elaborado": "elaborar",
    "elaboradora": "elaborador",
    "elaboradoras": "elaborador",
    "elaboradores": "elaborador",
    "elaborados": "elaborar",
    "elaboradíssima": "elaborado",
    "elaboradíssimas": "elaborado",
    "elaboradíssimo": "elaborado",
    "elaboradíssimos": "elaborado",
    "elaborai": "elaborar",
    "elaborais": "elaborar",
    "elaboram": "elaborar",
    "elaboramo": "elaborar",
    "elaboramos": "elaborar",
    "elaborando": "elaborar",
    "elaborara": "elaborar",
    "elaboraram": "elaborar",
    "elaboraras": "elaborar",
    "elaborarde": "elaborar",
    "elaborardes": "elaborar",
    "elaborare": "elaborar",
    "elaborarei": "elaborar",
    "elaborareis": "elaborar",
    "elaborarem": "elaborar",
    "elaboraremos": "elaborar",
    "elaborares": "elaborar",
    "elaboraria": "elaborar",
    "elaborariam": "elaborar",
    "elaborarias": "elaborar",
    "elaborarmo": "elaborar",
    "elaborarmos": "elaborar",
    "elaborará": "elaborar",
    "elaborarás": "elaborar",
    "elaborarão": "elaborar",
    "elaboraríamos": "elaborar",
    "elaboraríeis": "elaborar",
    "elaboras": "elaborar",
    "elaborasse": "elaborar",
    "elaborassem": "elaborar",
    "elaborasses": "elaborar",
    "elaboraste": "elaborar",
    "elaborastes": "elaborar",
    "elaborava": "elaborar",
    "elaboravam": "elaborar",
    "elaboravas": "elaborar",
    "elaborações": "elaboração",
    "elabore": "elaborar",
    "elaborei": "elaborar",
    "elaboreis": "elaborar",
    "elaborem": "elaborar",
    "elaboremo": "elaborar",
    "elaboremos": "elaborar",
    "elabores": "elaborar",
    "elaboro": "elaborar",
    "elaborou": "elaborar",
    "elaborá": "elaborar",
    "elaborámo": "elaborar",
    "elaborámos": "elaborar",
    "elaboráramo": "elaborar",
    "elaboráramos": "elaborar",
    "elaborárei": "elaborar",
    "elaboráreis": "elaborar",
    "elaborásseis": "elaborar",
    "elaborássemos": "elaborar",
    "elaborávamo": "elaborar",
    "elaborávamos": "elaborar",
    "elaborávei": "elaborar",
    "elaboráveis": "elaborável",
    "elanguesce": "elanguescer",
    "elanguescei": "elanguescer",
    "elanguesceis": "elanguescer",
    "elanguescem": "elanguescer",
    "elanguescemo": "elanguescer",
    "elanguescemos": "elanguescer",
    "elanguescendo": "elanguescer",
    "elanguescentes": "elanguescente",
    "elanguescera": "elanguescer",
    "elanguesceram": "elanguescer",
    "elanguesceras": "elanguescer",
    "elanguescerdes": "elanguescer",
    "elanguescerei": "elanguescer",
    "elanguescereis": "elanguescer",
    "elanguescerem": "elanguescer",
    "elanguesceremos": "elanguescer",
    "elanguesceres": "elanguescer",
    "elanguesceria": "elanguescer",
    "elanguesceriam": "elanguescer",
    "elanguescerias": "elanguescer",
    "elanguescermo": "elanguescer",
    "elanguescermos": "elanguescer",
    "elanguescerá": "elanguescer",
    "elanguescerás": "elanguescer",
    "elanguescerão": "elanguescer",
    "elanguesceríamos": "elanguescer",
    "elanguesceríeis": "elanguescer",
    "elanguesces": "elanguescer",
    "elanguescesse": "elanguescer",
    "elanguescessem": "elanguescer",
    "elanguescesses": "elanguescer",
    "elanguesceste": "elanguescer",
    "elanguescestes": "elanguescer",
    "elanguesceu": "elanguescer",
    "elanguesci": "elanguescer",
    "elanguescia": "elanguescer",
    "elanguesciam": "elanguescer",
    "elanguescias": "elanguescer",
    "elanguescida": "elanguescer",
    "elanguescidas": "elanguescer",
    "elanguescido": "elanguescer",
    "elanguescidos": "elanguescer",
    "elanguescências": "elanguescência",
    "elanguescêramo": "elanguescer",
    "elanguescêramos": "elanguescer",
    "elanguescêreis": "elanguescer",
    "elanguescêsseis": "elanguescer",
    "elanguescêssemos": "elanguescer",
    "elanguescíamo": "elanguescer",
    "elanguescíamos": "elanguescer",
    "elanguescíeis": "elanguescer",
    "elanguesça": "elanguescer",
    "elanguesçais": "elanguescer",
    "elanguesçam": "elanguescer",
    "elanguesçamo": "elanguescer",
    "elanguesçamos": "elanguescer",
    "elanguesças": "elanguescer",
    "elanguesço": "elanguescer",
    "elas": "ele",
    "elasmobranquiada": "elasmobranquiado",
    "elasmobranquiadas": "elasmobranquiado",
    "elasmobranquiados": "elasmobranquiado",
    "elasmobrânquia": "elasmobrânquio",
    "elasmobrânquias": "elasmobrânquio",
    "elasmobrânquios": "elasmobrânquio",
    "elasticidades": "elasticidade",
    "elasticimetrias": "elasticimetria",
    "elasticinas": "elasticina",
    "elastinas": "elastina",
    "elastodinâmica": "elastodinâmico",
    "elastodinâmicas": "elastodinâmico",
    "elastodinâmicos": "elastodinâmico",
    "elastómeros": "elastómero",
    "elaterinas": "elaterina",
    "elaterídeos": "elaterídeo",
    "elatinas": "elatina",
    "elatináceas": "elatinácea",
    "elatéridas": "elatérida",
    "elatérios": "elatério",
    "elações": "elação",
    "eldorados": "eldorado",
    "eleagnos": "eleagno",
    "eleagnáceas": "eleagnácea",
    "eleatas": "eleata",
    "eleatismos": "eleatismo",
    "electiva": "electivo",
    "electivas": "electivo",
    "electividades": "electividade",
    "electivos": "electivo",
    "electrargóis": "electrargol",
    "electrencefalografias": "electrencefalografia",
    "electrencefalogramas": "electrencefalograma",
    "electrencefalógrafos": "electrencefalógrafo",
    "electretes": "electrete",
    "electrexecuções": "electrexecução",
    "electricidades": "electricidade",
    "electricismos": "electricismo",
    "electricistas": "electricista",
    "electrifica": "electrificar",
    "electrificada": "electrificar",
    "electrificadas": "electrificar",
    "electrificado": "electrificar",
    "electrificados": "electrificar",
    "electrificai": "electrificar",
    "electrificais": "electrificar",
    "electrificam": "electrificar",
    "electrificamo": "electrificar",
    "electrificamos": "electrificar",
    "electrificando": "electrificar",
    "electrificara": "electrificar",
    "electrificaram": "electrificar",
    "electrificaras": "electrificar",
    "electrificarde": "electrificar",
    "electrificardes": "electrificar",
    "electrificare": "electrificar",
    "electrificarei": "electrificar",
    "electrificareis": "electrificar",
    "electrificarem": "electrificar",
    "electrificaremos": "electrificar",
    "electrificares": "electrificar",
    "electrificaria": "electrificar",
    "electrificariam": "electrificar",
    "electrificarias": "electrificar",
    "electrificarmo": "electrificar",
    "electrificarmos": "electrificar",
    "electrificará": "electrificar",
    "electrificarás": "electrificar",
    "electrificarão": "electrificar",
    "electrificaríamos": "electrificar",
    "electrificaríeis": "electrificar",
    "electrificas": "electrificar",
    "electrificasse": "electrificar",
    "electrificassem": "electrificar",
    "electrificasses": "electrificar",
    "electrificaste": "electrificar",
    "electrificastes": "electrificar",
    "electrificava": "electrificar",
    "electrificavam": "electrificar",
    "electrificavas": "electrificar",
    "electrificações": "electrificação",
    "electrifico": "electrificar",
    "electrificou": "electrificar",
    "electrificá": "electrificar",
    "electrificámo": "electrificar",
    "electrificámos": "electrificar",
    "electrificáramo": "electrificar",
    "electrificáramos": "electrificar",
    "electrificárei": "electrificar",
    "electrificáreis": "electrificar",
    "electrificásseis": "electrificar",
    "electrificássemos": "electrificar",
    "electrificávamo": "electrificar",
    "electrificávamos": "electrificar",
    "electrificávei": "electrificar",
    "electrificáveis": "electrificar",
    "electrifique": "electrificar",
    "electrifiquei": "electrificar",
    "electrifiqueis": "electrificar",
    "electrifiquem": "electrificar",
    "electrifiquemo": "electrificar",
    "electrifiquemos": "electrificar",
    "electrifiques": "electrificar",
    "electriza": "electrizar",
    "electrizada": "electrizar",
    "electrizadas": "electrizar",
    "electrizado": "electrizar",
    "electrizadora": "electrizador",
    "electrizadoras": "electrizador",
    "electrizadores": "electrizador",
    "electrizados": "electrizar",
    "electrizai": "electrizar",
    "electrizais": "electrizar",
    "electrizam": "electrizar",
    "electrizamo": "electrizar",
    "electrizamos": "electrizar",
    "electrizando": "electrizar",
    "electrizantes": "electrizante",
    "electrizara": "electrizar",
    "electrizaram": "electrizar",
    "electrizaras": "electrizar",
    "electrizarde": "electrizar",
    "electrizardes": "electrizar",
    "electrizare": "electrizar",
    "electrizarei": "electrizar",
    "electrizareis": "electrizar",
    "electrizarem": "electrizar",
    "electrizaremos": "electrizar",
    "electrizares": "electrizar",
    "electrizaria": "electrizar",
    "electrizariam": "electrizar",
    "electrizarias": "electrizar",
    "electrizarmo": "electrizar",
    "electrizarmos": "electrizar",
    "electrizará": "electrizar",
    "electrizarás": "electrizar",
    "electrizarão": "electrizar",
    "electrizaríamos": "electrizar",
    "electrizaríeis": "electrizar",
    "electrizas": "electrizar",
    "electrizasse": "electrizar",
    "electrizassem": "electrizar",
    "electrizasses": "electrizar",
    "electrizaste": "electrizar",
    "electrizastes": "electrizar",
    "electrizava": "electrizar",
    "electrizavam": "electrizar",
    "electrizavas": "electrizar",
    "electrizações": "electrização",
    "electrize": "electrizar",
    "electrizei": "electrizar",
    "electrizeis": "electrizar",
    "electrizem": "electrizar",
    "electrizemo": "electrizar",
    "electrizemos": "electrizar",
    "electrizes": "electrizar",
    "electrizo": "electrizar",
    "electrizou": "electrizar",
    "electrizá": "electrizar",
    "electrizámo": "electrizar",
    "electrizámos": "electrizar",
    "electrizáramo": "electrizar",
    "electrizáramos": "electrizar",
    "electrizárei": "electrizar",
    "electrizáreis": "electrizar",
    "electrizásseis": "electrizar",
    "electrizássemos": "electrizar",
    "electrizávamo": "electrizar",
    "electrizávamos": "electrizar",
    "electrizávei": "electrizar",
    "electrizáveis": "electrizável",
    "electrobalísticas": "electrobalística",
    "electrobiologias": "electrobiologia",
    "electrobiológica": "electrobiológico",
    "electrobiológicas": "electrobiológico",
    "electrobiológicos": "electrobiológico",
    "electrobióloga": "electrobiólogo",
    "electrobiólogas": "electrobiólogo",
    "electrobiólogos": "electrobiólogo",
    "electrocardiografias": "electrocardiografia",
    "electrocardiogramas": "electrocardiograma",
    "electrocardiográfica": "electrocardiográfico",
    "electrocardiográficas": "electrocardiográfico",
    "electrocardiográficos": "electrocardiográfico",
    "electrocardiógrafos": "electrocardiógrafo",
    "electrochoques": "electrochoque",
    "electrocinética": "electrocinético",
    "electrocinéticas": "electrocinético",
    "electrocinéticos": "electrocinético",
    "electrocirurgias": "electrocirurgia",
    "electrocirurgiã": "electrocirurgião",
    "electrocirurgiãos": "electrocirurgião",
    "electrocirurgiãs": "electrocirurgião",
    "electrocirurgiões": "electrocirurgião",
    "electrocirúrgica": "electrocirúrgico",
    "electrocirúrgicas": "electrocirúrgico",
    "electrocirúrgicos": "electrocirúrgico",
    "electrocoagulada": "electrocoagulado",
    "electrocoaguladas": "electrocoagulado",
    "electrocoagulados": "electrocoagulado",
    "electrocoagulações": "electrocoagulação",
    "electrocussões": "electrocussão",
    "electrocuta": "electrocutar",
    "electrocutada": "electrocutar",
    "electrocutadas": "electrocutar",
    "electrocutado": "electrocutar",
    "electrocutados": "electrocutar",
    "electrocutai": "electrocutar",
    "electrocutais": "electrocutar",
    "electrocutam": "electrocutar",
    "electrocutamo": "electrocutar",
    "electrocutamos": "electrocutar",
    "electrocutando": "electrocutar",
    "electrocutara": "electrocutar",
    "electrocutaram": "electrocutar",
    "electrocutaras": "electrocutar",
    "electrocutarde": "electrocutar",
    "electrocutardes": "electrocutar",
    "electrocutare": "electrocutar",
    "electrocutarei": "electrocutar",
    "electrocutareis": "electrocutar",
    "electrocutarem": "electrocutar",
    "electrocutaremos": "electrocutar",
    "electrocutares": "electrocutar",
    "electrocutaria": "electrocutar",
    "electrocutariam": "electrocutar",
    "electrocutarias": "electrocutar",
    "electrocutarmo": "electrocutar",
    "electrocutarmos": "electrocutar",
    "electrocutará": "electrocutar",
    "electrocutarás": "electrocutar",
    "electrocutarão": "electrocutar",
    "electrocutaríamos": "electrocutar",
    "electrocutaríeis": "electrocutar",
    "electrocutas": "electrocutar",
    "electrocutasse": "electrocutar",
    "electrocutassem": "electrocutar",
    "electrocutasses": "electrocutar",
    "electrocutaste": "electrocutar",
    "electrocutastes": "electrocutar",
    "electrocutava": "electrocutar",
    "electrocutavam": "electrocutar",
    "electrocutavas": "electrocutar",
    "electrocute": "electrocutar",
    "electrocutei": "electrocutar",
    "electrocuteis": "electrocutar",
    "electrocutem": "electrocutar",
    "electrocutemo": "electrocutar",
    "electrocutemos": "electrocutar",
    "electrocutes": "electrocutar",
    "electrocuto": "electrocutar",
    "electrocutora": "electrocutor",
    "electrocutoras": "electrocutor",
    "electrocutores": "electrocutor",
    "electrocutou": "electrocutar",
    "electrocutá": "electrocutar",
    "electrocutámo": "electrocutar",
    "electrocutámos": "electrocutar",
    "electrocutáramo": "electrocutar",
    "electrocutáramos": "electrocutar",
    "electrocutárei": "electrocutar",
    "electrocutáreis": "electrocutar",
    "electrocutásseis": "electrocutar",
    "electrocutássemos": "electrocutar",
    "electrocutávamo": "electrocutar",
    "electrocutávamos": "electrocutar",
    "electrocutávei": "electrocutar",
    "electrocutáveis": "electrocutar",
    "electrodiagnoses": "electrodiagnose",
    "electrodiagnósticos": "electrodiagnóstico",
    "electrodinamismos": "electrodinamismo",
    "electrodinamometrias": "electrodinamometria",
    "electrodinamométrica": "electrodinamométrico",
    "electrodinamométricas": "electrodinamométrico",
    "electrodinamométricos": "electrodinamométrico",
    "electrodinamómetros": "electrodinamómetro",
    "electrodinâmica": "electrodinâmico",
    "electrodinâmicas": "electrodinâmico",
    "electrodinâmicos": "electrodinâmico",
    "electrodiálises": "electrodiálise",
    "electrodoméstica": "electrodoméstico",
    "electrodomésticas": "electrodoméstico",
    "electrodomésticos": "electrodoméstico",
    "electroencefalogramas": "electroencefalograma",
    "electroencefalográfica": "electroencefalográfico",
    "electroencefalográficas": "electroencefalográfico",
    "electroencefalográficos": "electroencefalográfico",
    "electrofisiologias": "electrofisiologia",
    "electrofisiologistas": "electrofisiologista",
    "electrofisiológica": "electrofisiológico",
    "electrofisiológicas": "electrofisiológico",
    "electrofisiológicos": "electrofisiológico",
    "electrofones": "electrofone",
    "electroforeses": "electroforese",
    "electrogalvanismos": "electrogalvanismo",
    "electrogalvânica": "electrogalvânico",
    "electrogalvânicas": "electrogalvânico",
    "electrogalvânicos": "electrogalvânico",
    "electrogeradores": "electrogerador",
    "electrografias": "electrografia",
    "electrográfica": "electrográfico",
    "electrográficas": "electrográfico",
    "electrográficos": "electrográfico",
    "electrogénea": "electrogéneo",
    "electrogéneas": "electrogéneo",
    "electrogéneos": "electrogéneo",
    "electrolisa": "electrolisar",
    "electrolisada": "electrolisar",
    "electrolisadas": "electrolisar",
    "electrolisado": "electrolisar",
    "electrolisados": "electrolisar",
    "electrolisai": "electrolisar",
    "electrolisais": "electrolisar",
    "electrolisam": "electrolisar",
    "electrolisamo": "electrolisar",
    "electrolisamos": "electrolisar",
    "electrolisando": "electrolisar",
    "electrolisara": "electrolisar",
    "electrolisaram": "electrolisar",
    "electrolisaras": "electrolisar",
    "electrolisarde": "electrolisar",
    "electrolisardes": "electrolisar",
    "electrolisare": "electrolisar",
    "electrolisarei": "electrolisar",
    "electrolisareis": "electrolisar",
    "electrolisarem": "electrolisar",
    "electrolisaremos": "electrolisar",
    "electrolisares": "electrolisar",
    "electrolisaria": "electrolisar",
    "electrolisariam": "electrolisar",
    "electrolisarias": "electrolisar",
    "electrolisarmo": "electrolisar",
    "electrolisarmos": "electrolisar",
    "electrolisará": "electrolisar",
    "electrolisarás": "electrolisar",
    "electrolisarão": "electrolisar",
    "electrolisaríamos": "electrolisar",
    "electrolisaríeis": "electrolisar",
    "electrolisas": "electrolisar",
    "electrolisasse": "electrolisar",
    "electrolisassem": "electrolisar",
    "electrolisasses": "electrolisar",
    "electrolisaste": "electrolisar",
    "electrolisastes": "electrolisar",
    "electrolisava": "electrolisar",
    "electrolisavam": "electrolisar",
    "electrolisavas": "electrolisar",
    "electrolisações": "electrolisação",
    "electrolise": "electrolisar",
    "electrolisei": "electrolisar",
    "electroliseis": "electrolisar",
    "electrolisem": "electrolisar",
    "electrolisemo": "electrolisar",
    "electrolisemos": "electrolisar",
    "electrolises": "electrolisar",
    "electroliso": "electrolisar",
    "electrolisou": "electrolisar",
    "electrolisá": "electrolisar",
    "electrolisámo": "electrolisar",
    "electrolisámos": "electrolisar",
    "electrolisáramo": "electrolisar",
    "electrolisáramos": "electrolisar",
    "electrolisárei": "electrolisar",
    "electrolisáreis": "electrolisar",
    "electrolisásseis": "electrolisar",
    "electrolisássemos": "electrolisar",
    "electrolisávamo": "electrolisar",
    "electrolisávamos": "electrolisar",
    "electrolisávei": "electrolisar",
    "electrolisáveis": "electrolisar",
    "electrologias": "electrologia",
    "electroluminescentes": "electroluminescente",
    "electroluminescências": "electroluminescência",
    "electrolítica": "electrolítico",
    "electrolíticas": "electrolítico",
    "electrolíticos": "electrolítico",
    "electrológica": "electrológico",
    "electrológicas": "electrológico",
    "electrológicos": "electrológico",
    "electromagnetes": "electromagnete",
    "electromagnetismos": "electromagnetismo",
    "electromagnetizada": "electromagnetizado",
    "electromagnetizadas": "electromagnetizado",
    "electromagnetizados": "electromagnetizado",
    "electromagnética": "electromagnético",
    "electromagnéticas": "electromagnético",
    "electromagnéticos": "electromagnético",
    "electromecânica": "electromecânico",
    "electromecânicas": "electromecânico",
    "electromecânicos": "electromecânico",
    "electromeopatas": "electromeopata",
    "electromeopatias": "electromeopatia",
    "electromeopática": "electromeopático",
    "electromeopáticas": "electromeopático",
    "electromeopáticos": "electromeopático",
    "electromeoterapeutas": "electromeoterapeuta",
    "electrometalurgias": "electrometalurgia",
    "electrometalúrgica": "electrometalúrgico",
    "electrometalúrgicas": "electrometalúrgico",
    "electrometalúrgicos": "electrometalúrgico",
    "electrometrias": "electrometria",
    "electromotora": "electromotor",
    "electromotoras": "electromotor",
    "electromotores": "electromotor",
    "electromotrizes": "electromotriz",
    "electrométrica": "electrométrico",
    "electrométricas": "electrométrico",
    "electrométricos": "electrométrico",
    "electromóveis": "electromóvel",
    "electronegativa": "electronegativo",
    "electronegativas": "electronegativo",
    "electronegatividades": "electronegatividade",
    "electronegativos": "electronegativo",
    "electropexias": "electropexia",
    "electropositiva": "electropositivo",
    "electropositivas": "electropositivo",
    "electropositivos": "electropositivo",
    "electropunctora": "electropunctor",
    "electropunctoras": "electropunctor",
    "electropunctores": "electropunctor",
    "electropuncturas": "electropunctura",
    "electropuncturistas": "electropuncturista",
    "electroquímica": "electroquímico",
    "electroquímicas": "electroquímico",
    "electroquímicos": "electroquímico",
    "electroscópica": "electroscópico",
    "electroscópicas": "electroscópico",
    "electroscópicos": "electroscópico",
    "electroscópios": "electroscópio",
    "electrosiderúrgica": "electrosiderúrgico",
    "electrosiderúrgicas": "electrosiderúrgico",
    "electrosiderúrgicos": "electrosiderúrgico",
    "electrossemáforos": "electrossemáforo",
    "electrossiderurgias": "electrossiderurgia",
    "electrossoldaduras": "electrossoldadura",
    "electrostricções": "electrostricção",
    "electrostática": "electrostático",
    "electrostáticas": "electrostático",
    "electrostáticos": "electrostático",
    "electrotecnias": "electrotecnia",
    "electroterapeutas": "electroterapeuta",
    "electroterapias": "electroterapia",
    "electroterapêutica": "electroterapêutico",
    "electroterapêuticas": "electroterapêutico",
    "electroterapêuticos": "electroterapêutico",
    "electrotermias": "electrotermia",
    "electroterápica": "electroterápico",
    "electroterápicas": "electroterápico",
    "electroterápicos": "electroterápico",
    "electrotipias": "electrotipia",
    "electrotropismos": "electrotropismo",
    "electrotrópica": "electrotrópico",
    "electrotrópicas": "electrotrópico",
    "electrotrópicos": "electrotrópico",
    "electrotécnica": "electrotécnico",
    "electrotécnicas": "electrotécnico",
    "electrotécnicos": "electrotécnico",
    "electrotérmica": "electrotérmico",
    "electrotérmicas": "electrotérmico",
    "electrotérmicos": "electrotérmico",
    "electrotípica": "electrotípico",
    "electrotípicas": "electrotípico",
    "electrotípicos": "electrotípico",
    "electrotónica": "electrotónico",
    "electrotónicas": "electrotónico",
    "electrotónicos": "electrotónico",
    "electrovalentes": "electrovalente",
    "electrovalências": "electrovalência",
    "electroímanes": "electroíman",
    "electroópticas": "electroóptica",
    "electródios": "electródio",
    "electróforos": "electróforo",
    "electrógrafos": "electrógrafo",
    "electrólises": "electrólise",
    "electrólitos": "electrólito",
    "electróloga": "electrólogo",
    "electrólogas": "electrólogo",
    "electrólogos": "electrólogo",
    "electrómetros": "electrómetro",
    "electrónica": "electrónico",
    "electrónicas": "electrónico",
    "electrónicos": "electrónico",
    "electrões": "electrão",
    "electuários": "electuário",
    "elefanta": "elefante",
    "elefantas": "elefante",
    "elefantes": "elefante",
    "elefantina": "elefantino",
    "elefantinas": "elefantino",
    "elefantinos": "elefantino",
    "elefantíaca": "elefantíaco",
    "elefantíacas": "elefantíaco",
    "elefantíacos": "elefantíaco",
    "elefantíases": "elefantíase",
    "elefantídeos": "elefantídeo",
    "elefantóides": "elefantóide",
    "elefântica": "elefântico",
    "elefânticas": "elefântico",
    "elefânticos": "elefântico",
    "elegantes": "elegante",
    "elegantismos": "elegantismo",
    "elegantíssima": "elegante",
    "elegantíssimas": "elegante",
    "elegantíssimo": "elegante",
    "elegantíssimos": "elegante",
    "elege": "eleger",
    "elegei": "eleger",
    "elegeis": "eleger",
    "elegem": "eleger",
    "elegemo": "eleger",
    "elegemos": "eleger",
    "elegenda": "elegendo",
    "elegendas": "elegendo",
    "elegendo": "eleger",
    "elegendos": "elegendo",
    "elegera": "eleger",
    "elegeram": "eleger",
    "elegeras": "eleger",
    "elegerde": "eleger",
    "elegerdes": "eleger",
    "elegere": "eleger",
    "elegerei": "eleger",
    "elegereis": "eleger",
    "elegerem": "eleger",
    "elegeremos": "eleger",
    "elegeres": "eleger",
    "elegeria": "eleger",
    "elegeriam": "eleger",
    "elegerias": "eleger",
    "elegermo": "eleger",
    "elegermos": "eleger",
    "elegerá": "eleger",
    "elegerás": "eleger",
    "elegerão": "eleger",
    "elegeríamos": "eleger",
    "elegeríeis": "eleger",
    "eleges": "eleger",
    "elegesse": "eleger",
    "elegessem": "eleger",
    "elegesses": "eleger",
    "elegeste": "eleger",
    "elegestes": "eleger",
    "elegeu": "eleger",
    "elegi": "eleger",
    "elegia": "eleger",
    "elegiam": "eleger",
    "elegiambos": "elegiambo",
    "elegias": "elegia",
    "elegibilidades": "elegibilidade",
    "elegida": "elegido",
    "elegidas": "elegido",
    "elegido": "eleger",
    "elegidos": "elegido",
    "elegistas": "elegista",
    "elegiógrafa": "elegiógrafo",
    "elegiógrafas": "elegiógrafo",
    "elegiógrafos": "elegiógrafo",
    "elegâncias": "elegância",
    "elegê": "eleger",
    "elegêramo": "eleger",
    "elegêramos": "eleger",
    "elegêrei": "eleger",
    "elegêreis": "eleger",
    "elegêsseis": "eleger",
    "elegêssemos": "eleger",
    "elegíaca": "elegíaco",
    "elegíacas": "elegíaco",
    "elegíacos": "elegíaco",
    "elegíadas": "elegíada",
    "elegíamo": "eleger",
    "elegíamos": "eleger",
    "elegíei": "eleger",
    "elegíeis": "eleger",
    "elegíveis": "elegível",
    "eleita": "eleito",
    "eleitas": "eleito",
    "eleitora": "eleitor",
    "eleitorados": "eleitorado",
    "eleitorais": "eleitoral",
    "eleitoralismos": "eleitoralismo",
    "eleitoralistas": "eleitoralista",
    "eleitoras": "eleitor",
    "eleitores": "eleitor",
    "eleitorites": "eleitorite",
    "eleitos": "eleito",
    "eleitrica": "eleitrico",
    "eleitricas": "eleitrico",
    "eleitricos": "eleitrico",
    "eleiçoeira": "eleiçoeiro",
    "eleiçoeiras": "eleiçoeiro",
    "eleiçoeiros": "eleiçoeiro",
    "eleições": "eleição",
    "eleja": "eleger",
    "elejais": "eleger",
    "elejam": "eleger",
    "elejamo": "eleger",
    "elejamos": "eleger",
    "elejas": "eleger",
    "elejo": "eleger",
    "elementais": "elemental",
    "elementares": "elementar",
    "elementaridades": "elementaridade",
    "elementaríssima": "elementar",
    "elementaríssimas": "elementar",
    "elementaríssimo": "elementar",
    "elementaríssimos": "elementar",
    "elementos": "elemento",
    "elementária": "elementário",
    "elementárias": "elementário",
    "elementários": "elementário",
    "elemicinas": "elemicina",
    "elemieiras": "elemieira",
    "eleminas": "elemina",
    "elemis": "elemi",
    "elencos": "elenco",
    "eleoceróleos": "eleoceróleo",
    "eleodendros": "eleodendro",
    "eleolites": "eleolite",
    "eleometrias": "eleometria",
    "eles": "ele",
    "eleusina": "eleusino",
    "eleusinas": "eleusino",
    "eleusinea": "eleusineo",
    "eleusineas": "eleusineo",
    "eleusineos": "eleusineo",
    "eleusinos": "eleusino",
    "eleusínia": "eleusínio",
    "eleusínias": "eleusínio",
    "eleusínios": "eleusínio",
    "eleuterodáctila": "eleuterodáctilo",
    "eleuterodáctilas": "eleuterodáctilo",
    "eleuterodáctilos": "eleuterodáctilo",
    "eleuteroginias": "eleuteroginia",
    "eleuterogínica": "eleuterogínico",
    "eleuterogínicas": "eleuterogínico",
    "eleuterogínicos": "eleuterogínico",
    "eleuterozoários": "eleuterozoário",
    "eleuterógina": "eleuterógino",
    "eleuteróginas": "eleuterógino",
    "eleuteróginos": "eleuterógino",
    "eleuterómana": "eleuterómano",
    "eleuterómanas": "eleuterómano",
    "eleuterómanos": "eleuterómano",
    "eleutéria": "eleutério",
    "eleutérias": "eleutério",
    "eleutérios": "eleutério",
    "eleva": "elevar",
    "elevada": "elevar",
    "elevadas": "elevar",
    "elevado": "elevar",
    "elevadora": "elevador",
    "elevadoras": "elevador",
    "elevadores": "elevador",
    "elevados": "elevar",
    "elevadíssima": "elevado",
    "elevadíssimas": "elevado",
    "elevadíssimo": "elevado",
    "elevadíssimos": "elevado",
    "elevai": "elevar",
    "elevais": "elevar",
    "elevam": "elevar",
    "elevamo": "elevar",
    "elevamos": "elevar",
    "elevando": "elevar",
    "elevara": "elevar",
    "elevaram": "elevar",
    "elevaras": "elevar",
    "elevarde": "elevar",
    "elevardes": "elevar",
    "elevare": "elevar",
    "elevarei": "elevar",
    "elevareis": "elevar",
    "elevarem": "elevar",
    "elevaremos": "elevar",
    "elevares": "elevar",
    "elevaria": "elevar",
    "elevariam": "elevar",
    "elevarias": "elevar",
    "elevarmo": "elevar",
    "elevarmos": "elevar",
    "elevará": "elevar",
    "elevarás": "elevar",
    "elevarão": "elevar",
    "elevaríamos": "elevar",
    "elevaríeis": "elevar",
    "elevas": "elevar",
    "elevasse": "elevar",
    "elevassem": "elevar",
    "elevasses": "elevar",
    "elevaste": "elevar",
    "elevastes": "elevar",
    "elevatória": "elevatório",
    "elevatórias": "elevatório",
    "elevatórios": "elevatório",
    "elevava": "elevar",
    "elevavam": "elevar",
    "elevavas": "elevar",
    "elevações": "elevação",
    "eleve": "elevar",
    "elevei": "elevar",
    "eleveis": "elevar",
    "elevem": "elevar",
    "elevemo": "elevar",
    "elevemos": "elevar",
    "eleves": "elevar",
    "elevo": "elevar",
    "elevou": "elevar",
    "elevá": "elevar",
    "elevámo": "elevar",
    "elevámos": "elevar",
    "eleváramo": "elevar",
    "eleváramos": "elevar",
    "elevárei": "elevar",
    "eleváreis": "elevar",
    "elevásseis": "elevar",
    "elevássemos": "elevar",
    "elevávamo": "elevar",
    "elevávamos": "elevar",
    "elevávei": "elevar",
    "eleváveis": "elevar",
    "eleágneas": "eleágnea",
    "eleática": "eleático",
    "eleáticas": "eleático",
    "eleáticos": "eleático",
    "eleófaga": "eleófago",
    "eleófagas": "eleófago",
    "eleófagos": "eleófago",
    "eleólea": "eleóleo",
    "eleóleas": "eleóleo",
    "eleóleos": "eleóleo",
    "eleólica": "eleólico",
    "eleólicas": "eleólico",
    "eleólicos": "eleólico",
    "eleúrias": "eleúria",
    "eleúrica": "eleúrico",
    "eleúricas": "eleúrico",
    "eleúricos": "eleúrico",
    "elfas": "elfa",
    "elicia": "eliciar",
    "eliciada": "eliciar",
    "eliciadas": "eliciar",
    "eliciado": "eliciar",
    "eliciados": "eliciar",
    "eliciai": "eliciar",
    "eliciais": "eliciar",
    "eliciam": "eliciar",
    "eliciamo": "eliciar",
    "eliciamos": "eliciar",
    "eliciando": "eliciar",
    "eliciara": "eliciar",
    "eliciaram": "eliciar",
    "eliciaras": "eliciar",
    "eliciarde": "eliciar",
    "eliciardes": "eliciar",
    "eliciare": "eliciar",
    "eliciarei": "eliciar",
    "eliciareis": "eliciar",
    "eliciarem": "eliciar",
    "eliciaremos": "eliciar",
    "eliciares": "eliciar",
    "eliciaria": "eliciar",
    "eliciariam": "eliciar",
    "eliciarias": "eliciar",
    "eliciarmo": "eliciar",
    "eliciarmos": "eliciar",
    "eliciará": "eliciar",
    "eliciarás": "eliciar",
    "eliciarão": "eliciar",
    "eliciaríamos": "eliciar",
    "eliciaríeis": "eliciar",
    "elicias": "eliciar",
    "eliciasse": "eliciar",
    "eliciassem": "eliciar",
    "eliciasses": "eliciar",
    "eliciaste": "eliciar",
    "eliciastes": "eliciar",
    "eliciava": "eliciar",
    "eliciavam": "eliciar",
    "eliciavas": "eliciar",
    "eliciações": "eliciação",
    "elicie": "eliciar",
    "eliciei": "eliciar",
    "elicieis": "eliciar",
    "eliciem": "eliciar",
    "eliciemo": "eliciar",
    "eliciemos": "eliciar",
    "elicies": "eliciar",
    "elicio": "eliciar",
    "eliciou": "eliciar",
    "eliciá": "eliciar",
    "eliciámo": "eliciar",
    "eliciámos": "eliciar",
    "eliciáramo": "eliciar",
    "eliciáramos": "eliciar",
    "eliciárei": "eliciar",
    "eliciáreis": "eliciar",
    "eliciásseis": "eliciar",
    "eliciássemos": "eliciar",
    "eliciávamo": "eliciar",
    "eliciávamos": "eliciar",
    "eliciávei": "eliciar",
    "eliciáveis": "eliciar",
    "elida": "elidir",
    "elidais": "elidir",
    "elidam": "elidir",
    "elidamo": "elidir",
    "elidamos": "elidir",
    "elidas": "elidir",
    "elide": "elidir",
    "elidem": "elidir",
    "elides": "elidir",
    "elidi": "elidir",
    "elidia": "elidir",
    "elidiam": "elidir",
    "elidias": "elidir",
    "elidibilidades": "elidibilidade",
    "elidida": "elidir",
    "elididas": "elidir",
    "elidido": "elidir",
    "elididos": "elidir",
    "elidimo": "elidir",
    "elidimos": "elidir",
    "elidindo": "elidir",
    "elidira": "elidir",
    "elidiram": "elidir",
    "elidiras": "elidir",
    "elidirde": "elidir",
    "elidirdes": "elidir",
    "elidire": "elidir",
    "elidirei": "elidir",
    "elidireis": "elidir",
    "elidirem": "elidir",
    "elidiremos": "elidir",
    "elidires": "elidir",
    "elidiria": "elidir",
    "elidiriam": "elidir",
    "elidirias": "elidir",
    "elidirmo": "elidir",
    "elidirmos": "elidir",
    "elidirá": "elidir",
    "elidirás": "elidir",
    "elidirão": "elidir",
    "elidiríamos": "elidir",
    "elidiríeis": "elidir",
    "elidis": "elidir",
    "elidisse": "elidir",
    "elidissem": "elidir",
    "elidisses": "elidir",
    "elidiste": "elidir",
    "elidistes": "elidir",
    "elidiu": "elidir",
    "elido": "elidir",
    "elidíamo": "elidir",
    "elidíamos": "elidir",
    "elidíei": "elidir",
    "elidíeis": "elidir",
    "elidíramo": "elidir",
    "elidíramos": "elidir",
    "elidírei": "elidir",
    "elidíreis": "elidir",
    "elidísseis": "elidir",
    "elidíssemos": "elidir",
    "elidíveis": "elidível",
    "elimina": "eliminar",
    "eliminada": "eliminar",
    "eliminadas": "eliminar",
    "eliminado": "eliminar",
    "eliminadora": "eliminador",
    "eliminadoras": "eliminador",
    "eliminadores": "eliminador",
    "eliminados": "eliminar",
    "eliminai": "eliminar",
    "eliminais": "eliminar",
    "eliminam": "eliminar",
    "eliminamo": "eliminar",
    "eliminamos": "eliminar",
    "eliminando": "eliminar",
    "eliminara": "eliminar",
    "eliminaram": "eliminar",
    "eliminaras": "eliminar",
    "eliminarde": "eliminar",
    "eliminardes": "eliminar",
    "eliminare": "eliminar",
    "eliminarei": "eliminar",
    "eliminareis": "eliminar",
    "eliminarem": "eliminar",
    "eliminaremos": "eliminar",
    "eliminares": "eliminar",
    "eliminaria": "eliminar",
    "eliminariam": "eliminar",
    "eliminarias": "eliminar",
    "eliminarmo": "eliminar",
    "eliminarmos": "eliminar",
    "eliminará": "eliminar",
    "eliminarás": "eliminar",
    "eliminarão": "eliminar",
    "eliminaríamos": "eliminar",
    "eliminaríeis": "eliminar",
    "eliminas": "eliminar",
    "eliminasse": "eliminar",
    "eliminassem": "eliminar",
    "eliminasses": "eliminar",
    "eliminaste": "eliminar",
    "eliminastes": "eliminar",
    "eliminatória": "eliminatório",
    "eliminatórias": "eliminatório",
    "eliminatórios": "eliminatório",
    "eliminava": "eliminar",
    "eliminavam": "eliminar",
    "eliminavas": "eliminar",
    "eliminações": "eliminação",
    "elimine": "eliminar",
    "eliminei": "eliminar",
    "elimineis": "eliminar",
    "eliminem": "eliminar",
    "eliminemo": "eliminar",
    "eliminemos": "eliminar",
    "elimines": "eliminar",
    "elimino": "eliminar",
    "eliminou": "eliminar",
    "eliminá": "eliminar",
    "eliminámo": "eliminar",
    "eliminámos": "eliminar",
    "elimináramo": "eliminar",
    "elimináramos": "eliminar",
    "eliminárei": "eliminar",
    "elimináreis": "eliminar",
    "eliminásseis": "eliminar",
    "eliminássemos": "eliminar",
    "eliminávamo": "eliminar",
    "eliminávamos": "eliminar",
    "eliminávei": "eliminar",
    "elimináveis": "eliminável",
    "elipanta": "elipanto",
    "elipantas": "elipanto",
    "elipantos": "elipanto",
    "elipses": "elipse",
    "elipsográfica": "elipsográfico",
    "elipsográficas": "elipsográfico",
    "elipsográficos": "elipsográfico",
    "elipsoidais": "elipsoidal",
    "elipsométrica": "elipsométrico",
    "elipsométricas": "elipsométrico",
    "elipsométricos": "elipsométrico",
    "elipsosperma": "elipsospermo",
    "elipsospermas": "elipsospermo",
    "elipsospermias": "elipsospermia",
    "elipsospermos": "elipsospermo",
    "elipsígrafos": "elipsígrafo",
    "elipsógrafos": "elipsógrafo",
    "elipsóides": "elipsóide",
    "elipsóstoma": "elipsóstomo",
    "elipsóstomas": "elipsóstomo",
    "elipsóstomos": "elipsóstomo",
    "elipticidades": "elipticidade",
    "elisões": "elisão",
    "elites": "elite",
    "elitismos": "elitismo",
    "elitistas": "elitista",
    "elitrorragias": "elitrorragia",
    "elitrorreias": "elitrorreia",
    "elitrorreica": "elitrorreico",
    "elitrorreicas": "elitrorreico",
    "elitrorreicos": "elitrorreico",
    "elitrorrágica": "elitrorrágico",
    "elitrorrágicas": "elitrorrágico",
    "elitrorrágicos": "elitrorrágico",
    "elitróptera": "elitróptero",
    "elitrópteras": "elitróptero",
    "elitrópteros": "elitróptero",
    "elixa": "elixar",
    "elixada": "elixar",
    "elixadas": "elixar",
    "elixado": "elixar",
    "elixados": "elixar",
    "elixai": "elixar",
    "elixais": "elixar",
    "elixam": "elixar",
    "elixamo": "elixar",
    "elixamos": "elixar",
    "elixando": "elixar",
    "elixara": "elixar",
    "elixaram": "elixar",
    "elixaras": "elixar",
    "elixarde": "elixar",
    "elixardes": "elixar",
    "elixare": "elixar",
    "elixarei": "elixar",
    "elixareis": "elixar",
    "elixarem": "elixar",
    "elixaremos": "elixar",
    "elixares": "elixar",
    "elixaria": "elixar",
    "elixariam": "elixar",
    "elixarias": "elixar",
    "elixarmo": "elixar",
    "elixarmos": "elixar",
    "elixará": "elixar",
    "elixarás": "elixar",
    "elixarão": "elixar",
    "elixaríamos": "elixar",
    "elixaríeis": "elixar",
    "elixas": "elixar",
    "elixasse": "elixar",
    "elixassem": "elixar",
    "elixasses": "elixar",
    "elixaste": "elixar",
    "elixastes": "elixar",
    "elixava": "elixar",
    "elixavam": "elixar",
    "elixavas": "elixar",
    "elixe": "elixar",
    "elixei": "elixar",
    "elixeis": "elixar",
    "elixem": "elixar",
    "elixemo": "elixar",
    "elixemos": "elixar",
    "elixes": "elixar",
    "elixires": "elixir",
    "elixo": "elixar",
    "elixou": "elixar",
    "elixá": "elixar",
    "elixámo": "elixar",
    "elixámos": "elixar",
    "elixáramo": "elixar",
    "elixáramos": "elixar",
    "elixárei": "elixar",
    "elixáreis": "elixar",
    "elixásseis": "elixar",
    "elixássemos": "elixar",
    "elixávamo": "elixar",
    "elixávamos": "elixar",
    "elixávei": "elixar",
    "elixáveis": "elixar",
    "elmanismos": "elmanismo",
    "elmanistas": "elmanista",
    "elmos": "elmo",
    "elocubradora": "elocubrador",
    "elocubradoras": "elocubrador",
    "elocubradores": "elocubrador",
    "elocutiva": "elocutivo",
    "elocutivas": "elocutivo",
    "elocutivos": "elocutivo",
    "elocutória": "elocutório",
    "elocutórias": "elocutório",
    "elocutórios": "elocutório",
    "elocuções": "elocução",
    "eloendros": "eloendro",
    "elogia": "elogiar",
    "elogiada": "elogiar",
    "elogiadas": "elogiar",
    "elogiado": "elogiar",
    "elogiadora": "elogiador",
    "elogiadoras": "elogiador",
    "elogiadores": "elogiador",
    "elogiados": "elogiar",
    "elogiadíssima": "elogiado",
    "elogiadíssimas": "elogiado",
    "elogiadíssimo": "elogiado",
    "elogiadíssimos": "elogiado",
    "elogiai": "elogiar",
    "elogiais": "elogiar",
    "elogiam": "elogiar",
    "elogiamo": "elogiar",
    "elogiamos": "elogiar",
    "elogiando": "elogiar",
    "elogiara": "elogiar",
    "elogiaram": "elogiar",
    "elogiaras": "elogiar",
    "elogiarde": "elogiar",
    "elogiardes": "elogiar",
    "elogiare": "elogiar",
    "elogiarei": "elogiar",
    "elogiareis": "elogiar",
    "elogiarem": "elogiar",
    "elogiaremos": "elogiar",
    "elogiares": "elogiar",
    "elogiaria": "elogiar",
    "elogiariam": "elogiar",
    "elogiarias": "elogiar",
    "elogiarmo": "elogiar",
    "elogiarmos": "elogiar",
    "elogiará": "elogiar",
    "elogiarás": "elogiar",
    "elogiarão": "elogiar",
    "elogiaríamos": "elogiar",
    "elogiaríeis": "elogiar",
    "elogias": "elogiar",
    "elogiasse": "elogiar",
    "elogiassem": "elogiar",
    "elogiasses": "elogiar",
    "elogiaste": "elogiar",
    "elogiastes": "elogiar",
    "elogiativa": "elogiativo",
    "elogiativas": "elogiativo",
    "elogiativos": "elogiativo",
    "elogiava": "elogiar",
    "elogiavam": "elogiar",
    "elogiavas": "elogiar",
    "elogie": "elogiar",
    "elogiei": "elogiar",
    "elogieis": "elogiar",
    "elogiem": "elogiar",
    "elogiemo": "elogiar",
    "elogiemos": "elogiar",
    "elogies": "elogiar",
    "elogio": "elogiar",
    "elogios": "elogio",
    "elogiosa": "elogioso",
    "elogiosas": "elogioso",
    "elogiosos": "elogioso",
    "elogiou": "elogiar",
    "elogiá": "elogiar",
    "elogiámo": "elogiar",
    "elogiámos": "elogiar",
    "elogiáramo": "elogiar",
    "elogiáramos": "elogiar",
    "elogiárei": "elogiar",
    "elogiáreis": "elogiar",
    "elogiásseis": "elogiar",
    "elogiássemos": "elogiar",
    "elogiávamo": "elogiar",
    "elogiávamos": "elogiar",
    "elogiávei": "elogiar",
    "elogiáveis": "elogiar",
    "elongações": "elongação",
    "eloquentes": "eloquente",
    "eloquentíssima": "eloquente",
    "eloquentíssimas": "eloquente",
    "eloquentíssimo": "eloquente",
    "eloquentíssimos": "eloquente",
    "eloquências": "eloquência",
    "elos": "elo",
    "elpiniana": "elpiniano",
    "elpinianas": "elpiniano",
    "elpinianos": "elpiniano",
    "elucida": "elucidar",
    "elucidada": "elucidar",
    "elucidadas": "elucidar",
    "elucidado": "elucidar",
    "elucidados": "elucidar",
    "elucidai": "elucidar",
    "elucidais": "elucidar",
    "elucidam": "elucidar",
    "elucidamo": "elucidar",
    "elucidamos": "elucidar",
    "elucidando": "elucidar",
    "elucidara": "elucidar",
    "elucidaram": "elucidar",
    "elucidaras": "elucidar",
    "elucidarde": "elucidar",
    "elucidardes": "elucidar",
    "elucidare": "elucidar",
    "elucidarei": "elucidar",
    "elucidareis": "elucidar",
    "elucidarem": "elucidar",
    "elucidaremos": "elucidar",
    "elucidares": "elucidar",
    "elucidaria": "elucidar",
    "elucidariam": "elucidar",
    "elucidarias": "elucidar",
    "elucidarmo": "elucidar",
    "elucidarmos": "elucidar",
    "elucidará": "elucidar",
    "elucidarás": "elucidar",
    "elucidarão": "elucidar",
    "elucidaríamos": "elucidar",
    "elucidaríeis": "elucidar",
    "elucidas": "elucidar",
    "elucidasse": "elucidar",
    "elucidassem": "elucidar",
    "elucidasses": "elucidar",
    "elucidaste": "elucidar",
    "elucidastes": "elucidar",
    "elucidativa": "elucidativo",
    "elucidativas": "elucidativo",
    "elucidativos": "elucidativo",
    "elucidava": "elucidar",
    "elucidavam": "elucidar",
    "elucidavas": "elucidar",
    "elucidações": "elucidação",
    "elucide": "elucidar",
    "elucidei": "elucidar",
    "elucideis": "elucidar",
    "elucidem": "elucidar",
    "elucidemo": "elucidar",
    "elucidemos": "elucidar",
    "elucides": "elucidar",
    "elucido": "elucidar",
    "elucidou": "elucidar",
    "elucidá": "elucidar",
    "elucidámo": "elucidar",
    "elucidámos": "elucidar",
    "elucidáramo": "elucidar",
    "elucidáramos": "elucidar",
    "elucidárei": "elucidar",
    "elucidáreis": "elucidar",
    "elucidários": "elucidário",
    "elucidásseis": "elucidar",
    "elucidássemos": "elucidar",
    "elucidávamo": "elucidar",
    "elucidávamos": "elucidar",
    "elucidávei": "elucidar",
    "elucidáveis": "elucidável",
    "elucubra": "elucubrar",
    "elucubrada": "elucubrar",
    "elucubradas": "elucubrar",
    "elucubrado": "elucubrar",
    "elucubradora": "elucubrador",
    "elucubradoras": "elucubrador",
    "elucubradores": "elucubrador",
    "elucubrados": "elucubrar",
    "elucubrai": "elucubrar",
    "elucubrais": "elucubrar",
    "elucubram": "elucubrar",
    "elucubramo": "elucubrar",
    "elucubramos": "elucubrar",
    "elucubrando": "elucubrar",
    "elucubrara": "elucubrar",
    "elucubraram": "elucubrar",
    "elucubraras": "elucubrar",
    "elucubrarde": "elucubrar",
    "elucubrardes": "elucubrar",
    "elucubrare": "elucubrar",
    "elucubrarei": "elucubrar",
    "elucubrareis": "elucubrar",
    "elucubrarem": "elucubrar",
    "elucubraremos": "elucubrar",
    "elucubrares": "elucubrar",
    "elucubraria": "elucubrar",
    "elucubrariam": "elucubrar",
    "elucubrarias": "elucubrar",
    "elucubrarmo": "elucubrar",
    "elucubrarmos": "elucubrar",
    "elucubrará": "elucubrar",
    "elucubrarás": "elucubrar",
    "elucubrarão": "elucubrar",
    "elucubraríamos": "elucubrar",
    "elucubraríeis": "elucubrar",
    "elucubras": "elucubrar",
    "elucubrasse": "elucubrar",
    "elucubrassem": "elucubrar",
    "elucubrasses": "elucubrar",
    "elucubraste": "elucubrar",
    "elucubrastes": "elucubrar",
    "elucubrava": "elucubrar",
    "elucubravam": "elucubrar",
    "elucubravas": "elucubrar",
    "elucubrações": "elucubração",
    "elucubre": "elucubrar",
    "elucubrei": "elucubrar",
    "elucubreis": "elucubrar",
    "elucubrem": "elucubrar",
    "elucubremo": "elucubrar",
    "elucubremos": "elucubrar",
    "elucubres": "elucubrar",
    "elucubro": "elucubrar",
    "elucubrou": "elucubrar",
    "elucubrá": "elucubrar",
    "elucubrámo": "elucubrar",
    "elucubrámos": "elucubrar",
    "elucubráramo": "elucubrar",
    "elucubráramos": "elucubrar",
    "elucubrárei": "elucubrar",
    "elucubráreis": "elucubrar",
    "elucubrásseis": "elucubrar",
    "elucubrássemos": "elucubrar",
    "elucubrávamo": "elucubrar",
    "elucubrávamos": "elucubrar",
    "elucubrávei": "elucubrar",
    "elucubráveis": "elucubrar",
    "eluda": "eludir",
    "eludais": "eludir",
    "eludam": "eludir",
    "eludamo": "eludir",
    "eludamos": "eludir",
    "eludas": "eludir",
    "elude": "eludir",
    "eludem": "eludir",
    "eludes": "eludir",
    "eludi": "eludir",
    "eludia": "eludir",
    "eludiam": "eludir",
    "eludias": "eludir",
    "eludida": "eludir",
    "eludidas": "eludir",
    "eludido": "eludir",
    "eludidos": "eludir",
    "eludimo": "eludir",
    "eludimos": "eludir",
    "eludindo": "eludir",
    "eludira": "eludir",
    "eludiram": "eludir",
    "eludiras": "eludir",
    "eludirde": "eludir",
    "eludirdes": "eludir",
    "eludire": "eludir",
    "eludirei": "eludir",
    "eludireis": "eludir",
    "eludirem": "eludir",
    "eludiremos": "eludir",
    "eludires": "eludir",
    "eludiria": "eludir",
    "eludiriam": "eludir",
    "eludirias": "eludir",
    "eludirmo": "eludir",
    "eludirmos": "eludir",
    "eludirá": "eludir",
    "eludirás": "eludir",
    "eludirão": "eludir",
    "eludiríamos": "eludir",
    "eludiríeis": "eludir",
    "eludis": "eludir",
    "eludisse": "eludir",
    "eludissem": "eludir",
    "eludisses": "eludir",
    "eludiste": "eludir",
    "eludistes": "eludir",
    "eludiu": "eludir",
    "eludo": "eludir",
    "eludíamo": "eludir",
    "eludíamos": "eludir",
    "eludíei": "eludir",
    "eludíeis": "eludir",
    "eludíramo": "eludir",
    "eludíramos": "eludir",
    "eludírei": "eludir",
    "eludíreis": "eludir",
    "eludísseis": "eludir",
    "eludíssemos": "eludir",
    "elutriações": "elutriação",
    "eluviais": "eluvial",
    "eluviões": "eluvião",
    "elvenses": "elvense",
    "elzevires": "elzevir",
    "elzeviriana": "elzeviriano",
    "elzevirianas": "elzeviriano",
    "elzevirianos": "elzeviriano",
    "elástica": "elástico",
    "elásticas": "elástico",
    "elásticos": "elástico",
    "eléctrica": "eléctrico",
    "eléctricas": "eléctrico",
    "eléctricos": "eléctrico",
    "eléctrodos": "eléctrodo",
    "eléctrons": "eléctron",
    "elícita": "elícito",
    "elícitas": "elícito",
    "elícitos": "elícito",
    "elíptica": "elíptico",
    "elípticas": "elíptico",
    "elípticos": "elíptico",
    "elísia": "elísio",
    "elísias": "elísio",
    "elísios": "elísio",
    "elóquios": "elóquio",
    "emace": "emaçar",
    "emacei": "emaçar",
    "emaceis": "emaçar",
    "emacem": "emaçar",
    "emacemo": "emaçar",
    "emacemos": "emaçar",
    "emaces": "emaçar",
    "emacia": "emaciar",
    "emaciada": "emaciar",
    "emaciadas": "emaciar",
    "emaciado": "emaciar",
    "emaciados": "emaciar",
    "emaciai": "emaciar",
    "emaciais": "emaciar",
    "emaciam": "emaciar",
    "emaciamo": "emaciar",
    "emaciamos": "emaciar",
    "emaciando": "emaciar",
    "emaciara": "emaciar",
    "emaciaram": "emaciar",
    "emaciaras": "emaciar",
    "emaciarde": "emaciar",
    "emaciardes": "emaciar",
    "emaciare": "emaciar",
    "emaciarei": "emaciar",
    "emaciareis": "emaciar",
    "emaciarem": "emaciar",
    "emaciaremos": "emaciar",
    "emaciares": "emaciar",
    "emaciaria": "emaciar",
    "emaciariam": "emaciar",
    "emaciarias": "emaciar",
    "emaciarmo": "emaciar",
    "emaciarmos": "emaciar",
    "emaciará": "emaciar",
    "emaciarás": "emaciar",
    "emaciarão": "emaciar",
    "emaciaríamos": "emaciar",
    "emaciaríeis": "emaciar",
    "emacias": "emaciar",
    "emaciasse": "emaciar",
    "emaciassem": "emaciar",
    "emaciasses": "emaciar",
    "emaciaste": "emaciar",
    "emaciastes": "emaciar",
    "emaciava": "emaciar",
    "emaciavam": "emaciar",
    "emaciavas": "emaciar",
    "emaciações": "emaciação",
    "emacie": "emaciar",
    "emaciei": "emaciar",
    "emacieis": "emaciar",
    "emaciem": "emaciar",
    "emaciemo": "emaciar",
    "emaciemos": "emaciar",
    "emacies": "emaciar",
    "emacio": "emaciar",
    "emaciou": "emaciar",
    "emaciá": "emaciar",
    "emaciámo": "emaciar",
    "emaciámos": "emaciar",
    "emaciáramo": "emaciar",
    "emaciáramos": "emaciar",
    "emaciárei": "emaciar",
    "emaciáreis": "emaciar",
    "emaciásseis": "emaciar",
    "emaciássemos": "emaciar",
    "emaciávamo": "emaciar",
    "emaciávamos": "emaciar",
    "emaciávei": "emaciar",
    "emaciáveis": "emaciar",
    "emadeira": "emadeirar",
    "emadeirada": "emadeirar",
    "emadeiradas": "emadeirar",
    "emadeirado": "emadeirar",
    "emadeirados": "emadeirar",
    "emadeirai": "emadeirar",
    "emadeirais": "emadeirar",
    "emadeiram": "emadeirar",
    "emadeiramentos": "emadeiramento",
    "emadeiramo": "emadeirar",
    "emadeiramos": "emadeirar",
    "emadeirando": "emadeirar",
    "emadeirara": "emadeirar",
    "emadeiraram": "emadeirar",
    "emadeiraras": "emadeirar",
    "emadeirarde": "emadeirar",
    "emadeirardes": "emadeirar",
    "emadeirare": "emadeirar",
    "emadeirarei": "emadeirar",
    "emadeirareis": "emadeirar",
    "emadeirarem": "emadeirar",
    "emadeiraremos": "emadeirar",
    "emadeirares": "emadeirar",
    "emadeiraria": "emadeirar",
    "emadeirariam": "emadeirar",
    "emadeirarias": "emadeirar",
    "emadeirarmo": "emadeirar",
    "emadeirarmos": "emadeirar",
    "emadeirará": "emadeirar",
    "emadeirarás": "emadeirar",
    "emadeirarão": "emadeirar",
    "emadeiraríamos": "emadeirar",
    "emadeiraríeis": "emadeirar",
    "emadeiras": "emadeirar",
    "emadeirasse": "emadeirar",
    "emadeirassem": "emadeirar",
    "emadeirasses": "emadeirar",
    "emadeiraste": "emadeirar",
    "emadeirastes": "emadeirar",
    "emadeirava": "emadeirar",
    "emadeiravam": "emadeirar",
    "emadeiravas": "emadeirar",
    "emadeire": "emadeirar",
    "emadeirei": "emadeirar",
    "emadeireis": "emadeirar",
    "emadeirem": "emadeirar",
    "emadeiremo": "emadeirar",
    "emadeiremos": "emadeirar",
    "emadeires": "emadeirar",
    "emadeiro": "emadeirar",
    "emadeirou": "emadeirar",
    "emadeirá": "emadeirar",
    "emadeirámo": "emadeirar",
    "emadeirámos": "emadeirar",
    "emadeiráramo": "emadeirar",
    "emadeiráramos": "emadeirar",
    "emadeirárei": "emadeirar",
    "emadeiráreis": "emadeirar",
    "emadeirásseis": "emadeirar",
    "emadeirássemos": "emadeirar",
    "emadeirávamo": "emadeirar",
    "emadeirávamos": "emadeirar",
    "emadeirávei": "emadeirar",
    "emadeiráveis": "emadeirar",
    "emadeixa": "emadeixar",
    "emadeixada": "emadeixar",
    "emadeixadas": "emadeixar",
    "emadeixado": "emadeixar",
    "emadeixados": "emadeixar",
    "emadeixai": "emadeixar",
    "emadeixais": "emadeixar",
    "emadeixam": "emadeixar",
    "emadeixamo": "emadeixar",
    "emadeixamos": "emadeixar",
    "emadeixando": "emadeixar",
    "emadeixara": "emadeixar",
    "emadeixaram": "emadeixar",
    "emadeixaras": "emadeixar",
    "emadeixarde": "emadeixar",
    "emadeixardes": "emadeixar",
    "emadeixare": "emadeixar",
    "emadeixarei": "emadeixar",
    "emadeixareis": "emadeixar",
    "emadeixarem": "emadeixar",
    "emadeixaremos": "emadeixar",
    "emadeixares": "emadeixar",
    "emadeixaria": "emadeixar",
    "emadeixariam": "emadeixar",
    "emadeixarias": "emadeixar",
    "emadeixarmo": "emadeixar",
    "emadeixarmos": "emadeixar",
    "emadeixará": "emadeixar",
    "emadeixarás": "emadeixar",
    "emadeixarão": "emadeixar",
    "emadeixaríamos": "emadeixar",
    "emadeixaríeis": "emadeixar",
    "emadeixas": "emadeixar",
    "emadeixasse": "emadeixar",
    "emadeixassem": "emadeixar",
    "emadeixasses": "emadeixar",
    "emadeixaste": "emadeixar",
    "emadeixastes": "emadeixar",
    "emadeixava": "emadeixar",
    "emadeixavam": "emadeixar",
    "emadeixavas": "emadeixar",
    "emadeixe": "emadeixar",
    "emadeixei": "emadeixar",
    "emadeixeis": "emadeixar",
    "emadeixem": "emadeixar",
    "emadeixemo": "emadeixar",
    "emadeixemos": "emadeixar",
    "emadeixes": "emadeixar",
    "emadeixo": "emadeixar",
    "emadeixou": "emadeixar",
    "emadeixá": "emadeixar",
    "emadeixámo": "emadeixar",
    "emadeixámos": "emadeixar",
    "emadeixáramo": "emadeixar",
    "emadeixáramos": "emadeixar",
    "emadeixárei": "emadeixar",
    "emadeixáreis": "emadeixar",
    "emadeixásseis": "emadeixar",
    "emadeixássemos": "emadeixar",
    "emadeixávamo": "emadeixar",
    "emadeixávamos": "emadeixar",
    "emadeixávei": "emadeixar",
    "emadeixáveis": "emadeixar",
    "emagrece": "emagrecer",
    "emagrecei": "emagrecer",
    "emagreceis": "emagrecer",
    "emagrecem": "emagrecer",
    "emagrecemo": "emagrecer",
    "emagrecemos": "emagrecer",
    "emagrecendo": "emagrecer",
    "emagrecera": "emagrecer",
    "emagreceram": "emagrecer",
    "emagreceras": "emagrecer",
    "emagrecerdes": "emagrecer",
    "emagrecerei": "emagrecer",
    "emagrecereis": "emagrecer",
    "emagrecerem": "emagrecer",
    "emagreceremos": "emagrecer",
    "emagreceres": "emagrecer",
    "emagreceria": "emagrecer",
    "emagreceriam": "emagrecer",
    "emagrecerias": "emagrecer",
    "emagrecermo": "emagrecer",
    "emagrecermos": "emagrecer",
    "emagrecerá": "emagrecer",
    "emagrecerás": "emagrecer",
    "emagrecerão": "emagrecer",
    "emagreceríamos": "emagrecer",
    "emagreceríeis": "emagrecer",
    "emagreces": "emagrecer",
    "emagrecesse": "emagrecer",
    "emagrecessem": "emagrecer",
    "emagrecesses": "emagrecer",
    "emagreceste": "emagrecer",
    "emagrecestes": "emagrecer",
    "emagreceu": "emagrecer",
    "emagreci": "emagrecer",
    "emagrecia": "emagrecer",
    "emagreciam": "emagrecer",
    "emagrecias": "emagrecer",
    "emagrecida": "emagrecer",
    "emagrecidas": "emagrecer",
    "emagrecido": "emagrecer",
    "emagrecidos": "emagrecer",
    "emagrecimentos": "emagrecimento",
    "emagrecêramo": "emagrecer",
    "emagrecêramos": "emagrecer",
    "emagrecêreis": "emagrecer",
    "emagrecêsseis": "emagrecer",
    "emagrecêssemos": "emagrecer",
    "emagrecíamo": "emagrecer",
    "emagrecíamos": "emagrecer",
    "emagrecíeis": "emagrecer",
    "emagreça": "emagrecer",
    "emagreçais": "emagrecer",
    "emagreçam": "emagrecer",
    "emagreçamo": "emagrecer",
    "emagreçamos": "emagrecer",
    "emagreças": "emagrecer",
    "emagreço": "emagrecer",
    "emails": "email",
    "emala": "emalar",
    "emalada": "emalar",
    "emaladas": "emalar",
    "emalado": "emalar",
    "emalados": "emalar",
    "emalai": "emalar",
    "emalais": "emalar",
    "emalam": "emalar",
    "emalamo": "emalar",
    "emalamos": "emalar",
    "emalando": "emalar",
    "emalara": "emalar",
    "emalaram": "emalar",
    "emalaras": "emalar",
    "emalarde": "emalar",
    "emalardes": "emalar",
    "emalare": "emalar",
    "emalarei": "emalar",
    "emalareis": "emalar",
    "emalarem": "emalar",
    "emalaremos": "emalar",
    "emalares": "emalar",
    "emalaria": "emalar",
    "emalariam": "emalar",
    "emalarias": "emalar",
    "emalarmo": "emalar",
    "emalarmos": "emalar",
    "emalará": "emalar",
    "emalarás": "emalar",
    "emalarão": "emalar",
    "emalaríamos": "emalar",
    "emalaríeis": "emalar",
    "emalas": "emalar",
    "emalasse": "emalar",
    "emalassem": "emalar",
    "emalasses": "emalar",
    "emalaste": "emalar",
    "emalastes": "emalar",
    "emalava": "emalar",
    "emalavam": "emalar",
    "emalavas": "emalar",
    "emale": "emalar",
    "emalei": "emalar",
    "emaleis": "emalar",
    "emalem": "emalar",
    "emalemo": "emalar",
    "emalemos": "emalar",
    "emales": "emalar",
    "emalha": "emalhar",
    "emalhada": "emalhar",
    "emalhadas": "emalhar",
    "emalhado": "emalhar",
    "emalhados": "emalhar",
    "emalhai": "emalhar",
    "emalhais": "emalhar",
    "emalham": "emalhar",
    "emalhamo": "emalhar",
    "emalhamos": "emalhar",
    "emalhando": "emalhar",
    "emalhara": "emalhar",
    "emalharam": "emalhar",
    "emalharas": "emalhar",
    "emalharde": "emalhar",
    "emalhardes": "emalhar",
    "emalhare": "emalhar",
    "emalharei": "emalhar",
    "emalhareis": "emalhar",
    "emalharem": "emalhar",
    "emalharemos": "emalhar",
    "emalhares": "emalhar",
    "emalharia": "emalhar",
    "emalhariam": "emalhar",
    "emalharias": "emalhar",
    "emalharmo": "emalhar",
    "emalharmos": "emalhar",
    "emalhará": "emalhar",
    "emalharás": "emalhar",
    "emalharão": "emalhar",
    "emalharíamos": "emalhar",
    "emalharíeis": "emalhar",
    "emalhas": "emalhar",
    "emalhasse": "emalhar",
    "emalhassem": "emalhar",
    "emalhasses": "emalhar",
    "emalhaste": "emalhar",
    "emalhastes": "emalhar",
    "emalhava": "emalhar",
    "emalhavam": "emalhar",
    "emalhavas": "emalhar",
    "emalhe": "emalhar",
    "emalhei": "emalhar",
    "emalheis": "emalhar",
    "emalhem": "emalhar",
    "emalhemo": "emalhar",
    "emalhemos": "emalhar",
    "emalhes": "emalhar",
    "emalheta": "emalhetar",
    "emalhetada": "emalhetar",
    "emalhetadas": "emalhetar",
    "emalhetado": "emalhetar",
    "emalhetados": "emalhetar",
    "emalhetai": "emalhetar",
    "emalhetais": "emalhetar",
    "emalhetam": "emalhetar",
    "emalhetamo": "emalhetar",
    "emalhetamos": "emalhetar",
    "emalhetando": "emalhetar",
    "emalhetara": "emalhetar",
    "emalhetaram": "emalhetar",
    "emalhetaras": "emalhetar",
    "emalhetarde": "emalhetar",
    "emalhetardes": "emalhetar",
    "emalhetare": "emalhetar",
    "emalhetarei": "emalhetar",
    "emalhetareis": "emalhetar",
    "emalhetarem": "emalhetar",
    "emalhetaremos": "emalhetar",
    "emalhetares": "emalhetar",
    "emalhetaria": "emalhetar",
    "emalhetariam": "emalhetar",
    "emalhetarias": "emalhetar",
    "emalhetarmo": "emalhetar",
    "emalhetarmos": "emalhetar",
    "emalhetará": "emalhetar",
    "emalhetarás": "emalhetar",
    "emalhetarão": "emalhetar",
    "emalhetaríamos": "emalhetar",
    "emalhetaríeis": "emalhetar",
    "emalhetas": "emalhetar",
    "emalhetasse": "emalhetar",
    "emalhetassem": "emalhetar",
    "emalhetasses": "emalhetar",
    "emalhetaste": "emalhetar",
    "emalhetastes": "emalhetar",
    "emalhetava": "emalhetar",
    "emalhetavam": "emalhetar",
    "emalhetavas": "emalhetar",
    "emalhete": "emalhetar",
    "emalhetei": "emalhetar",
    "emalheteis": "emalhetar",
    "emalhetem": "emalhetar",
    "emalhetemo": "emalhetar",
    "emalhetemos": "emalhetar",
    "emalhetes": "emalhetar",
    "emalheto": "emalhetar",
    "emalhetou": "emalhetar",
    "emalhetá": "emalhetar",
    "emalhetámo": "emalhetar",
    "emalhetámos": "emalhetar",
    "emalhetáramo": "emalhetar",
    "emalhetáramos": "emalhetar",
    "emalhetárei": "emalhetar",
    "emalhetáreis": "emalhetar",
    "emalhetásseis": "emalhetar",
    "emalhetássemos": "emalhetar",
    "emalhetávamo": "emalhetar",
    "emalhetávamos": "emalhetar",
    "emalhetávei": "emalhetar",
    "emalhetáveis": "emalhetar",
    "emalho": "emalhar",
    "emalhou": "emalhar",
    "emalhá": "emalhar",
    "emalhámo": "emalhar",
    "emalhámos": "emalhar",
    "emalháramo": "emalhar",
    "emalháramos": "emalhar",
    "emalhárei": "emalhar",
    "emalháreis": "emalhar",
    "emalhásseis": "emalhar",
    "emalhássemos": "emalhar",
    "emalhávamo": "emalhar",
    "emalhávamos": "emalhar",
    "emalhávei": "emalhar",
    "emalháveis": "emalhar",
    "emalo": "emalar",
    "emalou": "emalar",
    "emalá": "emalar",
    "emalámo": "emalar",
    "emalámos": "emalar",
    "emaláramo": "emalar",
    "emaláramos": "emalar",
    "emalárei": "emalar",
    "emaláreis": "emalar",
    "emalásseis": "emalar",
    "emalássemos": "emalar",
    "emalávamo": "emalar",
    "emalávamos": "emalar",
    "emalávei": "emalar",
    "emaláveis": "emalar",
    "emana": "emanar",
    "emanada": "emanar",
    "emanadas": "emanar",
    "emanado": "emanar",
    "emanados": "emanar",
    "emanai": "emanar",
    "emanais": "emanar",
    "emanam": "emanar",
    "emanamo": "emanar",
    "emanamos": "emanar",
    "emanando": "emanar",
    "emanantes": "emanante",
    "emanara": "emanar",
    "emanaram": "emanar",
    "emanaras": "emanar",
    "emanarde": "emanar",
    "emanardes": "emanar",
    "emanare": "emanar",
    "emanarei": "emanar",
    "emanareis": "emanar",
    "emanarem": "emanar",
    "emanaremos": "emanar",
    "emanares": "emanar",
    "emanaria": "emanar",
    "emanariam": "emanar",
    "emanarias": "emanar",
    "emanarmo": "emanar",
    "emanarmos": "emanar",
    "emanará": "emanar",
    "emanarás": "emanar",
    "emanarão": "emanar",
    "emanaríamos": "emanar",
    "emanaríeis": "emanar",
    "emanas": "emanar",
    "emanasse": "emanar",
    "emanassem": "emanar",
    "emanasses": "emanar",
    "emanaste": "emanar",
    "emanastes": "emanar",
    "emanatismos": "emanatismo",
    "emanava": "emanar",
    "emanavam": "emanar",
    "emanavas": "emanar",
    "emanações": "emanação",
    "emancipa": "emancipar",
    "emancipada": "emancipar",
    "emancipadas": "emancipar",
    "emancipado": "emancipar",
    "emancipadora": "emancipador",
    "emancipadoras": "emancipador",
    "emancipadores": "emancipador",
    "emancipados": "emancipar",
    "emancipai": "emancipar",
    "emancipais": "emancipar",
    "emancipam": "emancipar",
    "emancipamo": "emancipar",
    "emancipamos": "emancipar",
    "emancipando": "emancipar",
    "emancipara": "emancipar",
    "emanciparam": "emancipar",
    "emanciparas": "emancipar",
    "emanciparde": "emancipar",
    "emancipardes": "emancipar",
    "emancipare": "emancipar",
    "emanciparei": "emancipar",
    "emancipareis": "emancipar",
    "emanciparem": "emancipar",
    "emanciparemos": "emancipar",
    "emancipares": "emancipar",
    "emanciparia": "emancipar",
    "emancipariam": "emancipar",
    "emanciparias": "emancipar",
    "emanciparmo": "emancipar",
    "emanciparmos": "emancipar",
    "emancipará": "emancipar",
    "emanciparás": "emancipar",
    "emanciparão": "emancipar",
    "emanciparíamos": "emancipar",
    "emanciparíeis": "emancipar",
    "emancipas": "emancipar",
    "emancipasse": "emancipar",
    "emancipassem": "emancipar",
    "emancipasses": "emancipar",
    "emancipaste": "emancipar",
    "emancipastes": "emancipar",
    "emancipatória": "emancipatório",
    "emancipatórias": "emancipatório",
    "emancipatórios": "emancipatório",
    "emancipava": "emancipar",
    "emancipavam": "emancipar",
    "emancipavas": "emancipar",
    "emancipações": "emancipação",
    "emancipe": "emancipar",
    "emancipei": "emancipar",
    "emancipeis": "emancipar",
    "emancipem": "emancipar",
    "emancipemo": "emancipar",
    "emancipemos": "emancipar",
    "emancipes": "emancipar",
    "emancipo": "emancipar",
    "emancipou": "emancipar",
    "emancipá": "emancipar",
    "emancipámo": "emancipar",
    "emancipámos": "emancipar",
    "emancipáramo": "emancipar",
    "emancipáramos": "emancipar",
    "emancipárei": "emancipar",
    "emancipáreis": "emancipar",
    "emancipásseis": "emancipar",
    "emancipássemos": "emancipar",
    "emancipávamo": "emancipar",
    "emancipávamos": "emancipar",
    "emancipávei": "emancipar",
    "emancipáveis": "emancipar",
    "emane": "emanar",
    "emanei": "emanar",
    "emaneis": "emanar",
    "emanem": "emanar",
    "emanemo": "emanar",
    "emanemos": "emanar",
    "emanes": "emanar",
    "emano": "emanar",
    "emanou": "emanar",
    "emanquece": "emanquecer",
    "emanquecei": "emanquecer",
    "emanqueceis": "emanquecer",
    "emanquecem": "emanquecer",
    "emanquecemo": "emanquecer",
    "emanquecemos": "emanquecer",
    "emanquecendo": "emanquecer",
    "emanquecera": "emanquecer",
    "emanqueceram": "emanquecer",
    "emanqueceras": "emanquecer",
    "emanquecerdes": "emanquecer",
    "emanquecerei": "emanquecer",
    "emanquecereis": "emanquecer",
    "emanquecerem": "emanquecer",
    "emanqueceremos": "emanquecer",
    "emanqueceres": "emanquecer",
    "emanqueceria": "emanquecer",
    "emanqueceriam": "emanquecer",
    "emanquecerias": "emanquecer",
    "emanquecermo": "emanquecer",
    "emanquecermos": "emanquecer",
    "emanquecerá": "emanquecer",
    "emanquecerás": "emanquecer",
    "emanquecerão": "emanquecer",
    "emanqueceríamos": "emanquecer",
    "emanqueceríeis": "emanquecer",
    "emanqueces": "emanquecer",
    "emanquecesse": "emanquecer",
    "emanquecessem": "emanquecer",
    "emanquecesses": "emanquecer",
    "emanqueceste": "emanquecer",
    "emanquecestes": "emanquecer",
    "emanqueceu": "emanquecer",
    "emanqueci": "emanquecer",
    "emanquecia": "emanquecer",
    "emanqueciam": "emanquecer",
    "emanquecias": "emanquecer",
    "emanquecida": "emanquecer",
    "emanquecidas": "emanquecer",
    "emanquecido": "emanquecer",
    "emanquecidos": "emanquecer",
    "emanquecêramo": "emanquecer",
    "emanquecêramos": "emanquecer",
    "emanquecêreis": "emanquecer",
    "emanquecêsseis": "emanquecer",
    "emanquecêssemos": "emanquecer",
    "emanquecíamo": "emanquecer",
    "emanquecíamos": "emanquecer",
    "emanquecíeis": "emanquecer",
    "emanqueça": "emanquecer",
    "emanqueçais": "emanquecer",
    "emanqueçam": "emanquecer",
    "emanqueçamo": "emanquecer",
    "emanqueçamos": "emanquecer",
    "emanqueças": "emanquecer",
    "emanqueço": "emanquecer",
    "emantilha": "emantilhar",
    "emantilhada": "emantilhar",
    "emantilhadas": "emantilhar",
    "emantilhado": "emantilhar",
    "emantilhados": "emantilhar",
    "emantilhai": "emantilhar",
    "emantilhais": "emantilhar",
    "emantilham": "emantilhar",
    "emantilhamo": "emantilhar",
    "emantilhamos": "emantilhar",
    "emantilhando": "emantilhar",
    "emantilhara": "emantilhar",
    "emantilharam": "emantilhar",
    "emantilharas": "emantilhar",
    "emantilharde": "emantilhar",
    "emantilhardes": "emantilhar",
    "emantilhare": "emantilhar",
    "emantilharei": "emantilhar",
    "emantilhareis": "emantilhar",
    "emantilharem": "emantilhar",
    "emantilharemos": "emantilhar",
    "emantilhares": "emantilhar",
    "emantilharia": "emantilhar",
    "emantilhariam": "emantilhar",
    "emantilharias": "emantilhar",
    "emantilharmo": "emantilhar",
    "emantilharmos": "emantilhar",
    "emantilhará": "emantilhar",
    "emantilharás": "emantilhar",
    "emantilharão": "emantilhar",
    "emantilharíamos": "emantilhar",
    "emantilharíeis": "emantilhar",
    "emantilhas": "emantilhar",
    "emantilhasse": "emantilhar",
    "emantilhassem": "emantilhar",
    "emantilhasses": "emantilhar",
    "emantilhaste": "emantilhar",
    "emantilhastes": "emantilhar",
    "emantilhava": "emantilhar",
    "emantilhavam": "emantilhar",
    "emantilhavas": "emantilhar",
    "emantilhe": "emantilhar",
    "emantilhei": "emantilhar",
    "emantilheis": "emantilhar",
    "emantilhem": "emantilhar",
    "emantilhemo": "emantilhar",
    "emantilhemos": "emantilhar",
    "emantilhes": "emantilhar",
    "emantilho": "emantilhar",
    "emantilhou": "emantilhar",
    "emantilhá": "emantilhar",
    "emantilhámo": "emantilhar",
    "emantilhámos": "emantilhar",
    "emantilháramo": "emantilhar",
    "emantilháramos": "emantilhar",
    "emantilhárei": "emantilhar",
    "emantilháreis": "emantilhar",
    "emantilhásseis": "emantilhar",
    "emantilhássemos": "emantilhar",
    "emantilhávamo": "emantilhar",
    "emantilhávamos": "emantilhar",
    "emantilhávei": "emantilhar",
    "emantilháveis": "emantilhar",
    "emaná": "emanar",
    "emanámo": "emanar",
    "emanámos": "emanar",
    "emanáramo": "emanar",
    "emanáramos": "emanar",
    "emanárei": "emanar",
    "emanáreis": "emanar",
    "emanásseis": "emanar",
    "emanássemos": "emanar",
    "emanávamo": "emanar",
    "emanávamos": "emanar",
    "emanávei": "emanar",
    "emanáveis": "emanar",
    "emaranha": "emaranhar",
    "emaranhada": "emaranhar",
    "emaranhadas": "emaranhar",
    "emaranhado": "emaranhar",
    "emaranhados": "emaranhar",
    "emaranhai": "emaranhar",
    "emaranhais": "emaranhar",
    "emaranham": "emaranhar",
    "emaranhamo": "emaranhar",
    "emaranhamos": "emaranhar",
    "emaranhando": "emaranhar",
    "emaranhara": "emaranhar",
    "emaranharam": "emaranhar",
    "emaranharas": "emaranhar",
    "emaranharde": "emaranhar",
    "emaranhardes": "emaranhar",
    "emaranhare": "emaranhar",
    "emaranharei": "emaranhar",
    "emaranhareis": "emaranhar",
    "emaranharem": "emaranhar",
    "emaranharemos": "emaranhar",
    "emaranhares": "emaranhar",
    "emaranharia": "emaranhar",
    "emaranhariam": "emaranhar",
    "emaranharias": "emaranhar",
    "emaranharmo": "emaranhar",
    "emaranharmos": "emaranhar",
    "emaranhará": "emaranhar",
    "emaranharás": "emaranhar",
    "emaranharão": "emaranhar",
    "emaranharíamos": "emaranhar",
    "emaranharíeis": "emaranhar",
    "emaranhas": "emaranhar",
    "emaranhasse": "emaranhar",
    "emaranhassem": "emaranhar",
    "emaranhasses": "emaranhar",
    "emaranhaste": "emaranhar",
    "emaranhastes": "emaranhar",
    "emaranhava": "emaranhar",
    "emaranhavam": "emaranhar",
    "emaranhavas": "emaranhar",
    "emaranhe": "emaranhar",
    "emaranhei": "emaranhar",
    "emaranheis": "emaranhar",
    "emaranhem": "emaranhar",
    "emaranhemo": "emaranhar",
    "emaranhemos": "emaranhar",
    "emaranhes": "emaranhar",
    "emaranho": "emaranhar",
    "emaranhou": "emaranhar",
    "emaranhá": "emaranhar",
    "emaranhámo": "emaranhar",
    "emaranhámos": "emaranhar",
    "emaranháramo": "emaranhar",
    "emaranháramos": "emaranhar",
    "emaranhárei": "emaranhar",
    "emaranháreis": "emaranhar",
    "emaranhásseis": "emaranhar",
    "emaranhássemos": "emaranhar",
    "emaranhávamo": "emaranhar",
    "emaranhávamos": "emaranhar",
    "emaranhávei": "emaranhar",
    "emaranháveis": "emaranhar",
    "emareada": "emarear",
    "emareadas": "emarear",
    "emareado": "emarear",
    "emareados": "emarear",
    "emareai": "emarear",
    "emareais": "emarear",
    "emareamo": "emarear",
    "emareamos": "emarear",
    "emareando": "emarear",
    "emareara": "emarear",
    "emarearam": "emarear",
    "emarearas": "emarear",
    "emareardes": "emarear",
    "emarearei": "emarear",
    "emareareis": "emarear",
    "emarearem": "emarear",
    "emarearemos": "emarear",
    "emareares": "emarear",
    "emarearia": "emarear",
    "emareariam": "emarear",
    "emarearias": "emarear",
    "emarearmo": "emarear",
    "emarearmos": "emarear",
    "emareará": "emarear",
    "emarearás": "emarear",
    "emarearão": "emarear",
    "emarearíamos": "emarear",
    "emarearíeis": "emarear",
    "emareasse": "emarear",
    "emareassem": "emarear",
    "emareasses": "emarear",
    "emareaste": "emarear",
    "emareastes": "emarear",
    "emareava": "emarear",
    "emareavam": "emarear",
    "emareavas": "emarear",
    "emareei": "emarear",
    "emareeis": "emarear",
    "emareemo": "emarear",
    "emareemos": "emarear",
    "emareia": "emarear",
    "emareiam": "emarear",
    "emareias": "emarear",
    "emareie": "emarear",
    "emareiem": "emarear",
    "emareies": "emarear",
    "emareio": "emarear",
    "emarelece": "emarelecer",
    "emarelecei": "emarelecer",
    "emareleceis": "emarelecer",
    "emarelecem": "emarelecer",
    "emarelecemo": "emarelecer",
    "emarelecemos": "emarelecer",
    "emarelecendo": "emarelecer",
    "emarelecera": "emarelecer",
    "emareleceram": "emarelecer",
    "emareleceras": "emarelecer",
    "emarelecerde": "emarelecer",
    "emarelecerdes": "emarelecer",
    "emarelecere": "emarelecer",
    "emarelecerei": "emarelecer",
    "emarelecereis": "emarelecer",
    "emarelecerem": "emarelecer",
    "emareleceremos": "emarelecer",
    "emareleceres": "emarelecer",
    "emareleceria": "emarelecer",
    "emareleceriam": "emarelecer",
    "emarelecerias": "emarelecer",
    "emarelecermo": "emarelecer",
    "emarelecermos": "emarelecer",
    "emarelecerá": "emarelecer",
    "emarelecerás": "emarelecer",
    "emarelecerão": "emarelecer",
    "emareleceríamos": "emarelecer",
    "emareleceríeis": "emarelecer",
    "emareleces": "emarelecer",
    "emarelecesse": "emarelecer",
    "emarelecessem": "emarelecer",
    "emarelecesses": "emarelecer",
    "emareleceste": "emarelecer",
    "emarelecestes": "emarelecer",
    "emareleceu": "emarelecer",
    "emareleci": "emarelecer",
    "emarelecia": "emarelecer",
    "emareleciam": "emarelecer",
    "emarelecias": "emarelecer",
    "emarelecida": "emarelecer",
    "emarelecidas": "emarelecer",
    "emarelecido": "emarelecer",
    "emarelecidos": "emarelecer",
    "emarelecê": "emarelecer",
    "emarelecêramo": "emarelecer",
    "emarelecêramos": "emarelecer",
    "emarelecêrei": "emarelecer",
    "emarelecêreis": "emarelecer",
    "emarelecêsseis": "emarelecer",
    "emarelecêssemos": "emarelecer",
    "emarelecíamo": "emarelecer",
    "emarelecíamos": "emarelecer",
    "emarelecíei": "emarelecer",
    "emarelecíeis": "emarelecer",
    "emareleça": "emarelecer",
    "emareleçais": "emarelecer",
    "emareleçam": "emarelecer",
    "emareleçamo": "emarelecer",
    "emareleçamos": "emarelecer",
    "emareleças": "emarelecer",
    "emareleço": "emarelecer",
    "emareou": "emarear",
    "emareámo": "emarear",
    "emareámos": "emarear",
    "emareáramo": "emarear",
    "emareáramos": "emarear",
    "emareáreis": "emarear",
    "emareásseis": "emarear",
    "emareássemos": "emarear",
    "emareávamo": "emarear",
    "emareávamos": "emarear",
    "emareáveis": "emarear",
    "emas": "ema",
    "emascula": "emascular",
    "emasculada": "emascular",
    "emasculadas": "emascular",
    "emasculado": "emascular",
    "emasculados": "emascular",
    "emasculai": "emascular",
    "emasculais": "emascular",
    "emasculam": "emascular",
    "emasculamo": "emascular",
    "emasculamos": "emascular",
    "emasculando": "emascular",
    "emasculara": "emascular",
    "emascularam": "emascular",
    "emascularas": "emascular",
    "emascularde": "emascular",
    "emasculardes": "emascular",
    "emasculare": "emascular",
    "emascularei": "emascular",
    "emasculareis": "emascular",
    "emascularem": "emascular",
    "emascularemos": "emascular",
    "emasculares": "emascular",
    "emascularia": "emascular",
    "emasculariam": "emascular",
    "emascularias": "emascular",
    "emascularmo": "emascular",
    "emascularmos": "emascular",
    "emasculará": "emascular",
    "emascularás": "emascular",
    "emascularão": "emascular",
    "emascularíamos": "emascular",
    "emascularíeis": "emascular",
    "emasculas": "emascular",
    "emasculasse": "emascular",
    "emasculassem": "emascular",
    "emasculasses": "emascular",
    "emasculaste": "emascular",
    "emasculastes": "emascular",
    "emasculava": "emascular",
    "emasculavam": "emascular",
    "emasculavas": "emascular",
    "emasculações": "emasculação",
    "emascule": "emascular",
    "emasculei": "emascular",
    "emasculeis": "emascular",
    "emasculem": "emascular",
    "emasculemo": "emascular",
    "emasculemos": "emascular",
    "emascules": "emascular",
    "emasculo": "emascular",
    "emasculou": "emascular",
    "emasculá": "emascular",
    "emasculámo": "emascular",
    "emasculámos": "emascular",
    "emasculáramo": "emascular",
    "emasculáramos": "emascular",
    "emasculárei": "emascular",
    "emasculáreis": "emascular",
    "emasculásseis": "emascular",
    "emasculássemos": "emascular",
    "emasculávamo": "emascular",
    "emasculávamos": "emascular",
    "emasculávei": "emascular",
    "emasculáveis": "emascular",
    "emassa": "emassar",
    "emassada": "emassar",
    "emassadas": "emassar",
    "emassado": "emassar",
    "emassados": "emassar",
    "emassai": "emassar",
    "emassais": "emassar",
    "emassam": "emassar",
    "emassamo": "emassar",
    "emassamos": "emassar",
    "emassando": "emassar",
    "emassara": "emassar",
    "emassaram": "emassar",
    "emassaras": "emassar",
    "emassardes": "emassar",
    "emassarei": "emassar",
    "emassareis": "emassar",
    "emassarem": "emassar",
    "emassaremos": "emassar",
    "emassares": "emassar",
    "emassaria": "emassar",
    "emassariam": "emassar",
    "emassarias": "emassar",
    "emassarmo": "emassar",
    "emassarmos": "emassar",
    "emassará": "emassar",
    "emassarás": "emassar",
    "emassarão": "emassar",
    "emassaríamos": "emassar",
    "emassaríeis": "emassar",
    "emassas": "emassar",
    "emassasse": "emassar",
    "emassassem": "emassar",
    "emassasses": "emassar",
    "emassaste": "emassar",
    "emassastes": "emassar",
    "emassava": "emassar",
    "emassavam": "emassar",
    "emassavas": "emassar",
    "emasse": "emassar",
    "emassei": "emassar",
    "emasseis": "emassar",
    "emassem": "emassar",
    "emassemo": "emassar",
    "emassemos": "emassar",
    "emasses": "emassar",
    "emasso": "emassar",
    "emassou": "emassar",
    "emassámo": "emassar",
    "emassámos": "emassar",
    "emassáramo": "emassar",
    "emassáramos": "emassar",
    "emassáreis": "emassar",
    "emassásseis": "emassar",
    "emassássemos": "emassar",
    "emassávamo": "emassar",
    "emassávamos": "emassar",
    "emassáveis": "emassar",
    "emastra": "emastrar",
    "emastrada": "emastrar",
    "emastradas": "emastrar",
    "emastrado": "emastrar",
    "emastrados": "emastrar",
    "emastrai": "emastrar",
    "emastrais": "emastrar",
    "emastram": "emastrar",
    "emastramo": "emastrar",
    "emastramos": "emastrar",
    "emastrando": "emastrar",
    "emastrara": "emastrar",
    "emastraram": "emastrar",
    "emastraras": "emastrar",
    "emastrarde": "emastrar",
    "emastrardes": "emastrar",
    "emastrare": "emastrar",
    "emastrarei": "emastrar",
    "emastrareis": "emastrar",
    "emastrarem": "emastrar",
    "emastraremos": "emastrar",
    "emastrares": "emastrar",
    "emastraria": "emastrar",
    "emastrariam": "emastrar",
    "emastrarias": "emastrar",
    "emastrarmo": "emastrar",
    "emastrarmos": "emastrar",
    "emastrará": "emastrar",
    "emastrarás": "emastrar",
    "emastrarão": "emastrar",
    "emastraríamos": "emastrar",
    "emastraríeis": "emastrar",
    "emastras": "emastrar",
    "emastrasse": "emastrar",
    "emastrassem": "emastrar",
    "emastrasses": "emastrar",
    "emastraste": "emastrar",
    "emastrastes": "emastrar",
    "emastrava": "emastrar",
    "emastravam": "emastrar",
    "emastravas": "emastrar",
    "emastre": "emastrar",
    "emastreada": "emastrear",
    "emastreadas": "emastrear",
    "emastreado": "emastrear",
    "emastreados": "emastrear",
    "emastreai": "emastrear",
    "emastreais": "emastrear",
    "emastreamo": "emastrear",
    "emastreamos": "emastrear",
    "emastreando": "emastrear",
    "emastreara": "emastrear",
    "emastrearam": "emastrear",
    "emastrearas": "emastrear",
    "emastrearde": "emastrear",
    "emastreardes": "emastrear",
    "emastreare": "emastrear",
    "emastrearei": "emastrear",
    "emastreareis": "emastrear",
    "emastrearem": "emastrear",
    "emastrearemos": "emastrear",
    "emastreares": "emastrear",
    "emastrearia": "emastrear",
    "emastreariam": "emastrear",
    "emastrearias": "emastrear",
    "emastrearmo": "emastrear",
    "emastrearmos": "emastrear",
    "emastreará": "emastrear",
    "emastrearás": "emastrear",
    "emastrearão": "emastrear",
    "emastrearíamos": "emastrear",
    "emastrearíeis": "emastrear",
    "emastreasse": "emastrear",
    "emastreassem": "emastrear",
    "emastreasses": "emastrear",
    "emastreaste": "emastrear",
    "emastreastes": "emastrear",
    "emastreava": "emastrear",
    "emastreavam": "emastrear",
    "emastreavas": "emastrear",
    "emastreei": "emastrear",
    "emastreeis": "emastrear",
    "emastreemo": "emastrear",
    "emastreemos": "emastrear",
    "emastrei": "emastrar",
    "emastreia": "emastrear",
    "emastreiam": "emastrear",
    "emastreias": "emastrear",
    "emastreie": "emastrear",
    "emastreiem": "emastrear",
    "emastreies": "emastrear",
    "emastreio": "emastrear",
    "emastreis": "emastrar",
    "emastrem": "emastrar",
    "emastremo": "emastrar",
    "emastremos": "emastrar",
    "emastreou": "emastrear",
    "emastres": "emastrar",
    "emastreá": "emastrear",
    "emastreámo": "emastrear",
    "emastreámos": "emastrear",
    "emastreáramo": "emastrear",
    "emastreáramos": "emastrear",
    "emastreárei": "emastrear",
    "emastreáreis": "emastrear",
    "emastreásseis": "emastrear",
    "emastreássemos": "emastrear",
    "emastreávamo": "emastrear",
    "emastreávamos": "emastrear",
    "emastreávei": "emastrear",
    "emastreáveis": "emastrear",
    "emastro": "emastrar",
    "emastrou": "emastrar",
    "emastrá": "emastrar",
    "emastrámo": "emastrar",
    "emastrámos": "emastrar",
    "emastráramo": "emastrar",
    "emastráramos": "emastrar",
    "emastrárei": "emastrar",
    "emastráreis": "emastrar",
    "emastrásseis": "emastrar",
    "emastrássemos": "emastrar",
    "emastrávamo": "emastrar",
    "emastrávamos": "emastrar",
    "emastrávei": "emastrar",
    "emastráveis": "emastrar",
    "emaça": "emaçar",
    "emaçada": "emaçar",
    "emaçadas": "emaçar",
    "emaçado": "emaçar",
    "emaçados": "emaçar",
    "emaçai": "emaçar",
    "emaçais": "emaçar",
    "emaçam": "emaçar",
    "emaçamentos": "emaçamento",
    "emaçamo": "emaçar",
    "emaçamos": "emaçar",
    "emaçando": "emaçar",
    "emaçara": "emaçar",
    "emaçaram": "emaçar",
    "emaçaras": "emaçar",
    "emaçarde": "emaçar",
    "emaçardes": "emaçar",
    "emaçare": "emaçar",
    "emaçarei": "emaçar",
    "emaçareis": "emaçar",
    "emaçarem": "emaçar",
    "emaçaremos": "emaçar",
    "emaçares": "emaçar",
    "emaçaria": "emaçar",
    "emaçariam": "emaçar",
    "emaçarias": "emaçar",
    "emaçarmo": "emaçar",
    "emaçarmos": "emaçar",
    "emaçará": "emaçar",
    "emaçarás": "emaçar",
    "emaçarão": "emaçar",
    "emaçaríamos": "emaçar",
    "emaçaríeis": "emaçar",
    "emaças": "emaçar",
    "emaçasse": "emaçar",
    "emaçassem": "emaçar",
    "emaçasses": "emaçar",
    "emaçaste": "emaçar",
    "emaçastes": "emaçar",
    "emaçava": "emaçar",
    "emaçavam": "emaçar",
    "emaçavas": "emaçar",
    "emaço": "emaçar",
    "emaçou": "emaçar",
    "emaçá": "emaçar",
    "emaçámo": "emaçar",
    "emaçámos": "emaçar",
    "emaçáramo": "emaçar",
    "emaçáramos": "emaçar",
    "emaçárei": "emaçar",
    "emaçáreis": "emaçar",
    "emaçásseis": "emaçar",
    "emaçássemos": "emaçar",
    "emaçávamo": "emaçar",
    "emaçávamos": "emaçar",
    "emaçávei": "emaçar",
    "emaçáveis": "emaçar",
    "embace": "embaçar",
    "embacei": "embaçar",
    "embaceis": "embaçar",
    "embacela": "embacelar",
    "embacelada": "embacelar",
    "embaceladas": "embacelar",
    "embacelado": "embacelar",
    "embacelados": "embacelar",
    "embacelai": "embacelar",
    "embacelais": "embacelar",
    "embacelam": "embacelar",
    "embacelamo": "embacelar",
    "embacelamos": "embacelar",
    "embacelando": "embacelar",
    "embacelara": "embacelar",
    "embacelaram": "embacelar",
    "embacelaras": "embacelar",
    "embacelarde": "embacelar",
    "embacelardes": "embacelar",
    "embacelare": "embacelar",
    "embacelarei": "embacelar",
    "embacelareis": "embacelar",
    "embacelarem": "embacelar",
    "embacelaremos": "embacelar",
    "embacelares": "embacelar",
    "embacelaria": "embacelar",
    "embacelariam": "embacelar",
    "embacelarias": "embacelar",
    "embacelarmo": "embacelar",
    "embacelarmos": "embacelar",
    "embacelará": "embacelar",
    "embacelarás": "embacelar",
    "embacelarão": "embacelar",
    "embacelaríamos": "embacelar",
    "embacelaríeis": "embacelar",
    "embacelas": "embacelar",
    "embacelasse": "embacelar",
    "embacelassem": "embacelar",
    "embacelasses": "embacelar",
    "embacelaste": "embacelar",
    "embacelastes": "embacelar",
    "embacelava": "embacelar",
    "embacelavam": "embacelar",
    "embacelavas": "embacelar",
    "embacele": "embacelar",
    "embacelei": "embacelar",
    "embaceleis": "embacelar",
    "embacelem": "embacelar",
    "embacelemo": "embacelar",
    "embacelemos": "embacelar",
    "embaceles": "embacelar",
    "embacelo": "embacelar",
    "embacelou": "embacelar",
    "embacelá": "embacelar",
    "embacelámo": "embacelar",
    "embacelámos": "embacelar",
    "embaceláramo": "embacelar",
    "embaceláramos": "embacelar",
    "embacelárei": "embacelar",
    "embaceláreis": "embacelar",
    "embacelásseis": "embacelar",
    "embacelássemos": "embacelar",
    "embacelávamo": "embacelar",
    "embacelávamos": "embacelar",
    "embacelávei": "embacelar",
    "embaceláveis": "embacelar",
    "embacem": "embaçar",
    "embacemo": "embaçar",
    "embacemos": "embaçar",
    "embaces": "embaçar",
    "embacia": "embaciar",
    "embaciada": "embaciar",
    "embaciadas": "embaciar",
    "embaciado": "embaciar",
    "embaciados": "embaciar",
    "embaciai": "embaciar",
    "embaciais": "embaciar",
    "embaciam": "embaciar",
    "embaciamentos": "embaciamento",
    "embaciamo": "embaciar",
    "embaciamos": "embaciar",
    "embaciando": "embaciar",
    "embaciara": "embaciar",
    "embaciaram": "embaciar",
    "embaciaras": "embaciar",
    "embaciarde": "embaciar",
    "embaciardes": "embaciar",
    "embaciare": "embaciar",
    "embaciarei": "embaciar",
    "embaciareis": "embaciar",
    "embaciarem": "embaciar",
    "embaciaremos": "embaciar",
    "embaciares": "embaciar",
    "embaciaria": "embaciar",
    "embaciariam": "embaciar",
    "embaciarias": "embaciar",
    "embaciarmo": "embaciar",
    "embaciarmos": "embaciar",
    "embaciará": "embaciar",
    "embaciarás": "embaciar",
    "embaciarão": "embaciar",
    "embaciaríamos": "embaciar",
    "embaciaríeis": "embaciar",
    "embacias": "embaciar",
    "embaciasse": "embaciar",
    "embaciassem": "embaciar",
    "embaciasses": "embaciar",
    "embaciaste": "embaciar",
    "embaciastes": "embaciar",
    "embaciava": "embaciar",
    "embaciavam": "embaciar",
    "embaciavas": "embaciar",
    "embacie": "embaciar",
    "embaciei": "embaciar",
    "embacieis": "embaciar",
    "embaciem": "embaciar",
    "embaciemo": "embaciar",
    "embaciemos": "embaciar",
    "embacies": "embaciar",
    "embacio": "embaciar",
    "embaciou": "embaciar",
    "embaciá": "embaciar",
    "embaciámo": "embaciar",
    "embaciámos": "embaciar",
    "embaciáramo": "embaciar",
    "embaciáramos": "embaciar",
    "embaciárei": "embaciar",
    "embaciáreis": "embaciar",
    "embaciásseis": "embaciar",
    "embaciássemos": "embaciar",
    "embaciávamo": "embaciar",
    "embaciávamos": "embaciar",
    "embaciávei": "embaciar",
    "embaciáveis": "embaciável",
    "embaem": "embair",
    "embai": "embair",
    "embaia": "embair",
    "embaiadora": "embaiador",
    "embaiadoras": "embaiador",
    "embaiadores": "embaiador",
    "embaiais": "embair",
    "embaiam": "embair",
    "embaiamo": "embair",
    "embaiamos": "embair",
    "embaias": "embair",
    "embaidora": "embaidor",
    "embaidoras": "embaidor",
    "embaidores": "embaidor",
    "embaimentos": "embaimento",
    "embaindo": "embair",
    "embainha": "embainhar",
    "embainhada": "embainhar",
    "embainhadas": "embainhar",
    "embainhado": "embainhar",
    "embainhados": "embainhar",
    "embainhai": "embainhar",
    "embainhais": "embainhar",
    "embainham": "embainhar",
    "embainhamo": "embainhar",
    "embainhamos": "embainhar",
    "embainhando": "embainhar",
    "embainhara": "embainhar",
    "embainharam": "embainhar",
    "embainharas": "embainhar",
    "embainharde": "embainhar",
    "embainhardes": "embainhar",
    "embainhare": "embainhar",
    "embainharei": "embainhar",
    "embainhareis": "embainhar",
    "embainharem": "embainhar",
    "embainharemos": "embainhar",
    "embainhares": "embainhar",
    "embainharia": "embainhar",
    "embainhariam": "embainhar",
    "embainharias": "embainhar",
    "embainharmo": "embainhar",
    "embainharmos": "embainhar",
    "embainhará": "embainhar",
    "embainharás": "embainhar",
    "embainharão": "embainhar",
    "embainharíamos": "embainhar",
    "embainharíeis": "embainhar",
    "embainhas": "embainhar",
    "embainhasse": "embainhar",
    "embainhassem": "embainhar",
    "embainhasses": "embainhar",
    "embainhaste": "embainhar",
    "embainhastes": "embainhar",
    "embainhava": "embainhar",
    "embainhavam": "embainhar",
    "embainhavas": "embainhar",
    "embainhe": "embainhar",
    "embainhei": "embainhar",
    "embainheis": "embainhar",
    "embainhem": "embainhar",
    "embainhemo": "embainhar",
    "embainhemos": "embainhar",
    "embainhes": "embainhar",
    "embainho": "embainhar",
    "embainhou": "embainhar",
    "embainhá": "embainhar",
    "embainhámo": "embainhar",
    "embainhámos": "embainhar",
    "embainháramo": "embainhar",
    "embainháramos": "embainhar",
    "embainhárei": "embainhar",
    "embainháreis": "embainhar",
    "embainhásseis": "embainhar",
    "embainhássemos": "embainhar",
    "embainhávamo": "embainhar",
    "embainhávamos": "embainhar",
    "embainhávei": "embainhar",
    "embainháveis": "embainhar",
    "embaio": "embair",
    "embairde": "embair",
    "embairdes": "embair",
    "embairei": "embair",
    "embaireis": "embair",
    "embairemos": "embair",
    "embairia": "embair",
    "embairiam": "embair",
    "embairias": "embair",
    "embairmo": "embair",
    "embairmos": "embair",
    "embairá": "embair",
    "embairás": "embair",
    "embairão": "embair",
    "embairíamos": "embair",
    "embairíeis": "embair",
    "embais": "embair",
    "embaiu": "embair",
    "embaixadas": "embaixada",
    "embaixadora": "embaixador",
    "embaixadoras": "embaixador",
    "embaixadores": "embaixador",
    "embaixatriz": "embaixador",
    "embaixatrizes": "embaixador",
    "embala": "embalar",
    "embalada": "embalar",
    "embaladas": "embalar",
    "embaladeiras": "embaladeira",
    "embalado": "embalar",
    "embaladora": "embalador",
    "embaladoras": "embalador",
    "embaladores": "embalador",
    "embalados": "embalar",
    "embaladíssima": "embalado",
    "embaladíssimas": "embalado",
    "embaladíssimo": "embalado",
    "embaladíssimos": "embalado",
    "embalagens": "embalagem",
    "embalai": "embalar",
    "embalais": "embalar",
    "embalam": "embalar",
    "embalamentos": "embalamento",
    "embalamo": "embalar",
    "embalamos": "embalar",
    "embalance": "embalançar",
    "embalancei": "embalançar",
    "embalanceis": "embalançar",
    "embalancem": "embalançar",
    "embalancemo": "embalançar",
    "embalancemos": "embalançar",
    "embalances": "embalançar",
    "embalando": "embalar",
    "embalança": "embalançar",
    "embalançada": "embalançar",
    "embalançadas": "embalançar",
    "embalançado": "embalançar",
    "embalançados": "embalançar",
    "embalançai": "embalançar",
    "embalançais": "embalançar",
    "embalançam": "embalançar",
    "embalançamo": "embalançar",
    "embalançamos": "embalançar",
    "embalançando": "embalançar",
    "embalançara": "embalançar",
    "embalançaram": "embalançar",
    "embalançaras": "embalançar",
    "embalançarde": "embalançar",
    "embalançardes": "embalançar",
    "embalançare": "embalançar",
    "embalançarei": "embalançar",
    "embalançareis": "embalançar",
    "embalançarem": "embalançar",
    "embalançaremos": "embalançar",
    "embalançares": "embalançar",
    "embalançaria": "embalançar",
    "embalançariam": "embalançar",
    "embalançarias": "embalançar",
    "embalançarmo": "embalançar",
    "embalançarmos": "embalançar",
    "embalançará": "embalançar",
    "embalançarás": "embalançar",
    "embalançarão": "embalançar",
    "embalançaríamos": "embalançar",
    "embalançaríeis": "embalançar",
    "embalanças": "embalançar",
    "embalançasse": "embalançar",
    "embalançassem": "embalançar",
    "embalançasses": "embalançar",
    "embalançaste": "embalançar",
    "embalançastes": "embalançar",
    "embalançava": "embalançar",
    "embalançavam": "embalançar",
    "embalançavas": "embalançar",
    "embalanço": "embalançar",
    "embalançou": "embalançar",
    "embalançá": "embalançar",
    "embalançámo": "embalançar",
    "embalançámos": "embalançar",
    "embalançáramo": "embalançar",
    "embalançáramos": "embalançar",
    "embalançárei": "embalançar",
    "embalançáreis": "embalançar",
    "embalançásseis": "embalançar",
    "embalançássemos": "embalançar",
    "embalançávamo": "embalançar",
    "embalançávamos": "embalançar",
    "embalançávei": "embalançar",
    "embalançáveis": "embalançar",
    "embalara": "embalar",
    "embalaram": "embalar",
    "embalaras": "embalar",
    "embalarde": "embalar",
    "embalardes": "embalar",
    "embalare": "embalar",
    "embalarei": "embalar",
    "embalareis": "embalar",
    "embalarem": "embalar",
    "embalaremos": "embalar",
    "embalares": "embalar",
    "embalaria": "embalar",
    "embalariam": "embalar",
    "embalarias": "embalar",
    "embalarmo": "embalar",
    "embalarmos": "embalar",
    "embalará": "embalar",
    "embalarás": "embalar",
    "embalarão": "embalar",
    "embalaríamos": "embalar",
    "embalaríeis": "embalar",
    "embalas": "embalar",
    "embalasse": "embalar",
    "embalassem": "embalar",
    "embalasses": "embalar",
    "embalaste": "embalar",
    "embalastes": "embalar",
    "embalava": "embalar",
    "embalavam": "embalar",
    "embalavas": "embalar",
    "embalce": "embalçar",
    "embalcei": "embalçar",
    "embalceis": "embalçar",
    "embalcem": "embalçar",
    "embalcemo": "embalçar",
    "embalcemos": "embalçar",
    "embalces": "embalçar",
    "embale": "embalar",
    "embalei": "embalar",
    "embaleis": "embalar",
    "embalem": "embalar",
    "embalemo": "embalar",
    "embalemos": "embalar",
    "embales": "embalar",
    "embaletes": "embalete",
    "embalhestada": "embalhestado",
    "embalhestadas": "embalhestado",
    "embalhestados": "embalhestado",
    "embalo": "embalar",
    "embalos": "embalo",
    "embalou": "embalar",
    "embalsa": "embalsar",
    "embalsada": "embalsar",
    "embalsadas": "embalsar",
    "embalsado": "embalsar",
    "embalsados": "embalsar",
    "embalsai": "embalsar",
    "embalsais": "embalsar",
    "embalsam": "embalsar",
    "embalsama": "embalsamar",
    "embalsamada": "embalsamar",
    "embalsamadas": "embalsamar",
    "embalsamado": "embalsamar",
    "embalsamadora": "embalsamador",
    "embalsamadoras": "embalsamador",
    "embalsamadores": "embalsamador",
    "embalsamados": "embalsamar",
    "embalsamai": "embalsamar",
    "embalsamais": "embalsamar",
    "embalsamam": "embalsamar",
    "embalsamamentos": "embalsamamento",
    "embalsamamo": "embalsamar",
    "embalsamamos": "embalsamar",
    "embalsamando": "embalsamar",
    "embalsamantes": "embalsamante",
    "embalsamara": "embalsamar",
    "embalsamaram": "embalsamar",
    "embalsamaras": "embalsamar",
    "embalsamarde": "embalsamar",
    "embalsamardes": "embalsamar",
    "embalsamare": "embalsamar",
    "embalsamarei": "embalsamar",
    "embalsamareis": "embalsamar",
    "embalsamarem": "embalsamar",
    "embalsamaremos": "embalsamar",
    "embalsamares": "embalsamar",
    "embalsamaria": "embalsamar",
    "embalsamariam": "embalsamar",
    "embalsamarias": "embalsamar",
    "embalsamarmo": "embalsamar",
    "embalsamarmos": "embalsamar",
    "embalsamará": "embalsamar",
    "embalsamarás": "embalsamar",
    "embalsamarão": "embalsamar",
    "embalsamaríamos": "embalsamar",
    "embalsamaríeis": "embalsamar",
    "embalsamas": "embalsamar",
    "embalsamasse": "embalsamar",
    "embalsamassem": "embalsamar",
    "embalsamasses": "embalsamar",
    "embalsamaste": "embalsamar",
    "embalsamastes": "embalsamar",
    "embalsamava": "embalsamar",
    "embalsamavam": "embalsamar",
    "embalsamavas": "embalsamar",
    "embalsamações": "embalsamação",
    "embalsame": "embalsamar",
    "embalsamei": "embalsamar",
    "embalsameis": "embalsamar",
    "embalsamem": "embalsamar",
    "embalsamemo": "embalsamar",
    "embalsamemos": "embalsamar",
    "embalsamentos": "embalsamento",
    "embalsames": "embalsamar",
    "embalsamo": "embalsar",
    "embalsamos": "embalsar",
    "embalsamou": "embalsamar",
    "embalsamá": "embalsamar",
    "embalsamámo": "embalsamar",
    "embalsamámos": "embalsamar",
    "embalsamáramo": "embalsamar",
    "embalsamáramos": "embalsamar",
    "embalsamárei": "embalsamar",
    "embalsamáreis": "embalsamar",
    "embalsamásseis": "embalsamar",
    "embalsamássemos": "embalsamar",
    "embalsamávamo": "embalsamar",
    "embalsamávamos": "embalsamar",
    "embalsamávei": "embalsamar",
    "embalsamáveis": "embalsamar",
    "embalsando": "embalsar",
    "embalsara": "embalsar",
    "embalsaram": "embalsar",
    "embalsaras": "embalsar",
    "embalsarde": "embalsar",
    "embalsardes": "embalsar",
    "embalsare": "embalsar",
    "embalsarei": "embalsar",
    "embalsareis": "embalsar",
    "embalsarem": "embalsar",
    "embalsaremos": "embalsar",
    "embalsares": "embalsar",
    "embalsaria": "embalsar",
    "embalsariam": "embalsar",
    "embalsarias": "embalsar",
    "embalsarmo": "embalsar",
    "embalsarmos": "embalsar",
    "embalsará": "embalsar",
    "embalsarás": "embalsar",
    "embalsarão": "embalsar",
    "embalsaríamos": "embalsar",
    "embalsaríeis": "embalsar",
    "embalsas": "embalsar",
    "embalsasse": "embalsar",
    "embalsassem": "embalsar",
    "embalsasses": "embalsar",
    "embalsaste": "embalsar",
    "embalsastes": "embalsar",
    "embalsava": "embalsar",
    "embalsavam": "embalsar",
    "embalsavas": "embalsar",
    "embalse": "embalsar",
    "embalsei": "embalsar",
    "embalseis": "embalsar",
    "embalsem": "embalsar",
    "embalsemo": "embalsar",
    "embalsemos": "embalsar",
    "embalses": "embalsar",
    "embalso": "embalsar",
    "embalsou": "embalsar",
    "embalsá": "embalsar",
    "embalsámo": "embalsar",
    "embalsámos": "embalsar",
    "embalsáramo": "embalsar",
    "embalsáramos": "embalsar",
    "embalsárei": "embalsar",
    "embalsáreis": "embalsar",
    "embalsásseis": "embalsar",
    "embalsássemos": "embalsar",
    "embalsávamo": "embalsar",
    "embalsávamos": "embalsar",
    "embalsávei": "embalsar",
    "embalsáveis": "embalsar",
    "embalá": "embalar",
    "embalámo": "embalar",
    "embalámos": "embalar",
    "embaláramo": "embalar",
    "embaláramos": "embalar",
    "embalárei": "embalar",
    "embaláreis": "embalar",
    "embalásseis": "embalar",
    "embalássemos": "embalar",
    "embalávamo": "embalar",
    "embalávamos": "embalar",
    "embalávei": "embalar",
    "embaláveis": "embalar",
    "embalça": "embalçar",
    "embalçada": "embalçar",
    "embalçadas": "embalçar",
    "embalçado": "embalçar",
    "embalçados": "embalçar",
    "embalçai": "embalçar",
    "embalçais": "embalçar",
    "embalçam": "embalçar",
    "embalçamo": "embalçar",
    "embalçamos": "embalçar",
    "embalçando": "embalçar",
    "embalçara": "embalçar",
    "embalçaram": "embalçar",
    "embalçaras": "embalçar",
    "embalçarde": "embalçar",
    "embalçardes": "embalçar",
    "embalçare": "embalçar",
    "embalçarei": "embalçar",
    "embalçareis": "embalçar",
    "embalçarem": "embalçar",
    "embalçaremos": "embalçar",
    "embalçares": "embalçar",
    "embalçaria": "embalçar",
    "embalçariam": "embalçar",
    "embalçarias": "embalçar",
    "embalçarmo": "embalçar",
    "embalçarmos": "embalçar",
    "embalçará": "embalçar",
    "embalçarás": "embalçar",
    "embalçarão": "embalçar",
    "embalçaríamos": "embalçar",
    "embalçaríeis": "embalçar",
    "embalças": "embalçar",
    "embalçasse": "embalçar",
    "embalçassem": "embalçar",
    "embalçasses": "embalçar",
    "embalçaste": "embalçar",
    "embalçastes": "embalçar",
    "embalçava": "embalçar",
    "embalçavam": "embalçar",
    "embalçavas": "embalçar",
    "embalço": "embalçar",
    "embalçou": "embalçar",
    "embalçá": "embalçar",
    "embalçámo": "embalçar",
    "embalçámos": "embalçar",
    "embalçáramo": "embalçar",
    "embalçáramos": "embalçar",
    "embalçárei": "embalçar",
    "embalçáreis": "embalçar",
    "embalçásseis": "embalçar",
    "embalçássemos": "embalçar",
    "embalçávamo": "embalçar",
    "embalçávamos": "embalçar",
    "embalçávei": "embalçar",
    "embalçáveis": "embalçar",
    "embana": "embanar",
    "embanada": "embanar",
    "embanadas": "embanar",
    "embanado": "embanar",
    "embanados": "embanar",
    "embanai": "embanar",
    "embanais": "embanar",
    "embanam": "embanar",
    "embanamo": "embanar",
    "embanamos": "embanar",
    "embanando": "embanar",
    "embanara": "embanar",
    "embanaram": "embanar",
    "embanaras": "embanar",
    "embanarde": "embanar",
    "embanardes": "embanar",
    "embanare": "embanar",
    "embanarei": "embanar",
    "embanareis": "embanar",
    "embanarem": "embanar",
    "embanaremos": "embanar",
    "embanares": "embanar",
    "embanaria": "embanar",
    "embanariam": "embanar",
    "embanarias": "embanar",
    "embanarmo": "embanar",
    "embanarmos": "embanar",
    "embanará": "embanar",
    "embanarás": "embanar",
    "embanarão": "embanar",
    "embanaríamos": "embanar",
    "embanaríeis": "embanar",
    "embanas": "embanar",
    "embanasse": "embanar",
    "embanassem": "embanar",
    "embanasses": "embanar",
    "embanaste": "embanar",
    "embanastes": "embanar",
    "embanava": "embanar",
    "embanavam": "embanar",
    "embanavas": "embanar",
    "embanda": "embandar",
    "embandada": "embandar",
    "embandadas": "embandar",
    "embandado": "embandar",
    "embandados": "embandar",
    "embandai": "embandar",
    "embandais": "embandar",
    "embandam": "embandar",
    "embandamo": "embandar",
    "embandamos": "embandar",
    "embandando": "embandar",
    "embandara": "embandar",
    "embandaram": "embandar",
    "embandaras": "embandar",
    "embandarde": "embandar",
    "embandardes": "embandar",
    "embandare": "embandar",
    "embandarei": "embandar",
    "embandareis": "embandar",
    "embandarem": "embandar",
    "embandaremos": "embandar",
    "embandares": "embandar",
    "embandaria": "embandar",
    "embandariam": "embandar",
    "embandarias": "embandar",
    "embandarmo": "embandar",
    "embandarmos": "embandar",
    "embandará": "embandar",
    "embandarás": "embandar",
    "embandarão": "embandar",
    "embandaríamos": "embandar",
    "embandaríeis": "embandar",
    "embandas": "embandar",
    "embandasse": "embandar",
    "embandassem": "embandar",
    "embandasses": "embandar",
    "embandaste": "embandar",
    "embandastes": "embandar",
    "embandava": "embandar",
    "embandavam": "embandar",
    "embandavas": "embandar",
    "embande": "embandar",
    "embandei": "embandar",
    "embandeira": "embandeirar",
    "embandeirada": "embandeirar",
    "embandeiradas": "embandeirar",
    "embandeirado": "embandeirar",
    "embandeirados": "embandeirar",
    "embandeirai": "embandeirar",
    "embandeirais": "embandeirar",
    "embandeiram": "embandeirar",
    "embandeiramentos": "embandeiramento",
    "embandeiramo": "embandeirar",
    "embandeiramos": "embandeirar",
    "embandeirando": "embandeirar",
    "embandeirara": "embandeirar",
    "embandeiraram": "embandeirar",
    "embandeiraras": "embandeirar",
    "embandeirarde": "embandeirar",
    "embandeirardes": "embandeirar",
    "embandeirare": "embandeirar",
    "embandeirarei": "embandeirar",
    "embandeirareis": "embandeirar",
    "embandeirarem": "embandeirar",
    "embandeiraremos": "embandeirar",
    "embandeirares": "embandeirar",
    "embandeiraria": "embandeirar",
    "embandeirariam": "embandeirar",
    "embandeirarias": "embandeirar",
    "embandeirarmo": "embandeirar",
    "embandeirarmos": "embandeirar",
    "embandeirará": "embandeirar",
    "embandeirarás": "embandeirar",
    "embandeirarão": "embandeirar",
    "embandeiraríamos": "embandeirar",
    "embandeiraríeis": "embandeirar",
    "embandeiras": "embandeirar",
    "embandeirasse": "embandeirar",
    "embandeirassem": "embandeirar",
    "embandeirasses": "embandeirar",
    "embandeiraste": "embandeirar",
    "embandeirastes": "embandeirar",
    "embandeirava": "embandeirar",
    "embandeiravam": "embandeirar",
    "embandeiravas": "embandeirar",
    "embandeire": "embandeirar",
    "embandeirei": "embandeirar",
    "embandeireis": "embandeirar",
    "embandeirem": "embandeirar",
    "embandeiremo": "embandeirar",
    "embandeiremos": "embandeirar",
    "embandeires": "embandeirar",
    "embandeiro": "embandeirar",
    "embandeirou": "embandeirar",
    "embandeirá": "embandeirar",
    "embandeirámo": "embandeirar",
    "embandeirámos": "embandeirar",
    "embandeiráramo": "embandeirar",
    "embandeiráramos": "embandeirar",
    "embandeirárei": "embandeirar",
    "embandeiráreis": "embandeirar",
    "embandeirásseis": "embandeirar",
    "embandeirássemos": "embandeirar",
    "embandeirávamo": "embandeirar",
    "embandeirávamos": "embandeirar",
    "embandeirávei": "embandeirar",
    "embandeiráveis": "embandeirar",
    "embandeis": "embandar",
    "embandem": "embandar",
    "embandemo": "embandar",
    "embandemos": "embandar",
    "embandes": "embandar",
    "embando": "embandar",
    "embandou": "embandar",
    "embandá": "embandar",
    "embandámo": "embandar",
    "embandámos": "embandar",
    "embandáramo": "embandar",
    "embandáramos": "embandar",
    "embandárei": "embandar",
    "embandáreis": "embandar",
    "embandásseis": "embandar",
    "embandássemos": "embandar",
    "embandávamo": "embandar",
    "embandávamos": "embandar",
    "embandávei": "embandar",
    "embandáveis": "embandar",
    "embane": "embanar",
    "embanei": "embanar",
    "embaneis": "embanar",
    "embanem": "embanar",
    "embanemo": "embanar",
    "embanemos": "embanar",
    "embanes": "embanar",
    "embano": "embanar",
    "embanou": "embanar",
    "embaná": "embanar",
    "embanámo": "embanar",
    "embanámos": "embanar",
    "embanáramo": "embanar",
    "embanáramos": "embanar",
    "embanárei": "embanar",
    "embanáreis": "embanar",
    "embanásseis": "embanar",
    "embanássemos": "embanar",
    "embanávamo": "embanar",
    "embanávamos": "embanar",
    "embanávei": "embanar",
    "embanáveis": "embanar",
    "embarace": "embaraçar",
    "embaracei": "embaraçar",
    "embaraceis": "embaraçar",
    "embaracem": "embaraçar",
    "embaracemo": "embaraçar",
    "embaracemos": "embaraçar",
    "embaraces": "embaraçar",
    "embaralha": "embaralhar",
    "embaralhada": "embaralhar",
    "embaralhadas": "embaralhar",
    "embaralhado": "embaralhar",
    "embaralhados": "embaralhar",
    "embaralhai": "embaralhar",
    "embaralhais": "embaralhar",
    "embaralham": "embaralhar",
    "embaralhamo": "embaralhar",
    "embaralhamos": "embaralhar",
    "embaralhando": "embaralhar",
    "embaralhara": "embaralhar",
    "embaralharam": "embaralhar",
    "embaralharas": "embaralhar",
    "embaralharde": "embaralhar",
    "embaralhardes": "embaralhar",
    "embaralhare": "embaralhar",
    "embaralharei": "embaralhar",
    "embaralhareis": "embaralhar",
    "embaralharem": "embaralhar",
    "embaralharemos": "embaralhar",
    "embaralhares": "embaralhar",
    "embaralharia": "embaralhar",
    "embaralhariam": "embaralhar",
    "embaralharias": "embaralhar",
    "embaralharmo": "embaralhar",
    "embaralharmos": "embaralhar",
    "embaralhará": "embaralhar",
    "embaralharás": "embaralhar",
    "embaralharão": "embaralhar",
    "embaralharíamos": "embaralhar",
    "embaralharíeis": "embaralhar",
    "embaralhas": "embaralhar",
    "embaralhasse": "embaralhar",
    "embaralhassem": "embaralhar",
    "embaralhasses": "embaralhar",
    "embaralhaste": "embaralhar",
    "embaralhastes": "embaralhar",
    "embaralhava": "embaralhar",
    "embaralhavam": "embaralhar",
    "embaralhavas": "embaralhar",
    "embaralhações": "embaralhação",
    "embaralhe": "embaralhar",
    "embaralhei": "embaralhar",
    "embaralheis": "embaralhar",
    "embaralhem": "embaralhar",
    "embaralhemo": "embaralhar",
    "embaralhemos": "embaralhar",
    "embaralhes": "embaralhar",
    "embaralho": "embaralhar",
    "embaralhou": "embaralhar",
    "embaralhá": "embaralhar",
    "embaralhámo": "embaralhar",
    "embaralhámos": "embaralhar",
    "embaralháramo": "embaralhar",
    "embaralháramos": "embaralhar",
    "embaralhárei": "embaralhar",
    "embaralháreis": "embaralhar",
    "embaralhásseis": "embaralhar",
    "embaralhássemos": "embaralhar",
    "embaralhávamo": "embaralhar",
    "embaralhávamos": "embaralhar",
    "embaralhávei": "embaralhar",
    "embaralháveis": "embaralhável",
    "embaratece": "embaratecer",
    "embaratecei": "embaratecer",
    "embarateceis": "embaratecer",
    "embaratecem": "embaratecer",
    "embaratecemo": "embaratecer",
    "embaratecemos": "embaratecer",
    "embaratecendo": "embaratecer",
    "embaratecera": "embaratecer",
    "embarateceram": "embaratecer",
    "embarateceras": "embaratecer",
    "embaratecerde": "embaratecer",
    "embaratecerdes": "embaratecer",
    "embaratecere": "embaratecer",
    "embaratecerei": "embaratecer",
    "embaratecereis": "embaratecer",
    "embaratecerem": "embaratecer",
    "embarateceremos": "embaratecer",
    "embarateceres": "embaratecer",
    "embarateceria": "embaratecer",
    "embarateceriam": "embaratecer",
    "embaratecerias": "embaratecer",
    "embaratecermo": "embaratecer",
    "embaratecermos": "embaratecer",
    "embaratecerá": "embaratecer",
    "embaratecerás": "embaratecer",
    "embaratecerão": "embaratecer",
    "embarateceríamos": "embaratecer",
    "embarateceríeis": "embaratecer",
    "embarateces": "embaratecer",
    "embaratecesse": "embaratecer",
    "embaratecessem": "embaratecer",
    "embaratecesses": "embaratecer",
    "embarateceste": "embaratecer",
    "embaratecestes": "embaratecer",
    "embarateceu": "embaratecer",
    "embarateci": "embaratecer",
    "embaratecia": "embaratecer",
    "embarateciam": "embaratecer",
    "embaratecias": "embaratecer",
    "embaratecida": "embaratecer",
    "embaratecidas": "embaratecer",
    "embaratecido": "embaratecer",
    "embaratecidos": "embaratecer",
    "embaratecimentos": "embaratecimento",
    "embaratecê": "embaratecer",
    "embaratecêramo": "embaratecer",
    "embaratecêramos": "embaratecer",
    "embaratecêrei": "embaratecer",
    "embaratecêreis": "embaratecer",
    "embaratecêsseis": "embaratecer",
    "embaratecêssemos": "embaratecer",
    "embaratecíamo": "embaratecer",
    "embaratecíamos": "embaratecer",
    "embaratecíei": "embaratecer",
    "embaratecíeis": "embaratecer",
    "embarateça": "embaratecer",
    "embarateçais": "embaratecer",
    "embarateçam": "embaratecer",
    "embarateçamo": "embaratecer",
    "embarateçamos": "embaratecer",
    "embarateças": "embaratecer",
    "embarateço": "embaratecer",
    "embaraça": "embaraçar",
    "embaraçada": "embaraçar",
    "embaraçadas": "embaraçar",
    "embaraçado": "embaraçar",
    "embaraçadora": "embaraçador",
    "embaraçadoras": "embaraçador",
    "embaraçadores": "embaraçador",
    "embaraçados": "embaraçar",
    "embaraçadíssima": "embaraçado",
    "embaraçadíssimas": "embaraçado",
    "embaraçadíssimo": "embaraçado",
    "embaraçadíssimos": "embaraçado",
    "embaraçai": "embaraçar",
    "embaraçais": "embaraçar",
    "embaraçam": "embaraçar",
    "embaraçamo": "embaraçar",
    "embaraçamos": "embaraçar",
    "embaraçando": "embaraçar",
    "embaraçantes": "embaraçante",
    "embaraçara": "embaraçar",
    "embaraçaram": "embaraçar",
    "embaraçaras": "embaraçar",
    "embaraçarde": "embaraçar",
    "embaraçardes": "embaraçar",
    "embaraçare": "embaraçar",
    "embaraçarei": "embaraçar",
    "embaraçareis": "embaraçar",
    "embaraçarem": "embaraçar",
    "embaraçaremos": "embaraçar",
    "embaraçares": "embaraçar",
    "embaraçaria": "embaraçar",
    "embaraçariam": "embaraçar",
    "embaraçarias": "embaraçar",
    "embaraçarmo": "embaraçar",
    "embaraçarmos": "embaraçar",
    "embaraçará": "embaraçar",
    "embaraçarás": "embaraçar",
    "embaraçarão": "embaraçar",
    "embaraçaríamos": "embaraçar",
    "embaraçaríeis": "embaraçar",
    "embaraças": "embaraçar",
    "embaraçasse": "embaraçar",
    "embaraçassem": "embaraçar",
    "embaraçasses": "embaraçar",
    "embaraçaste": "embaraçar",
    "embaraçastes": "embaraçar",
    "embaraçava": "embaraçar",
    "embaraçavam": "embaraçar",
    "embaraçavas": "embaraçar",
    "embaraço": "embaraçar",
    "embaraços": "embaraço",
    "embaraçosa": "embaraçoso",
    "embaraçosas": "embaraçoso",
    "embaraçosos": "embaraçoso",
    "embaraçou": "embaraçar",
    "embaraçá": "embaraçar",
    "embaraçámo": "embaraçar",
    "embaraçámos": "embaraçar",
    "embaraçáramo": "embaraçar",
    "embaraçáramos": "embaraçar",
    "embaraçárei": "embaraçar",
    "embaraçáreis": "embaraçar",
    "embaraçásseis": "embaraçar",
    "embaraçássemos": "embaraçar",
    "embaraçávamo": "embaraçar",
    "embaraçávamos": "embaraçar",
    "embaraçávei": "embaraçar",
    "embaraçáveis": "embaraçável",
    "embarbasca": "embarbascar",
    "embarbascada": "embarbascar",
    "embarbascadas": "embarbascar",
    "embarbascado": "embarbascar",
    "embarbascados": "embarbascar",
    "embarbascai": "embarbascar",
    "embarbascais": "embarbascar",
    "embarbascam": "embarbascar",
    "embarbascamo": "embarbascar",
    "embarbascamos": "embarbascar",
    "embarbascando": "embarbascar",
    "embarbascara": "embarbascar",
    "embarbascaram": "embarbascar",
    "embarbascaras": "embarbascar",
    "embarbascarde": "embarbascar",
    "embarbascardes": "embarbascar",
    "embarbascare": "embarbascar",
    "embarbascarei": "embarbascar",
    "embarbascareis": "embarbascar",
    "embarbascarem": "embarbascar",
    "embarbascaremos": "embarbascar",
    "embarbascares": "embarbascar",
    "embarbascaria": "embarbascar",
    "embarbascariam": "embarbascar",
    "embarbascarias": "embarbascar",
    "embarbascarmo": "embarbascar",
    "embarbascarmos": "embarbascar",
    "embarbascará": "embarbascar",
    "embarbascarás": "embarbascar",
    "embarbascarão": "embarbascar",
    "embarbascaríamos": "embarbascar",
    "embarbascaríeis": "embarbascar",
    "embarbascas": "embarbascar",
    "embarbascasse": "embarbascar",
    "embarbascassem": "embarbascar",
    "embarbascasses": "embarbascar",
    "embarbascaste": "embarbascar",
    "embarbascastes": "embarbascar",
    "embarbascava": "embarbascar",
    "embarbascavam": "embarbascar",
    "embarbascavas": "embarbascar",
    "embarbasco": "embarbascar",
    "embarbascou": "embarbascar",
    "embarbascá": "embarbascar",
    "embarbascámo": "embarbascar",
    "embarbascámos": "embarbascar",
    "embarbascáramo": "embarbascar",
    "embarbascáramos": "embarbascar",
    "embarbascárei": "embarbascar",
    "embarbascáreis": "embarbascar",
    "embarbascásseis": "embarbascar",
    "embarbascássemos": "embarbascar",
    "embarbascávamo": "embarbascar",
    "embarbascávamos": "embarbascar",
    "embarbascávei": "embarbascar",
    "embarbascáveis": "embarbascar",
    "embarbasque": "embarbascar",
    "embarbasquei": "embarbascar",
    "embarbasqueis": "embarbascar",
    "embarbasquem": "embarbascar",
    "embarbasquemo": "embarbascar",
    "embarbasquemos": "embarbascar",
    "embarbasques": "embarbascar",
    "embarbece": "embarbecer",
    "embarbecei": "embarbecer",
    "embarbeceis": "embarbecer",
    "embarbecem": "embarbecer",
    "embarbecemo": "embarbecer",
    "embarbecemos": "embarbecer",
    "embarbecendo": "embarbecer",
    "embarbecera": "embarbecer",
    "embarbeceram": "embarbecer",
    "embarbeceras": "embarbecer",
    "embarbecerdes": "embarbecer",
    "embarbecerei": "embarbecer",
    "embarbecereis": "embarbecer",
    "embarbecerem": "embarbecer",
    "embarbeceremos": "embarbecer",
    "embarbeceres": "embarbecer",
    "embarbeceria": "embarbecer",
    "embarbeceriam": "embarbecer",
    "embarbecerias": "embarbecer",
    "embarbecermo": "embarbecer",
    "embarbecermos": "embarbecer",
    "embarbecerá": "embarbecer",
    "embarbecerás": "embarbecer",
    "embarbecerão": "embarbecer",
    "embarbeceríamos": "embarbecer",
    "embarbeceríeis": "embarbecer",
    "embarbeces": "embarbecer",
    "embarbecesse": "embarbecer",
    "embarbecessem": "embarbecer",
    "embarbecesses": "embarbecer",
    "embarbeceste": "embarbecer",
    "embarbecestes": "embarbecer",
    "embarbeceu": "embarbecer",
    "embarbeci": "embarbecer",
    "embarbecia": "embarbecer",
    "embarbeciam": "embarbecer",
    "embarbecias": "embarbecer",
    "embarbecida": "embarbecer",
    "embarbecidas": "embarbecer",
    "embarbecido": "embarbecer",
    "embarbecidos": "embarbecer",
    "embarbecêramo": "embarbecer",
    "embarbecêramos": "embarbecer",
    "embarbecêreis": "embarbecer",
    "embarbecêsseis": "embarbecer",
    "embarbecêssemos": "embarbecer",
    "embarbecíamo": "embarbecer",
    "embarbecíamos": "embarbecer",
    "embarbecíeis": "embarbecer",
    "embarbela": "embarbelar",
    "embarbelada": "embarbelar",
    "embarbeladas": "embarbelar",
    "embarbelado": "embarbelar",
    "embarbelados": "embarbelar",
    "embarbelai": "embarbelar",
    "embarbelais": "embarbelar",
    "embarbelam": "embarbelar",
    "embarbelamo": "embarbelar",
    "embarbelamos": "embarbelar",
    "embarbelando": "embarbelar",
    "embarbelara": "embarbelar",
    "embarbelaram": "embarbelar",
    "embarbelaras": "embarbelar",
    "embarbelarde": "embarbelar",
    "embarbelardes": "embarbelar",
    "embarbelare": "embarbelar",
    "embarbelarei": "embarbelar",
    "embarbelareis": "embarbelar",
    "embarbelarem": "embarbelar",
    "embarbelaremos": "embarbelar",
    "embarbelares": "embarbelar",
    "embarbelaria": "embarbelar",
    "embarbelariam": "embarbelar",
    "embarbelarias": "embarbelar",
    "embarbelarmo": "embarbelar",
    "embarbelarmos": "embarbelar",
    "embarbelará": "embarbelar",
    "embarbelarás": "embarbelar",
    "embarbelarão": "embarbelar",
    "embarbelaríamos": "embarbelar",
    "embarbelaríeis": "embarbelar",
    "embarbelas": "embarbelar",
    "embarbelasse": "embarbelar",
    "embarbelassem": "embarbelar",
    "embarbelasses": "embarbelar",
    "embarbelaste": "embarbelar",
    "embarbelastes": "embarbelar",
    "embarbelava": "embarbelar",
    "embarbelavam": "embarbelar",
    "embarbelavas": "embarbelar",
    "embarbele": "embarbelar",
    "embarbelei": "embarbelar",
    "embarbeleis": "embarbelar",
    "embarbelem": "embarbelar",
    "embarbelemo": "embarbelar",
    "embarbelemos": "embarbelar",
    "embarbeles": "embarbelar",
    "embarbelo": "embarbelar",
    "embarbelou": "embarbelar",
    "embarbelá": "embarbelar",
    "embarbelámo": "embarbelar",
    "embarbelámos": "embarbelar",
    "embarbeláramo": "embarbelar",
    "embarbeláramos": "embarbelar",
    "embarbelárei": "embarbelar",
    "embarbeláreis": "embarbelar",
    "embarbelásseis": "embarbelar",
    "embarbelássemos": "embarbelar",
    "embarbelávamo": "embarbelar",
    "embarbelávamos": "embarbelar",
    "embarbelávei": "embarbelar",
    "embarbeláveis": "embarbelar",
    "embarbeça": "embarbecer",
    "embarbeçais": "embarbecer",
    "embarbeçam": "embarbecer",
    "embarbeçamo": "embarbecer",
    "embarbeçamos": "embarbecer",
    "embarbeças": "embarbecer",
    "embarbeço": "embarbecer",
    "embarbilhada": "embarbilhado",
    "embarbilhadas": "embarbilhado",
    "embarbilhados": "embarbilhado",
    "embarca": "embarcar",
    "embarcada": "embarcar",
    "embarcadas": "embarcar",
    "embarcadiça": "embarcadiço",
    "embarcadiças": "embarcadiço",
    "embarcadiços": "embarcadiço",
    "embarcado": "embarcar",
    "embarcadoiros": "embarcadoiro",
    "embarcados": "embarcar",
    "embarcadouros": "embarcadouro",
    "embarcai": "embarcar",
    "embarcais": "embarcar",
    "embarcam": "embarcar",
    "embarcamentos": "embarcamento",
    "embarcamo": "embarcar",
    "embarcamos": "embarcar",
    "embarcando": "embarcar",
    "embarcara": "embarcar",
    "embarcaram": "embarcar",
    "embarcaras": "embarcar",
    "embarcarde": "embarcar",
    "embarcardes": "embarcar",
    "embarcare": "embarcar",
    "embarcarei": "embarcar",
    "embarcareis": "embarcar",
    "embarcarem": "embarcar",
    "embarcaremos": "embarcar",
    "embarcares": "embarcar",
    "embarcaria": "embarcar",
    "embarcariam": "embarcar",
    "embarcarias": "embarcar",
    "embarcarmo": "embarcar",
    "embarcarmos": "embarcar",
    "embarcará": "embarcar",
    "embarcarás": "embarcar",
    "embarcarão": "embarcar",
    "embarcaríamos": "embarcar",
    "embarcaríeis": "embarcar",
    "embarcas": "embarcar",
    "embarcasse": "embarcar",
    "embarcassem": "embarcar",
    "embarcasses": "embarcar",
    "embarcaste": "embarcar",
    "embarcastes": "embarcar",
    "embarcava": "embarcar",
    "embarcavam": "embarcar",
    "embarcavas": "embarcar",
    "embarcações": "embarcação",
    "embarco": "embarcar",
    "embarcou": "embarcar",
    "embarcá": "embarcar",
    "embarcámo": "embarcar",
    "embarcámos": "embarcar",
    "embarcáramo": "embarcar",
    "embarcáramos": "embarcar",
    "embarcárei": "embarcar",
    "embarcáreis": "embarcar",
    "embarcásseis": "embarcar",
    "embarcássemos": "embarcar",
    "embarcávamo": "embarcar",
    "embarcávamos": "embarcar",
    "embarcávei": "embarcar",
    "embarcáveis": "embarcar",
    "embarda": "embardar",
    "embardada": "embardar",
    "embardadas": "embardar",
    "embardado": "embardar",
    "embardados": "embardar",
    "embardai": "embardar",
    "embardais": "embardar",
    "embardam": "embardar",
    "embardamo": "embardar",
    "embardamos": "embardar",
    "embardando": "embardar",
    "embardara": "embardar",
    "embardaram": "embardar",
    "embardaras": "embardar",
    "embardarde": "embardar",
    "embardardes": "embardar",
    "embardare": "embardar",
    "embardarei": "embardar",
    "embardareis": "embardar",
    "embardarem": "embardar",
    "embardaremos": "embardar",
    "embardares": "embardar",
    "embardaria": "embardar",
    "embardariam": "embardar",
    "embardarias": "embardar",
    "embardarmo": "embardar",
    "embardarmos": "embardar",
    "embardará": "embardar",
    "embardarás": "embardar",
    "embardarão": "embardar",
    "embardaríamos": "embardar",
    "embardaríeis": "embardar",
    "embardas": "embardar",
    "embardasse": "embardar",
    "embardassem": "embardar",
    "embardasses": "embardar",
    "embardaste": "embardar",
    "embardastes": "embardar",
    "embardava": "embardar",
    "embardavam": "embardar",
    "embardavas": "embardar",
    "embarde": "embardar",
    "embardei": "embardar",
    "embardeis": "embardar",
    "embardem": "embardar",
    "embardemo": "embardar",
    "embardemos": "embardar",
    "embardes": "embardar",
    "embardo": "embardar",
    "embardou": "embardar",
    "embardá": "embardar",
    "embardámo": "embardar",
    "embardámos": "embardar",
    "embardáramo": "embardar",
    "embardáramos": "embardar",
    "embardárei": "embardar",
    "embardáreis": "embardar",
    "embardásseis": "embardar",
    "embardássemos": "embardar",
    "embardávamo": "embardar",
    "embardávamos": "embardar",
    "embardávei": "embardar",
    "embardáveis": "embardar",
    "embarga": "embargar",
    "embargada": "embargar",
    "embargadas": "embargar",
    "embargado": "embargar",
    "embargadora": "embargador",
    "embargadoras": "embargador",
    "embargadores": "embargador",
    "embargados": "embargar",
    "embargai": "embargar",
    "embargais": "embargar",
    "embargam": "embargar",
    "embargamentos": "embargamento",
    "embargamo": "embargar",
    "embargamos": "embargar",
    "embargando": "embargar",
    "embargantes": "embargante",
    "embargara": "embargar",
    "embargaram": "embargar",
    "embargaras": "embargar",
    "embargarde": "embargar",
    "embargardes": "embargar",
    "embargare": "embargar",
    "embargarei": "embargar",
    "embargareis": "embargar",
    "embargarem": "embargar",
    "embargaremos": "embargar",
    "embargares": "embargar",
    "embargaria": "embargar",
    "embargariam": "embargar",
    "embargarias": "embargar",
    "embargarmo": "embargar",
    "embargarmos": "embargar",
    "embargará": "embargar",
    "embargarás": "embargar",
    "embargarão": "embargar",
    "embargaríamos": "embargar",
    "embargaríeis": "embargar",
    "embargas": "embargar",
    "embargasse": "embargar",
    "embargassem": "embargar",
    "embargasses": "embargar",
    "embargaste": "embargar",
    "embargastes": "embargar",
    "embargava": "embargar",
    "embargavam": "embargar",
    "embargavas": "embargar",
    "embargo": "embargar",
    "embargos": "embargo",
    "embargou": "embargar",
    "embargue": "embargar",
    "embarguei": "embargar",
    "embargueis": "embargar",
    "embarguem": "embargar",
    "embarguemo": "embargar",
    "embarguemos": "embargar",
    "embargues": "embargar",
    "embargá": "embargar",
    "embargámo": "embargar",
    "embargámos": "embargar",
    "embargáramo": "embargar",
    "embargáramos": "embargar",
    "embargárei": "embargar",
    "embargáreis": "embargar",
    "embargásseis": "embargar",
    "embargássemos": "embargar",
    "embargávamo": "embargar",
    "embargávamos": "embargar",
    "embargávei": "embargar",
    "embargáveis": "embargável",
    "embarque": "embarcar",
    "embarquei": "embarcar",
    "embarqueis": "embarcar",
    "embarquem": "embarcar",
    "embarquemo": "embarcar",
    "embarquemos": "embarcar",
    "embarques": "embarque",
    "embarra": "embarrar",
    "embarraca": "embarracar",
    "embarracada": "embarracar",
    "embarracadas": "embarracar",
    "embarracado": "embarracar",
    "embarracados": "embarracar",
    "embarracai": "embarracar",
    "embarracais": "embarracar",
    "embarracam": "embarracar",
    "embarracamo": "embarracar",
    "embarracamos": "embarracar",
    "embarracando": "embarracar",
    "embarracara": "embarracar",
    "embarracaram": "embarracar",
    "embarracaras": "embarracar",
    "embarracarde": "embarracar",
    "embarracardes": "embarracar",
    "embarracare": "embarracar",
    "embarracarei": "embarracar",
    "embarracareis": "embarracar",
    "embarracarem": "embarracar",
    "embarracaremos": "embarracar",
    "embarracares": "embarracar",
    "embarracaria": "embarracar",
    "embarracariam": "embarracar",
    "embarracarias": "embarracar",
    "embarracarmo": "embarracar",
    "embarracarmos": "embarracar",
    "embarracará": "embarracar",
    "embarracarás": "embarracar",
    "embarracarão": "embarracar",
    "embarracaríamos": "embarracar",
    "embarracaríeis": "embarracar",
    "embarracas": "embarracar",
    "embarracasse": "embarracar",
    "embarracassem": "embarracar",
    "embarracasses": "embarracar",
    "embarracaste": "embarracar",
    "embarracastes": "embarracar",
    "embarracava": "embarracar",
    "embarracavam": "embarracar",
    "embarracavas": "embarracar",
    "embarraco": "embarracar",
    "embarracou": "embarracar",
    "embarracá": "embarracar",
    "embarracámo": "embarracar",
    "embarracámos": "embarracar",
    "embarracáramo": "embarracar",
    "embarracáramos": "embarracar",
    "embarracárei": "embarracar",
    "embarracáreis": "embarracar",
    "embarracásseis": "embarracar",
    "embarracássemos": "embarracar",
    "embarracávamo": "embarracar",
    "embarracávamos": "embarracar",
    "embarracávei": "embarracar",
    "embarracáveis": "embarracar",
    "embarrada": "embarrar",
    "embarradas": "embarrar",
    "embarrado": "embarrar",
    "embarradora": "embarrador",
    "embarradoras": "embarrador",
    "embarradores": "embarrador",
    "embarrados": "embarrar",
    "embarrai": "embarrar",
    "embarrais": "embarrar",
    "embarram": "embarrar",
    "embarramentos": "embarramento",
    "embarramo": "embarrar",
    "embarramos": "embarrar",
    "embarranca": "embarrancar",
    "embarrancada": "embarrancar",
    "embarrancadas": "embarrancar",
    "embarrancado": "embarrancar",
    "embarrancados": "embarrancar",
    "embarrancai": "embarrancar",
    "embarrancais": "embarrancar",
    "embarrancam": "embarrancar",
    "embarrancamo": "embarrancar",
    "embarrancamos": "embarrancar",
    "embarrancando": "embarrancar",
    "embarrancara": "embarrancar",
    "embarrancaram": "embarrancar",
    "embarrancaras": "embarrancar",
    "embarrancarde": "embarrancar",
    "embarrancardes": "embarrancar",
    "embarrancare": "embarrancar",
    "embarrancarei": "embarrancar",
    "embarrancareis": "embarrancar",
    "embarrancarem": "embarrancar",
    "embarrancaremos": "embarrancar",
    "embarrancares": "embarrancar",
    "embarrancaria": "embarrancar",
    "embarrancariam": "embarrancar",
    "embarrancarias": "embarrancar",
    "embarrancarmo": "embarrancar",
    "embarrancarmos": "embarrancar",
    "embarrancará": "embarrancar",
    "embarrancarás": "embarrancar",
    "embarrancarão": "embarrancar",
    "embarrancaríamos": "embarrancar",
    "embarrancaríeis": "embarrancar",
    "embarrancas": "embarrancar",
    "embarrancasse": "embarrancar",
    "embarrancassem": "embarrancar",
    "embarrancasses": "embarrancar",
    "embarrancaste": "embarrancar",
    "embarrancastes": "embarrancar",
    "embarrancava": "embarrancar",
    "embarrancavam": "embarrancar",
    "embarrancavas": "embarrancar",
    "embarranco": "embarrancar",
    "embarrancou": "embarrancar",
    "embarrancá": "embarrancar",
    "embarrancámo": "embarrancar",
    "embarrancámos": "embarrancar",
    "embarrancáramo": "embarrancar",
    "embarrancáramos": "embarrancar",
    "embarrancárei": "embarrancar",
    "embarrancáreis": "embarrancar",
    "embarrancásseis": "embarrancar",
    "embarrancássemos": "embarrancar",
    "embarrancávamo": "embarrancar",
    "embarrancávamos": "embarrancar",
    "embarrancávei": "embarrancar",
    "embarrancáveis": "embarrancar",
    "embarrando": "embarrar",
    "embarranque": "embarrancar",
    "embarranquei": "embarrancar",
    "embarranqueis": "embarrancar",
    "embarranquem": "embarrancar",
    "embarranquemo": "embarrancar",
    "embarranquemos": "embarrancar",
    "embarranques": "embarrancar",
    "embarraque": "embarracar",
    "embarraquei": "embarracar",
    "embarraqueis": "embarracar",
    "embarraquem": "embarracar",
    "embarraquemo": "embarracar",
    "embarraquemos": "embarracar",
    "embarraques": "embarracar",
    "embarrara": "embarrar",
    "embarraram": "embarrar",
    "embarraras": "embarrar",
    "embarrarde": "embarrar",
    "embarrardes": "embarrar",
    "embarrare": "embarrar",
    "embarrarei": "embarrar",
    "embarrareis": "embarrar",
    "embarrarem": "embarrar",
    "embarraremos": "embarrar",
    "embarrares": "embarrar",
    "embarraria": "embarrar",
    "embarrariam": "embarrar",
    "embarrarias": "embarrar",
    "embarrarmo": "embarrar",
    "embarrarmos": "embarrar",
    "embarrará": "embarrar",
    "embarrarás": "embarrar",
    "embarrarão": "embarrar",
    "embarraríamos": "embarrar",
    "embarraríeis": "embarrar",
    "embarras": "embarrar",
    "embarrasse": "embarrar",
    "embarrassem": "embarrar",
    "embarrasses": "embarrar",
    "embarraste": "embarrar",
    "embarrastes": "embarrar",
    "embarrava": "embarrar",
    "embarravam": "embarrar",
    "embarravas": "embarrar",
    "embarrações": "embarração",
    "embarre": "embarrar",
    "embarrei": "embarrar",
    "embarreira": "embarreirar",
    "embarreirada": "embarreirar",
    "embarreiradas": "embarreirar",
    "embarreirado": "embarreirar",
    "embarreirados": "embarreirar",
    "embarreirai": "embarreirar",
    "embarreirais": "embarreirar",
    "embarreiram": "embarreirar",
    "embarreiramo": "embarreirar",
    "embarreiramos": "embarreirar",
    "embarreirando": "embarreirar",
    "embarreirara": "embarreirar",
    "embarreiraram": "embarreirar",
    "embarreiraras": "embarreirar",
    "embarreirarde": "embarreirar",
    "embarreirardes": "embarreirar",
    "embarreirare": "embarreirar",
    "embarreirarei": "embarreirar",
    "embarreirareis": "embarreirar",
    "embarreirarem": "embarreirar",
    "embarreiraremos": "embarreirar",
    "embarreirares": "embarreirar",
    "embarreiraria": "embarreirar",
    "embarreirariam": "embarreirar",
    "embarreirarias": "embarreirar",
    "embarreirarmo": "embarreirar",
    "embarreirarmos": "embarreirar",
    "embarreirará": "embarreirar",
    "embarreirarás": "embarreirar",
    "embarreirarão": "embarreirar",
    "embarreiraríamos": "embarreirar",
    "embarreiraríeis": "embarreirar",
    "embarreiras": "embarreirar",
    "embarreirasse": "embarreirar",
    "embarreirassem": "embarreirar",
    "embarreirasses": "embarreirar",
    "embarreiraste": "embarreirar",
    "embarreirastes": "embarreirar",
    "embarreirava": "embarreirar",
    "embarreiravam": "embarreirar",
    "embarreiravas": "embarreirar",
    "embarreire": "embarreirar",
    "embarreirei": "embarreirar",
    "embarreireis": "embarreirar",
    "embarreirem": "embarreirar",
    "embarreiremo": "embarreirar",
    "embarreiremos": "embarreirar",
    "embarreires": "embarreirar",
    "embarreiro": "embarreirar",
    "embarreirou": "embarreirar",
    "embarreirá": "embarreirar",
    "embarreirámo": "embarreirar",
    "embarreirámos": "embarreirar",
    "embarreiráramo": "embarreirar",
    "embarreiráramos": "embarreirar",
    "embarreirárei": "embarreirar",
    "embarreiráreis": "embarreirar",
    "embarreirásseis": "embarreirar",
    "embarreirássemos": "embarreirar",
    "embarreirávamo": "embarreirar",
    "embarreirávamos": "embarreirar",
    "embarreirávei": "embarreirar",
    "embarreiráveis": "embarreirar",
    "embarreis": "embarrar",
    "embarrela": "embarrelar",
    "embarrelada": "embarrelar",
    "embarreladas": "embarrelar",
    "embarrelado": "embarrelar",
    "embarrelados": "embarrelar",
    "embarrelai": "embarrelar",
    "embarrelais": "embarrelar",
    "embarrelam": "embarrelar",
    "embarrelamo": "embarrelar",
    "embarrelamos": "embarrelar",
    "embarrelando": "embarrelar",
    "embarrelara": "embarrelar",
    "embarrelaram": "embarrelar",
    "embarrelaras": "embarrelar",
    "embarrelarde": "embarrelar",
    "embarrelardes": "embarrelar",
    "embarrelare": "embarrelar",
    "embarrelarei": "embarrelar",
    "embarrelareis": "embarrelar",
    "embarrelarem": "embarrelar",
    "embarrelaremos": "embarrelar",
    "embarrelares": "embarrelar",
    "embarrelaria": "embarrelar",
    "embarrelariam": "embarrelar",
    "embarrelarias": "embarrelar",
    "embarrelarmo": "embarrelar",
    "embarrelarmos": "embarrelar",
    "embarrelará": "embarrelar",
    "embarrelarás": "embarrelar",
    "embarrelarão": "embarrelar",
    "embarrelaríamos": "embarrelar",
    "embarrelaríeis": "embarrelar",
    "embarrelas": "embarrelar",
    "embarrelasse": "embarrelar",
    "embarrelassem": "embarrelar",
    "embarrelasses": "embarrelar",
    "embarrelaste": "embarrelar",
    "embarrelastes": "embarrelar",
    "embarrelava": "embarrelar",
    "embarrelavam": "embarrelar",
    "embarrelavas": "embarrelar",
    "embarrele": "embarrelar",
    "embarrelei": "embarrelar",
    "embarreleis": "embarrelar",
    "embarrelem": "embarrelar",
    "embarrelemo": "embarrelar",
    "embarrelemos": "embarrelar",
    "embarreles": "embarrelar",
    "embarrelo": "embarrelar",
    "embarrelou": "embarrelar",
    "embarrelá": "embarrelar",
    "embarrelámo": "embarrelar",
    "embarrelámos": "embarrelar",
    "embarreláramo": "embarrelar",
    "embarreláramos": "embarrelar",
    "embarrelárei": "embarrelar",
    "embarreláreis": "embarrelar",
    "embarrelásseis": "embarrelar",
    "embarrelássemos": "embarrelar",
    "embarrelávamo": "embarrelar",
    "embarrelávamos": "embarrelar",
    "embarrelávei": "embarrelar",
    "embarreláveis": "embarrelar",
    "embarrem": "embarrar",
    "embarremo": "embarrar",
    "embarremos": "embarrar",
    "embarres": "embarrar",
    "embarreta": "embarretar",
    "embarretada": "embarretar",
    "embarretadas": "embarretar",
    "embarretado": "embarretar",
    "embarretados": "embarretar",
    "embarretai": "embarretar",
    "embarretais": "embarretar",
    "embarretam": "embarretar",
    "embarretamo": "embarretar",
    "embarretamos": "embarretar",
    "embarretando": "embarretar",
    "embarretara": "embarretar",
    "embarretaram": "embarretar",
    "embarretaras": "embarretar",
    "embarretarde": "embarretar",
    "embarretardes": "embarretar",
    "embarretare": "embarretar",
    "embarretarei": "embarretar",
    "embarretareis": "embarretar",
    "embarretarem": "embarretar",
    "embarretaremos": "embarretar",
    "embarretares": "embarretar",
    "embarretaria": "embarretar",
    "embarretariam": "embarretar",
    "embarretarias": "embarretar",
    "embarretarmo": "embarretar",
    "embarretarmos": "embarretar",
    "embarretará": "embarretar",
    "embarretarás": "embarretar",
    "embarretarão": "embarretar",
    "embarretaríamos": "embarretar",
    "embarretaríeis": "embarretar",
    "embarretas": "embarretar",
    "embarretasse": "embarretar",
    "embarretassem": "embarretar",
    "embarretasses": "embarretar",
    "embarretaste": "embarretar",
    "embarretastes": "embarretar",
    "embarretava": "embarretar",
    "embarretavam": "embarretar",
    "embarretavas": "embarretar",
    "embarrete": "embarretar",
    "embarretei": "embarretar",
    "embarreteis": "embarretar",
    "embarretem": "embarretar",
    "embarretemo": "embarretar",
    "embarretemos": "embarretar",
    "embarretes": "embarretar",
    "embarreto": "embarretar",
    "embarretou": "embarretar",
    "embarretá": "embarretar",
    "embarretámo": "embarretar",
    "embarretámos": "embarretar",
    "embarretáramo": "embarretar",
    "embarretáramos": "embarretar",
    "embarretárei": "embarretar",
    "embarretáreis": "embarretar",
    "embarretásseis": "embarretar",
    "embarretássemos": "embarretar",
    "embarretávamo": "embarretar",
    "embarretávamos": "embarretar",
    "embarretávei": "embarretar",
    "embarretáveis": "embarretar",
    "embarrica": "embarricar",
    "embarricada": "embarricar",
    "embarricadas": "embarricar",
    "embarricado": "embarricar",
    "embarricados": "embarricar",
    "embarricai": "embarricar",
    "embarricais": "embarricar",
    "embarricam": "embarricar",
    "embarricamentos": "embarricamento",
    "embarricamo": "embarricar",
    "embarricamos": "embarricar",
    "embarricando": "embarricar",
    "embarricara": "embarricar",
    "embarricaram": "embarricar",
    "embarricaras": "embarricar",
    "embarricarde": "embarricar",
    "embarricardes": "embarricar",
    "embarricare": "embarricar",
    "embarricarei": "embarricar",
    "embarricareis": "embarricar",
    "embarricarem": "embarricar",
    "embarricaremos": "embarricar",
    "embarricares": "embarricar",
    "embarricaria": "embarricar",
    "embarricariam": "embarricar",
    "embarricarias": "embarricar",
    "embarricarmo": "embarricar",
    "embarricarmos": "embarricar",
    "embarricará": "embarricar",
    "embarricarás": "embarricar",
    "embarricarão": "embarricar",
    "embarricaríamos": "embarricar",
    "embarricaríeis": "embarricar",
    "embarricas": "embarricar",
    "embarricasse": "embarricar",
    "embarricassem": "embarricar",
    "embarricasses": "embarricar",
    "embarricaste": "embarricar",
    "embarricastes": "embarricar",
    "embarricava": "embarricar",
    "embarricavam": "embarricar",
    "embarricavas": "embarricar",
    "embarrico": "embarricar",
    "embarricou": "embarricar",
    "embarricá": "embarricar",
    "embarricámo": "embarricar",
    "embarricámos": "embarricar",
    "embarricáramo": "embarricar",
    "embarricáramos": "embarricar",
    "embarricárei": "embarricar",
    "embarricáreis": "embarricar",
    "embarricásseis": "embarricar",
    "embarricássemos": "embarricar",
    "embarricávamo": "embarricar",
    "embarricávamos": "embarricar",
    "embarricávei": "embarricar",
    "embarricáveis": "embarricar",
    "embarrila": "embarrilar",
    "embarrilada": "embarrilar",
    "embarriladas": "embarrilar",
    "embarrilado": "embarrilar",
    "embarrilados": "embarrilar",
    "embarrilagens": "embarrilagem",
    "embarrilai": "embarrilar",
    "embarrilais": "embarrilar",
    "embarrilam": "embarrilar",
    "embarrilamentos": "embarrilamento",
    "embarrilamo": "embarrilar",
    "embarrilamos": "embarrilar",
    "embarrilando": "embarrilar",
    "embarrilara": "embarrilar",
    "embarrilaram": "embarrilar",
    "embarrilaras": "embarrilar",
    "embarrilarde": "embarrilar",
    "embarrilardes": "embarrilar",
    "embarrilare": "embarrilar",
    "embarrilarei": "embarrilar",
    "embarrilareis": "embarrilar",
    "embarrilarem": "embarrilar",
    "embarrilaremos": "embarrilar",
    "embarrilares": "embarrilar",
    "embarrilaria": "embarrilar",
    "embarrilariam": "embarrilar",
    "embarrilarias": "embarrilar",
    "embarrilarmo": "embarrilar",
    "embarrilarmos": "embarrilar",
    "embarrilará": "embarrilar",
    "embarrilarás": "embarrilar",
    "embarrilarão": "embarrilar",
    "embarrilaríamos": "embarrilar",
    "embarrilaríeis": "embarrilar",
    "embarrilas": "embarrilar",
    "embarrilasse": "embarrilar",
    "embarrilassem": "embarrilar",
    "embarrilasses": "embarrilar",
    "embarrilaste": "embarrilar",
    "embarrilastes": "embarrilar",
    "embarrilava": "embarrilar",
    "embarrilavam": "embarrilar",
    "embarrilavas": "embarrilar",
    "embarrilações": "embarrilação",
    "embarrile": "embarrilar",
    "embarrilei": "embarrilar",
    "embarrileis": "embarrilar",
    "embarrilem": "embarrilar",
    "embarrilemo": "embarrilar",
    "embarrilemos": "embarrilar",
    "embarriles": "embarrilar",
    "embarrilo": "embarrilar",
    "embarrilou": "embarrilar",
    "embarrilá": "embarrilar",
    "embarrilámo": "embarrilar",
    "embarrilámos": "embarrilar",
    "embarriláramo": "embarrilar",
    "embarriláramos": "embarrilar",
    "embarrilárei": "embarrilar",
    "embarriláreis": "embarrilar",
    "embarrilásseis": "embarrilar",
    "embarrilássemos": "embarrilar",
    "embarrilávamo": "embarrilar",
    "embarrilávamos": "embarrilar",
    "embarrilávei": "embarrilar",
    "embarriláveis": "embarrilar",
    "embarrique": "embarricar",
    "embarriquei": "embarricar",
    "embarriqueis": "embarricar",
    "embarriquem": "embarricar",
    "embarriquemo": "embarricar",
    "embarriquemos": "embarricar",
    "embarriques": "embarricar",
    "embarro": "embarrar",
    "embarrou": "embarrar",
    "embarrá": "embarrar",
    "embarrámo": "embarrar",
    "embarrámos": "embarrar",
    "embarráramo": "embarrar",
    "embarráramos": "embarrar",
    "embarrárei": "embarrar",
    "embarráreis": "embarrar",
    "embarrásseis": "embarrar",
    "embarrássemos": "embarrar",
    "embarrávamo": "embarrar",
    "embarrávamos": "embarrar",
    "embarrávei": "embarrar",
    "embarráveis": "embarrar",
    "embasbaca": "embasbacar",
    "embasbacada": "embasbacar",
    "embasbacadas": "embasbacar",
    "embasbacado": "embasbacar",
    "embasbacados": "embasbacar",
    "embasbacadíssima": "embasbacado",
    "embasbacadíssimas": "embasbacado",
    "embasbacadíssimo": "embasbacado",
    "embasbacadíssimos": "embasbacado",
    "embasbacai": "embasbacar",
    "embasbacais": "embasbacar",
    "embasbacam": "embasbacar",
    "embasbacamentos": "embasbacamento",
    "embasbacamo": "embasbacar",
    "embasbacamos": "embasbacar",
    "embasbacando": "embasbacar",
    "embasbacara": "embasbacar",
    "embasbacaram": "embasbacar",
    "embasbacaras": "embasbacar",
    "embasbacarde": "embasbacar",
    "embasbacardes": "embasbacar",
    "embasbacare": "embasbacar",
    "embasbacarei": "embasbacar",
    "embasbacareis": "embasbacar",
    "embasbacarem": "embasbacar",
    "embasbacaremos": "embasbacar",
    "embasbacares": "embasbacar",
    "embasbacaria": "embasbacar",
    "embasbacariam": "embasbacar",
    "embasbacarias": "embasbacar",
    "embasbacarmo": "embasbacar",
    "embasbacarmos": "embasbacar",
    "embasbacará": "embasbacar",
    "embasbacarás": "embasbacar",
    "embasbacarão": "embasbacar",
    "embasbacaríamos": "embasbacar",
    "embasbacaríeis": "embasbacar",
    "embasbacas": "embasbacar",
    "embasbacasse": "embasbacar",
    "embasbacassem": "embasbacar",
    "embasbacasses": "embasbacar",
    "embasbacaste": "embasbacar",
    "embasbacastes": "embasbacar",
    "embasbacava": "embasbacar",
    "embasbacavam": "embasbacar",
    "embasbacavas": "embasbacar",
    "embasbacações": "embasbacação",
    "embasbaco": "embasbacar",
    "embasbacou": "embasbacar",
    "embasbacá": "embasbacar",
    "embasbacámo": "embasbacar",
    "embasbacámos": "embasbacar",
    "embasbacáramo": "embasbacar",
    "embasbacáramos": "embasbacar",
    "embasbacárei": "embasbacar",
    "embasbacáreis": "embasbacar",
    "embasbacásseis": "embasbacar",
    "embasbacássemos": "embasbacar",
    "embasbacávamo": "embasbacar",
    "embasbacávamos": "embasbacar",
    "embasbacávei": "embasbacar",
    "embasbacáveis": "embasbacar",
    "embasbaque": "embasbacar",
    "embasbaquei": "embasbacar",
    "embasbaqueis": "embasbacar",
    "embasbaquem": "embasbacar",
    "embasbaquemo": "embasbacar",
    "embasbaquemos": "embasbacar",
    "embasbaques": "embasbacar",
    "embasta": "embastar",
    "embastada": "embastar",
    "embastadas": "embastar",
    "embastado": "embastar",
    "embastados": "embastar",
    "embastai": "embastar",
    "embastais": "embastar",
    "embastam": "embastar",
    "embastamo": "embastar",
    "embastamos": "embastar",
    "embastando": "embastar",
    "embastara": "embastar",
    "embastaram": "embastar",
    "embastaras": "embastar",
    "embastarde": "embastar",
    "embastardes": "embastar",
    "embastare": "embastar",
    "embastarei": "embastar",
    "embastareis": "embastar",
    "embastarem": "embastar",
    "embastaremos": "embastar",
    "embastares": "embastar",
    "embastaria": "embastar",
    "embastariam": "embastar",
    "embastarias": "embastar",
    "embastarmo": "embastar",
    "embastarmos": "embastar",
    "embastará": "embastar",
    "embastarás": "embastar",
    "embastarão": "embastar",
    "embastaríamos": "embastar",
    "embastaríeis": "embastar",
    "embastas": "embastar",
    "embastasse": "embastar",
    "embastassem": "embastar",
    "embastasses": "embastar",
    "embastaste": "embastar",
    "embastastes": "embastar",
    "embastava": "embastar",
    "embastavam": "embastar",
    "embastavas": "embastar",
    "embaste": "embastar",
    "embastece": "embastecer",
    "embastecei": "embastecer",
    "embasteceis": "embastecer",
    "embastecem": "embastecer",
    "embastecemo": "embastecer",
    "embastecemos": "embastecer",
    "embastecendo": "embastecer",
    "embastecera": "embastecer",
    "embasteceram": "embastecer",
    "embasteceras": "embastecer",
    "embastecerde": "embastecer",
    "embastecerdes": "embastecer",
    "embastecere": "embastecer",
    "embastecerei": "embastecer",
    "embastecereis": "embastecer",
    "embastecerem": "embastecer",
    "embasteceremos": "embastecer",
    "embasteceres": "embastecer",
    "embasteceria": "embastecer",
    "embasteceriam": "embastecer",
    "embastecerias": "embastecer",
    "embastecermo": "embastecer",
    "embastecermos": "embastecer",
    "embastecerá": "embastecer",
    "embastecerás": "embastecer",
    "embastecerão": "embastecer",
    "embasteceríamos": "embastecer",
    "embasteceríeis": "embastecer",
    "embasteces": "embastecer",
    "embastecesse": "embastecer",
    "embastecessem": "embastecer",
    "embastecesses": "embastecer",
    "embasteceste": "embastecer",
    "embastecestes": "embastecer",
    "embasteceu": "embastecer",
    "embasteci": "embastecer",
    "embastecia": "embastecer",
    "embasteciam": "embastecer",
    "embastecias": "embastecer",
    "embastecida": "embastecer",
    "embastecidas": "embastecer",
    "embastecido": "embastecer",
    "embastecidos": "embastecer",
    "embastecê": "embastecer",
    "embastecêramo": "embastecer",
    "embastecêramos": "embastecer",
    "embastecêrei": "embastecer",
    "embastecêreis": "embastecer",
    "embastecêsseis": "embastecer",
    "embastecêssemos": "embastecer",
    "embastecíamo": "embastecer",
    "embastecíamos": "embastecer",
    "embastecíei": "embastecer",
    "embastecíeis": "embastecer",
    "embastei": "embastar",
    "embasteis": "embastar",
    "embastem": "embastar",
    "embastemo": "embastar",
    "embastemos": "embastar",
    "embastes": "embastar",
    "embasteça": "embastecer",
    "embasteçais": "embastecer",
    "embasteçam": "embastecer",
    "embasteçamo": "embastecer",
    "embasteçamos": "embastecer",
    "embasteças": "embastecer",
    "embasteço": "embastecer",
    "embasto": "embastar",
    "embastou": "embastar",
    "embastá": "embastar",
    "embastámo": "embastar",
    "embastámos": "embastar",
    "embastáramo": "embastar",
    "embastáramos": "embastar",
    "embastárei": "embastar",
    "embastáreis": "embastar",
    "embastásseis": "embastar",
    "embastássemos": "embastar",
    "embastávamo": "embastar",
    "embastávamos": "embastar",
    "embastávei": "embastar",
    "embastáveis": "embastar",
    "embata": "embater",
    "embatais": "embater",
    "embatam": "embater",
    "embatamo": "embater",
    "embatamos": "embater",
    "embatas": "embater",
    "embate": "embater",
    "embatei": "embater",
    "embateis": "embater",
    "embatem": "embater",
    "embatemo": "embater",
    "embatemos": "embater",
    "embatendo": "embater",
    "embatera": "embater",
    "embateram": "embater",
    "embateras": "embater",
    "embaterdes": "embater",
    "embaterei": "embater",
    "embatereis": "embater",
    "embaterem": "embater",
    "embateremos": "embater",
    "embateres": "embater",
    "embateria": "embater",
    "embateriam": "embater",
    "embaterias": "embater",
    "embatermo": "embater",
    "embatermos": "embater",
    "embaterá": "embater",
    "embaterás": "embater",
    "embaterão": "embater",
    "embateríamos": "embater",
    "embateríeis": "embater",
    "embates": "embater",
    "embatesse": "embater",
    "embatessem": "embater",
    "embatesses": "embater",
    "embateste": "embater",
    "embatestes": "embater",
    "embateu": "embater",
    "embati": "embater",
    "embatia": "embater",
    "embatiam": "embater",
    "embatias": "embater",
    "embatida": "embater",
    "embatidas": "embater",
    "embatido": "embater",
    "embatidos": "embater",
    "embato": "embater",
    "embatoca": "embatocar",
    "embatocada": "embatocar",
    "embatocadas": "embatocar",
    "embatocado": "embatocar",
    "embatocados": "embatocar",
    "embatocai": "embatocar",
    "embatocais": "embatocar",
    "embatocam": "embatocar",
    "embatocamo": "embatocar",
    "embatocamos": "embatocar",
    "embatocando": "embatocar",
    "embatocara": "embatocar",
    "embatocaram": "embatocar",
    "embatocaras": "embatocar",
    "embatocarde": "embatocar",
    "embatocardes": "embatocar",
    "embatocare": "embatocar",
    "embatocarei": "embatocar",
    "embatocareis": "embatocar",
    "embatocarem": "embatocar",
    "embatocaremos": "embatocar",
    "embatocares": "embatocar",
    "embatocaria": "embatocar",
    "embatocariam": "embatocar",
    "embatocarias": "embatocar",
    "embatocarmo": "embatocar",
    "embatocarmos": "embatocar",
    "embatocará": "embatocar",
    "embatocarás": "embatocar",
    "embatocarão": "embatocar",
    "embatocaríamos": "embatocar",
    "embatocaríeis": "embatocar",
    "embatocas": "embatocar",
    "embatocasse": "embatocar",
    "embatocassem": "embatocar",
    "embatocasses": "embatocar",
    "embatocaste": "embatocar",
    "embatocastes": "embatocar",
    "embatocava": "embatocar",
    "embatocavam": "embatocar",
    "embatocavas": "embatocar",
    "embatoco": "embatocar",
    "embatocou": "embatocar",
    "embatocá": "embatocar",
    "embatocámo": "embatocar",
    "embatocámos": "embatocar",
    "embatocáramo": "embatocar",
    "embatocáramos": "embatocar",
    "embatocárei": "embatocar",
    "embatocáreis": "embatocar",
    "embatocásseis": "embatocar",
    "embatocássemos": "embatocar",
    "embatocávamo": "embatocar",
    "embatocávamos": "embatocar",
    "embatocávei": "embatocar",
    "embatocáveis": "embatocar",
    "embatoque": "embatocar",
    "embatoquei": "embatocar",
    "embatoqueis": "embatocar",
    "embatoquem": "embatocar",
    "embatoquemo": "embatocar",
    "embatoquemos": "embatocar",
    "embatoques": "embatocar",
    "embatuca": "embatucar",
    "embatucada": "embatucar",
    "embatucadas": "embatucar",
    "embatucado": "embatucar",
    "embatucados": "embatucar",
    "embatucadíssima": "embatucado",
    "embatucadíssimas": "embatucado",
    "embatucadíssimo": "embatucado",
    "embatucadíssimos": "embatucado",
    "embatucai": "embatucar",
    "embatucais": "embatucar",
    "embatucam": "embatucar",
    "embatucamo": "embatucar",
    "embatucamos": "embatucar",
    "embatucando": "embatucar",
    "embatucara": "embatucar",
    "embatucaram": "embatucar",
    "embatucaras": "embatucar",
    "embatucarde": "embatucar",
    "embatucardes": "embatucar",
    "embatucare": "embatucar",
    "embatucarei": "embatucar",
    "embatucareis": "embatucar",
    "embatucarem": "embatucar",
    "embatucaremos": "embatucar",
    "embatucares": "embatucar",
    "embatucaria": "embatucar",
    "embatucariam": "embatucar",
    "embatucarias": "embatucar",
    "embatucarmo": "embatucar",
    "embatucarmos": "embatucar",
    "embatucará": "embatucar",
    "embatucarás": "embatucar",
    "embatucarão": "embatucar",
    "embatucaríamos": "embatucar",
    "embatucaríeis": "embatucar",
    "embatucas": "embatucar",
    "embatucasse": "embatucar",
    "embatucassem": "embatucar",
    "embatucasses": "embatucar",
    "embatucaste": "embatucar",
    "embatucastes": "embatucar",
    "embatucava": "embatucar",
    "embatucavam": "embatucar",
    "embatucavas": "embatucar",
    "embatuco": "embatucar",
    "embatucou": "embatucar",
    "embatucá": "embatucar",
    "embatucámo": "embatucar",
    "embatucámos": "embatucar",
    "embatucáramo": "embatucar",
    "embatucáramos": "embatucar",
    "embatucárei": "embatucar",
    "embatucáreis": "embatucar",
    "embatucásseis": "embatucar",
    "embatucássemos": "embatucar",
    "embatucávamo": "embatucar",
    "embatucávamos": "embatucar",
    "embatucávei": "embatucar",
    "embatucáveis": "embatucar",
    "embatuque": "embatucar",
    "embatuquei": "embatucar",
    "embatuqueis": "embatucar",
    "embatuquem": "embatucar",
    "embatuquemo": "embatucar",
    "embatuquemos": "embatucar",
    "embatuques": "embatucar",
    "embatêramo": "embater",
    "embatêramos": "embater",
    "embatêreis": "embater",
    "embatêsseis": "embater",
    "embatêssemos": "embater",
    "embatíamo": "embater",
    "embatíamos": "embater",
    "embatíeis": "embater",
    "embauca": "embaucar",
    "embaucada": "embaucar",
    "embaucadas": "embaucar",
    "embaucado": "embaucar",
    "embaucadora": "embaucador",
    "embaucadoras": "embaucador",
    "embaucadores": "embaucador",
    "embaucados": "embaucar",
    "embaucai": "embaucar",
    "embaucais": "embaucar",
    "embaucam": "embaucar",
    "embaucamentos": "embaucamento",
    "embaucamo": "embaucar",
    "embaucamos": "embaucar",
    "embaucando": "embaucar",
    "embaucara": "embaucar",
    "embaucaram": "embaucar",
    "embaucaras": "embaucar",
    "embaucarde": "embaucar",
    "embaucardes": "embaucar",
    "embaucare": "embaucar",
    "embaucarei": "embaucar",
    "embaucareis": "embaucar",
    "embaucarem": "embaucar",
    "embaucaremos": "embaucar",
    "embaucares": "embaucar",
    "embaucaria": "embaucar",
    "embaucariam": "embaucar",
    "embaucarias": "embaucar",
    "embaucarmo": "embaucar",
    "embaucarmos": "embaucar",
    "embaucará": "embaucar",
    "embaucarás": "embaucar",
    "embaucarão": "embaucar",
    "embaucaríamos": "embaucar",
    "embaucaríeis": "embaucar",
    "embaucas": "embaucar",
    "embaucasse": "embaucar",
    "embaucassem": "embaucar",
    "embaucasses": "embaucar",
    "embaucaste": "embaucar",
    "embaucastes": "embaucar",
    "embaucava": "embaucar",
    "embaucavam": "embaucar",
    "embaucavas": "embaucar",
    "embauco": "embaucar",
    "embaucou": "embaucar",
    "embaucá": "embaucar",
    "embaucámo": "embaucar",
    "embaucámos": "embaucar",
    "embaucáramo": "embaucar",
    "embaucáramos": "embaucar",
    "embaucárei": "embaucar",
    "embaucáreis": "embaucar",
    "embaucásseis": "embaucar",
    "embaucássemos": "embaucar",
    "embaucávamo": "embaucar",
    "embaucávamos": "embaucar",
    "embaucávei": "embaucar",
    "embaucáveis": "embaucar",
    "embaula": "embaular",
    "embaulada": "embaular",
    "embauladas": "embaular",
    "embaulado": "embaular",
    "embauladora": "embaulador",
    "embauladoras": "embaulador",
    "embauladores": "embaulador",
    "embaulados": "embaular",
    "embaulai": "embaular",
    "embaulais": "embaular",
    "embaulam": "embaular",
    "embaulamentos": "embaulamento",
    "embaulamo": "embaular",
    "embaulamos": "embaular",
    "embaulando": "embaular",
    "embaulara": "embaular",
    "embaularam": "embaular",
    "embaularas": "embaular",
    "embaularde": "embaular",
    "embaulardes": "embaular",
    "embaulare": "embaular",
    "embaularei": "embaular",
    "embaulareis": "embaular",
    "embaularem": "embaular",
    "embaularemos": "embaular",
    "embaulares": "embaular",
    "embaularia": "embaular",
    "embaulariam": "embaular",
    "embaularias": "embaular",
    "embaularmo": "embaular",
    "embaularmos": "embaular",
    "embaulará": "embaular",
    "embaularás": "embaular",
    "embaularão": "embaular",
    "embaularíamos": "embaular",
    "embaularíeis": "embaular",
    "embaulas": "embaular",
    "embaulasse": "embaular",
    "embaulassem": "embaular",
    "embaulasses": "embaular",
    "embaulaste": "embaular",
    "embaulastes": "embaular",
    "embaulava": "embaular",
    "embaulavam": "embaular",
    "embaulavas": "embaular",
    "embaule": "embaular",
    "embaulei": "embaular",
    "embauleis": "embaular",
    "embaulem": "embaular",
    "embaulemo": "embaular",
    "embaulemos": "embaular",
    "embaules": "embaular",
    "embaulo": "embaular",
    "embaulou": "embaular",
    "embaulá": "embaular",
    "embaulámo": "embaular",
    "embaulámos": "embaular",
    "embauláramo": "embaular",
    "embauláramos": "embaular",
    "embaulárei": "embaular",
    "embauláreis": "embaular",
    "embaulásseis": "embaular",
    "embaulássemos": "embaular",
    "embaulávamo": "embaular",
    "embaulávamos": "embaular",
    "embaulávei": "embaular",
    "embauláveis": "embaular",
    "embauque": "embaucar",
    "embauquei": "embaucar",
    "embauqueis": "embaucar",
    "embauquem": "embaucar",
    "embauquemo": "embaucar",
    "embauquemos": "embaucar",
    "embauques": "embaucar",
    "embaça": "embaçar",
    "embaçada": "embaçar",
    "embaçadas": "embaçar",
    "embaçadelas": "embaçadela",
    "embaçado": "embaçar",
    "embaçados": "embaçar",
    "embaçai": "embaçar",
    "embaçais": "embaçar",
    "embaçam": "embaçar",
    "embaçamo": "embaçar",
    "embaçamos": "embaçar",
    "embaçando": "embaçar",
    "embaçantes": "embaçante",
    "embaçara": "embaçar",
    "embaçaram": "embaçar",
    "embaçaras": "embaçar",
    "embaçarde": "embaçar",
    "embaçardes": "embaçar",
    "embaçare": "embaçar",
    "embaçarei": "embaçar",
    "embaçareis": "embaçar",
    "embaçarem": "embaçar",
    "embaçaremos": "embaçar",
    "embaçares": "embaçar",
    "embaçaria": "embaçar",
    "embaçariam": "embaçar",
    "embaçarias": "embaçar",
    "embaçarmo": "embaçar",
    "embaçarmos": "embaçar",
    "embaçará": "embaçar",
    "embaçarás": "embaçar",
    "embaçarão": "embaçar",
    "embaçaríamos": "embaçar",
    "embaçaríeis": "embaçar",
    "embaças": "embaçar",
    "embaçasse": "embaçar",
    "embaçassem": "embaçar",
    "embaçasses": "embaçar",
    "embaçaste": "embaçar",
    "embaçastes": "embaçar",
    "embaçava": "embaçar",
    "embaçavam": "embaçar",
    "embaçavas": "embaçar",
    "embaço": "embaçar",
    "embaçou": "embaçar",
    "embaçá": "embaçar",
    "embaçámo": "embaçar",
    "embaçámos": "embaçar",
    "embaçáramo": "embaçar",
    "embaçáramos": "embaçar",
    "embaçárei": "embaçar",
    "embaçáreis": "embaçar",
    "embaçásseis": "embaçar",
    "embaçássemos": "embaçar",
    "embaçávamo": "embaçar",
    "embaçávamos": "embaçar",
    "embaçávei": "embaçar",
    "embaçáveis": "embaçar",
    "embaí": "embair",
    "embaía": "embair",
    "embaíam": "embair",
    "embaíamo": "embair",
    "embaíamos": "embair",
    "embaías": "embair",
    "embaída": "embair",
    "embaídas": "embair",
    "embaído": "embair",
    "embaídos": "embair",
    "embaíei": "embair",
    "embaíeis": "embair",
    "embaímo": "embair",
    "embaímos": "embair",
    "embaíra": "embair",
    "embaíram": "embair",
    "embaíramo": "embair",
    "embaíramos": "embair",
    "embaíras": "embair",
    "embaíre": "embair",
    "embaírei": "embair",
    "embaíreis": "embair",
    "embaírem": "embair",
    "embaíres": "embair",
    "embaís": "embair",
    "embaísse": "embair",
    "embaísseis": "embair",
    "embaíssem": "embair",
    "embaíssemos": "embair",
    "embaísses": "embair",
    "embaíste": "embair",
    "embaístes": "embair",
    "embeba": "embeber",
    "embebais": "embeber",
    "embebam": "embeber",
    "embebamo": "embeber",
    "embebamos": "embeber",
    "embebas": "embeber",
    "embebe": "embeber",
    "embebece": "embebecer",
    "embebecei": "embebecer",
    "embebeceis": "embebecer",
    "embebecem": "embebecer",
    "embebecemo": "embebecer",
    "embebecemos": "embebecer",
    "embebecendo": "embebecer",
    "embebecera": "embebecer",
    "embebeceram": "embebecer",
    "embebeceras": "embebecer",
    "embebecerde": "embebecer",
    "embebecerdes": "embebecer",
    "embebecere": "embebecer",
    "embebecerei": "embebecer",
    "embebecereis": "embebecer",
    "embebecerem": "embebecer",
    "embebeceremos": "embebecer",
    "embebeceres": "embebecer",
    "embebeceria": "embebecer",
    "embebeceriam": "embebecer",
    "embebecerias": "embebecer",
    "embebecermo": "embebecer",
    "embebecermos": "embebecer",
    "embebecerá": "embebecer",
    "embebecerás": "embebecer",
    "embebecerão": "embebecer",
    "embebeceríamos": "embebecer",
    "embebeceríeis": "embebecer",
    "embebeces": "embebecer",
    "embebecesse": "embebecer",
    "embebecessem": "embebecer",
    "embebecesses": "embebecer",
    "embebeceste": "embebecer",
    "embebecestes": "embebecer",
    "embebeceu": "embebecer",
    "embebeci": "embebecer",
    "embebecia": "embebecer",
    "embebeciam": "embebecer",
    "embebecias": "embebecer",
    "embebecida": "embebecer",
    "embebecidas": "embebecer",
    "embebecido": "embebecer",
    "embebecidos": "embebecer",
    "embebecê": "embebecer",
    "embebecêramo": "embebecer",
    "embebecêramos": "embebecer",
    "embebecêrei": "embebecer",
    "embebecêreis": "embebecer",
    "embebecêsseis": "embebecer",
    "embebecêssemos": "embebecer",
    "embebecíamo": "embebecer",
    "embebecíamos": "embebecer",
    "embebecíei": "embebecer",
    "embebecíeis": "embebecer",
    "embebeda": "embebedar",
    "embebedada": "embebedar",
    "embebedadas": "embebedar",
    "embebedado": "embebedar",
    "embebedados": "embebedar",
    "embebedai": "embebedar",
    "embebedais": "embebedar",
    "embebedam": "embebedar",
    "embebedamentos": "embebedamento",
    "embebedamo": "embebedar",
    "embebedamos": "embebedar",
    "embebedando": "embebedar",
    "embebedara": "embebedar",
    "embebedaram": "embebedar",
    "embebedaras": "embebedar",
    "embebedarde": "embebedar",
    "embebedardes": "embebedar",
    "embebedare": "embebedar",
    "embebedarei": "embebedar",
    "embebedareis": "embebedar",
    "embebedarem": "embebedar",
    "embebedaremos": "embebedar",
    "embebedares": "embebedar",
    "embebedaria": "embebedar",
    "embebedariam": "embebedar",
    "embebedarias": "embebedar",
    "embebedarmo": "embebedar",
    "embebedarmos": "embebedar",
    "embebedará": "embebedar",
    "embebedarás": "embebedar",
    "embebedarão": "embebedar",
    "embebedaríamos": "embebedar",
    "embebedaríeis": "embebedar",
    "embebedas": "embebedar",
    "embebedasse": "embebedar",
    "embebedassem": "embebedar",
    "embebedasses": "embebedar",
    "embebedaste": "embebedar",
    "embebedastes": "embebedar",
    "embebedava": "embebedar",
    "embebedavam": "embebedar",
    "embebedavas": "embebedar",
    "embebede": "embebedar",
    "embebedei": "embebedar",
    "embebedeis": "embebedar",
    "embebedem": "embebedar",
    "embebedemo": "embebedar",
    "embebedemos": "embebedar",
    "embebedes": "embebedar",
    "embebedo": "embebedar",
    "embebedou": "embebedar",
    "embebedá": "embebedar",
    "embebedámo": "embebedar",
    "embebedámos": "embebedar",
    "embebedáramo": "embebedar",
    "embebedáramos": "embebedar",
    "embebedárei": "embebedar",
    "embebedáreis": "embebedar",
    "embebedásseis": "embebedar",
    "embebedássemos": "embebedar",
    "embebedávamo": "embebedar",
    "embebedávamos": "embebedar",
    "embebedávei": "embebedar",
    "embebedáveis": "embebedar",
    "embebei": "embeber",
    "embebeis": "embeber",
    "embebem": "embeber",
    "embebemo": "embeber",
    "embebemos": "embeber",
    "embebendo": "embeber",
    "embebera": "embeberar",
    "embeberada": "embeberar",
    "embeberadas": "embeberar",
    "embeberado": "embeberar",
    "embeberados": "embeberar",
    "embeberai": "embeberar",
    "embeberais": "embeberar",
    "embeberam": "embeberar",
    "embeberamo": "embeberar",
    "embeberamos": "embeberar",
    "embeberando": "embeberar",
    "embeberara": "embeberar",
    "embeberaram": "embeberar",
    "embeberaras": "embeberar",
    "embeberarde": "embeberar",
    "embeberardes": "embeberar",
    "embeberare": "embeberar",
    "embeberarei": "embeberar",
    "embeberareis": "embeberar",
    "embeberarem": "embeberar",
    "embeberaremos": "embeberar",
    "embeberares": "embeberar",
    "embeberaria": "embeberar",
    "embeberariam": "embeberar",
    "embeberarias": "embeberar",
    "embeberarmo": "embeberar",
    "embeberarmos": "embeberar",
    "embeberará": "embeberar",
    "embeberarás": "embeberar",
    "embeberarão": "embeberar",
    "embeberaríamos": "embeberar",
    "embeberaríeis": "embeberar",
    "embeberas": "embeberar",
    "embeberasse": "embeberar",
    "embeberassem": "embeberar",
    "embeberasses": "embeberar",
    "embeberaste": "embeberar",
    "embeberastes": "embeberar",
    "embeberava": "embeberar",
    "embeberavam": "embeberar",
    "embeberavas": "embeberar",
    "embeberde": "embeber",
    "embeberdes": "embeber",
    "embebere": "embeberar",
    "embeberei": "embeberar",
    "embebereis": "embeberar",
    "embeberem": "embeberar",
    "embeberemo": "embeberar",
    "embeberemos": "embeberar",
    "embeberes": "embeberar",
    "embeberia": "embeber",
    "embeberiam": "embeber",
    "embeberias": "embeber",
    "embebermo": "embeber",
    "embebermos": "embeber",
    "embebero": "embeberar",
    "embeberou": "embeberar",
    "embeberá": "embeberar",
    "embeberámo": "embeberar",
    "embeberámos": "embeberar",
    "embeberáramo": "embeberar",
    "embeberáramos": "embeberar",
    "embeberárei": "embeberar",
    "embeberáreis": "embeberar",
    "embeberás": "embeber",
    "embeberásseis": "embeberar",
    "embeberássemos": "embeberar",
    "embeberávamo": "embeberar",
    "embeberávamos": "embeberar",
    "embeberávei": "embeberar",
    "embeberáveis": "embeberar",
    "embeberão": "embeber",
    "embeberíamos": "embeber",
    "embeberíeis": "embeber",
    "embebes": "embeber",
    "embebesse": "embeber",
    "embebessem": "embeber",
    "embebesses": "embeber",
    "embebeste": "embeber",
    "embebestes": "embeber",
    "embebeu": "embeber",
    "embebeça": "embebecer",
    "embebeçais": "embebecer",
    "embebeçam": "embebecer",
    "embebeçamo": "embebecer",
    "embebeçamos": "embebecer",
    "embebeças": "embebecer",
    "embebeço": "embebecer",
    "embebi": "embeber",
    "embebia": "embeber",
    "embebiam": "embeber",
    "embebias": "embeber",
    "embebida": "embebido",
    "embebidas": "embebido",
    "embebido": "embeber",
    "embebidos": "embebido",
    "embebições": "embebição",
    "embebo": "embeber",
    "embebê": "embeber",
    "embebêramo": "embeber",
    "embebêramos": "embeber",
    "embebêrei": "embeber",
    "embebêreis": "embeber",
    "embebêsseis": "embeber",
    "embebêssemos": "embeber",
    "embebíamo": "embeber",
    "embebíamos": "embeber",
    "embebíei": "embeber",
    "embebíeis": "embeber",
    "embeice": "embeiçar",
    "embeicei": "embeiçar",
    "embeiceis": "embeiçar",
    "embeicem": "embeiçar",
    "embeicemo": "embeiçar",
    "embeicemos": "embeiçar",
    "embeices": "embeiçar",
    "embeiça": "embeiçar",
    "embeiçada": "embeiçar",
    "embeiçadas": "embeiçar",
    "embeiçado": "embeiçar",
    "embeiçados": "embeiçar",
    "embeiçadíssima": "embeiçado",
    "embeiçadíssimas": "embeiçado",
    "embeiçadíssimo": "embeiçado",
    "embeiçadíssimos": "embeiçado",
    "embeiçai": "embeiçar",
    "embeiçais": "embeiçar",
    "embeiçam": "embeiçar",
    "embeiçamentos": "embeiçamento",
    "embeiçamo": "embeiçar",
    "embeiçamos": "embeiçar",
    "embeiçando": "embeiçar",
    "embeiçara": "embeiçar",
    "embeiçaram": "embeiçar",
    "embeiçaras": "embeiçar",
    "embeiçarde": "embeiçar",
    "embeiçardes": "embeiçar",
    "embeiçare": "embeiçar",
    "embeiçarei": "embeiçar",
    "embeiçareis": "embeiçar",
    "embeiçarem": "embeiçar",
    "embeiçaremos": "embeiçar",
    "embeiçares": "embeiçar",
    "embeiçaria": "embeiçar",
    "embeiçariam": "embeiçar",
    "embeiçarias": "embeiçar",
    "embeiçarmo": "embeiçar",
    "embeiçarmos": "embeiçar",
    "embeiçará": "embeiçar",
    "embeiçarás": "embeiçar",
    "embeiçarão": "embeiçar",
    "embeiçaríamos": "embeiçar",
    "embeiçaríeis": "embeiçar",
    "embeiças": "embeiçar",
    "embeiçasse": "embeiçar",
    "embeiçassem": "embeiçar",
    "embeiçasses": "embeiçar",
    "embeiçaste": "embeiçar",
    "embeiçastes": "embeiçar",
    "embeiçava": "embeiçar",
    "embeiçavam": "embeiçar",
    "embeiçavas": "embeiçar",
    "embeiço": "embeiçar",
    "embeiçou": "embeiçar",
    "embeiçá": "embeiçar",
    "embeiçámo": "embeiçar",
    "embeiçámos": "embeiçar",
    "embeiçáramo": "embeiçar",
    "embeiçáramos": "embeiçar",
    "embeiçárei": "embeiçar",
    "embeiçáreis": "embeiçar",
    "embeiçásseis": "embeiçar",
    "embeiçássemos": "embeiçar",
    "embeiçávamo": "embeiçar",
    "embeiçávamos": "embeiçar",
    "embeiçávei": "embeiçar",
    "embeiçáveis": "embeiçar",
    "embeleca": "embelecar",
    "embelecada": "embelecar",
    "embelecadas": "embelecar",
    "embelecado": "embelecar",
    "embelecadora": "embelecador",
    "embelecadoras": "embelecador",
    "embelecadores": "embelecador",
    "embelecados": "embelecar",
    "embelecai": "embelecar",
    "embelecais": "embelecar",
    "embelecam": "embelecar",
    "embelecamo": "embelecar",
    "embelecamos": "embelecar",
    "embelecando": "embelecar",
    "embelecara": "embelecar",
    "embelecaram": "embelecar",
    "embelecaras": "embelecar",
    "embelecarde": "embelecar",
    "embelecardes": "embelecar",
    "embelecare": "embelecar",
    "embelecarei": "embelecar",
    "embelecareis": "embelecar",
    "embelecarem": "embelecar",
    "embelecaremos": "embelecar",
    "embelecares": "embelecar",
    "embelecaria": "embelecar",
    "embelecariam": "embelecar",
    "embelecarias": "embelecar",
    "embelecarmo": "embelecar",
    "embelecarmos": "embelecar",
    "embelecará": "embelecar",
    "embelecarás": "embelecar",
    "embelecarão": "embelecar",
    "embelecaríamos": "embelecar",
    "embelecaríeis": "embelecar",
    "embelecas": "embelecar",
    "embelecasse": "embelecar",
    "embelecassem": "embelecar",
    "embelecasses": "embelecar",
    "embelecaste": "embelecar",
    "embelecastes": "embelecar",
    "embelecava": "embelecar",
    "embelecavam": "embelecar",
    "embelecavas": "embelecar",
    "embelece": "embelecer",
    "embelecei": "embelecer",
    "embeleceis": "embelecer",
    "embelecem": "embelecer",
    "embelecemo": "embelecer",
    "embelecemos": "embelecer",
    "embelecendo": "embelecer",
    "embelecera": "embelecer",
    "embeleceram": "embelecer",
    "embeleceras": "embelecer",
    "embelecerde": "embelecer",
    "embelecerdes": "embelecer",
    "embelecere": "embelecer",
    "embelecerei": "embelecer",
    "embelecereis": "embelecer",
    "embelecerem": "embelecer",
    "embeleceremos": "embelecer",
    "embeleceres": "embelecer",
    "embeleceria": "embelecer",
    "embeleceriam": "embelecer",
    "embelecerias": "embelecer",
    "embelecermo": "embelecer",
    "embelecermos": "embelecer",
    "embelecerá": "embelecer",
    "embelecerás": "embelecer",
    "embelecerão": "embelecer",
    "embeleceríamos": "embelecer",
    "embeleceríeis": "embelecer",
    "embeleces": "embelecer",
    "embelecesse": "embelecer",
    "embelecessem": "embelecer",
    "embelecesses": "embelecer",
    "embeleceste": "embelecer",
    "embelecestes": "embelecer",
    "embeleceu": "embelecer",
    "embeleci": "embelecer",
    "embelecia": "embelecer",
    "embeleciam": "embelecer",
    "embelecias": "embelecer",
    "embelecida": "embelecer",
    "embelecidas": "embelecer",
    "embelecido": "embelecer",
    "embelecidos": "embelecer",
    "embeleco": "embelecar",
    "embelecos": "embeleco",
    "embelecou": "embelecar",
    "embelecá": "embelecar",
    "embelecámo": "embelecar",
    "embelecámos": "embelecar",
    "embelecáramo": "embelecar",
    "embelecáramos": "embelecar",
    "embelecárei": "embelecar",
    "embelecáreis": "embelecar",
    "embelecásseis": "embelecar",
    "embelecássemos": "embelecar",
    "embelecávamo": "embelecar",
    "embelecávamos": "embelecar",
    "embelecávei": "embelecar",
    "embelecáveis": "embelecar",
    "embelecê": "embelecer",
    "embelecêramo": "embelecer",
    "embelecêramos": "embelecer",
    "embelecêrei": "embelecer",
    "embelecêreis": "embelecer",
    "embelecêsseis": "embelecer",
    "embelecêssemos": "embelecer",
    "embelecíamo": "embelecer",
    "embelecíamos": "embelecer",
    "embelecíei": "embelecer",
    "embelecíeis": "embelecer",
    "embeleque": "embelecar",
    "embelequei": "embelecar",
    "embelequeis": "embelecar",
    "embelequem": "embelecar",
    "embelequemo": "embelecar",
    "embelequemos": "embelecar",
    "embeleques": "embelecar",
    "embeleza": "embelezar",
    "embelezada": "embelezar",
    "embelezadas": "embelezar",
    "embelezado": "embelezar",
    "embelezadora": "embelezador",
    "embelezadoras": "embelezador",
    "embelezadores": "embelezador",
    "embelezados": "embelezar",
    "embelezai": "embelezar",
    "embelezais": "embelezar",
    "embelezam": "embelezar",
    "embelezamentos": "embelezamento",
    "embelezamo": "embelezar",
    "embelezamos": "embelezar",
    "embelezando": "embelezar",
    "embelezantes": "embelezante",
    "embelezara": "embelezar",
    "embelezaram": "embelezar",
    "embelezaras": "embelezar",
    "embelezarde": "embelezar",
    "embelezardes": "embelezar",
    "embelezare": "embelezar",
    "embelezarei": "embelezar",
    "embelezareis": "embelezar",
    "embelezarem": "embelezar",
    "embelezaremos": "embelezar",
    "embelezares": "embelezar",
    "embelezaria": "embelezar",
    "embelezariam": "embelezar",
    "embelezarias": "embelezar",
    "embelezarmo": "embelezar",
    "embelezarmos": "embelezar",
    "embelezará": "embelezar",
    "embelezarás": "embelezar",
    "embelezarão": "embelezar",
    "embelezaríamos": "embelezar",
    "embelezaríeis": "embelezar",
    "embelezas": "embelezar",
    "embelezasse": "embelezar",
    "embelezassem": "embelezar",
    "embelezasses": "embelezar",
    "embelezaste": "embelezar",
    "embelezastes": "embelezar",
    "embelezava": "embelezar",
    "embelezavam": "embelezar",
    "embelezavas": "embelezar",
    "embeleze": "embelezar",
    "embelezei": "embelezar",
    "embelezeis": "embelezar",
    "embelezem": "embelezar",
    "embelezemo": "embelezar",
    "embelezemos": "embelezar",
    "embelezes": "embelezar",
    "embelezo": "embelezar",
    "embelezou": "embelezar",
    "embelezá": "embelezar",
    "embelezámo": "embelezar",
    "embelezámos": "embelezar",
    "embelezáramo": "embelezar",
    "embelezáramos": "embelezar",
    "embelezárei": "embelezar",
    "embelezáreis": "embelezar",
    "embelezásseis": "embelezar",
    "embelezássemos": "embelezar",
    "embelezávamo": "embelezar",
    "embelezávamos": "embelezar",
    "embelezávei": "embelezar",
    "embelezáveis": "embelezar",
    "embeleça": "embelecer",
    "embeleçais": "embelecer",
    "embeleçam": "embelecer",
    "embeleçamo": "embelecer",
    "embeleçamos": "embelecer",
    "embeleças": "embelecer",
    "embeleço": "embelecer",
    "embelga": "embelgar",
    "embelgada": "embelgar",
    "embelgadas": "embelgar",
    "embelgado": "embelgar",
    "embelgados": "embelgar",
    "embelgai": "embelgar",
    "embelgais": "embelgar",
    "embelgam": "embelgar",
    "embelgamo": "embelgar",
    "embelgamos": "embelgar",
    "embelgando": "embelgar",
    "embelgara": "embelgar",
    "embelgaram": "embelgar",
    "embelgaras": "embelgar",
    "embelgarde": "embelgar",
    "embelgardes": "embelgar",
    "embelgare": "embelgar",
    "embelgarei": "embelgar",
    "embelgareis": "embelgar",
    "embelgarem": "embelgar",
    "embelgaremos": "embelgar",
    "embelgares": "embelgar",
    "embelgaria": "embelgar",
    "embelgariam": "embelgar",
    "embelgarias": "embelgar",
    "embelgarmo": "embelgar",
    "embelgarmos": "embelgar",
    "embelgará": "embelgar",
    "embelgarás": "embelgar",
    "embelgarão": "embelgar",
    "embelgaríamos": "embelgar",
    "embelgaríeis": "embelgar",
    "embelgas": "embelgar",
    "embelgasse": "embelgar",
    "embelgassem": "embelgar",
    "embelgasses": "embelgar",
    "embelgaste": "embelgar",
    "embelgastes": "embelgar",
    "embelgava": "embelgar",
    "embelgavam": "embelgar",
    "embelgavas": "embelgar",
    "embelgações": "embelgação",
    "embelgo": "embelgar",
    "embelgou": "embelgar",
    "embelgue": "embelgar",
    "embelguei": "embelgar",
    "embelgueis": "embelgar",
    "embelguem": "embelgar",
    "embelguemo": "embelgar",
    "embelguemos": "embelgar",
    "embelgues": "embelgar",
    "embelgá": "embelgar",
    "embelgámo": "embelgar",
    "embelgámos": "embelgar",
    "embelgáramo": "embelgar",
    "embelgáramos": "embelgar",
    "embelgárei": "embelgar",
    "embelgáreis": "embelgar",
    "embelgásseis": "embelgar",
    "embelgássemos": "embelgar",
    "embelgávamo": "embelgar",
    "embelgávamos": "embelgar",
    "embelgávei": "embelgar",
    "embelgáveis": "embelgar",
    "emberizas": "emberiza",
    "embesoira": "embesoirar",
    "embesoirada": "embesoirar",
    "embesoiradas": "embesoirar",
    "embesoirado": "embesoirar",
    "embesoirados": "embesoirar",
    "embesoirai": "embesoirar",
    "embesoirais": "embesoirar",
    "embesoiram": "embesoirar",
    "embesoiramo": "embesoirar",
    "embesoiramos": "embesoirar",
    "embesoirando": "embesoirar",
    "embesoirara": "embesoirar",
    "embesoiraram": "embesoirar",
    "embesoiraras": "embesoirar",
    "embesoirarde": "embesoirar",
    "embesoirardes": "embesoirar",
    "embesoirare": "embesoirar",
    "embesoirarei": "embesoirar",
    "embesoirareis": "embesoirar",
    "embesoirarem": "embesoirar",
    "embesoiraremos": "embesoirar",
    "embesoirares": "embesoirar",
    "embesoiraria": "embesoirar",
    "embesoirariam": "embesoirar",
    "embesoirarias": "embesoirar",
    "embesoirarmo": "embesoirar",
    "embesoirarmos": "embesoirar",
    "embesoirará": "embesoirar",
    "embesoirarás": "embesoirar",
    "embesoirarão": "embesoirar",
    "embesoiraríamos": "embesoirar",
    "embesoiraríeis": "embesoirar",
    "embesoiras": "embesoirar",
    "embesoirasse": "embesoirar",
    "embesoirassem": "embesoirar",
    "embesoirasses": "embesoirar",
    "embesoiraste": "embesoirar",
    "embesoirastes": "embesoirar",
    "embesoirava": "embesoirar",
    "embesoiravam": "embesoirar",
    "embesoiravas": "embesoirar",
    "embesoire": "embesoirar",
    "embesoirei": "embesoirar",
    "embesoireis": "embesoirar",
    "embesoirem": "embesoirar",
    "embesoiremo": "embesoirar",
    "embesoiremos": "embesoirar",
    "embesoires": "embesoirar",
    "embesoiro": "embesoirar",
    "embesoirou": "embesoirar",
    "embesoirá": "embesoirar",
    "embesoirámo": "embesoirar",
    "embesoirámos": "embesoirar",
    "embesoiráramo": "embesoirar",
    "embesoiráramos": "embesoirar",
    "embesoirárei": "embesoirar",
    "embesoiráreis": "embesoirar",
    "embesoirásseis": "embesoirar",
    "embesoirássemos": "embesoirar",
    "embesoirávamo": "embesoirar",
    "embesoirávamos": "embesoirar",
    "embesoirávei": "embesoirar",
    "embesoiráveis": "embesoirar",
    "embesoura": "embesourar",
    "embesourada": "embesourar",
    "embesouradas": "embesourar",
    "embesourado": "embesourar",
    "embesourados": "embesourar",
    "embesourai": "embesourar",
    "embesourais": "embesourar",
    "embesouram": "embesourar",
    "embesouramo": "embesourar",
    "embesouramos": "embesourar",
    "embesourando": "embesourar",
    "embesourara": "embesourar",
    "embesouraram": "embesourar",
    "embesouraras": "embesourar",
    "embesourarde": "embesourar",
    "embesourardes": "embesourar",
    "embesourare": "embesourar",
    "embesourarei": "embesourar",
    "embesourareis": "embesourar",
    "embesourarem": "embesourar",
    "embesouraremos": "embesourar",
    "embesourares": "embesourar",
    "embesouraria": "embesourar",
    "embesourariam": "embesourar",
    "embesourarias": "embesourar",
    "embesourarmo": "embesourar",
    "embesourarmos": "embesourar",
    "embesourará": "embesourar",
    "embesourarás": "embesourar",
    "embesourarão": "embesourar",
    "embesouraríamos": "embesourar",
    "embesouraríeis": "embesourar",
    "embesouras": "embesourar",
    "embesourasse": "embesourar",
    "embesourassem": "embesourar",
    "embesourasses": "embesourar",
    "embesouraste": "embesourar",
    "embesourastes": "embesourar",
    "embesourava": "embesourar",
    "embesouravam": "embesourar",
    "embesouravas": "embesourar",
    "embesoure": "embesourar",
    "embesourei": "embesourar",
    "embesoureis": "embesourar",
    "embesourem": "embesourar",
    "embesouremo": "embesourar",
    "embesouremos": "embesourar",
    "embesoures": "embesourar",
    "embesouro": "embesourar",
    "embesourou": "embesourar",
    "embesourá": "embesourar",
    "embesourámo": "embesourar",
    "embesourámos": "embesourar",
    "embesouráramo": "embesourar",
    "embesouráramos": "embesourar",
    "embesourárei": "embesourar",
    "embesouráreis": "embesourar",
    "embesourásseis": "embesourar",
    "embesourássemos": "embesourar",
    "embesourávamo": "embesourar",
    "embesourávamos": "embesourar",
    "embesourávei": "embesourar",
    "embesouráveis": "embesourar",
    "embespinha": "embespinhar",
    "embespinhada": "embespinhar",
    "embespinhadas": "embespinhar",
    "embespinhado": "embespinhar",
    "embespinhados": "embespinhar",
    "embespinhai": "embespinhar",
    "embespinhais": "embespinhar",
    "embespinham": "embespinhar",
    "embespinhamo": "embespinhar",
    "embespinhamos": "embespinhar",
    "embespinhando": "embespinhar",
    "embespinhara": "embespinhar",
    "embespinharam": "embespinhar",
    "embespinharas": "embespinhar",
    "embespinharde": "embespinhar",
    "embespinhardes": "embespinhar",
    "embespinhare": "embespinhar",
    "embespinharei": "embespinhar",
    "embespinhareis": "embespinhar",
    "embespinharem": "embespinhar",
    "embespinharemos": "embespinhar",
    "embespinhares": "embespinhar",
    "embespinharia": "embespinhar",
    "embespinhariam": "embespinhar",
    "embespinharias": "embespinhar",
    "embespinharmo": "embespinhar",
    "embespinharmos": "embespinhar",
    "embespinhará": "embespinhar",
    "embespinharás": "embespinhar",
    "embespinharão": "embespinhar",
    "embespinharíamos": "embespinhar",
    "embespinharíeis": "embespinhar",
    "embespinhas": "embespinhar",
    "embespinhasse": "embespinhar",
    "embespinhassem": "embespinhar",
    "embespinhasses": "embespinhar",
    "embespinhaste": "embespinhar",
    "embespinhastes": "embespinhar",
    "embespinhava": "embespinhar",
    "embespinhavam": "embespinhar",
    "embespinhavas": "embespinhar",
    "embespinhe": "embespinhar",
    "embespinhei": "embespinhar",
    "embespinheis": "embespinhar",
    "embespinhem": "embespinhar",
    "embespinhemo": "embespinhar",
    "embespinhemos": "embespinhar",
    "embespinhes": "embespinhar",
    "embespinho": "embespinhar",
    "embespinhou": "embespinhar",
    "embespinhá": "embespinhar",
    "embespinhámo": "embespinhar",
    "embespinhámos": "embespinhar",
    "embespinháramo": "embespinhar",
    "embespinháramos": "embespinhar",
    "embespinhárei": "embespinhar",
    "embespinháreis": "embespinhar",
    "embespinhásseis": "embespinhar",
    "embespinhássemos": "embespinhar",
    "embespinhávamo": "embespinhar",
    "embespinhávamos": "embespinhar",
    "embespinhávei": "embespinhar",
    "embespinháveis": "embespinhar",
    "embesta": "embestar",
    "embestada": "embestar",
    "embestadas": "embestar",
    "embestado": "embestar",
    "embestados": "embestar",
    "embestai": "embestar",
    "embestais": "embestar",
    "embestam": "embestar",
    "embestamo": "embestar",
    "embestamos": "embestar",
    "embestando": "embestar",
    "embestara": "embestar",
    "embestaram": "embestar",
    "embestaras": "embestar",
    "embestarde": "embestar",
    "embestardes": "embestar",
    "embestare": "embestar",
    "embestarei": "embestar",
    "embestareis": "embestar",
    "embestarem": "embestar",
    "embestaremos": "embestar",
    "embestares": "embestar",
    "embestaria": "embestar",
    "embestariam": "embestar",
    "embestarias": "embestar",
    "embestarmo": "embestar",
    "embestarmos": "embestar",
    "embestará": "embestar",
    "embestarás": "embestar",
    "embestarão": "embestar",
    "embestaríamos": "embestar",
    "embestaríeis": "embestar",
    "embestas": "embestar",
    "embestasse": "embestar",
    "embestassem": "embestar",
    "embestasses": "embestar",
    "embestaste": "embestar",
    "embestastes": "embestar",
    "embestava": "embestar",
    "embestavam": "embestar",
    "embestavas": "embestar",
    "embeste": "embestar",
    "embestei": "embestar",
    "embesteis": "embestar",
    "embestem": "embestar",
    "embestemo": "embestar",
    "embestemos": "embestar",
    "embestes": "embestar",
    "embesto": "embestar",
    "embestou": "embestar",
    "embestá": "embestar",
    "embestámo": "embestar",
    "embestámos": "embestar",
    "embestáramo": "embestar",
    "embestáramos": "embestar",
    "embestárei": "embestar",
    "embestáreis": "embestar",
    "embestásseis": "embestar",
    "embestássemos": "embestar",
    "embestávamo": "embestar",
    "embestávamos": "embestar",
    "embestávei": "embestar",
    "embestáveis": "embestar",
    "embetesga": "embetesgar",
    "embetesgada": "embetesgar",
    "embetesgadas": "embetesgar",
    "embetesgado": "embetesgar",
    "embetesgados": "embetesgar",
    "embetesgai": "embetesgar",
    "embetesgais": "embetesgar",
    "embetesgam": "embetesgar",
    "embetesgamo": "embetesgar",
    "embetesgamos": "embetesgar",
    "embetesgando": "embetesgar",
    "embetesgara": "embetesgar",
    "embetesgaram": "embetesgar",
    "embetesgaras": "embetesgar",
    "embetesgarde": "embetesgar",
    "embetesgardes": "embetesgar",
    "embetesgare": "embetesgar",
    "embetesgarei": "embetesgar",
    "embetesgareis": "embetesgar",
    "embetesgarem": "embetesgar",
    "embetesgaremos": "embetesgar",
    "embetesgares": "embetesgar",
    "embetesgaria": "embetesgar",
    "embetesgariam": "embetesgar",
    "embetesgarias": "embetesgar",
    "embetesgarmo": "embetesgar",
    "embetesgarmos": "embetesgar",
    "embetesgará": "embetesgar",
    "embetesgarás": "embetesgar",
    "embetesgarão": "embetesgar",
    "embetesgaríamos": "embetesgar",
    "embetesgaríeis": "embetesgar",
    "embetesgas": "embetesgar",
    "embetesgasse": "embetesgar",
    "embetesgassem": "embetesgar",
    "embetesgasses": "embetesgar",
    "embetesgaste": "embetesgar",
    "embetesgastes": "embetesgar",
    "embetesgava": "embetesgar",
    "embetesgavam": "embetesgar",
    "embetesgavas": "embetesgar",
    "embetesgo": "embetesgar",
    "embetesgou": "embetesgar",
    "embetesgue": "embetesgar",
    "embetesguei": "embetesgar",
    "embetesgueis": "embetesgar",
    "embetesguem": "embetesgar",
    "embetesguemo": "embetesgar",
    "embetesguemos": "embetesgar",
    "embetesgues": "embetesgar",
    "embetesgá": "embetesgar",
    "embetesgámo": "embetesgar",
    "embetesgámos": "embetesgar",
    "embetesgáramo": "embetesgar",
    "embetesgáramos": "embetesgar",
    "embetesgárei": "embetesgar",
    "embetesgáreis": "embetesgar",
    "embetesgásseis": "embetesgar",
    "embetesgássemos": "embetesgar",
    "embetesgávamo": "embetesgar",
    "embetesgávamos": "embetesgar",
    "embetesgávei": "embetesgar",
    "embetesgáveis": "embetesgar",
    "embetuma": "embetumar",
    "embetumada": "embetumar",
    "embetumadas": "embetumar",
    "embetumado": "embetumar",
    "embetumados": "embetumar",
    "embetumai": "embetumar",
    "embetumais": "embetumar",
    "embetumam": "embetumar",
    "embetumamo": "embetumar",
    "embetumamos": "embetumar",
    "embetumando": "embetumar",
    "embetumara": "embetumar",
    "embetumaram": "embetumar",
    "embetumaras": "embetumar",
    "embetumarde": "embetumar",
    "embetumardes": "embetumar",
    "embetumare": "embetumar",
    "embetumarei": "embetumar",
    "embetumareis": "embetumar",
    "embetumarem": "embetumar",
    "embetumaremos": "embetumar",
    "embetumares": "embetumar",
    "embetumaria": "embetumar",
    "embetumariam": "embetumar",
    "embetumarias": "embetumar",
    "embetumarmo": "embetumar",
    "embetumarmos": "embetumar",
    "embetumará": "embetumar",
    "embetumarás": "embetumar",
    "embetumarão": "embetumar",
    "embetumaríamos": "embetumar",
    "embetumaríeis": "embetumar",
    "embetumas": "embetumar",
    "embetumasse": "embetumar",
    "embetumassem": "embetumar",
    "embetumasses": "embetumar",
    "embetumaste": "embetumar",
    "embetumastes": "embetumar",
    "embetumava": "embetumar",
    "embetumavam": "embetumar",
    "embetumavas": "embetumar",
    "embetume": "embetumar",
    "embetumei": "embetumar",
    "embetumeis": "embetumar",
    "embetumem": "embetumar",
    "embetumemo": "embetumar",
    "embetumemos": "embetumar",
    "embetumes": "embetumar",
    "embetumo": "embetumar",
    "embetumou": "embetumar",
    "embetumá": "embetumar",
    "embetumámo": "embetumar",
    "embetumámos": "embetumar",
    "embetumáramo": "embetumar",
    "embetumáramos": "embetumar",
    "embetumárei": "embetumar",
    "embetumáreis": "embetumar",
    "embetumásseis": "embetumar",
    "embetumássemos": "embetumar",
    "embetumávamo": "embetumar",
    "embetumávamos": "embetumar",
    "embetumávei": "embetumar",
    "embetumáveis": "embetumar",
    "embevece": "embevecer",
    "embevecei": "embevecer",
    "embeveceis": "embevecer",
    "embevecem": "embevecer",
    "embevecemo": "embevecer",
    "embevecemos": "embevecer",
    "embevecendo": "embevecer",
    "embevecera": "embevecer",
    "embeveceram": "embevecer",
    "embeveceras": "embevecer",
    "embevecerde": "embevecer",
    "embevecerdes": "embevecer",
    "embevecere": "embevecer",
    "embevecerei": "embevecer",
    "embevecereis": "embevecer",
    "embevecerem": "embevecer",
    "embeveceremos": "embevecer",
    "embeveceres": "embevecer",
    "embeveceria": "embevecer",
    "embeveceriam": "embevecer",
    "embevecerias": "embevecer",
    "embevecermo": "embevecer",
    "embevecermos": "embevecer",
    "embevecerá": "embevecer",
    "embevecerás": "embevecer",
    "embevecerão": "embevecer",
    "embeveceríamos": "embevecer",
    "embeveceríeis": "embevecer",
    "embeveces": "embevecer",
    "embevecesse": "embevecer",
    "embevecessem": "embevecer",
    "embevecesses": "embevecer",
    "embeveceste": "embevecer",
    "embevecestes": "embevecer",
    "embeveceu": "embevecer",
    "embeveci": "embevecer",
    "embevecia": "embevecer",
    "embeveciam": "embevecer",
    "embevecias": "embevecer",
    "embevecida": "embevecido",
    "embevecidas": "embevecido",
    "embevecido": "embevecer",
    "embevecidos": "embevecido",
    "embevecidíssima": "embevecido",
    "embevecidíssimas": "embevecido",
    "embevecidíssimo": "embevecido",
    "embevecidíssimos": "embevecido",
    "embevecimentos": "embevecimento",
    "embevecê": "embevecer",
    "embevecêramo": "embevecer",
    "embevecêramos": "embevecer",
    "embevecêrei": "embevecer",
    "embevecêreis": "embevecer",
    "embevecêsseis": "embevecer",
    "embevecêssemos": "embevecer",
    "embevecíamo": "embevecer",
    "embevecíamos": "embevecer",
    "embevecíei": "embevecer",
    "embevecíeis": "embevecer",
    "embeveça": "embevecer",
    "embeveçais": "embevecer",
    "embeveçam": "embevecer",
    "embeveçamo": "embevecer",
    "embeveçamos": "embevecer",
    "embeveças": "embevecer",
    "embeveço": "embevecer",
    "embezerra": "embezerrar",
    "embezerrada": "embezerrar",
    "embezerradas": "embezerrar",
    "embezerrado": "embezerrar",
    "embezerrados": "embezerrar",
    "embezerrai": "embezerrar",
    "embezerrais": "embezerrar",
    "embezerram": "embezerrar",
    "embezerramo": "embezerrar",
    "embezerramos": "embezerrar",
    "embezerrando": "embezerrar",
    "embezerrara": "embezerrar",
    "embezerraram": "embezerrar",
    "embezerraras": "embezerrar",
    "embezerrarde": "embezerrar",
    "embezerrardes": "embezerrar",
    "embezerrare": "embezerrar",
    "embezerrarei": "embezerrar",
    "embezerrareis": "embezerrar",
    "embezerrarem": "embezerrar",
    "embezerraremos": "embezerrar",
    "embezerrares": "embezerrar",
    "embezerraria": "embezerrar",
    "embezerrariam": "embezerrar",
    "embezerrarias": "embezerrar",
    "embezerrarmo": "embezerrar",
    "embezerrarmos": "embezerrar",
    "embezerrará": "embezerrar",
    "embezerrarás": "embezerrar",
    "embezerrarão": "embezerrar",
    "embezerraríamos": "embezerrar",
    "embezerraríeis": "embezerrar",
    "embezerras": "embezerrar",
    "embezerrasse": "embezerrar",
    "embezerrassem": "embezerrar",
    "embezerrasses": "embezerrar",
    "embezerraste": "embezerrar",
    "embezerrastes": "embezerrar",
    "embezerrava": "embezerrar",
    "embezerravam": "embezerrar",
    "embezerravas": "embezerrar",
    "embezerre": "embezerrar",
    "embezerrei": "embezerrar",
    "embezerreis": "embezerrar",
    "embezerrem": "embezerrar",
    "embezerremo": "embezerrar",
    "embezerremos": "embezerrar",
    "embezerres": "embezerrar",
    "embezerro": "embezerrar",
    "embezerrou": "embezerrar",
    "embezerrá": "embezerrar",
    "embezerrámo": "embezerrar",
    "embezerrámos": "embezerrar",
    "embezerráramo": "embezerrar",
    "embezerráramos": "embezerrar",
    "embezerrárei": "embezerrar",
    "embezerráreis": "embezerrar",
    "embezerrásseis": "embezerrar",
    "embezerrássemos": "embezerrar",
    "embezerrávamo": "embezerrar",
    "embezerrávamos": "embezerrar",
    "embezerrávei": "embezerrar",
    "embezerráveis": "embezerrar",
    "embiaras": "embiara",
    "embica": "embicar",
    "embicada": "embicar",
    "embicadas": "embicar",
    "embicado": "embicar",
    "embicadora": "embicador",
    "embicadoras": "embicador",
    "embicadores": "embicador",
    "embicados": "embicar",
    "embicaduras": "embicadura",
    "embicais": "embicar",
    "embicam": "embicar",
    "embicamo": "embicar",
    "embicamos": "embicar",
    "embicando": "embicar",
    "embicara": "embicar",
    "embicaram": "embicar",
    "embicaras": "embicar",
    "embicardes": "embicar",
    "embicarei": "embicar",
    "embicareis": "embicar",
    "embicarem": "embicar",
    "embicaremos": "embicar",
    "embicares": "embicar",
    "embicaria": "embicar",
    "embicariam": "embicar",
    "embicarias": "embicar",
    "embicarmo": "embicar",
    "embicarmos": "embicar",
    "embicará": "embicar",
    "embicarás": "embicar",
    "embicarão": "embicar",
    "embicaríamos": "embicar",
    "embicaríeis": "embicar",
    "embicas": "embicar",
    "embicasse": "embicar",
    "embicassem": "embicar",
    "embicasses": "embicar",
    "embicaste": "embicar",
    "embicastes": "embicar",
    "embicava": "embicar",
    "embicavam": "embicar",
    "embicavas": "embicar",
    "embico": "embicar",
    "embicou": "embicar",
    "embicámo": "embicar",
    "embicámos": "embicar",
    "embicáramo": "embicar",
    "embicáramos": "embicar",
    "embicáreis": "embicar",
    "embicásseis": "embicar",
    "embicássemos": "embicar",
    "embicávamo": "embicar",
    "embicávamos": "embicar",
    "embicáveis": "embicar",
    "embidas": "embida",
    "embigadas": "embigada",
    "embigos": "embigo",
    "embilha": "embilhar",
    "embilhada": "embilhar",
    "embilhadas": "embilhar",
    "embilhado": "embilhar",
    "embilhados": "embilhar",
    "embilhai": "embilhar",
    "embilhais": "embilhar",
    "embilham": "embilhar",
    "embilhamo": "embilhar",
    "embilhamos": "embilhar",
    "embilhando": "embilhar",
    "embilhara": "embilhar",
    "embilharam": "embilhar",
    "embilharas": "embilhar",
    "embilharde": "embilhar",
    "embilhardes": "embilhar",
    "embilhare": "embilhar",
    "embilharei": "embilhar",
    "embilhareis": "embilhar",
    "embilharem": "embilhar",
    "embilharemos": "embilhar",
    "embilhares": "embilhar",
    "embilharia": "embilhar",
    "embilhariam": "embilhar",
    "embilharias": "embilhar",
    "embilharmo": "embilhar",
    "embilharmos": "embilhar",
    "embilhará": "embilhar",
    "embilharás": "embilhar",
    "embilharão": "embilhar",
    "embilharíamos": "embilhar",
    "embilharíeis": "embilhar",
    "embilhas": "embilhar",
    "embilhasse": "embilhar",
    "embilhassem": "embilhar",
    "embilhasses": "embilhar",
    "embilhaste": "embilhar",
    "embilhastes": "embilhar",
    "embilhava": "embilhar",
    "embilhavam": "embilhar",
    "embilhavas": "embilhar",
    "embilhe": "embilhar",
    "embilhei": "embilhar",
    "embilheis": "embilhar",
    "embilhem": "embilhar",
    "embilhemo": "embilhar",
    "embilhemos": "embilhar",
    "embilhes": "embilhar",
    "embilho": "embilhar",
    "embilhou": "embilhar",
    "embilhá": "embilhar",
    "embilhámo": "embilhar",
    "embilhámos": "embilhar",
    "embilháramo": "embilhar",
    "embilháramos": "embilhar",
    "embilhárei": "embilhar",
    "embilháreis": "embilhar",
    "embilhásseis": "embilhar",
    "embilhássemos": "embilhar",
    "embilhávamo": "embilhar",
    "embilhávamos": "embilhar",
    "embilhávei": "embilhar",
    "embilháveis": "embilhar",
    "embioca": "embiocar",
    "embiocada": "embiocar",
    "embiocadas": "embiocar",
    "embiocado": "embiocar",
    "embiocados": "embiocar",
    "embiocai": "embiocar",
    "embiocais": "embiocar",
    "embiocam": "embiocar",
    "embiocamo": "embiocar",
    "embiocamos": "embiocar",
    "embiocando": "embiocar",
    "embiocara": "embiocar",
    "embiocaram": "embiocar",
    "embiocaras": "embiocar",
    "embiocarde": "embiocar",
    "embiocardes": "embiocar",
    "embiocare": "embiocar",
    "embiocarei": "embiocar",
    "embiocareis": "embiocar",
    "embiocarem": "embiocar",
    "embiocaremos": "embiocar",
    "embiocares": "embiocar",
    "embiocaria": "embiocar",
    "embiocariam": "embiocar",
    "embiocarias": "embiocar",
    "embiocarmo": "embiocar",
    "embiocarmos": "embiocar",
    "embiocará": "embiocar",
    "embiocarás": "embiocar",
    "embiocarão": "embiocar",
    "embiocaríamos": "embiocar",
    "embiocaríeis": "embiocar",
    "embiocas": "embiocar",
    "embiocasse": "embiocar",
    "embiocassem": "embiocar",
    "embiocasses": "embiocar",
    "embiocaste": "embiocar",
    "embiocastes": "embiocar",
    "embiocava": "embiocar",
    "embiocavam": "embiocar",
    "embiocavas": "embiocar",
    "embioco": "embiocar",
    "embiocou": "embiocar",
    "embiocá": "embiocar",
    "embiocámo": "embiocar",
    "embiocámos": "embiocar",
    "embiocáramo": "embiocar",
    "embiocáramos": "embiocar",
    "embiocárei": "embiocar",
    "embiocáreis": "embiocar",
    "embiocásseis": "embiocar",
    "embiocássemos": "embiocar",
    "embiocávamo": "embiocar",
    "embiocávamos": "embiocar",
    "embiocávei": "embiocar",
    "embiocáveis": "embiocar",
    "embioque": "embiocar",
    "embioquei": "embiocar",
    "embioqueis": "embiocar",
    "embioquem": "embiocar",
    "embioquemo": "embiocar",
    "embioquemos": "embiocar",
    "embioques": "embiocar",
    "embique": "embicar",
    "embiquei": "embicar",
    "embiqueis": "embicar",
    "embiquem": "embicar",
    "embiquemos": "embicar",
    "embiques": "embicar",
    "embiras": "embira",
    "embirra": "embirrar",
    "embirrada": "embirrar",
    "embirradas": "embirrar",
    "embirrado": "embirrar",
    "embirrados": "embirrar",
    "embirrai": "embirrar",
    "embirrais": "embirrar",
    "embirram": "embirrar",
    "embirramo": "embirrar",
    "embirramos": "embirrar",
    "embirrando": "embirrar",
    "embirrantes": "embirrante",
    "embirrara": "embirrar",
    "embirraram": "embirrar",
    "embirraras": "embirrar",
    "embirrardes": "embirrar",
    "embirrarei": "embirrar",
    "embirrareis": "embirrar",
    "embirrarem": "embirrar",
    "embirraremos": "embirrar",
    "embirrares": "embirrar",
    "embirraria": "embirrar",
    "embirrariam": "embirrar",
    "embirrarias": "embirrar",
    "embirrarmo": "embirrar",
    "embirrarmos": "embirrar",
    "embirrará": "embirrar",
    "embirrarás": "embirrar",
    "embirrarão": "embirrar",
    "embirraríamos": "embirrar",
    "embirraríeis": "embirrar",
    "embirras": "embirrar",
    "embirrasse": "embirrar",
    "embirrassem": "embirrar",
    "embirrasses": "embirrar",
    "embirraste": "embirrar",
    "embirrastes": "embirrar",
    "embirrativa": "embirrativo",
    "embirrativas": "embirrativo",
    "embirrativos": "embirrativo",
    "embirrava": "embirrar",
    "embirravam": "embirrar",
    "embirravas": "embirrar",
    "embirrações": "embirração",
    "embirre": "embirrar",
    "embirrei": "embirrar",
    "embirreis": "embirrar",
    "embirrem": "embirrar",
    "embirremo": "embirrar",
    "embirremos": "embirrar",
    "embirrenta": "embirrento",
    "embirrentas": "embirrento",
    "embirrentos": "embirrento",
    "embirres": "embirrar",
    "embirro": "embirrar",
    "embirrou": "embirrar",
    "embirrámo": "embirrar",
    "embirrámos": "embirrar",
    "embirráramo": "embirrar",
    "embirráramos": "embirrar",
    "embirráreis": "embirrar",
    "embirrásseis": "embirrar",
    "embirrássemos": "embirrar",
    "embirrávamo": "embirrar",
    "embirrávamos": "embirrar",
    "embirráveis": "embirrar",
    "embirrânçias": "embirrânçia",
    "emblema": "emblemar",
    "emblemada": "emblemar",
    "emblemadas": "emblemar",
    "emblemado": "emblemar",
    "emblemados": "emblemar",
    "emblemai": "emblemar",
    "emblemais": "emblemar",
    "emblemam": "emblemar",
    "emblemamo": "emblemar",
    "emblemamos": "emblemar",
    "emblemando": "emblemar",
    "emblemara": "emblemar",
    "emblemaram": "emblemar",
    "emblemaras": "emblemar",
    "emblemarde": "emblemar",
    "emblemardes": "emblemar",
    "emblemare": "emblemar",
    "emblemarei": "emblemar",
    "emblemareis": "emblemar",
    "emblemarem": "emblemar",
    "emblemaremos": "emblemar",
    "emblemares": "emblemar",
    "emblemaria": "emblemar",
    "emblemariam": "emblemar",
    "emblemarias": "emblemaria",
    "emblemarmo": "emblemar",
    "emblemarmos": "emblemar",
    "emblemará": "emblemar",
    "emblemarás": "emblemar",
    "emblemarão": "emblemar",
    "emblemaríamos": "emblemar",
    "emblemaríeis": "emblemar",
    "emblemas": "emblemar",
    "emblemasse": "emblemar",
    "emblemassem": "emblemar",
    "emblemasses": "emblemar",
    "emblemaste": "emblemar",
    "emblemastes": "emblemar",
    "emblemava": "emblemar",
    "emblemavam": "emblemar",
    "emblemavas": "emblemar",
    "embleme": "emblemar",
    "emblemei": "emblemar",
    "emblemeis": "emblemar",
    "emblemem": "emblemar",
    "emblememo": "emblemar",
    "emblememos": "emblemar",
    "emblemes": "emblemar",
    "emblemo": "emblemar",
    "emblemou": "emblemar",
    "emblemá": "emblemar",
    "emblemámo": "emblemar",
    "emblemámos": "emblemar",
    "emblemáramo": "emblemar",
    "emblemáramos": "emblemar",
    "emblemárei": "emblemar",
    "emblemáreis": "emblemar",
    "emblemásseis": "emblemar",
    "emblemássemos": "emblemar",
    "emblemática": "emblemático",
    "emblemáticas": "emblemático",
    "emblemáticos": "emblemático",
    "emblemávamo": "emblemar",
    "emblemávamos": "emblemar",
    "emblemávei": "emblemar",
    "emblemáveis": "emblemar",
    "emboba": "embobar",
    "embobada": "embobar",
    "embobadas": "embobar",
    "embobado": "embobar",
    "embobados": "embobar",
    "embobai": "embobar",
    "embobais": "embobar",
    "embobam": "embobar",
    "embobamo": "embobar",
    "embobamos": "embobar",
    "embobando": "embobar",
    "embobara": "embobar",
    "embobaram": "embobar",
    "embobaras": "embobar",
    "embobarde": "embobar",
    "embobardes": "embobar",
    "embobare": "embobar",
    "embobarei": "embobar",
    "embobareis": "embobar",
    "embobarem": "embobar",
    "embobaremos": "embobar",
    "embobares": "embobar",
    "embobaria": "embobar",
    "embobariam": "embobar",
    "embobarias": "embobar",
    "embobarmo": "embobar",
    "embobarmos": "embobar",
    "embobará": "embobar",
    "embobarás": "embobar",
    "embobarão": "embobar",
    "embobaríamos": "embobar",
    "embobaríeis": "embobar",
    "embobas": "embobar",
    "embobasse": "embobar",
    "embobassem": "embobar",
    "embobasses": "embobar",
    "embobaste": "embobar",
    "embobastes": "embobar",
    "embobava": "embobar",
    "embobavam": "embobar",
    "embobavas": "embobar",
    "embobe": "embobar",
    "embobei": "embobar",
    "embobeis": "embobar",
    "embobem": "embobar",
    "embobemo": "embobar",
    "embobemos": "embobar",
    "embobes": "embobar",
    "embobina": "embobinar",
    "embobinada": "embobinar",
    "embobinadas": "embobinar",
    "embobinado": "embobinar",
    "embobinadora": "embobinador",
    "embobinadoras": "embobinadora",
    "embobinadores": "embobinador",
    "embobinados": "embobinar",
    "embobinai": "embobinar",
    "embobinais": "embobinar",
    "embobinam": "embobinar",
    "embobinamo": "embobinar",
    "embobinamos": "embobinar",
    "embobinando": "embobinar",
    "embobinara": "embobinar",
    "embobinaram": "embobinar",
    "embobinaras": "embobinar",
    "embobinarde": "embobinar",
    "embobinardes": "embobinar",
    "embobinare": "embobinar",
    "embobinarei": "embobinar",
    "embobinareis": "embobinar",
    "embobinarem": "embobinar",
    "embobinaremos": "embobinar",
    "embobinares": "embobinar",
    "embobinaria": "embobinar",
    "embobinariam": "embobinar",
    "embobinarias": "embobinar",
    "embobinarmo": "embobinar",
    "embobinarmos": "embobinar",
    "embobinará": "embobinar",
    "embobinarás": "embobinar",
    "embobinarão": "embobinar",
    "embobinaríamos": "embobinar",
    "embobinaríeis": "embobinar",
    "embobinas": "embobinar",
    "embobinasse": "embobinar",
    "embobinassem": "embobinar",
    "embobinasses": "embobinar",
    "embobinaste": "embobinar",
    "embobinastes": "embobinar",
    "embobinava": "embobinar",
    "embobinavam": "embobinar",
    "embobinavas": "embobinar",
    "embobine": "embobinar",
    "embobinei": "embobinar",
    "embobineis": "embobinar",
    "embobinem": "embobinar",
    "embobinemo": "embobinar",
    "embobinemos": "embobinar",
    "embobines": "embobinar",
    "embobino": "embobinar",
    "embobinou": "embobinar",
    "embobiná": "embobinar",
    "embobinámo": "embobinar",
    "embobinámos": "embobinar",
    "embobináramo": "embobinar",
    "embobináramos": "embobinar",
    "embobinárei": "embobinar",
    "embobináreis": "embobinar",
    "embobinásseis": "embobinar",
    "embobinássemos": "embobinar",
    "embobinávamo": "embobinar",
    "embobinávamos": "embobinar",
    "embobinávei": "embobinar",
    "embobináveis": "embobinar",
    "embobo": "embobar",
    "embobou": "embobar",
    "embobá": "embobar",
    "embobámo": "embobar",
    "embobámos": "embobar",
    "embobáramo": "embobar",
    "embobáramos": "embobar",
    "embobárei": "embobar",
    "embobáreis": "embobar",
    "embobásseis": "embobar",
    "embobássemos": "embobar",
    "embobávamo": "embobar",
    "embobávamos": "embobar",
    "embobávei": "embobar",
    "embobáveis": "embobar",
    "emboca": "embocar",
    "embocada": "embocar",
    "embocadas": "embocar",
    "embocado": "embocar",
    "embocados": "embocar",
    "embocai": "embocar",
    "embocais": "embocar",
    "embocam": "embocar",
    "embocamentos": "embocamento",
    "embocamo": "embocar",
    "embocamos": "embocar",
    "embocando": "embocar",
    "embocara": "embocar",
    "embocaram": "embocar",
    "embocaras": "embocar",
    "embocarde": "embocar",
    "embocardes": "embocar",
    "embocare": "embocar",
    "embocarei": "embocar",
    "embocareis": "embocar",
    "embocarem": "embocar",
    "embocaremos": "embocar",
    "embocares": "embocar",
    "embocaria": "embocar",
    "embocariam": "embocar",
    "embocarias": "embocar",
    "embocarmo": "embocar",
    "embocarmos": "embocar",
    "embocará": "embocar",
    "embocarás": "embocar",
    "embocarão": "embocar",
    "embocaríamos": "embocar",
    "embocaríeis": "embocar",
    "embocas": "embocar",
    "embocasse": "embocar",
    "embocassem": "embocar",
    "embocasses": "embocar",
    "embocaste": "embocar",
    "embocastes": "embocar",
    "embocava": "embocar",
    "embocavam": "embocar",
    "embocavas": "embocar",
    "emboceta": "embocetar",
    "embocetada": "embocetar",
    "embocetadas": "embocetar",
    "embocetado": "embocetar",
    "embocetados": "embocetar",
    "embocetai": "embocetar",
    "embocetais": "embocetar",
    "embocetam": "embocetar",
    "embocetamentos": "embocetamento",
    "embocetamo": "embocetar",
    "embocetamos": "embocetar",
    "embocetando": "embocetar",
    "embocetara": "embocetar",
    "embocetaram": "embocetar",
    "embocetaras": "embocetar",
    "embocetarde": "embocetar",
    "embocetardes": "embocetar",
    "embocetare": "embocetar",
    "embocetarei": "embocetar",
    "embocetareis": "embocetar",
    "embocetarem": "embocetar",
    "embocetaremos": "embocetar",
    "embocetares": "embocetar",
    "embocetaria": "embocetar",
    "embocetariam": "embocetar",
    "embocetarias": "embocetar",
    "embocetarmo": "embocetar",
    "embocetarmos": "embocetar",
    "embocetará": "embocetar",
    "embocetarás": "embocetar",
    "embocetarão": "embocetar",
    "embocetaríamos": "embocetar",
    "embocetaríeis": "embocetar",
    "embocetas": "embocetar",
    "embocetasse": "embocetar",
    "embocetassem": "embocetar",
    "embocetasses": "embocetar",
    "embocetaste": "embocetar",
    "embocetastes": "embocetar",
    "embocetava": "embocetar",
    "embocetavam": "embocetar",
    "embocetavas": "embocetar",
    "embocete": "embocetar",
    "embocetei": "embocetar",
    "emboceteis": "embocetar",
    "embocetem": "embocetar",
    "embocetemo": "embocetar",
    "embocetemos": "embocetar",
    "embocetes": "embocetar",
    "emboceto": "embocetar",
    "embocetou": "embocetar",
    "embocetá": "embocetar",
    "embocetámo": "embocetar",
    "embocetámos": "embocetar",
    "embocetáramo": "embocetar",
    "embocetáramos": "embocetar",
    "embocetárei": "embocetar",
    "embocetáreis": "embocetar",
    "embocetásseis": "embocetar",
    "embocetássemos": "embocetar",
    "embocetávamo": "embocetar",
    "embocetávamos": "embocetar",
    "embocetávei": "embocetar",
    "embocetáveis": "embocetar",
    "emboco": "embocar",
    "embocou": "embocar",
    "embocá": "embocar",
    "embocámo": "embocar",
    "embocámos": "embocar",
    "embocáramo": "embocar",
    "embocáramos": "embocar",
    "embocárei": "embocar",
    "embocáreis": "embocar",
    "embocásseis": "embocar",
    "embocássemos": "embocar",
    "embocávamo": "embocar",
    "embocávamos": "embocar",
    "embocávei": "embocar",
    "embocáveis": "embocar",
    "embodalha": "embodalhar",
    "embodalhada": "embodalhar",
    "embodalhadas": "embodalhar",
    "embodalhado": "embodalhar",
    "embodalhados": "embodalhar",
    "embodalhai": "embodalhar",
    "embodalhais": "embodalhar",
    "embodalham": "embodalhar",
    "embodalhamo": "embodalhar",
    "embodalhamos": "embodalhar",
    "embodalhando": "embodalhar",
    "embodalhara": "embodalhar",
    "embodalharam": "embodalhar",
    "embodalharas": "embodalhar",
    "embodalharde": "embodalhar",
    "embodalhardes": "embodalhar",
    "embodalhare": "embodalhar",
    "embodalharei": "embodalhar",
    "embodalhareis": "embodalhar",
    "embodalharem": "embodalhar",
    "embodalharemos": "embodalhar",
    "embodalhares": "embodalhar",
    "embodalharia": "embodalhar",
    "embodalhariam": "embodalhar",
    "embodalharias": "embodalhar",
    "embodalharmo": "embodalhar",
    "embodalharmos": "embodalhar",
    "embodalhará": "embodalhar",
    "embodalharás": "embodalhar",
    "embodalharão": "embodalhar",
    "embodalharíamos": "embodalhar",
    "embodalharíeis": "embodalhar",
    "embodalhas": "embodalhar",
    "embodalhasse": "embodalhar",
    "embodalhassem": "embodalhar",
    "embodalhasses": "embodalhar",
    "embodalhaste": "embodalhar",
    "embodalhastes": "embodalhar",
    "embodalhava": "embodalhar",
    "embodalhavam": "embodalhar",
    "embodalhavas": "embodalhar",
    "embodalhe": "embodalhar",
    "embodalhei": "embodalhar",
    "embodalheis": "embodalhar",
    "embodalhem": "embodalhar",
    "embodalhemo": "embodalhar",
    "embodalhemos": "embodalhar",
    "embodalhes": "embodalhar",
    "embodalho": "embodalhar",
    "embodalhou": "embodalhar",
    "embodalhá": "embodalhar",
    "embodalhámo": "embodalhar",
    "embodalhámos": "embodalhar",
    "embodalháramo": "embodalhar",
    "embodalháramos": "embodalhar",
    "embodalhárei": "embodalhar",
    "embodalháreis": "embodalhar",
    "embodalhásseis": "embodalhar",
    "embodalhássemos": "embodalhar",
    "embodalhávamo": "embodalhar",
    "embodalhávamos": "embodalhar",
    "embodalhávei": "embodalhar",
    "embodalháveis": "embodalhar",
    "embodega": "embodegar",
    "embodegada": "embodegar",
    "embodegadas": "embodegar",
    "embodegado": "embodegar",
    "embodegados": "embodegar",
    "embodegai": "embodegar",
    "embodegais": "embodegar",
    "embodegam": "embodegar",
    "embodegamo": "embodegar",
    "embodegamos": "embodegar",
    "embodegando": "embodegar",
    "embodegara": "embodegar",
    "embodegaram": "embodegar",
    "embodegaras": "embodegar",
    "embodegarde": "embodegar",
    "embodegardes": "embodegar",
    "embodegare": "embodegar",
    "embodegarei": "embodegar",
    "embodegareis": "embodegar",
    "embodegarem": "embodegar",
    "embodegaremos": "embodegar",
    "embodegares": "embodegar",
    "embodegaria": "embodegar",
    "embodegariam": "embodegar",
    "embodegarias": "embodegar",
    "embodegarmo": "embodegar",
    "embodegarmos": "embodegar",
    "embodegará": "embodegar",
    "embodegarás": "embodegar",
    "embodegarão": "embodegar",
    "embodegaríamos": "embodegar",
    "embodegaríeis": "embodegar",
    "embodegas": "embodegar",
    "embodegasse": "embodegar",
    "embodegassem": "embodegar",
    "embodegasses": "embodegar",
    "embodegaste": "embodegar",
    "embodegastes": "embodegar",
    "embodegava": "embodegar",
    "embodegavam": "embodegar",
    "embodegavas": "embodegar",
    "embodego": "embodegar",
    "embodegou": "embodegar",
    "embodegue": "embodegar",
    "embodeguei": "embodegar",
    "embodegueis": "embodegar",
    "embodeguem": "embodegar",
    "embodeguemo": "embodegar",
    "embodeguemos": "embodegar",
    "embodegues": "embodegar",
    "embodegá": "embodegar",
    "embodegámo": "embodegar",
    "embodegámos": "embodegar",
    "embodegáramo": "embodegar",
    "embodegáramos": "embodegar",
    "embodegárei": "embodegar",
    "embodegáreis": "embodegar",
    "embodegásseis": "embodegar",
    "embodegássemos": "embodegar",
    "embodegávamo": "embodegar",
    "embodegávamos": "embodegar",
    "embodegávei": "embodegar",
    "embodegáveis": "embodegar",
    "embolada": "embolado",
    "emboladas": "embolado",
    "embolados": "embolado",
    "embolações": "embolação",
    "emboldrega": "emboldregar",
    "emboldregada": "emboldregar",
    "emboldregadas": "emboldregar",
    "emboldregado": "emboldregar",
    "emboldregados": "emboldregar",
    "emboldregai": "emboldregar",
    "emboldregais": "emboldregar",
    "emboldregam": "emboldregar",
    "emboldregamo": "emboldregar",
    "emboldregamos": "emboldregar",
    "emboldregando": "emboldregar",
    "emboldregara": "emboldregar",
    "emboldregaram": "emboldregar",
    "emboldregaras": "emboldregar",
    "emboldregarde": "emboldregar",
    "emboldregardes": "emboldregar",
    "emboldregare": "emboldregar",
    "emboldregarei": "emboldregar",
    "emboldregareis": "emboldregar",
    "emboldregarem": "emboldregar",
    "emboldregaremos": "emboldregar",
    "emboldregares": "emboldregar",
    "emboldregaria": "emboldregar",
    "emboldregariam": "emboldregar",
    "emboldregarias": "emboldregar",
    "emboldregarmo": "emboldregar",
    "emboldregarmos": "emboldregar",
    "emboldregará": "emboldregar",
    "emboldregarás": "emboldregar",
    "emboldregarão": "emboldregar",
    "emboldregaríamos": "emboldregar",
    "emboldregaríeis": "emboldregar",
    "emboldregas": "emboldregar",
    "emboldregasse": "emboldregar",
    "emboldregassem": "emboldregar",
    "emboldregasses": "emboldregar",
    "emboldregaste": "emboldregar",
    "emboldregastes": "emboldregar",
    "emboldregava": "emboldregar",
    "emboldregavam": "emboldregar",
    "emboldregavas": "emboldregar",
    "emboldrego": "emboldregar",
    "emboldregou": "emboldregar",
    "emboldregue": "emboldregar",
    "emboldreguei": "emboldregar",
    "emboldregueis": "emboldregar",
    "emboldreguem": "emboldregar",
    "emboldreguemo": "emboldregar",
    "emboldreguemos": "emboldregar",
    "emboldregues": "emboldregar",
    "emboldregá": "emboldregar",
    "emboldregámo": "emboldregar",
    "emboldregámos": "emboldregar",
    "emboldregáramo": "emboldregar",
    "emboldregáramos": "emboldregar",
    "emboldregárei": "emboldregar",
    "emboldregáreis": "emboldregar",
    "emboldregásseis": "emboldregar",
    "emboldregássemos": "emboldregar",
    "emboldregávamo": "emboldregar",
    "emboldregávamos": "emboldregar",
    "emboldregávei": "emboldregar",
    "emboldregáveis": "emboldregar",
    "emboldria": "emboldriar",
    "emboldriada": "emboldriar",
    "emboldriadas": "emboldriar",
    "emboldriado": "emboldriar",
    "emboldriados": "emboldriar",
    "emboldriai": "emboldriar",
    "emboldriais": "emboldriar",
    "emboldriam": "emboldriar",
    "emboldriamo": "emboldriar",
    "emboldriamos": "emboldriar",
    "emboldriando": "emboldriar",
    "emboldriara": "emboldriar",
    "emboldriaram": "emboldriar",
    "emboldriaras": "emboldriar",
    "emboldriarde": "emboldriar",
    "emboldriardes": "emboldriar",
    "emboldriare": "emboldriar",
    "emboldriarei": "emboldriar",
    "emboldriareis": "emboldriar",
    "emboldriarem": "emboldriar",
    "emboldriaremos": "emboldriar",
    "emboldriares": "emboldriar",
    "emboldriaria": "emboldriar",
    "emboldriariam": "emboldriar",
    "emboldriarias": "emboldriar",
    "emboldriarmo": "emboldriar",
    "emboldriarmos": "emboldriar",
    "emboldriará": "emboldriar",
    "emboldriarás": "emboldriar",
    "emboldriarão": "emboldriar",
    "emboldriaríamos": "emboldriar",
    "emboldriaríeis": "emboldriar",
    "emboldrias": "emboldriar",
    "emboldriasse": "emboldriar",
    "emboldriassem": "emboldriar",
    "emboldriasses": "emboldriar",
    "emboldriaste": "emboldriar",
    "emboldriastes": "emboldriar",
    "emboldriava": "emboldriar",
    "emboldriavam": "emboldriar",
    "emboldriavas": "emboldriar",
    "emboldrie": "emboldriar",
    "emboldriei": "emboldriar",
    "emboldrieis": "emboldriar",
    "emboldriem": "emboldriar",
    "emboldriemo": "emboldriar",
    "emboldriemos": "emboldriar",
    "emboldries": "emboldriar",
    "emboldrio": "emboldriar",
    "emboldriou": "emboldriar",
    "emboldriá": "emboldriar",
    "emboldriámo": "emboldriar",
    "emboldriámos": "emboldriar",
    "emboldriáramo": "emboldriar",
    "emboldriáramos": "emboldriar",
    "emboldriárei": "emboldriar",
    "emboldriáreis": "emboldriar",
    "emboldriásseis": "emboldriar",
    "emboldriássemos": "emboldriar",
    "emboldriávamo": "emboldriar",
    "emboldriávamos": "emboldriar",
    "emboldriávei": "emboldriar",
    "emboldriáveis": "emboldriar",
    "embolias": "embolia",
    "embolismais": "embolismal",
    "embolismos": "embolismo",
    "embolorece": "embolorecer",
    "embolorecei": "embolorecer",
    "emboloreceis": "embolorecer",
    "embolorecem": "embolorecer",
    "embolorecemo": "embolorecer",
    "embolorecemos": "embolorecer",
    "embolorecendo": "embolorecer",
    "embolorecera": "embolorecer",
    "emboloreceram": "embolorecer",
    "emboloreceras": "embolorecer",
    "embolorecerdes": "embolorecer",
    "embolorecerei": "embolorecer",
    "embolorecereis": "embolorecer",
    "embolorecerem": "embolorecer",
    "emboloreceremos": "embolorecer",
    "emboloreceres": "embolorecer",
    "emboloreceria": "embolorecer",
    "emboloreceriam": "embolorecer",
    "embolorecerias": "embolorecer",
    "embolorecermo": "embolorecer",
    "embolorecermos": "embolorecer",
    "embolorecerá": "embolorecer",
    "embolorecerás": "embolorecer",
    "embolorecerão": "embolorecer",
    "emboloreceríamos": "embolorecer",
    "emboloreceríeis": "embolorecer",
    "emboloreces": "embolorecer",
    "embolorecesse": "embolorecer",
    "embolorecessem": "embolorecer",
    "embolorecesses": "embolorecer",
    "emboloreceste": "embolorecer",
    "embolorecestes": "embolorecer",
    "emboloreceu": "embolorecer",
    "emboloreci": "embolorecer",
    "embolorecia": "embolorecer",
    "emboloreciam": "embolorecer",
    "embolorecias": "embolorecer",
    "embolorecida": "embolorecer",
    "embolorecidas": "embolorecer",
    "embolorecido": "embolorecer",
    "embolorecidos": "embolorecer",
    "embolorecimentos": "embolorecimento",
    "embolorecêramo": "embolorecer",
    "embolorecêramos": "embolorecer",
    "embolorecêreis": "embolorecer",
    "embolorecêsseis": "embolorecer",
    "embolorecêssemos": "embolorecer",
    "embolorecíamo": "embolorecer",
    "embolorecíamos": "embolorecer",
    "embolorecíeis": "embolorecer",
    "emboloreça": "embolorecer",
    "emboloreçais": "embolorecer",
    "emboloreçam": "embolorecer",
    "emboloreçamo": "embolorecer",
    "emboloreçamos": "embolorecer",
    "emboloreças": "embolorecer",
    "emboloreço": "embolorecer",
    "embolsa": "embolsar",
    "embolsada": "embolsar",
    "embolsadas": "embolsar",
    "embolsado": "embolsar",
    "embolsados": "embolsar",
    "embolsai": "embolsar",
    "embolsais": "embolsar",
    "embolsam": "embolsar",
    "embolsamo": "embolsar",
    "embolsamos": "embolsar",
    "embolsando": "embolsar",
    "embolsara": "embolsar",
    "embolsaram": "embolsar",
    "embolsaras": "embolsar",
    "embolsarde": "embolsar",
    "embolsardes": "embolsar",
    "embolsare": "embolsar",
    "embolsarei": "embolsar",
    "embolsareis": "embolsar",
    "embolsarem": "embolsar",
    "embolsaremos": "embolsar",
    "embolsares": "embolsar",
    "embolsaria": "embolsar",
    "embolsariam": "embolsar",
    "embolsarias": "embolsar",
    "embolsarmo": "embolsar",
    "embolsarmos": "embolsar",
    "embolsará": "embolsar",
    "embolsarás": "embolsar",
    "embolsarão": "embolsar",
    "embolsaríamos": "embolsar",
    "embolsaríeis": "embolsar",
    "embolsas": "embolsar",
    "embolsasse": "embolsar",
    "embolsassem": "embolsar",
    "embolsasses": "embolsar",
    "embolsaste": "embolsar",
    "embolsastes": "embolsar",
    "embolsava": "embolsar",
    "embolsavam": "embolsar",
    "embolsavas": "embolsar",
    "embolse": "embolsar",
    "embolsei": "embolsar",
    "embolseis": "embolsar",
    "embolsem": "embolsar",
    "embolsemo": "embolsar",
    "embolsemos": "embolsar",
    "embolses": "embolsar",
    "embolso": "embolsar",
    "embolsos": "embolso",
    "embolsou": "embolsar",
    "embolsá": "embolsar",
    "embolsámo": "embolsar",
    "embolsámos": "embolsar",
    "embolsáramo": "embolsar",
    "embolsáramos": "embolsar",
    "embolsárei": "embolsar",
    "embolsáreis": "embolsar",
    "embolsásseis": "embolsar",
    "embolsássemos": "embolsar",
    "embolsávamo": "embolsar",
    "embolsávamos": "embolsar",
    "embolsávei": "embolsar",
    "embolsáveis": "embolsável",
    "embolísmica": "embolísmico",
    "embolísmicas": "embolísmico",
    "embolísmicos": "embolísmico",
    "embona": "embonar",
    "embonada": "embonar",
    "embonadas": "embonar",
    "embonado": "embonar",
    "embonados": "embonar",
    "embonai": "embonar",
    "embonais": "embonar",
    "embonam": "embonar",
    "embonamo": "embonar",
    "embonamos": "embonar",
    "embonando": "embonar",
    "embonara": "embonar",
    "embonaram": "embonar",
    "embonaras": "embonar",
    "embonarde": "embonar",
    "embonardes": "embonar",
    "embonare": "embonar",
    "embonarei": "embonar",
    "embonareis": "embonar",
    "embonarem": "embonar",
    "embonaremos": "embonar",
    "embonares": "embonar",
    "embonaria": "embonar",
    "embonariam": "embonar",
    "embonarias": "embonar",
    "embonarmo": "embonar",
    "embonarmos": "embonar",
    "embonará": "embonar",
    "embonarás": "embonar",
    "embonarão": "embonar",
    "embonaríamos": "embonar",
    "embonaríeis": "embonar",
    "embonas": "embonar",
    "embonasse": "embonar",
    "embonassem": "embonar",
    "embonasses": "embonar",
    "embonaste": "embonar",
    "embonastes": "embonar",
    "embonava": "embonar",
    "embonavam": "embonar",
    "embonavas": "embonar",
    "embondeiros": "embondeiro",
    "embone": "embonar",
    "emboneca": "embonecar",
    "embonecada": "embonecar",
    "embonecadas": "embonecar",
    "embonecado": "embonecar",
    "embonecados": "embonecar",
    "embonecai": "embonecar",
    "embonecais": "embonecar",
    "embonecam": "embonecar",
    "embonecamo": "embonecar",
    "embonecamos": "embonecar",
    "embonecando": "embonecar",
    "embonecara": "embonecar",
    "embonecaram": "embonecar",
    "embonecaras": "embonecar",
    "embonecarde": "embonecar",
    "embonecardes": "embonecar",
    "embonecare": "embonecar",
    "embonecarei": "embonecar",
    "embonecareis": "embonecar",
    "embonecarem": "embonecar",
    "embonecaremos": "embonecar",
    "embonecares": "embonecar",
    "embonecaria": "embonecar",
    "embonecariam": "embonecar",
    "embonecarias": "embonecar",
    "embonecarmo": "embonecar",
    "embonecarmos": "embonecar",
    "embonecará": "embonecar",
    "embonecarás": "embonecar",
    "embonecarão": "embonecar",
    "embonecaríamos": "embonecar",
    "embonecaríeis": "embonecar",
    "embonecas": "embonecar",
    "embonecasse": "embonecar",
    "embonecassem": "embonecar",
    "embonecasses": "embonecar",
    "embonecaste": "embonecar",
    "embonecastes": "embonecar",
    "embonecava": "embonecar",
    "embonecavam": "embonecar",
    "embonecavas": "embonecar",
    "emboneco": "embonecar",
    "embonecou": "embonecar",
    "embonecá": "embonecar",
    "embonecámo": "embonecar",
    "embonecámos": "embonecar",
    "embonecáramo": "embonecar",
    "embonecáramos": "embonecar",
    "embonecárei": "embonecar",
    "embonecáreis": "embonecar",
    "embonecásseis": "embonecar",
    "embonecássemos": "embonecar",
    "embonecávamo": "embonecar",
    "embonecávamos": "embonecar",
    "embonecávei": "embonecar",
    "embonecáveis": "embonecar",
    "embonei": "embonar",
    "emboneis": "embonar",
    "embonem": "embonar",
    "embonemo": "embonar",
    "embonemos": "embonar",
    "emboneque": "embonecar",
    "embonequei": "embonecar",
    "embonequeis": "embonecar",
    "embonequem": "embonecar",
    "embonequemo": "embonecar",
    "embonequemos": "embonecar",
    "emboneques": "embonecar",
    "embones": "embonar",
    "embono": "embonar",
    "embonos": "embono",
    "embonou": "embonar",
    "emboná": "embonar",
    "embonámo": "embonar",
    "embonámos": "embonar",
    "embonáramo": "embonar",
    "embonáramos": "embonar",
    "embonárei": "embonar",
    "embonáreis": "embonar",
    "embonásseis": "embonar",
    "embonássemos": "embonar",
    "embonávamo": "embonar",
    "embonávamos": "embonar",
    "embonávei": "embonar",
    "embonáveis": "embonar",
    "emboque": "embocar",
    "emboquei": "embocar",
    "emboqueis": "embocar",
    "emboquem": "embocar",
    "emboquemo": "embocar",
    "emboquemos": "embocar",
    "emboques": "embocar",
    "emboquilha": "emboquilhar",
    "emboquilhada": "emboquilhar",
    "emboquilhadas": "emboquilhar",
    "emboquilhado": "emboquilhar",
    "emboquilhados": "emboquilhar",
    "emboquilhai": "emboquilhar",
    "emboquilhais": "emboquilhar",
    "emboquilham": "emboquilhar",
    "emboquilhamo": "emboquilhar",
    "emboquilhamos": "emboquilhar",
    "emboquilhando": "emboquilhar",
    "emboquilhara": "emboquilhar",
    "emboquilharam": "emboquilhar",
    "emboquilharas": "emboquilhar",
    "emboquilharde": "emboquilhar",
    "emboquilhardes": "emboquilhar",
    "emboquilhare": "emboquilhar",
    "emboquilharei": "emboquilhar",
    "emboquilhareis": "emboquilhar",
    "emboquilharem": "emboquilhar",
    "emboquilharemos": "emboquilhar",
    "emboquilhares": "emboquilhar",
    "emboquilharia": "emboquilhar",
    "emboquilhariam": "emboquilhar",
    "emboquilharias": "emboquilhar",
    "emboquilharmo": "emboquilhar",
    "emboquilharmos": "emboquilhar",
    "emboquilhará": "emboquilhar",
    "emboquilharás": "emboquilhar",
    "emboquilharão": "emboquilhar",
    "emboquilharíamos": "emboquilhar",
    "emboquilharíeis": "emboquilhar",
    "emboquilhas": "emboquilhar",
    "emboquilhasse": "emboquilhar",
    "emboquilhassem": "emboquilhar",
    "emboquilhasses": "emboquilhar",
    "emboquilhaste": "emboquilhar",
    "emboquilhastes": "emboquilhar",
    "emboquilhava": "emboquilhar",
    "emboquilhavam": "emboquilhar",
    "emboquilhavas": "emboquilhar",
    "emboquilhe": "emboquilhar",
    "emboquilhei": "emboquilhar",
    "emboquilheis": "emboquilhar",
    "emboquilhem": "emboquilhar",
    "emboquilhemo": "emboquilhar",
    "emboquilhemos": "emboquilhar",
    "emboquilhes": "emboquilhar",
    "emboquilho": "emboquilhar",
    "emboquilhou": "emboquilhar",
    "emboquilhá": "emboquilhar",
    "emboquilhámo": "emboquilhar",
    "emboquilhámos": "emboquilhar",
    "emboquilháramo": "emboquilhar",
    "emboquilháramos": "emboquilhar",
    "emboquilhárei": "emboquilhar",
    "emboquilháreis": "emboquilhar",
    "emboquilhásseis": "emboquilhar",
    "emboquilhássemos": "emboquilhar",
    "emboquilhávamo": "emboquilhar",
    "emboquilhávamos": "emboquilhar",
    "emboquilhávei": "emboquilhar",
    "emboquilháveis": "emboquilhar",
    "emborca": "emborcar",
    "emborcada": "emborcar",
    "emborcadas": "emborcar",
    "emborcado": "emborcar",
    "emborcados": "emborcar",
    "emborcai": "emborcar",
    "emborcais": "emborcar",
    "emborcam": "emborcar",
    "emborcamo": "emborcar",
    "emborcamos": "emborcar",
    "emborcando": "emborcar",
    "emborcara": "emborcar",
    "emborcaram": "emborcar",
    "emborcaras": "emborcar",
    "emborcarde": "emborcar",
    "emborcardes": "emborcar",
    "emborcare": "emborcar",
    "emborcarei": "emborcar",
    "emborcareis": "emborcar",
    "emborcarem": "emborcar",
    "emborcaremos": "emborcar",
    "emborcares": "emborcar",
    "emborcaria": "emborcar",
    "emborcariam": "emborcar",
    "emborcarias": "emborcar",
    "emborcarmo": "emborcar",
    "emborcarmos": "emborcar",
    "emborcará": "emborcar",
    "emborcarás": "emborcar",
    "emborcarão": "emborcar",
    "emborcaríamos": "emborcar",
    "emborcaríeis": "emborcar",
    "emborcas": "emborcar",
    "emborcasse": "emborcar",
    "emborcassem": "emborcar",
    "emborcasses": "emborcar",
    "emborcaste": "emborcar",
    "emborcastes": "emborcar",
    "emborcava": "emborcar",
    "emborcavam": "emborcar",
    "emborcavas": "emborcar",
    "emborcações": "emborcação",
    "emborco": "emborcar",
    "emborcos": "emborco",
    "emborcou": "emborcar",
    "emborcá": "emborcar",
    "emborcámo": "emborcar",
    "emborcámos": "emborcar",
    "emborcáramo": "emborcar",
    "emborcáramos": "emborcar",
    "emborcárei": "emborcar",
    "emborcáreis": "emborcar",
    "emborcásseis": "emborcar",
    "emborcássemos": "emborcar",
    "emborcávamo": "emborcar",
    "emborcávamos": "emborcar",
    "emborcávei": "emborcar",
    "emborcáveis": "emborcar",
    "embornais": "embornal",
    "embornala": "embornalar",
    "embornalada": "embornalar",
    "embornaladas": "embornalar",
    "embornalado": "embornalar",
    "embornalados": "embornalar",
    "embornalai": "embornalar",
    "embornalais": "embornalar",
    "embornalam": "embornalar",
    "embornalamo": "embornalar",
    "embornalamos": "embornalar",
    "embornalando": "embornalar",
    "embornalara": "embornalar",
    "embornalaram": "embornalar",
    "embornalaras": "embornalar",
    "embornalarde": "embornalar",
    "embornalardes": "embornalar",
    "embornalare": "embornalar",
    "embornalarei": "embornalar",
    "embornalareis": "embornalar",
    "embornalarem": "embornalar",
    "embornalaremos": "embornalar",
    "embornalares": "embornalar",
    "embornalaria": "embornalar",
    "embornalariam": "embornalar",
    "embornalarias": "embornalar",
    "embornalarmo": "embornalar",
    "embornalarmos": "embornalar",
    "embornalará": "embornalar",
    "embornalarás": "embornalar",
    "embornalarão": "embornalar",
    "embornalaríamos": "embornalar",
    "embornalaríeis": "embornalar",
    "embornalas": "embornalar",
    "embornalasse": "embornalar",
    "embornalassem": "embornalar",
    "embornalasses": "embornalar",
    "embornalaste": "embornalar",
    "embornalastes": "embornalar",
    "embornalava": "embornalar",
    "embornalavam": "embornalar",
    "embornalavas": "embornalar",
    "embornale": "embornalar",
    "embornalei": "embornalar",
    "embornaleis": "embornalar",
    "embornalem": "embornalar",
    "embornalemo": "embornalar",
    "embornalemos": "embornalar",
    "embornales": "embornalar",
    "embornalo": "embornalar",
    "embornalou": "embornalar",
    "embornalá": "embornalar",
    "embornalámo": "embornalar",
    "embornalámos": "embornalar",
    "embornaláramo": "embornalar",
    "embornaláramos": "embornalar",
    "embornalárei": "embornalar",
    "embornaláreis": "embornalar",
    "embornalásseis": "embornalar",
    "embornalássemos": "embornalar",
    "embornalávamo": "embornalar",
    "embornalávamos": "embornalar",
    "embornalávei": "embornalar",
    "embornaláveis": "embornalar",
    "emborque": "emborcar",
    "emborquei": "emborcar",
    "emborqueis": "emborcar",
    "emborquem": "emborcar",
    "emborquemo": "emborcar",
    "emborquemos": "emborcar",
    "emborques": "emborque",
    "emborra": "emborrar",
    "emborracha": "emborrachar",
    "emborrachada": "emborrachar",
    "emborrachadas": "emborrachar",
    "emborrachado": "emborrachar",
    "emborrachados": "emborrachar",
    "emborrachai": "emborrachar",
    "emborrachais": "emborrachar",
    "emborracham": "emborrachar",
    "emborrachamo": "emborrachar",
    "emborrachamos": "emborrachar",
    "emborrachando": "emborrachar",
    "emborrachara": "emborrachar",
    "emborracharam": "emborrachar",
    "emborracharas": "emborrachar",
    "emborracharde": "emborrachar",
    "emborrachardes": "emborrachar",
    "emborrachare": "emborrachar",
    "emborracharei": "emborrachar",
    "emborrachareis": "emborrachar",
    "emborracharem": "emborrachar",
    "emborracharemos": "emborrachar",
    "emborrachares": "emborrachar",
    "emborracharia": "emborrachar",
    "emborrachariam": "emborrachar",
    "emborracharias": "emborrachar",
    "emborracharmo": "emborrachar",
    "emborracharmos": "emborrachar",
    "emborrachará": "emborrachar",
    "emborracharás": "emborrachar",
    "emborracharão": "emborrachar",
    "emborracharíamos": "emborrachar",
    "emborracharíeis": "emborrachar",
    "emborrachas": "emborrachar",
    "emborrachasse": "emborrachar",
    "emborrachassem": "emborrachar",
    "emborrachasses": "emborrachar",
    "emborrachaste": "emborrachar",
    "emborrachastes": "emborrachar",
    "emborrachava": "emborrachar",
    "emborrachavam": "emborrachar",
    "emborrachavas": "emborrachar",
    "emborrache": "emborrachar",
    "emborrachei": "emborrachar",
    "emborracheis": "emborrachar",
    "emborrachem": "emborrachar",
    "emborrachemo": "emborrachar",
    "emborrachemos": "emborrachar",
    "emborraches": "emborrachar",
    "emborracho": "emborrachar",
    "emborrachou": "emborrachar",
    "emborrachá": "emborrachar",
    "emborrachámo": "emborrachar",
    "emborrachámos": "emborrachar",
    "emborracháramo": "emborrachar",
    "emborracháramos": "emborrachar",
    "emborrachárei": "emborrachar",
    "emborracháreis": "emborrachar",
    "emborrachásseis": "emborrachar",
    "emborrachássemos": "emborrachar",
    "emborrachávamo": "emborrachar",
    "emborrachávamos": "emborrachar",
    "emborrachávei": "emborrachar",
    "emborracháveis": "emborrachar",
    "emborrada": "emborrar",
    "emborradas": "emborrar",
    "emborrado": "emborrar",
    "emborrados": "emborrar",
    "emborraduras": "emborradura",
    "emborrai": "emborrar",
    "emborrais": "emborrar",
    "emborralha": "emborralhar",
    "emborralhada": "emborralhar",
    "emborralhadas": "emborralhar",
    "emborralhado": "emborralhar",
    "emborralhados": "emborralhar",
    "emborralhai": "emborralhar",
    "emborralhais": "emborralhar",
    "emborralham": "emborralhar",
    "emborralhamo": "emborralhar",
    "emborralhamos": "emborralhar",
    "emborralhando": "emborralhar",
    "emborralhara": "emborralhar",
    "emborralharam": "emborralhar",
    "emborralharas": "emborralhar",
    "emborralharde": "emborralhar",
    "emborralhardes": "emborralhar",
    "emborralhare": "emborralhar",
    "emborralharei": "emborralhar",
    "emborralhareis": "emborralhar",
    "emborralharem": "emborralhar",
    "emborralharemos": "emborralhar",
    "emborralhares": "emborralhar",
    "emborralharia": "emborralhar",
    "emborralhariam": "emborralhar",
    "emborralharias": "emborralhar",
    "emborralharmo": "emborralhar",
    "emborralharmos": "emborralhar",
    "emborralhará": "emborralhar",
    "emborralharás": "emborralhar",
    "emborralharão": "emborralhar",
    "emborralharíamos": "emborralhar",
    "emborralharíeis": "emborralhar",
    "emborralhas": "emborralhar",
    "emborralhasse": "emborralhar",
    "emborralhassem": "emborralhar",
    "emborralhasses": "emborralhar",
    "emborralhaste": "emborralhar",
    "emborralhastes": "emborralhar",
    "emborralhava": "emborralhar",
    "emborralhavam": "emborralhar",
    "emborralhavas": "emborralhar",
    "emborralhe": "emborralhar",
    "emborralhei": "emborralhar",
    "emborralheis": "emborralhar",
    "emborralhem": "emborralhar",
    "emborralhemo": "emborralhar",
    "emborralhemos": "emborralhar",
    "emborralhes": "emborralhar",
    "emborralho": "emborralhar",
    "emborralhou": "emborralhar",
    "emborralhá": "emborralhar",
    "emborralhámo": "emborralhar",
    "emborralhámos": "emborralhar",
    "emborralháramo": "emborralhar",
    "emborralháramos": "emborralhar",
    "emborralhárei": "emborralhar",
    "emborralháreis": "emborralhar",
    "emborralhásseis": "emborralhar",
    "emborralhássemos": "emborralhar",
    "emborralhávamo": "emborralhar",
    "emborralhávamos": "emborralhar",
    "emborralhávei": "emborralhar",
    "emborralháveis": "emborralhar",
    "emborram": "emborrar",
    "emborramo": "emborrar",
    "emborramos": "emborrar",
    "emborrando": "emborrar",
    "emborrara": "emborrar",
    "emborraram": "emborrar",
    "emborraras": "emborrar",
    "emborrarde": "emborrar",
    "emborrardes": "emborrar",
    "emborrare": "emborrar",
    "emborrarei": "emborrar",
    "emborrareis": "emborrar",
    "emborrarem": "emborrar",
    "emborraremos": "emborrar",
    "emborrares": "emborrar",
    "emborraria": "emborrar",
    "emborrariam": "emborrar",
    "emborrarias": "emborrar",
    "emborrarmo": "emborrar",
    "emborrarmos": "emborrar",
    "emborrará": "emborrar",
    "emborrarás": "emborrar",
    "emborrarão": "emborrar",
    "emborraríamos": "emborrar",
    "emborraríeis": "emborrar",
    "emborras": "emborrar",
    "emborrasca": "emborrascar",
    "emborrascada": "emborrascar",
    "emborrascadas": "emborrascar",
    "emborrascado": "emborrascar",
    "emborrascados": "emborrascar",
    "emborrascai": "emborrascar",
    "emborrascais": "emborrascar",
    "emborrascam": "emborrascar",
    "emborrascamo": "emborrascar",
    "emborrascamos": "emborrascar",
    "emborrascando": "emborrascar",
    "emborrascara": "emborrascar",
    "emborrascaram": "emborrascar",
    "emborrascaras": "emborrascar",
    "emborrascarde": "emborrascar",
    "emborrascardes": "emborrascar",
    "emborrascare": "emborrascar",
    "emborrascarei": "emborrascar",
    "emborrascareis": "emborrascar",
    "emborrascarem": "emborrascar",
    "emborrascaremos": "emborrascar",
    "emborrascares": "emborrascar",
    "emborrascaria": "emborrascar",
    "emborrascariam": "emborrascar",
    "emborrascarias": "emborrascar",
    "emborrascarmo": "emborrascar",
    "emborrascarmos": "emborrascar",
    "emborrascará": "emborrascar",
    "emborrascarás": "emborrascar",
    "emborrascarão": "emborrascar",
    "emborrascaríamos": "emborrascar",
    "emborrascaríeis": "emborrascar",
    "emborrascas": "emborrascar",
    "emborrascasse": "emborrascar",
    "emborrascassem": "emborrascar",
    "emborrascasses": "emborrascar",
    "emborrascaste": "emborrascar",
    "emborrascastes": "emborrascar",
    "emborrascava": "emborrascar",
    "emborrascavam": "emborrascar",
    "emborrascavas": "emborrascar",
    "emborrasco": "emborrascar",
    "emborrascou": "emborrascar",
    "emborrascá": "emborrascar",
    "emborrascámo": "emborrascar",
    "emborrascámos": "emborrascar",
    "emborrascáramo": "emborrascar",
    "emborrascáramos": "emborrascar",
    "emborrascárei": "emborrascar",
    "emborrascáreis": "emborrascar",
    "emborrascásseis": "emborrascar",
    "emborrascássemos": "emborrascar",
    "emborrascávamo": "emborrascar",
    "emborrascávamos": "emborrascar",
    "emborrascávei": "emborrascar",
    "emborrascáveis": "emborrascar",
    "emborrasque": "emborrascar",
    "emborrasquei": "emborrascar",
    "emborrasqueis": "emborrascar",
    "emborrasquem": "emborrascar",
    "emborrasquemo": "emborrascar",
    "emborrasquemos": "emborrascar",
    "emborrasques": "emborrascar",
    "emborrasse": "emborrar",
    "emborrassem": "emborrar",
    "emborrasses": "emborrar",
    "emborraste": "emborrar",
    "emborrastes": "emborrar",
    "emborrava": "emborrar",
    "emborravam": "emborrar",
    "emborravas": "emborrar",
    "emborre": "emborrar",
    "emborrei": "emborrar",
    "emborreis": "emborrar",
    "emborrem": "emborrar",
    "emborremo": "emborrar",
    "emborremos": "emborrar",
    "emborres": "emborrar",
    "emborro": "emborrar",
    "emborrou": "emborrar",
    "emborrá": "emborrar",
    "emborrámo": "emborrar",
    "emborrámos": "emborrar",
    "emborráramo": "emborrar",
    "emborráramos": "emborrar",
    "emborrárei": "emborrar",
    "emborráreis": "emborrar",
    "emborrásseis": "emborrar",
    "emborrássemos": "emborrar",
    "emborrávamo": "emborrar",
    "emborrávamos": "emborrar",
    "emborrávei": "emborrar",
    "emborráveis": "emborrar",
    "embosca": "emboscar",
    "emboscada": "emboscar",
    "emboscadas": "emboscar",
    "emboscado": "emboscar",
    "emboscados": "emboscar",
    "emboscai": "emboscar",
    "emboscais": "emboscar",
    "emboscam": "emboscar",
    "emboscamo": "emboscar",
    "emboscamos": "emboscar",
    "emboscando": "emboscar",
    "emboscara": "emboscar",
    "emboscaram": "emboscar",
    "emboscaras": "emboscar",
    "emboscarde": "emboscar",
    "emboscardes": "emboscar",
    "emboscare": "emboscar",
    "emboscarei": "emboscar",
    "emboscareis": "emboscar",
    "emboscarem": "emboscar",
    "emboscaremos": "emboscar",
    "emboscares": "emboscar",
    "emboscaria": "emboscar",
    "emboscariam": "emboscar",
    "emboscarias": "emboscar",
    "emboscarmo": "emboscar",
    "emboscarmos": "emboscar",
    "emboscará": "emboscar",
    "emboscarás": "emboscar",
    "emboscarão": "emboscar",
    "emboscaríamos": "emboscar",
    "emboscaríeis": "emboscar",
    "emboscas": "emboscar",
    "emboscasse": "emboscar",
    "emboscassem": "emboscar",
    "emboscasses": "emboscar",
    "emboscaste": "emboscar",
    "emboscastes": "emboscar",
    "emboscava": "emboscar",
    "emboscavam": "emboscar",
    "emboscavas": "emboscar",
    "embosco": "emboscar",
    "emboscou": "emboscar",
    "emboscá": "emboscar",
    "emboscámo": "emboscar",
    "emboscámos": "emboscar",
    "emboscáramo": "emboscar",
    "emboscáramos": "emboscar",
    "emboscárei": "emboscar",
    "emboscáreis": "emboscar",
    "emboscásseis": "emboscar",
    "emboscássemos": "emboscar",
    "emboscávamo": "emboscar",
    "emboscávamos": "emboscar",
    "emboscávei": "emboscar",
    "emboscáveis": "emboscar",
    "embosque": "emboscar",
    "embosquei": "emboscar",
    "embosqueis": "emboscar",
    "embosquem": "emboscar",
    "embosquemo": "emboscar",
    "embosquemos": "emboscar",
    "embosques": "emboscar",
    "embosta": "embostar",
    "embostada": "embostar",
    "embostadas": "embostar",
    "embostado": "embostar",
    "embostados": "embostar",
    "embostai": "embostar",
    "embostais": "embostar",
    "embostam": "embostar",
    "embostamo": "embostar",
    "embostamos": "embostar",
    "embostando": "embostar",
    "embostara": "embostar",
    "embostaram": "embostar",
    "embostaras": "embostar",
    "embostarde": "embostar",
    "embostardes": "embostar",
    "embostare": "embostar",
    "embostarei": "embostar",
    "embostareis": "embostar",
    "embostarem": "embostar",
    "embostaremos": "embostar",
    "embostares": "embostar",
    "embostaria": "embostar",
    "embostariam": "embostar",
    "embostarias": "embostar",
    "embostarmo": "embostar",
    "embostarmos": "embostar",
    "embostará": "embostar",
    "embostarás": "embostar",
    "embostarão": "embostar",
    "embostaríamos": "embostar",
    "embostaríeis": "embostar",
    "embostas": "embostar",
    "embostasse": "embostar",
    "embostassem": "embostar",
    "embostasses": "embostar",
    "embostaste": "embostar",
    "embostastes": "embostar",
    "embostava": "embostar",
    "embostavam": "embostar",
    "embostavas": "embostar",
    "emboste": "embostar",
    "embosteada": "embostear",
    "embosteadas": "embostear",
    "embosteado": "embostear",
    "embosteados": "embostear",
    "embosteai": "embostear",
    "embosteais": "embostear",
    "embosteamo": "embostear",
    "embosteamos": "embostear",
    "embosteando": "embostear",
    "embosteara": "embostear",
    "embostearam": "embostear",
    "embostearas": "embostear",
    "embostearde": "embostear",
    "embosteardes": "embostear",
    "embosteare": "embostear",
    "embostearei": "embostear",
    "embosteareis": "embostear",
    "embostearem": "embostear",
    "embostearemos": "embostear",
    "embosteares": "embostear",
    "embostearia": "embostear",
    "embosteariam": "embostear",
    "embostearias": "embostear",
    "embostearmo": "embostear",
    "embostearmos": "embostear",
    "embosteará": "embostear",
    "embostearás": "embostear",
    "embostearão": "embostear",
    "embostearíamos": "embostear",
    "embostearíeis": "embostear",
    "embosteasse": "embostear",
    "embosteassem": "embostear",
    "embosteasses": "embostear",
    "embosteaste": "embostear",
    "embosteastes": "embostear",
    "embosteava": "embostear",
    "embosteavam": "embostear",
    "embosteavas": "embostear",
    "embosteei": "embostear",
    "embosteeis": "embostear",
    "embosteemo": "embostear",
    "embosteemos": "embostear",
    "embostei": "embostar",
    "embosteia": "embostear",
    "embosteiam": "embostear",
    "embosteias": "embostear",
    "embosteie": "embostear",
    "embosteiem": "embostear",
    "embosteies": "embostear",
    "embosteio": "embostear",
    "embosteis": "embostar",
    "embostela": "embostelar",
    "embostelada": "embostelar",
    "embosteladas": "embostelar",
    "embostelado": "embostelar",
    "embostelados": "embostelar",
    "embostelai": "embostelar",
    "embostelais": "embostelar",
    "embostelam": "embostelar",
    "embostelamo": "embostelar",
    "embostelamos": "embostelar",
    "embostelando": "embostelar",
    "embostelara": "embostelar",
    "embostelaram": "embostelar",
    "embostelaras": "embostelar",
    "embostelarde": "embostelar",
    "embostelardes": "embostelar",
    "embostelare": "embostelar",
    "embostelarei": "embostelar",
    "embostelareis": "embostelar",
    "embostelarem": "embostelar",
    "embostelaremos": "embostelar",
    "embostelares": "embostelar",
    "embostelaria": "embostelar",
    "embostelariam": "embostelar",
    "embostelarias": "embostelar",
    "embostelarmo": "embostelar",
    "embostelarmos": "embostelar",
    "embostelará": "embostelar",
    "embostelarás": "embostelar",
    "embostelarão": "embostelar",
    "embostelaríamos": "embostelar",
    "embostelaríeis": "embostelar",
    "embostelas": "embostelar",
    "embostelasse": "embostelar",
    "embostelassem": "embostelar",
    "embostelasses": "embostelar",
    "embostelaste": "embostelar",
    "embostelastes": "embostelar",
    "embostelava": "embostelar",
    "embostelavam": "embostelar",
    "embostelavas": "embostelar",
    "embostele": "embostelar",
    "embostelei": "embostelar",
    "embosteleis": "embostelar",
    "embostelem": "embostelar",
    "embostelemo": "embostelar",
    "embostelemos": "embostelar",
    "embosteles": "embostelar",
    "embostelo": "embostelar",
    "embostelou": "embostelar",
    "embostelá": "embostelar",
    "embostelámo": "embostelar",
    "embostelámos": "embostelar",
    "embosteláramo": "embostelar",
    "embosteláramos": "embostelar",
    "embostelárei": "embostelar",
    "embosteláreis": "embostelar",
    "embostelásseis": "embostelar",
    "embostelássemos": "embostelar",
    "embostelávamo": "embostelar",
    "embostelávamos": "embostelar",
    "embostelávei": "embostelar",
    "embosteláveis": "embostelar",
    "embostem": "embostar",
    "embostemo": "embostar",
    "embostemos": "embostar",
    "embosteou": "embostear",
    "embostes": "embostar",
    "embosteá": "embostear",
    "embosteámo": "embostear",
    "embosteámos": "embostear",
    "embosteáramo": "embostear",
    "embosteáramos": "embostear",
    "embosteárei": "embostear",
    "embosteáreis": "embostear",
    "embosteásseis": "embostear",
    "embosteássemos": "embostear",
    "embosteávamo": "embostear",
    "embosteávamos": "embostear",
    "embosteávei": "embostear",
    "embosteáveis": "embostear",
    "embosto": "embostar",
    "embostou": "embostar",
    "embostá": "embostar",
    "embostámo": "embostar",
    "embostámos": "embostar",
    "embostáramo": "embostar",
    "embostáramos": "embostar",
    "embostárei": "embostar",
    "embostáreis": "embostar",
    "embostásseis": "embostar",
    "embostássemos": "embostar",
    "embostávamo": "embostar",
    "embostávamos": "embostar",
    "embostávei": "embostar",
    "embostáveis": "embostar",
    "embota": "embotar",
    "embotada": "embotar",
    "embotadas": "embotar",
    "embotadeiras": "embotadeira",
    "embotado": "embotar",
    "embotadora": "embotador",
    "embotadoras": "embotador",
    "embotadores": "embotador",
    "embotados": "embotar",
    "embotaduras": "embotadura",
    "embotai": "embotar",
    "embotais": "embotar",
    "embotam": "embotar",
    "embotamentos": "embotamento",
    "embotamo": "embotar",
    "embotamos": "embotar",
    "embotando": "embotar",
    "embotara": "embotar",
    "embotaram": "embotar",
    "embotaras": "embotar",
    "embotarde": "embotar",
    "embotardes": "embotar",
    "embotare": "embotar",
    "embotarei": "embotar",
    "embotareis": "embotar",
    "embotarem": "embotar",
    "embotaremos": "embotar",
    "embotares": "embotar",
    "embotaria": "embotar",
    "embotariam": "embotar",
    "embotarias": "embotar",
    "embotarmo": "embotar",
    "embotarmos": "embotar",
    "embotará": "embotar",
    "embotarás": "embotar",
    "embotarão": "embotar",
    "embotaríamos": "embotar",
    "embotaríeis": "embotar",
    "embotas": "embotar",
    "embotasse": "embotar",
    "embotassem": "embotar",
    "embotasses": "embotar",
    "embotaste": "embotar",
    "embotastes": "embotar",
    "embotava": "embotar",
    "embotavam": "embotar",
    "embotavas": "embotar",
    "embote": "embotar",
    "embotei": "embotar",
    "emboteis": "embotar",
    "embotelha": "embotelhar",
    "embotelhada": "embotelhar",
    "embotelhadas": "embotelhar",
    "embotelhado": "embotelhar",
    "embotelhados": "embotelhar",
    "embotelhai": "embotelhar",
    "embotelhais": "embotelhar",
    "embotelham": "embotelhar",
    "embotelhamo": "embotelhar",
    "embotelhamos": "embotelhar",
    "embotelhando": "embotelhar",
    "embotelhara": "embotelhar",
    "embotelharam": "embotelhar",
    "embotelharas": "embotelhar",
    "embotelharde": "embotelhar",
    "embotelhardes": "embotelhar",
    "embotelhare": "embotelhar",
    "embotelharei": "embotelhar",
    "embotelhareis": "embotelhar",
    "embotelharem": "embotelhar",
    "embotelharemos": "embotelhar",
    "embotelhares": "embotelhar",
    "embotelharia": "embotelhar",
    "embotelhariam": "embotelhar",
    "embotelharias": "embotelhar",
    "embotelharmo": "embotelhar",
    "embotelharmos": "embotelhar",
    "embotelhará": "embotelhar",
    "embotelharás": "embotelhar",
    "embotelharão": "embotelhar",
    "embotelharíamos": "embotelhar",
    "embotelharíeis": "embotelhar",
    "embotelhas": "embotelhar",
    "embotelhasse": "embotelhar",
    "embotelhassem": "embotelhar",
    "embotelhasses": "embotelhar",
    "embotelhaste": "embotelhar",
    "embotelhastes": "embotelhar",
    "embotelhava": "embotelhar",
    "embotelhavam": "embotelhar",
    "embotelhavas": "embotelhar",
    "embotelhe": "embotelhar",
    "embotelhei": "embotelhar",
    "embotelheis": "embotelhar",
    "embotelhem": "embotelhar",
    "embotelhemo": "embotelhar",
    "embotelhemos": "embotelhar",
    "embotelhes": "embotelhar",
    "embotelho": "embotelhar",
    "embotelhou": "embotelhar",
    "embotelhá": "embotelhar",
    "embotelhámo": "embotelhar",
    "embotelhámos": "embotelhar",
    "embotelháramo": "embotelhar",
    "embotelháramos": "embotelhar",
    "embotelhárei": "embotelhar",
    "embotelháreis": "embotelhar",
    "embotelhásseis": "embotelhar",
    "embotelhássemos": "embotelhar",
    "embotelhávamo": "embotelhar",
    "embotelhávamos": "embotelhar",
    "embotelhávei": "embotelhar",
    "embotelháveis": "embotelhar",
    "embotem": "embotar",
    "embotemo": "embotar",
    "embotemos": "embotar",
    "embotes": "embotar",
    "embotija": "embotijar",
    "embotijada": "embotijar",
    "embotijadas": "embotijar",
    "embotijado": "embotijar",
    "embotijados": "embotijar",
    "embotijai": "embotijar",
    "embotijais": "embotijar",
    "embotijam": "embotijar",
    "embotijamentos": "embotijamento",
    "embotijamo": "embotijar",
    "embotijamos": "embotijar",
    "embotijando": "embotijar",
    "embotijara": "embotijar",
    "embotijaram": "embotijar",
    "embotijaras": "embotijar",
    "embotijarde": "embotijar",
    "embotijardes": "embotijar",
    "embotijare": "embotijar",
    "embotijarei": "embotijar",
    "embotijareis": "embotijar",
    "embotijarem": "embotijar",
    "embotijaremos": "embotijar",
    "embotijares": "embotijar",
    "embotijaria": "embotijar",
    "embotijariam": "embotijar",
    "embotijarias": "embotijar",
    "embotijarmo": "embotijar",
    "embotijarmos": "embotijar",
    "embotijará": "embotijar",
    "embotijarás": "embotijar",
    "embotijarão": "embotijar",
    "embotijaríamos": "embotijar",
    "embotijaríeis": "embotijar",
    "embotijas": "embotijar",
    "embotijasse": "embotijar",
    "embotijassem": "embotijar",
    "embotijasses": "embotijar",
    "embotijaste": "embotijar",
    "embotijastes": "embotijar",
    "embotijava": "embotijar",
    "embotijavam": "embotijar",
    "embotijavas": "embotijar",
    "embotije": "embotijar",
    "embotijei": "embotijar",
    "embotijeis": "embotijar",
    "embotijem": "embotijar",
    "embotijemo": "embotijar",
    "embotijemos": "embotijar",
    "embotijes": "embotijar",
    "embotijo": "embotijar",
    "embotijou": "embotijar",
    "embotijá": "embotijar",
    "embotijámo": "embotijar",
    "embotijámos": "embotijar",
    "embotijáramo": "embotijar",
    "embotijáramos": "embotijar",
    "embotijárei": "embotijar",
    "embotijáreis": "embotijar",
    "embotijásseis": "embotijar",
    "embotijássemos": "embotijar",
    "embotijávamo": "embotijar",
    "embotijávamos": "embotijar",
    "embotijávei": "embotijar",
    "embotijáveis": "embotijar",
    "emboto": "embotar",
    "embotou": "embotar",
    "embotá": "embotar",
    "embotámo": "embotar",
    "embotámos": "embotar",
    "embotáramo": "embotar",
    "embotáramos": "embotar",
    "embotárei": "embotar",
    "embotáreis": "embotar",
    "embotásseis": "embotar",
    "embotássemos": "embotar",
    "embotávamo": "embotar",
    "embotávamos": "embotar",
    "embotávei": "embotar",
    "embotáveis": "embotar",
    "emboçadeiras": "emboçadeira",
    "emboçadora": "emboçador",
    "emboçadoras": "emboçador",
    "emboçadores": "emboçador",
    "emboçaduras": "emboçadura",
    "emboçamentos": "emboçamento",
    "emboços": "emboço",
    "embrace": "embraçar",
    "embracei": "embraçar",
    "embraceira": "embraceirar",
    "embraceirada": "embraceirar",
    "embraceiradas": "embraceirar",
    "embraceirado": "embraceirar",
    "embraceirados": "embraceirar",
    "embraceirai": "embraceirar",
    "embraceirais": "embraceirar",
    "embraceiram": "embraceirar",
    "embraceiramo": "embraceirar",
    "embraceiramos": "embraceirar",
    "embraceirando": "embraceirar",
    "embraceirara": "embraceirar",
    "embraceiraram": "embraceirar",
    "embraceiraras": "embraceirar",
    "embraceirarde": "embraceirar",
    "embraceirardes": "embraceirar",
    "embraceirare": "embraceirar",
    "embraceirarei": "embraceirar",
    "embraceirareis": "embraceirar",
    "embraceirarem": "embraceirar",
    "embraceiraremos": "embraceirar",
    "embraceirares": "embraceirar",
    "embraceiraria": "embraceirar",
    "embraceirariam": "embraceirar",
    "embraceirarias": "embraceirar",
    "embraceirarmo": "embraceirar",
    "embraceirarmos": "embraceirar",
    "embraceirará": "embraceirar",
    "embraceirarás": "embraceirar",
    "embraceirarão": "embraceirar",
    "embraceiraríamos": "embraceirar",
    "embraceiraríeis": "embraceirar",
    "embraceiras": "embraceirar",
    "embraceirasse": "embraceirar",
    "embraceirassem": "embraceirar",
    "embraceirasses": "embraceirar",
    "embraceiraste": "embraceirar",
    "embraceirastes": "embraceirar",
    "embraceirava": "embraceirar",
    "embraceiravam": "embraceirar",
    "embraceiravas": "embraceirar",
    "embraceire": "embraceirar",
    "embraceirei": "embraceirar",
    "embraceireis": "embraceirar",
    "embraceirem": "embraceirar",
    "embraceiremo": "embraceirar",
    "embraceiremos": "embraceirar",
    "embraceires": "embraceirar",
    "embraceiro": "embraceirar",
    "embraceirou": "embraceirar",
    "embraceirá": "embraceirar",
    "embraceirámo": "embraceirar",
    "embraceirámos": "embraceirar",
    "embraceiráramo": "embraceirar",
    "embraceiráramos": "embraceirar",
    "embraceirárei": "embraceirar",
    "embraceiráreis": "embraceirar",
    "embraceirásseis": "embraceirar",
    "embraceirássemos": "embraceirar",
    "embraceirávamo": "embraceirar",
    "embraceirávamos": "embraceirar",
    "embraceirávei": "embraceirar",
    "embraceiráveis": "embraceirar",
    "embraceis": "embraçar",
    "embracem": "embraçar",
    "embracemo": "embraçar",
    "embracemos": "embraçar",
    "embraces": "embraçar",
    "embraia": "embraiar",
    "embraiada": "embraiar",
    "embraiadas": "embraiar",
    "embraiado": "embraiar",
    "embraiados": "embraiar",
    "embraiagens": "embraiagem",
    "embraiai": "embraiar",
    "embraiais": "embraiar",
    "embraiam": "embraiar",
    "embraiamo": "embraiar",
    "embraiamos": "embraiar",
    "embraiando": "embraiar",
    "embraiara": "embraiar",
    "embraiaram": "embraiar",
    "embraiaras": "embraiar",
    "embraiardes": "embraiar",
    "embraiarei": "embraiar",
    "embraiareis": "embraiar",
    "embraiarem": "embraiar",
    "embraiaremos": "embraiar",
    "embraiares": "embraiar",
    "embraiaria": "embraiar",
    "embraiariam": "embraiar",
    "embraiarias": "embraiar",
    "embraiarmo": "embraiar",
    "embraiarmos": "embraiar",
    "embraiará": "embraiar",
    "embraiarás": "embraiar",
    "embraiarão": "embraiar",
    "embraiaríamos": "embraiar",
    "embraiaríeis": "embraiar",
    "embraias": "embraiar",
    "embraiasse": "embraiar",
    "embraiassem": "embraiar",
    "embraiasses": "embraiar",
    "embraiaste": "embraiar",
    "embraiastes": "embraiar",
    "embraiava": "embraiar",
    "embraiavam": "embraiar",
    "embraiavas": "embraiar",
    "embraie": "embraiar",
    "embraiei": "embraiar",
    "embraieis": "embraiar",
    "embraiem": "embraiar",
    "embraiemo": "embraiar",
    "embraiemos": "embraiar",
    "embraies": "embraiar",
    "embraio": "embraiar",
    "embraiou": "embraiar",
    "embraiámo": "embraiar",
    "embraiámos": "embraiar",
    "embraiáramo": "embraiar",
    "embraiáramos": "embraiar",
    "embraiáreis": "embraiar",
    "embraiásseis": "embraiar",
    "embraiássemos": "embraiar",
    "embraiávamo": "embraiar",
    "embraiávamos": "embraiar",
    "embraiáveis": "embraiar",
    "embranca": "embrancar",
    "embrancada": "embrancar",
    "embrancadas": "embrancar",
    "embrancado": "embrancar",
    "embrancados": "embrancar",
    "embrancai": "embrancar",
    "embrancais": "embrancar",
    "embrancam": "embrancar",
    "embrancamo": "embrancar",
    "embrancamos": "embrancar",
    "embrancando": "embrancar",
    "embrancara": "embrancar",
    "embrancaram": "embrancar",
    "embrancaras": "embrancar",
    "embrancarde": "embrancar",
    "embrancardes": "embrancar",
    "embrancare": "embrancar",
    "embrancarei": "embrancar",
    "embrancareis": "embrancar",
    "embrancarem": "embrancar",
    "embrancaremos": "embrancar",
    "embrancares": "embrancar",
    "embrancaria": "embrancar",
    "embrancariam": "embrancar",
    "embrancarias": "embrancar",
    "embrancarmo": "embrancar",
    "embrancarmos": "embrancar",
    "embrancará": "embrancar",
    "embrancarás": "embrancar",
    "embrancarão": "embrancar",
    "embrancaríamos": "embrancar",
    "embrancaríeis": "embrancar",
    "embrancas": "embrancar",
    "embrancasse": "embrancar",
    "embrancassem": "embrancar",
    "embrancasses": "embrancar",
    "embrancaste": "embrancar",
    "embrancastes": "embrancar",
    "embrancava": "embrancar",
    "embrancavam": "embrancar",
    "embrancavas": "embrancar",
    "embranco": "embrancar",
    "embrancou": "embrancar",
    "embrancá": "embrancar",
    "embrancámo": "embrancar",
    "embrancámos": "embrancar",
    "embrancáramo": "embrancar",
    "embrancáramos": "embrancar",
    "embrancárei": "embrancar",
    "embrancáreis": "embrancar",
    "embrancásseis": "embrancar",
    "embrancássemos": "embrancar",
    "embrancávamo": "embrancar",
    "embrancávamos": "embrancar",
    "embrancávei": "embrancar",
    "embrancáveis": "embrancar",
    "embrandece": "embrandecer",
    "embrandecei": "embrandecer",
    "embrandeceis": "embrandecer",
    "embrandecem": "embrandecer",
    "embrandecemo": "embrandecer",
    "embrandecemos": "embrandecer",
    "embrandecendo": "embrandecer",
    "embrandecera": "embrandecer",
    "embrandeceram": "embrandecer",
    "embrandeceras": "embrandecer",
    "embrandecerde": "embrandecer",
    "embrandecerdes": "embrandecer",
    "embrandecere": "embrandecer",
    "embrandecerei": "embrandecer",
    "embrandecereis": "embrandecer",
    "embrandecerem": "embrandecer",
    "embrandeceremos": "embrandecer",
    "embrandeceres": "embrandecer",
    "embrandeceria": "embrandecer",
    "embrandeceriam": "embrandecer",
    "embrandecerias": "embrandecer",
    "embrandecermo": "embrandecer",
    "embrandecermos": "embrandecer",
    "embrandecerá": "embrandecer",
    "embrandecerás": "embrandecer",
    "embrandecerão": "embrandecer",
    "embrandeceríamos": "embrandecer",
    "embrandeceríeis": "embrandecer",
    "embrandeces": "embrandecer",
    "embrandecesse": "embrandecer",
    "embrandecessem": "embrandecer",
    "embrandecesses": "embrandecer",
    "embrandeceste": "embrandecer",
    "embrandecestes": "embrandecer",
    "embrandeceu": "embrandecer",
    "embrandeci": "embrandecer",
    "embrandecia": "embrandecer",
    "embrandeciam": "embrandecer",
    "embrandecias": "embrandecer",
    "embrandecida": "embrandecido",
    "embrandecidas": "embrandecido",
    "embrandecido": "embrandecer",
    "embrandecidos": "embrandecido",
    "embrandecê": "embrandecer",
    "embrandecêramo": "embrandecer",
    "embrandecêramos": "embrandecer",
    "embrandecêrei": "embrandecer",
    "embrandecêreis": "embrandecer",
    "embrandecêsseis": "embrandecer",
    "embrandecêssemos": "embrandecer",
    "embrandecíamo": "embrandecer",
    "embrandecíamos": "embrandecer",
    "embrandecíei": "embrandecer",
    "embrandecíeis": "embrandecer",
    "embrandeça": "embrandecer",
    "embrandeçais": "embrandecer",
    "embrandeçam": "embrandecer",
    "embrandeçamo": "embrandecer",
    "embrandeçamos": "embrandecer",
    "embrandeças": "embrandecer",
    "embrandeço": "embrandecer",
    "embranque": "embrancar",
    "embranquece": "embranquecer",
    "embranquecei": "embranquecer",
    "embranqueceis": "embranquecer",
    "embranquecem": "embranquecer",
    "embranquecemo": "embranquecer",
    "embranquecemos": "embranquecer",
    "embranquecendo": "embranquecer",
    "embranquecera": "embranquecer",
    "embranqueceram": "embranquecer",
    "embranqueceras": "embranquecer",
    "embranquecerde": "embranquecer",
    "embranquecerdes": "embranquecer",
    "embranquecere": "embranquecer",
    "embranquecerei": "embranquecer",
    "embranquecereis": "embranquecer",
    "embranquecerem": "embranquecer",
    "embranqueceremos": "embranquecer",
    "embranqueceres": "embranquecer",
    "embranqueceria": "embranquecer",
    "embranqueceriam": "embranquecer",
    "embranquecerias": "embranquecer",
    "embranquecermo": "embranquecer",
    "embranquecermos": "embranquecer",
    "embranquecerá": "embranquecer",
    "embranquecerás": "embranquecer",
    "embranquecerão": "embranquecer",
    "embranqueceríamos": "embranquecer",
    "embranqueceríeis": "embranquecer",
    "embranqueces": "embranquecer",
    "embranquecesse": "embranquecer",
    "embranquecessem": "embranquecer",
    "embranquecesses": "embranquecer",
    "embranqueceste": "embranquecer",
    "embranquecestes": "embranquecer",
    "embranqueceu": "embranquecer",
    "embranqueci": "embranquecer",
    "embranquecia": "embranquecer",
    "embranqueciam": "embranquecer",
    "embranquecias": "embranquecer",
    "embranquecida": "embranquecido",
    "embranquecidas": "embranquecido",
    "embranquecido": "embranquecer",
    "embranquecidos": "embranquecido",
    "embranquecimentos": "embranquecimento",
    "embranquecê": "embranquecer",
    "embranquecêramo": "embranquecer",
    "embranquecêramos": "embranquecer",
    "embranquecêrei": "embranquecer",
    "embranquecêreis": "embranquecer",
    "embranquecêsseis": "embranquecer",
    "embranquecêssemos": "embranquecer",
    "embranquecíamo": "embranquecer",
    "embranquecíamos": "embranquecer",
    "embranquecíei": "embranquecer",
    "embranquecíeis": "embranquecer",
    "embranquei": "embrancar",
    "embranqueis": "embrancar",
    "embranquem": "embrancar",
    "embranquemo": "embrancar",
    "embranquemos": "embrancar",
    "embranques": "embrancar",
    "embranqueça": "embranquecer",
    "embranqueçais": "embranquecer",
    "embranqueçam": "embranquecer",
    "embranqueçamo": "embranquecer",
    "embranqueçamos": "embranquecer",
    "embranqueças": "embranquecer",
    "embranqueço": "embranquecer",
    "embravece": "embravecer",
    "embravecei": "embravecer",
    "embraveceis": "embravecer",
    "embravecem": "embravecer",
    "embravecemo": "embravecer",
    "embravecemos": "embravecer",
    "embravecendo": "embravecer",
    "embravecera": "embravecer",
    "embraveceram": "embravecer",
    "embraveceras": "embravecer",
    "embravecerde": "embravecer",
    "embravecerdes": "embravecer",
    "embravecere": "embravecer",
    "embravecerei": "embravecer",
    "embravecereis": "embravecer",
    "embravecerem": "embravecer",
    "embraveceremos": "embravecer",
    "embraveceres": "embravecer",
    "embraveceria": "embravecer",
    "embraveceriam": "embravecer",
    "embravecerias": "embravecer",
    "embravecermo": "embravecer",
    "embravecermos": "embravecer",
    "embravecerá": "embravecer",
    "embravecerás": "embravecer",
    "embravecerão": "embravecer",
    "embraveceríamos": "embravecer",
    "embraveceríeis": "embravecer",
    "embraveces": "embravecer",
    "embravecesse": "embravecer",
    "embravecessem": "embravecer",
    "embravecesses": "embravecer",
    "embraveceste": "embravecer",
    "embravecestes": "embravecer",
    "embraveceu": "embravecer",
    "embraveci": "embravecer",
    "embravecia": "embravecer",
    "embraveciam": "embravecer",
    "embravecias": "embravecer",
    "embravecida": "embravecido",
    "embravecidas": "embravecido",
    "embravecido": "embravecer",
    "embravecidos": "embravecido",
    "embravecimentos": "embravecimento",
    "embravecê": "embravecer",
    "embravecêramo": "embravecer",
    "embravecêramos": "embravecer",
    "embravecêrei": "embravecer",
    "embravecêreis": "embravecer",
    "embravecêsseis": "embravecer",
    "embravecêssemos": "embravecer",
    "embravecíamo": "embravecer",
    "embravecíamos": "embravecer",
    "embravecíei": "embravecer",
    "embravecíeis": "embravecer",
    "embraveça": "embravecer",
    "embraveçais": "embravecer",
    "embraveçam": "embravecer",
    "embraveçamo": "embravecer",
    "embraveçamos": "embravecer",
    "embraveças": "embravecer",
    "embraveço": "embravecer",
    "embraça": "embraçar",
    "embraçada": "embraçar",
    "embraçadas": "embraçar",
    "embraçado": "embraçar",
    "embraçados": "embraçar",
    "embraçaduras": "embraçadura",
    "embraçai": "embraçar",
    "embraçais": "embraçar",
    "embraçam": "embraçar",
    "embraçamentos": "embraçamento",
    "embraçamo": "embraçar",
    "embraçamos": "embraçar",
    "embraçando": "embraçar",
    "embraçara": "embraçar",
    "embraçaram": "embraçar",
    "embraçaras": "embraçar",
    "embraçarde": "embraçar",
    "embraçardes": "embraçar",
    "embraçare": "embraçar",
    "embraçarei": "embraçar",
    "embraçareis": "embraçar",
    "embraçarem": "embraçar",
    "embraçaremos": "embraçar",
    "embraçares": "embraçar",
    "embraçaria": "embraçar",
    "embraçariam": "embraçar",
    "embraçarias": "embraçar",
    "embraçarmo": "embraçar",
    "embraçarmos": "embraçar",
    "embraçará": "embraçar",
    "embraçarás": "embraçar",
    "embraçarão": "embraçar",
    "embraçaríamos": "embraçar",
    "embraçaríeis": "embraçar",
    "embraças": "embraçar",
    "embraçasse": "embraçar",
    "embraçassem": "embraçar",
    "embraçasses": "embraçar",
    "embraçaste": "embraçar",
    "embraçastes": "embraçar",
    "embraçava": "embraçar",
    "embraçavam": "embraçar",
    "embraçavas": "embraçar",
    "embraço": "embraçar",
    "embraços": "embraço",
    "embraçou": "embraçar",
    "embraçá": "embraçar",
    "embraçámo": "embraçar",
    "embraçámos": "embraçar",
    "embraçáramo": "embraçar",
    "embraçáramos": "embraçar",
    "embraçárei": "embraçar",
    "embraçáreis": "embraçar",
    "embraçásseis": "embraçar",
    "embraçássemos": "embraçar",
    "embraçávamo": "embraçar",
    "embraçávamos": "embraçar",
    "embraçávei": "embraçar",
    "embraçáveis": "embraçar",
    "embreada": "embrear",
    "embreadas": "embrear",
    "embreado": "embrear",
    "embreados": "embrear",
    "embreaduras": "embreadura",
    "embreagens": "embreagem",
    "embreai": "embrear",
    "embreais": "embrear",
    "embreamo": "embrear",
    "embreamos": "embrear",
    "embreando": "embrear",
    "embreara": "embrear",
    "embrearam": "embrear",
    "embrearas": "embrear",
    "embrearde": "embrear",
    "embreardes": "embrear",
    "embreare": "embrear",
    "embrearei": "embrear",
    "embreareis": "embrear",
    "embrearem": "embrear",
    "embrearemos": "embrear",
    "embreares": "embrear",
    "embrearia": "embrear",
    "embreariam": "embrear",
    "embrearias": "embrear",
    "embrearmo": "embrear",
    "embrearmos": "embrear",
    "embreará": "embrear",
    "embrearás": "embrear",
    "embrearão": "embrear",
    "embrearíamos": "embrear",
    "embrearíeis": "embrear",
    "embreasse": "embrear",
    "embreassem": "embrear",
    "embreasses": "embrear",
    "embreaste": "embrear",
    "embreastes": "embrear",
    "embreava": "embrear",
    "embreavam": "embrear",
    "embreavas": "embrear",
    "embrecha": "embrechar",
    "embrechada": "embrechar",
    "embrechadas": "embrechar",
    "embrechado": "embrechar",
    "embrechados": "embrechar",
    "embrechai": "embrechar",
    "embrechais": "embrechar",
    "embrecham": "embrechar",
    "embrechamo": "embrechar",
    "embrechamos": "embrechar",
    "embrechando": "embrechar",
    "embrechara": "embrechar",
    "embrecharam": "embrechar",
    "embrecharas": "embrechar",
    "embrecharde": "embrechar",
    "embrechardes": "embrechar",
    "embrechare": "embrechar",
    "embrecharei": "embrechar",
    "embrechareis": "embrechar",
    "embrecharem": "embrechar",
    "embrecharemos": "embrechar",
    "embrechares": "embrechar",
    "embrecharia": "embrechar",
    "embrechariam": "embrechar",
    "embrecharias": "embrechar",
    "embrecharmo": "embrechar",
    "embrecharmos": "embrechar",
    "embrechará": "embrechar",
    "embrecharás": "embrechar",
    "embrecharão": "embrechar",
    "embrecharíamos": "embrechar",
    "embrecharíeis": "embrechar",
    "embrechas": "embrechar",
    "embrechasse": "embrechar",
    "embrechassem": "embrechar",
    "embrechasses": "embrechar",
    "embrechaste": "embrechar",
    "embrechastes": "embrechar",
    "embrechava": "embrechar",
    "embrechavam": "embrechar",
    "embrechavas": "embrechar",
    "embreche": "embrechar",
    "embrechei": "embrechar",
    "embrecheis": "embrechar",
    "embrechem": "embrechar",
    "embrechemo": "embrechar",
    "embrechemos": "embrechar",
    "embreches": "embrechar",
    "embrecho": "embrechar",
    "embrechou": "embrechar",
    "embrechá": "embrechar",
    "embrechámo": "embrechar",
    "embrechámos": "embrechar",
    "embrecháramo": "embrechar",
    "embrecháramos": "embrechar",
    "embrechárei": "embrechar",
    "embrecháreis": "embrechar",
    "embrechásseis": "embrechar",
    "embrechássemos": "embrechar",
    "embrechávamo": "embrechar",
    "embrechávamos": "embrechar",
    "embrechávei": "embrechar",
    "embrecháveis": "embrechar",
    "embreei": "embrear",
    "embreeis": "embrear",
    "embreemo": "embrear",
    "embreemos": "embrear",
    "embreia": "embrear",
    "embreiam": "embrear",
    "embreias": "embrear",
    "embreie": "embrear",
    "embreiem": "embrear",
    "embreies": "embrear",
    "embreio": "embrear",
    "embrenha": "embrenhar",
    "embrenhada": "embrenhar",
    "embrenhadas": "embrenhar",
    "embrenhado": "embrenhar",
    "embrenhados": "embrenhar",
    "embrenhadíssima": "embrenhado",
    "embrenhadíssimas": "embrenhado",
    "embrenhadíssimo": "embrenhado",
    "embrenhadíssimos": "embrenhado",
    "embrenhai": "embrenhar",
    "embrenhais": "embrenhar",
    "embrenham": "embrenhar",
    "embrenhamo": "embrenhar",
    "embrenhamos": "embrenhar",
    "embrenhando": "embrenhar",
    "embrenhara": "embrenhar",
    "embrenharam": "embrenhar",
    "embrenharas": "embrenhar",
    "embrenharde": "embrenhar",
    "embrenhardes": "embrenhar",
    "embrenhare": "embrenhar",
    "embrenharei": "embrenhar",
    "embrenhareis": "embrenhar",
    "embrenharem": "embrenhar",
    "embrenharemos": "embrenhar",
    "embrenhares": "embrenhar",
    "embrenharia": "embrenhar",
    "embrenhariam": "embrenhar",
    "embrenharias": "embrenhar",
    "embrenharmo": "embrenhar",
    "embrenharmos": "embrenhar",
    "embrenhará": "embrenhar",
    "embrenharás": "embrenhar",
    "embrenharão": "embrenhar",
    "embrenharíamos": "embrenhar",
    "embrenharíeis": "embrenhar",
    "embrenhas": "embrenhar",
    "embrenhasse": "embrenhar",
    "embrenhassem": "embrenhar",
    "embrenhasses": "embrenhar",
    "embrenhaste": "embrenhar",
    "embrenhastes": "embrenhar",
    "embrenhava": "embrenhar",
    "embrenhavam": "embrenhar",
    "embrenhavas": "embrenhar",
    "embrenhe": "embrenhar",
    "embrenhei": "embrenhar",
    "embrenheis": "embrenhar",
    "embrenhem": "embrenhar",
    "embrenhemo": "embrenhar",
    "embrenhemos": "embrenhar",
    "embrenhes": "embrenhar",
    "embrenho": "embrenhar",
    "embrenhou": "embrenhar",
    "embrenhá": "embrenhar",
    "embrenhámo": "embrenhar",
    "embrenhámos": "embrenhar",
    "embrenháramo": "embrenhar",
    "embrenháramos": "embrenhar",
    "embrenhárei": "embrenhar",
    "embrenháreis": "embrenhar",
    "embrenhásseis": "embrenhar",
    "embrenhássemos": "embrenhar",
    "embrenhávamo": "embrenhar",
    "embrenhávamos": "embrenhar",
    "embrenhávei": "embrenhar",
    "embrenháveis": "embrenhar",
    "embreou": "embrear",
    "embreá": "embrear",
    "embreámo": "embrear",
    "embreámos": "embrear",
    "embreáramo": "embrear",
    "embreáramos": "embrear",
    "embreárei": "embrear",
    "embreáreis": "embrear",
    "embreásseis": "embrear",
    "embreássemos": "embrear",
    "embreávamo": "embrear",
    "embreávamos": "embrear",
    "embreávei": "embrear",
    "embreáveis": "embrear",
    "embriaga": "embriagar",
    "embriagada": "embriagar",
    "embriagadas": "embriagar",
    "embriagado": "embriagar",
    "embriagadora": "embriagador",
    "embriagadoras": "embriagador",
    "embriagadores": "embriagador",
    "embriagados": "embriagar",
    "embriagadíssima": "embriagado",
    "embriagadíssimas": "embriagado",
    "embriagadíssimo": "embriagado",
    "embriagadíssimos": "embriagado",
    "embriagai": "embriagar",
    "embriagais": "embriagar",
    "embriagam": "embriagar",
    "embriagamentos": "embriagamento",
    "embriagamo": "embriagar",
    "embriagamos": "embriagar",
    "embriagando": "embriagar",
    "embriagantes": "embriagante",
    "embriagara": "embriagar",
    "embriagaram": "embriagar",
    "embriagaras": "embriagar",
    "embriagarde": "embriagar",
    "embriagardes": "embriagar",
    "embriagare": "embriagar",
    "embriagarei": "embriagar",
    "embriagareis": "embriagar",
    "embriagarem": "embriagar",
    "embriagaremos": "embriagar",
    "embriagares": "embriagar",
    "embriagaria": "embriagar",
    "embriagariam": "embriagar",
    "embriagarias": "embriagar",
    "embriagarmo": "embriagar",
    "embriagarmos": "embriagar",
    "embriagará": "embriagar",
    "embriagarás": "embriagar",
    "embriagarão": "embriagar",
    "embriagaríamos": "embriagar",
    "embriagaríeis": "embriagar",
    "embriagas": "embriagar",
    "embriagasse": "embriagar",
    "embriagassem": "embriagar",
    "embriagasses": "embriagar",
    "embriagaste": "embriagar",
    "embriagastes": "embriagar",
    "embriagava": "embriagar",
    "embriagavam": "embriagar",
    "embriagavas": "embriagar",
    "embriago": "embriagar",
    "embriagou": "embriagar",
    "embriague": "embriagar",
    "embriaguei": "embriagar",
    "embriagueis": "embriagar",
    "embriaguem": "embriagar",
    "embriaguemo": "embriagar",
    "embriaguemos": "embriagar",
    "embriagues": "embriagar",
    "embriaguezes": "embriaguez",
    "embriagá": "embriagar",
    "embriagámo": "embriagar",
    "embriagámos": "embriagar",
    "embriagáramo": "embriagar",
    "embriagáramos": "embriagar",
    "embriagárei": "embriagar",
    "embriagáreis": "embriagar",
    "embriagásseis": "embriagar",
    "embriagássemos": "embriagar",
    "embriagávamo": "embriagar",
    "embriagávamos": "embriagar",
    "embriagávei": "embriagar",
    "embriagáveis": "embriagar",
    "embrida": "embridar",
    "embridada": "embridar",
    "embridadas": "embridar",
    "embridado": "embridar",
    "embridados": "embridar",
    "embridai": "embridar",
    "embridais": "embridar",
    "embridam": "embridar",
    "embridamo": "embridar",
    "embridamos": "embridar",
    "embridando": "embridar",
    "embridara": "embridar",
    "embridaram": "embridar",
    "embridaras": "embridar",
    "embridarde": "embridar",
    "embridardes": "embridar",
    "embridare": "embridar",
    "embridarei": "embridar",
    "embridareis": "embridar",
    "embridarem": "embridar",
    "embridaremos": "embridar",
    "embridares": "embridar",
    "embridaria": "embridar",
    "embridariam": "embridar",
    "embridarias": "embridar",
    "embridarmo": "embridar",
    "embridarmos": "embridar",
    "embridará": "embridar",
    "embridarás": "embridar",
    "embridarão": "embridar",
    "embridaríamos": "embridar",
    "embridaríeis": "embridar",
    "embridas": "embridar",
    "embridasse": "embridar",
    "embridassem": "embridar",
    "embridasses": "embridar",
    "embridaste": "embridar",
    "embridastes": "embridar",
    "embridava": "embridar",
    "embridavam": "embridar",
    "embridavas": "embridar",
    "embride": "embridar",
    "embridei": "embridar",
    "embrideis": "embridar",
    "embridem": "embridar",
    "embridemo": "embridar",
    "embridemos": "embridar",
    "embrides": "embridar",
    "embrido": "embridar",
    "embridou": "embridar",
    "embridá": "embridar",
    "embridámo": "embridar",
    "embridámos": "embridar",
    "embridáramo": "embridar",
    "embridáramos": "embridar",
    "embridárei": "embridar",
    "embridáreis": "embridar",
    "embridásseis": "embridar",
    "embridássemos": "embridar",
    "embridávamo": "embridar",
    "embridávamos": "embridar",
    "embridávei": "embridar",
    "embridáveis": "embridar",
    "embrinca": "embrincar",
    "embrincada": "embrincar",
    "embrincadas": "embrincar",
    "embrincado": "embrincar",
    "embrincados": "embrincar",
    "embrincai": "embrincar",
    "embrincais": "embrincar",
    "embrincam": "embrincar",
    "embrincamo": "embrincar",
    "embrincamos": "embrincar",
    "embrincando": "embrincar",
    "embrincara": "embrincar",
    "embrincaram": "embrincar",
    "embrincaras": "embrincar",
    "embrincarde": "embrincar",
    "embrincardes": "embrincar",
    "embrincare": "embrincar",
    "embrincarei": "embrincar",
    "embrincareis": "embrincar",
    "embrincarem": "embrincar",
    "embrincaremos": "embrincar",
    "embrincares": "embrincar",
    "embrincaria": "embrincar",
    "embrincariam": "embrincar",
    "embrincarias": "embrincar",
    "embrincarmo": "embrincar",
    "embrincarmos": "embrincar",
    "embrincará": "embrincar",
    "embrincarás": "embrincar",
    "embrincarão": "embrincar",
    "embrincaríamos": "embrincar",
    "embrincaríeis": "embrincar",
    "embrincas": "embrincar",
    "embrincasse": "embrincar",
    "embrincassem": "embrincar",
    "embrincasses": "embrincar",
    "embrincaste": "embrincar",
    "embrincastes": "embrincar",
    "embrincava": "embrincar",
    "embrincavam": "embrincar",
    "embrincavas": "embrincar",
    "embrinco": "embrincar",
    "embrincou": "embrincar",
    "embrincá": "embrincar",
    "embrincámo": "embrincar",
    "embrincámos": "embrincar",
    "embrincáramo": "embrincar",
    "embrincáramos": "embrincar",
    "embrincárei": "embrincar",
    "embrincáreis": "embrincar",
    "embrincásseis": "embrincar",
    "embrincássemos": "embrincar",
    "embrincávamo": "embrincar",
    "embrincávamos": "embrincar",
    "embrincávei": "embrincar",
    "embrincáveis": "embrincar",
    "embrinque": "embrincar",
    "embrinquei": "embrincar",
    "embrinqueis": "embrincar",
    "embrinquem": "embrincar",
    "embrinquemo": "embrincar",
    "embrinquemos": "embrincar",
    "embrinques": "embrincar",
    "embriogenias": "embriogenia",
    "embriogenésica": "embriogenésico",
    "embriogenésicas": "embriogenésico",
    "embriogenésicos": "embriogenésico",
    "embriogénica": "embriogénico",
    "embriogénicas": "embriogénico",
    "embriogénicos": "embriogénico",
    "embriolada": "embriolado",
    "embrioladas": "embriolado",
    "embriolados": "embriolado",
    "embriologias": "embriologia",
    "embriologistas": "embriologista",
    "embriológica": "embriológico",
    "embriológicas": "embriológico",
    "embriológicos": "embriológico",
    "embrionada": "embrionado",
    "embrionadas": "embrionado",
    "embrionados": "embrionado",
    "embrionária": "embrionário",
    "embrionárias": "embrionário",
    "embrionários": "embrionário",
    "embrionífera": "embrionífero",
    "embrioníferas": "embrionífero",
    "embrioníferos": "embrionífero",
    "embriopatas": "embriopata",
    "embriopatias": "embriopatia",
    "embriotomias": "embriotomia",
    "embriotómica": "embriotómico",
    "embriotómicas": "embriotómico",
    "embriotómicos": "embriotómico",
    "embriulcos": "embriulco",
    "embrióloga": "embriólogo",
    "embriólogas": "embriólogo",
    "embriólogos": "embriólogo",
    "embriótomos": "embriótomo",
    "embriões": "embrião",
    "embrolhos": "embrolho",
    "embroma": "embromar",
    "embromada": "embromar",
    "embromadas": "embromar",
    "embromado": "embromar",
    "embromados": "embromar",
    "embromai": "embromar",
    "embromais": "embromar",
    "embromam": "embromar",
    "embromamo": "embromar",
    "embromamos": "embromar",
    "embromando": "embromar",
    "embromara": "embromar",
    "embromaram": "embromar",
    "embromaras": "embromar",
    "embromarde": "embromar",
    "embromardes": "embromar",
    "embromare": "embromar",
    "embromarei": "embromar",
    "embromareis": "embromar",
    "embromarem": "embromar",
    "embromaremos": "embromar",
    "embromares": "embromar",
    "embromaria": "embromar",
    "embromariam": "embromar",
    "embromarias": "embromar",
    "embromarmo": "embromar",
    "embromarmos": "embromar",
    "embromará": "embromar",
    "embromarás": "embromar",
    "embromarão": "embromar",
    "embromaríamos": "embromar",
    "embromaríeis": "embromar",
    "embromas": "embromar",
    "embromasse": "embromar",
    "embromassem": "embromar",
    "embromasses": "embromar",
    "embromaste": "embromar",
    "embromastes": "embromar",
    "embromava": "embromar",
    "embromavam": "embromar",
    "embromavas": "embromar",
    "embrome": "embromar",
    "embromei": "embromar",
    "embromeis": "embromar",
    "embromem": "embromar",
    "embromemo": "embromar",
    "embromemos": "embromar",
    "embromes": "embromar",
    "embromo": "embromar",
    "embromou": "embromar",
    "embromá": "embromar",
    "embromámo": "embromar",
    "embromámos": "embromar",
    "embromáramo": "embromar",
    "embromáramos": "embromar",
    "embromárei": "embromar",
    "embromáreis": "embromar",
    "embromásseis": "embromar",
    "embromássemos": "embromar",
    "embromávamo": "embromar",
    "embromávamos": "embromar",
    "embromávei": "embromar",
    "embromáveis": "embromar",
    "embrulha": "embrulhar",
    "embrulhada": "embrulhar",
    "embrulhadas": "embrulhar",
    "embrulhado": "embrulhar",
    "embrulhadora": "embrulhador",
    "embrulhadoras": "embrulhador",
    "embrulhadores": "embrulhador",
    "embrulhados": "embrulhar",
    "embrulhadíssima": "embrulhado",
    "embrulhadíssimas": "embrulhado",
    "embrulhadíssimo": "embrulhado",
    "embrulhadíssimos": "embrulhado",
    "embrulhai": "embrulhar",
    "embrulhais": "embrulhar",
    "embrulham": "embrulhar",
    "embrulhamentos": "embrulhamento",
    "embrulhamo": "embrulhar",
    "embrulhamos": "embrulhar",
    "embrulhando": "embrulhar",
    "embrulhara": "embrulhar",
    "embrulharam": "embrulhar",
    "embrulharas": "embrulhar",
    "embrulharde": "embrulhar",
    "embrulhardes": "embrulhar",
    "embrulhare": "embrulhar",
    "embrulharei": "embrulhar",
    "embrulhareis": "embrulhar",
    "embrulharem": "embrulhar",
    "embrulharemos": "embrulhar",
    "embrulhares": "embrulhar",
    "embrulharia": "embrulhar",
    "embrulhariam": "embrulhar",
    "embrulharias": "embrulhar",
    "embrulharmo": "embrulhar",
    "embrulharmos": "embrulhar",
    "embrulhará": "embrulhar",
    "embrulharás": "embrulhar",
    "embrulharão": "embrulhar",
    "embrulharíamos": "embrulhar",
    "embrulharíeis": "embrulhar",
    "embrulhas": "embrulhar",
    "embrulhasse": "embrulhar",
    "embrulhassem": "embrulhar",
    "embrulhasses": "embrulhar",
    "embrulhaste": "embrulhar",
    "embrulhastes": "embrulhar",
    "embrulhava": "embrulhar",
    "embrulhavam": "embrulhar",
    "embrulhavas": "embrulhar",
    "embrulhe": "embrulhar",
    "embrulhei": "embrulhar",
    "embrulheis": "embrulhar",
    "embrulhem": "embrulhar",
    "embrulhemo": "embrulhar",
    "embrulhemos": "embrulhar",
    "embrulhes": "embrulhar",
    "embrulhinho": "embrulho",
    "embrulhinhos": "embrulho",
    "embrulhito": "embrulho",
    "embrulhitos": "embrulho",
    "embrulho": "embrulhar",
    "embrulhos": "embrulho",
    "embrulhou": "embrulhar",
    "embrulhozinho": "embrulho",
    "embrulhozinhos": "embrulho",
    "embrulhozito": "embrulho",
    "embrulhozitos": "embrulho",
    "embrulhá": "embrulhar",
    "embrulhámo": "embrulhar",
    "embrulhámos": "embrulhar",
    "embrulháramo": "embrulhar",
    "embrulháramos": "embrulhar",
    "embrulhárei": "embrulhar",
    "embrulháreis": "embrulhar",
    "embrulhásseis": "embrulhar",
    "embrulhássemos": "embrulhar",
    "embrulhávamo": "embrulhar",
    "embrulhávamos": "embrulhar",
    "embrulhávei": "embrulhar",
    "embrulháveis": "embrulhar",
    "embruma": "embrumar",
    "embrumada": "embrumar",
    "embrumadas": "embrumar",
    "embrumado": "embrumar",
    "embrumados": "embrumar",
    "embrumai": "embrumar",
    "embrumais": "embrumar",
    "embrumam": "embrumar",
    "embrumamo": "embrumar",
    "embrumamos": "embrumar",
    "embrumando": "embrumar",
    "embrumara": "embrumar",
    "embrumaram": "embrumar",
    "embrumaras": "embrumar",
    "embrumarde": "embrumar",
    "embrumardes": "embrumar",
    "embrumare": "embrumar",
    "embrumarei": "embrumar",
    "embrumareis": "embrumar",
    "embrumarem": "embrumar",
    "embrumaremos": "embrumar",
    "embrumares": "embrumar",
    "embrumaria": "embrumar",
    "embrumariam": "embrumar",
    "embrumarias": "embrumar",
    "embrumarmo": "embrumar",
    "embrumarmos": "embrumar",
    "embrumará": "embrumar",
    "embrumarás": "embrumar",
    "embrumarão": "embrumar",
    "embrumaríamos": "embrumar",
    "embrumaríeis": "embrumar",
    "embrumas": "embrumar",
    "embrumasse": "embrumar",
    "embrumassem": "embrumar",
    "embrumasses": "embrumar",
    "embrumaste": "embrumar",
    "embrumastes": "embrumar",
    "embrumava": "embrumar",
    "embrumavam": "embrumar",
    "embrumavas": "embrumar",
    "embrumações": "embrumação",
    "embrume": "embrumar",
    "embrumei": "embrumar",
    "embrumeis": "embrumar",
    "embrumem": "embrumar",
    "embrumemo": "embrumar",
    "embrumemos": "embrumar",
    "embrumes": "embrumar",
    "embrumo": "embrumar",
    "embrumou": "embrumar",
    "embrumá": "embrumar",
    "embrumámo": "embrumar",
    "embrumámos": "embrumar",
    "embrumáramo": "embrumar",
    "embrumáramos": "embrumar",
    "embrumárei": "embrumar",
    "embrumáreis": "embrumar",
    "embrumásseis": "embrumar",
    "embrumássemos": "embrumar",
    "embrumávamo": "embrumar",
    "embrumávamos": "embrumar",
    "embrumávei": "embrumar",
    "embrumáveis": "embrumar",
    "embruta": "embrutar",
    "embrutada": "embrutar",
    "embrutadas": "embrutar",
    "embrutado": "embrutar",
    "embrutados": "embrutar",
    "embrutai": "embrutar",
    "embrutais": "embrutar",
    "embrutam": "embrutar",
    "embrutamo": "embrutar",
    "embrutamos": "embrutar",
    "embrutando": "embrutar",
    "embrutara": "embrutar",
    "embrutaram": "embrutar",
    "embrutaras": "embrutar",
    "embrutarde": "embrutar",
    "embrutardes": "embrutar",
    "embrutare": "embrutar",
    "embrutarei": "embrutar",
    "embrutareis": "embrutar",
    "embrutarem": "embrutar",
    "embrutaremos": "embrutar",
    "embrutares": "embrutar",
    "embrutaria": "embrutar",
    "embrutariam": "embrutar",
    "embrutarias": "embrutar",
    "embrutarmo": "embrutar",
    "embrutarmos": "embrutar",
    "embrutará": "embrutar",
    "embrutarás": "embrutar",
    "embrutarão": "embrutar",
    "embrutaríamos": "embrutar",
    "embrutaríeis": "embrutar",
    "embrutas": "embrutar",
    "embrutasse": "embrutar",
    "embrutassem": "embrutar",
    "embrutasses": "embrutar",
    "embrutaste": "embrutar",
    "embrutastes": "embrutar",
    "embrutava": "embrutar",
    "embrutavam": "embrutar",
    "embrutavas": "embrutar",
    "embrute": "embrutar",
    "embrutece": "embrutecer",
    "embrutecedora": "embrutecedor",
    "embrutecedoras": "embrutecedor",
    "embrutecedores": "embrutecedor",
    "embrutecei": "embrutecer",
    "embruteceis": "embrutecer",
    "embrutecem": "embrutecer",
    "embrutecemo": "embrutecer",
    "embrutecemos": "embrutecer",
    "embrutecendo": "embrutecer",
    "embrutecera": "embrutecer",
    "embruteceram": "embrutecer",
    "embruteceras": "embrutecer",
    "embrutecerde": "embrutecer",
    "embrutecerdes": "embrutecer",
    "embrutecere": "embrutecer",
    "embrutecerei": "embrutecer",
    "embrutecereis": "embrutecer",
    "embrutecerem": "embrutecer",
    "embruteceremos": "embrutecer",
    "embruteceres": "embrutecer",
    "embruteceria": "embrutecer",
    "embruteceriam": "embrutecer",
    "embrutecerias": "embrutecer",
    "embrutecermo": "embrutecer",
    "embrutecermos": "embrutecer",
    "embrutecerá": "embrutecer",
    "embrutecerás": "embrutecer",
    "embrutecerão": "embrutecer",
    "embruteceríamos": "embrutecer",
    "embruteceríeis": "embrutecer",
    "embruteces": "embrutecer",
    "embrutecesse": "embrutecer",
    "embrutecessem": "embrutecer",
    "embrutecesses": "embrutecer",
    "embruteceste": "embrutecer",
    "embrutecestes": "embrutecer",
    "embruteceu": "embrutecer",
    "embruteci": "embrutecer",
    "embrutecia": "embrutecer",
    "embruteciam": "embrutecer",
    "embrutecias": "embrutecer",
    "embrutecida": "embrutecido",
    "embrutecidas": "embrutecido",
    "embrutecido": "embrutecer",
    "embrutecidos": "embrutecido",
    "embrutecimentos": "embrutecimento",
    "embrutecê": "embrutecer",
    "embrutecêramo": "embrutecer",
    "embrutecêramos": "embrutecer",
    "embrutecêrei": "embrutecer",
    "embrutecêreis": "embrutecer",
    "embrutecêsseis": "embrutecer",
    "embrutecêssemos": "embrutecer",
    "embrutecíamo": "embrutecer",
    "embrutecíamos": "embrutecer",
    "embrutecíei": "embrutecer",
    "embrutecíeis": "embrutecer",
    "embrutei": "embrutar",
    "embruteis": "embrutar",
    "embrutem": "embrutar",
    "embrutemo": "embrutar",
    "embrutemos": "embrutar",
    "embrutes": "embrutar",
    "embruteça": "embrutecer",
    "embruteçais": "embrutecer",
    "embruteçam": "embrutecer",
    "embruteçamo": "embrutecer",
    "embruteçamos": "embrutecer",
    "embruteças": "embrutecer",
    "embruteço": "embrutecer",
    "embruto": "embrutar",
    "embrutou": "embrutar",
    "embrutá": "embrutar",
    "embrutámo": "embrutar",
    "embrutámos": "embrutar",
    "embrutáramo": "embrutar",
    "embrutáramos": "embrutar",
    "embrutárei": "embrutar",
    "embrutáreis": "embrutar",
    "embrutásseis": "embrutar",
    "embrutássemos": "embrutar",
    "embrutávamo": "embrutar",
    "embrutávamos": "embrutar",
    "embrutávei": "embrutar",
    "embrutáveis": "embrutar",
    "embruxa": "embruxar",
    "embruxada": "embruxar",
    "embruxadas": "embruxar",
    "embruxado": "embruxar",
    "embruxadora": "embruxador",
    "embruxadoras": "embruxador",
    "embruxadores": "embruxador",
    "embruxados": "embruxar",
    "embruxai": "embruxar",
    "embruxais": "embruxar",
    "embruxam": "embruxar",
    "embruxamo": "embruxar",
    "embruxamos": "embruxar",
    "embruxando": "embruxar",
    "embruxara": "embruxar",
    "embruxaram": "embruxar",
    "embruxaras": "embruxar",
    "embruxarde": "embruxar",
    "embruxardes": "embruxar",
    "embruxare": "embruxar",
    "embruxarei": "embruxar",
    "embruxareis": "embruxar",
    "embruxarem": "embruxar",
    "embruxaremos": "embruxar",
    "embruxares": "embruxar",
    "embruxaria": "embruxar",
    "embruxariam": "embruxar",
    "embruxarias": "embruxar",
    "embruxarmo": "embruxar",
    "embruxarmos": "embruxar",
    "embruxará": "embruxar",
    "embruxarás": "embruxar",
    "embruxarão": "embruxar",
    "embruxaríamos": "embruxar",
    "embruxaríeis": "embruxar",
    "embruxas": "embruxar",
    "embruxasse": "embruxar",
    "embruxassem": "embruxar",
    "embruxasses": "embruxar",
    "embruxaste": "embruxar",
    "embruxastes": "embruxar",
    "embruxava": "embruxar",
    "embruxavam": "embruxar",
    "embruxavas": "embruxar",
    "embruxe": "embruxar",
    "embruxei": "embruxar",
    "embruxeis": "embruxar",
    "embruxem": "embruxar",
    "embruxemo": "embruxar",
    "embruxemos": "embruxar",
    "embruxes": "embruxar",
    "embruxo": "embruxar",
    "embruxou": "embruxar",
    "embruxá": "embruxar",
    "embruxámo": "embruxar",
    "embruxámos": "embruxar",
    "embruxáramo": "embruxar",
    "embruxáramos": "embruxar",
    "embruxárei": "embruxar",
    "embruxáreis": "embruxar",
    "embruxásseis": "embruxar",
    "embruxássemos": "embruxar",
    "embruxávamo": "embruxar",
    "embruxávamos": "embruxar",
    "embruxávei": "embruxar",
    "embruxáveis": "embruxar",
    "embuce": "embuçar",
    "embucei": "embuçar",
    "embuceis": "embuçar",
    "embucem": "embuçar",
    "embucemo": "embuçar",
    "embucemos": "embuçar",
    "embuces": "embuçar",
    "embucha": "embuchar",
    "embuchada": "embuchar",
    "embuchadas": "embuchar",
    "embuchado": "embuchar",
    "embuchados": "embuchar",
    "embuchai": "embuchar",
    "embuchais": "embuchar",
    "embucham": "embuchar",
    "embuchamo": "embuchar",
    "embuchamos": "embuchar",
    "embuchando": "embuchar",
    "embuchara": "embuchar",
    "embucharam": "embuchar",
    "embucharas": "embuchar",
    "embucharde": "embuchar",
    "embuchardes": "embuchar",
    "embuchare": "embuchar",
    "embucharei": "embuchar",
    "embuchareis": "embuchar",
    "embucharem": "embuchar",
    "embucharemos": "embuchar",
    "embuchares": "embuchar",
    "embucharia": "embuchar",
    "embuchariam": "embuchar",
    "embucharias": "embuchar",
    "embucharmo": "embuchar",
    "embucharmos": "embuchar",
    "embuchará": "embuchar",
    "embucharás": "embuchar",
    "embucharão": "embuchar",
    "embucharíamos": "embuchar",
    "embucharíeis": "embuchar",
    "embuchas": "embuchar",
    "embuchasse": "embuchar",
    "embuchassem": "embuchar",
    "embuchasses": "embuchar",
    "embuchaste": "embuchar",
    "embuchastes": "embuchar",
    "embuchava": "embuchar",
    "embuchavam": "embuchar",
    "embuchavas": "embuchar",
    "embuche": "embuchar",
    "embuchei": "embuchar",
    "embucheis": "embuchar",
    "embuchem": "embuchar",
    "embuchemo": "embuchar",
    "embuchemos": "embuchar",
    "embuches": "embuchar",
    "embucho": "embuchar",
    "embuchou": "embuchar",
    "embuchá": "embuchar",
    "embuchámo": "embuchar",
    "embuchámos": "embuchar",
    "embucháramo": "embuchar",
    "embucháramos": "embuchar",
    "embuchárei": "embuchar",
    "embucháreis": "embuchar",
    "embuchásseis": "embuchar",
    "embuchássemos": "embuchar",
    "embuchávamo": "embuchar",
    "embuchávamos": "embuchar",
    "embuchávei": "embuchar",
    "embucháveis": "embuchar",
    "embuda": "embudar",
    "embudada": "embudar",
    "embudadas": "embudar",
    "embudado": "embudar",
    "embudados": "embudar",
    "embudai": "embudar",
    "embudais": "embudar",
    "embudam": "embudar",
    "embudamo": "embudar",
    "embudamos": "embudar",
    "embudando": "embudar",
    "embudara": "embudar",
    "embudaram": "embudar",
    "embudaras": "embudar",
    "embudarde": "embudar",
    "embudardes": "embudar",
    "embudare": "embudar",
    "embudarei": "embudar",
    "embudareis": "embudar",
    "embudarem": "embudar",
    "embudaremos": "embudar",
    "embudares": "embudar",
    "embudaria": "embudar",
    "embudariam": "embudar",
    "embudarias": "embudar",
    "embudarmo": "embudar",
    "embudarmos": "embudar",
    "embudará": "embudar",
    "embudarás": "embudar",
    "embudarão": "embudar",
    "embudaríamos": "embudar",
    "embudaríeis": "embudar",
    "embudas": "embudar",
    "embudasse": "embudar",
    "embudassem": "embudar",
    "embudasses": "embudar",
    "embudaste": "embudar",
    "embudastes": "embudar",
    "embudava": "embudar",
    "embudavam": "embudar",
    "embudavas": "embudar",
    "embude": "embudar",
    "embudei": "embudar",
    "embudeis": "embudar",
    "embudem": "embudar",
    "embudemo": "embudar",
    "embudemos": "embudar",
    "embudes": "embude",
    "embudo": "embudar",
    "embudos": "embudo",
    "embudou": "embudar",
    "embudá": "embudar",
    "embudámo": "embudar",
    "embudámos": "embudar",
    "embudáramo": "embudar",
    "embudáramos": "embudar",
    "embudárei": "embudar",
    "embudáreis": "embudar",
    "embudásseis": "embudar",
    "embudássemos": "embudar",
    "embudávamo": "embudar",
    "embudávamos": "embudar",
    "embudávei": "embudar",
    "embudáveis": "embudar",
    "emburguesada": "emburguesado",
    "emburguesadas": "emburguesado",
    "emburguesados": "emburguesado",
    "emburra": "emburrar",
    "emburrada": "emburrar",
    "emburradas": "emburrar",
    "emburrado": "emburrar",
    "emburrados": "emburrar",
    "emburrai": "emburrar",
    "emburrais": "emburrar",
    "emburram": "emburrar",
    "emburramo": "emburrar",
    "emburramos": "emburrar",
    "emburrando": "emburrar",
    "emburrara": "emburrar",
    "emburraram": "emburrar",
    "emburraras": "emburrar",
    "emburrarde": "emburrar",
    "emburrardes": "emburrar",
    "emburrare": "emburrar",
    "emburrarei": "emburrar",
    "emburrareis": "emburrar",
    "emburrarem": "emburrar",
    "emburraremos": "emburrar",
    "emburrares": "emburrar",
    "emburraria": "emburrar",
    "emburrariam": "emburrar",
    "emburrarias": "emburrar",
    "emburrarmo": "emburrar",
    "emburrarmos": "emburrar",
    "emburrará": "emburrar",
    "emburrarás": "emburrar",
    "emburrarão": "emburrar",
    "emburraríamos": "emburrar",
    "emburraríeis": "emburrar",
    "emburras": "emburrar",
    "emburrasse": "emburrar",
    "emburrassem": "emburrar",
    "emburrasses": "emburrar",
    "emburraste": "emburrar",
    "emburrastes": "emburrar",
    "emburrava": "emburrar",
    "emburravam": "emburrar",
    "emburravas": "emburrar",
    "emburre": "emburrar",
    "emburrei": "emburrar",
    "emburreis": "emburrar",
    "emburrem": "emburrar",
    "emburremo": "emburrar",
    "emburremos": "emburrar",
    "emburres": "emburrar",
    "emburrica": "emburricar",
    "emburricada": "emburricar",
    "emburricadas": "emburricar",
    "emburricado": "emburricar",
    "emburricados": "emburricar",
    "emburricai": "emburricar",
    "emburricais": "emburricar",
    "emburricam": "emburricar",
    "emburricamo": "emburricar",
    "emburricamos": "emburricar",
    "emburricando": "emburricar",
    "emburricara": "emburricar",
    "emburricaram": "emburricar",
    "emburricaras": "emburricar",
    "emburricarde": "emburricar",
    "emburricardes": "emburricar",
    "emburricare": "emburricar",
    "emburricarei": "emburricar",
    "emburricareis": "emburricar",
    "emburricarem": "emburricar",
    "emburricaremos": "emburricar",
    "emburricares": "emburricar",
    "emburricaria": "emburricar",
    "emburricariam": "emburricar",
    "emburricarias": "emburricar",
    "emburricarmo": "emburricar",
    "emburricarmos": "emburricar",
    "emburricará": "emburricar",
    "emburricarás": "emburricar",
    "emburricarão": "emburricar",
    "emburricaríamos": "emburricar",
    "emburricaríeis": "emburricar",
    "emburricas": "emburricar",
    "emburricasse": "emburricar",
    "emburricassem": "emburricar",
    "emburricasses": "emburricar",
    "emburricaste": "emburricar",
    "emburricastes": "emburricar",
    "emburricava": "emburricar",
    "emburricavam": "emburricar",
    "emburricavas": "emburricar",
    "emburrico": "emburricar",
    "emburricou": "emburricar",
    "emburricá": "emburricar",
    "emburricámo": "emburricar",
    "emburricámos": "emburricar",
    "emburricáramo": "emburricar",
    "emburricáramos": "emburricar",
    "emburricárei": "emburricar",
    "emburricáreis": "emburricar",
    "emburricásseis": "emburricar",
    "emburricássemos": "emburricar",
    "emburricávamo": "emburricar",
    "emburricávamos": "emburricar",
    "emburricávei": "emburricar",
    "emburricáveis": "emburricar",
    "emburrique": "emburricar",
    "emburriquei": "emburricar",
    "emburriqueis": "emburricar",
    "emburriquem": "emburricar",
    "emburriquemo": "emburricar",
    "emburriquemos": "emburricar",
    "emburriques": "emburricar",
    "emburro": "emburrar",
    "emburrou": "emburrar",
    "emburrá": "emburrar",
    "emburrámo": "emburrar",
    "emburrámos": "emburrar",
    "emburráramo": "emburrar",
    "emburráramos": "emburrar",
    "emburrárei": "emburrar",
    "emburráreis": "emburrar",
    "emburrásseis": "emburrar",
    "emburrássemos": "emburrar",
    "emburrávamo": "emburrar",
    "emburrávamos": "emburrar",
    "emburrávei": "emburrar",
    "emburráveis": "emburrar",
    "embusteada": "embustear",
    "embusteadas": "embustear",
    "embusteado": "embustear",
    "embusteados": "embustear",
    "embusteai": "embustear",
    "embusteais": "embustear",
    "embusteamo": "embustear",
    "embusteamos": "embustear",
    "embusteando": "embustear",
    "embusteara": "embustear",
    "embustearam": "embustear",
    "embustearas": "embustear",
    "embustearde": "embustear",
    "embusteardes": "embustear",
    "embusteare": "embustear",
    "embustearei": "embustear",
    "embusteareis": "embustear",
    "embustearem": "embustear",
    "embustearemos": "embustear",
    "embusteares": "embustear",
    "embustearia": "embustear",
    "embusteariam": "embustear",
    "embustearias": "embustear",
    "embustearmo": "embustear",
    "embustearmos": "embustear",
    "embusteará": "embustear",
    "embustearás": "embustear",
    "embustearão": "embustear",
    "embustearíamos": "embustear",
    "embustearíeis": "embustear",
    "embusteasse": "embustear",
    "embusteassem": "embustear",
    "embusteasses": "embustear",
    "embusteaste": "embustear",
    "embusteastes": "embustear",
    "embusteava": "embustear",
    "embusteavam": "embustear",
    "embusteavas": "embustear",
    "embusteei": "embustear",
    "embusteeis": "embustear",
    "embusteemo": "embustear",
    "embusteemos": "embustear",
    "embusteia": "embustear",
    "embusteiam": "embustear",
    "embusteias": "embustear",
    "embusteie": "embustear",
    "embusteiem": "embustear",
    "embusteies": "embustear",
    "embusteio": "embustear",
    "embusteira": "embusteiro",
    "embusteiras": "embusteiro",
    "embusteiros": "embusteiro",
    "embusteou": "embustear",
    "embustes": "embuste",
    "embusteá": "embustear",
    "embusteámo": "embustear",
    "embusteámos": "embustear",
    "embusteáramo": "embustear",
    "embusteáramos": "embustear",
    "embusteárei": "embustear",
    "embusteáreis": "embustear",
    "embusteásseis": "embustear",
    "embusteássemos": "embustear",
    "embusteávamo": "embustear",
    "embusteávamos": "embustear",
    "embusteávei": "embustear",
    "embusteáveis": "embustear",
    "embustices": "embustice",
    "embuta": "embutir",
    "embutais": "embutir",
    "embutam": "embutir",
    "embutamo": "embutir",
    "embutamos": "embutir",
    "embutas": "embutir",
    "embute": "embutir",
    "embutem": "embutir",
    "embutes": "embutir",
    "embuti": "embutir",
    "embutia": "embutir",
    "embutiam": "embutir",
    "embutias": "embutir",
    "embutida": "embutir",
    "embutidas": "embutir",
    "embutideiras": "embutideira",
    "embutido": "embutir",
    "embutidora": "embutidor",
    "embutidoras": "embutidor",
    "embutidores": "embutidor",
    "embutidos": "embutir",
    "embutiduras": "embutidura",
    "embutimentos": "embutimento",
    "embutimo": "embutir",
    "embutimos": "embutir",
    "embutindo": "embutir",
    "embutira": "embutir",
    "embutiram": "embutir",
    "embutiras": "embutir",
    "embutirde": "embutir",
    "embutirdes": "embutir",
    "embutire": "embutir",
    "embutirei": "embutir",
    "embutireis": "embutir",
    "embutirem": "embutir",
    "embutiremos": "embutir",
    "embutires": "embutir",
    "embutiria": "embutir",
    "embutiriam": "embutir",
    "embutirias": "embutir",
    "embutirmo": "embutir",
    "embutirmos": "embutir",
    "embutirá": "embutir",
    "embutirás": "embutir",
    "embutirão": "embutir",
    "embutiríamos": "embutir",
    "embutiríeis": "embutir",
    "embutis": "embutir",
    "embutisse": "embutir",
    "embutissem": "embutir",
    "embutisses": "embutir",
    "embutiste": "embutir",
    "embutistes": "embutir",
    "embutiu": "embutir",
    "embuto": "embutir",
    "embutíamo": "embutir",
    "embutíamos": "embutir",
    "embutíei": "embutir",
    "embutíeis": "embutir",
    "embutíramo": "embutir",
    "embutíramos": "embutir",
    "embutírei": "embutir",
    "embutíreis": "embutir",
    "embutísseis": "embutir",
    "embutíssemos": "embutir",
    "embutíveis": "embutível",
    "embuzina": "embuzinar",
    "embuzinada": "embuzinar",
    "embuzinadas": "embuzinar",
    "embuzinado": "embuzinar",
    "embuzinados": "embuzinar",
    "embuzinai": "embuzinar",
    "embuzinais": "embuzinar",
    "embuzinam": "embuzinar",
    "embuzinamo": "embuzinar",
    "embuzinamos": "embuzinar",
    "embuzinando": "embuzinar",
    "embuzinara": "embuzinar",
    "embuzinaram": "embuzinar",
    "embuzinaras": "embuzinar",
    "embuzinarde": "embuzinar",
    "embuzinardes": "embuzinar",
    "embuzinare": "embuzinar",
    "embuzinarei": "embuzinar",
    "embuzinareis": "embuzinar",
    "embuzinarem": "embuzinar",
    "embuzinaremos": "embuzinar",
    "embuzinares": "embuzinar",
    "embuzinaria": "embuzinar",
    "embuzinariam": "embuzinar",
    "embuzinarias": "embuzinar",
    "embuzinarmo": "embuzinar",
    "embuzinarmos": "embuzinar",
    "embuzinará": "embuzinar",
    "embuzinarás": "embuzinar",
    "embuzinarão": "embuzinar",
    "embuzinaríamos": "embuzinar",
    "embuzinaríeis": "embuzinar",
    "embuzinas": "embuzinar",
    "embuzinasse": "embuzinar",
    "embuzinassem": "embuzinar",
    "embuzinasses": "embuzinar",
    "embuzinaste": "embuzinar",
    "embuzinastes": "embuzinar",
    "embuzinava": "embuzinar",
    "embuzinavam": "embuzinar",
    "embuzinavas": "embuzinar",
    "embuzine": "embuzinar",
    "embuzinei": "embuzinar",
    "embuzineis": "embuzinar",
    "embuzinem": "embuzinar",
    "embuzinemo": "embuzinar",
    "embuzinemos": "embuzinar",
    "embuzines": "embuzinar",
    "embuzino": "embuzinar",
    "embuzinou": "embuzinar",
    "embuziná": "embuzinar",
    "embuzinámo": "embuzinar",
    "embuzinámos": "embuzinar",
    "embuzináramo": "embuzinar",
    "embuzináramos": "embuzinar",
    "embuzinárei": "embuzinar",
    "embuzináreis": "embuzinar",
    "embuzinásseis": "embuzinar",
    "embuzinássemos": "embuzinar",
    "embuzinávamo": "embuzinar",
    "embuzinávamos": "embuzinar",
    "embuzinávei": "embuzinar",
    "embuzináveis": "embuzinar",
    "embuça": "embuçar",
    "embuçada": "embuçar",
    "embuçadas": "embuçar",
    "embuçado": "embuçar",
    "embuçados": "embuçar",
    "embuçai": "embuçar",
    "embuçais": "embuçar",
    "embuçam": "embuçar",
    "embuçamo": "embuçar",
    "embuçamos": "embuçar",
    "embuçando": "embuçar",
    "embuçara": "embuçar",
    "embuçaram": "embuçar",
    "embuçaras": "embuçar",
    "embuçarde": "embuçar",
    "embuçardes": "embuçar",
    "embuçare": "embuçar",
    "embuçarei": "embuçar",
    "embuçareis": "embuçar",
    "embuçarem": "embuçar",
    "embuçaremos": "embuçar",
    "embuçares": "embuçar",
    "embuçaria": "embuçar",
    "embuçariam": "embuçar",
    "embuçarias": "embuçar",
    "embuçarmo": "embuçar",
    "embuçarmos": "embuçar",
    "embuçará": "embuçar",
    "embuçarás": "embuçar",
    "embuçarão": "embuçar",
    "embuçaríamos": "embuçar",
    "embuçaríeis": "embuçar",
    "embuças": "embuçar",
    "embuçasse": "embuçar",
    "embuçassem": "embuçar",
    "embuçasses": "embuçar",
    "embuçaste": "embuçar",
    "embuçastes": "embuçar",
    "embuçava": "embuçar",
    "embuçavam": "embuçar",
    "embuçavas": "embuçar",
    "embuço": "embuçar",
    "embuços": "embuço",
    "embuçou": "embuçar",
    "embuçá": "embuçar",
    "embuçámo": "embuçar",
    "embuçámos": "embuçar",
    "embuçáramo": "embuçar",
    "embuçáramos": "embuçar",
    "embuçárei": "embuçar",
    "embuçáreis": "embuçar",
    "embuçásseis": "embuçar",
    "embuçássemos": "embuçar",
    "embuçávamo": "embuçar",
    "embuçávamos": "embuçar",
    "embuçávei": "embuçar",
    "embuçáveis": "embuçar",
    "embófias": "embófia",
    "emecha": "emechar",
    "emechada": "emechar",
    "emechadas": "emechar",
    "emechado": "emechar",
    "emechados": "emechar",
    "emechai": "emechar",
    "emechais": "emechar",
    "emecham": "emechar",
    "emechamo": "emechar",
    "emechamos": "emechar",
    "emechando": "emechar",
    "emechara": "emechar",
    "emecharam": "emechar",
    "emecharas": "emechar",
    "emecharde": "emechar",
    "emechardes": "emechar",
    "emechare": "emechar",
    "emecharei": "emechar",
    "emechareis": "emechar",
    "emecharem": "emechar",
    "emecharemos": "emechar",
    "emechares": "emechar",
    "emecharia": "emechar",
    "emechariam": "emechar",
    "emecharias": "emechar",
    "emecharmo": "emechar",
    "emecharmos": "emechar",
    "emechará": "emechar",
    "emecharás": "emechar",
    "emecharão": "emechar",
    "emecharíamos": "emechar",
    "emecharíeis": "emechar",
    "emechas": "emechar",
    "emechasse": "emechar",
    "emechassem": "emechar",
    "emechasses": "emechar",
    "emechaste": "emechar",
    "emechastes": "emechar",
    "emechava": "emechar",
    "emechavam": "emechar",
    "emechavas": "emechar",
    "emeche": "emechar",
    "emechei": "emechar",
    "emecheis": "emechar",
    "emechem": "emechar",
    "emechemo": "emechar",
    "emechemos": "emechar",
    "emeches": "emechar",
    "emecho": "emechar",
    "emechou": "emechar",
    "emechá": "emechar",
    "emechámo": "emechar",
    "emechámos": "emechar",
    "emecháramo": "emechar",
    "emecháramos": "emechar",
    "emechárei": "emechar",
    "emecháreis": "emechar",
    "emechásseis": "emechar",
    "emechássemos": "emechar",
    "emechávamo": "emechar",
    "emechávamos": "emechar",
    "emechávei": "emechar",
    "emecháveis": "emechar",
    "emeda": "emedar",
    "emedada": "emedar",
    "emedadas": "emedar",
    "emedado": "emedar",
    "emedados": "emedar",
    "emedai": "emedar",
    "emedais": "emedar",
    "emedam": "emedar",
    "emedamo": "emedar",
    "emedamos": "emedar",
    "emedando": "emedar",
    "emedara": "emedar",
    "emedaram": "emedar",
    "emedaras": "emedar",
    "emedarde": "emedar",
    "emedardes": "emedar",
    "emedare": "emedar",
    "emedarei": "emedar",
    "emedareis": "emedar",
    "emedarem": "emedar",
    "emedaremos": "emedar",
    "emedares": "emedar",
    "emedaria": "emedar",
    "emedariam": "emedar",
    "emedarias": "emedar",
    "emedarmo": "emedar",
    "emedarmos": "emedar",
    "emedará": "emedar",
    "emedarás": "emedar",
    "emedarão": "emedar",
    "emedaríamos": "emedar",
    "emedaríeis": "emedar",
    "emedas": "emedar",
    "emedasse": "emedar",
    "emedassem": "emedar",
    "emedasses": "emedar",
    "emedaste": "emedar",
    "emedastes": "emedar",
    "emedava": "emedar",
    "emedavam": "emedar",
    "emedavas": "emedar",
    "emede": "emedar",
    "emedei": "emedar",
    "emedeis": "emedar",
    "emedem": "emedar",
    "emedemo": "emedar",
    "emedemos": "emedar",
    "emedes": "emedar",
    "emedo": "emedar",
    "emedou": "emedar",
    "emedá": "emedar",
    "emedámo": "emedar",
    "emedámos": "emedar",
    "emedáramo": "emedar",
    "emedáramos": "emedar",
    "emedárei": "emedar",
    "emedáreis": "emedar",
    "emedásseis": "emedar",
    "emedássemos": "emedar",
    "emedávamo": "emedar",
    "emedávamos": "emedar",
    "emedávei": "emedar",
    "emedáveis": "emedar",
    "emela": "emelar",
    "emelada": "emelar",
    "emeladas": "emelar",
    "emelado": "emelar",
    "emelados": "emelar",
    "emelai": "emelar",
    "emelais": "emelar",
    "emelam": "emelar",
    "emelamo": "emelar",
    "emelamos": "emelar",
    "emelando": "emelar",
    "emelara": "emelar",
    "emelaram": "emelar",
    "emelaras": "emelar",
    "emelarde": "emelar",
    "emelardes": "emelar",
    "emelare": "emelar",
    "emelarei": "emelar",
    "emelareis": "emelar",
    "emelarem": "emelar",
    "emelaremos": "emelar",
    "emelares": "emelar",
    "emelaria": "emelar",
    "emelariam": "emelar",
    "emelarias": "emelar",
    "emelarmo": "emelar",
    "emelarmos": "emelar",
    "emelará": "emelar",
    "emelarás": "emelar",
    "emelarão": "emelar",
    "emelaríamos": "emelar",
    "emelaríeis": "emelar",
    "emelas": "emelar",
    "emelasse": "emelar",
    "emelassem": "emelar",
    "emelasses": "emelar",
    "emelaste": "emelar",
    "emelastes": "emelar",
    "emelava": "emelar",
    "emelavam": "emelar",
    "emelavas": "emelar",
    "emele": "emelar",
    "emelei": "emelar",
    "emeleis": "emelar",
    "emelem": "emelar",
    "emelemo": "emelar",
    "emelemos": "emelar",
    "emeles": "emelar",
    "emelo": "emelar",
    "emelou": "emelar",
    "emelá": "emelar",
    "emelámo": "emelar",
    "emelámos": "emelar",
    "emeláramo": "emelar",
    "emeláramos": "emelar",
    "emelárei": "emelar",
    "emeláreis": "emelar",
    "emelásseis": "emelar",
    "emelássemos": "emelar",
    "emelávamo": "emelar",
    "emelávamos": "emelar",
    "emelávei": "emelar",
    "emeláveis": "emelar",
    "emenagoga": "emenagogo",
    "emenagogas": "emenagogo",
    "emenagogos": "emenagogo",
    "emenda": "emendar",
    "emendada": "emendar",
    "emendadas": "emendar",
    "emendado": "emendar",
    "emendadora": "emendador",
    "emendadoras": "emendador",
    "emendadores": "emendador",
    "emendados": "emendar",
    "emendai": "emendar",
    "emendais": "emendar",
    "emendam": "emendar",
    "emendamo": "emendar",
    "emendamos": "emendar",
    "emendando": "emendar",
    "emendara": "emendar",
    "emendaram": "emendar",
    "emendaras": "emendar",
    "emendarde": "emendar",
    "emendardes": "emendar",
    "emendare": "emendar",
    "emendarei": "emendar",
    "emendareis": "emendar",
    "emendarem": "emendar",
    "emendaremos": "emendar",
    "emendares": "emendar",
    "emendaria": "emendar",
    "emendariam": "emendar",
    "emendarias": "emendar",
    "emendarmo": "emendar",
    "emendarmos": "emendar",
    "emendará": "emendar",
    "emendarás": "emendar",
    "emendarão": "emendar",
    "emendaríamos": "emendar",
    "emendaríeis": "emendar",
    "emendas": "emendar",
    "emendasse": "emendar",
    "emendassem": "emendar",
    "emendasses": "emendar",
    "emendaste": "emendar",
    "emendastes": "emendar",
    "emendava": "emendar",
    "emendavam": "emendar",
    "emendavas": "emendar",
    "emende": "emendar",
    "emendei": "emendar",
    "emendeis": "emendar",
    "emendem": "emendar",
    "emendemo": "emendar",
    "emendemos": "emendar",
    "emendes": "emendar",
    "emendo": "emendar",
    "emendou": "emendar",
    "emendá": "emendar",
    "emendámo": "emendar",
    "emendámos": "emendar",
    "emendáramo": "emendar",
    "emendáramos": "emendar",
    "emendárei": "emendar",
    "emendáreis": "emendar",
    "emendásseis": "emendar",
    "emendássemos": "emendar",
    "emendávamo": "emendar",
    "emendávamos": "emendar",
    "emendávei": "emendar",
    "emendáveis": "emendável",
    "ementa": "ementar",
    "ementada": "ementar",
    "ementadas": "ementar",
    "ementado": "ementar",
    "ementados": "ementar",
    "ementai": "ementar",
    "ementais": "ementar",
    "ementam": "ementar",
    "ementamo": "ementar",
    "ementamos": "ementar",
    "ementando": "ementar",
    "ementara": "ementar",
    "ementaram": "ementar",
    "ementaras": "ementar",
    "ementarde": "ementar",
    "ementardes": "ementar",
    "ementare": "ementar",
    "ementarei": "ementar",
    "ementareis": "ementar",
    "ementarem": "ementar",
    "ementaremos": "ementar",
    "ementares": "ementar",
    "ementaria": "ementar",
    "ementariam": "ementar",
    "ementarias": "ementar",
    "ementarmo": "ementar",
    "ementarmos": "ementar",
    "ementará": "ementar",
    "ementarás": "ementar",
    "ementarão": "ementar",
    "ementaríamos": "ementar",
    "ementaríeis": "ementar",
    "ementas": "ementar",
    "ementasse": "ementar",
    "ementassem": "ementar",
    "ementasses": "ementar",
    "ementaste": "ementar",
    "ementastes": "ementar",
    "ementava": "ementar",
    "ementavam": "ementar",
    "ementavas": "ementar",
    "emente": "ementar",
    "ementei": "ementar",
    "ementeis": "ementar",
    "ementem": "ementar",
    "ementemo": "ementar",
    "ementemos": "ementar",
    "ementes": "ementar",
    "emento": "ementar",
    "ementou": "ementar",
    "ementá": "ementar",
    "ementámo": "ementar",
    "ementámos": "ementar",
    "ementáramo": "ementar",
    "ementáramos": "ementar",
    "ementárei": "ementar",
    "ementáreis": "ementar",
    "ementários": "ementário",
    "ementásseis": "ementar",
    "ementássemos": "ementar",
    "ementávamo": "ementar",
    "ementávamos": "ementar",
    "ementávei": "ementar",
    "ementáveis": "ementar",
    "emerge": "emergir",
    "emergem": "emergir",
    "emergentes": "emergente",
    "emerges": "emergir",
    "emergi": "emergir",
    "emergia": "emergir",
    "emergiam": "emergir",
    "emergias": "emergir",
    "emergida": "emergir",
    "emergidas": "emergir",
    "emergido": "emergir",
    "emergidos": "emergir",
    "emergimo": "emergir",
    "emergimos": "emergir",
    "emergindo": "emergir",
    "emergira": "emergir",
    "emergiram": "emergir",
    "emergiras": "emergir",
    "emergirde": "emergir",
    "emergirdes": "emergir",
    "emergire": "emergir",
    "emergirei": "emergir",
    "emergireis": "emergir",
    "emergirem": "emergir",
    "emergiremos": "emergir",
    "emergires": "emergir",
    "emergiria": "emergir",
    "emergiriam": "emergir",
    "emergirias": "emergir",
    "emergirmo": "emergir",
    "emergirmos": "emergir",
    "emergirá": "emergir",
    "emergirás": "emergir",
    "emergirão": "emergir",
    "emergiríamos": "emergir",
    "emergiríeis": "emergir",
    "emergis": "emergir",
    "emergisse": "emergir",
    "emergissem": "emergir",
    "emergisses": "emergir",
    "emergiste": "emergir",
    "emergistes": "emergir",
    "emergiu": "emergir",
    "emergências": "emergência",
    "emergíamo": "emergir",
    "emergíamos": "emergir",
    "emergíei": "emergir",
    "emergíeis": "emergir",
    "emergíramo": "emergir",
    "emergíramos": "emergir",
    "emergírei": "emergir",
    "emergíreis": "emergir",
    "emergísseis": "emergir",
    "emergíssemos": "emergir",
    "emeritenses": "emeritense",
    "emersa": "emerso",
    "emersas": "emerso",
    "emersos": "emerso",
    "emersões": "emersão",
    "emes": "eme",
    "emesianos": "emesiano",
    "emeticidades": "emeticidade",
    "emetinas": "emetina",
    "emetiza": "emetizar",
    "emetizada": "emetizar",
    "emetizadas": "emetizar",
    "emetizado": "emetizar",
    "emetizados": "emetizar",
    "emetizai": "emetizar",
    "emetizais": "emetizar",
    "emetizam": "emetizar",
    "emetizamo": "emetizar",
    "emetizamos": "emetizar",
    "emetizando": "emetizar",
    "emetizantes": "emetizante",
    "emetizara": "emetizar",
    "emetizaram": "emetizar",
    "emetizaras": "emetizar",
    "emetizarde": "emetizar",
    "emetizardes": "emetizar",
    "emetizare": "emetizar",
    "emetizarei": "emetizar",
    "emetizareis": "emetizar",
    "emetizarem": "emetizar",
    "emetizaremos": "emetizar",
    "emetizares": "emetizar",
    "emetizaria": "emetizar",
    "emetizariam": "emetizar",
    "emetizarias": "emetizar",
    "emetizarmo": "emetizar",
    "emetizarmos": "emetizar",
    "emetizará": "emetizar",
    "emetizarás": "emetizar",
    "emetizarão": "emetizar",
    "emetizaríamos": "emetizar",
    "emetizaríeis": "emetizar",
    "emetizas": "emetizar",
    "emetizasse": "emetizar",
    "emetizassem": "emetizar",
    "emetizasses": "emetizar",
    "emetizaste": "emetizar",
    "emetizastes": "emetizar",
    "emetizava": "emetizar",
    "emetizavam": "emetizar",
    "emetizavas": "emetizar",
    "emetize": "emetizar",
    "emetizei": "emetizar",
    "emetizeis": "emetizar",
    "emetizem": "emetizar",
    "emetizemo": "emetizar",
    "emetizemos": "emetizar",
    "emetizes": "emetizar",
    "emetizo": "emetizar",
    "emetizou": "emetizar",
    "emetizá": "emetizar",
    "emetizámo": "emetizar",
    "emetizámos": "emetizar",
    "emetizáramo": "emetizar",
    "emetizáramos": "emetizar",
    "emetizárei": "emetizar",
    "emetizáreis": "emetizar",
    "emetizásseis": "emetizar",
    "emetizássemos": "emetizar",
    "emetizávamo": "emetizar",
    "emetizávamos": "emetizar",
    "emetizávei": "emetizar",
    "emetizáveis": "emetizar",
    "emetropes": "emetrope",
    "emetropias": "emetropia",
    "emetrópica": "emetrópico",
    "emetrópicas": "emetrópico",
    "emetrópicos": "emetrópico",
    "emigra": "emigrar",
    "emigrada": "emigrar",
    "emigradas": "emigrar",
    "emigrado": "emigrar",
    "emigradora": "emigrador",
    "emigradoras": "emigrador",
    "emigradores": "emigrador",
    "emigrados": "emigrar",
    "emigrai": "emigrar",
    "emigrais": "emigrar",
    "emigram": "emigrar",
    "emigramo": "emigrar",
    "emigramos": "emigrar",
    "emigrando": "emigrar",
    "emigrantes": "emigrante",
    "emigrara": "emigrar",
    "emigraram": "emigrar",
    "emigraras": "emigrar",
    "emigrardes": "emigrar",
    "emigrarei": "emigrar",
    "emigrareis": "emigrar",
    "emigrarem": "emigrar",
    "emigraremos": "emigrar",
    "emigrares": "emigrar",
    "emigraria": "emigrar",
    "emigrariam": "emigrar",
    "emigrarias": "emigrar",
    "emigrarmo": "emigrar",
    "emigrarmos": "emigrar",
    "emigrará": "emigrar",
    "emigrarás": "emigrar",
    "emigrarão": "emigrar",
    "emigraríamos": "emigrar",
    "emigraríeis": "emigrar",
    "emigras": "emigrar",
    "emigrasse": "emigrar",
    "emigrassem": "emigrar",
    "emigrasses": "emigrar",
    "emigraste": "emigrar",
    "emigrastes": "emigrar",
    "emigratória": "emigratório",
    "emigratórias": "emigratório",
    "emigratórios": "emigratório",
    "emigrava": "emigrar",
    "emigravam": "emigrar",
    "emigravas": "emigrar",
    "emigrações": "emigração",
    "emigre": "emigrar",
    "emigrei": "emigrar",
    "emigreis": "emigrar",
    "emigrem": "emigrar",
    "emigremo": "emigrar",
    "emigremos": "emigrar",
    "emigres": "emigrar",
    "emigro": "emigrar",
    "emigrou": "emigrar",
    "emigrámo": "emigrar",
    "emigrámos": "emigrar",
    "emigráramo": "emigrar",
    "emigráramos": "emigrar",
    "emigráreis": "emigrar",
    "emigrásseis": "emigrar",
    "emigrássemos": "emigrar",
    "emigrávamo": "emigrar",
    "emigrávamos": "emigrar",
    "emigráveis": "emigrar",
    "eminencia": "eminenciar",
    "eminenciada": "eminenciar",
    "eminenciadas": "eminenciar",
    "eminenciado": "eminenciar",
    "eminenciados": "eminenciar",
    "eminenciai": "eminenciar",
    "eminenciais": "eminenciar",
    "eminenciam": "eminenciar",
    "eminenciamo": "eminenciar",
    "eminenciamos": "eminenciar",
    "eminenciando": "eminenciar",
    "eminenciara": "eminenciar",
    "eminenciaram": "eminenciar",
    "eminenciaras": "eminenciar",
    "eminenciardes": "eminenciar",
    "eminenciarei": "eminenciar",
    "eminenciareis": "eminenciar",
    "eminenciarem": "eminenciar",
    "eminenciaremos": "eminenciar",
    "eminenciares": "eminenciar",
    "eminenciaria": "eminenciar",
    "eminenciariam": "eminenciar",
    "eminenciarias": "eminenciar",
    "eminenciarmo": "eminenciar",
    "eminenciarmos": "eminenciar",
    "eminenciará": "eminenciar",
    "eminenciarás": "eminenciar",
    "eminenciarão": "eminenciar",
    "eminenciaríamos": "eminenciar",
    "eminenciaríeis": "eminenciar",
    "eminencias": "eminenciar",
    "eminenciasse": "eminenciar",
    "eminenciassem": "eminenciar",
    "eminenciasses": "eminenciar",
    "eminenciaste": "eminenciar",
    "eminenciastes": "eminenciar",
    "eminenciava": "eminenciar",
    "eminenciavam": "eminenciar",
    "eminenciavas": "eminenciar",
    "eminencie": "eminenciar",
    "eminenciei": "eminenciar",
    "eminencieis": "eminenciar",
    "eminenciem": "eminenciar",
    "eminenciemo": "eminenciar",
    "eminenciemos": "eminenciar",
    "eminencies": "eminenciar",
    "eminencio": "eminenciar",
    "eminenciou": "eminenciar",
    "eminenciámo": "eminenciar",
    "eminenciámos": "eminenciar",
    "eminenciáramo": "eminenciar",
    "eminenciáramos": "eminenciar",
    "eminenciáreis": "eminenciar",
    "eminenciásseis": "eminenciar",
    "eminenciássemos": "eminenciar",
    "eminenciávamo": "eminenciar",
    "eminenciávamos": "eminenciar",
    "eminenciáveis": "eminenciar",
    "eminentes": "eminente",
    "eminentíssima": "eminente",
    "eminentíssimas": "eminente",
    "eminentíssimo": "eminente",
    "eminentíssimos": "eminente",
    "eminências": "eminência",
    "emirados": "emirado",
    "emires": "emir",
    "emirja": "emergir",
    "emirjais": "emergir",
    "emirjam": "emergir",
    "emirjamo": "emergir",
    "emirjamos": "emergir",
    "emirjas": "emergir",
    "emirjo": "emergir",
    "emissionismos": "emissionismo",
    "emissiva": "emissivo",
    "emissivas": "emissivo",
    "emissividades": "emissividade",
    "emissivos": "emissivo",
    "emissora": "emissor",
    "emissoras": "emissora",
    "emissores": "emissor",
    "emissors": "emissor",
    "emissária": "emissário",
    "emissárias": "emissário",
    "emissários": "emissário",
    "emissíveis": "emissível",
    "emissória": "emissório",
    "emissórias": "emissório",
    "emissórios": "emissório",
    "emissões": "emissão",
    "emita": "emitir",
    "emitais": "emitir",
    "emitam": "emitir",
    "emitamo": "emitir",
    "emitamos": "emitir",
    "emitas": "emitir",
    "emite": "emitir",
    "emitem": "emitir",
    "emitentes": "emitente",
    "emites": "emitir",
    "emiti": "emitir",
    "emitia": "emitir",
    "emitiam": "emitir",
    "emitias": "emitir",
    "emitida": "emitir",
    "emitidas": "emitir",
    "emitido": "emitir",
    "emitidos": "emitir",
    "emitimo": "emitir",
    "emitimos": "emitir",
    "emitindo": "emitir",
    "emitira": "emitir",
    "emitiram": "emitir",
    "emitiras": "emitir",
    "emitirde": "emitir",
    "emitirdes": "emitir",
    "emitire": "emitir",
    "emitirei": "emitir",
    "emitireis": "emitir",
    "emitirem": "emitir",
    "emitiremos": "emitir",
    "emitires": "emitir",
    "emitiria": "emitir",
    "emitiriam": "emitir",
    "emitirias": "emitir",
    "emitirmo": "emitir",
    "emitirmos": "emitir",
    "emitirá": "emitir",
    "emitirás": "emitir",
    "emitirão": "emitir",
    "emitiríamos": "emitir",
    "emitiríeis": "emitir",
    "emitis": "emitir",
    "emitisse": "emitir",
    "emitissem": "emitir",
    "emitisses": "emitir",
    "emitiste": "emitir",
    "emitistes": "emitir",
    "emitiu": "emitir",
    "emito": "emitir",
    "emitâncias": "emitância",
    "emitíamo": "emitir",
    "emitíamos": "emitir",
    "emitíei": "emitir",
    "emitíeis": "emitir",
    "emitíramo": "emitir",
    "emitíramos": "emitir",
    "emitírei": "emitir",
    "emitíreis": "emitir",
    "emitísseis": "emitir",
    "emitíssemos": "emitir",
    "emitíveis": "emitível",
    "emmeios": "emmeio",
    "emociona": "emocionar",
    "emocionada": "emocionar",
    "emocionadas": "emocionar",
    "emocionado": "emocionar",
    "emocionados": "emocionar",
    "emocionadíssima": "emocionado",
    "emocionadíssimas": "emocionado",
    "emocionadíssimo": "emocionado",
    "emocionadíssimos": "emocionado",
    "emocionai": "emocionar",
    "emocionais": "emocionar",
    "emocionam": "emocionar",
    "emocionamo": "emocionar",
    "emocionamos": "emocionar",
    "emocionando": "emocionar",
    "emocionantes": "emocionante",
    "emocionara": "emocionar",
    "emocionaram": "emocionar",
    "emocionaras": "emocionar",
    "emocionarde": "emocionar",
    "emocionardes": "emocionar",
    "emocionare": "emocionar",
    "emocionarei": "emocionar",
    "emocionareis": "emocionar",
    "emocionarem": "emocionar",
    "emocionaremos": "emocionar",
    "emocionares": "emocionar",
    "emocionaria": "emocionar",
    "emocionariam": "emocionar",
    "emocionarias": "emocionar",
    "emocionarmo": "emocionar",
    "emocionarmos": "emocionar",
    "emocionará": "emocionar",
    "emocionarás": "emocionar",
    "emocionarão": "emocionar",
    "emocionaríamos": "emocionar",
    "emocionaríeis": "emocionar",
    "emocionas": "emocionar",
    "emocionasse": "emocionar",
    "emocionassem": "emocionar",
    "emocionasses": "emocionar",
    "emocionaste": "emocionar",
    "emocionastes": "emocionar",
    "emocionava": "emocionar",
    "emocionavam": "emocionar",
    "emocionavas": "emocionar",
    "emocione": "emocionar",
    "emocionei": "emocionar",
    "emocioneis": "emocionar",
    "emocionem": "emocionar",
    "emocionemo": "emocionar",
    "emocionemos": "emocionar",
    "emociones": "emocionar",
    "emociono": "emocionar",
    "emocionou": "emocionar",
    "emocioná": "emocionar",
    "emocionámo": "emocionar",
    "emocionámos": "emocionar",
    "emocionáramo": "emocionar",
    "emocionáramos": "emocionar",
    "emocionárei": "emocionar",
    "emocionáreis": "emocionar",
    "emocionásseis": "emocionar",
    "emocionássemos": "emocionar",
    "emocionávamo": "emocionar",
    "emocionávamos": "emocionar",
    "emocionávei": "emocionar",
    "emocionáveis": "emocionável",
    "emola": "emolar",
    "emolada": "emolar",
    "emoladas": "emolar",
    "emolado": "emolar",
    "emolados": "emolar",
    "emolai": "emolar",
    "emolais": "emolar",
    "emolam": "emolar",
    "emolamo": "emolar",
    "emolamos": "emolar",
    "emolando": "emolar",
    "emolara": "emolar",
    "emolaram": "emolar",
    "emolaras": "emolar",
    "emolarde": "emolar",
    "emolardes": "emolar",
    "emolare": "emolar",
    "emolarei": "emolar",
    "emolareis": "emolar",
    "emolarem": "emolar",
    "emolaremos": "emolar",
    "emolares": "emolar",
    "emolaria": "emolar",
    "emolariam": "emolar",
    "emolarias": "emolar",
    "emolarmo": "emolar",
    "emolarmos": "emolar",
    "emolará": "emolar",
    "emolarás": "emolar",
    "emolarão": "emolar",
    "emolaríamos": "emolar",
    "emolaríeis": "emolar",
    "emolas": "emolar",
    "emolasse": "emolar",
    "emolassem": "emolar",
    "emolasses": "emolar",
    "emolaste": "emolar",
    "emolastes": "emolar",
    "emolava": "emolar",
    "emolavam": "emolar",
    "emolavas": "emolar",
    "emolda": "emoldar",
    "emoldada": "emoldar",
    "emoldadas": "emoldar",
    "emoldado": "emoldar",
    "emoldados": "emoldar",
    "emoldai": "emoldar",
    "emoldais": "emoldar",
    "emoldam": "emoldar",
    "emoldamo": "emoldar",
    "emoldamos": "emoldar",
    "emoldando": "emoldar",
    "emoldara": "emoldar",
    "emoldaram": "emoldar",
    "emoldaras": "emoldar",
    "emoldarde": "emoldar",
    "emoldardes": "emoldar",
    "emoldare": "emoldar",
    "emoldarei": "emoldar",
    "emoldareis": "emoldar",
    "emoldarem": "emoldar",
    "emoldaremos": "emoldar",
    "emoldares": "emoldar",
    "emoldaria": "emoldar",
    "emoldariam": "emoldar",
    "emoldarias": "emoldar",
    "emoldarmo": "emoldar",
    "emoldarmos": "emoldar",
    "emoldará": "emoldar",
    "emoldarás": "emoldar",
    "emoldarão": "emoldar",
    "emoldaríamos": "emoldar",
    "emoldaríeis": "emoldar",
    "emoldas": "emoldar",
    "emoldasse": "emoldar",
    "emoldassem": "emoldar",
    "emoldasses": "emoldar",
    "emoldaste": "emoldar",
    "emoldastes": "emoldar",
    "emoldava": "emoldar",
    "emoldavam": "emoldar",
    "emoldavas": "emoldar",
    "emolde": "emoldar",
    "emoldei": "emoldar",
    "emoldeis": "emoldar",
    "emoldem": "emoldar",
    "emoldemo": "emoldar",
    "emoldemos": "emoldar",
    "emoldes": "emoldar",
    "emoldo": "emoldar",
    "emoldou": "emoldar",
    "emoldura": "emoldurar",
    "emoldurada": "emoldurar",
    "emolduradas": "emoldurar",
    "emoldurado": "emoldurar",
    "emoldurados": "emoldurar",
    "emoldurai": "emoldurar",
    "emoldurais": "emoldurar",
    "emolduram": "emoldurar",
    "emolduramo": "emoldurar",
    "emolduramos": "emoldurar",
    "emoldurando": "emoldurar",
    "emoldurara": "emoldurar",
    "emolduraram": "emoldurar",
    "emolduraras": "emoldurar",
    "emoldurarde": "emoldurar",
    "emoldurardes": "emoldurar",
    "emoldurare": "emoldurar",
    "emoldurarei": "emoldurar",
    "emoldurareis": "emoldurar",
    "emoldurarem": "emoldurar",
    "emolduraremos": "emoldurar",
    "emoldurares": "emoldurar",
    "emolduraria": "emoldurar",
    "emoldurariam": "emoldurar",
    "emoldurarias": "emoldurar",
    "emoldurarmo": "emoldurar",
    "emoldurarmos": "emoldurar",
    "emoldurará": "emoldurar",
    "emoldurarás": "emoldurar",
    "emoldurarão": "emoldurar",
    "emolduraríamos": "emoldurar",
    "emolduraríeis": "emoldurar",
    "emolduras": "emoldurar",
    "emoldurasse": "emoldurar",
    "emoldurassem": "emoldurar",
    "emoldurasses": "emoldurar",
    "emolduraste": "emoldurar",
    "emoldurastes": "emoldurar",
    "emoldurava": "emoldurar",
    "emolduravam": "emoldurar",
    "emolduravas": "emoldurar",
    "emoldure": "emoldurar",
    "emoldurei": "emoldurar",
    "emoldureis": "emoldurar",
    "emoldurem": "emoldurar",
    "emolduremo": "emoldurar",
    "emolduremos": "emoldurar",
    "emoldures": "emoldurar",
    "emolduro": "emoldurar",
    "emoldurou": "emoldurar",
    "emoldurá": "emoldurar",
    "emoldurámo": "emoldurar",
    "emoldurámos": "emoldurar",
    "emolduráramo": "emoldurar",
    "emolduráramos": "emoldurar",
    "emoldurárei": "emoldurar",
    "emolduráreis": "emoldurar",
    "emoldurásseis": "emoldurar",
    "emoldurássemos": "emoldurar",
    "emoldurávamo": "emoldurar",
    "emoldurávamos": "emoldurar",
    "emoldurávei": "emoldurar",
    "emolduráveis": "emoldurar",
    "emoldá": "emoldar",
    "emoldámo": "emoldar",
    "emoldámos": "emoldar",
    "emoldáramo": "emoldar",
    "emoldáramos": "emoldar",
    "emoldárei": "emoldar",
    "emoldáreis": "emoldar",
    "emoldásseis": "emoldar",
    "emoldássemos": "emoldar",
    "emoldávamo": "emoldar",
    "emoldávamos": "emoldar",
    "emoldávei": "emoldar",
    "emoldáveis": "emoldar",
    "emole": "emolir",
    "emolei": "emolar",
    "emoleira": "emoleirar",
    "emoleirada": "emoleirar",
    "emoleiradas": "emoleirar",
    "emoleirado": "emoleirar",
    "emoleirados": "emoleirar",
    "emoleirai": "emoleirar",
    "emoleirais": "emoleirar",
    "emoleiram": "emoleirar",
    "emoleiramo": "emoleirar",
    "emoleiramos": "emoleirar",
    "emoleirando": "emoleirar",
    "emoleirara": "emoleirar",
    "emoleiraram": "emoleirar",
    "emoleiraras": "emoleirar",
    "emoleirarde": "emoleirar",
    "emoleirardes": "emoleirar",
    "emoleirare": "emoleirar",
    "emoleirarei": "emoleirar",
    "emoleirareis": "emoleirar",
    "emoleirarem": "emoleirar",
    "emoleiraremos": "emoleirar",
    "emoleirares": "emoleirar",
    "emoleiraria": "emoleirar",
    "emoleirariam": "emoleirar",
    "emoleirarias": "emoleirar",
    "emoleirarmo": "emoleirar",
    "emoleirarmos": "emoleirar",
    "emoleirará": "emoleirar",
    "emoleirarás": "emoleirar",
    "emoleirarão": "emoleirar",
    "emoleiraríamos": "emoleirar",
    "emoleiraríeis": "emoleirar",
    "emoleiras": "emoleirar",
    "emoleirasse": "emoleirar",
    "emoleirassem": "emoleirar",
    "emoleirasses": "emoleirar",
    "emoleiraste": "emoleirar",
    "emoleirastes": "emoleirar",
    "emoleirava": "emoleirar",
    "emoleiravam": "emoleirar",
    "emoleiravas": "emoleirar",
    "emoleire": "emoleirar",
    "emoleirei": "emoleirar",
    "emoleireis": "emoleirar",
    "emoleirem": "emoleirar",
    "emoleiremo": "emoleirar",
    "emoleiremos": "emoleirar",
    "emoleires": "emoleirar",
    "emoleiro": "emoleirar",
    "emoleirou": "emoleirar",
    "emoleirá": "emoleirar",
    "emoleirámo": "emoleirar",
    "emoleirámos": "emoleirar",
    "emoleiráramo": "emoleirar",
    "emoleiráramos": "emoleirar",
    "emoleirárei": "emoleirar",
    "emoleiráreis": "emoleirar",
    "emoleirásseis": "emoleirar",
    "emoleirássemos": "emoleirar",
    "emoleirávamo": "emoleirar",
    "emoleirávamos": "emoleirar",
    "emoleirávei": "emoleirar",
    "emoleiráveis": "emoleirar",
    "emoleis": "emolar",
    "emolem": "emolir",
    "emolemo": "emolar",
    "emolemos": "emolar",
    "emoles": "emolir",
    "emoli": "emolir",
    "emolia": "emolir",
    "emoliam": "emolir",
    "emolias": "emolir",
    "emolida": "emolir",
    "emolidas": "emolir",
    "emolido": "emolir",
    "emolidos": "emolir",
    "emolientes": "emoliente",
    "emolimo": "emolir",
    "emolimos": "emolir",
    "emolindo": "emolir",
    "emolira": "emolir",
    "emoliram": "emolir",
    "emoliras": "emolir",
    "emolirde": "emolir",
    "emolirdes": "emolir",
    "emolire": "emolir",
    "emolirei": "emolir",
    "emolireis": "emolir",
    "emolirem": "emolir",
    "emoliremos": "emolir",
    "emolires": "emolir",
    "emoliria": "emolir",
    "emoliriam": "emolir",
    "emolirias": "emolir",
    "emolirmo": "emolir",
    "emolirmos": "emolir",
    "emolirá": "emolir",
    "emolirás": "emolir",
    "emolirão": "emolir",
    "emoliríamos": "emolir",
    "emoliríeis": "emolir",
    "emolis": "emolir",
    "emolisse": "emolir",
    "emolissem": "emolir",
    "emolisses": "emolir",
    "emoliste": "emolir",
    "emolistes": "emolir",
    "emoliu": "emolir",
    "emolo": "emolar",
    "emolou": "emolar",
    "emolumentos": "emolumento",
    "emolá": "emolar",
    "emolámo": "emolar",
    "emolámos": "emolar",
    "emoláramo": "emolar",
    "emoláramos": "emolar",
    "emolárei": "emolar",
    "emoláreis": "emolar",
    "emolásseis": "emolar",
    "emolássemos": "emolar",
    "emolávamo": "emolar",
    "emolávamos": "emolar",
    "emolávei": "emolar",
    "emoláveis": "emolar",
    "emolíamo": "emolir",
    "emolíamos": "emolir",
    "emolíei": "emolir",
    "emolíeis": "emolir",
    "emolíramo": "emolir",
    "emolíramos": "emolir",
    "emolírei": "emolir",
    "emolíreis": "emolir",
    "emolísseis": "emolir",
    "emolíssemos": "emolir",
    "emona": "emonar",
    "emonada": "emonar",
    "emonadas": "emonar",
    "emonado": "emonar",
    "emonados": "emonar",
    "emonai": "emonar",
    "emonais": "emonar",
    "emonam": "emonar",
    "emonamo": "emonar",
    "emonamos": "emonar",
    "emonando": "emonar",
    "emonara": "emonar",
    "emonaram": "emonar",
    "emonaras": "emonar",
    "emonarde": "emonar",
    "emonardes": "emonar",
    "emonare": "emonar",
    "emonarei": "emonar",
    "emonareis": "emonar",
    "emonarem": "emonar",
    "emonaremos": "emonar",
    "emonares": "emonar",
    "emonaria": "emonar",
    "emonariam": "emonar",
    "emonarias": "emonar",
    "emonarmo": "emonar",
    "emonarmos": "emonar",
    "emonará": "emonar",
    "emonarás": "emonar",
    "emonarão": "emonar",
    "emonaríamos": "emonar",
    "emonaríeis": "emonar",
    "emonas": "emonar",
    "emonasse": "emonar",
    "emonassem": "emonar",
    "emonasses": "emonar",
    "emonaste": "emonar",
    "emonastes": "emonar",
    "emonava": "emonar",
    "emonavam": "emonar",
    "emonavas": "emonar",
    "emone": "emonar",
    "emonei": "emonar",
    "emoneis": "emonar",
    "emonem": "emonar",
    "emonemo": "emonar",
    "emonemos": "emonar",
    "emones": "emonar",
    "emono": "emonar",
    "emonou": "emonar",
    "emoná": "emonar",
    "emonámo": "emonar",
    "emonámos": "emonar",
    "emonáramo": "emonar",
    "emonáramos": "emonar",
    "emonárei": "emonar",
    "emonáreis": "emonar",
    "emonásseis": "emonar",
    "emonássemos": "emonar",
    "emonávamo": "emonar",
    "emonávamos": "emonar",
    "emonávei": "emonar",
    "emonáveis": "emonar",
    "emordace": "emordaçar",
    "emordacei": "emordaçar",
    "emordaceis": "emordaçar",
    "emordacem": "emordaçar",
    "emordacemo": "emordaçar",
    "emordacemos": "emordaçar",
    "emordaces": "emordaçar",
    "emordaça": "emordaçar",
    "emordaçada": "emordaçar",
    "emordaçadas": "emordaçar",
    "emordaçado": "emordaçar",
    "emordaçados": "emordaçar",
    "emordaçai": "emordaçar",
    "emordaçais": "emordaçar",
    "emordaçam": "emordaçar",
    "emordaçamo": "emordaçar",
    "emordaçamos": "emordaçar",
    "emordaçando": "emordaçar",
    "emordaçara": "emordaçar",
    "emordaçaram": "emordaçar",
    "emordaçaras": "emordaçar",
    "emordaçarde": "emordaçar",
    "emordaçardes": "emordaçar",
    "emordaçare": "emordaçar",
    "emordaçarei": "emordaçar",
    "emordaçareis": "emordaçar",
    "emordaçarem": "emordaçar",
    "emordaçaremos": "emordaçar",
    "emordaçares": "emordaçar",
    "emordaçaria": "emordaçar",
    "emordaçariam": "emordaçar",
    "emordaçarias": "emordaçar",
    "emordaçarmo": "emordaçar",
    "emordaçarmos": "emordaçar",
    "emordaçará": "emordaçar",
    "emordaçarás": "emordaçar",
    "emordaçarão": "emordaçar",
    "emordaçaríamos": "emordaçar",
    "emordaçaríeis": "emordaçar",
    "emordaças": "emordaçar",
    "emordaçasse": "emordaçar",
    "emordaçassem": "emordaçar",
    "emordaçasses": "emordaçar",
    "emordaçaste": "emordaçar",
    "emordaçastes": "emordaçar",
    "emordaçava": "emordaçar",
    "emordaçavam": "emordaçar",
    "emordaçavas": "emordaçar",
    "emordaço": "emordaçar",
    "emordaçou": "emordaçar",
    "emordaçá": "emordaçar",
    "emordaçámo": "emordaçar",
    "emordaçámos": "emordaçar",
    "emordaçáramo": "emordaçar",
    "emordaçáramos": "emordaçar",
    "emordaçárei": "emordaçar",
    "emordaçáreis": "emordaçar",
    "emordaçásseis": "emordaçar",
    "emordaçássemos": "emordaçar",
    "emordaçávamo": "emordaçar",
    "emordaçávamos": "emordaçar",
    "emordaçávei": "emordaçar",
    "emordaçáveis": "emordaçar",
    "emoreada": "emorear",
    "emoreadas": "emorear",
    "emoreado": "emorear",
    "emoreados": "emorear",
    "emoreai": "emorear",
    "emoreais": "emorear",
    "emoreamo": "emorear",
    "emoreamos": "emorear",
    "emoreando": "emorear",
    "emoreara": "emorear",
    "emorearam": "emorear",
    "emorearas": "emorear",
    "emorearde": "emorear",
    "emoreardes": "emorear",
    "emoreare": "emorear",
    "emorearei": "emorear",
    "emoreareis": "emorear",
    "emorearem": "emorear",
    "emorearemos": "emorear",
    "emoreares": "emorear",
    "emorearia": "emorear",
    "emoreariam": "emorear",
    "emorearias": "emorear",
    "emorearmo": "emorear",
    "emorearmos": "emorear",
    "emoreará": "emorear",
    "emorearás": "emorear",
    "emorearão": "emorear",
    "emorearíamos": "emorear",
    "emorearíeis": "emorear",
    "emoreasse": "emorear",
    "emoreassem": "emorear",
    "emoreasses": "emorear",
    "emoreaste": "emorear",
    "emoreastes": "emorear",
    "emoreava": "emorear",
    "emoreavam": "emorear",
    "emoreavas": "emorear",
    "emoreei": "emorear",
    "emoreeis": "emorear",
    "emoreemo": "emorear",
    "emoreemos": "emorear",
    "emoreia": "emorear",
    "emoreiam": "emorear",
    "emoreias": "emorear",
    "emoreie": "emorear",
    "emoreiem": "emorear",
    "emoreies": "emorear",
    "emoreio": "emorear",
    "emoreou": "emorear",
    "emoreá": "emorear",
    "emoreámo": "emorear",
    "emoreámos": "emorear",
    "emoreáramo": "emorear",
    "emoreáramos": "emorear",
    "emoreárei": "emorear",
    "emoreáreis": "emorear",
    "emoreásseis": "emorear",
    "emoreássemos": "emorear",
    "emoreávamo": "emorear",
    "emoreávamos": "emorear",
    "emoreávei": "emorear",
    "emoreáveis": "emorear",
    "emosta": "emostar",
    "emostada": "emostar",
    "emostadas": "emostar",
    "emostado": "emostar",
    "emostados": "emostar",
    "emostai": "emostar",
    "emostais": "emostar",
    "emostam": "emostar",
    "emostamo": "emostar",
    "emostamos": "emostar",
    "emostando": "emostar",
    "emostara": "emostar",
    "emostaram": "emostar",
    "emostaras": "emostar",
    "emostarde": "emostar",
    "emostardes": "emostar",
    "emostare": "emostar",
    "emostarei": "emostar",
    "emostareis": "emostar",
    "emostarem": "emostar",
    "emostaremos": "emostar",
    "emostares": "emostar",
    "emostaria": "emostar",
    "emostariam": "emostar",
    "emostarias": "emostar",
    "emostarmo": "emostar",
    "emostarmos": "emostar",
    "emostará": "emostar",
    "emostarás": "emostar",
    "emostarão": "emostar",
    "emostaríamos": "emostar",
    "emostaríeis": "emostar",
    "emostas": "emostar",
    "emostasse": "emostar",
    "emostassem": "emostar",
    "emostasses": "emostar",
    "emostaste": "emostar",
    "emostastes": "emostar",
    "emostava": "emostar",
    "emostavam": "emostar",
    "emostavas": "emostar",
    "emoste": "emostar",
    "emostei": "emostar",
    "emosteis": "emostar",
    "emostem": "emostar",
    "emostemo": "emostar",
    "emostemos": "emostar",
    "emostes": "emostar",
    "emosto": "emostar",
    "emostou": "emostar",
    "emostá": "emostar",
    "emostámo": "emostar",
    "emostámos": "emostar",
    "emostáramo": "emostar",
    "emostáramos": "emostar",
    "emostárei": "emostar",
    "emostáreis": "emostar",
    "emostásseis": "emostar",
    "emostássemos": "emostar",
    "emostávamo": "emostar",
    "emostávamos": "emostar",
    "emostávei": "emostar",
    "emostáveis": "emostar",
    "emotiva": "emotivo",
    "emotivas": "emotivo",
    "emotividades": "emotividade",
    "emotivos": "emotivo",
    "emouquece": "emouquecer",
    "emouquecei": "emouquecer",
    "emouqueceis": "emouquecer",
    "emouquecem": "emouquecer",
    "emouquecemo": "emouquecer",
    "emouquecemos": "emouquecer",
    "emouquecendo": "emouquecer",
    "emouquecera": "emouquecer",
    "emouqueceram": "emouquecer",
    "emouqueceras": "emouquecer",
    "emouquecerde": "emouquecer",
    "emouquecerdes": "emouquecer",
    "emouquecere": "emouquecer",
    "emouquecerei": "emouquecer",
    "emouquecereis": "emouquecer",
    "emouquecerem": "emouquecer",
    "emouqueceremos": "emouquecer",
    "emouqueceres": "emouquecer",
    "emouqueceria": "emouquecer",
    "emouqueceriam": "emouquecer",
    "emouquecerias": "emouquecer",
    "emouquecermo": "emouquecer",
    "emouquecermos": "emouquecer",
    "emouquecerá": "emouquecer",
    "emouquecerás": "emouquecer",
    "emouquecerão": "emouquecer",
    "emouqueceríamos": "emouquecer",
    "emouqueceríeis": "emouquecer",
    "emouqueces": "emouquecer",
    "emouquecesse": "emouquecer",
    "emouquecessem": "emouquecer",
    "emouquecesses": "emouquecer",
    "emouqueceste": "emouquecer",
    "emouquecestes": "emouquecer",
    "emouqueceu": "emouquecer",
    "emouqueci": "emouquecer",
    "emouquecia": "emouquecer",
    "emouqueciam": "emouquecer",
    "emouquecias": "emouquecer",
    "emouquecida": "emouquecido",
    "emouquecidas": "emouquecido",
    "emouquecido": "emouquecer",
    "emouquecidos": "emouquecido",
    "emouquecimentos": "emouquecimento",
    "emouquecê": "emouquecer",
    "emouquecêramo": "emouquecer",
    "emouquecêramos": "emouquecer",
    "emouquecêrei": "emouquecer",
    "emouquecêreis": "emouquecer",
    "emouquecêsseis": "emouquecer",
    "emouquecêssemos": "emouquecer",
    "emouquecíamo": "emouquecer",
    "emouquecíamos": "emouquecer",
    "emouquecíei": "emouquecer",
    "emouquecíeis": "emouquecer",
    "emouqueça": "emouquecer",
    "emouqueçais": "emouquecer",
    "emouqueçam": "emouquecer",
    "emouqueçamo": "emouquecer",
    "emouqueçamos": "emouquecer",
    "emouqueças": "emouquecer",
    "emouqueço": "emouquecer",
    "emoções": "emoção",
    "empa": "empar",
    "empaca": "empacar",
    "empacada": "empacar",
    "empacadas": "empacar",
    "empacado": "empacar",
    "empacados": "empacar",
    "empacai": "empacar",
    "empacais": "empacar",
    "empacam": "empacar",
    "empacamo": "empacar",
    "empacamos": "empacar",
    "empacando": "empacar",
    "empacara": "empacar",
    "empacaram": "empacar",
    "empacaras": "empacar",
    "empacarde": "empacar",
    "empacardes": "empacar",
    "empacare": "empacar",
    "empacarei": "empacar",
    "empacareis": "empacar",
    "empacarem": "empacar",
    "empacaremos": "empacar",
    "empacares": "empacar",
    "empacaria": "empacar",
    "empacariam": "empacar",
    "empacarias": "empacar",
    "empacarmo": "empacar",
    "empacarmos": "empacar",
    "empacará": "empacar",
    "empacarás": "empacar",
    "empacarão": "empacar",
    "empacaríamos": "empacar",
    "empacaríeis": "empacar",
    "empacas": "empacar",
    "empacasse": "empacar",
    "empacassem": "empacar",
    "empacasses": "empacar",
    "empacaste": "empacar",
    "empacastes": "empacar",
    "empacava": "empacar",
    "empacavam": "empacar",
    "empacavas": "empacar",
    "empacha": "empachar",
    "empachada": "empachar",
    "empachadas": "empachar",
    "empachado": "empachar",
    "empachados": "empachar",
    "empachai": "empachar",
    "empachais": "empachar",
    "empacham": "empachar",
    "empachamentos": "empachamento",
    "empachamo": "empachar",
    "empachamos": "empachar",
    "empachando": "empachar",
    "empachara": "empachar",
    "empacharam": "empachar",
    "empacharas": "empachar",
    "empacharde": "empachar",
    "empachardes": "empachar",
    "empachare": "empachar",
    "empacharei": "empachar",
    "empachareis": "empachar",
    "empacharem": "empachar",
    "empacharemos": "empachar",
    "empachares": "empachar",
    "empacharia": "empachar",
    "empachariam": "empachar",
    "empacharias": "empachar",
    "empacharmo": "empachar",
    "empacharmos": "empachar",
    "empachará": "empachar",
    "empacharás": "empachar",
    "empacharão": "empachar",
    "empacharíamos": "empachar",
    "empacharíeis": "empachar",
    "empachas": "empachar",
    "empachasse": "empachar",
    "empachassem": "empachar",
    "empachasses": "empachar",
    "empachaste": "empachar",
    "empachastes": "empachar",
    "empachava": "empachar",
    "empachavam": "empachar",
    "empachavas": "empachar",
    "empache": "empachar",
    "empachei": "empachar",
    "empacheis": "empachar",
    "empachem": "empachar",
    "empachemo": "empachar",
    "empachemos": "empachar",
    "empaches": "empache",
    "empacho": "empachar",
    "empachos": "empacho",
    "empachosa": "empachoso",
    "empachosas": "empachoso",
    "empachosos": "empachoso",
    "empachou": "empachar",
    "empachá": "empachar",
    "empachámo": "empachar",
    "empachámos": "empachar",
    "empacháramo": "empachar",
    "empacháramos": "empachar",
    "empachárei": "empachar",
    "empacháreis": "empachar",
    "empachásseis": "empachar",
    "empachássemos": "empachar",
    "empachávamo": "empachar",
    "empachávamos": "empachar",
    "empachávei": "empachar",
    "empacháveis": "empachar",
    "empaco": "empacar",
    "empacota": "empacotar",
    "empacotada": "empacotar",
    "empacotadas": "empacotar",
    "empacotadeiras": "empacotadeira",
    "empacotado": "empacotar",
    "empacotadora": "empacotador",
    "empacotadoras": "empacotador",
    "empacotadores": "empacotador",
    "empacotados": "empacotar",
    "empacotai": "empacotar",
    "empacotais": "empacotar",
    "empacotam": "empacotar",
    "empacotamentos": "empacotamento",
    "empacotamo": "empacotar",
    "empacotamos": "empacotar",
    "empacotando": "empacotar",
    "empacotara": "empacotar",
    "empacotaram": "empacotar",
    "empacotaras": "empacotar",
    "empacotarde": "empacotar",
    "empacotardes": "empacotar",
    "empacotare": "empacotar",
    "empacotarei": "empacotar",
    "empacotareis": "empacotar",
    "empacotarem": "empacotar",
    "empacotaremos": "empacotar",
    "empacotares": "empacotar",
    "empacotaria": "empacotar",
    "empacotariam": "empacotar",
    "empacotarias": "empacotar",
    "empacotarmo": "empacotar",
    "empacotarmos": "empacotar",
    "empacotará": "empacotar",
    "empacotarás": "empacotar",
    "empacotarão": "empacotar",
    "empacotaríamos": "empacotar",
    "empacotaríeis": "empacotar",
    "empacotas": "empacotar",
    "empacotasse": "empacotar",
    "empacotassem": "empacotar",
    "empacotasses": "empacotar",
    "empacotaste": "empacotar",
    "empacotastes": "empacotar",
    "empacotava": "empacotar",
    "empacotavam": "empacotar",
    "empacotavas": "empacotar",
    "empacote": "empacotar",
    "empacotei": "empacotar",
    "empacoteis": "empacotar",
    "empacotem": "empacotar",
    "empacotemo": "empacotar",
    "empacotemos": "empacotar",
    "empacotes": "empacotar",
    "empacoto": "empacotar",
    "empacotou": "empacotar",
    "empacotá": "empacotar",
    "empacotámo": "empacotar",
    "empacotámos": "empacotar",
    "empacotáramo": "empacotar",
    "empacotáramos": "empacotar",
    "empacotárei": "empacotar",
    "empacotáreis": "empacotar",
    "empacotásseis": "empacotar",
    "empacotássemos": "empacotar",
    "empacotávamo": "empacotar",
    "empacotávamos": "empacotar",
    "empacotávei": "empacotar",
    "empacotáveis": "empacotar",
    "empacou": "empacar",
    "empacá": "empacar",
    "empacámo": "empacar",
    "empacámos": "empacar",
    "empacáramo": "empacar",
    "empacáramos": "empacar",
    "empacárei": "empacar",
    "empacáreis": "empacar",
    "empacásseis": "empacar",
    "empacássemos": "empacar",
    "empacávamo": "empacar",
    "empacávamos": "empacar",
    "empacávei": "empacar",
    "empacáveis": "empacar",
    "empada": "empar",
    "empadas": "empar",
    "empadinha": "empada",
    "empadinhas": "empada",
    "empadita": "empada",
    "empaditas": "empada",
    "empado": "empar",
    "empados": "empar",
    "empadroa": "empadroar",
    "empadroada": "empadroar",
    "empadroadas": "empadroar",
    "empadroado": "empadroar",
    "empadroados": "empadroar",
    "empadroai": "empadroar",
    "empadroais": "empadroar",
    "empadroam": "empadroar",
    "empadroamo": "empadroar",
    "empadroamos": "empadroar",
    "empadroando": "empadroar",
    "empadroara": "empadroar",
    "empadroaram": "empadroar",
    "empadroaras": "empadroar",
    "empadroarde": "empadroar",
    "empadroardes": "empadroar",
    "empadroare": "empadroar",
    "empadroarei": "empadroar",
    "empadroareis": "empadroar",
    "empadroarem": "empadroar",
    "empadroaremos": "empadroar",
    "empadroares": "empadroar",
    "empadroaria": "empadroar",
    "empadroariam": "empadroar",
    "empadroarias": "empadroar",
    "empadroarmo": "empadroar",
    "empadroarmos": "empadroar",
    "empadroará": "empadroar",
    "empadroarás": "empadroar",
    "empadroarão": "empadroar",
    "empadroaríamos": "empadroar",
    "empadroaríeis": "empadroar",
    "empadroas": "empadroar",
    "empadroasse": "empadroar",
    "empadroassem": "empadroar",
    "empadroasses": "empadroar",
    "empadroaste": "empadroar",
    "empadroastes": "empadroar",
    "empadroava": "empadroar",
    "empadroavam": "empadroar",
    "empadroavas": "empadroar",
    "empadroe": "empadroar",
    "empadroei": "empadroar",
    "empadroeis": "empadroar",
    "empadroem": "empadroar",
    "empadroemo": "empadroar",
    "empadroemos": "empadroar",
    "empadroes": "empadroar",
    "empadroo": "empadroar",
    "empadroou": "empadroar",
    "empadroá": "empadroar",
    "empadroámo": "empadroar",
    "empadroámos": "empadroar",
    "empadroáramo": "empadroar",
    "empadroáramos": "empadroar",
    "empadroárei": "empadroar",
    "empadroáreis": "empadroar",
    "empadroásseis": "empadroar",
    "empadroássemos": "empadroar",
    "empadroávamo": "empadroar",
    "empadroávamos": "empadroar",
    "empadroávei": "empadroar",
    "empadroáveis": "empadroar",
    "empadões": "empadão",
    "empai": "empar",
    "empais": "empar",
    "empala": "empalar",
    "empalada": "empalar",
    "empaladas": "empalar",
    "empalado": "empalar",
    "empalados": "empalar",
    "empalagosa": "empalagoso",
    "empalagosas": "empalagoso",
    "empalagosos": "empalagoso",
    "empalai": "empalar",
    "empalais": "empalar",
    "empalam": "empalar",
    "empalamada": "empalamado",
    "empalamadas": "empalamado",
    "empalamados": "empalamado",
    "empalamentos": "empalamento",
    "empalamo": "empalar",
    "empalamos": "empalar",
    "empalando": "empalar",
    "empalara": "empalar",
    "empalaram": "empalar",
    "empalaras": "empalar",
    "empalarde": "empalar",
    "empalardes": "empalar",
    "empalare": "empalar",
    "empalarei": "empalar",
    "empalareis": "empalar",
    "empalarem": "empalar",
    "empalaremos": "empalar",
    "empalares": "empalar",
    "empalaria": "empalar",
    "empalariam": "empalar",
    "empalarias": "empalar",
    "empalarmo": "empalar",
    "empalarmos": "empalar",
    "empalará": "empalar",
    "empalarás": "empalar",
    "empalarão": "empalar",
    "empalaríamos": "empalar",
    "empalaríeis": "empalar",
    "empalas": "empalar",
    "empalasse": "empalar",
    "empalassem": "empalar",
    "empalasses": "empalar",
    "empalaste": "empalar",
    "empalastes": "empalar",
    "empalava": "empalar",
    "empalavam": "empalar",
    "empalavas": "empalar",
    "empalações": "empalação",
    "empale": "empalar",
    "empaleada": "empalear",
    "empaleadas": "empalear",
    "empaleado": "empalear",
    "empaleados": "empalear",
    "empaleai": "empalear",
    "empaleais": "empalear",
    "empaleamo": "empalear",
    "empaleamos": "empalear",
    "empaleando": "empalear",
    "empaleara": "empalear",
    "empalearam": "empalear",
    "empalearas": "empalear",
    "empalearde": "empalear",
    "empaleardes": "empalear",
    "empaleare": "empalear",
    "empalearei": "empalear",
    "empaleareis": "empalear",
    "empalearem": "empalear",
    "empalearemos": "empalear",
    "empaleares": "empalear",
    "empalearia": "empalear",
    "empaleariam": "empalear",
    "empalearias": "empalear",
    "empalearmo": "empalear",
    "empalearmos": "empalear",
    "empaleará": "empalear",
    "empalearás": "empalear",
    "empalearão": "empalear",
    "empalearíamos": "empalear",
    "empalearíeis": "empalear",
    "empaleasse": "empalear",
    "empaleassem": "empalear",
    "empaleasses": "empalear",
    "empaleaste": "empalear",
    "empaleastes": "empalear",
    "empaleava": "empalear",
    "empaleavam": "empalear",
    "empaleavas": "empalear",
    "empalece": "empalecer",
    "empalecei": "empalecer",
    "empaleceis": "empalecer",
    "empalecem": "empalecer",
    "empalecemo": "empalecer",
    "empalecemos": "empalecer",
    "empalecendo": "empalecer",
    "empalecera": "empalecer",
    "empaleceram": "empalecer",
    "empaleceras": "empalecer",
    "empalecerdes": "empalecer",
    "empalecerei": "empalecer",
    "empalecereis": "empalecer",
    "empalecerem": "empalecer",
    "empaleceremos": "empalecer",
    "empaleceres": "empalecer",
    "empaleceria": "empalecer",
    "empaleceriam": "empalecer",
    "empalecerias": "empalecer",
    "empalecermo": "empalecer",
    "empalecermos": "empalecer",
    "empalecerá": "empalecer",
    "empalecerás": "empalecer",
    "empalecerão": "empalecer",
    "empaleceríamos": "empalecer",
    "empaleceríeis": "empalecer",
    "empaleces": "empalecer",
    "empalecesse": "empalecer",
    "empalecessem": "empalecer",
    "empalecesses": "empalecer",
    "empaleceste": "empalecer",
    "empalecestes": "empalecer",
    "empaleceu": "empalecer",
    "empaleci": "empalecer",
    "empalecia": "empalecer",
    "empaleciam": "empalecer",
    "empalecias": "empalecer",
    "empalecida": "empalecer",
    "empalecidas": "empalecer",
    "empalecido": "empalecer",
    "empalecidos": "empalecer",
    "empalecêramo": "empalecer",
    "empalecêramos": "empalecer",
    "empalecêreis": "empalecer",
    "empalecêsseis": "empalecer",
    "empalecêssemos": "empalecer",
    "empalecíamo": "empalecer",
    "empalecíamos": "empalecer",
    "empalecíeis": "empalecer",
    "empaleei": "empalear",
    "empaleeis": "empalear",
    "empaleemo": "empalear",
    "empaleemos": "empalear",
    "empalei": "empalar",
    "empaleia": "empalear",
    "empaleiam": "empalear",
    "empaleias": "empalear",
    "empaleie": "empalear",
    "empaleiem": "empalear",
    "empaleies": "empalear",
    "empaleio": "empalear",
    "empaleis": "empalar",
    "empalem": "empalar",
    "empalemo": "empalar",
    "empalemos": "empalar",
    "empaleou": "empalear",
    "empales": "empalar",
    "empaleá": "empalear",
    "empaleámo": "empalear",
    "empaleámos": "empalear",
    "empaleáramo": "empalear",
    "empaleáramos": "empalear",
    "empaleárei": "empalear",
    "empaleáreis": "empalear",
    "empaleásseis": "empalear",
    "empaleássemos": "empalear",
    "empaleávamo": "empalear",
    "empaleávamos": "empalear",
    "empaleávei": "empalear",
    "empaleáveis": "empalear",
    "empaleça": "empalecer",
    "empaleçais": "empalecer",
    "empaleçam": "empalecer",
    "empaleçamo": "empalecer",
    "empaleçamos": "empalecer",
    "empaleças": "empalecer",
    "empaleço": "empalecer",
    "empalha": "empalhar",
    "empalhada": "empalhar",
    "empalhadas": "empalhar",
    "empalhadeiras": "empalhadeira",
    "empalhado": "empalhar",
    "empalhadora": "empalhador",
    "empalhadoras": "empalhador",
    "empalhadores": "empalhador",
    "empalhados": "empalhar",
    "empalhai": "empalhar",
    "empalhais": "empalhar",
    "empalham": "empalhar",
    "empalhamentos": "empalhamento",
    "empalhamo": "empalhar",
    "empalhamos": "empalhar",
    "empalhando": "empalhar",
    "empalhara": "empalhar",
    "empalharam": "empalhar",
    "empalharas": "empalhar",
    "empalharde": "empalhar",
    "empalhardes": "empalhar",
    "empalhare": "empalhar",
    "empalharei": "empalhar",
    "empalhareis": "empalhar",
    "empalharem": "empalhar",
    "empalharemos": "empalhar",
    "empalhares": "empalhar",
    "empalharia": "empalhar",
    "empalhariam": "empalhar",
    "empalharias": "empalhar",
    "empalharmo": "empalhar",
    "empalharmos": "empalhar",
    "empalhará": "empalhar",
    "empalharás": "empalhar",
    "empalharão": "empalhar",
    "empalharíamos": "empalhar",
    "empalharíeis": "empalhar",
    "empalhas": "empalhar",
    "empalhasse": "empalhar",
    "empalhassem": "empalhar",
    "empalhasses": "empalhar",
    "empalhaste": "empalhar",
    "empalhastes": "empalhar",
    "empalhava": "empalhar",
    "empalhavam": "empalhar",
    "empalhavas": "empalhar",
    "empalhações": "empalhação",
    "empalhe": "empalhar",
    "empalhei": "empalhar",
    "empalheira": "empalheirar",
    "empalheirada": "empalheirar",
    "empalheiradas": "empalheirar",
    "empalheirado": "empalheirar",
    "empalheirados": "empalheirar",
    "empalheirai": "empalheirar",
    "empalheirais": "empalheirar",
    "empalheiram": "empalheirar",
    "empalheiramo": "empalheirar",
    "empalheiramos": "empalheirar",
    "empalheirando": "empalheirar",
    "empalheirara": "empalheirar",
    "empalheiraram": "empalheirar",
    "empalheiraras": "empalheirar",
    "empalheirarde": "empalheirar",
    "empalheirardes": "empalheirar",
    "empalheirare": "empalheirar",
    "empalheirarei": "empalheirar",
    "empalheirareis": "empalheirar",
    "empalheirarem": "empalheirar",
    "empalheiraremos": "empalheirar",
    "empalheirares": "empalheirar",
    "empalheiraria": "empalheirar",
    "empalheirariam": "empalheirar",
    "empalheirarias": "empalheirar",
    "empalheirarmo": "empalheirar",
    "empalheirarmos": "empalheirar",
    "empalheirará": "empalheirar",
    "empalheirarás": "empalheirar",
    "empalheirarão": "empalheirar",
    "empalheiraríamos": "empalheirar",
    "empalheiraríeis": "empalheirar",
    "empalheiras": "empalheirar",
    "empalheirasse": "empalheirar",
    "empalheirassem": "empalheirar",
    "empalheirasses": "empalheirar",
    "empalheiraste": "empalheirar",
    "empalheirastes": "empalheirar",
    "empalheirava": "empalheirar",
    "empalheiravam": "empalheirar",
    "empalheiravas": "empalheirar",
    "empalheire": "empalheirar",
    "empalheirei": "empalheirar",
    "empalheireis": "empalheirar",
    "empalheirem": "empalheirar",
    "empalheiremo": "empalheirar",
    "empalheiremos": "empalheirar",
    "empalheires": "empalheirar",
    "empalheiro": "empalheirar",
    "empalheirou": "empalheirar",
    "empalheirá": "empalheirar",
    "empalheirámo": "empalheirar",
    "empalheirámos": "empalheirar",
    "empalheiráramo": "empalheirar",
    "empalheiráramos": "empalheirar",
    "empalheirárei": "empalheirar",
    "empalheiráreis": "empalheirar",
    "empalheirásseis": "empalheirar",
    "empalheirássemos": "empalheirar",
    "empalheirávamo": "empalheirar",
    "empalheirávamos": "empalheirar",
    "empalheirávei": "empalheirar",
    "empalheiráveis": "empalheirar",
    "empalheis": "empalhar",
    "empalhem": "empalhar",
    "empalhemo": "empalhar",
    "empalhemos": "empalhar",
    "empalhes": "empalhar",
    "empalho": "empalhar",
    "empalhou": "empalhar",
    "empalhá": "empalhar",
    "empalhámo": "empalhar",
    "empalhámos": "empalhar",
    "empalháramo": "empalhar",
    "empalháramos": "empalhar",
    "empalhárei": "empalhar",
    "empalháreis": "empalhar",
    "empalhásseis": "empalhar",
    "empalhássemos": "empalhar",
    "empalhávamo": "empalhar",
    "empalhávamos": "empalhar",
    "empalhávei": "empalhar",
    "empalháveis": "empalhar",
    "empalidece": "empalidecer",
    "empalidecei": "empalidecer",
    "empalideceis": "empalidecer",
    "empalidecem": "empalidecer",
    "empalidecemo": "empalidecer",
    "empalidecemos": "empalidecer",
    "empalidecendo": "empalidecer",
    "empalidecera": "empalidecer",
    "empalideceram": "empalidecer",
    "empalideceras": "empalidecer",
    "empalidecerdes": "empalidecer",
    "empalidecerei": "empalidecer",
    "empalidecereis": "empalidecer",
    "empalidecerem": "empalidecer",
    "empalideceremos": "empalidecer",
    "empalideceres": "empalidecer",
    "empalideceria": "empalidecer",
    "empalideceriam": "empalidecer",
    "empalidecerias": "empalidecer",
    "empalidecermo": "empalidecer",
    "empalidecermos": "empalidecer",
    "empalidecerá": "empalidecer",
    "empalidecerás": "empalidecer",
    "empalidecerão": "empalidecer",
    "empalideceríamos": "empalidecer",
    "empalideceríeis": "empalidecer",
    "empalideces": "empalidecer",
    "empalidecesse": "empalidecer",
    "empalidecessem": "empalidecer",
    "empalidecesses": "empalidecer",
    "empalideceste": "empalidecer",
    "empalidecestes": "empalidecer",
    "empalideceu": "empalidecer",
    "empalideci": "empalidecer",
    "empalidecia": "empalidecer",
    "empalideciam": "empalidecer",
    "empalidecias": "empalidecer",
    "empalidecida": "empalidecido",
    "empalidecidas": "empalidecido",
    "empalidecido": "empalidecer",
    "empalidecidos": "empalidecido",
    "empalidecêramo": "empalidecer",
    "empalidecêramos": "empalidecer",
    "empalidecêreis": "empalidecer",
    "empalidecêsseis": "empalidecer",
    "empalidecêssemos": "empalidecer",
    "empalidecíamo": "empalidecer",
    "empalidecíamos": "empalidecer",
    "empalidecíeis": "empalidecer",
    "empalideça": "empalidecer",
    "empalideçais": "empalidecer",
    "empalideçam": "empalidecer",
    "empalideçamo": "empalidecer",
    "empalideçamos": "empalidecer",
    "empalideças": "empalidecer",
    "empalideço": "empalidecer",
    "empalma": "empalmar",
    "empalmada": "empalmar",
    "empalmadas": "empalmar",
    "empalmado": "empalmar",
    "empalmadora": "empalmador",
    "empalmadoras": "empalmador",
    "empalmadores": "empalmador",
    "empalmados": "empalmar",
    "empalmai": "empalmar",
    "empalmais": "empalmar",
    "empalmam": "empalmar",
    "empalmamo": "empalmar",
    "empalmamos": "empalmar",
    "empalmando": "empalmar",
    "empalmara": "empalmar",
    "empalmaram": "empalmar",
    "empalmaras": "empalmar",
    "empalmarde": "empalmar",
    "empalmardes": "empalmar",
    "empalmare": "empalmar",
    "empalmarei": "empalmar",
    "empalmareis": "empalmar",
    "empalmarem": "empalmar",
    "empalmaremos": "empalmar",
    "empalmares": "empalmar",
    "empalmaria": "empalmar",
    "empalmariam": "empalmar",
    "empalmarias": "empalmar",
    "empalmarmo": "empalmar",
    "empalmarmos": "empalmar",
    "empalmará": "empalmar",
    "empalmarás": "empalmar",
    "empalmarão": "empalmar",
    "empalmaríamos": "empalmar",
    "empalmaríeis": "empalmar",
    "empalmas": "empalmar",
    "empalmasse": "empalmar",
    "empalmassem": "empalmar",
    "empalmasses": "empalmar",
    "empalmaste": "empalmar",
    "empalmastes": "empalmar",
    "empalmava": "empalmar",
    "empalmavam": "empalmar",
    "empalmavas": "empalmar",
    "empalmações": "empalmação",
    "empalme": "empalmar",
    "empalmei": "empalmar",
    "empalmeis": "empalmar",
    "empalmem": "empalmar",
    "empalmemo": "empalmar",
    "empalmemos": "empalmar",
    "empalmes": "empalmar",
    "empalmo": "empalmar",
    "empalmou": "empalmar",
    "empalmá": "empalmar",
    "empalmámo": "empalmar",
    "empalmámos": "empalmar",
    "empalmáramo": "empalmar",
    "empalmáramos": "empalmar",
    "empalmárei": "empalmar",
    "empalmáreis": "empalmar",
    "empalmásseis": "empalmar",
    "empalmássemos": "empalmar",
    "empalmávamo": "empalmar",
    "empalmávamos": "empalmar",
    "empalmávei": "empalmar",
    "empalmáveis": "empalmar",
    "empalo": "empalar",
    "empalou": "empalar",
    "empalá": "empalar",
    "empalámo": "empalar",
    "empalámos": "empalar",
    "empaláramo": "empalar",
    "empaláramos": "empalar",
    "empalárei": "empalar",
    "empaláreis": "empalar",
    "empalásseis": "empalar",
    "empalássemos": "empalar",
    "empalávamo": "empalar",
    "empalávamos": "empalar",
    "empalávei": "empalar",
    "empaláveis": "empalar",
    "empam": "empar",
    "empamo": "empar",
    "empamos": "empar",
    "empampana": "empampanar",
    "empampanada": "empampanar",
    "empampanadas": "empampanar",
    "empampanado": "empampanar",
    "empampanados": "empampanar",
    "empampanai": "empampanar",
    "empampanais": "empampanar",
    "empampanam": "empampanar",
    "empampanamo": "empampanar",
    "empampanamos": "empampanar",
    "empampanando": "empampanar",
    "empampanara": "empampanar",
    "empampanaram": "empampanar",
    "empampanaras": "empampanar",
    "empampanarde": "empampanar",
    "empampanardes": "empampanar",
    "empampanare": "empampanar",
    "empampanarei": "empampanar",
    "empampanareis": "empampanar",
    "empampanarem": "empampanar",
    "empampanaremos": "empampanar",
    "empampanares": "empampanar",
    "empampanaria": "empampanar",
    "empampanariam": "empampanar",
    "empampanarias": "empampanar",
    "empampanarmo": "empampanar",
    "empampanarmos": "empampanar",
    "empampanará": "empampanar",
    "empampanarás": "empampanar",
    "empampanarão": "empampanar",
    "empampanaríamos": "empampanar",
    "empampanaríeis": "empampanar",
    "empampanas": "empampanar",
    "empampanasse": "empampanar",
    "empampanassem": "empampanar",
    "empampanasses": "empampanar",
    "empampanaste": "empampanar",
    "empampanastes": "empampanar",
    "empampanava": "empampanar",
    "empampanavam": "empampanar",
    "empampanavas": "empampanar",
    "empampane": "empampanar",
    "empampanei": "empampanar",
    "empampaneis": "empampanar",
    "empampanem": "empampanar",
    "empampanemo": "empampanar",
    "empampanemos": "empampanar",
    "empampanes": "empampanar",
    "empampano": "empampanar",
    "empampanou": "empampanar",
    "empampaná": "empampanar",
    "empampanámo": "empampanar",
    "empampanámos": "empampanar",
    "empampanáramo": "empampanar",
    "empampanáramos": "empampanar",
    "empampanárei": "empampanar",
    "empampanáreis": "empampanar",
    "empampanásseis": "empampanar",
    "empampanássemos": "empampanar",
    "empampanávamo": "empampanar",
    "empampanávamos": "empampanar",
    "empampanávei": "empampanar",
    "empampanáveis": "empampanar",
    "empana": "empanar",
    "empanada": "empanar",
    "empanadas": "empanar",
    "empanadilhas": "empanadilha",
    "empanado": "empanar",
    "empanados": "empanar",
    "empanai": "empanar",
    "empanais": "empanar",
    "empanam": "empanar",
    "empanamentos": "empanamento",
    "empanamo": "empanar",
    "empanamos": "empanar",
    "empanando": "empanar",
    "empanara": "empanar",
    "empanaram": "empanar",
    "empanaras": "empanar",
    "empanarde": "empanar",
    "empanardes": "empanar",
    "empanare": "empanar",
    "empanarei": "empanar",
    "empanareis": "empanar",
    "empanarem": "empanar",
    "empanaremos": "empanar",
    "empanares": "empanar",
    "empanaria": "empanar",
    "empanariam": "empanar",
    "empanarias": "empanar",
    "empanarmo": "empanar",
    "empanarmos": "empanar",
    "empanará": "empanar",
    "empanarás": "empanar",
    "empanarão": "empanar",
    "empanaríamos": "empanar",
    "empanaríeis": "empanar",
    "empanas": "empanar",
    "empanasse": "empanar",
    "empanassem": "empanar",
    "empanasses": "empanar",
    "empanaste": "empanar",
    "empanastes": "empanar",
    "empanava": "empanar",
    "empanavam": "empanar",
    "empanavas": "empanar",
    "empanca": "empancar",
    "empancada": "empancar",
    "empancadas": "empancar",
    "empancado": "empancar",
    "empancados": "empancar",
    "empancai": "empancar",
    "empancais": "empancar",
    "empancam": "empancar",
    "empancamentos": "empancamento",
    "empancamo": "empancar",
    "empancamos": "empancar",
    "empancando": "empancar",
    "empancara": "empancar",
    "empancaram": "empancar",
    "empancaras": "empancar",
    "empancarde": "empancar",
    "empancardes": "empancar",
    "empancare": "empancar",
    "empancarei": "empancar",
    "empancareis": "empancar",
    "empancarem": "empancar",
    "empancaremos": "empancar",
    "empancares": "empancar",
    "empancaria": "empancar",
    "empancariam": "empancar",
    "empancarias": "empancar",
    "empancarmo": "empancar",
    "empancarmos": "empancar",
    "empancará": "empancar",
    "empancarás": "empancar",
    "empancarão": "empancar",
    "empancaríamos": "empancar",
    "empancaríeis": "empancar",
    "empancas": "empancar",
    "empancasse": "empancar",
    "empancassem": "empancar",
    "empancasses": "empancar",
    "empancaste": "empancar",
    "empancastes": "empancar",
    "empancava": "empancar",
    "empancavam": "empancar",
    "empancavas": "empancar",
    "empanco": "empancar",
    "empancou": "empancar",
    "empancá": "empancar",
    "empancámo": "empancar",
    "empancámos": "empancar",
    "empancáramo": "empancar",
    "empancáramos": "empancar",
    "empancárei": "empancar",
    "empancáreis": "empancar",
    "empancásseis": "empancar",
    "empancássemos": "empancar",
    "empancávamo": "empancar",
    "empancávamos": "empancar",
    "empancávei": "empancar",
    "empancáveis": "empancar",
    "empandeira": "empandeirar",
    "empandeirada": "empandeirar",
    "empandeiradas": "empandeirar",
    "empandeirado": "empandeirar",
    "empandeirados": "empandeirar",
    "empandeirai": "empandeirar",
    "empandeirais": "empandeirar",
    "empandeiram": "empandeirar",
    "empandeiramentos": "empandeiramento",
    "empandeiramo": "empandeirar",
    "empandeiramos": "empandeirar",
    "empandeirando": "empandeirar",
    "empandeirara": "empandeirar",
    "empandeiraram": "empandeirar",
    "empandeiraras": "empandeirar",
    "empandeirarde": "empandeirar",
    "empandeirardes": "empandeirar",
    "empandeirare": "empandeirar",
    "empandeirarei": "empandeirar",
    "empandeirareis": "empandeirar",
    "empandeirarem": "empandeirar",
    "empandeiraremos": "empandeirar",
    "empandeirares": "empandeirar",
    "empandeiraria": "empandeirar",
    "empandeirariam": "empandeirar",
    "empandeirarias": "empandeirar",
    "empandeirarmo": "empandeirar",
    "empandeirarmos": "empandeirar",
    "empandeirará": "empandeirar",
    "empandeirarás": "empandeirar",
    "empandeirarão": "empandeirar",
    "empandeiraríamos": "empandeirar",
    "empandeiraríeis": "empandeirar",
    "empandeiras": "empandeirar",
    "empandeirasse": "empandeirar",
    "empandeirassem": "empandeirar",
    "empandeirasses": "empandeirar",
    "empandeiraste": "empandeirar",
    "empandeirastes": "empandeirar",
    "empandeirava": "empandeirar",
    "empandeiravam": "empandeirar",
    "empandeiravas": "empandeirar",
    "empandeire": "empandeirar",
    "empandeirei": "empandeirar",
    "empandeireis": "empandeirar",
    "empandeirem": "empandeirar",
    "empandeiremo": "empandeirar",
    "empandeiremos": "empandeirar",
    "empandeires": "empandeirar",
    "empandeiro": "empandeirar",
    "empandeirou": "empandeirar",
    "empandeirá": "empandeirar",
    "empandeirámo": "empandeirar",
    "empandeirámos": "empandeirar",
    "empandeiráramo": "empandeirar",
    "empandeiráramos": "empandeirar",
    "empandeirárei": "empandeirar",
    "empandeiráreis": "empandeirar",
    "empandeirásseis": "empandeirar",
    "empandeirássemos": "empandeirar",
    "empandeirávamo": "empandeirar",
    "empandeirávamos": "empandeirar",
    "empandeirávei": "empandeirar",
    "empandeiráveis": "empandeirável",
    "empandilha": "empandilhar",
    "empandilhada": "empandilhar",
    "empandilhadas": "empandilhar",
    "empandilhado": "empandilhar",
    "empandilhados": "empandilhar",
    "empandilhai": "empandilhar",
    "empandilhais": "empandilhar",
    "empandilham": "empandilhar",
    "empandilhamo": "empandilhar",
    "empandilhamos": "empandilhar",
    "empandilhando": "empandilhar",
    "empandilhara": "empandilhar",
    "empandilharam": "empandilhar",
    "empandilharas": "empandilhar",
    "empandilharde": "empandilhar",
    "empandilhardes": "empandilhar",
    "empandilhare": "empandilhar",
    "empandilharei": "empandilhar",
    "empandilhareis": "empandilhar",
    "empandilharem": "empandilhar",
    "empandilharemos": "empandilhar",
    "empandilhares": "empandilhar",
    "empandilharia": "empandilhar",
    "empandilhariam": "empandilhar",
    "empandilharias": "empandilhar",
    "empandilharmo": "empandilhar",
    "empandilharmos": "empandilhar",
    "empandilhará": "empandilhar",
    "empandilharás": "empandilhar",
    "empandilharão": "empandilhar",
    "empandilharíamos": "empandilhar",
    "empandilharíeis": "empandilhar",
    "empandilhas": "empandilhar",
    "empandilhasse": "empandilhar",
    "empandilhassem": "empandilhar",
    "empandilhasses": "empandilhar",
    "empandilhaste": "empandilhar",
    "empandilhastes": "empandilhar",
    "empandilhava": "empandilhar",
    "empandilhavam": "empandilhar",
    "empandilhavas": "empandilhar",
    "empandilhe": "empandilhar",
    "empandilhei": "empandilhar",
    "empandilheis": "empandilhar",
    "empandilhem": "empandilhar",
    "empandilhemo": "empandilhar",
    "empandilhemos": "empandilhar",
    "empandilhes": "empandilhar",
    "empandilho": "empandilhar",
    "empandilhou": "empandilhar",
    "empandilhá": "empandilhar",
    "empandilhámo": "empandilhar",
    "empandilhámos": "empandilhar",
    "empandilháramo": "empandilhar",
    "empandilháramos": "empandilhar",
    "empandilhárei": "empandilhar",
    "empandilháreis": "empandilhar",
    "empandilhásseis": "empandilhar",
    "empandilhássemos": "empandilhar",
    "empandilhávamo": "empandilhar",
    "empandilhávamos": "empandilhar",
    "empandilhávei": "empandilhar",
    "empandilháveis": "empandilhar",
    "empandina": "empandinar",
    "empandinada": "empandinar",
    "empandinadas": "empandinar",
    "empandinado": "empandinar",
    "empandinados": "empandinar",
    "empandinai": "empandinar",
    "empandinais": "empandinar",
    "empandinam": "empandinar",
    "empandinamo": "empandinar",
    "empandinamos": "empandinar",
    "empandinando": "empandinar",
    "empandinara": "empandinar",
    "empandinaram": "empandinar",
    "empandinaras": "empandinar",
    "empandinarde": "empandinar",
    "empandinardes": "empandinar",
    "empandinare": "empandinar",
    "empandinarei": "empandinar",
    "empandinareis": "empandinar",
    "empandinarem": "empandinar",
    "empandinaremos": "empandinar",
    "empandinares": "empandinar",
    "empandinaria": "empandinar",
    "empandinariam": "empandinar",
    "empandinarias": "empandinar",
    "empandinarmo": "empandinar",
    "empandinarmos": "empandinar",
    "empandinará": "empandinar",
    "empandinarás": "empandinar",
    "empandinarão": "empandinar",
    "empandinaríamos": "empandinar",
    "empandinaríeis": "empandinar",
    "empandinas": "empandinar",
    "empandinasse": "empandinar",
    "empandinassem": "empandinar",
    "empandinasses": "empandinar",
    "empandinaste": "empandinar",
    "empandinastes": "empandinar",
    "empandinava": "empandinar",
    "empandinavam": "empandinar",
    "empandinavas": "empandinar",
    "empandine": "empandinar",
    "empandinei": "empandinar",
    "empandineis": "empandinar",
    "empandinem": "empandinar",
    "empandinemo": "empandinar",
    "empandinemos": "empandinar",
    "empandines": "empandinar",
    "empandino": "empandinar",
    "empandinou": "empandinar",
    "empandiná": "empandinar",
    "empandinámo": "empandinar",
    "empandinámos": "empandinar",
    "empandináramo": "empandinar",
    "empandináramos": "empandinar",
    "empandinárei": "empandinar",
    "empandináreis": "empandinar",
    "empandinásseis": "empandinar",
    "empandinássemos": "empandinar",
    "empandinávamo": "empandinar",
    "empandinávamos": "empandinar",
    "empandinávei": "empandinar",
    "empandináveis": "empandinar",
    "empando": "empar",
    "empane": "empanar",
    "empanei": "empanar",
    "empaneis": "empanar",
    "empanem": "empanar",
    "empanemo": "empanar",
    "empanemos": "empanar",
    "empanes": "empanar",
    "empano": "empanar",
    "empanou": "empanar",
    "empanque": "empancar",
    "empanquei": "empancar",
    "empanqueis": "empancar",
    "empanquem": "empancar",
    "empanquemo": "empancar",
    "empanquemos": "empancar",
    "empanques": "empanque",
    "empantana": "empantanar",
    "empantanada": "empantanar",
    "empantanadas": "empantanar",
    "empantanado": "empantanar",
    "empantanados": "empantanar",
    "empantanai": "empantanar",
    "empantanais": "empantanar",
    "empantanam": "empantanar",
    "empantanamo": "empantanar",
    "empantanamos": "empantanar",
    "empantanando": "empantanar",
    "empantanara": "empantanar",
    "empantanaram": "empantanar",
    "empantanaras": "empantanar",
    "empantanarde": "empantanar",
    "empantanardes": "empantanar",
    "empantanare": "empantanar",
    "empantanarei": "empantanar",
    "empantanareis": "empantanar",
    "empantanarem": "empantanar",
    "empantanaremos": "empantanar",
    "empantanares": "empantanar",
    "empantanaria": "empantanar",
    "empantanariam": "empantanar",
    "empantanarias": "empantanar",
    "empantanarmo": "empantanar",
    "empantanarmos": "empantanar",
    "empantanará": "empantanar",
    "empantanarás": "empantanar",
    "empantanarão": "empantanar",
    "empantanaríamos": "empantanar",
    "empantanaríeis": "empantanar",
    "empantanas": "empantanar",
    "empantanasse": "empantanar",
    "empantanassem": "empantanar",
    "empantanasses": "empantanar",
    "empantanaste": "empantanar",
    "empantanastes": "empantanar",
    "empantanava": "empantanar",
    "empantanavam": "empantanar",
    "empantanavas": "empantanar",
    "empantane": "empantanar",
    "empantanei": "empantanar",
    "empantaneis": "empantanar",
    "empantanem": "empantanar",
    "empantanemo": "empantanar",
    "empantanemos": "empantanar",
    "empantanes": "empantanar",
    "empantano": "empantanar",
    "empantanou": "empantanar",
    "empantaná": "empantanar",
    "empantanámo": "empantanar",
    "empantanámos": "empantanar",
    "empantanáramo": "empantanar",
    "empantanáramos": "empantanar",
    "empantanárei": "empantanar",
    "empantanáreis": "empantanar",
    "empantanásseis": "empantanar",
    "empantanássemos": "empantanar",
    "empantanávamo": "empantanar",
    "empantanávamos": "empantanar",
    "empantanávei": "empantanar",
    "empantanáveis": "empantanar",
    "empantufa": "empantufar",
    "empantufada": "empantufar",
    "empantufadas": "empantufar",
    "empantufado": "empantufar",
    "empantufados": "empantufar",
    "empantufai": "empantufar",
    "empantufais": "empantufar",
    "empantufam": "empantufar",
    "empantufamo": "empantufar",
    "empantufamos": "empantufar",
    "empantufando": "empantufar",
    "empantufara": "empantufar",
    "empantufaram": "empantufar",
    "empantufaras": "empantufar",
    "empantufarde": "empantufar",
    "empantufardes": "empantufar",
    "empantufare": "empantufar",
    "empantufarei": "empantufar",
    "empantufareis": "empantufar",
    "empantufarem": "empantufar",
    "empantufaremos": "empantufar",
    "empantufares": "empantufar",
    "empantufaria": "empantufar",
    "empantufariam": "empantufar",
    "empantufarias": "empantufar",
    "empantufarmo": "empantufar",
    "empantufarmos": "empantufar",
    "empantufará": "empantufar",
    "empantufarás": "empantufar",
    "empantufarão": "empantufar",
    "empantufaríamos": "empantufar",
    "empantufaríeis": "empantufar",
    "empantufas": "empantufar",
    "empantufasse": "empantufar",
    "empantufassem": "empantufar",
    "empantufasses": "empantufar",
    "empantufaste": "empantufar",
    "empantufastes": "empantufar",
    "empantufava": "empantufar",
    "empantufavam": "empantufar",
    "empantufavas": "empantufar",
    "empantufe": "empantufar",
    "empantufei": "empantufar",
    "empantufeis": "empantufar",
    "empantufem": "empantufar",
    "empantufemo": "empantufar",
    "empantufemos": "empantufar",
    "empantufes": "empantufar",
    "empantufo": "empantufar",
    "empantufou": "empantufar",
    "empantufá": "empantufar",
    "empantufámo": "empantufar",
    "empantufámos": "empantufar",
    "empantufáramo": "empantufar",
    "empantufáramos": "empantufar",
    "empantufárei": "empantufar",
    "empantufáreis": "empantufar",
    "empantufásseis": "empantufar",
    "empantufássemos": "empantufar",
    "empantufávamo": "empantufar",
    "empantufávamos": "empantufar",
    "empantufávei": "empantufar",
    "empantufáveis": "empantufar",
    "empanturra": "empanturrar",
    "empanturrada": "empanturrar",
    "empanturradas": "empanturrar",
    "empanturrado": "empanturrar",
    "empanturrados": "empanturrar",
    "empanturradíssima": "empanturrado",
    "empanturradíssimas": "empanturrado",
    "empanturradíssimo": "empanturrado",
    "empanturradíssimos": "empanturrado",
    "empanturrai": "empanturrar",
    "empanturrais": "empanturrar",
    "empanturram": "empanturrar",
    "empanturramentos": "empanturramento",
    "empanturramo": "empanturrar",
    "empanturramos": "empanturrar",
    "empanturrando": "empanturrar",
    "empanturrara": "empanturrar",
    "empanturraram": "empanturrar",
    "empanturraras": "empanturrar",
    "empanturrarde": "empanturrar",
    "empanturrardes": "empanturrar",
    "empanturrare": "empanturrar",
    "empanturrarei": "empanturrar",
    "empanturrareis": "empanturrar",
    "empanturrarem": "empanturrar",
    "empanturraremos": "empanturrar",
    "empanturrares": "empanturrar",
    "empanturraria": "empanturrar",
    "empanturrariam": "empanturrar",
    "empanturrarias": "empanturrar",
    "empanturrarmo": "empanturrar",
    "empanturrarmos": "empanturrar",
    "empanturrará": "empanturrar",
    "empanturrarás": "empanturrar",
    "empanturrarão": "empanturrar",
    "empanturraríamos": "empanturrar",
    "empanturraríeis": "empanturrar",
    "empanturras": "empanturrar",
    "empanturrasse": "empanturrar",
    "empanturrassem": "empanturrar",
    "empanturrasses": "empanturrar",
    "empanturraste": "empanturrar",
    "empanturrastes": "empanturrar",
    "empanturrava": "empanturrar",
    "empanturravam": "empanturrar",
    "empanturravas": "empanturrar",
    "empanturre": "empanturrar",
    "empanturrei": "empanturrar",
    "empanturreis": "empanturrar",
    "empanturrem": "empanturrar",
    "empanturremo": "empanturrar",
    "empanturremos": "empanturrar",
    "empanturres": "empanturrar",
    "empanturro": "empanturrar",
    "empanturrou": "empanturrar",
    "empanturrá": "empanturrar",
    "empanturrámo": "empanturrar",
    "empanturrámos": "empanturrar",
    "empanturráramo": "empanturrar",
    "empanturráramos": "empanturrar",
    "empanturrárei": "empanturrar",
    "empanturráreis": "empanturrar",
    "empanturrásseis": "empanturrar",
    "empanturrássemos": "empanturrar",
    "empanturrávamo": "empanturrar",
    "empanturrávamos": "empanturrar",
    "empanturrávei": "empanturrar",
    "empanturráveis": "empanturrar",
    "empanzina": "empanzinar",
    "empanzinada": "empanzinar",
    "empanzinadas": "empanzinar",
    "empanzinadelas": "empanzinadela",
    "empanzinado": "empanzinar",
    "empanzinadora": "empanzinador",
    "empanzinadoras": "empanzinador",
    "empanzinadores": "empanzinador",
    "empanzinados": "empanzinar",
    "empanzinai": "empanzinar",
    "empanzinais": "empanzinar",
    "empanzinam": "empanzinar",
    "empanzinamentos": "empanzinamento",
    "empanzinamo": "empanzinar",
    "empanzinamos": "empanzinar",
    "empanzinando": "empanzinar",
    "empanzinara": "empanzinar",
    "empanzinaram": "empanzinar",
    "empanzinaras": "empanzinar",
    "empanzinarde": "empanzinar",
    "empanzinardes": "empanzinar",
    "empanzinare": "empanzinar",
    "empanzinarei": "empanzinar",
    "empanzinareis": "empanzinar",
    "empanzinarem": "empanzinar",
    "empanzinaremos": "empanzinar",
    "empanzinares": "empanzinar",
    "empanzinaria": "empanzinar",
    "empanzinariam": "empanzinar",
    "empanzinarias": "empanzinar",
    "empanzinarmo": "empanzinar",
    "empanzinarmos": "empanzinar",
    "empanzinará": "empanzinar",
    "empanzinarás": "empanzinar",
    "empanzinarão": "empanzinar",
    "empanzinaríamos": "empanzinar",
    "empanzinaríeis": "empanzinar",
    "empanzinas": "empanzinar",
    "empanzinasse": "empanzinar",
    "empanzinassem": "empanzinar",
    "empanzinasses": "empanzinar",
    "empanzinaste": "empanzinar",
    "empanzinastes": "empanzinar",
    "empanzinava": "empanzinar",
    "empanzinavam": "empanzinar",
    "empanzinavas": "empanzinar",
    "empanzine": "empanzinar",
    "empanzinei": "empanzinar",
    "empanzineis": "empanzinar",
    "empanzinem": "empanzinar",
    "empanzinemo": "empanzinar",
    "empanzinemos": "empanzinar",
    "empanzines": "empanzinar",
    "empanzino": "empanzinar",
    "empanzinou": "empanzinar",
    "empanziná": "empanzinar",
    "empanzinámo": "empanzinar",
    "empanzinámos": "empanzinar",
    "empanzináramo": "empanzinar",
    "empanzináramos": "empanzinar",
    "empanzinárei": "empanzinar",
    "empanzináreis": "empanzinar",
    "empanzinásseis": "empanzinar",
    "empanzinássemos": "empanzinar",
    "empanzinávamo": "empanzinar",
    "empanzinávamos": "empanzinar",
    "empanzinávei": "empanzinar",
    "empanzináveis": "empanzinar",
    "empaná": "empanar",
    "empanámo": "empanar",
    "empanámos": "empanar",
    "empanáramo": "empanar",
    "empanáramos": "empanar",
    "empanárei": "empanar",
    "empanáreis": "empanar",
    "empanásseis": "empanar",
    "empanássemos": "empanar",
    "empanávamo": "empanar",
    "empanávamos": "empanar",
    "empanávei": "empanar",
    "empanáveis": "empanar",
    "empapa": "empapar",
    "empapada": "empapar",
    "empapadas": "empapar",
    "empapado": "empapar",
    "empapados": "empapar",
    "empapadíssima": "empapado",
    "empapadíssimas": "empapado",
    "empapadíssimo": "empapado",
    "empapadíssimos": "empapado",
    "empapagens": "empapagem",
    "empapai": "empapar",
    "empapais": "empapar",
    "empapam": "empapar",
    "empapamo": "empapar",
    "empapamos": "empapar",
    "empapando": "empapar",
    "empapara": "empapar",
    "empaparam": "empapar",
    "empaparas": "empapar",
    "empaparde": "empapar",
    "empapardes": "empapar",
    "empapare": "empapar",
    "empaparei": "empapar",
    "empapareis": "empapar",
    "empaparem": "empapar",
    "empaparemos": "empapar",
    "empapares": "empapar",
    "empaparia": "empapar",
    "empapariam": "empapar",
    "empaparias": "empapar",
    "empaparmo": "empapar",
    "empaparmos": "empapar",
    "empapará": "empapar",
    "empaparás": "empapar",
    "empaparão": "empapar",
    "empaparíamos": "empapar",
    "empaparíeis": "empapar",
    "empapas": "empapar",
    "empapasse": "empapar",
    "empapassem": "empapar",
    "empapasses": "empapar",
    "empapaste": "empapar",
    "empapastes": "empapar",
    "empapava": "empapar",
    "empapavam": "empapar",
    "empapavas": "empapar",
    "empape": "empapar",
    "empapei": "empapar",
    "empapeis": "empapar",
    "empapela": "empapelar",
    "empapelada": "empapelar",
    "empapeladas": "empapelar",
    "empapelado": "empapelar",
    "empapelados": "empapelar",
    "empapelai": "empapelar",
    "empapelais": "empapelar",
    "empapelam": "empapelar",
    "empapelamentos": "empapelamento",
    "empapelamo": "empapelar",
    "empapelamos": "empapelar",
    "empapelando": "empapelar",
    "empapelara": "empapelar",
    "empapelaram": "empapelar",
    "empapelaras": "empapelar",
    "empapelarde": "empapelar",
    "empapelardes": "empapelar",
    "empapelare": "empapelar",
    "empapelarei": "empapelar",
    "empapelareis": "empapelar",
    "empapelarem": "empapelar",
    "empapelaremos": "empapelar",
    "empapelares": "empapelar",
    "empapelaria": "empapelar",
    "empapelariam": "empapelar",
    "empapelarias": "empapelar",
    "empapelarmo": "empapelar",
    "empapelarmos": "empapelar",
    "empapelará": "empapelar",
    "empapelarás": "empapelar",
    "empapelarão": "empapelar",
    "empapelaríamos": "empapelar",
    "empapelaríeis": "empapelar",
    "empapelas": "empapelar",
    "empapelasse": "empapelar",
    "empapelassem": "empapelar",
    "empapelasses": "empapelar",
    "empapelaste": "empapelar",
    "empapelastes": "empapelar",
    "empapelava": "empapelar",
    "empapelavam": "empapelar",
    "empapelavas": "empapelar",
    "empapele": "empapelar",
    "empapelei": "empapelar",
    "empapeleis": "empapelar",
    "empapelem": "empapelar",
    "empapelemo": "empapelar",
    "empapelemos": "empapelar",
    "empapeles": "empapelar",
    "empapelo": "empapelar",
    "empapelos": "empapelo",
    "empapelou": "empapelar",
    "empapelá": "empapelar",
    "empapelámo": "empapelar",
    "empapelámos": "empapelar",
    "empapeláramo": "empapelar",
    "empapeláramos": "empapelar",
    "empapelárei": "empapelar",
    "empapeláreis": "empapelar",
    "empapelásseis": "empapelar",
    "empapelássemos": "empapelar",
    "empapelávamo": "empapelar",
    "empapelávamos": "empapelar",
    "empapelávei": "empapelar",
    "empapeláveis": "empapelar",
    "empapem": "empapar",
    "empapemo": "empapar",
    "empapemos": "empapar",
    "empapes": "empapar",
    "empapo": "empapar",
    "empapoila": "empapoilar",
    "empapoilada": "empapoilar",
    "empapoiladas": "empapoilar",
    "empapoilado": "empapoilar",
    "empapoilados": "empapoilar",
    "empapoilai": "empapoilar",
    "empapoilais": "empapoilar",
    "empapoilam": "empapoilar",
    "empapoilamo": "empapoilar",
    "empapoilamos": "empapoilar",
    "empapoilando": "empapoilar",
    "empapoilara": "empapoilar",
    "empapoilaram": "empapoilar",
    "empapoilaras": "empapoilar",
    "empapoilarde": "empapoilar",
    "empapoilardes": "empapoilar",
    "empapoilare": "empapoilar",
    "empapoilarei": "empapoilar",
    "empapoilareis": "empapoilar",
    "empapoilarem": "empapoilar",
    "empapoilaremos": "empapoilar",
    "empapoilares": "empapoilar",
    "empapoilaria": "empapoilar",
    "empapoilariam": "empapoilar",
    "empapoilarias": "empapoilar",
    "empapoilarmo": "empapoilar",
    "empapoilarmos": "empapoilar",
    "empapoilará": "empapoilar",
    "empapoilarás": "empapoilar",
    "empapoilarão": "empapoilar",
    "empapoilaríamos": "empapoilar",
    "empapoilaríeis": "empapoilar",
    "empapoilas": "empapoilar",
    "empapoilasse": "empapoilar",
    "empapoilassem": "empapoilar",
    "empapoilasses": "empapoilar",
    "empapoilaste": "empapoilar",
    "empapoilastes": "empapoilar",
    "empapoilava": "empapoilar",
    "empapoilavam": "empapoilar",
    "empapoilavas": "empapoilar",
    "empapoile": "empapoilar",
    "empapoilei": "empapoilar",
    "empapoileis": "empapoilar",
    "empapoilem": "empapoilar",
    "empapoilemo": "empapoilar",
    "empapoilemos": "empapoilar",
    "empapoiles": "empapoilar",
    "empapoilo": "empapoilar",
    "empapoilou": "empapoilar",
    "empapoilá": "empapoilar",
    "empapoilámo": "empapoilar",
    "empapoilámos": "empapoilar",
    "empapoiláramo": "empapoilar",
    "empapoiláramos": "empapoilar",
    "empapoilárei": "empapoilar",
    "empapoiláreis": "empapoilar",
    "empapoilásseis": "empapoilar",
    "empapoilássemos": "empapoilar",
    "empapoilávamo": "empapoilar",
    "empapoilávamos": "empapoilar",
    "empapoilávei": "empapoilar",
    "empapoiláveis": "empapoilar",
    "empapou": "empapar",
    "empapoula": "empapoular",
    "empapoulada": "empapoular",
    "empapouladas": "empapoular",
    "empapoulado": "empapoular",
    "empapoulados": "empapoular",
    "empapoulai": "empapoular",
    "empapoulais": "empapoular",
    "empapoulam": "empapoular",
    "empapoulamo": "empapoular",
    "empapoulamos": "empapoular",
    "empapoulando": "empapoular",
    "empapoulara": "empapoular",
    "empapoularam": "empapoular",
    "empapoularas": "empapoular",
    "empapoularde": "empapoular",
    "empapoulardes": "empapoular",
    "empapoulare": "empapoular",
    "empapoularei": "empapoular",
    "empapoulareis": "empapoular",
    "empapoularem": "empapoular",
    "empapoularemos": "empapoular",
    "empapoulares": "empapoular",
    "empapoularia": "empapoular",
    "empapoulariam": "empapoular",
    "empapoularias": "empapoular",
    "empapoularmo": "empapoular",
    "empapoularmos": "empapoular",
    "empapoulará": "empapoular",
    "empapoularás": "empapoular",
    "empapoularão": "empapoular",
    "empapoularíamos": "empapoular",
    "empapoularíeis": "empapoular",
    "empapoulas": "empapoular",
    "empapoulasse": "empapoular",
    "empapoulassem": "empapoular",
    "empapoulasses": "empapoular",
    "empapoulaste": "empapoular",
    "empapoulastes": "empapoular",
    "empapoulava": "empapoular",
    "empapoulavam": "empapoular",
    "empapoulavas": "empapoular",
    "empapoule": "empapoular",
    "empapoulei": "empapoular",
    "empapouleis": "empapoular",
    "empapoulem": "empapoular",
    "empapoulemo": "empapoular",
    "empapoulemos": "empapoular",
    "empapoules": "empapoular",
    "empapoulo": "empapoular",
    "empapoulou": "empapoular",
    "empapoulá": "empapoular",
    "empapoulámo": "empapoular",
    "empapoulámos": "empapoular",
    "empapouláramo": "empapoular",
    "empapouláramos": "empapoular",
    "empapoulárei": "empapoular",
    "empapouláreis": "empapoular",
    "empapoulásseis": "empapoular",
    "empapoulássemos": "empapoular",
    "empapoulávamo": "empapoular",
    "empapoulávamos": "empapoular",
    "empapoulávei": "empapoular",
    "empapouláveis": "empapoular",
    "empapuce": "empapuçar",
    "empapucei": "empapuçar",
    "empapuceis": "empapuçar",
    "empapucem": "empapuçar",
    "empapucemo": "empapuçar",
    "empapucemos": "empapuçar",
    "empapuces": "empapuçar",
    "empapuça": "empapuçar",
    "empapuçada": "empapuçar",
    "empapuçadas": "empapuçar",
    "empapuçado": "empapuçar",
    "empapuçados": "empapuçar",
    "empapuçai": "empapuçar",
    "empapuçais": "empapuçar",
    "empapuçam": "empapuçar",
    "empapuçamo": "empapuçar",
    "empapuçamos": "empapuçar",
    "empapuçando": "empapuçar",
    "empapuçara": "empapuçar",
    "empapuçaram": "empapuçar",
    "empapuçaras": "empapuçar",
    "empapuçarde": "empapuçar",
    "empapuçardes": "empapuçar",
    "empapuçare": "empapuçar",
    "empapuçarei": "empapuçar",
    "empapuçareis": "empapuçar",
    "empapuçarem": "empapuçar",
    "empapuçaremos": "empapuçar",
    "empapuçares": "empapuçar",
    "empapuçaria": "empapuçar",
    "empapuçariam": "empapuçar",
    "empapuçarias": "empapuçar",
    "empapuçarmo": "empapuçar",
    "empapuçarmos": "empapuçar",
    "empapuçará": "empapuçar",
    "empapuçarás": "empapuçar",
    "empapuçarão": "empapuçar",
    "empapuçaríamos": "empapuçar",
    "empapuçaríeis": "empapuçar",
    "empapuças": "empapuçar",
    "empapuçasse": "empapuçar",
    "empapuçassem": "empapuçar",
    "empapuçasses": "empapuçar",
    "empapuçaste": "empapuçar",
    "empapuçastes": "empapuçar",
    "empapuçava": "empapuçar",
    "empapuçavam": "empapuçar",
    "empapuçavas": "empapuçar",
    "empapuço": "empapuçar",
    "empapuçou": "empapuçar",
    "empapuçá": "empapuçar",
    "empapuçámo": "empapuçar",
    "empapuçámos": "empapuçar",
    "empapuçáramo": "empapuçar",
    "empapuçáramos": "empapuçar",
    "empapuçárei": "empapuçar",
    "empapuçáreis": "empapuçar",
    "empapuçásseis": "empapuçar",
    "empapuçássemos": "empapuçar",
    "empapuçávamo": "empapuçar",
    "empapuçávamos": "empapuçar",
    "empapuçávei": "empapuçar",
    "empapuçáveis": "empapuçar",
    "empapá": "empapar",
    "empapámo": "empapar",
    "empapámos": "empapar",
    "empapáramo": "empapar",
    "empapáramos": "empapar",
    "empapárei": "empapar",
    "empapáreis": "empapar",
    "empapásseis": "empapar",
    "empapássemos": "empapar",
    "empapávamo": "empapar",
    "empapávamos": "empapar",
    "empapávei": "empapar",
    "empapáveis": "empapar",
    "empaque": "empacar",
    "empaquei": "empacar",
    "empaqueis": "empacar",
    "empaquem": "empacar",
    "empaquemo": "empacar",
    "empaquemos": "empacar",
    "empaques": "empacar",
    "empara": "emparar",
    "emparada": "emparar",
    "emparadas": "emparar",
    "emparado": "emparar",
    "emparados": "emparar",
    "emparai": "emparar",
    "emparais": "emparar",
    "emparam": "emparar",
    "emparamo": "emparar",
    "emparamos": "emparar",
    "emparando": "emparar",
    "emparara": "emparar",
    "empararam": "emparar",
    "empararas": "emparar",
    "empararde": "emparar",
    "emparardes": "emparar",
    "emparare": "emparar",
    "empararei": "emparar",
    "emparareis": "emparar",
    "empararem": "emparar",
    "empararemos": "emparar",
    "emparares": "emparar",
    "empararia": "emparar",
    "emparariam": "emparar",
    "empararias": "emparar",
    "empararmo": "emparar",
    "empararmos": "emparar",
    "emparará": "emparar",
    "empararás": "emparar",
    "empararão": "emparar",
    "empararíamos": "emparar",
    "empararíeis": "emparar",
    "emparas": "emparar",
    "emparasse": "emparar",
    "emparassem": "emparar",
    "emparasses": "emparar",
    "emparaste": "emparar",
    "emparastes": "emparar",
    "emparava": "emparar",
    "emparavam": "emparar",
    "emparavas": "emparar",
    "emparceira": "emparceirar",
    "emparceirada": "emparceirar",
    "emparceiradas": "emparceirar",
    "emparceirado": "emparceirar",
    "emparceirados": "emparceirar",
    "emparceirai": "emparceirar",
    "emparceirais": "emparceirar",
    "emparceiram": "emparceirar",
    "emparceiramo": "emparceirar",
    "emparceiramos": "emparceirar",
    "emparceirando": "emparceirar",
    "emparceirara": "emparceirar",
    "emparceiraram": "emparceirar",
    "emparceiraras": "emparceirar",
    "emparceirarde": "emparceirar",
    "emparceirardes": "emparceirar",
    "emparceirare": "emparceirar",
    "emparceirarei": "emparceirar",
    "emparceirareis": "emparceirar",
    "emparceirarem": "emparceirar",
    "emparceiraremos": "emparceirar",
    "emparceirares": "emparceirar",
    "emparceiraria": "emparceirar",
    "emparceirariam": "emparceirar",
    "emparceirarias": "emparceirar",
    "emparceirarmo": "emparceirar",
    "emparceirarmos": "emparceirar",
    "emparceirará": "emparceirar",
    "emparceirarás": "emparceirar",
    "emparceirarão": "emparceirar",
    "emparceiraríamos": "emparceirar",
    "emparceiraríeis": "emparceirar",
    "emparceiras": "emparceirar",
    "emparceirasse": "emparceirar",
    "emparceirassem": "emparceirar",
    "emparceirasses": "emparceirar",
    "emparceiraste": "emparceirar",
    "emparceirastes": "emparceirar",
    "emparceirava": "emparceirar",
    "emparceiravam": "emparceirar",
    "emparceiravas": "emparceirar",
    "emparceire": "emparceirar",
    "emparceirei": "emparceirar",
    "emparceireis": "emparceirar",
    "emparceirem": "emparceirar",
    "emparceiremo": "emparceirar",
    "emparceiremos": "emparceirar",
    "emparceires": "emparceirar",
    "emparceiro": "emparceirar",
    "emparceirou": "emparceirar",
    "emparceirá": "emparceirar",
    "emparceirámo": "emparceirar",
    "emparceirámos": "emparceirar",
    "emparceiráramo": "emparceirar",
    "emparceiráramos": "emparceirar",
    "emparceirárei": "emparceirar",
    "emparceiráreis": "emparceirar",
    "emparceirásseis": "emparceirar",
    "emparceirássemos": "emparceirar",
    "emparceirávamo": "emparceirar",
    "emparceirávamos": "emparceirar",
    "emparceirávei": "emparceirar",
    "emparceiráveis": "emparceirar",
    "emparcela": "emparcelar",
    "emparcelada": "emparcelar",
    "emparceladas": "emparcelar",
    "emparcelado": "emparcelar",
    "emparcelados": "emparcelar",
    "emparcelai": "emparcelar",
    "emparcelais": "emparcelar",
    "emparcelam": "emparcelar",
    "emparcelamentos": "emparcelamento",
    "emparcelamo": "emparcelar",
    "emparcelamos": "emparcelar",
    "emparcelando": "emparcelar",
    "emparcelara": "emparcelar",
    "emparcelaram": "emparcelar",
    "emparcelaras": "emparcelar",
    "emparcelarde": "emparcelar",
    "emparcelardes": "emparcelar",
    "emparcelare": "emparcelar",
    "emparcelarei": "emparcelar",
    "emparcelareis": "emparcelar",
    "emparcelarem": "emparcelar",
    "emparcelaremos": "emparcelar",
    "emparcelares": "emparcelar",
    "emparcelaria": "emparcelar",
    "emparcelariam": "emparcelar",
    "emparcelarias": "emparcelar",
    "emparcelarmo": "emparcelar",
    "emparcelarmos": "emparcelar",
    "emparcelará": "emparcelar",
    "emparcelarás": "emparcelar",
    "emparcelarão": "emparcelar",
    "emparcelaríamos": "emparcelar",
    "emparcelaríeis": "emparcelar",
    "emparcelas": "emparcelar",
    "emparcelasse": "emparcelar",
    "emparcelassem": "emparcelar",
    "emparcelasses": "emparcelar",
    "emparcelaste": "emparcelar",
    "emparcelastes": "emparcelar",
    "emparcelava": "emparcelar",
    "emparcelavam": "emparcelar",
    "emparcelavas": "emparcelar",
    "emparcele": "emparcelar",
    "emparcelei": "emparcelar",
    "emparceleis": "emparcelar",
    "emparcelem": "emparcelar",
    "emparcelemo": "emparcelar",
    "emparcelemos": "emparcelar",
    "emparceles": "emparcelar",
    "emparcelo": "emparcelar",
    "emparcelou": "emparcelar",
    "emparcelá": "emparcelar",
    "emparcelámo": "emparcelar",
    "emparcelámos": "emparcelar",
    "emparceláramo": "emparcelar",
    "emparceláramos": "emparcelar",
    "emparcelárei": "emparcelar",
    "emparceláreis": "emparcelar",
    "emparcelásseis": "emparcelar",
    "emparcelássemos": "emparcelar",
    "emparcelávamo": "emparcelar",
    "emparcelávamos": "emparcelar",
    "emparcelávei": "emparcelar",
    "emparceláveis": "emparcelar",
    "emparde": "empar",
    "empardece": "empardecer",
    "empardecei": "empardecer",
    "empardeceis": "empardecer",
    "empardecem": "empardecer",
    "empardecemo": "empardecer",
    "empardecemos": "empardecer",
    "empardecendo": "empardecer",
    "empardecera": "empardecer",
    "empardeceram": "empardecer",
    "empardeceras": "empardecer",
    "empardecerdes": "empardecer",
    "empardecerei": "empardecer",
    "empardecereis": "empardecer",
    "empardecerem": "empardecer",
    "empardeceremos": "empardecer",
    "empardeceres": "empardecer",
    "empardeceria": "empardecer",
    "empardeceriam": "empardecer",
    "empardecerias": "empardecer",
    "empardecermo": "empardecer",
    "empardecermos": "empardecer",
    "empardecerá": "empardecer",
    "empardecerás": "empardecer",
    "empardecerão": "empardecer",
    "empardeceríamos": "empardecer",
    "empardeceríeis": "empardecer",
    "empardeces": "empardecer",
    "empardecesse": "empardecer",
    "empardecessem": "empardecer",
    "empardecesses": "empardecer",
    "empardeceste": "empardecer",
    "empardecestes": "empardecer",
    "empardeceu": "empardecer",
    "empardeci": "empardecer",
    "empardecia": "empardecer",
    "empardeciam": "empardecer",
    "empardecias": "empardecer",
    "empardecida": "empardecido",
    "empardecidas": "empardecido",
    "empardecido": "empardecer",
    "empardecidos": "empardecido",
    "empardecêramo": "empardecer",
    "empardecêramos": "empardecer",
    "empardecêreis": "empardecer",
    "empardecêsseis": "empardecer",
    "empardecêssemos": "empardecer",
    "empardecíamo": "empardecer",
    "empardecíamos": "empardecer",
    "empardecíeis": "empardecer",
    "empardes": "empar",
    "empardeça": "empardecer",
    "empardeçais": "empardecer",
    "empardeçam": "empardecer",
    "empardeçamo": "empardecer",
    "empardeçamos": "empardecer",
    "empardeças": "empardecer",
    "empardeço": "empardecer",
    "empare": "emparar",
    "empareda": "emparedar",
    "emparedada": "emparedar",
    "emparedadas": "emparedar",
    "emparedado": "emparedar",
    "emparedados": "emparedar",
    "emparedai": "emparedar",
    "emparedais": "emparedar",
    "emparedam": "emparedar",
    "emparedamo": "emparedar",
    "emparedamos": "emparedar",
    "emparedando": "emparedar",
    "emparedara": "emparedar",
    "emparedaram": "emparedar",
    "emparedaras": "emparedar",
    "emparedarde": "emparedar",
    "emparedardes": "emparedar",
    "emparedare": "emparedar",
    "emparedarei": "emparedar",
    "emparedareis": "emparedar",
    "emparedarem": "emparedar",
    "emparedaremos": "emparedar",
    "emparedares": "emparedar",
    "emparedaria": "emparedar",
    "emparedariam": "emparedar",
    "emparedarias": "emparedar",
    "emparedarmo": "emparedar",
    "emparedarmos": "emparedar",
    "emparedará": "emparedar",
    "emparedarás": "emparedar",
    "emparedarão": "emparedar",
    "emparedaríamos": "emparedar",
    "emparedaríeis": "emparedar",
    "emparedas": "emparedar",
    "emparedasse": "emparedar",
    "emparedassem": "emparedar",
    "emparedasses": "emparedar",
    "emparedaste": "emparedar",
    "emparedastes": "emparedar",
    "emparedava": "emparedar",
    "emparedavam": "emparedar",
    "emparedavas": "emparedar",
    "emparede": "emparedar",
    "emparedei": "emparedar",
    "emparedeis": "emparedar",
    "emparedem": "emparedar",
    "emparedemo": "emparedar",
    "emparedemos": "emparedar",
    "emparedes": "emparedar",
    "emparedo": "emparedar",
    "emparedou": "emparedar",
    "emparedá": "emparedar",
    "emparedámo": "emparedar",
    "emparedámos": "emparedar",
    "emparedáramo": "emparedar",
    "emparedáramos": "emparedar",
    "emparedárei": "emparedar",
    "emparedáreis": "emparedar",
    "emparedásseis": "emparedar",
    "emparedássemos": "emparedar",
    "emparedávamo": "emparedar",
    "emparedávamos": "emparedar",
    "emparedávei": "emparedar",
    "emparedáveis": "emparedar",
    "emparei": "emparar",
    "empareis": "emparar",
    "emparelha": "emparelhar",
    "emparelhada": "emparelhar",
    "emparelhadas": "emparelhar",
    "emparelhado": "emparelhar",
    "emparelhados": "emparelhar",
    "emparelhai": "emparelhar",
    "emparelhais": "emparelhar",
    "emparelham": "emparelhar",
    "emparelhamentos": "emparelhamento",
    "emparelhamo": "emparelhar",
    "emparelhamos": "emparelhar",
    "emparelhando": "emparelhar",
    "emparelhara": "emparelhar",
    "emparelharam": "emparelhar",
    "emparelharas": "emparelhar",
    "emparelharde": "emparelhar",
    "emparelhardes": "emparelhar",
    "emparelhare": "emparelhar",
    "emparelharei": "emparelhar",
    "emparelhareis": "emparelhar",
    "emparelharem": "emparelhar",
    "emparelharemos": "emparelhar",
    "emparelhares": "emparelhar",
    "emparelharia": "emparelhar",
    "emparelhariam": "emparelhar",
    "emparelharias": "emparelhar",
    "emparelharmo": "emparelhar",
    "emparelharmos": "emparelhar",
    "emparelhará": "emparelhar",
    "emparelharás": "emparelhar",
    "emparelharão": "emparelhar",
    "emparelharíamos": "emparelhar",
    "emparelharíeis": "emparelhar",
    "emparelhas": "emparelhar",
    "emparelhasse": "emparelhar",
    "emparelhassem": "emparelhar",
    "emparelhasses": "emparelhar",
    "emparelhaste": "emparelhar",
    "emparelhastes": "emparelhar",
    "emparelhava": "emparelhar",
    "emparelhavam": "emparelhar",
    "emparelhavas": "emparelhar",
    "emparelhe": "emparelhar",
    "emparelhei": "emparelhar",
    "emparelheis": "emparelhar",
    "emparelhem": "emparelhar",
    "emparelhemo": "emparelhar",
    "emparelhemos": "emparelhar",
    "emparelhes": "emparelhar",
    "emparelho": "emparelhar",
    "emparelhou": "emparelhar",
    "emparelhá": "emparelhar",
    "emparelhámo": "emparelhar",
    "emparelhámos": "emparelhar",
    "emparelháramo": "emparelhar",
    "emparelháramos": "emparelhar",
    "emparelhárei": "emparelhar",
    "emparelháreis": "emparelhar",
    "emparelhásseis": "emparelhar",
    "emparelhássemos": "emparelhar",
    "emparelhávamo": "emparelhar",
    "emparelhávamos": "emparelhar",
    "emparelhávei": "emparelhar",
    "emparelháveis": "emparelhar",
    "emparem": "emparar",
    "emparemo": "emparar",
    "emparemos": "emparar",
    "empares": "emparar",
    "emparia": "empar",
    "empariam": "empar",
    "emparias": "empar",
    "emparmo": "empar",
    "emparmos": "empar",
    "emparo": "emparar",
    "emparou": "emparar",
    "emparra": "emparrar",
    "emparrada": "emparrar",
    "emparradas": "emparrar",
    "emparrado": "emparrar",
    "emparrados": "emparrar",
    "emparrai": "emparrar",
    "emparrais": "emparrar",
    "emparram": "emparrar",
    "emparramo": "emparrar",
    "emparramos": "emparrar",
    "emparrando": "emparrar",
    "emparrara": "emparrar",
    "emparraram": "emparrar",
    "emparraras": "emparrar",
    "emparrarde": "emparrar",
    "emparrardes": "emparrar",
    "emparrare": "emparrar",
    "emparrarei": "emparrar",
    "emparrareis": "emparrar",
    "emparrarem": "emparrar",
    "emparraremos": "emparrar",
    "emparrares": "emparrar",
    "emparraria": "emparrar",
    "emparrariam": "emparrar",
    "emparrarias": "emparrar",
    "emparrarmo": "emparrar",
    "emparrarmos": "emparrar",
    "emparrará": "emparrar",
    "emparrarás": "emparrar",
    "emparrarão": "emparrar",
    "emparraríamos": "emparrar",
    "emparraríeis": "emparrar",
    "emparras": "emparrar",
    "emparrasse": "emparrar",
    "emparrassem": "emparrar",
    "emparrasses": "emparrar",
    "emparraste": "emparrar",
    "emparrastes": "emparrar",
    "emparrava": "emparrar",
    "emparravam": "emparrar",
    "emparravas": "emparrar",
    "emparre": "emparrar",
    "emparrei": "emparrar",
    "emparreira": "emparreirar",
    "emparreirada": "emparreirar",
    "emparreiradas": "emparreirar",
    "emparreirado": "emparreirar",
    "emparreirados": "emparreirar",
    "emparreirai": "emparreirar",
    "emparreirais": "emparreirar",
    "emparreiram": "emparreirar",
    "emparreiramo": "emparreirar",
    "emparreiramos": "emparreirar",
    "emparreirando": "emparreirar",
    "emparreirara": "emparreirar",
    "emparreiraram": "emparreirar",
    "emparreiraras": "emparreirar",
    "emparreirarde": "emparreirar",
    "emparreirardes": "emparreirar",
    "emparreirare": "emparreirar",
    "emparreirarei": "emparreirar",
    "emparreirareis": "emparreirar",
    "emparreirarem": "emparreirar",
    "emparreiraremos": "emparreirar",
    "emparreirares": "emparreirar",
    "emparreiraria": "emparreirar",
    "emparreirariam": "emparreirar",
    "emparreirarias": "emparreirar",
    "emparreirarmo": "emparreirar",
    "emparreirarmos": "emparreirar",
    "emparreirará": "emparreirar",
    "emparreirarás": "emparreirar",
    "emparreirarão": "emparreirar",
    "emparreiraríamos": "emparreirar",
    "emparreiraríeis": "emparreirar",
    "emparreiras": "emparreirar",
    "emparreirasse": "emparreirar",
    "emparreirassem": "emparreirar",
    "emparreirasses": "emparreirar",
    "emparreiraste": "emparreirar",
    "emparreirastes": "emparreirar",
    "emparreirava": "emparreirar",
    "emparreiravam": "emparreirar",
    "emparreiravas": "emparreirar",
    "emparreire": "emparreirar",
    "emparreirei": "emparreirar",
    "emparreireis": "emparreirar",
    "emparreirem": "emparreirar",
    "emparreiremo": "emparreirar",
    "emparreiremos": "emparreirar",
    "emparreires": "emparreirar",
    "emparreiro": "emparreirar",
    "emparreirou": "emparreirar",
    "emparreirá": "emparreirar",
    "emparreirámo": "emparreirar",
    "emparreirámos": "emparreirar",
    "emparreiráramo": "emparreirar",
    "emparreiráramos": "emparreirar",
    "emparreirárei": "emparreirar",
    "emparreiráreis": "emparreirar",
    "emparreirásseis": "emparreirar",
    "emparreirássemos": "emparreirar",
    "emparreirávamo": "emparreirar",
    "emparreirávamos": "emparreirar",
    "emparreirávei": "emparreirar",
    "emparreiráveis": "emparreirar",
    "emparreis": "emparrar",
    "emparrem": "emparrar",
    "emparremo": "emparrar",
    "emparremos": "emparrar",
    "emparres": "emparrar",
    "emparro": "emparrar",
    "emparrou": "emparrar",
    "emparrá": "emparrar",
    "emparrámo": "emparrar",
    "emparrámos": "emparrar",
    "emparráramo": "emparrar",
    "emparráramos": "emparrar",
    "emparrárei": "emparrar",
    "emparráreis": "emparrar",
    "emparrásseis": "emparrar",
    "emparrássemos": "emparrar",
    "emparrávamo": "emparrar",
    "emparrávamos": "emparrar",
    "emparrávei": "emparrar",
    "emparráveis": "emparrar",
    "emparvece": "emparvecer",
    "emparvecei": "emparvecer",
    "emparveceis": "emparvecer",
    "emparvecem": "emparvecer",
    "emparvecemo": "emparvecer",
    "emparvecemos": "emparvecer",
    "emparvecendo": "emparvecer",
    "emparvecera": "emparvecer",
    "emparveceram": "emparvecer",
    "emparveceras": "emparvecer",
    "emparvecerde": "emparvecer",
    "emparvecerdes": "emparvecer",
    "emparvecere": "emparvecer",
    "emparvecerei": "emparvecer",
    "emparvecereis": "emparvecer",
    "emparvecerem": "emparvecer",
    "emparveceremos": "emparvecer",
    "emparveceres": "emparvecer",
    "emparveceria": "emparvecer",
    "emparveceriam": "emparvecer",
    "emparvecerias": "emparvecer",
    "emparvecermo": "emparvecer",
    "emparvecermos": "emparvecer",
    "emparvecerá": "emparvecer",
    "emparvecerás": "emparvecer",
    "emparvecerão": "emparvecer",
    "emparveceríamos": "emparvecer",
    "emparveceríeis": "emparvecer",
    "emparveces": "emparvecer",
    "emparvecesse": "emparvecer",
    "emparvecessem": "emparvecer",
    "emparvecesses": "emparvecer",
    "emparveceste": "emparvecer",
    "emparvecestes": "emparvecer",
    "emparveceu": "emparvecer",
    "emparveci": "emparvecer",
    "emparvecia": "emparvecer",
    "emparveciam": "emparvecer",
    "emparvecias": "emparvecer",
    "emparvecida": "emparvecido",
    "emparvecidas": "emparvecido",
    "emparvecido": "emparvecer",
    "emparvecidos": "emparvecido",
    "emparvecê": "emparvecer",
    "emparvecêramo": "emparvecer",
    "emparvecêramos": "emparvecer",
    "emparvecêrei": "emparvecer",
    "emparvecêreis": "emparvecer",
    "emparvecêsseis": "emparvecer",
    "emparvecêssemos": "emparvecer",
    "emparvecíamo": "emparvecer",
    "emparvecíamos": "emparvecer",
    "emparvecíei": "emparvecer",
    "emparvecíeis": "emparvecer",
    "emparveça": "emparvecer",
    "emparveçais": "emparvecer",
    "emparveçam": "emparvecer",
    "emparveçamo": "emparvecer",
    "emparveçamos": "emparvecer",
    "emparveças": "emparvecer",
    "emparveço": "emparvecer",
    "emparvoa": "emparvoar",
    "emparvoada": "emparvoar",
    "emparvoadas": "emparvoar",
    "emparvoado": "emparvoar",
    "emparvoados": "emparvoar",
    "emparvoai": "emparvoar",
    "emparvoais": "emparvoar",
    "emparvoam": "emparvoar",
    "emparvoamo": "emparvoar",
    "emparvoamos": "emparvoar",
    "emparvoando": "emparvoar",
    "emparvoara": "emparvoar",
    "emparvoaram": "emparvoar",
    "emparvoaras": "emparvoar",
    "emparvoarde": "emparvoar",
    "emparvoardes": "emparvoar",
    "emparvoare": "emparvoar",
    "emparvoarei": "emparvoar",
    "emparvoareis": "emparvoar",
    "emparvoarem": "emparvoar",
    "emparvoaremos": "emparvoar",
    "emparvoares": "emparvoar",
    "emparvoaria": "emparvoar",
    "emparvoariam": "emparvoar",
    "emparvoarias": "emparvoar",
    "emparvoarmo": "emparvoar",
    "emparvoarmos": "emparvoar",
    "emparvoará": "emparvoar",
    "emparvoarás": "emparvoar",
    "emparvoarão": "emparvoar",
    "emparvoaríamos": "emparvoar",
    "emparvoaríeis": "emparvoar",
    "emparvoas": "emparvoar",
    "emparvoasse": "emparvoar",
    "emparvoassem": "emparvoar",
    "emparvoasses": "emparvoar",
    "emparvoaste": "emparvoar",
    "emparvoastes": "emparvoar",
    "emparvoava": "emparvoar",
    "emparvoavam": "emparvoar",
    "emparvoavas": "emparvoar",
    "emparvoe": "emparvoar",
    "emparvoece": "emparvoecer",
    "emparvoecei": "emparvoecer",
    "emparvoeceis": "emparvoecer",
    "emparvoecem": "emparvoecer",
    "emparvoecemo": "emparvoecer",
    "emparvoecemos": "emparvoecer",
    "emparvoecendo": "emparvoecer",
    "emparvoecera": "emparvoecer",
    "emparvoeceram": "emparvoecer",
    "emparvoeceras": "emparvoecer",
    "emparvoecerdes": "emparvoecer",
    "emparvoecerei": "emparvoecer",
    "emparvoecereis": "emparvoecer",
    "emparvoecerem": "emparvoecer",
    "emparvoeceremos": "emparvoecer",
    "emparvoeceres": "emparvoecer",
    "emparvoeceria": "emparvoecer",
    "emparvoeceriam": "emparvoecer",
    "emparvoecerias": "emparvoecer",
    "emparvoecermo": "emparvoecer",
    "emparvoecermos": "emparvoecer",
    "emparvoecerá": "emparvoecer",
    "emparvoecerás": "emparvoecer",
    "emparvoecerão": "emparvoecer",
    "emparvoeceríamos": "emparvoecer",
    "emparvoeceríeis": "emparvoecer",
    "emparvoeces": "emparvoecer",
    "emparvoecesse": "emparvoecer",
    "emparvoecessem": "emparvoecer",
    "emparvoecesses": "emparvoecer",
    "emparvoeceste": "emparvoecer",
    "emparvoecestes": "emparvoecer",
    "emparvoeceu": "emparvoecer",
    "emparvoeci": "emparvoecer",
    "emparvoecia": "emparvoecer",
    "emparvoeciam": "emparvoecer",
    "emparvoecias": "emparvoecer",
    "emparvoecida": "emparvoecido",
    "emparvoecidas": "emparvoecido",
    "emparvoecido": "emparvoecer",
    "emparvoecidos": "emparvoecido",
    "emparvoecêramo": "emparvoecer",
    "emparvoecêramos": "emparvoecer",
    "emparvoecêreis": "emparvoecer",
    "emparvoecêsseis": "emparvoecer",
    "emparvoecêssemos": "emparvoecer",
    "emparvoecíamo": "emparvoecer",
    "emparvoecíamos": "emparvoecer",
    "emparvoecíeis": "emparvoecer",
    "emparvoei": "emparvoar",
    "emparvoeis": "emparvoar",
    "emparvoem": "emparvoar",
    "emparvoemo": "emparvoar",
    "emparvoemos": "emparvoar",
    "emparvoes": "emparvoar",
    "emparvoeça": "emparvoecer",
    "emparvoeçais": "emparvoecer",
    "emparvoeçam": "emparvoecer",
    "emparvoeçamo": "emparvoecer",
    "emparvoeçamos": "emparvoecer",
    "emparvoeças": "emparvoecer",
    "emparvoeço": "emparvoecer",
    "emparvoo": "emparvoar",
    "emparvoou": "emparvoar",
    "emparvoá": "emparvoar",
    "emparvoámo": "emparvoar",
    "emparvoámos": "emparvoar",
    "emparvoáramo": "emparvoar",
    "emparvoáramos": "emparvoar",
    "emparvoárei": "emparvoar",
    "emparvoáreis": "emparvoar",
    "emparvoásseis": "emparvoar",
    "emparvoássemos": "emparvoar",
    "emparvoávamo": "emparvoar",
    "emparvoávamos": "emparvoar",
    "emparvoávei": "emparvoar",
    "emparvoáveis": "emparvoar",
    "empará": "emparar",
    "emparámo": "emparar",
    "emparámos": "emparar",
    "emparáramo": "emparar",
    "emparáramos": "emparar",
    "emparárei": "emparar",
    "emparáreis": "emparar",
    "emparás": "empar",
    "emparásseis": "emparar",
    "emparássemos": "emparar",
    "emparávamo": "emparar",
    "emparávamos": "emparar",
    "emparávei": "emparar",
    "emparáveis": "emparar",
    "emparão": "empar",
    "emparíamos": "empar",
    "emparíeis": "empar",
    "empas": "empar",
    "empasmas": "empasma",
    "empasse": "empar",
    "empassem": "empar",
    "empasses": "empar",
    "empasta": "empastar",
    "empastada": "empastar",
    "empastadas": "empastar",
    "empastado": "empastar",
    "empastados": "empastar",
    "empastai": "empastar",
    "empastais": "empastar",
    "empastam": "empastar",
    "empastamentos": "empastamento",
    "empastamo": "empastar",
    "empastamos": "empastar",
    "empastando": "empastar",
    "empastara": "empastar",
    "empastaram": "empastar",
    "empastaras": "empastar",
    "empastarde": "empastar",
    "empastardes": "empastar",
    "empastare": "empastar",
    "empastarei": "empastar",
    "empastareis": "empastar",
    "empastarem": "empastar",
    "empastaremos": "empastar",
    "empastares": "empastar",
    "empastaria": "empastar",
    "empastariam": "empastar",
    "empastarias": "empastar",
    "empastarmo": "empastar",
    "empastarmos": "empastar",
    "empastará": "empastar",
    "empastarás": "empastar",
    "empastarão": "empastar",
    "empastaríamos": "empastar",
    "empastaríeis": "empastar",
    "empastas": "empastar",
    "empastasse": "empastar",
    "empastassem": "empastar",
    "empastasses": "empastar",
    "empastaste": "empastar",
    "empastastes": "empastar",
    "empastava": "empastar",
    "empastavam": "empastar",
    "empastavas": "empastar",
    "empaste": "empastar",
    "empastei": "empastar",
    "empasteis": "empastar",
    "empastela": "empastelar",
    "empastelada": "empastelar",
    "empasteladas": "empastelar",
    "empastelado": "empastelar",
    "empasteladora": "empastelador",
    "empasteladoras": "empastelador",
    "empasteladores": "empastelador",
    "empastelados": "empastelar",
    "empastelai": "empastelar",
    "empastelais": "empastelar",
    "empastelam": "empastelar",
    "empastelamentos": "empastelamento",
    "empastelamo": "empastelar",
    "empastelamos": "empastelar",
    "empastelando": "empastelar",
    "empastelara": "empastelar",
    "empastelaram": "empastelar",
    "empastelaras": "empastelar",
    "empastelarde": "empastelar",
    "empastelardes": "empastelar",
    "empastelare": "empastelar",
    "empastelarei": "empastelar",
    "empastelareis": "empastelar",
    "empastelarem": "empastelar",
    "empastelaremos": "empastelar",
    "empastelares": "empastelar",
    "empastelaria": "empastelar",
    "empastelariam": "empastelar",
    "empastelarias": "empastelar",
    "empastelarmo": "empastelar",
    "empastelarmos": "empastelar",
    "empastelará": "empastelar",
    "empastelarás": "empastelar",
    "empastelarão": "empastelar",
    "empastelaríamos": "empastelar",
    "empastelaríeis": "empastelar",
    "empastelas": "empastelar",
    "empastelasse": "empastelar",
    "empastelassem": "empastelar",
    "empastelasses": "empastelar",
    "empastelaste": "empastelar",
    "empastelastes": "empastelar",
    "empastelava": "empastelar",
    "empastelavam": "empastelar",
    "empastelavas": "empastelar",
    "empastele": "empastelar",
    "empastelei": "empastelar",
    "empasteleis": "empastelar",
    "empastelem": "empastelar",
    "empastelemo": "empastelar",
    "empastelemos": "empastelar",
    "empasteles": "empastelar",
    "empastelo": "empastelar",
    "empastelou": "empastelar",
    "empastelá": "empastelar",
    "empastelámo": "empastelar",
    "empastelámos": "empastelar",
    "empasteláramo": "empastelar",
    "empasteláramos": "empastelar",
    "empastelárei": "empastelar",
    "empasteláreis": "empastelar",
    "empastelásseis": "empastelar",
    "empastelássemos": "empastelar",
    "empastelávamo": "empastelar",
    "empastelávamos": "empastelar",
    "empastelávei": "empastelar",
    "empasteláveis": "empastelar",
    "empastem": "empastar",
    "empastemo": "empastar",
    "empastemos": "empastar",
    "empastes": "empaste",
    "empasto": "empastar",
    "empastou": "empastar",
    "empastá": "empastar",
    "empastámo": "empastar",
    "empastámos": "empastar",
    "empastáramo": "empastar",
    "empastáramos": "empastar",
    "empastárei": "empastar",
    "empastáreis": "empastar",
    "empastásseis": "empastar",
    "empastássemos": "empastar",
    "empastávamo": "empastar",
    "empastávamos": "empastar",
    "empastávei": "empastar",
    "empastáveis": "empastar",
    "empata": "empatar",
    "empatada": "empatar",
    "empatadas": "empatar",
    "empatado": "empatar",
    "empatadora": "empatador",
    "empatadoras": "empatador",
    "empatadores": "empatador",
    "empatados": "empatar",
    "empatai": "empatar",
    "empatais": "empatar",
    "empatam": "empatar",
    "empatamo": "empatar",
    "empatamos": "empatar",
    "empatando": "empatar",
    "empatara": "empatar",
    "empataram": "empatar",
    "empataras": "empatar",
    "empatarde": "empatar",
    "empatardes": "empatar",
    "empatare": "empatar",
    "empatarei": "empatar",
    "empatareis": "empatar",
    "empatarem": "empatar",
    "empataremos": "empatar",
    "empatares": "empatar",
    "empataria": "empatar",
    "empatariam": "empatar",
    "empatarias": "empatar",
    "empatarmo": "empatar",
    "empatarmos": "empatar",
    "empatará": "empatar",
    "empatarás": "empatar",
    "empatarão": "empatar",
    "empataríamos": "empatar",
    "empataríeis": "empatar",
    "empatas": "empatar",
    "empatasse": "empatar",
    "empatassem": "empatar",
    "empatasses": "empatar",
    "empataste": "empatar",
    "empatastes": "empatar",
    "empatava": "empatar",
    "empatavam": "empatar",
    "empatavas": "empatar",
    "empate": "empatar",
    "empatei": "empatar",
    "empateis": "empatar",
    "empatem": "empatar",
    "empatemo": "empatar",
    "empatemos": "empatar",
    "empates": "empate",
    "empatias": "empatia",
    "empato": "empatar",
    "empatou": "empatar",
    "empatá": "empatar",
    "empatámo": "empatar",
    "empatámos": "empatar",
    "empatáramo": "empatar",
    "empatáramos": "empatar",
    "empatárei": "empatar",
    "empatáreis": "empatar",
    "empatásseis": "empatar",
    "empatássemos": "empatar",
    "empatávamo": "empatar",
    "empatávamos": "empatar",
    "empatávei": "empatar",
    "empatáveis": "empatar",
    "empava": "empar",
    "empavam": "empar",
    "empavas": "empar",
    "empaveada": "empavear",
    "empaveadas": "empavear",
    "empaveado": "empavear",
    "empaveados": "empavear",
    "empaveai": "empavear",
    "empaveais": "empavear",
    "empaveamo": "empavear",
    "empaveamos": "empavear",
    "empaveando": "empavear",
    "empaveara": "empavear",
    "empavearam": "empavear",
    "empavearas": "empavear",
    "empavearde": "empavear",
    "empaveardes": "empavear",
    "empaveare": "empavear",
    "empavearei": "empavear",
    "empaveareis": "empavear",
    "empavearem": "empavear",
    "empavearemos": "empavear",
    "empaveares": "empavear",
    "empavearia": "empavear",
    "empaveariam": "empavear",
    "empavearias": "empavear",
    "empavearmo": "empavear",
    "empavearmos": "empavear",
    "empaveará": "empavear",
    "empavearás": "empavear",
    "empavearão": "empavear",
    "empavearíamos": "empavear",
    "empavearíeis": "empavear",
    "empaveasse": "empavear",
    "empaveassem": "empavear",
    "empaveasses": "empavear",
    "empaveaste": "empavear",
    "empaveastes": "empavear",
    "empaveava": "empavear",
    "empaveavam": "empavear",
    "empaveavas": "empavear",
    "empaveei": "empavear",
    "empaveeis": "empavear",
    "empaveemo": "empavear",
    "empaveemos": "empavear",
    "empaveia": "empavear",
    "empaveiam": "empavear",
    "empaveias": "empavear",
    "empaveie": "empavear",
    "empaveiem": "empavear",
    "empaveies": "empavear",
    "empaveio": "empavear",
    "empaveou": "empavear",
    "empavesa": "empavesar",
    "empavesada": "empavesar",
    "empavesadas": "empavesar",
    "empavesado": "empavesar",
    "empavesados": "empavesar",
    "empavesai": "empavesar",
    "empavesais": "empavesar",
    "empavesam": "empavesar",
    "empavesamentos": "empavesamento",
    "empavesamo": "empavesar",
    "empavesamos": "empavesar",
    "empavesando": "empavesar",
    "empavesara": "empavesar",
    "empavesaram": "empavesar",
    "empavesaras": "empavesar",
    "empavesarde": "empavesar",
    "empavesardes": "empavesar",
    "empavesare": "empavesar",
    "empavesarei": "empavesar",
    "empavesareis": "empavesar",
    "empavesarem": "empavesar",
    "empavesaremos": "empavesar",
    "empavesares": "empavesar",
    "empavesaria": "empavesar",
    "empavesariam": "empavesar",
    "empavesarias": "empavesar",
    "empavesarmo": "empavesar",
    "empavesarmos": "empavesar",
    "empavesará": "empavesar",
    "empavesarás": "empavesar",
    "empavesarão": "empavesar",
    "empavesaríamos": "empavesar",
    "empavesaríeis": "empavesar",
    "empavesas": "empavesar",
    "empavesasse": "empavesar",
    "empavesassem": "empavesar",
    "empavesasses": "empavesar",
    "empavesaste": "empavesar",
    "empavesastes": "empavesar",
    "empavesava": "empavesar",
    "empavesavam": "empavesar",
    "empavesavas": "empavesar",
    "empavese": "empavesar",
    "empavesei": "empavesar",
    "empaveseis": "empavesar",
    "empavesem": "empavesar",
    "empavesemo": "empavesar",
    "empavesemos": "empavesar",
    "empaveses": "empavesar",
    "empaveso": "empavesar",
    "empavesou": "empavesar",
    "empavesá": "empavesar",
    "empavesámo": "empavesar",
    "empavesámos": "empavesar",
    "empavesáramo": "empavesar",
    "empavesáramos": "empavesar",
    "empavesárei": "empavesar",
    "empavesáreis": "empavesar",
    "empavesásseis": "empavesar",
    "empavesássemos": "empavesar",
    "empavesávamo": "empavesar",
    "empavesávamos": "empavesar",
    "empavesávei": "empavesar",
    "empavesáveis": "empavesar",
    "empaveá": "empavear",
    "empaveámo": "empavear",
    "empaveámos": "empavear",
    "empaveáramo": "empavear",
    "empaveáramos": "empavear",
    "empaveárei": "empavear",
    "empaveáreis": "empavear",
    "empaveásseis": "empavear",
    "empaveássemos": "empavear",
    "empaveávamo": "empavear",
    "empaveávamos": "empavear",
    "empaveávei": "empavear",
    "empaveáveis": "empavear",
    "empavoa": "empavoar",
    "empavoada": "empavoar",
    "empavoadas": "empavoar",
    "empavoado": "empavoar",
    "empavoados": "empavoar",
    "empavoai": "empavoar",
    "empavoais": "empavoar",
    "empavoam": "empavoar",
    "empavoamo": "empavoar",
    "empavoamos": "empavoar",
    "empavoando": "empavoar",
    "empavoara": "empavoar",
    "empavoaram": "empavoar",
    "empavoaras": "empavoar",
    "empavoarde": "empavoar",
    "empavoardes": "empavoar",
    "empavoare": "empavoar",
    "empavoarei": "empavoar",
    "empavoareis": "empavoar",
    "empavoarem": "empavoar",
    "empavoaremos": "empavoar",
    "empavoares": "empavoar",
    "empavoaria": "empavoar",
    "empavoariam": "empavoar",
    "empavoarias": "empavoar",
    "empavoarmo": "empavoar",
    "empavoarmos": "empavoar",
    "empavoará": "empavoar",
    "empavoarás": "empavoar",
    "empavoarão": "empavoar",
    "empavoaríamos": "empavoar",
    "empavoaríeis": "empavoar",
    "empavoas": "empavoar",
    "empavoasse": "empavoar",
    "empavoassem": "empavoar",
    "empavoasses": "empavoar",
    "empavoaste": "empavoar",
    "empavoastes": "empavoar",
    "empavoava": "empavoar",
    "empavoavam": "empavoar",
    "empavoavas": "empavoar",
    "empavoe": "empavoar",
    "empavoei": "empavoar",
    "empavoeis": "empavoar",
    "empavoem": "empavoar",
    "empavoemo": "empavoar",
    "empavoemos": "empavoar",
    "empavoes": "empavoar",
    "empavona": "empavonar",
    "empavonada": "empavonar",
    "empavonadas": "empavonar",
    "empavonado": "empavonar",
    "empavonados": "empavonar",
    "empavonai": "empavonar",
    "empavonais": "empavonar",
    "empavonam": "empavonar",
    "empavonamo": "empavonar",
    "empavonamos": "empavonar",
    "empavonando": "empavonar",
    "empavonara": "empavonar",
    "empavonaram": "empavonar",
    "empavonaras": "empavonar",
    "empavonarde": "empavonar",
    "empavonardes": "empavonar",
    "empavonare": "empavonar",
    "empavonarei": "empavonar",
    "empavonareis": "empavonar",
    "empavonarem": "empavonar",
    "empavonaremos": "empavonar",
    "empavonares": "empavonar",
    "empavonaria": "empavonar",
    "empavonariam": "empavonar",
    "empavonarias": "empavonar",
    "empavonarmo": "empavonar",
    "empavonarmos": "empavonar",
    "empavonará": "empavonar",
    "empavonarás": "empavonar",
    "empavonarão": "empavonar",
    "empavonaríamos": "empavonar",
    "empavonaríeis": "empavonar",
    "empavonas": "empavonar",
    "empavonasse": "empavonar",
    "empavonassem": "empavonar",
    "empavonasses": "empavonar",
    "empavonaste": "empavonar",
    "empavonastes": "empavonar",
    "empavonava": "empavonar",
    "empavonavam": "empavonar",
    "empavonavas": "empavonar",
    "empavone": "empavonar",
    "empavonei": "empavonar",
    "empavoneis": "empavonar",
    "empavonem": "empavonar",
    "empavonemo": "empavonar",
    "empavonemos": "empavonar",
    "empavones": "empavonar",
    "empavono": "empavonar",
    "empavonou": "empavonar",
    "empavoná": "empavonar",
    "empavonámo": "empavonar",
    "empavonámos": "empavonar",
    "empavonáramo": "empavonar",
    "empavonáramos": "empavonar",
    "empavonárei": "empavonar",
    "empavonáreis": "empavonar",
    "empavonásseis": "empavonar",
    "empavonássemos": "empavonar",
    "empavonávamo": "empavonar",
    "empavonávamos": "empavonar",
    "empavonávei": "empavonar",
    "empavonáveis": "empavonar",
    "empavoo": "empavoar",
    "empavoou": "empavoar",
    "empavoá": "empavoar",
    "empavoámo": "empavoar",
    "empavoámos": "empavoar",
    "empavoáramo": "empavoar",
    "empavoáramos": "empavoar",
    "empavoárei": "empavoar",
    "empavoáreis": "empavoar",
    "empavoásseis": "empavoar",
    "empavoássemos": "empavoar",
    "empavoávamo": "empavoar",
    "empavoávamos": "empavoar",
    "empavoávei": "empavoar",
    "empavoáveis": "empavoar",
    "empe": "empar",
    "empecadada": "empecadado",
    "empecadadas": "empecadado",
    "empecadados": "empecadado",
    "empece": "empecer",
    "empecei": "empecer",
    "empeceis": "empecer",
    "empecem": "empecer",
    "empecemo": "empecer",
    "empecemos": "empecer",
    "empecendo": "empecer",
    "empecera": "empecer",
    "empeceram": "empecer",
    "empeceras": "empecer",
    "empecerdes": "empecer",
    "empecerei": "empecer",
    "empecereis": "empecer",
    "empecerem": "empecer",
    "empeceremos": "empecer",
    "empeceres": "empecer",
    "empeceria": "empecer",
    "empeceriam": "empecer",
    "empecerias": "empecer",
    "empecermo": "empecer",
    "empecermos": "empecer",
    "empecerá": "empecer",
    "empecerás": "empecer",
    "empecerão": "empecer",
    "empeceríamos": "empecer",
    "empeceríeis": "empecer",
    "empeces": "empecer",
    "empecesse": "empecer",
    "empecessem": "empecer",
    "empecesses": "empecer",
    "empeceste": "empecer",
    "empecestes": "empecer",
    "empeceu": "empecer",
    "empeci": "empecer",
    "empecia": "empecer",
    "empeciam": "empecer",
    "empecias": "empecer",
    "empecida": "empecer",
    "empecidas": "empecer",
    "empecido": "empecer",
    "empecidos": "empecer",
    "empecilha": "empecilho",
    "empecilhada": "empecilhar",
    "empecilhadas": "empecilhar",
    "empecilhado": "empecilhar",
    "empecilhados": "empecilhar",
    "empecilhai": "empecilhar",
    "empecilhais": "empecilhar",
    "empecilham": "empecilhar",
    "empecilhamo": "empecilhar",
    "empecilhamos": "empecilhar",
    "empecilhando": "empecilhar",
    "empecilhara": "empecilhar",
    "empecilharam": "empecilhar",
    "empecilharas": "empecilhar",
    "empecilharde": "empecilhar",
    "empecilhardes": "empecilhar",
    "empecilhare": "empecilhar",
    "empecilharei": "empecilhar",
    "empecilhareis": "empecilhar",
    "empecilharem": "empecilhar",
    "empecilharemos": "empecilhar",
    "empecilhares": "empecilhar",
    "empecilharia": "empecilhar",
    "empecilhariam": "empecilhar",
    "empecilharias": "empecilhar",
    "empecilharmo": "empecilhar",
    "empecilharmos": "empecilhar",
    "empecilhará": "empecilhar",
    "empecilharás": "empecilhar",
    "empecilharão": "empecilhar",
    "empecilharíamos": "empecilhar",
    "empecilharíeis": "empecilhar",
    "empecilhas": "empecilho",
    "empecilhasse": "empecilhar",
    "empecilhassem": "empecilhar",
    "empecilhasses": "empecilhar",
    "empecilhaste": "empecilhar",
    "empecilhastes": "empecilhar",
    "empecilhava": "empecilhar",
    "empecilhavam": "empecilhar",
    "empecilhavas": "empecilhar",
    "empecilhe": "empecilhar",
    "empecilhei": "empecilhar",
    "empecilheis": "empecilhar",
    "empecilhem": "empecilhar",
    "empecilhemo": "empecilhar",
    "empecilhemos": "empecilhar",
    "empecilhes": "empecilhar",
    "empecilho": "empecilhar",
    "empecilhos": "empecilho",
    "empecilhou": "empecilhar",
    "empecilhá": "empecilhar",
    "empecilhámo": "empecilhar",
    "empecilhámos": "empecilhar",
    "empecilháramo": "empecilhar",
    "empecilháramos": "empecilhar",
    "empecilhárei": "empecilhar",
    "empecilháreis": "empecilhar",
    "empecilhásseis": "empecilhar",
    "empecilhássemos": "empecilhar",
    "empecilhávamo": "empecilhar",
    "empecilhávamos": "empecilhar",
    "empecilhávei": "empecilhar",
    "empecilháveis": "empecilhar",
    "empecimentos": "empecimento",
    "empeciva": "empecivo",
    "empecivas": "empecivo",
    "empecivos": "empecivo",
    "empecêramo": "empecer",
    "empecêramos": "empecer",
    "empecêreis": "empecer",
    "empecêsseis": "empecer",
    "empecêssemos": "empecer",
    "empecíamo": "empecer",
    "empecíamos": "empecer",
    "empecíeis": "empecer",
    "empecíveis": "empecível",
    "empederna": "empedernir",
    "empedernais": "empedernir",
    "empedernam": "empedernir",
    "empedernamo": "empedernir",
    "empedernamos": "empedernir",
    "empedernas": "empedernir",
    "empederne": "empedernir",
    "empedernece": "empedernecer",
    "empedernecei": "empedernecer",
    "empederneceis": "empedernecer",
    "empedernecem": "empedernecer",
    "empedernecemo": "empedernecer",
    "empedernecemos": "empedernecer",
    "empedernecendo": "empedernecer",
    "empedernecera": "empedernecer",
    "empederneceram": "empedernecer",
    "empederneceras": "empedernecer",
    "empedernecerdes": "empedernecer",
    "empedernecerei": "empedernecer",
    "empedernecereis": "empedernecer",
    "empedernecerem": "empedernecer",
    "empederneceremos": "empedernecer",
    "empederneceres": "empedernecer",
    "empederneceria": "empedernecer",
    "empederneceriam": "empedernecer",
    "empedernecerias": "empedernecer",
    "empedernecermo": "empedernecer",
    "empedernecermos": "empedernecer",
    "empedernecerá": "empedernecer",
    "empedernecerás": "empedernecer",
    "empedernecerão": "empedernecer",
    "empederneceríamos": "empedernecer",
    "empederneceríeis": "empedernecer",
    "empederneces": "empedernecer",
    "empedernecesse": "empedernecer",
    "empedernecessem": "empedernecer",
    "empedernecesses": "empedernecer",
    "empederneceste": "empedernecer",
    "empedernecestes": "empedernecer",
    "empederneceu": "empedernecer",
    "empederneci": "empedernecer",
    "empedernecia": "empedernecer",
    "empederneciam": "empedernecer",
    "empedernecias": "empedernecer",
    "empedernecida": "empedernecer",
    "empedernecidas": "empedernecer",
    "empedernecido": "empedernecer",
    "empedernecidos": "empedernecer",
    "empedernecêramo": "empedernecer",
    "empedernecêramos": "empedernecer",
    "empedernecêreis": "empedernecer",
    "empedernecêsseis": "empedernecer",
    "empedernecêssemos": "empedernecer",
    "empedernecíamo": "empedernecer",
    "empedernecíamos": "empedernecer",
    "empedernecíeis": "empedernecer",
    "empedernem": "empedernir",
    "empedernes": "empedernir",
    "empederneça": "empedernecer",
    "empederneçais": "empedernecer",
    "empederneçam": "empedernecer",
    "empederneçamo": "empedernecer",
    "empederneçamos": "empedernecer",
    "empederneças": "empedernecer",
    "empederneço": "empedernecer",
    "empederni": "empedernir",
    "empedernia": "empedernir",
    "empederniam": "empedernir",
    "empedernias": "empedernir",
    "empedernida": "empedernir",
    "empedernidas": "empedernir",
    "empedernido": "empedernir",
    "empedernidos": "empedernir",
    "empedernimentos": "empedernimento",
    "empedernimo": "empedernir",
    "empedernimos": "empedernir",
    "empedernindo": "empedernir",
    "empedernira": "empedernir",
    "empederniram": "empedernir",
    "empederniras": "empedernir",
    "empedernirdes": "empedernir",
    "empedernirei": "empedernir",
    "empedernireis": "empedernir",
    "empedernirem": "empedernir",
    "empederniremos": "empedernir",
    "empedernires": "empedernir",
    "empederniria": "empedernir",
    "empederniriam": "empedernir",
    "empedernirias": "empedernir",
    "empedernirmo": "empedernir",
    "empedernirmos": "empedernir",
    "empedernirá": "empedernir",
    "empedernirás": "empedernir",
    "empedernirão": "empedernir",
    "empederniríamos": "empedernir",
    "empederniríeis": "empedernir",
    "empedernis": "empedernir",
    "empedernisse": "empedernir",
    "empedernissem": "empedernir",
    "empedernisses": "empedernir",
    "empederniste": "empedernir",
    "empedernistes": "empedernir",
    "empederniu": "empedernir",
    "empederno": "empedernir",
    "empederníamo": "empedernir",
    "empederníamos": "empedernir",
    "empederníeis": "empedernir",
    "empederníramo": "empedernir",
    "empederníramos": "empedernir",
    "empederníreis": "empedernir",
    "empedernísseis": "empedernir",
    "empederníssemos": "empedernir",
    "empedra": "empedrar",
    "empedrada": "empedrar",
    "empedradas": "empedrar",
    "empedrado": "empedrar",
    "empedradora": "empedrador",
    "empedradoras": "empedrador",
    "empedradores": "empedrador",
    "empedrados": "empedrar",
    "empedrai": "empedrar",
    "empedrais": "empedrar",
    "empedram": "empedrar",
    "empedramentos": "empedramento",
    "empedramo": "empedrar",
    "empedramos": "empedrar",
    "empedrando": "empedrar",
    "empedrara": "empedrar",
    "empedraram": "empedrar",
    "empedraras": "empedrar",
    "empedrarde": "empedrar",
    "empedrardes": "empedrar",
    "empedrare": "empedrar",
    "empedrarei": "empedrar",
    "empedrareis": "empedrar",
    "empedrarem": "empedrar",
    "empedraremos": "empedrar",
    "empedrares": "empedrar",
    "empedraria": "empedrar",
    "empedrariam": "empedrar",
    "empedrarias": "empedrar",
    "empedrarmo": "empedrar",
    "empedrarmos": "empedrar",
    "empedrará": "empedrar",
    "empedrarás": "empedrar",
    "empedrarão": "empedrar",
    "empedraríamos": "empedrar",
    "empedraríeis": "empedrar",
    "empedras": "empedrar",
    "empedrasse": "empedrar",
    "empedrassem": "empedrar",
    "empedrasses": "empedrar",
    "empedraste": "empedrar",
    "empedrastes": "empedrar",
    "empedrava": "empedrar",
    "empedravam": "empedrar",
    "empedravas": "empedrar",
    "empedre": "empedrar",
    "empedrei": "empedrar",
    "empedreis": "empedrar",
    "empedrem": "empedrar",
    "empedremo": "empedrar",
    "empedremos": "empedrar",
    "empedres": "empedrar",
    "empedro": "empedrar",
    "empedrou": "empedrar",
    "empedrá": "empedrar",
    "empedrámo": "empedrar",
    "empedrámos": "empedrar",
    "empedráramo": "empedrar",
    "empedráramos": "empedrar",
    "empedrárei": "empedrar",
    "empedráreis": "empedrar",
    "empedrásseis": "empedrar",
    "empedrássemos": "empedrar",
    "empedrávamo": "empedrar",
    "empedrávamos": "empedrar",
    "empedrávei": "empedrar",
    "empedráveis": "empedrar",
    "empega": "empegar",
    "empegada": "empegar",
    "empegadas": "empegar",
    "empegado": "empegar",
    "empegados": "empegar",
    "empegai": "empegar",
    "empegais": "empegar",
    "empegam": "empegar",
    "empegamo": "empegar",
    "empegamos": "empegar",
    "empegando": "empegar",
    "empegara": "empegar",
    "empegaram": "empegar",
    "empegaras": "empegar",
    "empegarde": "empegar",
    "empegardes": "empegar",
    "empegare": "empegar",
    "empegarei": "empegar",
    "empegareis": "empegar",
    "empegarem": "empegar",
    "empegaremos": "empegar",
    "empegares": "empegar",
    "empegaria": "empegar",
    "empegariam": "empegar",
    "empegarias": "empegar",
    "empegarmo": "empegar",
    "empegarmos": "empegar",
    "empegará": "empegar",
    "empegarás": "empegar",
    "empegarão": "empegar",
    "empegaríamos": "empegar",
    "empegaríeis": "empegar",
    "empegas": "empegar",
    "empegasse": "empegar",
    "empegassem": "empegar",
    "empegasses": "empegar",
    "empegaste": "empegar",
    "empegastes": "empegar",
    "empegava": "empegar",
    "empegavam": "empegar",
    "empegavas": "empegar",
    "empego": "empegar",
    "empegou": "empegar",
    "empegue": "empegar",
    "empeguei": "empegar",
    "empegueis": "empegar",
    "empeguem": "empegar",
    "empeguemo": "empegar",
    "empeguemos": "empegar",
    "empegues": "empegar",
    "empegá": "empegar",
    "empegámo": "empegar",
    "empegámos": "empegar",
    "empegáramo": "empegar",
    "empegáramos": "empegar",
    "empegárei": "empegar",
    "empegáreis": "empegar",
    "empegásseis": "empegar",
    "empegássemos": "empegar",
    "empegávamo": "empegar",
    "empegávamos": "empegar",
    "empegávei": "empegar",
    "empegáveis": "empegar",
    "empei": "empar",
    "empeis": "empar",
    "empeladoiros": "empeladoiro",
    "empeladouros": "empeladouro",
    "empelama": "empelamar",
    "empelamada": "empelamar",
    "empelamadas": "empelamar",
    "empelamado": "empelamar",
    "empelamados": "empelamar",
    "empelamai": "empelamar",
    "empelamais": "empelamar",
    "empelamam": "empelamar",
    "empelamamo": "empelamar",
    "empelamamos": "empelamar",
    "empelamando": "empelamar",
    "empelamara": "empelamar",
    "empelamaram": "empelamar",
    "empelamaras": "empelamar",
    "empelamarde": "empelamar",
    "empelamardes": "empelamar",
    "empelamare": "empelamar",
    "empelamarei": "empelamar",
    "empelamareis": "empelamar",
    "empelamarem": "empelamar",
    "empelamaremos": "empelamar",
    "empelamares": "empelamar",
    "empelamaria": "empelamar",
    "empelamariam": "empelamar",
    "empelamarias": "empelamar",
    "empelamarmo": "empelamar",
    "empelamarmos": "empelamar",
    "empelamará": "empelamar",
    "empelamarás": "empelamar",
    "empelamarão": "empelamar",
    "empelamaríamos": "empelamar",
    "empelamaríeis": "empelamar",
    "empelamas": "empelamar",
    "empelamasse": "empelamar",
    "empelamassem": "empelamar",
    "empelamasses": "empelamar",
    "empelamaste": "empelamar",
    "empelamastes": "empelamar",
    "empelamava": "empelamar",
    "empelamavam": "empelamar",
    "empelamavas": "empelamar",
    "empelame": "empelamar",
    "empelamei": "empelamar",
    "empelameis": "empelamar",
    "empelamem": "empelamar",
    "empelamemo": "empelamar",
    "empelamemos": "empelamar",
    "empelames": "empelamar",
    "empelamo": "empelamar",
    "empelamou": "empelamar",
    "empelamá": "empelamar",
    "empelamámo": "empelamar",
    "empelamámos": "empelamar",
    "empelamáramo": "empelamar",
    "empelamáramos": "empelamar",
    "empelamárei": "empelamar",
    "empelamáreis": "empelamar",
    "empelamásseis": "empelamar",
    "empelamássemos": "empelamar",
    "empelamávamo": "empelamar",
    "empelamávamos": "empelamar",
    "empelamávei": "empelamar",
    "empelamáveis": "empelamar",
    "empelica": "empelicar",
    "empelicada": "empelicar",
    "empelicadas": "empelicar",
    "empelicado": "empelicar",
    "empelicados": "empelicar",
    "empelicai": "empelicar",
    "empelicais": "empelicar",
    "empelicam": "empelicar",
    "empelicamo": "empelicar",
    "empelicamos": "empelicar",
    "empelicando": "empelicar",
    "empelicara": "empelicar",
    "empelicaram": "empelicar",
    "empelicaras": "empelicar",
    "empelicarde": "empelicar",
    "empelicardes": "empelicar",
    "empelicare": "empelicar",
    "empelicarei": "empelicar",
    "empelicareis": "empelicar",
    "empelicarem": "empelicar",
    "empelicaremos": "empelicar",
    "empelicares": "empelicar",
    "empelicaria": "empelicar",
    "empelicariam": "empelicar",
    "empelicarias": "empelicar",
    "empelicarmo": "empelicar",
    "empelicarmos": "empelicar",
    "empelicará": "empelicar",
    "empelicarás": "empelicar",
    "empelicarão": "empelicar",
    "empelicaríamos": "empelicar",
    "empelicaríeis": "empelicar",
    "empelicas": "empelicar",
    "empelicasse": "empelicar",
    "empelicassem": "empelicar",
    "empelicasses": "empelicar",
    "empelicaste": "empelicar",
    "empelicastes": "empelicar",
    "empelicava": "empelicar",
    "empelicavam": "empelicar",
    "empelicavas": "empelicar",
    "empelico": "empelicar",
    "empelicou": "empelicar",
    "empelicá": "empelicar",
    "empelicámo": "empelicar",
    "empelicámos": "empelicar",
    "empelicáramo": "empelicar",
    "empelicáramos": "empelicar",
    "empelicárei": "empelicar",
    "empelicáreis": "empelicar",
    "empelicásseis": "empelicar",
    "empelicássemos": "empelicar",
    "empelicávamo": "empelicar",
    "empelicávamos": "empelicar",
    "empelicávei": "empelicar",
    "empelicáveis": "empelicar",
    "empelique": "empelicar",
    "empeliquei": "empelicar",
    "empeliqueis": "empelicar",
    "empeliquem": "empelicar",
    "empeliquemo": "empelicar",
    "empeliquemos": "empelicar",
    "empeliques": "empelicar",
    "empelos": "empelo",
    "empelota": "empelotar",
    "empelotada": "empelotar",
    "empelotadas": "empelotar",
    "empelotado": "empelotar",
    "empelotados": "empelotar",
    "empelotai": "empelotar",
    "empelotais": "empelotar",
    "empelotam": "empelotar",
    "empelotamo": "empelotar",
    "empelotamos": "empelotar",
    "empelotando": "empelotar",
    "empelotara": "empelotar",
    "empelotaram": "empelotar",
    "empelotaras": "empelotar",
    "empelotarde": "empelotar",
    "empelotardes": "empelotar",
    "empelotare": "empelotar",
    "empelotarei": "empelotar",
    "empelotareis": "empelotar",
    "empelotarem": "empelotar",
    "empelotaremos": "empelotar",
    "empelotares": "empelotar",
    "empelotaria": "empelotar",
    "empelotariam": "empelotar",
    "empelotarias": "empelotar",
    "empelotarmo": "empelotar",
    "empelotarmos": "empelotar",
    "empelotará": "empelotar",
    "empelotarás": "empelotar",
    "empelotarão": "empelotar",
    "empelotaríamos": "empelotar",
    "empelotaríeis": "empelotar",
    "empelotas": "empelotar",
    "empelotasse": "empelotar",
    "empelotassem": "empelotar",
    "empelotasses": "empelotar",
    "empelotaste": "empelotar",
    "empelotastes": "empelotar",
    "empelotava": "empelotar",
    "empelotavam": "empelotar",
    "empelotavas": "empelotar",
    "empelote": "empelotar",
    "empelotei": "empelotar",
    "empeloteis": "empelotar",
    "empelotem": "empelotar",
    "empelotemo": "empelotar",
    "empelotemos": "empelotar",
    "empelotes": "empelotar",
    "empeloto": "empelotar",
    "empelotou": "empelotar",
    "empelotá": "empelotar",
    "empelotámo": "empelotar",
    "empelotámos": "empelotar",
    "empelotáramo": "empelotar",
    "empelotáramos": "empelotar",
    "empelotárei": "empelotar",
    "empelotáreis": "empelotar",
    "empelotásseis": "empelotar",
    "empelotássemos": "empelotar",
    "empelotávamo": "empelotar",
    "empelotávamos": "empelotar",
    "empelotávei": "empelotar",
    "empelotáveis": "empelotar",
    "empem": "empar",
    "empemo": "empar",
    "empemos": "empar",
    "empena": "empenar",
    "empenacha": "empenachar",
    "empenachada": "empenachar",
    "empenachadas": "empenachar",
    "empenachado": "empenachar",
    "empenachados": "empenachar",
    "empenachai": "empenachar",
    "empenachais": "empenachar",
    "empenacham": "empenachar",
    "empenachamo": "empenachar",
    "empenachamos": "empenachar",
    "empenachando": "empenachar",
    "empenachara": "empenachar",
    "empenacharam": "empenachar",
    "empenacharas": "empenachar",
    "empenacharde": "empenachar",
    "empenachardes": "empenachar",
    "empenachare": "empenachar",
    "empenacharei": "empenachar",
    "empenachareis": "empenachar",
    "empenacharem": "empenachar",
    "empenacharemos": "empenachar",
    "empenachares": "empenachar",
    "empenacharia": "empenachar",
    "empenachariam": "empenachar",
    "empenacharias": "empenachar",
    "empenacharmo": "empenachar",
    "empenacharmos": "empenachar",
    "empenachará": "empenachar",
    "empenacharás": "empenachar",
    "empenacharão": "empenachar",
    "empenacharíamos": "empenachar",
    "empenacharíeis": "empenachar",
    "empenachas": "empenachar",
    "empenachasse": "empenachar",
    "empenachassem": "empenachar",
    "empenachasses": "empenachar",
    "empenachaste": "empenachar",
    "empenachastes": "empenachar",
    "empenachava": "empenachar",
    "empenachavam": "empenachar",
    "empenachavas": "empenachar",
    "empenache": "empenachar",
    "empenachei": "empenachar",
    "empenacheis": "empenachar",
    "empenachem": "empenachar",
    "empenachemo": "empenachar",
    "empenachemos": "empenachar",
    "empenaches": "empenachar",
    "empenacho": "empenachar",
    "empenachou": "empenachar",
    "empenachá": "empenachar",
    "empenachámo": "empenachar",
    "empenachámos": "empenachar",
    "empenacháramo": "empenachar",
    "empenacháramos": "empenachar",
    "empenachárei": "empenachar",
    "empenacháreis": "empenachar",
    "empenachásseis": "empenachar",
    "empenachássemos": "empenachar",
    "empenachávamo": "empenachar",
    "empenachávamos": "empenachar",
    "empenachávei": "empenachar",
    "empenacháveis": "empenachar",
    "empenada": "empenar",
    "empenadas": "empenar",
    "empenado": "empenar",
    "empenados": "empenar",
    "empenagens": "empenagem",
    "empenai": "empenar",
    "empenais": "empenar",
    "empenam": "empenar",
    "empenamentos": "empenamento",
    "empenamo": "empenar",
    "empenamos": "empenar",
    "empenando": "empenar",
    "empenara": "empenar",
    "empenaram": "empenar",
    "empenaras": "empenar",
    "empenarde": "empenar",
    "empenardes": "empenar",
    "empenare": "empenar",
    "empenarei": "empenar",
    "empenareis": "empenar",
    "empenarem": "empenar",
    "empenaremos": "empenar",
    "empenares": "empenar",
    "empenaria": "empenar",
    "empenariam": "empenar",
    "empenarias": "empenar",
    "empenarmo": "empenar",
    "empenarmos": "empenar",
    "empenará": "empenar",
    "empenarás": "empenar",
    "empenarão": "empenar",
    "empenaríamos": "empenar",
    "empenaríeis": "empenar",
    "empenas": "empenar",
    "empenasse": "empenar",
    "empenassem": "empenar",
    "empenasses": "empenar",
    "empenaste": "empenar",
    "empenastes": "empenar",
    "empenava": "empenar",
    "empenavam": "empenar",
    "empenavas": "empenar",
    "empene": "empenar",
    "empenei": "empenar",
    "empeneis": "empenar",
    "empenem": "empenar",
    "empenemo": "empenar",
    "empenemos": "empenar",
    "empenes": "empenar",
    "empenha": "empenhar",
    "empenhada": "empenhar",
    "empenhadas": "empenhar",
    "empenhado": "empenhar",
    "empenhadora": "empenhador",
    "empenhadoras": "empenhador",
    "empenhadores": "empenhador",
    "empenhados": "empenhar",
    "empenhadíssima": "empenhado",
    "empenhadíssimas": "empenhado",
    "empenhadíssimo": "empenhado",
    "empenhadíssimos": "empenhado",
    "empenhai": "empenhar",
    "empenhais": "empenhar",
    "empenham": "empenhar",
    "empenhamentos": "empenhamento",
    "empenhamo": "empenhar",
    "empenhamos": "empenhar",
    "empenhando": "empenhar",
    "empenhara": "empenhar",
    "empenharam": "empenhar",
    "empenharas": "empenhar",
    "empenharde": "empenhar",
    "empenhardes": "empenhar",
    "empenhare": "empenhar",
    "empenharei": "empenhar",
    "empenhareis": "empenhar",
    "empenharem": "empenhar",
    "empenharemos": "empenhar",
    "empenhares": "empenhar",
    "empenharia": "empenhar",
    "empenhariam": "empenhar",
    "empenharias": "empenhar",
    "empenharmo": "empenhar",
    "empenharmos": "empenhar",
    "empenhará": "empenhar",
    "empenharás": "empenhar",
    "empenharão": "empenhar",
    "empenharíamos": "empenhar",
    "empenharíeis": "empenhar",
    "empenhas": "empenhar",
    "empenhasse": "empenhar",
    "empenhassem": "empenhar",
    "empenhasses": "empenhar",
    "empenhaste": "empenhar",
    "empenhastes": "empenhar",
    "empenhava": "empenhar",
    "empenhavam": "empenhar",
    "empenhavas": "empenhar",
    "empenhe": "empenhar",
    "empenhei": "empenhar",
    "empenheis": "empenhar",
    "empenhem": "empenhar",
    "empenhemo": "empenhar",
    "empenhemos": "empenhar",
    "empenhes": "empenhar",
    "empenho": "empenhar",
    "empenhocas": "empenhoca",
    "empenhora": "empenhorar",
    "empenhorada": "empenhorar",
    "empenhoradas": "empenhorar",
    "empenhorado": "empenhorar",
    "empenhorados": "empenhorar",
    "empenhorai": "empenhorar",
    "empenhorais": "empenhorar",
    "empenhoram": "empenhorar",
    "empenhoramo": "empenhorar",
    "empenhoramos": "empenhorar",
    "empenhorando": "empenhorar",
    "empenhorara": "empenhorar",
    "empenhoraram": "empenhorar",
    "empenhoraras": "empenhorar",
    "empenhorarde": "empenhorar",
    "empenhorardes": "empenhorar",
    "empenhorare": "empenhorar",
    "empenhorarei": "empenhorar",
    "empenhorareis": "empenhorar",
    "empenhorarem": "empenhorar",
    "empenhoraremos": "empenhorar",
    "empenhorares": "empenhorar",
    "empenhoraria": "empenhorar",
    "empenhorariam": "empenhorar",
    "empenhorarias": "empenhorar",
    "empenhorarmo": "empenhorar",
    "empenhorarmos": "empenhorar",
    "empenhorará": "empenhorar",
    "empenhorarás": "empenhorar",
    "empenhorarão": "empenhorar",
    "empenhoraríamos": "empenhorar",
    "empenhoraríeis": "empenhorar",
    "empenhoras": "empenhorar",
    "empenhorasse": "empenhorar",
    "empenhorassem": "empenhorar",
    "empenhorasses": "empenhorar",
    "empenhoraste": "empenhorar",
    "empenhorastes": "empenhorar",
    "empenhorava": "empenhorar",
    "empenhoravam": "empenhorar",
    "empenhoravas": "empenhorar",
    "empenhore": "empenhorar",
    "empenhorei": "empenhorar",
    "empenhoreis": "empenhorar",
    "empenhorem": "empenhorar",
    "empenhoremo": "empenhorar",
    "empenhoremos": "empenhorar",
    "empenhores": "empenhorar",
    "empenhoro": "empenhorar",
    "empenhorou": "empenhorar",
    "empenhorá": "empenhorar",
    "empenhorámo": "empenhorar",
    "empenhorámos": "empenhorar",
    "empenhoráramo": "empenhorar",
    "empenhoráramos": "empenhorar",
    "empenhorárei": "empenhorar",
    "empenhoráreis": "empenhorar",
    "empenhorásseis": "empenhorar",
    "empenhorássemos": "empenhorar",
    "empenhorávamo": "empenhorar",
    "empenhorávamos": "empenhorar",
    "empenhorávei": "empenhorar",
    "empenhoráveis": "empenhorar",
    "empenhos": "empenho",
    "empenhou": "empenhar",
    "empenhá": "empenhar",
    "empenhámo": "empenhar",
    "empenhámos": "empenhar",
    "empenháramo": "empenhar",
    "empenháramos": "empenhar",
    "empenhárei": "empenhar",
    "empenháreis": "empenhar",
    "empenhásseis": "empenhar",
    "empenhássemos": "empenhar",
    "empenhávamo": "empenhar",
    "empenhávamos": "empenhar",
    "empenhávei": "empenhar",
    "empenháveis": "empenhável",
    "empeno": "empenar",
    "empenos": "empeno",
    "empenou": "empenar",
    "empená": "empenar",
    "empenámo": "empenar",
    "empenámos": "empenar",
    "empenáramo": "empenar",
    "empenáramos": "empenar",
    "empenárei": "empenar",
    "empenáreis": "empenar",
    "empenásseis": "empenar",
    "empenássemos": "empenar",
    "empenávamo": "empenar",
    "empenávamos": "empenar",
    "empenávei": "empenar",
    "empenáveis": "empenar",
    "empepina": "empepinar",
    "empepinada": "empepinar",
    "empepinadas": "empepinar",
    "empepinado": "empepinar",
    "empepinados": "empepinar",
    "empepinai": "empepinar",
    "empepinais": "empepinar",
    "empepinam": "empepinar",
    "empepinamo": "empepinar",
    "empepinamos": "empepinar",
    "empepinando": "empepinar",
    "empepinara": "empepinar",
    "empepinaram": "empepinar",
    "empepinaras": "empepinar",
    "empepinarde": "empepinar",
    "empepinardes": "empepinar",
    "empepinare": "empepinar",
    "empepinarei": "empepinar",
    "empepinareis": "empepinar",
    "empepinarem": "empepinar",
    "empepinaremos": "empepinar",
    "empepinares": "empepinar",
    "empepinaria": "empepinar",
    "empepinariam": "empepinar",
    "empepinarias": "empepinar",
    "empepinarmo": "empepinar",
    "empepinarmos": "empepinar",
    "empepinará": "empepinar",
    "empepinarás": "empepinar",
    "empepinarão": "empepinar",
    "empepinaríamos": "empepinar",
    "empepinaríeis": "empepinar",
    "empepinas": "empepinar",
    "empepinasse": "empepinar",
    "empepinassem": "empepinar",
    "empepinasses": "empepinar",
    "empepinaste": "empepinar",
    "empepinastes": "empepinar",
    "empepinava": "empepinar",
    "empepinavam": "empepinar",
    "empepinavas": "empepinar",
    "empepine": "empepinar",
    "empepinei": "empepinar",
    "empepineis": "empepinar",
    "empepinem": "empepinar",
    "empepinemo": "empepinar",
    "empepinemos": "empepinar",
    "empepines": "empepinar",
    "empepino": "empepinar",
    "empepinou": "empepinar",
    "empepiná": "empepinar",
    "empepinámo": "empepinar",
    "empepinámos": "empepinar",
    "empepináramo": "empepinar",
    "empepináramos": "empepinar",
    "empepinárei": "empepinar",
    "empepináreis": "empepinar",
    "empepinásseis": "empepinar",
    "empepinássemos": "empepinar",
    "empepinávamo": "empepinar",
    "empepinávamos": "empepinar",
    "empepinávei": "empepinar",
    "empepináveis": "empepinar",
    "empequenece": "empequenecer",
    "empequenecei": "empequenecer",
    "empequeneceis": "empequenecer",
    "empequenecem": "empequenecer",
    "empequenecemo": "empequenecer",
    "empequenecemos": "empequenecer",
    "empequenecendo": "empequenecer",
    "empequenecera": "empequenecer",
    "empequeneceram": "empequenecer",
    "empequeneceras": "empequenecer",
    "empequenecerdes": "empequenecer",
    "empequenecerei": "empequenecer",
    "empequenecereis": "empequenecer",
    "empequenecerem": "empequenecer",
    "empequeneceremos": "empequenecer",
    "empequeneceres": "empequenecer",
    "empequeneceria": "empequenecer",
    "empequeneceriam": "empequenecer",
    "empequenecerias": "empequenecer",
    "empequenecermo": "empequenecer",
    "empequenecermos": "empequenecer",
    "empequenecerá": "empequenecer",
    "empequenecerás": "empequenecer",
    "empequenecerão": "empequenecer",
    "empequeneceríamos": "empequenecer",
    "empequeneceríeis": "empequenecer",
    "empequeneces": "empequenecer",
    "empequenecesse": "empequenecer",
    "empequenecessem": "empequenecer",
    "empequenecesses": "empequenecer",
    "empequeneceste": "empequenecer",
    "empequenecestes": "empequenecer",
    "empequeneceu": "empequenecer",
    "empequeneci": "empequenecer",
    "empequenecia": "empequenecer",
    "empequeneciam": "empequenecer",
    "empequenecias": "empequenecer",
    "empequenecida": "empequenecer",
    "empequenecidas": "empequenecer",
    "empequenecido": "empequenecer",
    "empequenecidos": "empequenecer",
    "empequenecêramo": "empequenecer",
    "empequenecêramos": "empequenecer",
    "empequenecêreis": "empequenecer",
    "empequenecêsseis": "empequenecer",
    "empequenecêssemos": "empequenecer",
    "empequenecíamo": "empequenecer",
    "empequenecíamos": "empequenecer",
    "empequenecíeis": "empequenecer",
    "empequeneça": "empequenecer",
    "empequeneçais": "empequenecer",
    "empequeneçam": "empequenecer",
    "empequeneçamo": "empequenecer",
    "empequeneçamos": "empequenecer",
    "empequeneças": "empequenecer",
    "empequeneço": "empequenecer",
    "empequenita": "empequenitar",
    "empequenitada": "empequenitar",
    "empequenitadas": "empequenitar",
    "empequenitado": "empequenitar",
    "empequenitados": "empequenitar",
    "empequenitai": "empequenitar",
    "empequenitais": "empequenitar",
    "empequenitam": "empequenitar",
    "empequenitamo": "empequenitar",
    "empequenitamos": "empequenitar",
    "empequenitando": "empequenitar",
    "empequenitara": "empequenitar",
    "empequenitaram": "empequenitar",
    "empequenitaras": "empequenitar",
    "empequenitarde": "empequenitar",
    "empequenitardes": "empequenitar",
    "empequenitare": "empequenitar",
    "empequenitarei": "empequenitar",
    "empequenitareis": "empequenitar",
    "empequenitarem": "empequenitar",
    "empequenitaremos": "empequenitar",
    "empequenitares": "empequenitar",
    "empequenitaria": "empequenitar",
    "empequenitariam": "empequenitar",
    "empequenitarias": "empequenitar",
    "empequenitarmo": "empequenitar",
    "empequenitarmos": "empequenitar",
    "empequenitará": "empequenitar",
    "empequenitarás": "empequenitar",
    "empequenitarão": "empequenitar",
    "empequenitaríamos": "empequenitar",
    "empequenitaríeis": "empequenitar",
    "empequenitas": "empequenitar",
    "empequenitasse": "empequenitar",
    "empequenitassem": "empequenitar",
    "empequenitasses": "empequenitar",
    "empequenitaste": "empequenitar",
    "empequenitastes": "empequenitar",
    "empequenitava": "empequenitar",
    "empequenitavam": "empequenitar",
    "empequenitavas": "empequenitar",
    "empequenite": "empequenitar",
    "empequenitei": "empequenitar",
    "empequeniteis": "empequenitar",
    "empequenitem": "empequenitar",
    "empequenitemo": "empequenitar",
    "empequenitemos": "empequenitar",
    "empequenites": "empequenitar",
    "empequenito": "empequenitar",
    "empequenitou": "empequenitar",
    "empequenitá": "empequenitar",
    "empequenitámo": "empequenitar",
    "empequenitámos": "empequenitar",
    "empequenitáramo": "empequenitar",
    "empequenitáramos": "empequenitar",
    "empequenitárei": "empequenitar",
    "empequenitáreis": "empequenitar",
    "empequenitásseis": "empequenitar",
    "empequenitássemos": "empequenitar",
    "empequenitávamo": "empequenitar",
    "empequenitávamos": "empequenitar",
    "empequenitávei": "empequenitar",
    "empequenitáveis": "empequenitar",
    "emperla": "emperlar",
    "emperlada": "emperlar",
    "emperladas": "emperlar",
    "emperlado": "emperlar",
    "emperlados": "emperlar",
    "emperlai": "emperlar",
    "emperlais": "emperlar",
    "emperlam": "emperlar",
    "emperlamo": "emperlar",
    "emperlamos": "emperlar",
    "emperlando": "emperlar",
    "emperlara": "emperlar",
    "emperlaram": "emperlar",
    "emperlaras": "emperlar",
    "emperlarde": "emperlar",
    "emperlardes": "emperlar",
    "emperlare": "emperlar",
    "emperlarei": "emperlar",
    "emperlareis": "emperlar",
    "emperlarem": "emperlar",
    "emperlaremos": "emperlar",
    "emperlares": "emperlar",
    "emperlaria": "emperlar",
    "emperlariam": "emperlar",
    "emperlarias": "emperlar",
    "emperlarmo": "emperlar",
    "emperlarmos": "emperlar",
    "emperlará": "emperlar",
    "emperlarás": "emperlar",
    "emperlarão": "emperlar",
    "emperlaríamos": "emperlar",
    "emperlaríeis": "emperlar",
    "emperlas": "emperlar",
    "emperlasse": "emperlar",
    "emperlassem": "emperlar",
    "emperlasses": "emperlar",
    "emperlaste": "emperlar",
    "emperlastes": "emperlar",
    "emperlava": "emperlar",
    "emperlavam": "emperlar",
    "emperlavas": "emperlar",
    "emperle": "emperlar",
    "emperlei": "emperlar",
    "emperleis": "emperlar",
    "emperlem": "emperlar",
    "emperlemo": "emperlar",
    "emperlemos": "emperlar",
    "emperles": "emperlar",
    "emperlo": "emperlar",
    "emperlou": "emperlar",
    "emperlá": "emperlar",
    "emperlámo": "emperlar",
    "emperlámos": "emperlar",
    "emperláramo": "emperlar",
    "emperláramos": "emperlar",
    "emperlárei": "emperlar",
    "emperláreis": "emperlar",
    "emperlásseis": "emperlar",
    "emperlássemos": "emperlar",
    "emperlávamo": "emperlar",
    "emperlávamos": "emperlar",
    "emperlávei": "emperlar",
    "emperláveis": "emperlar",
    "emperna": "empernar",
    "empernada": "empernar",
    "empernadas": "empernar",
    "empernado": "empernar",
    "empernados": "empernar",
    "empernai": "empernar",
    "empernais": "empernar",
    "empernam": "empernar",
    "empernamentos": "empernamento",
    "empernamo": "empernar",
    "empernamos": "empernar",
    "empernando": "empernar",
    "empernara": "empernar",
    "empernaram": "empernar",
    "empernaras": "empernar",
    "empernardes": "empernar",
    "empernarei": "empernar",
    "empernareis": "empernar",
    "empernarem": "empernar",
    "empernaremos": "empernar",
    "empernares": "empernar",
    "empernaria": "empernar",
    "empernariam": "empernar",
    "empernarias": "empernar",
    "empernarmo": "empernar",
    "empernarmos": "empernar",
    "empernará": "empernar",
    "empernarás": "empernar",
    "empernarão": "empernar",
    "empernaríamos": "empernar",
    "empernaríeis": "empernar",
    "empernas": "empernar",
    "empernasse": "empernar",
    "empernassem": "empernar",
    "empernasses": "empernar",
    "empernaste": "empernar",
    "empernastes": "empernar",
    "empernava": "empernar",
    "empernavam": "empernar",
    "empernavas": "empernar",
    "emperne": "empernar",
    "empernei": "empernar",
    "emperneis": "empernar",
    "empernem": "empernar",
    "empernemo": "empernar",
    "empernemos": "empernar",
    "empernes": "empernar",
    "empernica": "empernicar",
    "empernicada": "empernicar",
    "empernicadas": "empernicar",
    "empernicado": "empernicar",
    "empernicados": "empernicar",
    "empernicai": "empernicar",
    "empernicais": "empernicar",
    "empernicam": "empernicar",
    "empernicamo": "empernicar",
    "empernicamos": "empernicar",
    "empernicando": "empernicar",
    "empernicara": "empernicar",
    "empernicaram": "empernicar",
    "empernicaras": "empernicar",
    "empernicarde": "empernicar",
    "empernicardes": "empernicar",
    "empernicare": "empernicar",
    "empernicarei": "empernicar",
    "empernicareis": "empernicar",
    "empernicarem": "empernicar",
    "empernicaremos": "empernicar",
    "empernicares": "empernicar",
    "empernicaria": "empernicar",
    "empernicariam": "empernicar",
    "empernicarias": "empernicar",
    "empernicarmo": "empernicar",
    "empernicarmos": "empernicar",
    "empernicará": "empernicar",
    "empernicarás": "empernicar",
    "empernicarão": "empernicar",
    "empernicaríamos": "empernicar",
    "empernicaríeis": "empernicar",
    "empernicas": "empernicar",
    "empernicasse": "empernicar",
    "empernicassem": "empernicar",
    "empernicasses": "empernicar",
    "empernicaste": "empernicar",
    "empernicastes": "empernicar",
    "empernicava": "empernicar",
    "empernicavam": "empernicar",
    "empernicavas": "empernicar",
    "empernico": "empernicar",
    "empernicou": "empernicar",
    "empernicá": "empernicar",
    "empernicámo": "empernicar",
    "empernicámos": "empernicar",
    "empernicáramo": "empernicar",
    "empernicáramos": "empernicar",
    "empernicárei": "empernicar",
    "empernicáreis": "empernicar",
    "empernicásseis": "empernicar",
    "empernicássemos": "empernicar",
    "empernicávamo": "empernicar",
    "empernicávamos": "empernicar",
    "empernicávei": "empernicar",
    "empernicáveis": "empernicar",
    "empernique": "empernicar",
    "emperniquei": "empernicar",
    "emperniqueis": "empernicar",
    "emperniquem": "empernicar",
    "emperniquemo": "empernicar",
    "emperniquemos": "empernicar",
    "emperniques": "empernicar",
    "emperno": "empernar",
    "empernou": "empernar",
    "empernámo": "empernar",
    "empernámos": "empernar",
    "empernáramo": "empernar",
    "empernáramos": "empernar",
    "empernáreis": "empernar",
    "empernásseis": "empernar",
    "empernássemos": "empernar",
    "empernávamo": "empernar",
    "empernávamos": "empernar",
    "empernáveis": "empernar",
    "emperra": "emperrar",
    "emperrada": "emperrar",
    "emperradas": "emperrar",
    "emperrado": "emperrar",
    "emperrados": "emperrar",
    "emperrai": "emperrar",
    "emperrais": "emperrar",
    "emperram": "emperrar",
    "emperramentos": "emperramento",
    "emperramo": "emperrar",
    "emperramos": "emperrar",
    "emperrando": "emperrar",
    "emperrara": "emperrar",
    "emperraram": "emperrar",
    "emperraras": "emperrar",
    "emperrarde": "emperrar",
    "emperrardes": "emperrar",
    "emperrare": "emperrar",
    "emperrarei": "emperrar",
    "emperrareis": "emperrar",
    "emperrarem": "emperrar",
    "emperraremos": "emperrar",
    "emperrares": "emperrar",
    "emperraria": "emperrar",
    "emperrariam": "emperrar",
    "emperrarias": "emperrar",
    "emperrarmo": "emperrar",
    "emperrarmos": "emperrar",
    "emperrará": "emperrar",
    "emperrarás": "emperrar",
    "emperrarão": "emperrar",
    "emperraríamos": "emperrar",
    "emperraríeis": "emperrar",
    "emperras": "emperrar",
    "emperrasse": "emperrar",
    "emperrassem": "emperrar",
    "emperrasses": "emperrar",
    "emperraste": "emperrar",
    "emperrastes": "emperrar",
    "emperrava": "emperrar",
    "emperravam": "emperrar",
    "emperravas": "emperrar",
    "emperre": "emperrar",
    "emperrei": "emperrar",
    "emperreis": "emperrar",
    "emperrem": "emperrar",
    "emperremo": "emperrar",
    "emperremos": "emperrar",
    "emperres": "emperrar",
    "emperro": "emperrar",
    "emperros": "emperro",
    "emperrou": "emperrar",
    "emperrá": "emperrar",
    "emperrámo": "emperrar",
    "emperrámos": "emperrar",
    "emperráramo": "emperrar",
    "emperráramos": "emperrar",
    "emperrárei": "emperrar",
    "emperráreis": "emperrar",
    "emperrásseis": "emperrar",
    "emperrássemos": "emperrar",
    "emperrávamo": "emperrar",
    "emperrávamos": "emperrar",
    "emperrávei": "emperrar",
    "emperráveis": "emperrar",
    "empertiga": "empertigar",
    "empertigada": "empertigar",
    "empertigadas": "empertigar",
    "empertigado": "empertigar",
    "empertigados": "empertigar",
    "empertigadota": "empertigadote",
    "empertigadotas": "empertigadote",
    "empertigadotes": "empertigadote",
    "empertigadíssima": "empertigado",
    "empertigadíssimas": "empertigado",
    "empertigadíssimo": "empertigado",
    "empertigadíssimos": "empertigado",
    "empertigai": "empertigar",
    "empertigais": "empertigar",
    "empertigam": "empertigar",
    "empertigamo": "empertigar",
    "empertigamos": "empertigar",
    "empertigando": "empertigar",
    "empertigara": "empertigar",
    "empertigaram": "empertigar",
    "empertigaras": "empertigar",
    "empertigarde": "empertigar",
    "empertigardes": "empertigar",
    "empertigare": "empertigar",
    "empertigarei": "empertigar",
    "empertigareis": "empertigar",
    "empertigarem": "empertigar",
    "empertigaremos": "empertigar",
    "empertigares": "empertigar",
    "empertigaria": "empertigar",
    "empertigariam": "empertigar",
    "empertigarias": "empertigar",
    "empertigarmo": "empertigar",
    "empertigarmos": "empertigar",
    "empertigará": "empertigar",
    "empertigarás": "empertigar",
    "empertigarão": "empertigar",
    "empertigaríamos": "empertigar",
    "empertigaríeis": "empertigar",
    "empertigas": "empertigar",
    "empertigasse": "empertigar",
    "empertigassem": "empertigar",
    "empertigasses": "empertigar",
    "empertigaste": "empertigar",
    "empertigastes": "empertigar",
    "empertigava": "empertigar",
    "empertigavam": "empertigar",
    "empertigavas": "empertigar",
    "empertigo": "empertigar",
    "empertigou": "empertigar",
    "empertigue": "empertigar",
    "empertiguei": "empertigar",
    "empertigueis": "empertigar",
    "empertiguem": "empertigar",
    "empertiguemo": "empertigar",
    "empertiguemos": "empertigar",
    "empertigues": "empertigar",
    "empertigá": "empertigar",
    "empertigámo": "empertigar",
    "empertigámos": "empertigar",
    "empertigáramo": "empertigar",
    "empertigáramos": "empertigar",
    "empertigárei": "empertigar",
    "empertigáreis": "empertigar",
    "empertigásseis": "empertigar",
    "empertigássemos": "empertigar",
    "empertigávamo": "empertigar",
    "empertigávamos": "empertigar",
    "empertigávei": "empertigar",
    "empertigáveis": "empertigar",
    "empes": "empar",
    "empesa": "empesar",
    "empesada": "empesar",
    "empesadas": "empesar",
    "empesado": "empesar",
    "empesados": "empesar",
    "empesaduras": "empesadura",
    "empesai": "empesar",
    "empesais": "empesar",
    "empesam": "empesar",
    "empesamo": "empesar",
    "empesamos": "empesar",
    "empesando": "empesar",
    "empesara": "empesar",
    "empesaram": "empesar",
    "empesaras": "empesar",
    "empesarde": "empesar",
    "empesardes": "empesar",
    "empesare": "empesar",
    "empesarei": "empesar",
    "empesareis": "empesar",
    "empesarem": "empesar",
    "empesaremos": "empesar",
    "empesares": "empesar",
    "empesaria": "empesar",
    "empesariam": "empesar",
    "empesarias": "empesar",
    "empesarmo": "empesar",
    "empesarmos": "empesar",
    "empesará": "empesar",
    "empesarás": "empesar",
    "empesarão": "empesar",
    "empesaríamos": "empesar",
    "empesaríeis": "empesar",
    "empesas": "empesar",
    "empesasse": "empesar",
    "empesassem": "empesar",
    "empesasses": "empesar",
    "empesaste": "empesar",
    "empesastes": "empesar",
    "empesava": "empesar",
    "empesavam": "empesar",
    "empesavas": "empesar",
    "empese": "empesar",
    "empesei": "empesar",
    "empeseis": "empesar",
    "empesem": "empesar",
    "empesemo": "empesar",
    "empesemos": "empesar",
    "empeses": "empesar",
    "empesga": "empesgar",
    "empesgada": "empesgar",
    "empesgadas": "empesgar",
    "empesgado": "empesgar",
    "empesgados": "empesgar",
    "empesgai": "empesgar",
    "empesgais": "empesgar",
    "empesgam": "empesgar",
    "empesgamo": "empesgar",
    "empesgamos": "empesgar",
    "empesgando": "empesgar",
    "empesgara": "empesgar",
    "empesgaram": "empesgar",
    "empesgaras": "empesgar",
    "empesgarde": "empesgar",
    "empesgardes": "empesgar",
    "empesgare": "empesgar",
    "empesgarei": "empesgar",
    "empesgareis": "empesgar",
    "empesgarem": "empesgar",
    "empesgaremos": "empesgar",
    "empesgares": "empesgar",
    "empesgaria": "empesgar",
    "empesgariam": "empesgar",
    "empesgarias": "empesgar",
    "empesgarmo": "empesgar",
    "empesgarmos": "empesgar",
    "empesgará": "empesgar",
    "empesgarás": "empesgar",
    "empesgarão": "empesgar",
    "empesgaríamos": "empesgar",
    "empesgaríeis": "empesgar",
    "empesgas": "empesgar",
    "empesgasse": "empesgar",
    "empesgassem": "empesgar",
    "empesgasses": "empesgar",
    "empesgaste": "empesgar",
    "empesgastes": "empesgar",
    "empesgava": "empesgar",
    "empesgavam": "empesgar",
    "empesgavas": "empesgar",
    "empesgo": "empesgar",
    "empesgou": "empesgar",
    "empesgue": "empesgar",
    "empesguei": "empesgar",
    "empesgueis": "empesgar",
    "empesguem": "empesgar",
    "empesguemo": "empesgar",
    "empesguemos": "empesgar",
    "empesgues": "empesgar",
    "empesgá": "empesgar",
    "empesgámo": "empesgar",
    "empesgámos": "empesgar",
    "empesgáramo": "empesgar",
    "empesgáramos": "empesgar",
    "empesgárei": "empesgar",
    "empesgáreis": "empesgar",
    "empesgásseis": "empesgar",
    "empesgássemos": "empesgar",
    "empesgávamo": "empesgar",
    "empesgávamos": "empesgar",
    "empesgávei": "empesgar",
    "empesgáveis": "empesgar",
    "empeso": "empesar",
    "empesos": "empeso",
    "empesou": "empesar",
    "empesta": "empestar",
    "empestada": "empestar",
    "empestadas": "empestar",
    "empestado": "empestar",
    "empestadora": "empestador",
    "empestadoras": "empestador",
    "empestadores": "empestador",
    "empestados": "empestar",
    "empestadíssima": "empestado",
    "empestadíssimas": "empestado",
    "empestadíssimo": "empestado",
    "empestadíssimos": "empestado",
    "empestai": "empestar",
    "empestais": "empestar",
    "empestam": "empestar",
    "empestamentos": "empestamento",
    "empestamo": "empestar",
    "empestamos": "empestar",
    "empestando": "empestar",
    "empestara": "empestar",
    "empestaram": "empestar",
    "empestaras": "empestar",
    "empestarde": "empestar",
    "empestardes": "empestar",
    "empestare": "empestar",
    "empestarei": "empestar",
    "empestareis": "empestar",
    "empestarem": "empestar",
    "empestaremos": "empestar",
    "empestares": "empestar",
    "empestaria": "empestar",
    "empestariam": "empestar",
    "empestarias": "empestar",
    "empestarmo": "empestar",
    "empestarmos": "empestar",
    "empestará": "empestar",
    "empestarás": "empestar",
    "empestarão": "empestar",
    "empestaríamos": "empestar",
    "empestaríeis": "empestar",
    "empestas": "empestar",
    "empestasse": "empestar",
    "empestassem": "empestar",
    "empestasses": "empestar",
    "empestaste": "empestar",
    "empestastes": "empestar",
    "empestava": "empestar",
    "empestavam": "empestar",
    "empestavas": "empestar",
    "empeste": "empestar",
    "empestei": "empestar",
    "empesteis": "empestar",
    "empestem": "empestar",
    "empestemo": "empestar",
    "empestemos": "empestar",
    "empestes": "empestar",
    "empesto": "empestar",
    "empestou": "empestar",
    "empestá": "empestar",
    "empestámo": "empestar",
    "empestámos": "empestar",
    "empestáramo": "empestar",
    "empestáramos": "empestar",
    "empestárei": "empestar",
    "empestáreis": "empestar",
    "empestásseis": "empestar",
    "empestássemos": "empestar",
    "empestávamo": "empestar",
    "empestávamos": "empestar",
    "empestávei": "empestar",
    "empestáveis": "empestar",
    "empesá": "empesar",
    "empesámo": "empesar",
    "empesámos": "empesar",
    "empesáramo": "empesar",
    "empesáramos": "empesar",
    "empesárei": "empesar",
    "empesáreis": "empesar",
    "empesásseis": "empesar",
    "empesássemos": "empesar",
    "empesávamo": "empesar",
    "empesávamos": "empesar",
    "empesávei": "empesar",
    "empesáveis": "empesar",
    "empetráceas": "empetrácea",
    "empeuga": "empeugar",
    "empeugada": "empeugar",
    "empeugadas": "empeugar",
    "empeugado": "empeugar",
    "empeugados": "empeugar",
    "empeugai": "empeugar",
    "empeugais": "empeugar",
    "empeugam": "empeugar",
    "empeugamo": "empeugar",
    "empeugamos": "empeugar",
    "empeugando": "empeugar",
    "empeugara": "empeugar",
    "empeugaram": "empeugar",
    "empeugaras": "empeugar",
    "empeugarde": "empeugar",
    "empeugardes": "empeugar",
    "empeugare": "empeugar",
    "empeugarei": "empeugar",
    "empeugareis": "empeugar",
    "empeugarem": "empeugar",
    "empeugaremos": "empeugar",
    "empeugares": "empeugar",
    "empeugaria": "empeugar",
    "empeugariam": "empeugar",
    "empeugarias": "empeugar",
    "empeugarmo": "empeugar",
    "empeugarmos": "empeugar",
    "empeugará": "empeugar",
    "empeugarás": "empeugar",
    "empeugarão": "empeugar",
    "empeugaríamos": "empeugar",
    "empeugaríeis": "empeugar",
    "empeugas": "empeugar",
    "empeugasse": "empeugar",
    "empeugassem": "empeugar",
    "empeugasses": "empeugar",
    "empeugaste": "empeugar",
    "empeugastes": "empeugar",
    "empeugava": "empeugar",
    "empeugavam": "empeugar",
    "empeugavas": "empeugar",
    "empeugo": "empeugar",
    "empeugou": "empeugar",
    "empeugue": "empeugar",
    "empeuguei": "empeugar",
    "empeugueis": "empeugar",
    "empeuguem": "empeugar",
    "empeuguemo": "empeugar",
    "empeuguemos": "empeugar",
    "empeugues": "empeugar",
    "empeugá": "empeugar",
    "empeugámo": "empeugar",
    "empeugámos": "empeugar",
    "empeugáramo": "empeugar",
    "empeugáramos": "empeugar",
    "empeugárei": "empeugar",
    "empeugáreis": "empeugar",
    "empeugásseis": "empeugar",
    "empeugássemos": "empeugar",
    "empeugávamo": "empeugar",
    "empeugávamos": "empeugar",
    "empeugávei": "empeugar",
    "empeugáveis": "empeugar",
    "empeza": "empezar",
    "empezada": "empezar",
    "empezadas": "empezar",
    "empezado": "empezar",
    "empezados": "empezar",
    "empezai": "empezar",
    "empezais": "empezar",
    "empezam": "empezar",
    "empezamo": "empezar",
    "empezamos": "empezar",
    "empezando": "empezar",
    "empezara": "empezar",
    "empezaram": "empezar",
    "empezaras": "empezar",
    "empezarde": "empezar",
    "empezardes": "empezar",
    "empezare": "empezar",
    "empezarei": "empezar",
    "empezareis": "empezar",
    "empezarem": "empezar",
    "empezaremos": "empezar",
    "empezares": "empezar",
    "empezaria": "empezar",
    "empezariam": "empezar",
    "empezarias": "empezar",
    "empezarmo": "empezar",
    "empezarmos": "empezar",
    "empezará": "empezar",
    "empezarás": "empezar",
    "empezarão": "empezar",
    "empezaríamos": "empezar",
    "empezaríeis": "empezar",
    "empezas": "empezar",
    "empezasse": "empezar",
    "empezassem": "empezar",
    "empezasses": "empezar",
    "empezaste": "empezar",
    "empezastes": "empezar",
    "empezava": "empezar",
    "empezavam": "empezar",
    "empezavas": "empezar",
    "empeze": "empezar",
    "empezei": "empezar",
    "empezeis": "empezar",
    "empezem": "empezar",
    "empezemo": "empezar",
    "empezemos": "empezar",
    "empezes": "empezar",
    "empezinha": "empezinhar",
    "empezinhada": "empezinhar",
    "empezinhadas": "empezinhar",
    "empezinhado": "empezinhar",
    "empezinhados": "empezinhar",
    "empezinhai": "empezinhar",
    "empezinhais": "empezinhar",
    "empezinham": "empezinhar",
    "empezinhamo": "empezinhar",
    "empezinhamos": "empezinhar",
    "empezinhando": "empezinhar",
    "empezinhara": "empezinhar",
    "empezinharam": "empezinhar",
    "empezinharas": "empezinhar",
    "empezinharde": "empezinhar",
    "empezinhardes": "empezinhar",
    "empezinhare": "empezinhar",
    "empezinharei": "empezinhar",
    "empezinhareis": "empezinhar",
    "empezinharem": "empezinhar",
    "empezinharemos": "empezinhar",
    "empezinhares": "empezinhar",
    "empezinharia": "empezinhar",
    "empezinhariam": "empezinhar",
    "empezinharias": "empezinhar",
    "empezinharmo": "empezinhar",
    "empezinharmos": "empezinhar",
    "empezinhará": "empezinhar",
    "empezinharás": "empezinhar",
    "empezinharão": "empezinhar",
    "empezinharíamos": "empezinhar",
    "empezinharíeis": "empezinhar",
    "empezinhas": "empezinhar",
    "empezinhasse": "empezinhar",
    "empezinhassem": "empezinhar",
    "empezinhasses": "empezinhar",
    "empezinhaste": "empezinhar",
    "empezinhastes": "empezinhar",
    "empezinhava": "empezinhar",
    "empezinhavam": "empezinhar",
    "empezinhavas": "empezinhar",
    "empezinhe": "empezinhar",
    "empezinhei": "empezinhar",
    "empezinheis": "empezinhar",
    "empezinhem": "empezinhar",
    "empezinhemo": "empezinhar",
    "empezinhemos": "empezinhar",
    "empezinhes": "empezinhar",
    "empezinho": "empezinhar",
    "empezinhou": "empezinhar",
    "empezinhá": "empezinhar",
    "empezinhámo": "empezinhar",
    "empezinhámos": "empezinhar",
    "empezinháramo": "empezinhar",
    "empezinháramos": "empezinhar",
    "empezinhárei": "empezinhar",
    "empezinháreis": "empezinhar",
    "empezinhásseis": "empezinhar",
    "empezinhássemos": "empezinhar",
    "empezinhávamo": "empezinhar",
    "empezinhávamos": "empezinhar",
    "empezinhávei": "empezinhar",
    "empezinháveis": "empezinhar",
    "empezo": "empezar",
    "empezou": "empezar",
    "empezá": "empezar",
    "empezámo": "empezar",
    "empezámos": "empezar",
    "empezáramo": "empezar",
    "empezáramos": "empezar",
    "empezárei": "empezar",
    "empezáreis": "empezar",
    "empezásseis": "empezar",
    "empezássemos": "empezar",
    "empezávamo": "empezar",
    "empezávamos": "empezar",
    "empezávei": "empezar",
    "empezáveis": "empezar",
    "empeça": "empecer",
    "empeçada": "empeçar",
    "empeçadas": "empeçar",
    "empeçado": "empeçar",
    "empeçados": "empeçar",
    "empeçai": "empeçar",
    "empeçais": "empecer",
    "empeçam": "empecer",
    "empeçamo": "empecer",
    "empeçamos": "empecer",
    "empeçando": "empeçar",
    "empeçara": "empeçar",
    "empeçaram": "empeçar",
    "empeçaras": "empeçar",
    "empeçarde": "empeçar",
    "empeçardes": "empeçar",
    "empeçare": "empeçar",
    "empeçarei": "empeçar",
    "empeçareis": "empeçar",
    "empeçarem": "empeçar",
    "empeçaremos": "empeçar",
    "empeçares": "empeçar",
    "empeçaria": "empeçar",
    "empeçariam": "empeçar",
    "empeçarias": "empeçar",
    "empeçarmo": "empeçar",
    "empeçarmos": "empeçar",
    "empeçará": "empeçar",
    "empeçarás": "empeçar",
    "empeçarão": "empeçar",
    "empeçaríamos": "empeçar",
    "empeçaríeis": "empeçar",
    "empeças": "empecer",
    "empeçasse": "empeçar",
    "empeçassem": "empeçar",
    "empeçasses": "empeçar",
    "empeçaste": "empeçar",
    "empeçastes": "empeçar",
    "empeçava": "empeçar",
    "empeçavam": "empeçar",
    "empeçavas": "empeçar",
    "empeço": "empecer",
    "empeçonha": "onhar",
    "empeçonhada": "empeçonhar",
    "empeçonhadas": "empeçonhar",
    "empeçonhado": "empeçonhar",
    "empeçonhados": "empeçonhar",
    "empeçonhai": "empeçonhar",
    "empeçonhais": "empeçonhar",
    "empeçonham": "empeçonhar",
    "empeçonhamentos": "empeçonhamento",
    "empeçonhamo": "empeçonhar",
    "empeçonhamos": "empeçonhar",
    "empeçonhando": "empeçonhar",
    "empeçonhar": "onhar",
    "empeçonhara": "onhar",
    "empeçonharam": "onhar",
    "empeçonharas": "empeçonhar",
    "empeçonharde": "empeçonhar",
    "empeçonhardes": "empeçonhar",
    "empeçonhare": "empeçonhar",
    "empeçonharei": "empeçonhar",
    "empeçonhareis": "empeçonhar",
    "empeçonharem": "onhar",
    "empeçonharemos": "empeçonhar",
    "empeçonhares": "empeçonhar",
    "empeçonharia": "onhar",
    "empeçonhariam": "empeçonhar",
    "empeçonharias": "empeçonhar",
    "empeçonharmo": "empeçonhar",
    "empeçonharmos": "empeçonhar",
    "empeçonhará": "empeçonhar",
    "empeçonharás": "empeçonhar",
    "empeçonharão": "empeçonhar",
    "empeçonharíamos": "empeçonhar",
    "empeçonharíeis": "empeçonhar",
    "empeçonhas": "empeçonhar",
    "empeçonhasse": "onhar",
    "empeçonhassem": "empeçonhar",
    "empeçonhasses": "empeçonhar",
    "empeçonhaste": "empeçonhar",
    "empeçonhastes": "empeçonhar",
    "empeçonhava": "onhar",
    "empeçonhavam": "empeçonhar",
    "empeçonhavas": "empeçonhar",
    "empeçonhe": "onhar",
    "empeçonhei": "empeçonhar",
    "empeçonheis": "empeçonhar",
    "empeçonhem": "onhar",
    "empeçonhemo": "empeçonhar",
    "empeçonhemos": "empeçonhar",
    "empeçonhenta": "onhentar",
    "empeçonhentada": "empeçonhentar",
    "empeçonhentadas": "empeçonhentar",
    "empeçonhentado": "empeçonhentar",
    "empeçonhentados": "empeçonhentar",
    "empeçonhentai": "empeçonhentar",
    "empeçonhentais": "empeçonhentar",
    "empeçonhentam": "empeçonhentar",
    "empeçonhentamo": "empeçonhentar",
    "empeçonhentamos": "empeçonhentar",
    "empeçonhentando": "empeçonhentar",
    "empeçonhentar": "onhentar",
    "empeçonhentara": "onhentar",
    "empeçonhentaram": "onhentar",
    "empeçonhentaras": "empeçonhentar",
    "empeçonhentarde": "empeçonhentar",
    "empeçonhentardes": "empeçonhentar",
    "empeçonhentare": "empeçonhentar",
    "empeçonhentarei": "empeçonhentar",
    "empeçonhentareis": "empeçonhentar",
    "empeçonhentarem": "onhentar",
    "empeçonhentaremos": "empeçonhentar",
    "empeçonhentares": "empeçonhentar",
    "empeçonhentaria": "onhentar",
    "empeçonhentariam": "empeçonhentar",
    "empeçonhentarias": "empeçonhentar",
    "empeçonhentarmo": "empeçonhentar",
    "empeçonhentarmos": "empeçonhentar",
    "empeçonhentará": "empeçonhentar",
    "empeçonhentarás": "empeçonhentar",
    "empeçonhentarão": "empeçonhentar",
    "empeçonhentaríamos": "empeçonhentar",
    "empeçonhentaríeis": "empeçonhentar",
    "empeçonhentas": "empeçonhentar",
    "empeçonhentasse": "onhentar",
    "empeçonhentassem": "empeçonhentar",
    "empeçonhentasses": "empeçonhentar",
    "empeçonhentaste": "empeçonhentar",
    "empeçonhentastes": "empeçonhentar",
    "empeçonhentava": "onhentar",
    "empeçonhentavam": "empeçonhentar",
    "empeçonhentavas": "empeçonhentar",
    "empeçonhente": "onhentar",
    "empeçonhentei": "empeçonhentar",
    "empeçonhenteis": "empeçonhentar",
    "empeçonhentem": "onhentar",
    "empeçonhentemo": "empeçonhentar",
    "empeçonhentemos": "empeçonhentar",
    "empeçonhentes": "empeçonhentar",
    "empeçonhento": "empeçonhentar",
    "empeçonhentou": "empeçonhentar",
    "empeçonhentá": "onhentar",
    "empeçonhentámo": "empeçonhentar",
    "empeçonhentámos": "empeçonhentar",
    "empeçonhentáramo": "empeçonhentar",
    "empeçonhentáramos": "empeçonhentar",
    "empeçonhentárei": "empeçonhentar",
    "empeçonhentáreis": "empeçonhentar",
    "empeçonhentásseis": "empeçonhentar",
    "empeçonhentássemos": "empeçonhentar",
    "empeçonhentávamo": "empeçonhentar",
    "empeçonhentávamos": "empeçonhentar",
    "empeçonhentávei": "empeçonhentar",
    "empeçonhentáveis": "empeçonhentar",
    "empeçonhes": "empeçonhar",
    "empeçonho": "empeçonhar",
    "empeçonhou": "empeçonhar",
    "empeçonhá": "onhar",
    "empeçonhámo": "empeçonhar",
    "empeçonhámos": "empeçonhar",
    "empeçonháramo": "empeçonhar",
    "empeçonháramos": "empeçonhar",
    "empeçonhárei": "empeçonhar",
    "empeçonháreis": "empeçonhar",
    "empeçonhásseis": "empeçonhar",
    "empeçonhássemos": "empeçonhar",
    "empeçonhávamo": "empeçonhar",
    "empeçonhávamos": "empeçonhar",
    "empeçonhávei": "empeçonhar",
    "empeçonháveis": "empeçonhar",
    "empeços": "empeço",
    "empeçou": "empeçar",
    "empeçá": "empeçar",
    "empeçámo": "empeçar",
    "empeçámos": "empeçar",
    "empeçáramo": "empeçar",
    "empeçáramos": "empeçar",
    "empeçárei": "empeçar",
    "empeçáreis": "empeçar",
    "empeçásseis": "empeçar",
    "empeçássemos": "empeçar",
    "empeçávamo": "empeçar",
    "empeçávamos": "empeçar",
    "empeçávei": "empeçar",
    "empeçáveis": "empeçar",
    "empicota": "empicotar",
    "empicotada": "empicotar",
    "empicotadas": "empicotar",
    "empicotado": "empicotar",
    "empicotados": "empicotar",
    "empicotai": "empicotar",
    "empicotais": "empicotar",
    "empicotam": "empicotar",
    "empicotamentos": "empicotamento",
    "empicotamo": "empicotar",
    "empicotamos": "empicotar",
    "empicotando": "empicotar",
    "empicotara": "empicotar",
    "empicotaram": "empicotar",
    "empicotaras": "empicotar",
    "empicotarde": "empicotar",
    "empicotardes": "empicotar",
    "empicotare": "empicotar",
    "empicotarei": "empicotar",
    "empicotareis": "empicotar",
    "empicotarem": "empicotar",
    "empicotaremos": "empicotar",
    "empicotares": "empicotar",
    "empicotaria": "empicotar",
    "empicotariam": "empicotar",
    "empicotarias": "empicotar",
    "empicotarmo": "empicotar",
    "empicotarmos": "empicotar",
    "empicotará": "empicotar",
    "empicotarás": "empicotar",
    "empicotarão": "empicotar",
    "empicotaríamos": "empicotar",
    "empicotaríeis": "empicotar",
    "empicotas": "empicotar",
    "empicotasse": "empicotar",
    "empicotassem": "empicotar",
    "empicotasses": "empicotar",
    "empicotaste": "empicotar",
    "empicotastes": "empicotar",
    "empicotava": "empicotar",
    "empicotavam": "empicotar",
    "empicotavas": "empicotar",
    "empicote": "empicotar",
    "empicotei": "empicotar",
    "empicoteis": "empicotar",
    "empicotem": "empicotar",
    "empicotemo": "empicotar",
    "empicotemos": "empicotar",
    "empicotes": "empicotar",
    "empicoto": "empicotar",
    "empicotou": "empicotar",
    "empicotá": "empicotar",
    "empicotámo": "empicotar",
    "empicotámos": "empicotar",
    "empicotáramo": "empicotar",
    "empicotáramos": "empicotar",
    "empicotárei": "empicotar",
    "empicotáreis": "empicotar",
    "empicotásseis": "empicotar",
    "empicotássemos": "empicotar",
    "empicotávamo": "empicotar",
    "empicotávamos": "empicotar",
    "empicotávei": "empicotar",
    "empicotáveis": "empicotar",
    "empiemas": "empiema",
    "empilha": "empilhar",
    "empilhada": "empilhar",
    "empilhadas": "empilhar",
    "empilhadeiras": "empilhadeira",
    "empilhado": "empilhar",
    "empilhadoras": "empilhadora",
    "empilhados": "empilhar",
    "empilhai": "empilhar",
    "empilhais": "empilhar",
    "empilham": "empilhar",
    "empilhamentos": "empilhamento",
    "empilhamo": "empilhar",
    "empilhamos": "empilhar",
    "empilhando": "empilhar",
    "empilhara": "empilhar",
    "empilharam": "empilhar",
    "empilharas": "empilhar",
    "empilharde": "empilhar",
    "empilhardes": "empilhar",
    "empilhare": "empilhar",
    "empilharei": "empilhar",
    "empilhareis": "empilhar",
    "empilharem": "empilhar",
    "empilharemos": "empilhar",
    "empilhares": "empilhar",
    "empilharia": "empilhar",
    "empilhariam": "empilhar",
    "empilharias": "empilhar",
    "empilharmo": "empilhar",
    "empilharmos": "empilhar",
    "empilhará": "empilhar",
    "empilharás": "empilhar",
    "empilharão": "empilhar",
    "empilharíamos": "empilhar",
    "empilharíeis": "empilhar",
    "empilhas": "empilhar",
    "empilhasse": "empilhar",
    "empilhassem": "empilhar",
    "empilhasses": "empilhar",
    "empilhaste": "empilhar",
    "empilhastes": "empilhar",
    "empilhava": "empilhar",
    "empilhavam": "empilhar",
    "empilhavas": "empilhar",
    "empilhe": "empilhar",
    "empilhei": "empilhar",
    "empilheis": "empilhar",
    "empilhem": "empilhar",
    "empilhemo": "empilhar",
    "empilhemos": "empilhar",
    "empilhes": "empilhar",
    "empilho": "empilhar",
    "empilhou": "empilhar",
    "empilhá": "empilhar",
    "empilhámo": "empilhar",
    "empilhámos": "empilhar",
    "empilháramo": "empilhar",
    "empilháramos": "empilhar",
    "empilhárei": "empilhar",
    "empilháreis": "empilhar",
    "empilhásseis": "empilhar",
    "empilhássemos": "empilhar",
    "empilhávamo": "empilhar",
    "empilhávamos": "empilhar",
    "empilhávei": "empilhar",
    "empilháveis": "empilhável",
    "empina": "empinar",
    "empinada": "empinar",
    "empinadas": "empinar",
    "empinadelas": "empinadela",
    "empinado": "empinar",
    "empinados": "empinar",
    "empinai": "empinar",
    "empinais": "empinar",
    "empinam": "empinar",
    "empinamo": "empinar",
    "empinamos": "empinar",
    "empinando": "empinar",
    "empinanços": "empinanço",
    "empinara": "empinar",
    "empinaram": "empinar",
    "empinaras": "empinar",
    "empinarde": "empinar",
    "empinardes": "empinar",
    "empinare": "empinar",
    "empinarei": "empinar",
    "empinareis": "empinar",
    "empinarem": "empinar",
    "empinaremos": "empinar",
    "empinares": "empinar",
    "empinaria": "empinar",
    "empinariam": "empinar",
    "empinarias": "empinar",
    "empinarmo": "empinar",
    "empinarmos": "empinar",
    "empinará": "empinar",
    "empinarás": "empinar",
    "empinarão": "empinar",
    "empinaríamos": "empinar",
    "empinaríeis": "empinar",
    "empinas": "empinar",
    "empinasse": "empinar",
    "empinassem": "empinar",
    "empinasses": "empinar",
    "empinaste": "empinar",
    "empinastes": "empinar",
    "empinava": "empinar",
    "empinavam": "empinar",
    "empinavas": "empinar",
    "empine": "empinar",
    "empinei": "empinar",
    "empineis": "empinar",
    "empinem": "empinar",
    "empinemo": "empinar",
    "empinemos": "empinar",
    "empines": "empinar",
    "empinhoca": "empinhocar",
    "empinhocada": "empinhocar",
    "empinhocadas": "empinhocar",
    "empinhocado": "empinhocar",
    "empinhocados": "empinhocar",
    "empinhocai": "empinhocar",
    "empinhocais": "empinhocar",
    "empinhocam": "empinhocar",
    "empinhocamo": "empinhocar",
    "empinhocamos": "empinhocar",
    "empinhocando": "empinhocar",
    "empinhocara": "empinhocar",
    "empinhocaram": "empinhocar",
    "empinhocaras": "empinhocar",
    "empinhocarde": "empinhocar",
    "empinhocardes": "empinhocar",
    "empinhocare": "empinhocar",
    "empinhocarei": "empinhocar",
    "empinhocareis": "empinhocar",
    "empinhocarem": "empinhocar",
    "empinhocaremos": "empinhocar",
    "empinhocares": "empinhocar",
    "empinhocaria": "empinhocar",
    "empinhocariam": "empinhocar",
    "empinhocarias": "empinhocar",
    "empinhocarmo": "empinhocar",
    "empinhocarmos": "empinhocar",
    "empinhocará": "empinhocar",
    "empinhocarás": "empinhocar",
    "empinhocarão": "empinhocar",
    "empinhocaríamos": "empinhocar",
    "empinhocaríeis": "empinhocar",
    "empinhocas": "empinhocar",
    "empinhocasse": "empinhocar",
    "empinhocassem": "empinhocar",
    "empinhocasses": "empinhocar",
    "empinhocaste": "empinhocar",
    "empinhocastes": "empinhocar",
    "empinhocava": "empinhocar",
    "empinhocavam": "empinhocar",
    "empinhocavas": "empinhocar",
    "empinhoco": "empinhocar",
    "empinhocou": "empinhocar",
    "empinhocá": "empinhocar",
    "empinhocámo": "empinhocar",
    "empinhocámos": "empinhocar",
    "empinhocáramo": "empinhocar",
    "empinhocáramos": "empinhocar",
    "empinhocárei": "empinhocar",
    "empinhocáreis": "empinhocar",
    "empinhocásseis": "empinhocar",
    "empinhocássemos": "empinhocar",
    "empinhocávamo": "empinhocar",
    "empinhocávamos": "empinhocar",
    "empinhocávei": "empinhocar",
    "empinhocáveis": "empinhocar",
    "empinhoque": "empinhocar",
    "empinhoquei": "empinhocar",
    "empinhoqueis": "empinhocar",
    "empinhoquem": "empinhocar",
    "empinhoquemo": "empinhocar",
    "empinhoquemos": "empinhocar",
    "empinhoques": "empinhocar",
    "empino": "empinar",
    "empinoca": "empinocar",
    "empinocada": "empinocar",
    "empinocadas": "empinocar",
    "empinocado": "empinocar",
    "empinocados": "empinocar",
    "empinocai": "empinocar",
    "empinocais": "empinocar",
    "empinocam": "empinocar",
    "empinocamo": "empinocar",
    "empinocamos": "empinocar",
    "empinocando": "empinocar",
    "empinocara": "empinocar",
    "empinocaram": "empinocar",
    "empinocaras": "empinocar",
    "empinocarde": "empinocar",
    "empinocardes": "empinocar",
    "empinocare": "empinocar",
    "empinocarei": "empinocar",
    "empinocareis": "empinocar",
    "empinocarem": "empinocar",
    "empinocaremos": "empinocar",
    "empinocares": "empinocar",
    "empinocaria": "empinocar",
    "empinocariam": "empinocar",
    "empinocarias": "empinocar",
    "empinocarmo": "empinocar",
    "empinocarmos": "empinocar",
    "empinocará": "empinocar",
    "empinocarás": "empinocar",
    "empinocarão": "empinocar",
    "empinocaríamos": "empinocar",
    "empinocaríeis": "empinocar",
    "empinocas": "empinocar",
    "empinocasse": "empinocar",
    "empinocassem": "empinocar",
    "empinocasses": "empinocar",
    "empinocaste": "empinocar",
    "empinocastes": "empinocar",
    "empinocava": "empinocar",
    "empinocavam": "empinocar",
    "empinocavas": "empinocar",
    "empinoco": "empinocar",
    "empinocou": "empinocar",
    "empinocá": "empinocar",
    "empinocámo": "empinocar",
    "empinocámos": "empinocar",
    "empinocáramo": "empinocar",
    "empinocáramos": "empinocar",
    "empinocárei": "empinocar",
    "empinocáreis": "empinocar",
    "empinocásseis": "empinocar",
    "empinocássemos": "empinocar",
    "empinocávamo": "empinocar",
    "empinocávamos": "empinocar",
    "empinocávei": "empinocar",
    "empinocáveis": "empinocar",
    "empinoque": "empinocar",
    "empinoquei": "empinocar",
    "empinoqueis": "empinocar",
    "empinoquem": "empinocar",
    "empinoquemo": "empinocar",
    "empinoquemos": "empinocar",
    "empinoques": "empinocar",
    "empinos": "empino",
    "empinou": "empinar",
    "empiná": "empinar",
    "empinámo": "empinar",
    "empinámos": "empinar",
    "empináramo": "empinar",
    "empináramos": "empinar",
    "empinárei": "empinar",
    "empináreis": "empinar",
    "empinásseis": "empinar",
    "empinássemos": "empinar",
    "empinávamo": "empinar",
    "empinávamos": "empinar",
    "empinávei": "empinar",
    "empináveis": "empinar",
    "empiora": "empiorar",
    "empiorada": "empiorar",
    "empioradas": "empiorar",
    "empiorado": "empiorar",
    "empiorados": "empiorar",
    "empiorai": "empiorar",
    "empiorais": "empiorar",
    "empioram": "empiorar",
    "empioramo": "empiorar",
    "empioramos": "empiorar",
    "empiorando": "empiorar",
    "empiorara": "empiorar",
    "empioraram": "empiorar",
    "empioraras": "empiorar",
    "empiorarde": "empiorar",
    "empiorardes": "empiorar",
    "empiorare": "empiorar",
    "empiorarei": "empiorar",
    "empiorareis": "empiorar",
    "empiorarem": "empiorar",
    "empioraremos": "empiorar",
    "empiorares": "empiorar",
    "empioraria": "empiorar",
    "empiorariam": "empiorar",
    "empiorarias": "empiorar",
    "empiorarmo": "empiorar",
    "empiorarmos": "empiorar",
    "empiorará": "empiorar",
    "empiorarás": "empiorar",
    "empiorarão": "empiorar",
    "empioraríamos": "empiorar",
    "empioraríeis": "empiorar",
    "empioras": "empiorar",
    "empiorasse": "empiorar",
    "empiorassem": "empiorar",
    "empiorasses": "empiorar",
    "empioraste": "empiorar",
    "empiorastes": "empiorar",
    "empiorava": "empiorar",
    "empioravam": "empiorar",
    "empioravas": "empiorar",
    "empiore": "empiorar",
    "empiorei": "empiorar",
    "empioreis": "empiorar",
    "empiorem": "empiorar",
    "empioremo": "empiorar",
    "empioremos": "empiorar",
    "empiores": "empiorar",
    "empioro": "empiorar",
    "empiorou": "empiorar",
    "empiorá": "empiorar",
    "empiorámo": "empiorar",
    "empiorámos": "empiorar",
    "empioráramo": "empiorar",
    "empioráramos": "empiorar",
    "empiorárei": "empiorar",
    "empioráreis": "empiorar",
    "empiorásseis": "empiorar",
    "empiorássemos": "empiorar",
    "empiorávamo": "empiorar",
    "empiorávamos": "empiorar",
    "empiorávei": "empiorar",
    "empioráveis": "empiorar",
    "empipa": "empipar",
    "empipada": "empipar",
    "empipadas": "empipar",
    "empipado": "empipar",
    "empipados": "empipar",
    "empipai": "empipar",
    "empipais": "empipar",
    "empipam": "empipar",
    "empipamo": "empipar",
    "empipamos": "empipar",
    "empipando": "empipar",
    "empipara": "empipar",
    "empiparam": "empipar",
    "empiparas": "empipar",
    "empiparde": "empipar",
    "empipardes": "empipar",
    "empipare": "empipar",
    "empiparei": "empipar",
    "empipareis": "empipar",
    "empiparem": "empipar",
    "empiparemos": "empipar",
    "empipares": "empipar",
    "empiparia": "empipar",
    "empipariam": "empipar",
    "empiparias": "empipar",
    "empiparmo": "empipar",
    "empiparmos": "empipar",
    "empipará": "empipar",
    "empiparás": "empipar",
    "empiparão": "empipar",
    "empiparíamos": "empipar",
    "empiparíeis": "empipar",
    "empipas": "empipar",
    "empipasse": "empipar",
    "empipassem": "empipar",
    "empipasses": "empipar",
    "empipaste": "empipar",
    "empipastes": "empipar",
    "empipava": "empipar",
    "empipavam": "empipar",
    "empipavas": "empipar",
    "empipe": "empipar",
    "empipei": "empipar",
    "empipeis": "empipar",
    "empipem": "empipar",
    "empipemo": "empipar",
    "empipemos": "empipar",
    "empipes": "empipar",
    "empipo": "empipar",
    "empipou": "empipar",
    "empipá": "empipar",
    "empipámo": "empipar",
    "empipámos": "empipar",
    "empipáramo": "empipar",
    "empipáramos": "empipar",
    "empipárei": "empipar",
    "empipáreis": "empipar",
    "empipásseis": "empipar",
    "empipássemos": "empipar",
    "empipávamo": "empipar",
    "empipávamos": "empipar",
    "empipávei": "empipar",
    "empipáveis": "empipar",
    "empireumas": "empireuma",
    "empireumática": "empireumático",
    "empireumáticas": "empireumático",
    "empireumáticos": "empireumático",
    "empirismos": "empirismo",
    "empiristas": "empirista",
    "empisca": "empiscar",
    "empiscada": "empiscar",
    "empiscadas": "empiscar",
    "empiscado": "empiscar",
    "empiscados": "empiscar",
    "empiscai": "empiscar",
    "empiscais": "empiscar",
    "empiscam": "empiscar",
    "empiscamo": "empiscar",
    "empiscamos": "empiscar",
    "empiscando": "empiscar",
    "empiscara": "empiscar",
    "empiscaram": "empiscar",
    "empiscaras": "empiscar",
    "empiscarde": "empiscar",
    "empiscardes": "empiscar",
    "empiscare": "empiscar",
    "empiscarei": "empiscar",
    "empiscareis": "empiscar",
    "empiscarem": "empiscar",
    "empiscaremos": "empiscar",
    "empiscares": "empiscar",
    "empiscaria": "empiscar",
    "empiscariam": "empiscar",
    "empiscarias": "empiscar",
    "empiscarmo": "empiscar",
    "empiscarmos": "empiscar",
    "empiscará": "empiscar",
    "empiscarás": "empiscar",
    "empiscarão": "empiscar",
    "empiscaríamos": "empiscar",
    "empiscaríeis": "empiscar",
    "empiscas": "empiscar",
    "empiscasse": "empiscar",
    "empiscassem": "empiscar",
    "empiscasses": "empiscar",
    "empiscaste": "empiscar",
    "empiscastes": "empiscar",
    "empiscava": "empiscar",
    "empiscavam": "empiscar",
    "empiscavas": "empiscar",
    "empisco": "empiscar",
    "empiscou": "empiscar",
    "empiscá": "empiscar",
    "empiscámo": "empiscar",
    "empiscámos": "empiscar",
    "empiscáramo": "empiscar",
    "empiscáramos": "empiscar",
    "empiscárei": "empiscar",
    "empiscáreis": "empiscar",
    "empiscásseis": "empiscar",
    "empiscássemos": "empiscar",
    "empiscávamo": "empiscar",
    "empiscávamos": "empiscar",
    "empiscávei": "empiscar",
    "empiscáveis": "empiscar",
    "empisque": "empiscar",
    "empisquei": "empiscar",
    "empisqueis": "empiscar",
    "empisquem": "empiscar",
    "empisquemo": "empiscar",
    "empisquemos": "empiscar",
    "empisques": "empiscar",
    "empiteira": "empiteirar",
    "empiteirada": "empiteirar",
    "empiteiradas": "empiteirar",
    "empiteirado": "empiteirar",
    "empiteirados": "empiteirar",
    "empiteirai": "empiteirar",
    "empiteirais": "empiteirar",
    "empiteiram": "empiteirar",
    "empiteiramo": "empiteirar",
    "empiteiramos": "empiteirar",
    "empiteirando": "empiteirar",
    "empiteirara": "empiteirar",
    "empiteiraram": "empiteirar",
    "empiteiraras": "empiteirar",
    "empiteirarde": "empiteirar",
    "empiteirardes": "empiteirar",
    "empiteirare": "empiteirar",
    "empiteirarei": "empiteirar",
    "empiteirareis": "empiteirar",
    "empiteirarem": "empiteirar",
    "empiteiraremos": "empiteirar",
    "empiteirares": "empiteirar",
    "empiteiraria": "empiteirar",
    "empiteirariam": "empiteirar",
    "empiteirarias": "empiteirar",
    "empiteirarmo": "empiteirar",
    "empiteirarmos": "empiteirar",
    "empiteirará": "empiteirar",
    "empiteirarás": "empiteirar",
    "empiteirarão": "empiteirar",
    "empiteiraríamos": "empiteirar",
    "empiteiraríeis": "empiteirar",
    "empiteiras": "empiteirar",
    "empiteirasse": "empiteirar",
    "empiteirassem": "empiteirar",
    "empiteirasses": "empiteirar",
    "empiteiraste": "empiteirar",
    "empiteirastes": "empiteirar",
    "empiteirava": "empiteirar",
    "empiteiravam": "empiteirar",
    "empiteiravas": "empiteirar",
    "empiteire": "empiteirar",
    "empiteirei": "empiteirar",
    "empiteireis": "empiteirar",
    "empiteirem": "empiteirar",
    "empiteiremo": "empiteirar",
    "empiteiremos": "empiteirar",
    "empiteires": "empiteirar",
    "empiteiro": "empiteirar",
    "empiteirou": "empiteirar",
    "empiteirá": "empiteirar",
    "empiteirámo": "empiteirar",
    "empiteirámos": "empiteirar",
    "empiteiráramo": "empiteirar",
    "empiteiráramos": "empiteirar",
    "empiteirárei": "empiteirar",
    "empiteiráreis": "empiteirar",
    "empiteirásseis": "empiteirar",
    "empiteirássemos": "empiteirar",
    "empiteirávamo": "empiteirar",
    "empiteirávamos": "empiteirar",
    "empiteirávei": "empiteirar",
    "empiteiráveis": "empiteirar",
    "empitosgada": "empitosgado",
    "empitosgadas": "empitosgado",
    "empitosgados": "empitosgado",
    "emplasma": "emplasmar",
    "emplasmada": "emplasmar",
    "emplasmadas": "emplasmar",
    "emplasmado": "emplasmar",
    "emplasmados": "emplasmar",
    "emplasmai": "emplasmar",
    "emplasmais": "emplasmar",
    "emplasmam": "emplasmar",
    "emplasmamo": "emplasmar",
    "emplasmamos": "emplasmar",
    "emplasmando": "emplasmar",
    "emplasmara": "emplasmar",
    "emplasmaram": "emplasmar",
    "emplasmaras": "emplasmar",
    "emplasmarde": "emplasmar",
    "emplasmardes": "emplasmar",
    "emplasmare": "emplasmar",
    "emplasmarei": "emplasmar",
    "emplasmareis": "emplasmar",
    "emplasmarem": "emplasmar",
    "emplasmaremos": "emplasmar",
    "emplasmares": "emplasmar",
    "emplasmaria": "emplasmar",
    "emplasmariam": "emplasmar",
    "emplasmarias": "emplasmar",
    "emplasmarmo": "emplasmar",
    "emplasmarmos": "emplasmar",
    "emplasmará": "emplasmar",
    "emplasmarás": "emplasmar",
    "emplasmarão": "emplasmar",
    "emplasmaríamos": "emplasmar",
    "emplasmaríeis": "emplasmar",
    "emplasmas": "emplasmar",
    "emplasmasse": "emplasmar",
    "emplasmassem": "emplasmar",
    "emplasmasses": "emplasmar",
    "emplasmaste": "emplasmar",
    "emplasmastes": "emplasmar",
    "emplasmava": "emplasmar",
    "emplasmavam": "emplasmar",
    "emplasmavas": "emplasmar",
    "emplasme": "emplasmar",
    "emplasmei": "emplasmar",
    "emplasmeis": "emplasmar",
    "emplasmem": "emplasmar",
    "emplasmemo": "emplasmar",
    "emplasmemos": "emplasmar",
    "emplasmes": "emplasmar",
    "emplasmo": "emplasmar",
    "emplasmou": "emplasmar",
    "emplasmá": "emplasmar",
    "emplasmámo": "emplasmar",
    "emplasmámos": "emplasmar",
    "emplasmáramo": "emplasmar",
    "emplasmáramos": "emplasmar",
    "emplasmárei": "emplasmar",
    "emplasmáreis": "emplasmar",
    "emplasmásseis": "emplasmar",
    "emplasmássemos": "emplasmar",
    "emplasmávamo": "emplasmar",
    "emplasmávamos": "emplasmar",
    "emplasmávei": "emplasmar",
    "emplasmáveis": "emplasmar",
    "emplasta": "emplastar",
    "emplastada": "emplastar",
    "emplastadas": "emplastar",
    "emplastado": "emplastar",
    "emplastados": "emplastar",
    "emplastagens": "emplastagem",
    "emplastai": "emplastar",
    "emplastais": "emplastar",
    "emplastam": "emplastar",
    "emplastamo": "emplastar",
    "emplastamos": "emplastar",
    "emplastando": "emplastar",
    "emplastara": "emplastar",
    "emplastaram": "emplastar",
    "emplastaras": "emplastar",
    "emplastarde": "emplastar",
    "emplastardes": "emplastar",
    "emplastare": "emplastar",
    "emplastarei": "emplastar",
    "emplastareis": "emplastar",
    "emplastarem": "emplastar",
    "emplastaremos": "emplastar",
    "emplastares": "emplastar",
    "emplastaria": "emplastar",
    "emplastariam": "emplastar",
    "emplastarias": "emplastar",
    "emplastarmo": "emplastar",
    "emplastarmos": "emplastar",
    "emplastará": "emplastar",
    "emplastarás": "emplastar",
    "emplastarão": "emplastar",
    "emplastaríamos": "emplastar",
    "emplastaríeis": "emplastar",
    "emplastas": "emplastar",
    "emplastasse": "emplastar",
    "emplastassem": "emplastar",
    "emplastasses": "emplastar",
    "emplastaste": "emplastar",
    "emplastastes": "emplastar",
    "emplastava": "emplastar",
    "emplastavam": "emplastar",
    "emplastavas": "emplastar",
    "emplastações": "emplastação",
    "emplaste": "emplastar",
    "emplastei": "emplastar",
    "emplasteis": "emplastar",
    "emplastem": "emplastar",
    "emplastemo": "emplastar",
    "emplastemos": "emplastar",
    "emplastes": "emplastar",
    "emplasto": "emplastar",
    "emplastos": "emplasto",
    "emplastou": "emplastar",
    "emplastra": "emplastrar",
    "emplastrada": "emplastrar",
    "emplastradas": "emplastrar",
    "emplastrado": "emplastrar",
    "emplastrados": "emplastrar",
    "emplastragens": "emplastragem",
    "emplastrai": "emplastrar",
    "emplastrais": "emplastrar",
    "emplastram": "emplastrar",
    "emplastramentos": "emplastramento",
    "emplastramo": "emplastrar",
    "emplastramos": "emplastrar",
    "emplastrando": "emplastrar",
    "emplastrara": "emplastrar",
    "emplastraram": "emplastrar",
    "emplastraras": "emplastrar",
    "emplastrarde": "emplastrar",
    "emplastrardes": "emplastrar",
    "emplastrare": "emplastrar",
    "emplastrarei": "emplastrar",
    "emplastrareis": "emplastrar",
    "emplastrarem": "emplastrar",
    "emplastraremos": "emplastrar",
    "emplastrares": "emplastrar",
    "emplastraria": "emplastrar",
    "emplastrariam": "emplastrar",
    "emplastrarias": "emplastrar",
    "emplastrarmo": "emplastrar",
    "emplastrarmos": "emplastrar",
    "emplastrará": "emplastrar",
    "emplastrarás": "emplastrar",
    "emplastrarão": "emplastrar",
    "emplastraríamos": "emplastrar",
    "emplastraríeis": "emplastrar",
    "emplastras": "emplastrar",
    "emplastrasse": "emplastrar",
    "emplastrassem": "emplastrar",
    "emplastrasses": "emplastrar",
    "emplastraste": "emplastrar",
    "emplastrastes": "emplastrar",
    "emplastrava": "emplastrar",
    "emplastravam": "emplastrar",
    "emplastravas": "emplastrar",
    "emplastrações": "emplastração",
    "emplastre": "emplastrar",
    "emplastrei": "emplastrar",
    "emplastreis": "emplastrar",
    "emplastrem": "emplastrar",
    "emplastremo": "emplastrar",
    "emplastremos": "emplastrar",
    "emplastres": "emplastrar",
    "emplastro": "emplastrar",
    "emplastros": "emplastro",
    "emplastrou": "emplastrar",
    "emplastrá": "emplastrar",
    "emplastrámo": "emplastrar",
    "emplastrámos": "emplastrar",
    "emplastráramo": "emplastrar",
    "emplastráramos": "emplastrar",
    "emplastrárei": "emplastrar",
    "emplastráreis": "emplastrar",
    "emplastrásseis": "emplastrar",
    "emplastrássemos": "emplastrar",
    "emplastrávamo": "emplastrar",
    "emplastrávamos": "emplastrar",
    "emplastrávei": "emplastrar",
    "emplastráveis": "emplastrar",
    "emplastá": "emplastar",
    "emplastámo": "emplastar",
    "emplastámos": "emplastar",
    "emplastáramo": "emplastar",
    "emplastáramos": "emplastar",
    "emplastárei": "emplastar",
    "emplastáreis": "emplastar",
    "emplastásseis": "emplastar",
    "emplastássemos": "emplastar",
    "emplastávamo": "emplastar",
    "emplastávamos": "emplastar",
    "emplastávei": "emplastar",
    "emplastáveis": "emplastar",
    "emplogada": "emplogado",
    "emplogadas": "emplogado",
    "emplogados": "emplogado",
    "empluma": "emplumar",
    "emplumada": "emplumar",
    "emplumadas": "emplumar",
    "emplumado": "emplumar",
    "emplumados": "emplumar",
    "emplumai": "emplumar",
    "emplumais": "emplumar",
    "emplumam": "emplumar",
    "emplumamo": "emplumar",
    "emplumamos": "emplumar",
    "emplumando": "emplumar",
    "emplumara": "emplumar",
    "emplumaram": "emplumar",
    "emplumaras": "emplumar",
    "emplumarde": "emplumar",
    "emplumardes": "emplumar",
    "emplumare": "emplumar",
    "emplumarei": "emplumar",
    "emplumareis": "emplumar",
    "emplumarem": "emplumar",
    "emplumaremos": "emplumar",
    "emplumares": "emplumar",
    "emplumaria": "emplumar",
    "emplumariam": "emplumar",
    "emplumarias": "emplumar",
    "emplumarmo": "emplumar",
    "emplumarmos": "emplumar",
    "emplumará": "emplumar",
    "emplumarás": "emplumar",
    "emplumarão": "emplumar",
    "emplumaríamos": "emplumar",
    "emplumaríeis": "emplumar",
    "emplumas": "emplumar",
    "emplumasse": "emplumar",
    "emplumassem": "emplumar",
    "emplumasses": "emplumar",
    "emplumaste": "emplumar",
    "emplumastes": "emplumar",
    "emplumava": "emplumar",
    "emplumavam": "emplumar",
    "emplumavas": "emplumar",
    "emplumações": "emplumação",
    "emplume": "emplumar",
    "emplumei": "emplumar",
    "emplumeis": "emplumar",
    "emplumem": "emplumar",
    "emplumemo": "emplumar",
    "emplumemos": "emplumar",
    "emplumes": "emplumar",
    "emplumesce": "emplumescer",
    "emplumescei": "emplumescer",
    "emplumesceis": "emplumescer",
    "emplumescem": "emplumescer",
    "emplumescemo": "emplumescer",
    "emplumescemos": "emplumescer",
    "emplumescendo": "emplumescer",
    "emplumescera": "emplumescer",
    "emplumesceram": "emplumescer",
    "emplumesceras": "emplumescer",
    "emplumescerdes": "emplumescer",
    "emplumescerei": "emplumescer",
    "emplumescereis": "emplumescer",
    "emplumescerem": "emplumescer",
    "emplumesceremos": "emplumescer",
    "emplumesceres": "emplumescer",
    "emplumesceria": "emplumescer",
    "emplumesceriam": "emplumescer",
    "emplumescerias": "emplumescer",
    "emplumescermo": "emplumescer",
    "emplumescermos": "emplumescer",
    "emplumescerá": "emplumescer",
    "emplumescerás": "emplumescer",
    "emplumescerão": "emplumescer",
    "emplumesceríamos": "emplumescer",
    "emplumesceríeis": "emplumescer",
    "emplumesces": "emplumescer",
    "emplumescesse": "emplumescer",
    "emplumescessem": "emplumescer",
    "emplumescesses": "emplumescer",
    "emplumesceste": "emplumescer",
    "emplumescestes": "emplumescer",
    "emplumesceu": "emplumescer",
    "emplumesci": "emplumescer",
    "emplumescia": "emplumescer",
    "emplumesciam": "emplumescer",
    "emplumescias": "emplumescer",
    "emplumescida": "emplumescer",
    "emplumescidas": "emplumescer",
    "emplumescido": "emplumescer",
    "emplumescidos": "emplumescer",
    "emplumescêramo": "emplumescer",
    "emplumescêramos": "emplumescer",
    "emplumescêreis": "emplumescer",
    "emplumescêsseis": "emplumescer",
    "emplumescêssemos": "emplumescer",
    "emplumescíamo": "emplumescer",
    "emplumescíamos": "emplumescer",
    "emplumescíeis": "emplumescer",
    "emplumesça": "emplumescer",
    "emplumesçais": "emplumescer",
    "emplumesçam": "emplumescer",
    "emplumesçamo": "emplumescer",
    "emplumesçamos": "emplumescer",
    "emplumesças": "emplumescer",
    "emplumesço": "emplumescer",
    "emplumo": "emplumar",
    "emplumou": "emplumar",
    "emplumá": "emplumar",
    "emplumámo": "emplumar",
    "emplumámos": "emplumar",
    "emplumáramo": "emplumar",
    "emplumáramos": "emplumar",
    "emplumárei": "emplumar",
    "emplumáreis": "emplumar",
    "emplumásseis": "emplumar",
    "emplumássemos": "emplumar",
    "emplumávamo": "emplumar",
    "emplumávamos": "emplumar",
    "emplumávei": "emplumar",
    "emplumáveis": "emplumar",
    "emplástrica": "emplástrico",
    "emplástricas": "emplástrico",
    "emplástricos": "emplástrico",
    "empo": "empar",
    "empoa": "empoar",
    "empoada": "empoar",
    "empoadas": "empoar",
    "empoadelas": "empoadela",
    "empoado": "empoar",
    "empoados": "empoar",
    "empoai": "empoar",
    "empoais": "empoar",
    "empoam": "empoar",
    "empoamentos": "empoamento",
    "empoamo": "empoar",
    "empoamos": "empoar",
    "empoando": "empoar",
    "empoara": "empoar",
    "empoaram": "empoar",
    "empoaras": "empoar",
    "empoarde": "empoar",
    "empoardes": "empoar",
    "empoare": "empoar",
    "empoarei": "empoar",
    "empoareis": "empoar",
    "empoarem": "empoar",
    "empoaremos": "empoar",
    "empoares": "empoar",
    "empoaria": "empoar",
    "empoariam": "empoar",
    "empoarias": "empoar",
    "empoarmo": "empoar",
    "empoarmos": "empoar",
    "empoará": "empoar",
    "empoarás": "empoar",
    "empoarão": "empoar",
    "empoaríamos": "empoar",
    "empoaríeis": "empoar",
    "empoas": "empoar",
    "empoasse": "empoar",
    "empoassem": "empoar",
    "empoasses": "empoar",
    "empoaste": "empoar",
    "empoastes": "empoar",
    "empoava": "empoar",
    "empoavam": "empoar",
    "empoavas": "empoar",
    "empobrece": "empobrecer",
    "empobrecei": "empobrecer",
    "empobreceis": "empobrecer",
    "empobrecem": "empobrecer",
    "empobrecemo": "empobrecer",
    "empobrecemos": "empobrecer",
    "empobrecendo": "empobrecer",
    "empobrecera": "empobrecer",
    "empobreceram": "empobrecer",
    "empobreceras": "empobrecer",
    "empobrecerde": "empobrecer",
    "empobrecerdes": "empobrecer",
    "empobrecere": "empobrecer",
    "empobrecerei": "empobrecer",
    "empobrecereis": "empobrecer",
    "empobrecerem": "empobrecer",
    "empobreceremos": "empobrecer",
    "empobreceres": "empobrecer",
    "empobreceria": "empobrecer",
    "empobreceriam": "empobrecer",
    "empobrecerias": "empobrecer",
    "empobrecermo": "empobrecer",
    "empobrecermos": "empobrecer",
    "empobrecerá": "empobrecer",
    "empobrecerás": "empobrecer",
    "empobrecerão": "empobrecer",
    "empobreceríamos": "empobrecer",
    "empobreceríeis": "empobrecer",
    "empobreces": "empobrecer",
    "empobrecesse": "empobrecer",
    "empobrecessem": "empobrecer",
    "empobrecesses": "empobrecer",
    "empobreceste": "empobrecer",
    "empobrecestes": "empobrecer",
    "empobreceu": "empobrecer",
    "empobreci": "empobrecer",
    "empobrecia": "empobrecer",
    "empobreciam": "empobrecer",
    "empobrecias": "empobrecer",
    "empobrecida": "empobrecido",
    "empobrecidas": "empobrecido",
    "empobrecido": "empobrecer",
    "empobrecidos": "empobrecido",
    "empobrecimentos": "empobrecimento",
    "empobrecê": "empobrecer",
    "empobrecêramo": "empobrecer",
    "empobrecêramos": "empobrecer",
    "empobrecêrei": "empobrecer",
    "empobrecêreis": "empobrecer",
    "empobrecêsseis": "empobrecer",
    "empobrecêssemos": "empobrecer",
    "empobrecíamo": "empobrecer",
    "empobrecíamos": "empobrecer",
    "empobrecíei": "empobrecer",
    "empobrecíeis": "empobrecer",
    "empobreça": "empobrecer",
    "empobreçais": "empobrecer",
    "empobreçam": "empobrecer",
    "empobreçamo": "empobrecer",
    "empobreçamos": "empobrecer",
    "empobreças": "empobrecer",
    "empobreço": "empobrecer",
    "empoce": "empoçar",
    "empocei": "empoçar",
    "empoceis": "empoçar",
    "empocem": "empoçar",
    "empocemo": "empoçar",
    "empocemos": "empoçar",
    "empoces": "empoçar",
    "empoe": "empoar",
    "empoei": "empoar",
    "empoeira": "empoeirar",
    "empoeirada": "empoeirar",
    "empoeiradas": "empoeirar",
    "empoeirado": "empoeirar",
    "empoeirados": "empoeirar",
    "empoeirai": "empoeirar",
    "empoeirais": "empoeirar",
    "empoeiram": "empoeirar",
    "empoeiramo": "empoeirar",
    "empoeiramos": "empoeirar",
    "empoeirando": "empoeirar",
    "empoeirara": "empoeirar",
    "empoeiraram": "empoeirar",
    "empoeiraras": "empoeirar",
    "empoeirarde": "empoeirar",
    "empoeirardes": "empoeirar",
    "empoeirare": "empoeirar",
    "empoeirarei": "empoeirar",
    "empoeirareis": "empoeirar",
    "empoeirarem": "empoeirar",
    "empoeiraremos": "empoeirar",
    "empoeirares": "empoeirar",
    "empoeiraria": "empoeirar",
    "empoeirariam": "empoeirar",
    "empoeirarias": "empoeirar",
    "empoeirarmo": "empoeirar",
    "empoeirarmos": "empoeirar",
    "empoeirará": "empoeirar",
    "empoeirarás": "empoeirar",
    "empoeirarão": "empoeirar",
    "empoeiraríamos": "empoeirar",
    "empoeiraríeis": "empoeirar",
    "empoeiras": "empoeirar",
    "empoeirasse": "empoeirar",
    "empoeirassem": "empoeirar",
    "empoeirasses": "empoeirar",
    "empoeiraste": "empoeirar",
    "empoeirastes": "empoeirar",
    "empoeirava": "empoeirar",
    "empoeiravam": "empoeirar",
    "empoeiravas": "empoeirar",
    "empoeire": "empoeirar",
    "empoeirei": "empoeirar",
    "empoeireis": "empoeirar",
    "empoeirem": "empoeirar",
    "empoeiremo": "empoeirar",
    "empoeiremos": "empoeirar",
    "empoeires": "empoeirar",
    "empoeiro": "empoeirar",
    "empoeirou": "empoeirar",
    "empoeirá": "empoeirar",
    "empoeirámo": "empoeirar",
    "empoeirámos": "empoeirar",
    "empoeiráramo": "empoeirar",
    "empoeiráramos": "empoeirar",
    "empoeirárei": "empoeirar",
    "empoeiráreis": "empoeirar",
    "empoeirásseis": "empoeirar",
    "empoeirássemos": "empoeirar",
    "empoeirávamo": "empoeirar",
    "empoeirávamos": "empoeirar",
    "empoeirávei": "empoeirar",
    "empoeiráveis": "empoeirar",
    "empoeis": "empoar",
    "empoem": "empoar",
    "empoemo": "empoar",
    "empoemos": "empoar",
    "empoes": "empoar",
    "empola": "empolar",
    "empolada": "empolar",
    "empoladas": "empolar",
    "empolado": "empolar",
    "empolados": "empolar",
    "empoladíssima": "empolado",
    "empoladíssimas": "empolado",
    "empoladíssimo": "empolado",
    "empoladíssimos": "empolado",
    "empolai": "empolar",
    "empolais": "empolar",
    "empolam": "empolar",
    "empolamentos": "empolamento",
    "empolamo": "empolar",
    "empolamos": "empolar",
    "empolando": "empolar",
    "empolara": "empolar",
    "empolaram": "empolar",
    "empolaras": "empolar",
    "empolarde": "empolar",
    "empolardes": "empolar",
    "empolare": "empolar",
    "empolarei": "empolar",
    "empolareis": "empolar",
    "empolarem": "empolar",
    "empolaremos": "empolar",
    "empolares": "empolar",
    "empolaria": "empolar",
    "empolariam": "empolar",
    "empolarias": "empolar",
    "empolarmo": "empolar",
    "empolarmos": "empolar",
    "empolará": "empolar",
    "empolarás": "empolar",
    "empolarão": "empolar",
    "empolaríamos": "empolar",
    "empolaríeis": "empolar",
    "empolas": "empolar",
    "empolasse": "empolar",
    "empolassem": "empolar",
    "empolasses": "empolar",
    "empolaste": "empolar",
    "empolastes": "empolar",
    "empolava": "empolar",
    "empolavam": "empolar",
    "empolavas": "empolar",
    "empolciga": "empolcigar",
    "empolcigada": "empolcigar",
    "empolcigadas": "empolcigar",
    "empolcigado": "empolcigar",
    "empolcigados": "empolcigar",
    "empolcigai": "empolcigar",
    "empolcigais": "empolcigar",
    "empolcigam": "empolcigar",
    "empolcigamo": "empolcigar",
    "empolcigamos": "empolcigar",
    "empolcigando": "empolcigar",
    "empolcigara": "empolcigar",
    "empolcigaram": "empolcigar",
    "empolcigaras": "empolcigar",
    "empolcigarde": "empolcigar",
    "empolcigardes": "empolcigar",
    "empolcigare": "empolcigar",
    "empolcigarei": "empolcigar",
    "empolcigareis": "empolcigar",
    "empolcigarem": "empolcigar",
    "empolcigaremos": "empolcigar",
    "empolcigares": "empolcigar",
    "empolcigaria": "empolcigar",
    "empolcigariam": "empolcigar",
    "empolcigarias": "empolcigar",
    "empolcigarmo": "empolcigar",
    "empolcigarmos": "empolcigar",
    "empolcigará": "empolcigar",
    "empolcigarás": "empolcigar",
    "empolcigarão": "empolcigar",
    "empolcigaríamos": "empolcigar",
    "empolcigaríeis": "empolcigar",
    "empolcigas": "empolcigar",
    "empolcigasse": "empolcigar",
    "empolcigassem": "empolcigar",
    "empolcigasses": "empolcigar",
    "empolcigaste": "empolcigar",
    "empolcigastes": "empolcigar",
    "empolcigava": "empolcigar",
    "empolcigavam": "empolcigar",
    "empolcigavas": "empolcigar",
    "empolcigo": "empolcigar",
    "empolcigou": "empolcigar",
    "empolcigue": "empolcigar",
    "empolciguei": "empolcigar",
    "empolcigueis": "empolcigar",
    "empolciguem": "empolcigar",
    "empolciguemo": "empolcigar",
    "empolciguemos": "empolcigar",
    "empolcigues": "empolcigar",
    "empolcigá": "empolcigar",
    "empolcigámo": "empolcigar",
    "empolcigámos": "empolcigar",
    "empolcigáramo": "empolcigar",
    "empolcigáramos": "empolcigar",
    "empolcigárei": "empolcigar",
    "empolcigáreis": "empolcigar",
    "empolcigásseis": "empolcigar",
    "empolcigássemos": "empolcigar",
    "empolcigávamo": "empolcigar",
    "empolcigávamos": "empolcigar",
    "empolcigávei": "empolcigar",
    "empolcigáveis": "empolcigar",
    "empole": "empolar",
    "empoleada": "empolear",
    "empoleadas": "empolear",
    "empoleado": "empolear",
    "empoleados": "empolear",
    "empoleai": "empolear",
    "empoleais": "empolear",
    "empoleamo": "empolear",
    "empoleamos": "empolear",
    "empoleando": "empolear",
    "empoleara": "empolear",
    "empolearam": "empolear",
    "empolearas": "empolear",
    "empolearde": "empolear",
    "empoleardes": "empolear",
    "empoleare": "empolear",
    "empolearei": "empolear",
    "empoleareis": "empolear",
    "empolearem": "empolear",
    "empolearemos": "empolear",
    "empoleares": "empolear",
    "empolearia": "empolear",
    "empoleariam": "empolear",
    "empolearias": "empolear",
    "empolearmo": "empolear",
    "empolearmos": "empolear",
    "empoleará": "empolear",
    "empolearás": "empolear",
    "empolearão": "empolear",
    "empolearíamos": "empolear",
    "empolearíeis": "empolear",
    "empoleasse": "empolear",
    "empoleassem": "empolear",
    "empoleasses": "empolear",
    "empoleaste": "empolear",
    "empoleastes": "empolear",
    "empoleava": "empolear",
    "empoleavam": "empolear",
    "empoleavas": "empolear",
    "empoleações": "empoleação",
    "empoleei": "empolear",
    "empoleeis": "empolear",
    "empoleemo": "empolear",
    "empoleemos": "empolear",
    "empolei": "empolar",
    "empoleia": "empolear",
    "empoleiam": "empolear",
    "empoleias": "empolear",
    "empoleie": "empolear",
    "empoleiem": "empolear",
    "empoleies": "empolear",
    "empoleio": "empolear",
    "empoleira": "empoleirar",
    "empoleirada": "empoleirar",
    "empoleiradas": "empoleirar",
    "empoleirado": "empoleirar",
    "empoleirados": "empoleirar",
    "empoleirai": "empoleirar",
    "empoleirais": "empoleirar",
    "empoleiram": "empoleirar",
    "empoleiramo": "empoleirar",
    "empoleiramos": "empoleirar",
    "empoleirando": "empoleirar",
    "empoleirara": "empoleirar",
    "empoleiraram": "empoleirar",
    "empoleiraras": "empoleirar",
    "empoleirarde": "empoleirar",
    "empoleirardes": "empoleirar",
    "empoleirare": "empoleirar",
    "empoleirarei": "empoleirar",
    "empoleirareis": "empoleirar",
    "empoleirarem": "empoleirar",
    "empoleiraremos": "empoleirar",
    "empoleirares": "empoleirar",
    "empoleiraria": "empoleirar",
    "empoleirariam": "empoleirar",
    "empoleirarias": "empoleirar",
    "empoleirarmo": "empoleirar",
    "empoleirarmos": "empoleirar",
    "empoleirará": "empoleirar",
    "empoleirarás": "empoleirar",
    "empoleirarão": "empoleirar",
    "empoleiraríamos": "empoleirar",
    "empoleiraríeis": "empoleirar",
    "empoleiras": "empoleirar",
    "empoleirasse": "empoleirar",
    "empoleirassem": "empoleirar",
    "empoleirasses": "empoleirar",
    "empoleiraste": "empoleirar",
    "empoleirastes": "empoleirar",
    "empoleirava": "empoleirar",
    "empoleiravam": "empoleirar",
    "empoleiravas": "empoleirar",
    "empoleire": "empoleirar",
    "empoleirei": "empoleirar",
    "empoleireis": "empoleirar",
    "empoleirem": "empoleirar",
    "empoleiremo": "empoleirar",
    "empoleiremos": "empoleirar",
    "empoleires": "empoleirar",
    "empoleiro": "empoleirar",
    "empoleirou": "empoleirar",
    "empoleirá": "empoleirar",
    "empoleirámo": "empoleirar",
    "empoleirámos": "empoleirar",
    "empoleiráramo": "empoleirar",
    "empoleiráramos": "empoleirar",
    "empoleirárei": "empoleirar",
    "empoleiráreis": "empoleirar",
    "empoleirásseis": "empoleirar",
    "empoleirássemos": "empoleirar",
    "empoleirávamo": "empoleirar",
    "empoleirávamos": "empoleirar",
    "empoleirávei": "empoleirar",
    "empoleiráveis": "empoleirar",
    "empoleis": "empolar",
    "empolem": "empolar",
    "empolemo": "empolar",
    "empolemos": "empolar",
    "empoleou": "empolear",
    "empoles": "empolar",
    "empoleá": "empolear",
    "empoleámo": "empolear",
    "empoleámos": "empolear",
    "empoleáramo": "empolear",
    "empoleáramos": "empolear",
    "empoleárei": "empolear",
    "empoleáreis": "empolear",
    "empoleásseis": "empolear",
    "empoleássemos": "empolear",
    "empoleávamo": "empolear",
    "empoleávamos": "empolear",
    "empoleávei": "empolear",
    "empoleáveis": "empolear",
    "empolga": "empolgar",
    "empolgada": "empolgar",
    "empolgadas": "empolgar",
    "empolgadeiras": "empolgadeira",
    "empolgado": "empolgar",
    "empolgados": "empolgar",
    "empolgaduras": "empolgadura",
    "empolgai": "empolgar",
    "empolgais": "empolgar",
    "empolgam": "empolgar",
    "empolgamo": "empolgar",
    "empolgamos": "empolgar",
    "empolgando": "empolgar",
    "empolgantes": "empolgante",
    "empolgara": "empolgar",
    "empolgaram": "empolgar",
    "empolgaras": "empolgar",
    "empolgarde": "empolgar",
    "empolgardes": "empolgar",
    "empolgare": "empolgar",
    "empolgarei": "empolgar",
    "empolgareis": "empolgar",
    "empolgarem": "empolgar",
    "empolgaremos": "empolgar",
    "empolgares": "empolgar",
    "empolgaria": "empolgar",
    "empolgariam": "empolgar",
    "empolgarias": "empolgar",
    "empolgarmo": "empolgar",
    "empolgarmos": "empolgar",
    "empolgará": "empolgar",
    "empolgarás": "empolgar",
    "empolgarão": "empolgar",
    "empolgaríamos": "empolgar",
    "empolgaríeis": "empolgar",
    "empolgas": "empolgar",
    "empolgasse": "empolgar",
    "empolgassem": "empolgar",
    "empolgasses": "empolgar",
    "empolgaste": "empolgar",
    "empolgastes": "empolgar",
    "empolgava": "empolgar",
    "empolgavam": "empolgar",
    "empolgavas": "empolgar",
    "empolgações": "empolgação",
    "empolgo": "empolgar",
    "empolgou": "empolgar",
    "empolgue": "empolgar",
    "empolguei": "empolgar",
    "empolgueis": "empolgar",
    "empolguem": "empolgar",
    "empolguemo": "empolgar",
    "empolguemos": "empolgar",
    "empolgues": "empolgar",
    "empolgá": "empolgar",
    "empolgámo": "empolgar",
    "empolgámos": "empolgar",
    "empolgáramo": "empolgar",
    "empolgáramos": "empolgar",
    "empolgárei": "empolgar",
    "empolgáreis": "empolgar",
    "empolgásseis": "empolgar",
    "empolgássemos": "empolgar",
    "empolgávamo": "empolgar",
    "empolgávamos": "empolgar",
    "empolgávei": "empolgar",
    "empolgáveis": "empolgável",
    "empolha": "empolhar",
    "empolhada": "empolhar",
    "empolhadas": "empolhar",
    "empolhado": "empolhar",
    "empolhados": "empolhar",
    "empolhai": "empolhar",
    "empolhais": "empolhar",
    "empolham": "empolhar",
    "empolhamo": "empolhar",
    "empolhamos": "empolhar",
    "empolhando": "empolhar",
    "empolhara": "empolhar",
    "empolharam": "empolhar",
    "empolharas": "empolhar",
    "empolharde": "empolhar",
    "empolhardes": "empolhar",
    "empolhare": "empolhar",
    "empolharei": "empolhar",
    "empolhareis": "empolhar",
    "empolharem": "empolhar",
    "empolharemos": "empolhar",
    "empolhares": "empolhar",
    "empolharia": "empolhar",
    "empolhariam": "empolhar",
    "empolharias": "empolhar",
    "empolharmo": "empolhar",
    "empolharmos": "empolhar",
    "empolhará": "empolhar",
    "empolharás": "empolhar",
    "empolharão": "empolhar",
    "empolharíamos": "empolhar",
    "empolharíeis": "empolhar",
    "empolhas": "empolhar",
    "empolhasse": "empolhar",
    "empolhassem": "empolhar",
    "empolhasses": "empolhar",
    "empolhaste": "empolhar",
    "empolhastes": "empolhar",
    "empolhava": "empolhar",
    "empolhavam": "empolhar",
    "empolhavas": "empolhar",
    "empolhe": "empolhar",
    "empolhei": "empolhar",
    "empolheis": "empolhar",
    "empolhem": "empolhar",
    "empolhemo": "empolhar",
    "empolhemos": "empolhar",
    "empolhes": "empolhar",
    "empolho": "empolhar",
    "empolhou": "empolhar",
    "empolhá": "empolhar",
    "empolhámo": "empolhar",
    "empolhámos": "empolhar",
    "empolháramo": "empolhar",
    "empolháramos": "empolhar",
    "empolhárei": "empolhar",
    "empolháreis": "empolhar",
    "empolhásseis": "empolhar",
    "empolhássemos": "empolhar",
    "empolhávamo": "empolhar",
    "empolhávamos": "empolhar",
    "empolhávei": "empolhar",
    "empolháveis": "empolhar",
    "empolma": "empolmar",
    "empolmada": "empolmar",
    "empolmadas": "empolmar",
    "empolmado": "empolmar",
    "empolmados": "empolmar",
    "empolmai": "empolmar",
    "empolmais": "empolmar",
    "empolmam": "empolmar",
    "empolmamo": "empolmar",
    "empolmamos": "empolmar",
    "empolmando": "empolmar",
    "empolmara": "empolmar",
    "empolmaram": "empolmar",
    "empolmaras": "empolmar",
    "empolmarde": "empolmar",
    "empolmardes": "empolmar",
    "empolmare": "empolmar",
    "empolmarei": "empolmar",
    "empolmareis": "empolmar",
    "empolmarem": "empolmar",
    "empolmaremos": "empolmar",
    "empolmares": "empolmar",
    "empolmaria": "empolmar",
    "empolmariam": "empolmar",
    "empolmarias": "empolmar",
    "empolmarmo": "empolmar",
    "empolmarmos": "empolmar",
    "empolmará": "empolmar",
    "empolmarás": "empolmar",
    "empolmarão": "empolmar",
    "empolmaríamos": "empolmar",
    "empolmaríeis": "empolmar",
    "empolmas": "empolmar",
    "empolmasse": "empolmar",
    "empolmassem": "empolmar",
    "empolmasses": "empolmar",
    "empolmaste": "empolmar",
    "empolmastes": "empolmar",
    "empolmava": "empolmar",
    "empolmavam": "empolmar",
    "empolmavas": "empolmar",
    "empolme": "empolmar",
    "empolmei": "empolmar",
    "empolmeis": "empolmar",
    "empolmem": "empolmar",
    "empolmemo": "empolmar",
    "empolmemos": "empolmar",
    "empolmes": "empolmar",
    "empolmo": "empolmar",
    "empolmou": "empolmar",
    "empolmá": "empolmar",
    "empolmámo": "empolmar",
    "empolmámos": "empolmar",
    "empolmáramo": "empolmar",
    "empolmáramos": "empolmar",
    "empolmárei": "empolmar",
    "empolmáreis": "empolmar",
    "empolmásseis": "empolmar",
    "empolmássemos": "empolmar",
    "empolmávamo": "empolmar",
    "empolmávamos": "empolmar",
    "empolmávei": "empolmar",
    "empolmáveis": "empolmar",
    "empolo": "empolar",
    "empolou": "empolar",
    "empolá": "empolar",
    "empolámo": "empolar",
    "empolámos": "empolar",
    "empoláramo": "empolar",
    "empoláramos": "empolar",
    "empolárei": "empolar",
    "empoláreis": "empolar",
    "empolásseis": "empolar",
    "empolássemos": "empolar",
    "empolávamo": "empolar",
    "empolávamos": "empolar",
    "empolávei": "empolar",
    "empoláveis": "empolável",
    "emponta": "empontar",
    "empontada": "empontar",
    "empontadas": "empontar",
    "empontado": "empontar",
    "empontados": "empontar",
    "empontai": "empontar",
    "empontais": "empontar",
    "empontam": "empontar",
    "empontamo": "empontar",
    "empontamos": "empontar",
    "empontando": "empontar",
    "empontara": "empontar",
    "empontaram": "empontar",
    "empontaras": "empontar",
    "empontarde": "empontar",
    "empontardes": "empontar",
    "empontare": "empontar",
    "empontarei": "empontar",
    "empontareis": "empontar",
    "empontarem": "empontar",
    "empontaremos": "empontar",
    "empontares": "empontar",
    "empontaria": "empontar",
    "empontariam": "empontar",
    "empontarias": "empontar",
    "empontarmo": "empontar",
    "empontarmos": "empontar",
    "empontará": "empontar",
    "empontarás": "empontar",
    "empontarão": "empontar",
    "empontaríamos": "empontar",
    "empontaríeis": "empontar",
    "empontas": "empontar",
    "empontasse": "empontar",
    "empontassem": "empontar",
    "empontasses": "empontar",
    "empontaste": "empontar",
    "empontastes": "empontar",
    "empontava": "empontar",
    "empontavam": "empontar",
    "empontavas": "empontar",
    "emponte": "empontar",
    "empontei": "empontar",
    "emponteis": "empontar",
    "empontem": "empontar",
    "empontemo": "empontar",
    "empontemos": "empontar",
    "empontes": "empontar",
    "emponto": "empontar",
    "empontou": "empontar",
    "empontá": "empontar",
    "empontámo": "empontar",
    "empontámos": "empontar",
    "empontáramo": "empontar",
    "empontáramos": "empontar",
    "empontárei": "empontar",
    "empontáreis": "empontar",
    "empontásseis": "empontar",
    "empontássemos": "empontar",
    "empontávamo": "empontar",
    "empontávamos": "empontar",
    "empontávei": "empontar",
    "empontáveis": "empontar",
    "empoo": "empoar",
    "empoou": "empoar",
    "emporca": "emporcar",
    "emporcada": "emporcar",
    "emporcadas": "emporcar",
    "emporcado": "emporcar",
    "emporcados": "emporcar",
    "emporcai": "emporcar",
    "emporcais": "emporcar",
    "emporcalha": "emporcalhar",
    "emporcalhada": "emporcalhar",
    "emporcalhadas": "emporcalhar",
    "emporcalhado": "emporcalhar",
    "emporcalhados": "emporcalhar",
    "emporcalhai": "emporcalhar",
    "emporcalhais": "emporcalhar",
    "emporcalham": "emporcalhar",
    "emporcalhamo": "emporcalhar",
    "emporcalhamos": "emporcalhar",
    "emporcalhando": "emporcalhar",
    "emporcalhara": "emporcalhar",
    "emporcalharam": "emporcalhar",
    "emporcalharas": "emporcalhar",
    "emporcalharde": "emporcalhar",
    "emporcalhardes": "emporcalhar",
    "emporcalhare": "emporcalhar",
    "emporcalharei": "emporcalhar",
    "emporcalhareis": "emporcalhar",
    "emporcalharem": "emporcalhar",
    "emporcalharemos": "emporcalhar",
    "emporcalhares": "emporcalhar",
    "emporcalharia": "emporcalhar",
    "emporcalhariam": "emporcalhar",
    "emporcalharias": "emporcalhar",
    "emporcalharmo": "emporcalhar",
    "emporcalharmos": "emporcalhar",
    "emporcalhará": "emporcalhar",
    "emporcalharás": "emporcalhar",
    "emporcalharão": "emporcalhar",
    "emporcalharíamos": "emporcalhar",
    "emporcalharíeis": "emporcalhar",
    "emporcalhas": "emporcalhar",
    "emporcalhasse": "emporcalhar",
    "emporcalhassem": "emporcalhar",
    "emporcalhasses": "emporcalhar",
    "emporcalhaste": "emporcalhar",
    "emporcalhastes": "emporcalhar",
    "emporcalhava": "emporcalhar",
    "emporcalhavam": "emporcalhar",
    "emporcalhavas": "emporcalhar",
    "emporcalhe": "emporcalhar",
    "emporcalhei": "emporcalhar",
    "emporcalheis": "emporcalhar",
    "emporcalhem": "emporcalhar",
    "emporcalhemo": "emporcalhar",
    "emporcalhemos": "emporcalhar",
    "emporcalhes": "emporcalhar",
    "emporcalho": "emporcalhar",
    "emporcalhou": "emporcalhar",
    "emporcalhá": "emporcalhar",
    "emporcalhámo": "emporcalhar",
    "emporcalhámos": "emporcalhar",
    "emporcalháramo": "emporcalhar",
    "emporcalháramos": "emporcalhar",
    "emporcalhárei": "emporcalhar",
    "emporcalháreis": "emporcalhar",
    "emporcalhásseis": "emporcalhar",
    "emporcalhássemos": "emporcalhar",
    "emporcalhávamo": "emporcalhar",
    "emporcalhávamos": "emporcalhar",
    "emporcalhávei": "emporcalhar",
    "emporcalháveis": "emporcalhar",
    "emporcam": "emporcar",
    "emporcamo": "emporcar",
    "emporcamos": "emporcar",
    "emporcando": "emporcar",
    "emporcara": "emporcar",
    "emporcaram": "emporcar",
    "emporcaras": "emporcar",
    "emporcarde": "emporcar",
    "emporcardes": "emporcar",
    "emporcare": "emporcar",
    "emporcarei": "emporcar",
    "emporcareis": "emporcar",
    "emporcarem": "emporcar",
    "emporcaremos": "emporcar",
    "emporcares": "emporcar",
    "emporcaria": "emporcar",
    "emporcariam": "emporcar",
    "emporcarias": "emporcar",
    "emporcarmo": "emporcar",
    "emporcarmos": "emporcar",
    "emporcará": "emporcar",
    "emporcarás": "emporcar",
    "emporcarão": "emporcar",
    "emporcaríamos": "emporcar",
    "emporcaríeis": "emporcar",
    "emporcas": "emporcar",
    "emporcasse": "emporcar",
    "emporcassem": "emporcar",
    "emporcasses": "emporcar",
    "emporcaste": "emporcar",
    "emporcastes": "emporcar",
    "emporcava": "emporcar",
    "emporcavam": "emporcar",
    "emporcavas": "emporcar",
    "emporco": "emporcar",
    "emporcou": "emporcar",
    "emporcá": "emporcar",
    "emporcámo": "emporcar",
    "emporcámos": "emporcar",
    "emporcáramo": "emporcar",
    "emporcáramos": "emporcar",
    "emporcárei": "emporcar",
    "emporcáreis": "emporcar",
    "emporcásseis": "emporcar",
    "emporcássemos": "emporcar",
    "emporcávamo": "emporcar",
    "emporcávamos": "emporcar",
    "emporcávei": "emporcar",
    "emporcáveis": "emporcar",
    "emporque": "emporcar",
    "emporquei": "emporcar",
    "emporqueis": "emporcar",
    "emporquem": "emporcar",
    "emporquemo": "emporcar",
    "emporquemos": "emporcar",
    "emporques": "emporcar",
    "emporética": "emporético",
    "emporéticas": "emporético",
    "emporéticos": "emporético",
    "empossa": "empossar",
    "empossada": "empossar",
    "empossadas": "empossar",
    "empossado": "empossar",
    "empossados": "empossar",
    "empossai": "empossar",
    "empossais": "empossar",
    "empossam": "empossar",
    "empossamentos": "empossamento",
    "empossamo": "empossar",
    "empossamos": "empossar",
    "empossando": "empossar",
    "empossara": "empossar",
    "empossaram": "empossar",
    "empossaras": "empossar",
    "empossarde": "empossar",
    "empossardes": "empossar",
    "empossare": "empossar",
    "empossarei": "empossar",
    "empossareis": "empossar",
    "empossarem": "empossar",
    "empossaremos": "empossar",
    "empossares": "empossar",
    "empossaria": "empossar",
    "empossariam": "empossar",
    "empossarias": "empossar",
    "empossarmo": "empossar",
    "empossarmos": "empossar",
    "empossará": "empossar",
    "empossarás": "empossar",
    "empossarão": "empossar",
    "empossaríamos": "empossar",
    "empossaríeis": "empossar",
    "empossas": "empossar",
    "empossasse": "empossar",
    "empossassem": "empossar",
    "empossasses": "empossar",
    "empossaste": "empossar",
    "empossastes": "empossar",
    "empossava": "empossar",
    "empossavam": "empossar",
    "empossavas": "empossar",
    "emposse": "empossar",
    "empossei": "empossar",
    "emposseis": "empossar",
    "empossem": "empossar",
    "empossemo": "empossar",
    "empossemos": "empossar",
    "emposses": "emposse",
    "emposso": "empossar",
    "empossou": "empossar",
    "empossá": "empossar",
    "empossámo": "empossar",
    "empossámos": "empossar",
    "empossáramo": "empossar",
    "empossáramos": "empossar",
    "empossárei": "empossar",
    "empossáreis": "empossar",
    "empossásseis": "empossar",
    "empossássemos": "empossar",
    "empossávamo": "empossar",
    "empossávamos": "empossar",
    "empossávei": "empossar",
    "empossáveis": "empossar",
    "emposta": "empostar",
    "empostada": "empostar",
    "empostadas": "empostar",
    "empostado": "empostar",
    "empostados": "empostar",
    "empostai": "empostar",
    "empostais": "empostar",
    "empostam": "empostar",
    "empostamo": "empostar",
    "empostamos": "empostar",
    "empostando": "empostar",
    "empostara": "empostar",
    "empostaram": "empostar",
    "empostaras": "empostar",
    "empostarde": "empostar",
    "empostardes": "empostar",
    "empostare": "empostar",
    "empostarei": "empostar",
    "empostareis": "empostar",
    "empostarem": "empostar",
    "empostaremos": "empostar",
    "empostares": "empostar",
    "empostaria": "empostar",
    "empostariam": "empostar",
    "empostarias": "empostar",
    "empostarmo": "empostar",
    "empostarmos": "empostar",
    "empostará": "empostar",
    "empostarás": "empostar",
    "empostarão": "empostar",
    "empostaríamos": "empostar",
    "empostaríeis": "empostar",
    "empostas": "empostar",
    "empostasse": "empostar",
    "empostassem": "empostar",
    "empostasses": "empostar",
    "empostaste": "empostar",
    "empostastes": "empostar",
    "empostava": "empostar",
    "empostavam": "empostar",
    "empostavas": "empostar",
    "emposte": "empostar",
    "empostei": "empostar",
    "emposteis": "empostar",
    "empostem": "empostar",
    "empostemo": "empostar",
    "empostemos": "empostar",
    "empostes": "empostar",
    "emposto": "empostar",
    "empostou": "empostar",
    "empostá": "empostar",
    "empostámo": "empostar",
    "empostámos": "empostar",
    "empostáramo": "empostar",
    "empostáramos": "empostar",
    "empostárei": "empostar",
    "empostáreis": "empostar",
    "empostásseis": "empostar",
    "empostássemos": "empostar",
    "empostávamo": "empostar",
    "empostávamos": "empostar",
    "empostávei": "empostar",
    "empostáveis": "empostar",
    "empou": "empar",
    "empoá": "empoar",
    "empoámo": "empoar",
    "empoámos": "empoar",
    "empoáramo": "empoar",
    "empoáramos": "empoar",
    "empoárei": "empoar",
    "empoáreis": "empoar",
    "empoásseis": "empoar",
    "empoássemos": "empoar",
    "empoávamo": "empoar",
    "empoávamos": "empoar",
    "empoávei": "empoar",
    "empoáveis": "empoar",
    "empoça": "empoçar",
    "empoçada": "empoçar",
    "empoçadas": "empoçar",
    "empoçado": "empoçar",
    "empoçados": "empoçar",
    "empoçai": "empoçar",
    "empoçais": "empoçar",
    "empoçam": "empoçar",
    "empoçamentos": "empoçamento",
    "empoçamo": "empoçar",
    "empoçamos": "empoçar",
    "empoçando": "empoçar",
    "empoçara": "empoçar",
    "empoçaram": "empoçar",
    "empoçaras": "empoçar",
    "empoçarde": "empoçar",
    "empoçardes": "empoçar",
    "empoçare": "empoçar",
    "empoçarei": "empoçar",
    "empoçareis": "empoçar",
    "empoçarem": "empoçar",
    "empoçaremos": "empoçar",
    "empoçares": "empoçar",
    "empoçaria": "empoçar",
    "empoçariam": "empoçar",
    "empoçarias": "empoçar",
    "empoçarmo": "empoçar",
    "empoçarmos": "empoçar",
    "empoçará": "empoçar",
    "empoçarás": "empoçar",
    "empoçarão": "empoçar",
    "empoçaríamos": "empoçar",
    "empoçaríeis": "empoçar",
    "empoças": "empoçar",
    "empoçasse": "empoçar",
    "empoçassem": "empoçar",
    "empoçasses": "empoçar",
    "empoçaste": "empoçar",
    "empoçastes": "empoçar",
    "empoçava": "empoçar",
    "empoçavam": "empoçar",
    "empoçavas": "empoçar",
    "empoço": "empoçar",
    "empoçou": "empoçar",
    "empoçá": "empoçar",
    "empoçámo": "empoçar",
    "empoçámos": "empoçar",
    "empoçáramo": "empoçar",
    "empoçáramos": "empoçar",
    "empoçárei": "empoçar",
    "empoçáreis": "empoçar",
    "empoçásseis": "empoçar",
    "empoçássemos": "empoçar",
    "empoçávamo": "empoçar",
    "empoçávamos": "empoçar",
    "empoçávei": "empoçar",
    "empoçáveis": "empoçar",
    "empranchada": "empranchado",
    "empranchadas": "empranchado",
    "empranchados": "empranchado",
    "emprata": "empratar",
    "empratada": "empratar",
    "empratadas": "empratar",
    "empratado": "empratar",
    "empratados": "empratar",
    "empratai": "empratar",
    "empratais": "empratar",
    "empratam": "empratar",
    "empratamo": "empratar",
    "empratamos": "empratar",
    "empratando": "empratar",
    "empratara": "empratar",
    "emprataram": "empratar",
    "emprataras": "empratar",
    "empratarde": "empratar",
    "empratardes": "empratar",
    "empratare": "empratar",
    "empratarei": "empratar",
    "empratareis": "empratar",
    "empratarem": "empratar",
    "emprataremos": "empratar",
    "empratares": "empratar",
    "emprataria": "empratar",
    "empratariam": "empratar",
    "empratarias": "empratar",
    "empratarmo": "empratar",
    "empratarmos": "empratar",
    "empratará": "empratar",
    "empratarás": "empratar",
    "empratarão": "empratar",
    "emprataríamos": "empratar",
    "emprataríeis": "empratar",
    "empratas": "empratar",
    "empratasse": "empratar",
    "empratassem": "empratar",
    "empratasses": "empratar",
    "emprataste": "empratar",
    "empratastes": "empratar",
    "empratava": "empratar",
    "empratavam": "empratar",
    "empratavas": "empratar",
    "emprate": "empratar",
    "empratei": "empratar",
    "emprateis": "empratar",
    "empratem": "empratar",
    "empratemo": "empratar",
    "empratemos": "empratar",
    "emprates": "empratar",
    "emprato": "empratar",
    "empratou": "empratar",
    "empratá": "empratar",
    "empratámo": "empratar",
    "empratámos": "empratar",
    "empratáramo": "empratar",
    "empratáramos": "empratar",
    "empratárei": "empratar",
    "empratáreis": "empratar",
    "empratásseis": "empratar",
    "empratássemos": "empratar",
    "empratávamo": "empratar",
    "empratávamos": "empratar",
    "empratávei": "empratar",
    "empratáveis": "empratar",
    "empraza": "emprazar",
    "emprazada": "emprazar",
    "emprazadas": "emprazar",
    "emprazado": "emprazar",
    "emprazadora": "emprazador",
    "emprazadoras": "emprazador",
    "emprazadores": "emprazador",
    "emprazados": "emprazar",
    "emprazai": "emprazar",
    "emprazais": "emprazar",
    "emprazam": "emprazar",
    "emprazamentos": "emprazamento",
    "emprazamo": "emprazar",
    "emprazamos": "emprazar",
    "emprazando": "emprazar",
    "emprazara": "emprazar",
    "emprazaram": "emprazar",
    "emprazaras": "emprazar",
    "emprazarde": "emprazar",
    "emprazardes": "emprazar",
    "emprazare": "emprazar",
    "emprazarei": "emprazar",
    "emprazareis": "emprazar",
    "emprazarem": "emprazar",
    "emprazaremos": "emprazar",
    "emprazares": "emprazar",
    "emprazaria": "emprazar",
    "emprazariam": "emprazar",
    "emprazarias": "emprazar",
    "emprazarmo": "emprazar",
    "emprazarmos": "emprazar",
    "emprazará": "emprazar",
    "emprazarás": "emprazar",
    "emprazarão": "emprazar",
    "emprazaríamos": "emprazar",
    "emprazaríeis": "emprazar",
    "emprazas": "emprazar",
    "emprazasse": "emprazar",
    "emprazassem": "emprazar",
    "emprazasses": "emprazar",
    "emprazaste": "emprazar",
    "emprazastes": "emprazar",
    "emprazava": "emprazar",
    "emprazavam": "emprazar",
    "emprazavas": "emprazar",
    "empraze": "emprazar",
    "emprazei": "emprazar",
    "emprazeis": "emprazar",
    "emprazem": "emprazar",
    "emprazemo": "emprazar",
    "emprazemos": "emprazar",
    "emprazes": "emprazar",
    "emprazo": "emprazar",
    "emprazou": "emprazar",
    "emprazá": "emprazar",
    "emprazámo": "emprazar",
    "emprazámos": "emprazar",
    "emprazáramo": "emprazar",
    "emprazáramos": "emprazar",
    "emprazárei": "emprazar",
    "emprazáreis": "emprazar",
    "emprazásseis": "emprazar",
    "emprazássemos": "emprazar",
    "emprazávamo": "emprazar",
    "emprazávamos": "emprazar",
    "emprazávei": "emprazar",
    "emprazáveis": "emprazar",
    "empreenda": "empreender",
    "empreendais": "empreender",
    "empreendam": "empreender",
    "empreendamo": "empreender",
    "empreendamos": "empreender",
    "empreendas": "empreender",
    "empreende": "empreender",
    "empreendedora": "empreendedor",
    "empreendedoras": "empreendedor",
    "empreendedores": "empreendedor",
    "empreendei": "empreender",
    "empreendeis": "empreender",
    "empreendem": "empreender",
    "empreendemo": "empreender",
    "empreendemos": "empreender",
    "empreendendo": "empreender",
    "empreendera": "empreender",
    "empreenderam": "empreender",
    "empreenderas": "empreender",
    "empreenderde": "empreender",
    "empreenderdes": "empreender",
    "empreendere": "empreender",
    "empreenderei": "empreender",
    "empreendereis": "empreender",
    "empreenderem": "empreender",
    "empreenderemos": "empreender",
    "empreenderes": "empreender",
    "empreenderia": "empreender",
    "empreenderiam": "empreender",
    "empreenderias": "empreender",
    "empreendermo": "empreender",
    "empreendermos": "empreender",
    "empreenderá": "empreender",
    "empreenderás": "empreender",
    "empreenderão": "empreender",
    "empreenderíamos": "empreender",
    "empreenderíeis": "empreender",
    "empreendes": "empreender",
    "empreendesse": "empreender",
    "empreendessem": "empreender",
    "empreendesses": "empreender",
    "empreendeste": "empreender",
    "empreendestes": "empreender",
    "empreendeu": "empreender",
    "empreendi": "empreender",
    "empreendia": "empreender",
    "empreendiam": "empreender",
    "empreendias": "empreender",
    "empreendida": "empreendido",
    "empreendidas": "empreendido",
    "empreendido": "empreender",
    "empreendidos": "empreendido",
    "empreendimentos": "empreendimento",
    "empreendo": "empreender",
    "empreendê": "empreender",
    "empreendêramo": "empreender",
    "empreendêramos": "empreender",
    "empreendêrei": "empreender",
    "empreendêreis": "empreender",
    "empreendêsseis": "empreender",
    "empreendêssemos": "empreender",
    "empreendíamo": "empreender",
    "empreendíamos": "empreender",
    "empreendíei": "empreender",
    "empreendíeis": "empreender",
    "emprega": "empregar",
    "empregabilidades": "empregabilidade",
    "empregada": "empregar",
    "empregadas": "empregar",
    "empregadazinha": "empregado",
    "empregadazinhas": "empregado",
    "empregadazita": "empregado",
    "empregadazitas": "empregado",
    "empregadinha": "empregado",
    "empregadinhas": "empregado",
    "empregadinho": "empregado",
    "empregadinhos": "empregado",
    "empregadita": "empregado",
    "empregaditas": "empregado",
    "empregadito": "empregado",
    "empregaditos": "empregado",
    "empregado": "empregar",
    "empregadora": "empregador",
    "empregadoras": "empregador",
    "empregadores": "empregador",
    "empregados": "empregar",
    "empregadozinho": "empregado",
    "empregadozinhos": "empregado",
    "empregadozito": "empregado",
    "empregadozitos": "empregado",
    "empregai": "empregar",
    "empregais": "empregar",
    "empregam": "empregar",
    "empregamo": "empregar",
    "empregamos": "empregar",
    "empregando": "empregar",
    "empregara": "empregar",
    "empregaram": "empregar",
    "empregaras": "empregar",
    "empregarde": "empregar",
    "empregardes": "empregar",
    "empregare": "empregar",
    "empregarei": "empregar",
    "empregareis": "empregar",
    "empregarem": "empregar",
    "empregaremos": "empregar",
    "empregares": "empregar",
    "empregaria": "empregar",
    "empregariam": "empregar",
    "empregarias": "empregar",
    "empregarmo": "empregar",
    "empregarmos": "empregar",
    "empregará": "empregar",
    "empregarás": "empregar",
    "empregarão": "empregar",
    "empregaríamos": "empregar",
    "empregaríeis": "empregar",
    "empregas": "empregar",
    "empregasse": "empregar",
    "empregassem": "empregar",
    "empregasses": "empregar",
    "empregaste": "empregar",
    "empregastes": "empregar",
    "empregava": "empregar",
    "empregavam": "empregar",
    "empregavas": "empregar",
    "emprego": "empregar",
    "empregomanias": "empregomania",
    "empregomaníaca": "empregomaníaco",
    "empregomaníacas": "empregomaníaco",
    "empregomaníacos": "empregomaníaco",
    "empregos": "emprego",
    "empregou": "empregar",
    "empregue": "empregar",
    "empreguei": "empregar",
    "empregueis": "empregar",
    "empreguem": "empregar",
    "empreguemo": "empregar",
    "empreguemos": "empregar",
    "empregues": "empregue",
    "empreguice": "empreguiçar",
    "empreguicei": "empreguiçar",
    "empreguiceis": "empreguiçar",
    "empreguicem": "empreguiçar",
    "empreguicemo": "empreguiçar",
    "empreguicemos": "empreguiçar",
    "empreguices": "empreguiçar",
    "empreguismos": "empreguismo",
    "empreguiça": "empreguiçar",
    "empreguiçada": "empreguiçar",
    "empreguiçadas": "empreguiçar",
    "empreguiçado": "empreguiçar",
    "empreguiçados": "empreguiçar",
    "empreguiçai": "empreguiçar",
    "empreguiçais": "empreguiçar",
    "empreguiçam": "empreguiçar",
    "empreguiçamo": "empreguiçar",
    "empreguiçamos": "empreguiçar",
    "empreguiçando": "empreguiçar",
    "empreguiçara": "empreguiçar",
    "empreguiçaram": "empreguiçar",
    "empreguiçaras": "empreguiçar",
    "empreguiçarde": "empreguiçar",
    "empreguiçardes": "empreguiçar",
    "empreguiçare": "empreguiçar",
    "empreguiçarei": "empreguiçar",
    "empreguiçareis": "empreguiçar",
    "empreguiçarem": "empreguiçar",
    "empreguiçaremos": "empreguiçar",
    "empreguiçares": "empreguiçar",
    "empreguiçaria": "empreguiçar",
    "empreguiçariam": "empreguiçar",
    "empreguiçarias": "empreguiçar",
    "empreguiçarmo": "empreguiçar",
    "empreguiçarmos": "empreguiçar",
    "empreguiçará": "empreguiçar",
    "empreguiçarás": "empreguiçar",
    "empreguiçarão": "empreguiçar",
    "empreguiçaríamos": "empreguiçar",
    "empreguiçaríeis": "empreguiçar",
    "empreguiças": "empreguiçar",
    "empreguiçasse": "empreguiçar",
    "empreguiçassem": "empreguiçar",
    "empreguiçasses": "empreguiçar",
    "empreguiçaste": "empreguiçar",
    "empreguiçastes": "empreguiçar",
    "empreguiçava": "empreguiçar",
    "empreguiçavam": "empreguiçar",
    "empreguiçavas": "empreguiçar",
    "empreguiço": "empreguiçar",
    "empreguiçou": "empreguiçar",
    "empreguiçá": "empreguiçar",
    "empreguiçámo": "empreguiçar",
    "empreguiçámos": "empreguiçar",
    "empreguiçáramo": "empreguiçar",
    "empreguiçáramos": "empreguiçar",
    "empreguiçárei": "empreguiçar",
    "empreguiçáreis": "empreguiçar",
    "empreguiçásseis": "empreguiçar",
    "empreguiçássemos": "empreguiçar",
    "empreguiçávamo": "empreguiçar",
    "empreguiçávamos": "empreguiçar",
    "empreguiçávei": "empreguiçar",
    "empreguiçáveis": "empreguiçar",
    "empregá": "empregar",
    "empregámo": "empregar",
    "empregámos": "empregar",
    "empregáramo": "empregar",
    "empregáramos": "empregar",
    "empregárei": "empregar",
    "empregáreis": "empregar",
    "empregásseis": "empregar",
    "empregássemos": "empregar",
    "empregávamo": "empregar",
    "empregávamos": "empregar",
    "empregávei": "empregar",
    "empregáveis": "empregável",
    "empreita": "empreitar",
    "empreitada": "empreitar",
    "empreitadas": "empreitar",
    "empreitado": "empreitar",
    "empreitados": "empreitar",
    "empreitai": "empreitar",
    "empreitais": "empreitar",
    "empreitam": "empreitar",
    "empreitamo": "empreitar",
    "empreitamos": "empreitar",
    "empreitando": "empreitar",
    "empreitara": "empreitar",
    "empreitaram": "empreitar",
    "empreitaras": "empreitar",
    "empreitarde": "empreitar",
    "empreitardes": "empreitar",
    "empreitare": "empreitar",
    "empreitarei": "empreitar",
    "empreitareis": "empreitar",
    "empreitarem": "empreitar",
    "empreitaremos": "empreitar",
    "empreitares": "empreitar",
    "empreitaria": "empreitar",
    "empreitariam": "empreitar",
    "empreitarias": "empreitar",
    "empreitarmo": "empreitar",
    "empreitarmos": "empreitar",
    "empreitará": "empreitar",
    "empreitarás": "empreitar",
    "empreitarão": "empreitar",
    "empreitaríamos": "empreitar",
    "empreitaríeis": "empreitar",
    "empreitas": "empreitar",
    "empreitasse": "empreitar",
    "empreitassem": "empreitar",
    "empreitasses": "empreitar",
    "empreitaste": "empreitar",
    "empreitastes": "empreitar",
    "empreitava": "empreitar",
    "empreitavam": "empreitar",
    "empreitavas": "empreitar",
    "empreite": "empreitar",
    "empreitei": "empreitar",
    "empreiteira": "empreiteiro",
    "empreiteiras": "empreiteiro",
    "empreiteiros": "empreiteiro",
    "empreiteis": "empreitar",
    "empreitem": "empreitar",
    "empreitemo": "empreitar",
    "empreitemos": "empreitar",
    "empreites": "empreitar",
    "empreito": "empreitar",
    "empreitou": "empreitar",
    "empreitá": "empreitar",
    "empreitámo": "empreitar",
    "empreitámos": "empreitar",
    "empreitáramo": "empreitar",
    "empreitáramos": "empreitar",
    "empreitárei": "empreitar",
    "empreitáreis": "empreitar",
    "empreitásseis": "empreitar",
    "empreitássemos": "empreitar",
    "empreitávamo": "empreitar",
    "empreitávamos": "empreitar",
    "empreitávei": "empreitar",
    "empreitáveis": "empreitar",
    "emprenha": "emprenhar",
    "emprenhada": "emprenhar",
    "emprenhadas": "emprenhar",
    "emprenhado": "emprenhar",
    "emprenhadora": "emprenhador",
    "emprenhadoras": "emprenhador",
    "emprenhadores": "emprenhador",
    "emprenhados": "emprenhar",
    "emprenhai": "emprenhar",
    "emprenhais": "emprenhar",
    "emprenham": "emprenhar",
    "emprenhamo": "emprenhar",
    "emprenhamos": "emprenhar",
    "emprenhando": "emprenhar",
    "emprenhara": "emprenhar",
    "emprenharam": "emprenhar",
    "emprenharas": "emprenhar",
    "emprenharde": "emprenhar",
    "emprenhardes": "emprenhar",
    "emprenhare": "emprenhar",
    "emprenharei": "emprenhar",
    "emprenhareis": "emprenhar",
    "emprenharem": "emprenhar",
    "emprenharemos": "emprenhar",
    "emprenhares": "emprenhar",
    "emprenharia": "emprenhar",
    "emprenhariam": "emprenhar",
    "emprenharias": "emprenhar",
    "emprenharmo": "emprenhar",
    "emprenharmos": "emprenhar",
    "emprenhará": "emprenhar",
    "emprenharás": "emprenhar",
    "emprenharão": "emprenhar",
    "emprenharíamos": "emprenhar",
    "emprenharíeis": "emprenhar",
    "emprenhas": "emprenhar",
    "emprenhasse": "emprenhar",
    "emprenhassem": "emprenhar",
    "emprenhasses": "emprenhar",
    "emprenhaste": "emprenhar",
    "emprenhastes": "emprenhar",
    "emprenhava": "emprenhar",
    "emprenhavam": "emprenhar",
    "emprenhavas": "emprenhar",
    "emprenhe": "emprenhar",
    "emprenhei": "emprenhar",
    "emprenheis": "emprenhar",
    "emprenhem": "emprenhar",
    "emprenhemo": "emprenhar",
    "emprenhemos": "emprenhar",
    "emprenhes": "emprenhar",
    "emprenho": "emprenhar",
    "emprenhou": "emprenhar",
    "emprenhá": "emprenhar",
    "emprenhámo": "emprenhar",
    "emprenhámos": "emprenhar",
    "emprenháramo": "emprenhar",
    "emprenháramos": "emprenhar",
    "emprenhárei": "emprenhar",
    "emprenháreis": "emprenhar",
    "emprenhásseis": "emprenhar",
    "emprenhássemos": "emprenhar",
    "emprenhávamo": "emprenhar",
    "emprenhávamos": "emprenhar",
    "emprenhávei": "emprenhar",
    "emprenháveis": "emprenhar",
    "empresa": "empresar",
    "empresada": "empresar",
    "empresadas": "empresar",
    "empresado": "empresar",
    "empresadora": "empresador",
    "empresadoras": "empresador",
    "empresadores": "empresador",
    "empresados": "empresar",
    "empresai": "empresar",
    "empresais": "empresar",
    "empresam": "empresar",
    "empresamo": "empresar",
    "empresamos": "empresar",
    "empresando": "empresar",
    "empresara": "empresar",
    "empresaram": "empresar",
    "empresaras": "empresar",
    "empresarde": "empresar",
    "empresardes": "empresar",
    "empresare": "empresar",
    "empresarei": "empresar",
    "empresareis": "empresar",
    "empresarem": "empresar",
    "empresaremos": "empresar",
    "empresares": "empresar",
    "empresaria": "empresar",
    "empresariados": "empresariado",
    "empresariais": "empresarial",
    "empresariam": "empresar",
    "empresarias": "empresar",
    "empresarmo": "empresar",
    "empresarmos": "empresar",
    "empresará": "empresar",
    "empresarás": "empresar",
    "empresarão": "empresar",
    "empresaríamos": "empresar",
    "empresaríeis": "empresar",
    "empresas": "empresar",
    "empresasse": "empresar",
    "empresassem": "empresar",
    "empresasses": "empresar",
    "empresaste": "empresar",
    "empresastes": "empresar",
    "empresava": "empresar",
    "empresavam": "empresar",
    "empresavas": "empresar",
    "emprese": "empresar",
    "empresei": "empresar",
    "empreseis": "empresar",
    "empresem": "empresar",
    "empresemo": "empresar",
    "empresemos": "empresar",
    "empreses": "empresar",
    "empreso": "empresar",
    "empresou": "empresar",
    "empresta": "emprestar",
    "emprestada": "emprestar",
    "emprestadada": "emprestadar",
    "emprestadadas": "emprestadar",
    "emprestadado": "emprestadar",
    "emprestadados": "emprestadar",
    "emprestadai": "emprestadar",
    "emprestadais": "emprestadar",
    "emprestadam": "emprestadar",
    "emprestadamo": "emprestadar",
    "emprestadamos": "emprestadar",
    "emprestadando": "emprestadar",
    "emprestadara": "emprestadar",
    "emprestadaram": "emprestadar",
    "emprestadaras": "emprestadar",
    "emprestadarde": "emprestadar",
    "emprestadardes": "emprestadar",
    "emprestadare": "emprestadar",
    "emprestadarei": "emprestadar",
    "emprestadareis": "emprestadar",
    "emprestadarem": "emprestadar",
    "emprestadaremos": "emprestadar",
    "emprestadares": "emprestadar",
    "emprestadaria": "emprestadar",
    "emprestadariam": "emprestadar",
    "emprestadarias": "emprestadar",
    "emprestadarmo": "emprestadar",
    "emprestadarmos": "emprestadar",
    "emprestadará": "emprestadar",
    "emprestadarás": "emprestadar",
    "emprestadarão": "emprestadar",
    "emprestadaríamos": "emprestadar",
    "emprestadaríeis": "emprestadar",
    "emprestadas": "emprestar",
    "emprestadasse": "emprestadar",
    "emprestadassem": "emprestadar",
    "emprestadasses": "emprestadar",
    "emprestadaste": "emprestadar",
    "emprestadastes": "emprestadar",
    "emprestadava": "emprestadar",
    "emprestadavam": "emprestadar",
    "emprestadavas": "emprestadar",
    "emprestade": "emprestadar",
    "emprestadei": "emprestadar",
    "emprestadeis": "emprestadar",
    "emprestadem": "emprestadar",
    "emprestademo": "emprestadar",
    "emprestademos": "emprestadar",
    "emprestades": "emprestadar",
    "emprestadia": "emprestadio",
    "emprestadias": "emprestadio",
    "emprestadios": "emprestadio",
    "emprestado": "emprestar",
    "emprestadora": "emprestador",
    "emprestadoras": "emprestador",
    "emprestadores": "emprestador",
    "emprestados": "emprestar",
    "emprestadou": "emprestadar",
    "emprestadá": "emprestadar",
    "emprestadámo": "emprestadar",
    "emprestadámos": "emprestadar",
    "emprestadáramo": "emprestadar",
    "emprestadáramos": "emprestadar",
    "emprestadárei": "emprestadar",
    "emprestadáreis": "emprestadar",
    "emprestadásseis": "emprestadar",
    "emprestadássemos": "emprestadar",
    "emprestadávamo": "emprestadar",
    "emprestadávamos": "emprestadar",
    "emprestadávei": "emprestadar",
    "emprestadáveis": "emprestadar",
    "emprestai": "emprestar",
    "emprestais": "emprestar",
    "emprestam": "emprestar",
    "emprestamo": "emprestar",
    "emprestamos": "emprestar",
    "emprestando": "emprestar",
    "emprestara": "emprestar",
    "emprestaram": "emprestar",
    "emprestaras": "emprestar",
    "emprestarde": "emprestar",
    "emprestardes": "emprestar",
    "emprestare": "emprestar",
    "emprestarei": "emprestar",
    "emprestareis": "emprestar",
    "emprestarem": "emprestar",
    "emprestaremos": "emprestar",
    "emprestares": "emprestar",
    "emprestaria": "emprestar",
    "emprestariam": "emprestar",
    "emprestarias": "emprestar",
    "emprestarmo": "emprestar",
    "emprestarmos": "emprestar",
    "emprestará": "emprestar",
    "emprestarás": "emprestar",
    "emprestarão": "emprestar",
    "emprestaríamos": "emprestar",
    "emprestaríeis": "emprestar",
    "emprestas": "emprestar",
    "emprestasse": "emprestar",
    "emprestassem": "emprestar",
    "emprestasses": "emprestar",
    "emprestaste": "emprestar",
    "emprestastes": "emprestar",
    "emprestava": "emprestar",
    "emprestavam": "emprestar",
    "emprestavas": "emprestar",
    "empreste": "emprestar",
    "emprestei": "emprestar",
    "empresteis": "emprestar",
    "emprestem": "emprestar",
    "emprestemo": "emprestar",
    "emprestemos": "emprestar",
    "emprestes": "emprestar",
    "empresto": "emprestar",
    "emprestou": "emprestar",
    "emprestá": "emprestar",
    "emprestámo": "emprestar",
    "emprestámos": "emprestar",
    "emprestáramo": "emprestar",
    "emprestáramos": "emprestar",
    "emprestárei": "emprestar",
    "emprestáreis": "emprestar",
    "emprestásseis": "emprestar",
    "emprestássemos": "emprestar",
    "emprestávamo": "emprestar",
    "emprestávamos": "emprestar",
    "emprestávei": "emprestar",
    "emprestáveis": "emprestar",
    "empresá": "empresar",
    "empresámo": "empresar",
    "empresámos": "empresar",
    "empresáramo": "empresar",
    "empresáramos": "empresar",
    "empresárei": "empresar",
    "empresáreis": "empresar",
    "empresária": "empresário",
    "empresárias": "empresário",
    "empresários": "empresário",
    "empresásseis": "empresar",
    "empresássemos": "empresar",
    "empresávamo": "empresar",
    "empresávamos": "empresar",
    "empresávei": "empresar",
    "empresáveis": "empresar",
    "empretece": "empretecer",
    "empretecei": "empretecer",
    "empreteceis": "empretecer",
    "empretecem": "empretecer",
    "empretecemo": "empretecer",
    "empretecemos": "empretecer",
    "empretecendo": "empretecer",
    "empretecera": "empretecer",
    "empreteceram": "empretecer",
    "empreteceras": "empretecer",
    "empretecerde": "empretecer",
    "empretecerdes": "empretecer",
    "empretecere": "empretecer",
    "empretecerei": "empretecer",
    "empretecereis": "empretecer",
    "empretecerem": "empretecer",
    "empreteceremos": "empretecer",
    "empreteceres": "empretecer",
    "empreteceria": "empretecer",
    "empreteceriam": "empretecer",
    "empretecerias": "empretecer",
    "empretecermo": "empretecer",
    "empretecermos": "empretecer",
    "empretecerá": "empretecer",
    "empretecerás": "empretecer",
    "empretecerão": "empretecer",
    "empreteceríamos": "empretecer",
    "empreteceríeis": "empretecer",
    "empreteces": "empretecer",
    "empretecesse": "empretecer",
    "empretecessem": "empretecer",
    "empretecesses": "empretecer",
    "empreteceste": "empretecer",
    "empretecestes": "empretecer",
    "empreteceu": "empretecer",
    "empreteci": "empretecer",
    "empretecia": "empretecer",
    "empreteciam": "empretecer",
    "empretecias": "empretecer",
    "empretecida": "empretecer",
    "empretecidas": "empretecer",
    "empretecido": "empretecer",
    "empretecidos": "empretecer",
    "empretecê": "empretecer",
    "empretecêramo": "empretecer",
    "empretecêramos": "empretecer",
    "empretecêrei": "empretecer",
    "empretecêreis": "empretecer",
    "empretecêsseis": "empretecer",
    "empretecêssemos": "empretecer",
    "empretecíamo": "empretecer",
    "empretecíamos": "empretecer",
    "empretecíei": "empretecer",
    "empretecíeis": "empretecer",
    "empreteça": "empretecer",
    "empreteçais": "empretecer",
    "empreteçam": "empretecer",
    "empreteçamo": "empretecer",
    "empreteçamos": "empretecer",
    "empreteças": "empretecer",
    "empreteço": "empretecer",
    "emproa": "emproar",
    "emproada": "emproar",
    "emproadas": "emproar",
    "emproado": "emproar",
    "emproados": "emproar",
    "emproai": "emproar",
    "emproais": "emproar",
    "emproam": "emproar",
    "emproamo": "emproar",
    "emproamos": "emproar",
    "emproando": "emproar",
    "emproara": "emproar",
    "emproaram": "emproar",
    "emproaras": "emproar",
    "emproardes": "emproar",
    "emproarei": "emproar",
    "emproareis": "emproar",
    "emproarem": "emproar",
    "emproaremos": "emproar",
    "emproares": "emproar",
    "emproaria": "emproar",
    "emproariam": "emproar",
    "emproarias": "emproar",
    "emproarmo": "emproar",
    "emproarmos": "emproar",
    "emproará": "emproar",
    "emproarás": "emproar",
    "emproarão": "emproar",
    "emproaríamos": "emproar",
    "emproaríeis": "emproar",
    "emproas": "emproar",
    "emproasse": "emproar",
    "emproassem": "emproar",
    "emproasses": "emproar",
    "emproaste": "emproar",
    "emproastes": "emproar",
    "emproava": "emproar",
    "emproavam": "emproar",
    "emproavas": "emproar",
    "emproe": "emproar",
    "emproei": "emproar",
    "emproeis": "emproar",
    "emproem": "emproar",
    "emproemo": "emproar",
    "emproemos": "emproar",
    "emproes": "emproar",
    "emproo": "emproar",
    "emproou": "emproar",
    "emproámo": "emproar",
    "emproámos": "emproar",
    "emproáramo": "emproar",
    "emproáramos": "emproar",
    "emproáreis": "emproar",
    "emproásseis": "emproar",
    "emproássemos": "emproar",
    "emproávamo": "emproar",
    "emproávamos": "emproar",
    "emproáveis": "emproar",
    "empréstimos": "empréstimo",
    "empubesce": "empubescer",
    "empubescei": "empubescer",
    "empubesceis": "empubescer",
    "empubescem": "empubescer",
    "empubescemo": "empubescer",
    "empubescemos": "empubescer",
    "empubescendo": "empubescer",
    "empubescera": "empubescer",
    "empubesceram": "empubescer",
    "empubesceras": "empubescer",
    "empubescerdes": "empubescer",
    "empubescerei": "empubescer",
    "empubescereis": "empubescer",
    "empubescerem": "empubescer",
    "empubesceremos": "empubescer",
    "empubesceres": "empubescer",
    "empubesceria": "empubescer",
    "empubesceriam": "empubescer",
    "empubescerias": "empubescer",
    "empubescermo": "empubescer",
    "empubescermos": "empubescer",
    "empubescerá": "empubescer",
    "empubescerás": "empubescer",
    "empubescerão": "empubescer",
    "empubesceríamos": "empubescer",
    "empubesceríeis": "empubescer",
    "empubesces": "empubescer",
    "empubescesse": "empubescer",
    "empubescessem": "empubescer",
    "empubescesses": "empubescer",
    "empubesceste": "empubescer",
    "empubescestes": "empubescer",
    "empubesceu": "empubescer",
    "empubesci": "empubescer",
    "empubescia": "empubescer",
    "empubesciam": "empubescer",
    "empubescias": "empubescer",
    "empubescida": "empubescer",
    "empubescidas": "empubescer",
    "empubescido": "empubescer",
    "empubescidos": "empubescer",
    "empubescêramo": "empubescer",
    "empubescêramos": "empubescer",
    "empubescêreis": "empubescer",
    "empubescêsseis": "empubescer",
    "empubescêssemos": "empubescer",
    "empubescíamo": "empubescer",
    "empubescíamos": "empubescer",
    "empubescíeis": "empubescer",
    "empubesça": "empubescer",
    "empubesçais": "empubescer",
    "empubesçam": "empubescer",
    "empubesçamo": "empubescer",
    "empubesçamos": "empubescer",
    "empubesças": "empubescer",
    "empubesço": "empubescer",
    "empulha": "empulhar",
    "empulhada": "empulhar",
    "empulhadas": "empulhar",
    "empulhado": "empulhar",
    "empulhados": "empulhar",
    "empulhai": "empulhar",
    "empulhais": "empulhar",
    "empulham": "empulhar",
    "empulhamo": "empulhar",
    "empulhamos": "empulhar",
    "empulhando": "empulhar",
    "empulhara": "empulhar",
    "empulharam": "empulhar",
    "empulharas": "empulhar",
    "empulharde": "empulhar",
    "empulhardes": "empulhar",
    "empulhare": "empulhar",
    "empulharei": "empulhar",
    "empulhareis": "empulhar",
    "empulharem": "empulhar",
    "empulharemos": "empulhar",
    "empulhares": "empulhar",
    "empulharia": "empulhar",
    "empulhariam": "empulhar",
    "empulharias": "empulhar",
    "empulharmo": "empulhar",
    "empulharmos": "empulhar",
    "empulhará": "empulhar",
    "empulharás": "empulhar",
    "empulharão": "empulhar",
    "empulharíamos": "empulhar",
    "empulharíeis": "empulhar",
    "empulhas": "empulhar",
    "empulhasse": "empulhar",
    "empulhassem": "empulhar",
    "empulhasses": "empulhar",
    "empulhaste": "empulhar",
    "empulhastes": "empulhar",
    "empulhava": "empulhar",
    "empulhavam": "empulhar",
    "empulhavas": "empulhar",
    "empulhações": "empulhação",
    "empulhe": "empulhar",
    "empulhei": "empulhar",
    "empulheis": "empulhar",
    "empulhem": "empulhar",
    "empulhemo": "empulhar",
    "empulhemos": "empulhar",
    "empulhes": "empulhar",
    "empulho": "empulhar",
    "empulhou": "empulhar",
    "empulhá": "empulhar",
    "empulhámo": "empulhar",
    "empulhámos": "empulhar",
    "empulháramo": "empulhar",
    "empulháramos": "empulhar",
    "empulhárei": "empulhar",
    "empulháreis": "empulhar",
    "empulhásseis": "empulhar",
    "empulhássemos": "empulhar",
    "empulhávamo": "empulhar",
    "empulhávamos": "empulhar",
    "empulhávei": "empulhar",
    "empulháveis": "empulhar",
    "empulmonizações": "empulmonização",
    "empunha": "empunhar",
    "empunhada": "empunhar",
    "empunhadas": "empunhar",
    "empunhado": "empunhar",
    "empunhados": "empunhar",
    "empunhaduras": "empunhadura",
    "empunhai": "empunhar",
    "empunhais": "empunhar",
    "empunham": "empunhar",
    "empunhamentos": "empunhamento",
    "empunhamo": "empunhar",
    "empunhamos": "empunhar",
    "empunhando": "empunhar",
    "empunhara": "empunhar",
    "empunharam": "empunhar",
    "empunharas": "empunhar",
    "empunharde": "empunhar",
    "empunhardes": "empunhar",
    "empunhare": "empunhar",
    "empunharei": "empunhar",
    "empunhareis": "empunhar",
    "empunharem": "empunhar",
    "empunharemos": "empunhar",
    "empunhares": "empunhar",
    "empunharia": "empunhar",
    "empunhariam": "empunhar",
    "empunharias": "empunhar",
    "empunharmo": "empunhar",
    "empunharmos": "empunhar",
    "empunhará": "empunhar",
    "empunharás": "empunhar",
    "empunharão": "empunhar",
    "empunharíamos": "empunhar",
    "empunharíeis": "empunhar",
    "empunhas": "empunhar",
    "empunhasse": "empunhar",
    "empunhassem": "empunhar",
    "empunhasses": "empunhar",
    "empunhaste": "empunhar",
    "empunhastes": "empunhar",
    "empunhava": "empunhar",
    "empunhavam": "empunhar",
    "empunhavas": "empunhar",
    "empunhe": "empunhar",
    "empunhei": "empunhar",
    "empunheis": "empunhar",
    "empunhem": "empunhar",
    "empunhemo": "empunhar",
    "empunhemos": "empunhar",
    "empunhes": "empunhar",
    "empunho": "empunhar",
    "empunhou": "empunhar",
    "empunhá": "empunhar",
    "empunhámo": "empunhar",
    "empunhámos": "empunhar",
    "empunháramo": "empunhar",
    "empunháramos": "empunhar",
    "empunhárei": "empunhar",
    "empunháreis": "empunhar",
    "empunhásseis": "empunhar",
    "empunhássemos": "empunhar",
    "empunhávamo": "empunhar",
    "empunhávamos": "empunhar",
    "empunhávei": "empunhar",
    "empunháveis": "empunhar",
    "empurpura": "empurpurar",
    "empurpurada": "empurpurar",
    "empurpuradas": "empurpurar",
    "empurpurado": "empurpurar",
    "empurpurados": "empurpurar",
    "empurpurai": "empurpurar",
    "empurpurais": "empurpurar",
    "empurpuram": "empurpurar",
    "empurpuramo": "empurpurar",
    "empurpuramos": "empurpurar",
    "empurpurando": "empurpurar",
    "empurpurara": "empurpurar",
    "empurpuraram": "empurpurar",
    "empurpuraras": "empurpurar",
    "empurpurarde": "empurpurar",
    "empurpurardes": "empurpurar",
    "empurpurare": "empurpurar",
    "empurpurarei": "empurpurar",
    "empurpurareis": "empurpurar",
    "empurpurarem": "empurpurar",
    "empurpuraremos": "empurpurar",
    "empurpurares": "empurpurar",
    "empurpuraria": "empurpurar",
    "empurpurariam": "empurpurar",
    "empurpurarias": "empurpurar",
    "empurpurarmo": "empurpurar",
    "empurpurarmos": "empurpurar",
    "empurpurará": "empurpurar",
    "empurpurarás": "empurpurar",
    "empurpurarão": "empurpurar",
    "empurpuraríamos": "empurpurar",
    "empurpuraríeis": "empurpurar",
    "empurpuras": "empurpurar",
    "empurpurasse": "empurpurar",
    "empurpurassem": "empurpurar",
    "empurpurasses": "empurpurar",
    "empurpuraste": "empurpurar",
    "empurpurastes": "empurpurar",
    "empurpurava": "empurpurar",
    "empurpuravam": "empurpurar",
    "empurpuravas": "empurpurar",
    "empurpure": "empurpurar",
    "empurpurece": "empurpurecer",
    "empurpurecei": "empurpurecer",
    "empurpureceis": "empurpurecer",
    "empurpurecem": "empurpurecer",
    "empurpurecemo": "empurpurecer",
    "empurpurecemos": "empurpurecer",
    "empurpurecendo": "empurpurecer",
    "empurpurecera": "empurpurecer",
    "empurpureceram": "empurpurecer",
    "empurpureceras": "empurpurecer",
    "empurpurecerde": "empurpurecer",
    "empurpurecerdes": "empurpurecer",
    "empurpurecere": "empurpurecer",
    "empurpurecerei": "empurpurecer",
    "empurpurecereis": "empurpurecer",
    "empurpurecerem": "empurpurecer",
    "empurpureceremos": "empurpurecer",
    "empurpureceres": "empurpurecer",
    "empurpureceria": "empurpurecer",
    "empurpureceriam": "empurpurecer",
    "empurpurecerias": "empurpurecer",
    "empurpurecermo": "empurpurecer",
    "empurpurecermos": "empurpurecer",
    "empurpurecerá": "empurpurecer",
    "empurpurecerás": "empurpurecer",
    "empurpurecerão": "empurpurecer",
    "empurpureceríamos": "empurpurecer",
    "empurpureceríeis": "empurpurecer",
    "empurpureces": "empurpurecer",
    "empurpurecesse": "empurpurecer",
    "empurpurecessem": "empurpurecer",
    "empurpurecesses": "empurpurecer",
    "empurpureceste": "empurpurecer",
    "empurpurecestes": "empurpurecer",
    "empurpureceu": "empurpurecer",
    "empurpureci": "empurpurecer",
    "empurpurecia": "empurpurecer",
    "empurpureciam": "empurpurecer",
    "empurpurecias": "empurpurecer",
    "empurpurecida": "empurpurecer",
    "empurpurecidas": "empurpurecer",
    "empurpurecido": "empurpurecer",
    "empurpurecidos": "empurpurecer",
    "empurpurecê": "empurpurecer",
    "empurpurecêramo": "empurpurecer",
    "empurpurecêramos": "empurpurecer",
    "empurpurecêrei": "empurpurecer",
    "empurpurecêreis": "empurpurecer",
    "empurpurecêsseis": "empurpurecer",
    "empurpurecêssemos": "empurpurecer",
    "empurpurecíamo": "empurpurecer",
    "empurpurecíamos": "empurpurecer",
    "empurpurecíei": "empurpurecer",
    "empurpurecíeis": "empurpurecer",
    "empurpurei": "empurpurar",
    "empurpureis": "empurpurar",
    "empurpurem": "empurpurar",
    "empurpuremo": "empurpurar",
    "empurpuremos": "empurpurar",
    "empurpures": "empurpurar",
    "empurpureça": "empurpurecer",
    "empurpureçais": "empurpurecer",
    "empurpureçam": "empurpurecer",
    "empurpureçamo": "empurpurecer",
    "empurpureçamos": "empurpurecer",
    "empurpureças": "empurpurecer",
    "empurpureço": "empurpurecer",
    "empurpuro": "empurpurar",
    "empurpurou": "empurpurar",
    "empurpurá": "empurpurar",
    "empurpurámo": "empurpurar",
    "empurpurámos": "empurpurar",
    "empurpuráramo": "empurpurar",
    "empurpuráramos": "empurpurar",
    "empurpurárei": "empurpurar",
    "empurpuráreis": "empurpurar",
    "empurpurásseis": "empurpurar",
    "empurpurássemos": "empurpurar",
    "empurpurávamo": "empurpurar",
    "empurpurávamos": "empurpurar",
    "empurpurávei": "empurpurar",
    "empurpuráveis": "empurpurar",
    "empurra": "empurrar",
    "empurrada": "empurrar",
    "empurradas": "empurrar",
    "empurrado": "empurrar",
    "empurradora": "empurrador",
    "empurradoras": "empurrador",
    "empurradores": "empurrador",
    "empurrados": "empurrar",
    "empurrai": "empurrar",
    "empurrais": "empurrar",
    "empurram": "empurrar",
    "empurramo": "empurrar",
    "empurramos": "empurrar",
    "empurrando": "empurrar",
    "empurrara": "empurrar",
    "empurraram": "empurrar",
    "empurraras": "empurrar",
    "empurrarde": "empurrar",
    "empurrardes": "empurrar",
    "empurrare": "empurrar",
    "empurrarei": "empurrar",
    "empurrareis": "empurrar",
    "empurrarem": "empurrar",
    "empurraremos": "empurrar",
    "empurrares": "empurrar",
    "empurraria": "empurrar",
    "empurrariam": "empurrar",
    "empurrarias": "empurrar",
    "empurrarmo": "empurrar",
    "empurrarmos": "empurrar",
    "empurrará": "empurrar",
    "empurrarás": "empurrar",
    "empurrarão": "empurrar",
    "empurraríamos": "empurrar",
    "empurraríeis": "empurrar",
    "empurras": "empurrar",
    "empurrasse": "empurrar",
    "empurrassem": "empurrar",
    "empurrasses": "empurrar",
    "empurraste": "empurrar",
    "empurrastes": "empurrar",
    "empurrava": "empurrar",
    "empurravam": "empurrar",
    "empurravas": "empurrar",
    "empurrações": "empurração",
    "empurre": "empurrar",
    "empurrei": "empurrar",
    "empurreis": "empurrar",
    "empurrem": "empurrar",
    "empurremo": "empurrar",
    "empurremos": "empurrar",
    "empurres": "empurrar",
    "empurro": "empurrar",
    "empurros": "empurro",
    "empurrou": "empurrar",
    "empurrá": "empurrar",
    "empurrámo": "empurrar",
    "empurrámos": "empurrar",
    "empurráramo": "empurrar",
    "empurráramos": "empurrar",
    "empurrárei": "empurrar",
    "empurráreis": "empurrar",
    "empurrásseis": "empurrar",
    "empurrássemos": "empurrar",
    "empurrávamo": "empurrar",
    "empurrávamos": "empurrar",
    "empurrávei": "empurrar",
    "empurráveis": "empurrar",
    "empurrãozinho": "empurrão",
    "empurrãozito": "empurrão",
    "empurrões": "empurrão",
    "empurrõezinhos": "empurrão",
    "empurrõezitos": "empurrão",
    "empuxa": "empuxar",
    "empuxada": "empuxar",
    "empuxadas": "empuxar",
    "empuxado": "empuxar",
    "empuxadora": "empuxador",
    "empuxadoras": "empuxador",
    "empuxadores": "empuxador",
    "empuxados": "empuxar",
    "empuxai": "empuxar",
    "empuxais": "empuxar",
    "empuxam": "empuxar",
    "empuxamo": "empuxar",
    "empuxamos": "empuxar",
    "empuxando": "empuxar",
    "empuxara": "empuxar",
    "empuxaram": "empuxar",
    "empuxaras": "empuxar",
    "empuxarde": "empuxar",
    "empuxardes": "empuxar",
    "empuxare": "empuxar",
    "empuxarei": "empuxar",
    "empuxareis": "empuxar",
    "empuxarem": "empuxar",
    "empuxaremos": "empuxar",
    "empuxares": "empuxar",
    "empuxaria": "empuxar",
    "empuxariam": "empuxar",
    "empuxarias": "empuxar",
    "empuxarmo": "empuxar",
    "empuxarmos": "empuxar",
    "empuxará": "empuxar",
    "empuxarás": "empuxar",
    "empuxarão": "empuxar",
    "empuxaríamos": "empuxar",
    "empuxaríeis": "empuxar",
    "empuxas": "empuxar",
    "empuxasse": "empuxar",
    "empuxassem": "empuxar",
    "empuxasses": "empuxar",
    "empuxaste": "empuxar",
    "empuxastes": "empuxar",
    "empuxava": "empuxar",
    "empuxavam": "empuxar",
    "empuxavas": "empuxar",
    "empuxe": "empuxar",
    "empuxei": "empuxar",
    "empuxeis": "empuxar",
    "empuxem": "empuxar",
    "empuxemo": "empuxar",
    "empuxemos": "empuxar",
    "empuxes": "empuxar",
    "empuxo": "empuxar",
    "empuxos": "empuxo",
    "empuxou": "empuxar",
    "empuxá": "empuxar",
    "empuxámo": "empuxar",
    "empuxámos": "empuxar",
    "empuxáramo": "empuxar",
    "empuxáramos": "empuxar",
    "empuxárei": "empuxar",
    "empuxáreis": "empuxar",
    "empuxásseis": "empuxar",
    "empuxássemos": "empuxar",
    "empuxávamo": "empuxar",
    "empuxávamos": "empuxar",
    "empuxávei": "empuxar",
    "empuxáveis": "empuxar",
    "empuxões": "empuxão",
    "empá": "empar",
    "empáfia": "empáfio",
    "empáfias": "empáfio",
    "empáfios": "empáfio",
    "empámo": "empar",
    "empámos": "empar",
    "empáramo": "empar",
    "empáramos": "empar",
    "empárei": "empar",
    "empáreis": "empar",
    "empásseis": "empar",
    "empássemos": "empar",
    "empática": "empático",
    "empáticas": "empático",
    "empáticos": "empático",
    "empávamo": "empar",
    "empávamos": "empar",
    "empávei": "empar",
    "empáveis": "empar",
    "empíreos": "empíreo",
    "empírica": "empírico",
    "empíricas": "empírico",
    "empíricos": "empírico",
    "empórios": "empório",
    "emscheriana": "emscheriano",
    "emscherianas": "emscheriano",
    "emscherianos": "emscheriano",
    "emsiana": "emsiano",
    "emsianas": "emsiano",
    "emsianos": "emsiano",
    "emudece": "emudecer",
    "emudecei": "emudecer",
    "emudeceis": "emudecer",
    "emudecem": "emudecer",
    "emudecemo": "emudecer",
    "emudecemos": "emudecer",
    "emudecendo": "emudecer",
    "emudecera": "emudecer",
    "emudeceram": "emudecer",
    "emudeceras": "emudecer",
    "emudecerde": "emudecer",
    "emudecerdes": "emudecer",
    "emudecere": "emudecer",
    "emudecerei": "emudecer",
    "emudecereis": "emudecer",
    "emudecerem": "emudecer",
    "emudeceremos": "emudecer",
    "emudeceres": "emudecer",
    "emudeceria": "emudecer",
    "emudeceriam": "emudecer",
    "emudecerias": "emudecer",
    "emudecermo": "emudecer",
    "emudecermos": "emudecer",
    "emudecerá": "emudecer",
    "emudecerás": "emudecer",
    "emudecerão": "emudecer",
    "emudeceríamos": "emudecer",
    "emudeceríeis": "emudecer",
    "emudeces": "emudecer",
    "emudecesse": "emudecer",
    "emudecessem": "emudecer",
    "emudecesses": "emudecer",
    "emudeceste": "emudecer",
    "emudecestes": "emudecer",
    "emudeceu": "emudecer",
    "emudeci": "emudecer",
    "emudecia": "emudecer",
    "emudeciam": "emudecer",
    "emudecias": "emudecer",
    "emudecida": "emudecido",
    "emudecidas": "emudecido",
    "emudecido": "emudecer",
    "emudecidos": "emudecido",
    "emudecimentos": "emudecimento",
    "emudecê": "emudecer",
    "emudecêramo": "emudecer",
    "emudecêramos": "emudecer",
    "emudecêrei": "emudecer",
    "emudecêreis": "emudecer",
    "emudecêsseis": "emudecer",
    "emudecêssemos": "emudecer",
    "emudecíamo": "emudecer",
    "emudecíamos": "emudecer",
    "emudecíei": "emudecer",
    "emudecíeis": "emudecer",
    "emudeça": "emudecer",
    "emudeçais": "emudecer",
    "emudeçam": "emudecer",
    "emudeçamo": "emudecer",
    "emudeçamos": "emudecer",
    "emudeças": "emudecer",
    "emudeço": "emudecer",
    "emula": "emular",
    "emulada": "emular",
    "emuladas": "emular",
    "emulado": "emular",
    "emuladora": "emulador",
    "emuladoras": "emulador",
    "emuladores": "emulador",
    "emulados": "emular",
    "emulai": "emular",
    "emulais": "emular",
    "emulam": "emular",
    "emulamo": "emular",
    "emulamos": "emular",
    "emulando": "emular",
    "emulara": "emular",
    "emularam": "emular",
    "emularas": "emular",
    "emulardes": "emular",
    "emularei": "emular",
    "emulareis": "emular",
    "emularem": "emular",
    "emularemos": "emular",
    "emulares": "emular",
    "emularia": "emular",
    "emulariam": "emular",
    "emularias": "emular",
    "emularmo": "emular",
    "emularmos": "emular",
    "emulará": "emular",
    "emularás": "emular",
    "emularão": "emular",
    "emularíamos": "emular",
    "emularíeis": "emular",
    "emulas": "emular",
    "emulasse": "emular",
    "emulassem": "emular",
    "emulasses": "emular",
    "emulaste": "emular",
    "emulastes": "emular",
    "emulativa": "emulativo",
    "emulativas": "emulativo",
    "emulativos": "emulativo",
    "emulava": "emular",
    "emulavam": "emular",
    "emulavas": "emular",
    "emulações": "emulação",
    "emule": "emular",
    "emulei": "emular",
    "emuleis": "emular",
    "emulem": "emular",
    "emulemo": "emular",
    "emulemos": "emular",
    "emules": "emular",
    "emulgentes": "emulgente",
    "emuli": "emolir",
    "emulo": "emular",
    "emulou": "emular",
    "emulsificações": "emulsificação",
    "emulsinas": "emulsina",
    "emulsiona": "emulsionar",
    "emulsionada": "emulsionar",
    "emulsionadas": "emulsionar",
    "emulsionado": "emulsionar",
    "emulsionados": "emulsionar",
    "emulsionai": "emulsionar",
    "emulsionais": "emulsionar",
    "emulsionam": "emulsionar",
    "emulsionamo": "emulsionar",
    "emulsionamos": "emulsionar",
    "emulsionando": "emulsionar",
    "emulsionantes": "emulsionante",
    "emulsionara": "emulsionar",
    "emulsionaram": "emulsionar",
    "emulsionaras": "emulsionar",
    "emulsionarde": "emulsionar",
    "emulsionardes": "emulsionar",
    "emulsionare": "emulsionar",
    "emulsionarei": "emulsionar",
    "emulsionareis": "emulsionar",
    "emulsionarem": "emulsionar",
    "emulsionaremos": "emulsionar",
    "emulsionares": "emulsionar",
    "emulsionaria": "emulsionar",
    "emulsionariam": "emulsionar",
    "emulsionarias": "emulsionar",
    "emulsionarmo": "emulsionar",
    "emulsionarmos": "emulsionar",
    "emulsionará": "emulsionar",
    "emulsionarás": "emulsionar",
    "emulsionarão": "emulsionar",
    "emulsionaríamos": "emulsionar",
    "emulsionaríeis": "emulsionar",
    "emulsionas": "emulsionar",
    "emulsionasse": "emulsionar",
    "emulsionassem": "emulsionar",
    "emulsionasses": "emulsionar",
    "emulsionaste": "emulsionar",
    "emulsionastes": "emulsionar",
    "emulsionava": "emulsionar",
    "emulsionavam": "emulsionar",
    "emulsionavas": "emulsionar",
    "emulsione": "emulsionar",
    "emulsionei": "emulsionar",
    "emulsioneis": "emulsionar",
    "emulsionem": "emulsionar",
    "emulsionemo": "emulsionar",
    "emulsionemos": "emulsionar",
    "emulsiones": "emulsionar",
    "emulsiono": "emulsionar",
    "emulsionou": "emulsionar",
    "emulsioná": "emulsionar",
    "emulsionámo": "emulsionar",
    "emulsionámos": "emulsionar",
    "emulsionáramo": "emulsionar",
    "emulsionáramos": "emulsionar",
    "emulsionárei": "emulsionar",
    "emulsionáreis": "emulsionar",
    "emulsionásseis": "emulsionar",
    "emulsionássemos": "emulsionar",
    "emulsionávamo": "emulsionar",
    "emulsionávamos": "emulsionar",
    "emulsionávei": "emulsionar",
    "emulsionáveis": "emulsionar",
    "emulsiva": "emulsivo",
    "emulsivas": "emulsivo",
    "emulsivos": "emulsivo",
    "emulsões": "emulsão",
    "emulámo": "emular",
    "emulámos": "emular",
    "emuláramo": "emular",
    "emuláramos": "emular",
    "emuláreis": "emular",
    "emulásseis": "emular",
    "emulássemos": "emular",
    "emulávamo": "emular",
    "emulávamos": "emular",
    "emuláveis": "emular",
    "emunctória": "emunctório",
    "emunctórias": "emunctório",
    "emunctórios": "emunctório",
    "emunda": "emundar",
    "emundada": "emundar",
    "emundadas": "emundar",
    "emundado": "emundar",
    "emundados": "emundar",
    "emundai": "emundar",
    "emundais": "emundar",
    "emundam": "emundar",
    "emundamo": "emundar",
    "emundamos": "emundar",
    "emundando": "emundar",
    "emundara": "emundar",
    "emundaram": "emundar",
    "emundaras": "emundar",
    "emundarde": "emundar",
    "emundardes": "emundar",
    "emundare": "emundar",
    "emundarei": "emundar",
    "emundareis": "emundar",
    "emundarem": "emundar",
    "emundaremos": "emundar",
    "emundares": "emundar",
    "emundaria": "emundar",
    "emundariam": "emundar",
    "emundarias": "emundar",
    "emundarmo": "emundar",
    "emundarmos": "emundar",
    "emundará": "emundar",
    "emundarás": "emundar",
    "emundarão": "emundar",
    "emundaríamos": "emundar",
    "emundaríeis": "emundar",
    "emundas": "emundar",
    "emundasse": "emundar",
    "emundassem": "emundar",
    "emundasses": "emundar",
    "emundaste": "emundar",
    "emundastes": "emundar",
    "emundava": "emundar",
    "emundavam": "emundar",
    "emundavas": "emundar",
    "emundações": "emundação",
    "emunde": "emundar",
    "emundei": "emundar",
    "emundeis": "emundar",
    "emundem": "emundar",
    "emundemo": "emundar",
    "emundemos": "emundar",
    "emundes": "emundar",
    "emundo": "emundar",
    "emundou": "emundar",
    "emundá": "emundar",
    "emundámo": "emundar",
    "emundámos": "emundar",
    "emundáramo": "emundar",
    "emundáramos": "emundar",
    "emundárei": "emundar",
    "emundáreis": "emundar",
    "emundásseis": "emundar",
    "emundássemos": "emundar",
    "emundávamo": "emundar",
    "emundávamos": "emundar",
    "emundávei": "emundar",
    "emundáveis": "emundar",
    "emurchece": "emurchecer",
    "emurchecei": "emurchecer",
    "emurcheceis": "emurchecer",
    "emurchecem": "emurchecer",
    "emurchecemo": "emurchecer",
    "emurchecemos": "emurchecer",
    "emurchecendo": "emurchecer",
    "emurchecera": "emurchecer",
    "emurcheceram": "emurchecer",
    "emurcheceras": "emurchecer",
    "emurchecerdes": "emurchecer",
    "emurchecerei": "emurchecer",
    "emurchecereis": "emurchecer",
    "emurchecerem": "emurchecer",
    "emurcheceremos": "emurchecer",
    "emurcheceres": "emurchecer",
    "emurcheceria": "emurchecer",
    "emurcheceriam": "emurchecer",
    "emurchecerias": "emurchecer",
    "emurchecermo": "emurchecer",
    "emurchecermos": "emurchecer",
    "emurchecerá": "emurchecer",
    "emurchecerás": "emurchecer",
    "emurchecerão": "emurchecer",
    "emurcheceríamos": "emurchecer",
    "emurcheceríeis": "emurchecer",
    "emurcheces": "emurchecer",
    "emurchecesse": "emurchecer",
    "emurchecessem": "emurchecer",
    "emurchecesses": "emurchecer",
    "emurcheceste": "emurchecer",
    "emurchecestes": "emurchecer",
    "emurcheceu": "emurchecer",
    "emurcheci": "emurchecer",
    "emurchecia": "emurchecer",
    "emurcheciam": "emurchecer",
    "emurchecias": "emurchecer",
    "emurchecida": "emurchecer",
    "emurchecidas": "emurchecer",
    "emurchecido": "emurchecer",
    "emurchecidos": "emurchecer",
    "emurchecimentos": "emurchecimento",
    "emurchecêramo": "emurchecer",
    "emurchecêramos": "emurchecer",
    "emurchecêreis": "emurchecer",
    "emurchecêsseis": "emurchecer",
    "emurchecêssemos": "emurchecer",
    "emurchecíamo": "emurchecer",
    "emurchecíamos": "emurchecer",
    "emurchecíeis": "emurchecer",
    "emurcheça": "emurchecer",
    "emurcheçais": "emurchecer",
    "emurcheçam": "emurchecer",
    "emurcheçamo": "emurchecer",
    "emurcheçamos": "emurchecer",
    "emurcheças": "emurchecer",
    "emurcheço": "emurchecer",
    "emérita": "emérito",
    "eméritas": "emérito",
    "eméritos": "emérito",
    "emética": "emético",
    "eméticas": "emético",
    "eméticos": "emético",
    "enaipa": "enaipar",
    "enaipada": "enaipar",
    "enaipadas": "enaipar",
    "enaipado": "enaipar",
    "enaipados": "enaipar",
    "enaipai": "enaipar",
    "enaipais": "enaipar",
    "enaipam": "enaipar",
    "enaipamo": "enaipar",
    "enaipamos": "enaipar",
    "enaipando": "enaipar",
    "enaipara": "enaipar",
    "enaiparam": "enaipar",
    "enaiparas": "enaipar",
    "enaiparde": "enaipar",
    "enaipardes": "enaipar",
    "enaipare": "enaipar",
    "enaiparei": "enaipar",
    "enaipareis": "enaipar",
    "enaiparem": "enaipar",
    "enaiparemos": "enaipar",
    "enaipares": "enaipar",
    "enaiparia": "enaipar",
    "enaipariam": "enaipar",
    "enaiparias": "enaipar",
    "enaiparmo": "enaipar",
    "enaiparmos": "enaipar",
    "enaipará": "enaipar",
    "enaiparás": "enaipar",
    "enaiparão": "enaipar",
    "enaiparíamos": "enaipar",
    "enaiparíeis": "enaipar",
    "enaipas": "enaipar",
    "enaipasse": "enaipar",
    "enaipassem": "enaipar",
    "enaipasses": "enaipar",
    "enaipaste": "enaipar",
    "enaipastes": "enaipar",
    "enaipava": "enaipar",
    "enaipavam": "enaipar",
    "enaipavas": "enaipar",
    "enaipe": "enaipar",
    "enaipei": "enaipar",
    "enaipeis": "enaipar",
    "enaipem": "enaipar",
    "enaipemo": "enaipar",
    "enaipemos": "enaipar",
    "enaipes": "enaipar",
    "enaipo": "enaipar",
    "enaipou": "enaipar",
    "enaipá": "enaipar",
    "enaipámo": "enaipar",
    "enaipámos": "enaipar",
    "enaipáramo": "enaipar",
    "enaipáramos": "enaipar",
    "enaipárei": "enaipar",
    "enaipáreis": "enaipar",
    "enaipásseis": "enaipar",
    "enaipássemos": "enaipar",
    "enaipávamo": "enaipar",
    "enaipávamos": "enaipar",
    "enaipávei": "enaipar",
    "enaipáveis": "enaipar",
    "enaltece": "enaltecer",
    "enaltecedora": "enaltecedor",
    "enaltecedoras": "enaltecedor",
    "enaltecedores": "enaltecedor",
    "enaltecei": "enaltecer",
    "enalteceis": "enaltecer",
    "enaltecem": "enaltecer",
    "enaltecemo": "enaltecer",
    "enaltecemos": "enaltecer",
    "enaltecendo": "enaltecer",
    "enaltecera": "enaltecer",
    "enalteceram": "enaltecer",
    "enalteceras": "enaltecer",
    "enaltecerde": "enaltecer",
    "enaltecerdes": "enaltecer",
    "enaltecere": "enaltecer",
    "enaltecerei": "enaltecer",
    "enaltecereis": "enaltecer",
    "enaltecerem": "enaltecer",
    "enalteceremos": "enaltecer",
    "enalteceres": "enaltecer",
    "enalteceria": "enaltecer",
    "enalteceriam": "enaltecer",
    "enaltecerias": "enaltecer",
    "enaltecermo": "enaltecer",
    "enaltecermos": "enaltecer",
    "enaltecerá": "enaltecer",
    "enaltecerás": "enaltecer",
    "enaltecerão": "enaltecer",
    "enalteceríamos": "enaltecer",
    "enalteceríeis": "enaltecer",
    "enalteces": "enaltecer",
    "enaltecesse": "enaltecer",
    "enaltecessem": "enaltecer",
    "enaltecesses": "enaltecer",
    "enalteceste": "enaltecer",
    "enaltecestes": "enaltecer",
    "enalteceu": "enaltecer",
    "enalteci": "enaltecer",
    "enaltecia": "enaltecer",
    "enalteciam": "enaltecer",
    "enaltecias": "enaltecer",
    "enaltecida": "enaltecido",
    "enaltecidas": "enaltecido",
    "enaltecido": "enaltecer",
    "enaltecidos": "enaltecido",
    "enaltecimentos": "enaltecimento",
    "enaltecê": "enaltecer",
    "enaltecêramo": "enaltecer",
    "enaltecêramos": "enaltecer",
    "enaltecêrei": "enaltecer",
    "enaltecêreis": "enaltecer",
    "enaltecêsseis": "enaltecer",
    "enaltecêssemos": "enaltecer",
    "enaltecíamo": "enaltecer",
    "enaltecíamos": "enaltecer",
    "enaltecíei": "enaltecer",
    "enaltecíeis": "enaltecer",
    "enalteça": "enaltecer",
    "enalteçais": "enaltecer",
    "enalteçam": "enaltecer",
    "enalteçamo": "enaltecer",
    "enalteçamos": "enaltecer",
    "enalteças": "enaltecer",
    "enalteço": "enaltecer",
    "enamora": "enamorar",
    "enamorada": "enamorar",
    "enamoradas": "enamorar",
    "enamorado": "enamorar",
    "enamorados": "enamorar",
    "enamoradíssima": "enamorado",
    "enamoradíssimas": "enamorado",
    "enamoradíssimo": "enamorado",
    "enamoradíssimos": "enamorado",
    "enamorai": "enamorar",
    "enamorais": "enamorar",
    "enamoram": "enamorar",
    "enamoramentos": "enamoramento",
    "enamoramo": "enamorar",
    "enamoramos": "enamorar",
    "enamorando": "enamorar",
    "enamorara": "enamorar",
    "enamoraram": "enamorar",
    "enamoraras": "enamorar",
    "enamorarde": "enamorar",
    "enamorardes": "enamorar",
    "enamorare": "enamorar",
    "enamorarei": "enamorar",
    "enamorareis": "enamorar",
    "enamorarem": "enamorar",
    "enamoraremos": "enamorar",
    "enamorares": "enamorar",
    "enamoraria": "enamorar",
    "enamorariam": "enamorar",
    "enamorarias": "enamorar",
    "enamorarmo": "enamorar",
    "enamorarmos": "enamorar",
    "enamorará": "enamorar",
    "enamorarás": "enamorar",
    "enamorarão": "enamorar",
    "enamoraríamos": "enamorar",
    "enamoraríeis": "enamorar",
    "enamoras": "enamorar",
    "enamorasse": "enamorar",
    "enamorassem": "enamorar",
    "enamorasses": "enamorar",
    "enamoraste": "enamorar",
    "enamorastes": "enamorar",
    "enamorava": "enamorar",
    "enamoravam": "enamorar",
    "enamoravas": "enamorar",
    "enamore": "enamorar",
    "enamorei": "enamorar",
    "enamoreis": "enamorar",
    "enamorem": "enamorar",
    "enamoremo": "enamorar",
    "enamoremos": "enamorar",
    "enamores": "enamorar",
    "enamoro": "enamorar",
    "enamorou": "enamorar",
    "enamorá": "enamorar",
    "enamorámo": "enamorar",
    "enamorámos": "enamorar",
    "enamoráramo": "enamorar",
    "enamoráramos": "enamorar",
    "enamorárei": "enamorar",
    "enamoráreis": "enamorar",
    "enamorásseis": "enamorar",
    "enamorássemos": "enamorar",
    "enamorávamo": "enamorar",
    "enamorávamos": "enamorar",
    "enamorávei": "enamorar",
    "enamoráveis": "enamorar",
    "enantais": "enantal",
    "enantemas": "enantema",
    "enantinas": "enantina",
    "enantiomorfismos": "enantiomorfismo",
    "enantiomórfica": "enantiomórfico",
    "enantiomórficas": "enantiomórfico",
    "enantiomórficos": "enantiomórfico",
    "enantiotropismos": "enantiotropismo",
    "enantiotrópica": "enantiotrópico",
    "enantiotrópicas": "enantiotrópico",
    "enantiotrópicos": "enantiotrópico",
    "enantos": "enanto",
    "enargias": "enargia",
    "enarmonias": "enarmonia",
    "enarra": "enarrar",
    "enarrada": "enarrar",
    "enarradas": "enarrar",
    "enarrado": "enarrar",
    "enarrados": "enarrar",
    "enarrai": "enarrar",
    "enarrais": "enarrar",
    "enarram": "enarrar",
    "enarramo": "enarrar",
    "enarramos": "enarrar",
    "enarrando": "enarrar",
    "enarrara": "enarrar",
    "enarraram": "enarrar",
    "enarraras": "enarrar",
    "enarrarde": "enarrar",
    "enarrardes": "enarrar",
    "enarrare": "enarrar",
    "enarrarei": "enarrar",
    "enarrareis": "enarrar",
    "enarrarem": "enarrar",
    "enarraremos": "enarrar",
    "enarrares": "enarrar",
    "enarraria": "enarrar",
    "enarrariam": "enarrar",
    "enarrarias": "enarrar",
    "enarrarmo": "enarrar",
    "enarrarmos": "enarrar",
    "enarrará": "enarrar",
    "enarrarás": "enarrar",
    "enarrarão": "enarrar",
    "enarraríamos": "enarrar",
    "enarraríeis": "enarrar",
    "enarras": "enarrar",
    "enarrasse": "enarrar",
    "enarrassem": "enarrar",
    "enarrasses": "enarrar",
    "enarraste": "enarrar",
    "enarrastes": "enarrar",
    "enarrava": "enarrar",
    "enarravam": "enarrar",
    "enarravas": "enarrar",
    "enarre": "enarrar",
    "enarrei": "enarrar",
    "enarreis": "enarrar",
    "enarrem": "enarrar",
    "enarremo": "enarrar",
    "enarremos": "enarrar",
    "enarres": "enarrar",
    "enarro": "enarrar",
    "enarrou": "enarrar",
    "enarrá": "enarrar",
    "enarrámo": "enarrar",
    "enarrámos": "enarrar",
    "enarráramo": "enarrar",
    "enarráramos": "enarrar",
    "enarrárei": "enarrar",
    "enarráreis": "enarrar",
    "enarrásseis": "enarrar",
    "enarrássemos": "enarrar",
    "enarrávamo": "enarrar",
    "enarrávamos": "enarrar",
    "enarrávei": "enarrar",
    "enarráveis": "enarrar",
    "enartroses": "enartrose",
    "enases": "enase",
    "enastra": "enastrar",
    "enastrada": "enastrar",
    "enastradas": "enastrar",
    "enastrado": "enastrar",
    "enastrados": "enastrar",
    "enastrai": "enastrar",
    "enastrais": "enastrar",
    "enastram": "enastrar",
    "enastramo": "enastrar",
    "enastramos": "enastrar",
    "enastrando": "enastrar",
    "enastrara": "enastrar",
    "enastraram": "enastrar",
    "enastraras": "enastrar",
    "enastrarde": "enastrar",
    "enastrardes": "enastrar",
    "enastrare": "enastrar",
    "enastrarei": "enastrar",
    "enastrareis": "enastrar",
    "enastrarem": "enastrar",
    "enastraremos": "enastrar",
    "enastrares": "enastrar",
    "enastraria": "enastrar",
    "enastrariam": "enastrar",
    "enastrarias": "enastrar",
    "enastrarmo": "enastrar",
    "enastrarmos": "enastrar",
    "enastrará": "enastrar",
    "enastrarás": "enastrar",
    "enastrarão": "enastrar",
    "enastraríamos": "enastrar",
    "enastraríeis": "enastrar",
    "enastras": "enastrar",
    "enastrasse": "enastrar",
    "enastrassem": "enastrar",
    "enastrasses": "enastrar",
    "enastraste": "enastrar",
    "enastrastes": "enastrar",
    "enastrava": "enastrar",
    "enastravam": "enastrar",
    "enastravas": "enastrar",
    "enastre": "enastrar",
    "enastrei": "enastrar",
    "enastreis": "enastrar",
    "enastrem": "enastrar",
    "enastremo": "enastrar",
    "enastremos": "enastrar",
    "enastres": "enastrar",
    "enastro": "enastrar",
    "enastrou": "enastrar",
    "enastrá": "enastrar",
    "enastrámo": "enastrar",
    "enastrámos": "enastrar",
    "enastráramo": "enastrar",
    "enastráramos": "enastrar",
    "enastrárei": "enastrar",
    "enastráreis": "enastrar",
    "enastrásseis": "enastrar",
    "enastrássemos": "enastrar",
    "enastrávamo": "enastrar",
    "enastrávamos": "enastrar",
    "enastrávei": "enastrar",
    "enastráveis": "enastrar",
    "enata": "enatar",
    "enatada": "enatar",
    "enatadas": "enatar",
    "enatado": "enatar",
    "enatados": "enatar",
    "enatai": "enatar",
    "enatais": "enatar",
    "enatam": "enatar",
    "enatamo": "enatar",
    "enatamos": "enatar",
    "enatando": "enatar",
    "enatara": "enatar",
    "enataram": "enatar",
    "enataras": "enatar",
    "enatarde": "enatar",
    "enatardes": "enatar",
    "enatare": "enatar",
    "enatarei": "enatar",
    "enatareis": "enatar",
    "enatarem": "enatar",
    "enataremos": "enatar",
    "enatares": "enatar",
    "enataria": "enatar",
    "enatariam": "enatar",
    "enatarias": "enatar",
    "enatarmo": "enatar",
    "enatarmos": "enatar",
    "enatará": "enatar",
    "enatarás": "enatar",
    "enatarão": "enatar",
    "enataríamos": "enatar",
    "enataríeis": "enatar",
    "enatas": "enatar",
    "enatasse": "enatar",
    "enatassem": "enatar",
    "enatasses": "enatar",
    "enataste": "enatar",
    "enatastes": "enatar",
    "enatava": "enatar",
    "enatavam": "enatar",
    "enatavas": "enatar",
    "enate": "enatar",
    "enatei": "enatar",
    "enateira": "enateirar",
    "enateirada": "enateirar",
    "enateiradas": "enateirar",
    "enateirado": "enateirar",
    "enateirados": "enateirar",
    "enateirai": "enateirar",
    "enateirais": "enateirar",
    "enateiram": "enateirar",
    "enateiramentos": "enateiramento",
    "enateiramo": "enateirar",
    "enateiramos": "enateirar",
    "enateirando": "enateirar",
    "enateirara": "enateirar",
    "enateiraram": "enateirar",
    "enateiraras": "enateirar",
    "enateirarde": "enateirar",
    "enateirardes": "enateirar",
    "enateirare": "enateirar",
    "enateirarei": "enateirar",
    "enateirareis": "enateirar",
    "enateirarem": "enateirar",
    "enateiraremos": "enateirar",
    "enateirares": "enateirar",
    "enateiraria": "enateirar",
    "enateirariam": "enateirar",
    "enateirarias": "enateirar",
    "enateirarmo": "enateirar",
    "enateirarmos": "enateirar",
    "enateirará": "enateirar",
    "enateirarás": "enateirar",
    "enateirarão": "enateirar",
    "enateiraríamos": "enateirar",
    "enateiraríeis": "enateirar",
    "enateiras": "enateirar",
    "enateirasse": "enateirar",
    "enateirassem": "enateirar",
    "enateirasses": "enateirar",
    "enateiraste": "enateirar",
    "enateirastes": "enateirar",
    "enateirava": "enateirar",
    "enateiravam": "enateirar",
    "enateiravas": "enateirar",
    "enateire": "enateirar",
    "enateirei": "enateirar",
    "enateireis": "enateirar",
    "enateirem": "enateirar",
    "enateiremo": "enateirar",
    "enateiremos": "enateirar",
    "enateires": "enateirar",
    "enateiro": "enateirar",
    "enateirou": "enateirar",
    "enateirá": "enateirar",
    "enateirámo": "enateirar",
    "enateirámos": "enateirar",
    "enateiráramo": "enateirar",
    "enateiráramos": "enateirar",
    "enateirárei": "enateirar",
    "enateiráreis": "enateirar",
    "enateirásseis": "enateirar",
    "enateirássemos": "enateirar",
    "enateirávamo": "enateirar",
    "enateirávamos": "enateirar",
    "enateirávei": "enateirar",
    "enateiráveis": "enateirar",
    "enateis": "enatar",
    "enatem": "enatar",
    "enatemo": "enatar",
    "enatemos": "enatar",
    "enates": "enatar",
    "enato": "enatar",
    "enatou": "enatar",
    "enatá": "enatar",
    "enatámo": "enatar",
    "enatámos": "enatar",
    "enatáramo": "enatar",
    "enatáramos": "enatar",
    "enatárei": "enatar",
    "enatáreis": "enatar",
    "enatásseis": "enatar",
    "enatássemos": "enatar",
    "enatávamo": "enatar",
    "enatávamos": "enatar",
    "enatávei": "enatar",
    "enatáveis": "enatar",
    "encaba": "encabar",
    "encabada": "encabar",
    "encabadas": "encabar",
    "encabadelas": "encabadela",
    "encabado": "encabar",
    "encabadoiros": "encabadoiro",
    "encabados": "encabar",
    "encabadouros": "encabadouro",
    "encabai": "encabar",
    "encabais": "encabar",
    "encabam": "encabar",
    "encabamo": "encabar",
    "encabamos": "encabar",
    "encabando": "encabar",
    "encabara": "encabar",
    "encabaram": "encabar",
    "encabaras": "encabar",
    "encabarde": "encabar",
    "encabardes": "encabar",
    "encabare": "encabar",
    "encabarei": "encabar",
    "encabareis": "encabar",
    "encabarem": "encabar",
    "encabaremos": "encabar",
    "encabares": "encabar",
    "encabaria": "encabar",
    "encabariam": "encabar",
    "encabarias": "encabar",
    "encabarmo": "encabar",
    "encabarmos": "encabar",
    "encabará": "encabar",
    "encabarás": "encabar",
    "encabarão": "encabar",
    "encabaríamos": "encabar",
    "encabaríeis": "encabar",
    "encabas": "encabar",
    "encabasse": "encabar",
    "encabassem": "encabar",
    "encabasses": "encabar",
    "encabaste": "encabar",
    "encabastes": "encabar",
    "encabava": "encabar",
    "encabavam": "encabar",
    "encabavas": "encabar",
    "encabe": "encabar",
    "encabece": "encabeçar",
    "encabecei": "encabeçar",
    "encabeceis": "encabeçar",
    "encabecem": "encabeçar",
    "encabecemo": "encabeçar",
    "encabecemos": "encabeçar",
    "encabeces": "encabeçar",
    "encabei": "encabar",
    "encabeira": "encabeirar",
    "encabeirada": "encabeirar",
    "encabeiradas": "encabeirar",
    "encabeirado": "encabeirar",
    "encabeirados": "encabeirar",
    "encabeirai": "encabeirar",
    "encabeirais": "encabeirar",
    "encabeiram": "encabeirar",
    "encabeiramo": "encabeirar",
    "encabeiramos": "encabeirar",
    "encabeirando": "encabeirar",
    "encabeirara": "encabeirar",
    "encabeiraram": "encabeirar",
    "encabeiraras": "encabeirar",
    "encabeirarde": "encabeirar",
    "encabeirardes": "encabeirar",
    "encabeirare": "encabeirar",
    "encabeirarei": "encabeirar",
    "encabeirareis": "encabeirar",
    "encabeirarem": "encabeirar",
    "encabeiraremos": "encabeirar",
    "encabeirares": "encabeirar",
    "encabeiraria": "encabeirar",
    "encabeirariam": "encabeirar",
    "encabeirarias": "encabeirar",
    "encabeirarmo": "encabeirar",
    "encabeirarmos": "encabeirar",
    "encabeirará": "encabeirar",
    "encabeirarás": "encabeirar",
    "encabeirarão": "encabeirar",
    "encabeiraríamos": "encabeirar",
    "encabeiraríeis": "encabeirar",
    "encabeiras": "encabeirar",
    "encabeirasse": "encabeirar",
    "encabeirassem": "encabeirar",
    "encabeirasses": "encabeirar",
    "encabeiraste": "encabeirar",
    "encabeirastes": "encabeirar",
    "encabeirava": "encabeirar",
    "encabeiravam": "encabeirar",
    "encabeiravas": "encabeirar",
    "encabeire": "encabeirar",
    "encabeirei": "encabeirar",
    "encabeireis": "encabeirar",
    "encabeirem": "encabeirar",
    "encabeiremo": "encabeirar",
    "encabeiremos": "encabeirar",
    "encabeires": "encabeirar",
    "encabeiro": "encabeirar",
    "encabeirou": "encabeirar",
    "encabeirá": "encabeirar",
    "encabeirámo": "encabeirar",
    "encabeirámos": "encabeirar",
    "encabeiráramo": "encabeirar",
    "encabeiráramos": "encabeirar",
    "encabeirárei": "encabeirar",
    "encabeiráreis": "encabeirar",
    "encabeirásseis": "encabeirar",
    "encabeirássemos": "encabeirar",
    "encabeirávamo": "encabeirar",
    "encabeirávamos": "encabeirar",
    "encabeirávei": "encabeirar",
    "encabeiráveis": "encabeirar",
    "encabeis": "encabar",
    "encabela": "encabelar",
    "encabelada": "encabelar",
    "encabeladas": "encabelar",
    "encabelado": "encabelar",
    "encabeladora": "encabelador",
    "encabeladoras": "encabelador",
    "encabeladores": "encabelador",
    "encabelados": "encabelar",
    "encabeladuras": "encabeladura",
    "encabelai": "encabelar",
    "encabelais": "encabelar",
    "encabelam": "encabelar",
    "encabelamo": "encabelar",
    "encabelamos": "encabelar",
    "encabelando": "encabelar",
    "encabelara": "encabelar",
    "encabelaram": "encabelar",
    "encabelaras": "encabelar",
    "encabelardes": "encabelar",
    "encabelarei": "encabelar",
    "encabelareis": "encabelar",
    "encabelarem": "encabelar",
    "encabelaremos": "encabelar",
    "encabelares": "encabelar",
    "encabelaria": "encabelar",
    "encabelariam": "encabelar",
    "encabelarias": "encabelar",
    "encabelarmo": "encabelar",
    "encabelarmos": "encabelar",
    "encabelará": "encabelar",
    "encabelarás": "encabelar",
    "encabelarão": "encabelar",
    "encabelaríamos": "encabelar",
    "encabelaríeis": "encabelar",
    "encabelas": "encabelar",
    "encabelasse": "encabelar",
    "encabelassem": "encabelar",
    "encabelasses": "encabelar",
    "encabelaste": "encabelar",
    "encabelastes": "encabelar",
    "encabelava": "encabelar",
    "encabelavam": "encabelar",
    "encabelavas": "encabelar",
    "encabele": "encabelar",
    "encabelei": "encabelar",
    "encabeleis": "encabelar",
    "encabelem": "encabelar",
    "encabelemo": "encabelar",
    "encabelemos": "encabelar",
    "encabeles": "encabelar",
    "encabelo": "encabelar",
    "encabelou": "encabelar",
    "encabelámo": "encabelar",
    "encabelámos": "encabelar",
    "encabeláramo": "encabelar",
    "encabeláramos": "encabelar",
    "encabeláreis": "encabelar",
    "encabelásseis": "encabelar",
    "encabelássemos": "encabelar",
    "encabelávamo": "encabelar",
    "encabelávamos": "encabelar",
    "encabeláveis": "encabelar",
    "encabem": "encabar",
    "encabemo": "encabar",
    "encabemos": "encabar",
    "encabes": "encabar",
    "encabeça": "encabeçar",
    "encabeçada": "encabeçar",
    "encabeçadas": "encabeçar",
    "encabeçado": "encabeçar",
    "encabeçados": "encabeçar",
    "encabeçaduras": "encabeçadura",
    "encabeçai": "encabeçar",
    "encabeçais": "encabeçar",
    "encabeçam": "encabeçar",
    "encabeçamentos": "encabeçamento",
    "encabeçamo": "encabeçar",
    "encabeçamos": "encabeçar",
    "encabeçando": "encabeçar",
    "encabeçara": "encabeçar",
    "encabeçaram": "encabeçar",
    "encabeçaras": "encabeçar",
    "encabeçarde": "encabeçar",
    "encabeçardes": "encabeçar",
    "encabeçare": "encabeçar",
    "encabeçarei": "encabeçar",
    "encabeçareis": "encabeçar",
    "encabeçarem": "encabeçar",
    "encabeçaremos": "encabeçar",
    "encabeçares": "encabeçar",
    "encabeçaria": "encabeçar",
    "encabeçariam": "encabeçar",
    "encabeçarias": "encabeçar",
    "encabeçarmo": "encabeçar",
    "encabeçarmos": "encabeçar",
    "encabeçará": "encabeçar",
    "encabeçarás": "encabeçar",
    "encabeçarão": "encabeçar",
    "encabeçaríamos": "encabeçar",
    "encabeçaríeis": "encabeçar",
    "encabeças": "encabeçar",
    "encabeçasse": "encabeçar",
    "encabeçassem": "encabeçar",
    "encabeçasses": "encabeçar",
    "encabeçaste": "encabeçar",
    "encabeçastes": "encabeçar",
    "encabeçava": "encabeçar",
    "encabeçavam": "encabeçar",
    "encabeçavas": "encabeçar",
    "encabeço": "encabeçar",
    "encabeços": "encabeço",
    "encabeçou": "encabeçar",
    "encabeçá": "encabeçar",
    "encabeçámo": "encabeçar",
    "encabeçámos": "encabeçar",
    "encabeçáramo": "encabeçar",
    "encabeçáramos": "encabeçar",
    "encabeçárei": "encabeçar",
    "encabeçáreis": "encabeçar",
    "encabeçásseis": "encabeçar",
    "encabeçássemos": "encabeçar",
    "encabeçávamo": "encabeçar",
    "encabeçávamos": "encabeçar",
    "encabeçávei": "encabeçar",
    "encabeçáveis": "encabeçar",
    "encabo": "encabar",
    "encabou": "encabar",
    "encabresta": "encabrestar",
    "encabrestada": "encabrestar",
    "encabrestadas": "encabrestar",
    "encabrestado": "encabrestar",
    "encabrestados": "encabrestar",
    "encabrestai": "encabrestar",
    "encabrestais": "encabrestar",
    "encabrestam": "encabrestar",
    "encabrestamentos": "encabrestamento",
    "encabrestamo": "encabrestar",
    "encabrestamos": "encabrestar",
    "encabrestando": "encabrestar",
    "encabrestara": "encabrestar",
    "encabrestaram": "encabrestar",
    "encabrestaras": "encabrestar",
    "encabrestarde": "encabrestar",
    "encabrestardes": "encabrestar",
    "encabrestare": "encabrestar",
    "encabrestarei": "encabrestar",
    "encabrestareis": "encabrestar",
    "encabrestarem": "encabrestar",
    "encabrestaremos": "encabrestar",
    "encabrestares": "encabrestar",
    "encabrestaria": "encabrestar",
    "encabrestariam": "encabrestar",
    "encabrestarias": "encabrestar",
    "encabrestarmo": "encabrestar",
    "encabrestarmos": "encabrestar",
    "encabrestará": "encabrestar",
    "encabrestarás": "encabrestar",
    "encabrestarão": "encabrestar",
    "encabrestaríamos": "encabrestar",
    "encabrestaríeis": "encabrestar",
    "encabrestas": "encabrestar",
    "encabrestasse": "encabrestar",
    "encabrestassem": "encabrestar",
    "encabrestasses": "encabrestar",
    "encabrestaste": "encabrestar",
    "encabrestastes": "encabrestar",
    "encabrestava": "encabrestar",
    "encabrestavam": "encabrestar",
    "encabrestavas": "encabrestar",
    "encabreste": "encabrestar",
    "encabrestei": "encabrestar",
    "encabresteis": "encabrestar",
    "encabrestem": "encabrestar",
    "encabrestemo": "encabrestar",
    "encabrestemos": "encabrestar",
    "encabrestes": "encabrestar",
    "encabresto": "encabrestar",
    "encabrestou": "encabrestar",
    "encabresturas": "encabrestura",
    "encabrestá": "encabrestar",
    "encabrestámo": "encabrestar",
    "encabrestámos": "encabrestar",
    "encabrestáramo": "encabrestar",
    "encabrestáramos": "encabrestar",
    "encabrestárei": "encabrestar",
    "encabrestáreis": "encabrestar",
    "encabrestásseis": "encabrestar",
    "encabrestássemos": "encabrestar",
    "encabrestávamo": "encabrestar",
    "encabrestávamos": "encabrestar",
    "encabrestávei": "encabrestar",
    "encabrestáveis": "encabrestar",
    "encabrita": "encabritar",
    "encabritada": "encabritar",
    "encabritadas": "encabritar",
    "encabritado": "encabritar",
    "encabritados": "encabritar",
    "encabritai": "encabritar",
    "encabritais": "encabritar",
    "encabritam": "encabritar",
    "encabritamo": "encabritar",
    "encabritamos": "encabritar",
    "encabritando": "encabritar",
    "encabritara": "encabritar",
    "encabritaram": "encabritar",
    "encabritaras": "encabritar",
    "encabritarde": "encabritar",
    "encabritardes": "encabritar",
    "encabritare": "encabritar",
    "encabritarei": "encabritar",
    "encabritareis": "encabritar",
    "encabritarem": "encabritar",
    "encabritaremos": "encabritar",
    "encabritares": "encabritar",
    "encabritaria": "encabritar",
    "encabritariam": "encabritar",
    "encabritarias": "encabritar",
    "encabritarmo": "encabritar",
    "encabritarmos": "encabritar",
    "encabritará": "encabritar",
    "encabritarás": "encabritar",
    "encabritarão": "encabritar",
    "encabritaríamos": "encabritar",
    "encabritaríeis": "encabritar",
    "encabritas": "encabritar",
    "encabritasse": "encabritar",
    "encabritassem": "encabritar",
    "encabritasses": "encabritar",
    "encabritaste": "encabritar",
    "encabritastes": "encabritar",
    "encabritava": "encabritar",
    "encabritavam": "encabritar",
    "encabritavas": "encabritar",
    "encabrite": "encabritar",
    "encabritei": "encabritar",
    "encabriteis": "encabritar",
    "encabritem": "encabritar",
    "encabritemo": "encabritar",
    "encabritemos": "encabritar",
    "encabrites": "encabritar",
    "encabrito": "encabritar",
    "encabritou": "encabritar",
    "encabritá": "encabritar",
    "encabritámo": "encabritar",
    "encabritámos": "encabritar",
    "encabritáramo": "encabritar",
    "encabritáramos": "encabritar",
    "encabritárei": "encabritar",
    "encabritáreis": "encabritar",
    "encabritásseis": "encabritar",
    "encabritássemos": "encabritar",
    "encabritávamo": "encabritar",
    "encabritávamos": "encabritar",
    "encabritávei": "encabritar",
    "encabritáveis": "encabritar",
    "encabá": "encabar",
    "encabámo": "encabar",
    "encabámos": "encabar",
    "encabáramo": "encabar",
    "encabáramos": "encabar",
    "encabárei": "encabar",
    "encabáreis": "encabar",
    "encabásseis": "encabar",
    "encabássemos": "encabar",
    "encabávamo": "encabar",
    "encabávamos": "encabar",
    "encabávei": "encabar",
    "encabáveis": "encabar",
    "encacha": "encachar",
    "encachada": "encachar",
    "encachadas": "encachar",
    "encachado": "encachar",
    "encachados": "encachar",
    "encachai": "encachar",
    "encachais": "encachar",
    "encacham": "encachar",
    "encachamo": "encachar",
    "encachamos": "encachar",
    "encachando": "encachar",
    "encachara": "encachar",
    "encacharam": "encachar",
    "encacharas": "encachar",
    "encacharde": "encachar",
    "encachardes": "encachar",
    "encachare": "encachar",
    "encacharei": "encachar",
    "encachareis": "encachar",
    "encacharem": "encachar",
    "encacharemos": "encachar",
    "encachares": "encachar",
    "encacharia": "encachar",
    "encachariam": "encachar",
    "encacharias": "encachar",
    "encacharmo": "encachar",
    "encacharmos": "encachar",
    "encachará": "encachar",
    "encacharás": "encachar",
    "encacharão": "encachar",
    "encacharíamos": "encachar",
    "encacharíeis": "encachar",
    "encachas": "encachar",
    "encachasse": "encachar",
    "encachassem": "encachar",
    "encachasses": "encachar",
    "encachaste": "encachar",
    "encachastes": "encachar",
    "encachava": "encachar",
    "encachavam": "encachar",
    "encachavas": "encachar",
    "encache": "encachar",
    "encachei": "encachar",
    "encacheis": "encachar",
    "encachem": "encachar",
    "encachemo": "encachar",
    "encachemos": "encachar",
    "encaches": "encache",
    "encachia": "encachiar",
    "encachiada": "encachiar",
    "encachiadas": "encachiar",
    "encachiado": "encachiar",
    "encachiados": "encachiar",
    "encachiai": "encachiar",
    "encachiais": "encachiar",
    "encachiam": "encachiar",
    "encachiamo": "encachiar",
    "encachiamos": "encachiar",
    "encachiando": "encachiar",
    "encachiara": "encachiar",
    "encachiaram": "encachiar",
    "encachiaras": "encachiar",
    "encachiarde": "encachiar",
    "encachiardes": "encachiar",
    "encachiare": "encachiar",
    "encachiarei": "encachiar",
    "encachiareis": "encachiar",
    "encachiarem": "encachiar",
    "encachiaremos": "encachiar",
    "encachiares": "encachiar",
    "encachiaria": "encachiar",
    "encachiariam": "encachiar",
    "encachiarias": "encachiar",
    "encachiarmo": "encachiar",
    "encachiarmos": "encachiar",
    "encachiará": "encachiar",
    "encachiarás": "encachiar",
    "encachiarão": "encachiar",
    "encachiaríamos": "encachiar",
    "encachiaríeis": "encachiar",
    "encachias": "encachiar",
    "encachiasse": "encachiar",
    "encachiassem": "encachiar",
    "encachiasses": "encachiar",
    "encachiaste": "encachiar",
    "encachiastes": "encachiar",
    "encachiava": "encachiar",
    "encachiavam": "encachiar",
    "encachiavas": "encachiar",
    "encachie": "encachiar",
    "encachiei": "encachiar",
    "encachieis": "encachiar",
    "encachiem": "encachiar",
    "encachiemo": "encachiar",
    "encachiemos": "encachiar",
    "encachies": "encachiar",
    "encachio": "encachiar",
    "encachiou": "encachiar",
    "encachiá": "encachiar",
    "encachiámo": "encachiar",
    "encachiámos": "encachiar",
    "encachiáramo": "encachiar",
    "encachiáramos": "encachiar",
    "encachiárei": "encachiar",
    "encachiáreis": "encachiar",
    "encachiásseis": "encachiar",
    "encachiássemos": "encachiar",
    "encachiávamo": "encachiar",
    "encachiávamos": "encachiar",
    "encachiávei": "encachiar",
    "encachiáveis": "encachiar",
    "encacho": "encachar",
    "encachoeiramentos": "encachoeiramento",
    "encachola": "encacholar",
    "encacholada": "encacholar",
    "encacholadas": "encacholar",
    "encacholado": "encacholar",
    "encacholados": "encacholar",
    "encacholai": "encacholar",
    "encacholais": "encacholar",
    "encacholam": "encacholar",
    "encacholamo": "encacholar",
    "encacholamos": "encacholar",
    "encacholando": "encacholar",
    "encacholara": "encacholar",
    "encacholaram": "encacholar",
    "encacholaras": "encacholar",
    "encacholarde": "encacholar",
    "encacholardes": "encacholar",
    "encacholare": "encacholar",
    "encacholarei": "encacholar",
    "encacholareis": "encacholar",
    "encacholarem": "encacholar",
    "encacholaremos": "encacholar",
    "encacholares": "encacholar",
    "encacholaria": "encacholar",
    "encacholariam": "encacholar",
    "encacholarias": "encacholar",
    "encacholarmo": "encacholar",
    "encacholarmos": "encacholar",
    "encacholará": "encacholar",
    "encacholarás": "encacholar",
    "encacholarão": "encacholar",
    "encacholaríamos": "encacholar",
    "encacholaríeis": "encacholar",
    "encacholas": "encacholar",
    "encacholasse": "encacholar",
    "encacholassem": "encacholar",
    "encacholasses": "encacholar",
    "encacholaste": "encacholar",
    "encacholastes": "encacholar",
    "encacholava": "encacholar",
    "encacholavam": "encacholar",
    "encacholavas": "encacholar",
    "encachole": "encacholar",
    "encacholei": "encacholar",
    "encacholeis": "encacholar",
    "encacholem": "encacholar",
    "encacholemo": "encacholar",
    "encacholemos": "encacholar",
    "encacholes": "encacholar",
    "encacholo": "encacholar",
    "encacholou": "encacholar",
    "encacholá": "encacholar",
    "encacholámo": "encacholar",
    "encacholámos": "encacholar",
    "encacholáramo": "encacholar",
    "encacholáramos": "encacholar",
    "encacholárei": "encacholar",
    "encacholáreis": "encacholar",
    "encacholásseis": "encacholar",
    "encacholássemos": "encacholar",
    "encacholávamo": "encacholar",
    "encacholávamos": "encacholar",
    "encacholávei": "encacholar",
    "encacholáveis": "encacholar",
    "encachos": "encacho",
    "encachou": "encachar",
    "encachá": "encachar",
    "encachámo": "encachar",
    "encachámos": "encachar",
    "encacháramo": "encachar",
    "encacháramos": "encachar",
    "encachárei": "encachar",
    "encacháreis": "encachar",
    "encachásseis": "encachar",
    "encachássemos": "encachar",
    "encachávamo": "encachar",
    "encachávamos": "encachar",
    "encachávei": "encachar",
    "encacháveis": "encachar",
    "encadeada": "encadear",
    "encadeadas": "encadear",
    "encadeado": "encadear",
    "encadeados": "encadear",
    "encadeai": "encadear",
    "encadeais": "encadear",
    "encadeamentos": "encadeamento",
    "encadeamo": "encadear",
    "encadeamos": "encadear",
    "encadeando": "encadear",
    "encadeara": "encadear",
    "encadearam": "encadear",
    "encadearas": "encadear",
    "encadearde": "encadear",
    "encadeardes": "encadear",
    "encadeare": "encadear",
    "encadearei": "encadear",
    "encadeareis": "encadear",
    "encadearem": "encadear",
    "encadearemos": "encadear",
    "encadeares": "encadear",
    "encadearia": "encadear",
    "encadeariam": "encadear",
    "encadearias": "encadear",
    "encadearmo": "encadear",
    "encadearmos": "encadear",
    "encadeará": "encadear",
    "encadearás": "encadear",
    "encadearão": "encadear",
    "encadearíamos": "encadear",
    "encadearíeis": "encadear",
    "encadeasse": "encadear",
    "encadeassem": "encadear",
    "encadeasses": "encadear",
    "encadeaste": "encadear",
    "encadeastes": "encadear",
    "encadeava": "encadear",
    "encadeavam": "encadear",
    "encadeavas": "encadear",
    "encadeações": "encadeação",
    "encadeei": "encadear",
    "encadeeis": "encadear",
    "encadeemo": "encadear",
    "encadeemos": "encadear",
    "encadeia": "encadear",
    "encadeiam": "encadear",
    "encadeias": "encadear",
    "encadeie": "encadear",
    "encadeiem": "encadear",
    "encadeies": "encadear",
    "encadeio": "encadear",
    "encadeira": "encadeirar",
    "encadeirada": "encadeirar",
    "encadeiradas": "encadeirar",
    "encadeirado": "encadeirar",
    "encadeirados": "encadeirar",
    "encadeirai": "encadeirar",
    "encadeirais": "encadeirar",
    "encadeiram": "encadeirar",
    "encadeiramo": "encadeirar",
    "encadeiramos": "encadeirar",
    "encadeirando": "encadeirar",
    "encadeirara": "encadeirar",
    "encadeiraram": "encadeirar",
    "encadeiraras": "encadeirar",
    "encadeirarde": "encadeirar",
    "encadeirardes": "encadeirar",
    "encadeirare": "encadeirar",
    "encadeirarei": "encadeirar",
    "encadeirareis": "encadeirar",
    "encadeirarem": "encadeirar",
    "encadeiraremos": "encadeirar",
    "encadeirares": "encadeirar",
    "encadeiraria": "encadeirar",
    "encadeirariam": "encadeirar",
    "encadeirarias": "encadeirar",
    "encadeirarmo": "encadeirar",
    "encadeirarmos": "encadeirar",
    "encadeirará": "encadeirar",
    "encadeirarás": "encadeirar",
    "encadeirarão": "encadeirar",
    "encadeiraríamos": "encadeirar",
    "encadeiraríeis": "encadeirar",
    "encadeiras": "encadeirar",
    "encadeirasse": "encadeirar",
    "encadeirassem": "encadeirar",
    "encadeirasses": "encadeirar",
    "encadeiraste": "encadeirar",
    "encadeirastes": "encadeirar",
    "encadeirava": "encadeirar",
    "encadeiravam": "encadeirar",
    "encadeiravas": "encadeirar",
    "encadeire": "encadeirar",
    "encadeirei": "encadeirar",
    "encadeireis": "encadeirar",
    "encadeirem": "encadeirar",
    "encadeiremo": "encadeirar",
    "encadeiremos": "encadeirar",
    "encadeires": "encadeirar",
    "encadeiro": "encadeirar",
    "encadeirou": "encadeirar",
    "encadeirá": "encadeirar",
    "encadeirámo": "encadeirar",
    "encadeirámos": "encadeirar",
    "encadeiráramo": "encadeirar",
    "encadeiráramos": "encadeirar",
    "encadeirárei": "encadeirar",
    "encadeiráreis": "encadeirar",
    "encadeirásseis": "encadeirar",
    "encadeirássemos": "encadeirar",
    "encadeirávamo": "encadeirar",
    "encadeirávamos": "encadeirar",
    "encadeirávei": "encadeirar",
    "encadeiráveis": "encadeirar",
    "encadeou": "encadear",
    "encaderna": "encadernar",
    "encadernada": "encadernar",
    "encadernadas": "encadernar",
    "encadernado": "encadernar",
    "encadernadora": "encadernador",
    "encadernadoras": "encadernador",
    "encadernadores": "encadernador",
    "encadernados": "encadernar",
    "encadernai": "encadernar",
    "encadernais": "encadernar",
    "encadernam": "encadernar",
    "encadernamentos": "encadernamento",
    "encadernamo": "encadernar",
    "encadernamos": "encadernar",
    "encadernando": "encadernar",
    "encadernara": "encadernar",
    "encadernaram": "encadernar",
    "encadernaras": "encadernar",
    "encadernarde": "encadernar",
    "encadernardes": "encadernar",
    "encadernare": "encadernar",
    "encadernarei": "encadernar",
    "encadernareis": "encadernar",
    "encadernarem": "encadernar",
    "encadernaremos": "encadernar",
    "encadernares": "encadernar",
    "encadernaria": "encadernar",
    "encadernariam": "encadernar",
    "encadernarias": "encadernar",
    "encadernarmo": "encadernar",
    "encadernarmos": "encadernar",
    "encadernará": "encadernar",
    "encadernarás": "encadernar",
    "encadernarão": "encadernar",
    "encadernaríamos": "encadernar",
    "encadernaríeis": "encadernar",
    "encadernas": "encadernar",
    "encadernasse": "encadernar",
    "encadernassem": "encadernar",
    "encadernasses": "encadernar",
    "encadernaste": "encadernar",
    "encadernastes": "encadernar",
    "encadernava": "encadernar",
    "encadernavam": "encadernar",
    "encadernavas": "encadernar",
    "encadernações": "encadernação",
    "encaderne": "encadernar",
    "encadernei": "encadernar",
    "encaderneis": "encadernar",
    "encadernem": "encadernar",
    "encadernemo": "encadernar",
    "encadernemos": "encadernar",
    "encadernes": "encadernar",
    "encaderno": "encadernar",
    "encadernou": "encadernar",
    "encaderná": "encadernar",
    "encadernámo": "encadernar",
    "encadernámos": "encadernar",
    "encadernáramo": "encadernar",
    "encadernáramos": "encadernar",
    "encadernárei": "encadernar",
    "encadernáreis": "encadernar",
    "encadernásseis": "encadernar",
    "encadernássemos": "encadernar",
    "encadernávamo": "encadernar",
    "encadernávamos": "encadernar",
    "encadernávei": "encadernar",
    "encadernáveis": "encadernar",
    "encadeá": "encadear",
    "encadeámo": "encadear",
    "encadeámos": "encadear",
    "encadeáramo": "encadear",
    "encadeáramos": "encadear",
    "encadeárei": "encadear",
    "encadeáreis": "encadear",
    "encadeásseis": "encadear",
    "encadeássemos": "encadear",
    "encadeávamo": "encadear",
    "encadeávamos": "encadear",
    "encadeávei": "encadear",
    "encadeáveis": "encadear",
    "encafua": "encafuar",
    "encafuada": "encafuar",
    "encafuadas": "encafuar",
    "encafuado": "encafuar",
    "encafuados": "encafuar",
    "encafuai": "encafuar",
    "encafuais": "encafuar",
    "encafuam": "encafuar",
    "encafuamo": "encafuar",
    "encafuamos": "encafuar",
    "encafuando": "encafuar",
    "encafuara": "encafuar",
    "encafuaram": "encafuar",
    "encafuaras": "encafuar",
    "encafuarde": "encafuar",
    "encafuardes": "encafuar",
    "encafuare": "encafuar",
    "encafuarei": "encafuar",
    "encafuareis": "encafuar",
    "encafuarem": "encafuar",
    "encafuaremos": "encafuar",
    "encafuares": "encafuar",
    "encafuaria": "encafuar",
    "encafuariam": "encafuar",
    "encafuarias": "encafuar",
    "encafuarmo": "encafuar",
    "encafuarmos": "encafuar",
    "encafuará": "encafuar",
    "encafuarás": "encafuar",
    "encafuarão": "encafuar",
    "encafuaríamos": "encafuar",
    "encafuaríeis": "encafuar",
    "encafuas": "encafuar",
    "encafuasse": "encafuar",
    "encafuassem": "encafuar",
    "encafuasses": "encafuar",
    "encafuaste": "encafuar",
    "encafuastes": "encafuar",
    "encafuava": "encafuar",
    "encafuavam": "encafuar",
    "encafuavas": "encafuar",
    "encafue": "encafuar",
    "encafuei": "encafuar",
    "encafueis": "encafuar",
    "encafuem": "encafuar",
    "encafuemo": "encafuar",
    "encafuemos": "encafuar",
    "encafues": "encafuar",
    "encafuo": "encafuar",
    "encafuou": "encafuar",
    "encafurna": "encafurnar",
    "encafurnada": "encafurnar",
    "encafurnadas": "encafurnar",
    "encafurnado": "encafurnar",
    "encafurnados": "encafurnar",
    "encafurnai": "encafurnar",
    "encafurnais": "encafurnar",
    "encafurnam": "encafurnar",
    "encafurnamo": "encafurnar",
    "encafurnamos": "encafurnar",
    "encafurnando": "encafurnar",
    "encafurnara": "encafurnar",
    "encafurnaram": "encafurnar",
    "encafurnaras": "encafurnar",
    "encafurnarde": "encafurnar",
    "encafurnardes": "encafurnar",
    "encafurnare": "encafurnar",
    "encafurnarei": "encafurnar",
    "encafurnareis": "encafurnar",
    "encafurnarem": "encafurnar",
    "encafurnaremos": "encafurnar",
    "encafurnares": "encafurnar",
    "encafurnaria": "encafurnar",
    "encafurnariam": "encafurnar",
    "encafurnarias": "encafurnar",
    "encafurnarmo": "encafurnar",
    "encafurnarmos": "encafurnar",
    "encafurnará": "encafurnar",
    "encafurnarás": "encafurnar",
    "encafurnarão": "encafurnar",
    "encafurnaríamos": "encafurnar",
    "encafurnaríeis": "encafurnar",
    "encafurnas": "encafurnar",
    "encafurnasse": "encafurnar",
    "encafurnassem": "encafurnar",
    "encafurnasses": "encafurnar",
    "encafurnaste": "encafurnar",
    "encafurnastes": "encafurnar",
    "encafurnava": "encafurnar",
    "encafurnavam": "encafurnar",
    "encafurnavas": "encafurnar",
    "encafurne": "encafurnar",
    "encafurnei": "encafurnar",
    "encafurneis": "encafurnar",
    "encafurnem": "encafurnar",
    "encafurnemo": "encafurnar",
    "encafurnemos": "encafurnar",
    "encafurnes": "encafurnar",
    "encafurno": "encafurnar",
    "encafurnou": "encafurnar",
    "encafurná": "encafurnar",
    "encafurnámo": "encafurnar",
    "encafurnámos": "encafurnar",
    "encafurnáramo": "encafurnar",
    "encafurnáramos": "encafurnar",
    "encafurnárei": "encafurnar",
    "encafurnáreis": "encafurnar",
    "encafurnásseis": "encafurnar",
    "encafurnássemos": "encafurnar",
    "encafurnávamo": "encafurnar",
    "encafurnávamos": "encafurnar",
    "encafurnávei": "encafurnar",
    "encafurnáveis": "encafurnar",
    "encafuá": "encafuar",
    "encafuámo": "encafuar",
    "encafuámos": "encafuar",
    "encafuáramo": "encafuar",
    "encafuáramos": "encafuar",
    "encafuárei": "encafuar",
    "encafuáreis": "encafuar",
    "encafuásseis": "encafuar",
    "encafuássemos": "encafuar",
    "encafuávamo": "encafuar",
    "encafuávamos": "encafuar",
    "encafuávei": "encafuar",
    "encafuáveis": "encafuar",
    "encaibra": "encaibrar",
    "encaibrada": "encaibrar",
    "encaibradas": "encaibrar",
    "encaibrado": "encaibrar",
    "encaibrados": "encaibrar",
    "encaibrai": "encaibrar",
    "encaibrais": "encaibrar",
    "encaibram": "encaibrar",
    "encaibramentos": "encaibramento",
    "encaibramo": "encaibrar",
    "encaibramos": "encaibrar",
    "encaibrando": "encaibrar",
    "encaibrara": "encaibrar",
    "encaibraram": "encaibrar",
    "encaibraras": "encaibrar",
    "encaibrarde": "encaibrar",
    "encaibrardes": "encaibrar",
    "encaibrare": "encaibrar",
    "encaibrarei": "encaibrar",
    "encaibrareis": "encaibrar",
    "encaibrarem": "encaibrar",
    "encaibraremos": "encaibrar",
    "encaibrares": "encaibrar",
    "encaibraria": "encaibrar",
    "encaibrariam": "encaibrar",
    "encaibrarias": "encaibrar",
    "encaibrarmo": "encaibrar",
    "encaibrarmos": "encaibrar",
    "encaibrará": "encaibrar",
    "encaibrarás": "encaibrar",
    "encaibrarão": "encaibrar",
    "encaibraríamos": "encaibrar",
    "encaibraríeis": "encaibrar",
    "encaibras": "encaibrar",
    "encaibrasse": "encaibrar",
    "encaibrassem": "encaibrar",
    "encaibrasses": "encaibrar",
    "encaibraste": "encaibrar",
    "encaibrastes": "encaibrar",
    "encaibrava": "encaibrar",
    "encaibravam": "encaibrar",
    "encaibravas": "encaibrar",
    "encaibre": "encaibrar",
    "encaibrei": "encaibrar",
    "encaibreis": "encaibrar",
    "encaibrem": "encaibrar",
    "encaibremo": "encaibrar",
    "encaibremos": "encaibrar",
    "encaibres": "encaibrar",
    "encaibro": "encaibrar",
    "encaibrou": "encaibrar",
    "encaibrá": "encaibrar",
    "encaibrámo": "encaibrar",
    "encaibrámos": "encaibrar",
    "encaibráramo": "encaibrar",
    "encaibráramos": "encaibrar",
    "encaibrárei": "encaibrar",
    "encaibráreis": "encaibrar",
    "encaibrásseis": "encaibrar",
    "encaibrássemos": "encaibrar",
    "encaibrávamo": "encaibrar",
    "encaibrávamos": "encaibrar",
    "encaibrávei": "encaibrar",
    "encaibráveis": "encaibrar",
    "encaipora": "encaiporar",
    "encaiporada": "encaiporar",
    "encaiporadas": "encaiporar",
    "encaiporado": "encaiporar",
    "encaiporados": "encaiporar",
    "encaiporai": "encaiporar",
    "encaiporais": "encaiporar",
    "encaiporam": "encaiporar",
    "encaiporamo": "encaiporar",
    "encaiporamos": "encaiporar",
    "encaiporando": "encaiporar",
    "encaiporara": "encaiporar",
    "encaiporaram": "encaiporar",
    "encaiporaras": "encaiporar",
    "encaiporarde": "encaiporar",
    "encaiporardes": "encaiporar",
    "encaiporare": "encaiporar",
    "encaiporarei": "encaiporar",
    "encaiporareis": "encaiporar",
    "encaiporarem": "encaiporar",
    "encaiporaremos": "encaiporar",
    "encaiporares": "encaiporar",
    "encaiporaria": "encaiporar",
    "encaiporariam": "encaiporar",
    "encaiporarias": "encaiporar",
    "encaiporarmo": "encaiporar",
    "encaiporarmos": "encaiporar",
    "encaiporará": "encaiporar",
    "encaiporarás": "encaiporar",
    "encaiporarão": "encaiporar",
    "encaiporaríamos": "encaiporar",
    "encaiporaríeis": "encaiporar",
    "encaiporas": "encaiporar",
    "encaiporasse": "encaiporar",
    "encaiporassem": "encaiporar",
    "encaiporasses": "encaiporar",
    "encaiporaste": "encaiporar",
    "encaiporastes": "encaiporar",
    "encaiporava": "encaiporar",
    "encaiporavam": "encaiporar",
    "encaiporavas": "encaiporar",
    "encaipore": "encaiporar",
    "encaiporei": "encaiporar",
    "encaiporeis": "encaiporar",
    "encaiporem": "encaiporar",
    "encaiporemo": "encaiporar",
    "encaiporemos": "encaiporar",
    "encaipores": "encaiporar",
    "encaiporo": "encaiporar",
    "encaiporou": "encaiporar",
    "encaiporá": "encaiporar",
    "encaiporámo": "encaiporar",
    "encaiporámos": "encaiporar",
    "encaiporáramo": "encaiporar",
    "encaiporáramos": "encaiporar",
    "encaiporárei": "encaiporar",
    "encaiporáreis": "encaiporar",
    "encaiporásseis": "encaiporar",
    "encaiporássemos": "encaiporar",
    "encaiporávamo": "encaiporar",
    "encaiporávamos": "encaiporar",
    "encaiporávei": "encaiporar",
    "encaiporáveis": "encaiporar",
    "encaixa": "encaixar",
    "encaixada": "encaixar",
    "encaixadas": "encaixar",
    "encaixado": "encaixar",
    "encaixados": "encaixar",
    "encaixai": "encaixar",
    "encaixais": "encaixar",
    "encaixam": "encaixar",
    "encaixamentos": "encaixamento",
    "encaixamo": "encaixar",
    "encaixamos": "encaixar",
    "encaixando": "encaixar",
    "encaixara": "encaixar",
    "encaixaram": "encaixar",
    "encaixaras": "encaixar",
    "encaixarde": "encaixar",
    "encaixardes": "encaixar",
    "encaixare": "encaixar",
    "encaixarei": "encaixar",
    "encaixareis": "encaixar",
    "encaixarem": "encaixar",
    "encaixaremos": "encaixar",
    "encaixares": "encaixar",
    "encaixaria": "encaixar",
    "encaixariam": "encaixar",
    "encaixarias": "encaixar",
    "encaixarmo": "encaixar",
    "encaixarmos": "encaixar",
    "encaixará": "encaixar",
    "encaixarás": "encaixar",
    "encaixarão": "encaixar",
    "encaixaríamos": "encaixar",
    "encaixaríeis": "encaixar",
    "encaixas": "encaixar",
    "encaixasse": "encaixar",
    "encaixassem": "encaixar",
    "encaixasses": "encaixar",
    "encaixaste": "encaixar",
    "encaixastes": "encaixar",
    "encaixava": "encaixar",
    "encaixavam": "encaixar",
    "encaixavas": "encaixar",
    "encaixe": "encaixar",
    "encaixei": "encaixar",
    "encaixeis": "encaixar",
    "encaixem": "encaixar",
    "encaixemo": "encaixar",
    "encaixemos": "encaixar",
    "encaixes": "encaixe",
    "encaixilha": "encaixilhar",
    "encaixilhada": "encaixilhar",
    "encaixilhadas": "encaixilhar",
    "encaixilhado": "encaixilhar",
    "encaixilhados": "encaixilhar",
    "encaixilhai": "encaixilhar",
    "encaixilhais": "encaixilhar",
    "encaixilham": "encaixilhar",
    "encaixilhamo": "encaixilhar",
    "encaixilhamos": "encaixilhar",
    "encaixilhando": "encaixilhar",
    "encaixilhara": "encaixilhar",
    "encaixilharam": "encaixilhar",
    "encaixilharas": "encaixilhar",
    "encaixilharde": "encaixilhar",
    "encaixilhardes": "encaixilhar",
    "encaixilhare": "encaixilhar",
    "encaixilharei": "encaixilhar",
    "encaixilhareis": "encaixilhar",
    "encaixilharem": "encaixilhar",
    "encaixilharemos": "encaixilhar",
    "encaixilhares": "encaixilhar",
    "encaixilharia": "encaixilhar",
    "encaixilhariam": "encaixilhar",
    "encaixilharias": "encaixilhar",
    "encaixilharmo": "encaixilhar",
    "encaixilharmos": "encaixilhar",
    "encaixilhará": "encaixilhar",
    "encaixilharás": "encaixilhar",
    "encaixilharão": "encaixilhar",
    "encaixilharíamos": "encaixilhar",
    "encaixilharíeis": "encaixilhar",
    "encaixilhas": "encaixilhar",
    "encaixilhasse": "encaixilhar",
    "encaixilhassem": "encaixilhar",
    "encaixilhasses": "encaixilhar",
    "encaixilhaste": "encaixilhar",
    "encaixilhastes": "encaixilhar",
    "encaixilhava": "encaixilhar",
    "encaixilhavam": "encaixilhar",
    "encaixilhavas": "encaixilhar",
    "encaixilhe": "encaixilhar",
    "encaixilhei": "encaixilhar",
    "encaixilheis": "encaixilhar",
    "encaixilhem": "encaixilhar",
    "encaixilhemo": "encaixilhar",
    "encaixilhemos": "encaixilhar",
    "encaixilhes": "encaixilhar",
    "encaixilho": "encaixilhar",
    "encaixilhou": "encaixilhar",
    "encaixilhá": "encaixilhar",
    "encaixilhámo": "encaixilhar",
    "encaixilhámos": "encaixilhar",
    "encaixilháramo": "encaixilhar",
    "encaixilháramos": "encaixilhar",
    "encaixilhárei": "encaixilhar",
    "encaixilháreis": "encaixilhar",
    "encaixilhásseis": "encaixilhar",
    "encaixilhássemos": "encaixilhar",
    "encaixilhávamo": "encaixilhar",
    "encaixilhávamos": "encaixilhar",
    "encaixilhávei": "encaixilhar",
    "encaixilháveis": "encaixilhar",
    "encaixo": "encaixar",
    "encaixos": "encaixo",
    "encaixota": "encaixotar",
    "encaixotada": "encaixotar",
    "encaixotadas": "encaixotar",
    "encaixotado": "encaixotar",
    "encaixotadora": "encaixotador",
    "encaixotadoras": "encaixotador",
    "encaixotadores": "encaixotador",
    "encaixotados": "encaixotar",
    "encaixotai": "encaixotar",
    "encaixotais": "encaixotar",
    "encaixotam": "encaixotar",
    "encaixotamentos": "encaixotamento",
    "encaixotamo": "encaixotar",
    "encaixotamos": "encaixotar",
    "encaixotando": "encaixotar",
    "encaixotara": "encaixotar",
    "encaixotaram": "encaixotar",
    "encaixotaras": "encaixotar",
    "encaixotarde": "encaixotar",
    "encaixotardes": "encaixotar",
    "encaixotare": "encaixotar",
    "encaixotarei": "encaixotar",
    "encaixotareis": "encaixotar",
    "encaixotarem": "encaixotar",
    "encaixotaremos": "encaixotar",
    "encaixotares": "encaixotar",
    "encaixotaria": "encaixotar",
    "encaixotariam": "encaixotar",
    "encaixotarias": "encaixotar",
    "encaixotarmo": "encaixotar",
    "encaixotarmos": "encaixotar",
    "encaixotará": "encaixotar",
    "encaixotarás": "encaixotar",
    "encaixotarão": "encaixotar",
    "encaixotaríamos": "encaixotar",
    "encaixotaríeis": "encaixotar",
    "encaixotas": "encaixotar",
    "encaixotasse": "encaixotar",
    "encaixotassem": "encaixotar",
    "encaixotasses": "encaixotar",
    "encaixotaste": "encaixotar",
    "encaixotastes": "encaixotar",
    "encaixotava": "encaixotar",
    "encaixotavam": "encaixotar",
    "encaixotavas": "encaixotar",
    "encaixote": "encaixotar",
    "encaixotei": "encaixotar",
    "encaixoteis": "encaixotar",
    "encaixotem": "encaixotar",
    "encaixotemo": "encaixotar",
    "encaixotemos": "encaixotar",
    "encaixotes": "encaixotar",
    "encaixoto": "encaixotar",
    "encaixotou": "encaixotar",
    "encaixotá": "encaixotar",
    "encaixotámo": "encaixotar",
    "encaixotámos": "encaixotar",
    "encaixotáramo": "encaixotar",
    "encaixotáramos": "encaixotar",
    "encaixotárei": "encaixotar",
    "encaixotáreis": "encaixotar",
    "encaixotásseis": "encaixotar",
    "encaixotássemos": "encaixotar",
    "encaixotávamo": "encaixotar",
    "encaixotávamos": "encaixotar",
    "encaixotávei": "encaixotar",
    "encaixotáveis": "encaixotar",
    "encaixou": "encaixar",
    "encaixá": "encaixar",
    "encaixámo": "encaixar",
    "encaixámos": "encaixar",
    "encaixáramo": "encaixar",
    "encaixáramos": "encaixar",
    "encaixárei": "encaixar",
    "encaixáreis": "encaixar",
    "encaixásseis": "encaixar",
    "encaixássemos": "encaixar",
    "encaixávamo": "encaixar",
    "encaixávamos": "encaixar",
    "encaixávei": "encaixar",
    "encaixáveis": "encaixável",
    "encala": "encalir",
    "encalacra": "encalacrar",
    "encalacrada": "encalacrar",
    "encalacradas": "encalacrar",
    "encalacradelas": "encalacradela",
    "encalacrado": "encalacrar",
    "encalacradora": "encalacrador",
    "encalacradoras": "encalacrador",
    "encalacradores": "encalacrador",
    "encalacrados": "encalacrar",
    "encalacrai": "encalacrar",
    "encalacrais": "encalacrar",
    "encalacram": "encalacrar",
    "encalacramo": "encalacrar",
    "encalacramos": "encalacrar",
    "encalacrando": "encalacrar",
    "encalacrara": "encalacrar",
    "encalacraram": "encalacrar",
    "encalacraras": "encalacrar",
    "encalacrarde": "encalacrar",
    "encalacrardes": "encalacrar",
    "encalacrare": "encalacrar",
    "encalacrarei": "encalacrar",
    "encalacrareis": "encalacrar",
    "encalacrarem": "encalacrar",
    "encalacraremos": "encalacrar",
    "encalacrares": "encalacrar",
    "encalacraria": "encalacrar",
    "encalacrariam": "encalacrar",
    "encalacrarias": "encalacrar",
    "encalacrarmo": "encalacrar",
    "encalacrarmos": "encalacrar",
    "encalacrará": "encalacrar",
    "encalacrarás": "encalacrar",
    "encalacrarão": "encalacrar",
    "encalacraríamos": "encalacrar",
    "encalacraríeis": "encalacrar",
    "encalacras": "encalacrar",
    "encalacrasse": "encalacrar",
    "encalacrassem": "encalacrar",
    "encalacrasses": "encalacrar",
    "encalacraste": "encalacrar",
    "encalacrastes": "encalacrar",
    "encalacrava": "encalacrar",
    "encalacravam": "encalacrar",
    "encalacravas": "encalacrar",
    "encalacrações": "encalacração",
    "encalacre": "encalacrar",
    "encalacrei": "encalacrar",
    "encalacreis": "encalacrar",
    "encalacrem": "encalacrar",
    "encalacremo": "encalacrar",
    "encalacremos": "encalacrar",
    "encalacres": "encalacrar",
    "encalacro": "encalacrar",
    "encalacrou": "encalacrar",
    "encalacrá": "encalacrar",
    "encalacrámo": "encalacrar",
    "encalacrámos": "encalacrar",
    "encalacráramo": "encalacrar",
    "encalacráramos": "encalacrar",
    "encalacrárei": "encalacrar",
    "encalacráreis": "encalacrar",
    "encalacrásseis": "encalacrar",
    "encalacrássemos": "encalacrar",
    "encalacrávamo": "encalacrar",
    "encalacrávamos": "encalacrar",
    "encalacrávei": "encalacrar",
    "encalacráveis": "encalacrar",
    "encalada": "encalar",
    "encaladas": "encalar",
    "encalado": "encalar",
    "encalados": "encalar",
    "encalai": "encalar",
    "encalais": "encalir",
    "encalam": "encalir",
    "encalamistra": "encalamistrar",
    "encalamistrada": "encalamistrar",
    "encalamistradas": "encalamistrar",
    "encalamistrado": "encalamistrar",
    "encalamistrados": "encalamistrar",
    "encalamistrai": "encalamistrar",
    "encalamistrais": "encalamistrar",
    "encalamistram": "encalamistrar",
    "encalamistramo": "encalamistrar",
    "encalamistramos": "encalamistrar",
    "encalamistrando": "encalamistrar",
    "encalamistrara": "encalamistrar",
    "encalamistraram": "encalamistrar",
    "encalamistraras": "encalamistrar",
    "encalamistrarde": "encalamistrar",
    "encalamistrardes": "encalamistrar",
    "encalamistrare": "encalamistrar",
    "encalamistrarei": "encalamistrar",
    "encalamistrareis": "encalamistrar",
    "encalamistrarem": "encalamistrar",
    "encalamistraremos": "encalamistrar",
    "encalamistrares": "encalamistrar",
    "encalamistraria": "encalamistrar",
    "encalamistrariam": "encalamistrar",
    "encalamistrarias": "encalamistrar",
    "encalamistrarmo": "encalamistrar",
    "encalamistrarmos": "encalamistrar",
    "encalamistrará": "encalamistrar",
    "encalamistrarás": "encalamistrar",
    "encalamistrarão": "encalamistrar",
    "encalamistraríamos": "encalamistrar",
    "encalamistraríeis": "encalamistrar",
    "encalamistras": "encalamistrar",
    "encalamistrasse": "encalamistrar",
    "encalamistrassem": "encalamistrar",
    "encalamistrasses": "encalamistrar",
    "encalamistraste": "encalamistrar",
    "encalamistrastes": "encalamistrar",
    "encalamistrava": "encalamistrar",
    "encalamistravam": "encalamistrar",
    "encalamistravas": "encalamistrar",
    "encalamistre": "encalamistrar",
    "encalamistrei": "encalamistrar",
    "encalamistreis": "encalamistrar",
    "encalamistrem": "encalamistrar",
    "encalamistremo": "encalamistrar",
    "encalamistremos": "encalamistrar",
    "encalamistres": "encalamistrar",
    "encalamistro": "encalamistrar",
    "encalamistrou": "encalamistrar",
    "encalamistrá": "encalamistrar",
    "encalamistrámo": "encalamistrar",
    "encalamistrámos": "encalamistrar",
    "encalamistráramo": "encalamistrar",
    "encalamistráramos": "encalamistrar",
    "encalamistrárei": "encalamistrar",
    "encalamistráreis": "encalamistrar",
    "encalamistrásseis": "encalamistrar",
    "encalamistrássemos": "encalamistrar",
    "encalamistrávamo": "encalamistrar",
    "encalamistrávamos": "encalamistrar",
    "encalamistrávei": "encalamistrar",
    "encalamistráveis": "encalamistrar",
    "encalamo": "encalir",
    "encalamos": "encalir",
    "encalamouca": "encalamoucar",
    "encalamoucada": "encalamoucar",
    "encalamoucadas": "encalamoucar",
    "encalamoucado": "encalamoucar",
    "encalamoucados": "encalamoucar",
    "encalamoucai": "encalamoucar",
    "encalamoucais": "encalamoucar",
    "encalamoucam": "encalamoucar",
    "encalamoucamo": "encalamoucar",
    "encalamoucamos": "encalamoucar",
    "encalamoucando": "encalamoucar",
    "encalamoucara": "encalamoucar",
    "encalamoucaram": "encalamoucar",
    "encalamoucaras": "encalamoucar",
    "encalamoucarde": "encalamoucar",
    "encalamoucardes": "encalamoucar",
    "encalamoucare": "encalamoucar",
    "encalamoucarei": "encalamoucar",
    "encalamoucareis": "encalamoucar",
    "encalamoucarem": "encalamoucar",
    "encalamoucaremos": "encalamoucar",
    "encalamoucares": "encalamoucar",
    "encalamoucaria": "encalamoucar",
    "encalamoucariam": "encalamoucar",
    "encalamoucarias": "encalamoucar",
    "encalamoucarmo": "encalamoucar",
    "encalamoucarmos": "encalamoucar",
    "encalamoucará": "encalamoucar",
    "encalamoucarás": "encalamoucar",
    "encalamoucarão": "encalamoucar",
    "encalamoucaríamos": "encalamoucar",
    "encalamoucaríeis": "encalamoucar",
    "encalamoucas": "encalamoucar",
    "encalamoucasse": "encalamoucar",
    "encalamoucassem": "encalamoucar",
    "encalamoucasses": "encalamoucar",
    "encalamoucaste": "encalamoucar",
    "encalamoucastes": "encalamoucar",
    "encalamoucava": "encalamoucar",
    "encalamoucavam": "encalamoucar",
    "encalamoucavas": "encalamoucar",
    "encalamouco": "encalamoucar",
    "encalamoucou": "encalamoucar",
    "encalamoucá": "encalamoucar",
    "encalamoucámo": "encalamoucar",
    "encalamoucámos": "encalamoucar",
    "encalamoucáramo": "encalamoucar",
    "encalamoucáramos": "encalamoucar",
    "encalamoucárei": "encalamoucar",
    "encalamoucáreis": "encalamoucar",
    "encalamoucásseis": "encalamoucar",
    "encalamoucássemos": "encalamoucar",
    "encalamoucávamo": "encalamoucar",
    "encalamoucávamos": "encalamoucar",
    "encalamoucávei": "encalamoucar",
    "encalamoucáveis": "encalamoucar",
    "encalamouque": "encalamoucar",
    "encalamouquei": "encalamoucar",
    "encalamouqueis": "encalamoucar",
    "encalamouquem": "encalamoucar",
    "encalamouquemo": "encalamoucar",
    "encalamouquemos": "encalamoucar",
    "encalamouques": "encalamoucar",
    "encalando": "encalar",
    "encalara": "encalar",
    "encalaram": "encalar",
    "encalaras": "encalar",
    "encalarde": "encalar",
    "encalardes": "encalar",
    "encalare": "encalar",
    "encalarei": "encalar",
    "encalareis": "encalar",
    "encalarem": "encalar",
    "encalaremos": "encalar",
    "encalares": "encalar",
    "encalaria": "encalar",
    "encalariam": "encalar",
    "encalarias": "encalar",
    "encalarmo": "encalar",
    "encalarmos": "encalar",
    "encalará": "encalar",
    "encalarás": "encalar",
    "encalarão": "encalar",
    "encalaríamos": "encalar",
    "encalaríeis": "encalar",
    "encalas": "encalir",
    "encalasse": "encalar",
    "encalassem": "encalar",
    "encalasses": "encalar",
    "encalaste": "encalar",
    "encalastes": "encalar",
    "encalava": "encalar",
    "encalavam": "encalar",
    "encalavas": "encalar",
    "encalcadeiras": "encalcadeira",
    "encalce": "encalçar",
    "encalcei": "encalçar",
    "encalceis": "encalçar",
    "encalcem": "encalçar",
    "encalcemo": "encalçar",
    "encalcemos": "encalçar",
    "encalces": "encalçar",
    "encaldeira": "encaldeirar",
    "encaldeirada": "encaldeirar",
    "encaldeiradas": "encaldeirar",
    "encaldeirado": "encaldeirar",
    "encaldeirados": "encaldeirar",
    "encaldeirai": "encaldeirar",
    "encaldeirais": "encaldeirar",
    "encaldeiram": "encaldeirar",
    "encaldeiramo": "encaldeirar",
    "encaldeiramos": "encaldeirar",
    "encaldeirando": "encaldeirar",
    "encaldeirara": "encaldeirar",
    "encaldeiraram": "encaldeirar",
    "encaldeiraras": "encaldeirar",
    "encaldeirarde": "encaldeirar",
    "encaldeirardes": "encaldeirar",
    "encaldeirare": "encaldeirar",
    "encaldeirarei": "encaldeirar",
    "encaldeirareis": "encaldeirar",
    "encaldeirarem": "encaldeirar",
    "encaldeiraremos": "encaldeirar",
    "encaldeirares": "encaldeirar",
    "encaldeiraria": "encaldeirar",
    "encaldeirariam": "encaldeirar",
    "encaldeirarias": "encaldeirar",
    "encaldeirarmo": "encaldeirar",
    "encaldeirarmos": "encaldeirar",
    "encaldeirará": "encaldeirar",
    "encaldeirarás": "encaldeirar",
    "encaldeirarão": "encaldeirar",
    "encaldeiraríamos": "encaldeirar",
    "encaldeiraríeis": "encaldeirar",
    "encaldeiras": "encaldeirar",
    "encaldeirasse": "encaldeirar",
    "encaldeirassem": "encaldeirar",
    "encaldeirasses": "encaldeirar",
    "encaldeiraste": "encaldeirar",
    "encaldeirastes": "encaldeirar",
    "encaldeirava": "encaldeirar",
    "encaldeiravam": "encaldeirar",
    "encaldeiravas": "encaldeirar",
    "encaldeirações": "encaldeiração",
    "encaldeire": "encaldeirar",
    "encaldeirei": "encaldeirar",
    "encaldeireis": "encaldeirar",
    "encaldeirem": "encaldeirar",
    "encaldeiremo": "encaldeirar",
    "encaldeiremos": "encaldeirar",
    "encaldeires": "encaldeirar",
    "encaldeiro": "encaldeirar",
    "encaldeirou": "encaldeirar",
    "encaldeirá": "encaldeirar",
    "encaldeirámo": "encaldeirar",
    "encaldeirámos": "encaldeirar",
    "encaldeiráramo": "encaldeirar",
    "encaldeiráramos": "encaldeirar",
    "encaldeirárei": "encaldeirar",
    "encaldeiráreis": "encaldeirar",
    "encaldeirásseis": "encaldeirar",
    "encaldeirássemos": "encaldeirar",
    "encaldeirávamo": "encaldeirar",
    "encaldeirávamos": "encaldeirar",
    "encaldeirávei": "encaldeirar",
    "encaldeiráveis": "encaldeirar",
    "encale": "encalir",
    "encalece": "encalecer",
    "encalecei": "encalecer",
    "encaleceis": "encalecer",
    "encalecem": "encalecer",
    "encalecemo": "encalecer",
    "encalecemos": "encalecer",
    "encalecendo": "encalecer",
    "encalecera": "encalecer",
    "encaleceram": "encalecer",
    "encaleceras": "encalecer",
    "encalecerdes": "encalecer",
    "encalecerei": "encalecer",
    "encalecereis": "encalecer",
    "encalecerem": "encalecer",
    "encaleceremos": "encalecer",
    "encaleceres": "encalecer",
    "encaleceria": "encalecer",
    "encaleceriam": "encalecer",
    "encalecerias": "encalecer",
    "encalecermo": "encalecer",
    "encalecermos": "encalecer",
    "encalecerá": "encalecer",
    "encalecerás": "encalecer",
    "encalecerão": "encalecer",
    "encaleceríamos": "encalecer",
    "encaleceríeis": "encalecer",
    "encaleces": "encalecer",
    "encalecesse": "encalecer",
    "encalecessem": "encalecer",
    "encalecesses": "encalecer",
    "encaleceste": "encalecer",
    "encalecestes": "encalecer",
    "encaleceu": "encalecer",
    "encaleci": "encalecer",
    "encalecia": "encalecer",
    "encaleciam": "encalecer",
    "encalecias": "encalecer",
    "encalecida": "encalecer",
    "encalecidas": "encalecer",
    "encalecido": "encalecer",
    "encalecidos": "encalecer",
    "encalecêramo": "encalecer",
    "encalecêramos": "encalecer",
    "encalecêreis": "encalecer",
    "encalecêsseis": "encalecer",
    "encalecêssemos": "encalecer",
    "encalecíamo": "encalecer",
    "encalecíamos": "encalecer",
    "encalecíeis": "encalecer",
    "encalei": "encalar",
    "encaleira": "encaleirar",
    "encaleirada": "encaleirar",
    "encaleiradas": "encaleirar",
    "encaleirado": "encaleirar",
    "encaleirados": "encaleirar",
    "encaleirai": "encaleirar",
    "encaleirais": "encaleirar",
    "encaleiram": "encaleirar",
    "encaleiramo": "encaleirar",
    "encaleiramos": "encaleirar",
    "encaleirando": "encaleirar",
    "encaleirara": "encaleirar",
    "encaleiraram": "encaleirar",
    "encaleiraras": "encaleirar",
    "encaleirarde": "encaleirar",
    "encaleirardes": "encaleirar",
    "encaleirare": "encaleirar",
    "encaleirarei": "encaleirar",
    "encaleirareis": "encaleirar",
    "encaleirarem": "encaleirar",
    "encaleiraremos": "encaleirar",
    "encaleirares": "encaleirar",
    "encaleiraria": "encaleirar",
    "encaleirariam": "encaleirar",
    "encaleirarias": "encaleirar",
    "encaleirarmo": "encaleirar",
    "encaleirarmos": "encaleirar",
    "encaleirará": "encaleirar",
    "encaleirarás": "encaleirar",
    "encaleirarão": "encaleirar",
    "encaleiraríamos": "encaleirar",
    "encaleiraríeis": "encaleirar",
    "encaleiras": "encaleirar",
    "encaleirasse": "encaleirar",
    "encaleirassem": "encaleirar",
    "encaleirasses": "encaleirar",
    "encaleiraste": "encaleirar",
    "encaleirastes": "encaleirar",
    "encaleirava": "encaleirar",
    "encaleiravam": "encaleirar",
    "encaleiravas": "encaleirar",
    "encaleire": "encaleirar",
    "encaleirei": "encaleirar",
    "encaleireis": "encaleirar",
    "encaleirem": "encaleirar",
    "encaleiremo": "encaleirar",
    "encaleiremos": "encaleirar",
    "encaleires": "encaleirar",
    "encaleiro": "encaleirar",
    "encaleirou": "encaleirar",
    "encaleirá": "encaleirar",
    "encaleirámo": "encaleirar",
    "encaleirámos": "encaleirar",
    "encaleiráramo": "encaleirar",
    "encaleiráramos": "encaleirar",
    "encaleirárei": "encaleirar",
    "encaleiráreis": "encaleirar",
    "encaleirásseis": "encaleirar",
    "encaleirássemos": "encaleirar",
    "encaleirávamo": "encaleirar",
    "encaleirávamos": "encaleirar",
    "encaleirávei": "encaleirar",
    "encaleiráveis": "encaleirar",
    "encaleis": "encalar",
    "encalem": "encalir",
    "encalemo": "encalar",
    "encalemos": "encalar",
    "encales": "encalir",
    "encaleça": "encalecer",
    "encaleçais": "encalecer",
    "encaleçam": "encalecer",
    "encaleçamo": "encalecer",
    "encaleçamos": "encalecer",
    "encaleças": "encalecer",
    "encaleço": "encalecer",
    "encalha": "encalhar",
    "encalhada": "encalhar",
    "encalhadas": "encalhar",
    "encalhado": "encalhar",
    "encalhados": "encalhar",
    "encalhai": "encalhar",
    "encalhais": "encalhar",
    "encalham": "encalhar",
    "encalhamentos": "encalhamento",
    "encalhamo": "encalhar",
    "encalhamos": "encalhar",
    "encalhando": "encalhar",
    "encalhara": "encalhar",
    "encalharam": "encalhar",
    "encalharas": "encalhar",
    "encalhardes": "encalhar",
    "encalharei": "encalhar",
    "encalhareis": "encalhar",
    "encalharem": "encalhar",
    "encalharemos": "encalhar",
    "encalhares": "encalhar",
    "encalharia": "encalhar",
    "encalhariam": "encalhar",
    "encalharias": "encalhar",
    "encalharmo": "encalhar",
    "encalharmos": "encalhar",
    "encalhará": "encalhar",
    "encalharás": "encalhar",
    "encalharão": "encalhar",
    "encalharíamos": "encalhar",
    "encalharíeis": "encalhar",
    "encalhas": "encalhar",
    "encalhasse": "encalhar",
    "encalhassem": "encalhar",
    "encalhasses": "encalhar",
    "encalhaste": "encalhar",
    "encalhastes": "encalhar",
    "encalhava": "encalhar",
    "encalhavam": "encalhar",
    "encalhavas": "encalhar",
    "encalhações": "encalhação",
    "encalhe": "encalhar",
    "encalhei": "encalhar",
    "encalheis": "encalhar",
    "encalhem": "encalhar",
    "encalhemo": "encalhar",
    "encalhemos": "encalhar",
    "encalhes": "encalhe",
    "encalho": "encalhar",
    "encalhos": "encalho",
    "encalhou": "encalhar",
    "encalhámo": "encalhar",
    "encalhámos": "encalhar",
    "encalháramo": "encalhar",
    "encalháramos": "encalhar",
    "encalháreis": "encalhar",
    "encalhásseis": "encalhar",
    "encalhássemos": "encalhar",
    "encalhávamo": "encalhar",
    "encalhávamos": "encalhar",
    "encalháveis": "encalhar",
    "encali": "encalir",
    "encalia": "encalir",
    "encaliam": "encalir",
    "encalias": "encalir",
    "encalice": "encaliçar",
    "encalicei": "encaliçar",
    "encaliceis": "encaliçar",
    "encalicem": "encaliçar",
    "encalicemo": "encaliçar",
    "encalicemos": "encaliçar",
    "encalices": "encaliçar",
    "encalida": "encalir",
    "encalidas": "encalir",
    "encalidelas": "encalidela",
    "encalido": "encalir",
    "encalidos": "encalir",
    "encalimo": "encalir",
    "encalimos": "encalir",
    "encalindo": "encalir",
    "encalira": "encalir",
    "encaliram": "encalir",
    "encaliras": "encalir",
    "encalirde": "encalir",
    "encalirdes": "encalir",
    "encalire": "encalir",
    "encalirei": "encalir",
    "encalireis": "encalir",
    "encalirem": "encalir",
    "encaliremos": "encalir",
    "encalires": "encalir",
    "encaliria": "encalir",
    "encaliriam": "encalir",
    "encalirias": "encalir",
    "encalirmo": "encalir",
    "encalirmos": "encalir",
    "encalirá": "encalir",
    "encalirás": "encalir",
    "encalirão": "encalir",
    "encaliríamos": "encalir",
    "encaliríeis": "encalir",
    "encalis": "encalir",
    "encalisse": "encalir",
    "encalissem": "encalir",
    "encalisses": "encalir",
    "encalista": "encalistar",
    "encalistada": "encalistar",
    "encalistadas": "encalistar",
    "encalistado": "encalistar",
    "encalistados": "encalistar",
    "encalistai": "encalistar",
    "encalistais": "encalistar",
    "encalistam": "encalistar",
    "encalistamo": "encalistar",
    "encalistamos": "encalistar",
    "encalistando": "encalistar",
    "encalistara": "encalistar",
    "encalistaram": "encalistar",
    "encalistaras": "encalistar",
    "encalistarde": "encalistar",
    "encalistardes": "encalistar",
    "encalistare": "encalistar",
    "encalistarei": "encalistar",
    "encalistareis": "encalistar",
    "encalistarem": "encalistar",
    "encalistaremos": "encalistar",
    "encalistares": "encalistar",
    "encalistaria": "encalistar",
    "encalistariam": "encalistar",
    "encalistarias": "encalistar",
    "encalistarmo": "encalistar",
    "encalistarmos": "encalistar",
    "encalistará": "encalistar",
    "encalistarás": "encalistar",
    "encalistarão": "encalistar",
    "encalistaríamos": "encalistar",
    "encalistaríeis": "encalistar",
    "encalistas": "encalistar",
    "encalistasse": "encalistar",
    "encalistassem": "encalistar",
    "encalistasses": "encalistar",
    "encalistaste": "encalistar",
    "encalistastes": "encalistar",
    "encalistava": "encalistar",
    "encalistavam": "encalistar",
    "encalistavas": "encalistar",
    "encaliste": "encalistar",
    "encalistei": "encalistar",
    "encalisteis": "encalistar",
    "encalistem": "encalistar",
    "encalistemo": "encalistar",
    "encalistemos": "encalistar",
    "encalistes": "encalistar",
    "encalisto": "encalistar",
    "encalistou": "encalistar",
    "encalistra": "encalistrar",
    "encalistrada": "encalistrar",
    "encalistradas": "encalistrar",
    "encalistrado": "encalistrar",
    "encalistrados": "encalistrar",
    "encalistrai": "encalistrar",
    "encalistrais": "encalistrar",
    "encalistram": "encalistrar",
    "encalistramo": "encalistrar",
    "encalistramos": "encalistrar",
    "encalistrando": "encalistrar",
    "encalistrara": "encalistrar",
    "encalistraram": "encalistrar",
    "encalistraras": "encalistrar",
    "encalistrarde": "encalistrar",
    "encalistrardes": "encalistrar",
    "encalistrare": "encalistrar",
    "encalistrarei": "encalistrar",
    "encalistrareis": "encalistrar",
    "encalistrarem": "encalistrar",
    "encalistraremos": "encalistrar",
    "encalistrares": "encalistrar",
    "encalistraria": "encalistrar",
    "encalistrariam": "encalistrar",
    "encalistrarias": "encalistrar",
    "encalistrarmo": "encalistrar",
    "encalistrarmos": "encalistrar",
    "encalistrará": "encalistrar",
    "encalistrarás": "encalistrar",
    "encalistrarão": "encalistrar",
    "encalistraríamos": "encalistrar",
    "encalistraríeis": "encalistrar",
    "encalistras": "encalistrar",
    "encalistrasse": "encalistrar",
    "encalistrassem": "encalistrar",
    "encalistrasses": "encalistrar",
    "encalistraste": "encalistrar",
    "encalistrastes": "encalistrar",
    "encalistrava": "encalistrar",
    "encalistravam": "encalistrar",
    "encalistravas": "encalistrar",
    "encalistre": "encalistrar",
    "encalistrei": "encalistrar",
    "encalistreis": "encalistrar",
    "encalistrem": "encalistrar",
    "encalistremo": "encalistrar",
    "encalistremos": "encalistrar",
    "encalistres": "encalistrar",
    "encalistro": "encalistrar",
    "encalistrou": "encalistrar",
    "encalistrá": "encalistrar",
    "encalistrámo": "encalistrar",
    "encalistrámos": "encalistrar",
    "encalistráramo": "encalistrar",
    "encalistráramos": "encalistrar",
    "encalistrárei": "encalistrar",
    "encalistráreis": "encalistrar",
    "encalistrásseis": "encalistrar",
    "encalistrássemos": "encalistrar",
    "encalistrávamo": "encalistrar",
    "encalistrávamos": "encalistrar",
    "encalistrávei": "encalistrar",
    "encalistráveis": "encalistrar",
    "encalistá": "encalistar",
    "encalistámo": "encalistar",
    "encalistámos": "encalistar",
    "encalistáramo": "encalistar",
    "encalistáramos": "encalistar",
    "encalistárei": "encalistar",
    "encalistáreis": "encalistar",
    "encalistásseis": "encalistar",
    "encalistássemos": "encalistar",
    "encalistávamo": "encalistar",
    "encalistávamos": "encalistar",
    "encalistávei": "encalistar",
    "encalistáveis": "encalistar",
    "encaliu": "encalir",
    "encaliça": "encaliçar",
    "encaliçada": "encaliçar",
    "encaliçadas": "encaliçar",
    "encaliçado": "encaliçar",
    "encaliçados": "encaliçar",
    "encaliçai": "encaliçar",
    "encaliçais": "encaliçar",
    "encaliçam": "encaliçar",
    "encaliçamo": "encaliçar",
    "encaliçamos": "encaliçar",
    "encaliçando": "encaliçar",
    "encaliçara": "encaliçar",
    "encaliçaram": "encaliçar",
    "encaliçaras": "encaliçar",
    "encaliçarde": "encaliçar",
    "encaliçardes": "encaliçar",
    "encaliçare": "encaliçar",
    "encaliçarei": "encaliçar",
    "encaliçareis": "encaliçar",
    "encaliçarem": "encaliçar",
    "encaliçaremos": "encaliçar",
    "encaliçares": "encaliçar",
    "encaliçaria": "encaliçar",
    "encaliçariam": "encaliçar",
    "encaliçarias": "encaliçar",
    "encaliçarmo": "encaliçar",
    "encaliçarmos": "encaliçar",
    "encaliçará": "encaliçar",
    "encaliçarás": "encaliçar",
    "encaliçarão": "encaliçar",
    "encaliçaríamos": "encaliçar",
    "encaliçaríeis": "encaliçar",
    "encaliças": "encaliçar",
    "encaliçasse": "encaliçar",
    "encaliçassem": "encaliçar",
    "encaliçasses": "encaliçar",
    "encaliçaste": "encaliçar",
    "encaliçastes": "encaliçar",
    "encaliçava": "encaliçar",
    "encaliçavam": "encaliçar",
    "encaliçavas": "encaliçar",
    "encaliço": "encaliçar",
    "encaliçou": "encaliçar",
    "encaliçá": "encaliçar",
    "encaliçámo": "encaliçar",
    "encaliçámos": "encaliçar",
    "encaliçáramo": "encaliçar",
    "encaliçáramos": "encaliçar",
    "encaliçárei": "encaliçar",
    "encaliçáreis": "encaliçar",
    "encaliçásseis": "encaliçar",
    "encaliçássemos": "encaliçar",
    "encaliçávamo": "encaliçar",
    "encaliçávamos": "encaliçar",
    "encaliçávei": "encaliçar",
    "encaliçáveis": "encaliçar",
    "encalma": "encalmar",
    "encalmada": "encalmar",
    "encalmadas": "encalmar",
    "encalmadiça": "encalmadiço",
    "encalmadiças": "encalmadiço",
    "encalmadiços": "encalmadiço",
    "encalmado": "encalmar",
    "encalmados": "encalmar",
    "encalmai": "encalmar",
    "encalmais": "encalmar",
    "encalmam": "encalmar",
    "encalmamentos": "encalmamento",
    "encalmamo": "encalmar",
    "encalmamos": "encalmar",
    "encalmando": "encalmar",
    "encalmara": "encalmar",
    "encalmaram": "encalmar",
    "encalmaras": "encalmar",
    "encalmarde": "encalmar",
    "encalmardes": "encalmar",
    "encalmare": "encalmar",
    "encalmarei": "encalmar",
    "encalmareis": "encalmar",
    "encalmarem": "encalmar",
    "encalmaremos": "encalmar",
    "encalmares": "encalmar",
    "encalmaria": "encalmar",
    "encalmariam": "encalmar",
    "encalmarias": "encalmar",
    "encalmarmo": "encalmar",
    "encalmarmos": "encalmar",
    "encalmará": "encalmar",
    "encalmarás": "encalmar",
    "encalmarão": "encalmar",
    "encalmaríamos": "encalmar",
    "encalmaríeis": "encalmar",
    "encalmas": "encalmar",
    "encalmasse": "encalmar",
    "encalmassem": "encalmar",
    "encalmasses": "encalmar",
    "encalmaste": "encalmar",
    "encalmastes": "encalmar",
    "encalmava": "encalmar",
    "encalmavam": "encalmar",
    "encalmavas": "encalmar",
    "encalme": "encalmar",
    "encalmei": "encalmar",
    "encalmeis": "encalmar",
    "encalmem": "encalmar",
    "encalmemo": "encalmar",
    "encalmemos": "encalmar",
    "encalmes": "encalmar",
    "encalmo": "encalmar",
    "encalmou": "encalmar",
    "encalmá": "encalmar",
    "encalmámo": "encalmar",
    "encalmámos": "encalmar",
    "encalmáramo": "encalmar",
    "encalmáramos": "encalmar",
    "encalmárei": "encalmar",
    "encalmáreis": "encalmar",
    "encalmásseis": "encalmar",
    "encalmássemos": "encalmar",
    "encalmávamo": "encalmar",
    "encalmávamos": "encalmar",
    "encalmávei": "encalmar",
    "encalmáveis": "encalmar",
    "encalo": "encalir",
    "encalou": "encalar",
    "encalvece": "encalvecer",
    "encalvecei": "encalvecer",
    "encalveceis": "encalvecer",
    "encalvecem": "encalvecer",
    "encalvecemo": "encalvecer",
    "encalvecemos": "encalvecer",
    "encalvecendo": "encalvecer",
    "encalvecera": "encalvecer",
    "encalveceram": "encalvecer",
    "encalveceras": "encalvecer",
    "encalvecerdes": "encalvecer",
    "encalvecerei": "encalvecer",
    "encalvecereis": "encalvecer",
    "encalvecerem": "encalvecer",
    "encalveceremos": "encalvecer",
    "encalveceres": "encalvecer",
    "encalveceria": "encalvecer",
    "encalveceriam": "encalvecer",
    "encalvecerias": "encalvecer",
    "encalvecermo": "encalvecer",
    "encalvecermos": "encalvecer",
    "encalvecerá": "encalvecer",
    "encalvecerás": "encalvecer",
    "encalvecerão": "encalvecer",
    "encalveceríamos": "encalvecer",
    "encalveceríeis": "encalvecer",
    "encalveces": "encalvecer",
    "encalvecesse": "encalvecer",
    "encalvecessem": "encalvecer",
    "encalvecesses": "encalvecer",
    "encalveceste": "encalvecer",
    "encalvecestes": "encalvecer",
    "encalveceu": "encalvecer",
    "encalveci": "encalvecer",
    "encalvecia": "encalvecer",
    "encalveciam": "encalvecer",
    "encalvecias": "encalvecer",
    "encalvecida": "encalvecer",
    "encalvecidas": "encalvecer",
    "encalvecido": "encalvecer",
    "encalvecidos": "encalvecer",
    "encalvecêramo": "encalvecer",
    "encalvecêramos": "encalvecer",
    "encalvecêreis": "encalvecer",
    "encalvecêsseis": "encalvecer",
    "encalvecêssemos": "encalvecer",
    "encalvecíamo": "encalvecer",
    "encalvecíamos": "encalvecer",
    "encalvecíeis": "encalvecer",
    "encalveça": "encalvecer",
    "encalveçais": "encalvecer",
    "encalveçam": "encalvecer",
    "encalveçamo": "encalvecer",
    "encalveçamos": "encalvecer",
    "encalveças": "encalvecer",
    "encalveço": "encalvecer",
    "encalá": "encalar",
    "encalámo": "encalar",
    "encalámos": "encalar",
    "encaláramo": "encalar",
    "encaláramos": "encalar",
    "encalárei": "encalar",
    "encaláreis": "encalar",
    "encalásseis": "encalar",
    "encalássemos": "encalar",
    "encalávamo": "encalar",
    "encalávamos": "encalar",
    "encalávei": "encalar",
    "encaláveis": "encalar",
    "encalça": "encalçar",
    "encalçada": "encalçar",
    "encalçadas": "encalçar",
    "encalçado": "encalçar",
    "encalçados": "encalçar",
    "encalçai": "encalçar",
    "encalçais": "encalçar",
    "encalçam": "encalçar",
    "encalçamo": "encalçar",
    "encalçamos": "encalçar",
    "encalçando": "encalçar",
    "encalçara": "encalçar",
    "encalçaram": "encalçar",
    "encalçaras": "encalçar",
    "encalçarde": "encalçar",
    "encalçardes": "encalçar",
    "encalçare": "encalçar",
    "encalçarei": "encalçar",
    "encalçareis": "encalçar",
    "encalçarem": "encalçar",
    "encalçaremos": "encalçar",
    "encalçares": "encalçar",
    "encalçaria": "encalçar",
    "encalçariam": "encalçar",
    "encalçarias": "encalçar",
    "encalçarmo": "encalçar",
    "encalçarmos": "encalçar",
    "encalçará": "encalçar",
    "encalçarás": "encalçar",
    "encalçarão": "encalçar",
    "encalçaríamos": "encalçar",
    "encalçaríeis": "encalçar",
    "encalças": "encalçar",
    "encalçasse": "encalçar",
    "encalçassem": "encalçar",
    "encalçasses": "encalçar",
    "encalçaste": "encalçar",
    "encalçastes": "encalçar",
    "encalçava": "encalçar",
    "encalçavam": "encalçar",
    "encalçavas": "encalçar",
    "encalço": "encalçar",
    "encalços": "encalço",
    "encalçou": "encalçar",
    "encalçá": "encalçar",
    "encalçámo": "encalçar",
    "encalçámos": "encalçar",
    "encalçáramo": "encalçar",
    "encalçáramos": "encalçar",
    "encalçárei": "encalçar",
    "encalçáreis": "encalçar",
    "encalçásseis": "encalçar",
    "encalçássemos": "encalçar",
    "encalçávamo": "encalçar",
    "encalçávamos": "encalçar",
    "encalçávei": "encalçar",
    "encalçáveis": "encalçar",
    "encalíamo": "encalir",
    "encalíamos": "encalir",
    "encalíei": "encalir",
    "encalíeis": "encalir",
    "encalíramo": "encalir",
    "encalíramos": "encalir",
    "encalírei": "encalir",
    "encalíreis": "encalir",
    "encalísseis": "encalir",
    "encalíssemos": "encalir",
    "encama": "encamar",
    "encamada": "encamar",
    "encamadas": "encamar",
    "encamado": "encamar",
    "encamados": "encamar",
    "encamai": "encamar",
    "encamais": "encamar",
    "encamam": "encamar",
    "encamamo": "encamar",
    "encamamos": "encamar",
    "encamando": "encamar",
    "encamara": "encamar",
    "encamaram": "encamar",
    "encamaras": "encamar",
    "encamarde": "encamar",
    "encamardes": "encamar",
    "encamare": "encamar",
    "encamarei": "encamar",
    "encamareis": "encamar",
    "encamarem": "encamar",
    "encamaremos": "encamar",
    "encamares": "encamar",
    "encamaria": "encamar",
    "encamariam": "encamar",
    "encamarias": "encamar",
    "encamarmo": "encamar",
    "encamarmos": "encamar",
    "encamarota": "encamarotar",
    "encamarotada": "encamarotar",
    "encamarotadas": "encamarotar",
    "encamarotado": "encamarotar",
    "encamarotados": "encamarotar",
    "encamarotai": "encamarotar",
    "encamarotais": "encamarotar",
    "encamarotam": "encamarotar",
    "encamarotamo": "encamarotar",
    "encamarotamos": "encamarotar",
    "encamarotando": "encamarotar",
    "encamarotara": "encamarotar",
    "encamarotaram": "encamarotar",
    "encamarotaras": "encamarotar",
    "encamarotarde": "encamarotar",
    "encamarotardes": "encamarotar",
    "encamarotare": "encamarotar",
    "encamarotarei": "encamarotar",
    "encamarotareis": "encamarotar",
    "encamarotarem": "encamarotar",
    "encamarotaremos": "encamarotar",
    "encamarotares": "encamarotar",
    "encamarotaria": "encamarotar",
    "encamarotariam": "encamarotar",
    "encamarotarias": "encamarotar",
    "encamarotarmo": "encamarotar",
    "encamarotarmos": "encamarotar",
    "encamarotará": "encamarotar",
    "encamarotarás": "encamarotar",
    "encamarotarão": "encamarotar",
    "encamarotaríamos": "encamarotar",
    "encamarotaríeis": "encamarotar",
    "encamarotas": "encamarotar",
    "encamarotasse": "encamarotar",
    "encamarotassem": "encamarotar",
    "encamarotasses": "encamarotar",
    "encamarotaste": "encamarotar",
    "encamarotastes": "encamarotar",
    "encamarotava": "encamarotar",
    "encamarotavam": "encamarotar",
    "encamarotavas": "encamarotar",
    "encamarote": "encamarotar",
    "encamarotei": "encamarotar",
    "encamaroteis": "encamarotar",
    "encamarotem": "encamarotar",
    "encamarotemo": "encamarotar",
    "encamarotemos": "encamarotar",
    "encamarotes": "encamarotar",
    "encamaroto": "encamarotar",
    "encamarotou": "encamarotar",
    "encamarotá": "encamarotar",
    "encamarotámo": "encamarotar",
    "encamarotámos": "encamarotar",
    "encamarotáramo": "encamarotar",
    "encamarotáramos": "encamarotar",
    "encamarotárei": "encamarotar",
    "encamarotáreis": "encamarotar",
    "encamarotásseis": "encamarotar",
    "encamarotássemos": "encamarotar",
    "encamarotávamo": "encamarotar",
    "encamarotávamos": "encamarotar",
    "encamarotávei": "encamarotar",
    "encamarotáveis": "encamarotar",
    "encamará": "encamar",
    "encamarás": "encamar",
    "encamarão": "encamar",
    "encamaríamos": "encamar",
    "encamaríeis": "encamar",
    "encamas": "encamar",
    "encamasse": "encamar",
    "encamassem": "encamar",
    "encamasses": "encamar",
    "encamaste": "encamar",
    "encamastes": "encamar",
    "encamava": "encamar",
    "encamavam": "encamar",
    "encamavas": "encamar",
    "encamba": "encambar",
    "encambada": "encambar",
    "encambadas": "encambar",
    "encambado": "encambar",
    "encambados": "encambar",
    "encambai": "encambar",
    "encambais": "encambar",
    "encambam": "encambar",
    "encambamo": "encambar",
    "encambamos": "encambar",
    "encambando": "encambar",
    "encambara": "encambar",
    "encambaram": "encambar",
    "encambaras": "encambar",
    "encambarde": "encambar",
    "encambardes": "encambar",
    "encambare": "encambar",
    "encambarei": "encambar",
    "encambareis": "encambar",
    "encambarem": "encambar",
    "encambaremos": "encambar",
    "encambares": "encambar",
    "encambaria": "encambar",
    "encambariam": "encambar",
    "encambarias": "encambar",
    "encambarmo": "encambar",
    "encambarmos": "encambar",
    "encambará": "encambar",
    "encambarás": "encambar",
    "encambarão": "encambar",
    "encambaríamos": "encambar",
    "encambaríeis": "encambar",
    "encambas": "encambar",
    "encambasse": "encambar",
    "encambassem": "encambar",
    "encambasses": "encambar",
    "encambaste": "encambar",
    "encambastes": "encambar",
    "encambava": "encambar",
    "encambavam": "encambar",
    "encambavas": "encambar",
    "encambe": "encambar",
    "encambei": "encambar",
    "encambeira": "encambeirar",
    "encambeirada": "encambeirar",
    "encambeiradas": "encambeirar",
    "encambeirado": "encambeirar",
    "encambeirados": "encambeirar",
    "encambeirai": "encambeirar",
    "encambeirais": "encambeirar",
    "encambeiram": "encambeirar",
    "encambeiramo": "encambeirar",
    "encambeiramos": "encambeirar",
    "encambeirando": "encambeirar",
    "encambeirara": "encambeirar",
    "encambeiraram": "encambeirar",
    "encambeiraras": "encambeirar",
    "encambeirarde": "encambeirar",
    "encambeirardes": "encambeirar",
    "encambeirare": "encambeirar",
    "encambeirarei": "encambeirar",
    "encambeirareis": "encambeirar",
    "encambeirarem": "encambeirar",
    "encambeiraremos": "encambeirar",
    "encambeirares": "encambeirar",
    "encambeiraria": "encambeirar",
    "encambeirariam": "encambeirar",
    "encambeirarias": "encambeirar",
    "encambeirarmo": "encambeirar",
    "encambeirarmos": "encambeirar",
    "encambeirará": "encambeirar",
    "encambeirarás": "encambeirar",
    "encambeirarão": "encambeirar",
    "encambeiraríamos": "encambeirar",
    "encambeiraríeis": "encambeirar",
    "encambeiras": "encambeirar",
    "encambeirasse": "encambeirar",
    "encambeirassem": "encambeirar",
    "encambeirasses": "encambeirar",
    "encambeiraste": "encambeirar",
    "encambeirastes": "encambeirar",
    "encambeirava": "encambeirar",
    "encambeiravam": "encambeirar",
    "encambeiravas": "encambeirar",
    "encambeire": "encambeirar",
    "encambeirei": "encambeirar",
    "encambeireis": "encambeirar",
    "encambeirem": "encambeirar",
    "encambeiremo": "encambeirar",
    "encambeiremos": "encambeirar",
    "encambeires": "encambeirar",
    "encambeiro": "encambeirar",
    "encambeirou": "encambeirar",
    "encambeirá": "encambeirar",
    "encambeirámo": "encambeirar",
    "encambeirámos": "encambeirar",
    "encambeiráramo": "encambeirar",
    "encambeiráramos": "encambeirar",
    "encambeirárei": "encambeirar",
    "encambeiráreis": "encambeirar",
    "encambeirásseis": "encambeirar",
    "encambeirássemos": "encambeirar",
    "encambeirávamo": "encambeirar",
    "encambeirávamos": "encambeirar",
    "encambeirávei": "encambeirar",
    "encambeiráveis": "encambeirar",
    "encambeis": "encambar",
    "encambem": "encambar",
    "encambemo": "encambar",
    "encambemos": "encambar",
    "encambes": "encambar",
    "encambo": "encambar",
    "encamboa": "encamboar",
    "encamboada": "encamboar",
    "encamboadas": "encamboar",
    "encamboado": "encamboar",
    "encamboados": "encamboar",
    "encamboai": "encamboar",
    "encamboais": "encamboar",
    "encamboam": "encamboar",
    "encamboamo": "encamboar",
    "encamboamos": "encamboar",
    "encamboando": "encamboar",
    "encamboara": "encamboar",
    "encamboaram": "encamboar",
    "encamboaras": "encamboar",
    "encamboarde": "encamboar",
    "encamboardes": "encamboar",
    "encamboare": "encamboar",
    "encamboarei": "encamboar",
    "encamboareis": "encamboar",
    "encamboarem": "encamboar",
    "encamboaremos": "encamboar",
    "encamboares": "encamboar",
    "encamboaria": "encamboar",
    "encamboariam": "encamboar",
    "encamboarias": "encamboar",
    "encamboarmo": "encamboar",
    "encamboarmos": "encamboar",
    "encamboará": "encamboar",
    "encamboarás": "encamboar",
    "encamboarão": "encamboar",
    "encamboaríamos": "encamboar",
    "encamboaríeis": "encamboar",
    "encamboas": "encamboar",
    "encamboasse": "encamboar",
    "encamboassem": "encamboar",
    "encamboasses": "encamboar",
    "encamboaste": "encamboar",
    "encamboastes": "encamboar",
    "encamboava": "encamboar",
    "encamboavam": "encamboar",
    "encamboavas": "encamboar",
    "encamboe": "encamboar",
    "encamboei": "encamboar",
    "encamboeis": "encamboar",
    "encamboem": "encamboar",
    "encamboemo": "encamboar",
    "encamboemos": "encamboar",
    "encamboes": "encamboar",
    "encamboo": "encamboar",
    "encamboou": "encamboar",
    "encambou": "encambar",
    "encamboá": "encamboar",
    "encamboámo": "encamboar",
    "encamboámos": "encamboar",
    "encamboáramo": "encamboar",
    "encamboáramos": "encamboar",
    "encamboárei": "encamboar",
    "encamboáreis": "encamboar",
    "encamboásseis": "encamboar",
    "encamboássemos": "encamboar",
    "encamboávamo": "encamboar",
    "encamboávamos": "encamboar",
    "encamboávei": "encamboar",
    "encamboáveis": "encamboar",
    "encambulha": "encambulhar",
    "encambulhada": "encambulhar",
    "encambulhadas": "encambulhar",
    "encambulhado": "encambulhar",
    "encambulhados": "encambulhar",
    "encambulhai": "encambulhar",
    "encambulhais": "encambulhar",
    "encambulham": "encambulhar",
    "encambulhamo": "encambulhar",
    "encambulhamos": "encambulhar",
    "encambulhando": "encambulhar",
    "encambulhara": "encambulhar",
    "encambulharam": "encambulhar",
    "encambulharas": "encambulhar",
    "encambulharde": "encambulhar",
    "encambulhardes": "encambulhar",
    "encambulhare": "encambulhar",
    "encambulharei": "encambulhar",
    "encambulhareis": "encambulhar",
    "encambulharem": "encambulhar",
    "encambulharemos": "encambulhar",
    "encambulhares": "encambulhar",
    "encambulharia": "encambulhar",
    "encambulhariam": "encambulhar",
    "encambulharias": "encambulhar",
    "encambulharmo": "encambulhar",
    "encambulharmos": "encambulhar",
    "encambulhará": "encambulhar",
    "encambulharás": "encambulhar",
    "encambulharão": "encambulhar",
    "encambulharíamos": "encambulhar",
    "encambulharíeis": "encambulhar",
    "encambulhas": "encambulhar",
    "encambulhasse": "encambulhar",
    "encambulhassem": "encambulhar",
    "encambulhasses": "encambulhar",
    "encambulhaste": "encambulhar",
    "encambulhastes": "encambulhar",
    "encambulhava": "encambulhar",
    "encambulhavam": "encambulhar",
    "encambulhavas": "encambulhar",
    "encambulhe": "encambulhar",
    "encambulhei": "encambulhar",
    "encambulheis": "encambulhar",
    "encambulhem": "encambulhar",
    "encambulhemo": "encambulhar",
    "encambulhemos": "encambulhar",
    "encambulhes": "encambulhar",
    "encambulho": "encambulhar",
    "encambulhou": "encambulhar",
    "encambulhá": "encambulhar",
    "encambulhámo": "encambulhar",
    "encambulhámos": "encambulhar",
    "encambulháramo": "encambulhar",
    "encambulháramos": "encambulhar",
    "encambulhárei": "encambulhar",
    "encambulháreis": "encambulhar",
    "encambulhásseis": "encambulhar",
    "encambulhássemos": "encambulhar",
    "encambulhávamo": "encambulhar",
    "encambulhávamos": "encambulhar",
    "encambulhávei": "encambulhar",
    "encambulháveis": "encambulhar",
    "encambá": "encambar",
    "encambámo": "encambar",
    "encambámos": "encambar",
    "encambáramo": "encambar",
    "encambáramos": "encambar",
    "encambárei": "encambar",
    "encambáreis": "encambar",
    "encambásseis": "encambar",
    "encambássemos": "encambar",
    "encambávamo": "encambar",
    "encambávamos": "encambar",
    "encambávei": "encambar",
    "encambáveis": "encambar",
    "encame": "encamar",
    "encamei": "encamar",
    "encameis": "encamar",
    "encamem": "encamar",
    "encamemo": "encamar",
    "encamemos": "encamar",
    "encames": "encame",
    "encaminha": "encaminhar",
    "encaminhada": "encaminhar",
    "encaminhadas": "encaminhar",
    "encaminhado": "encaminhar",
    "encaminhadora": "encaminhador",
    "encaminhadoras": "encaminhador",
    "encaminhadores": "encaminhador",
    "encaminhados": "encaminhar",
    "encaminhai": "encaminhar",
    "encaminhais": "encaminhar",
    "encaminham": "encaminhar",
    "encaminhamentos": "encaminhamento",
    "encaminhamo": "encaminhar",
    "encaminhamos": "encaminhar",
    "encaminhando": "encaminhar",
    "encaminhara": "encaminhar",
    "encaminharam": "encaminhar",
    "encaminharas": "encaminhar",
    "encaminharde": "encaminhar",
    "encaminhardes": "encaminhar",
    "encaminhare": "encaminhar",
    "encaminharei": "encaminhar",
    "encaminhareis": "encaminhar",
    "encaminharem": "encaminhar",
    "encaminharemos": "encaminhar",
    "encaminhares": "encaminhar",
    "encaminharia": "encaminhar",
    "encaminhariam": "encaminhar",
    "encaminharias": "encaminhar",
    "encaminharmo": "encaminhar",
    "encaminharmos": "encaminhar",
    "encaminhará": "encaminhar",
    "encaminharás": "encaminhar",
    "encaminharão": "encaminhar",
    "encaminharíamos": "encaminhar",
    "encaminharíeis": "encaminhar",
    "encaminhas": "encaminhar",
    "encaminhasse": "encaminhar",
    "encaminhassem": "encaminhar",
    "encaminhasses": "encaminhar",
    "encaminhaste": "encaminhar",
    "encaminhastes": "encaminhar",
    "encaminhava": "encaminhar",
    "encaminhavam": "encaminhar",
    "encaminhavas": "encaminhar",
    "encaminhe": "encaminhar",
    "encaminhei": "encaminhar",
    "encaminheis": "encaminhar",
    "encaminhem": "encaminhar",
    "encaminhemo": "encaminhar",
    "encaminhemos": "encaminhar",
    "encaminhes": "encaminhar",
    "encaminho": "encaminhar",
    "encaminhou": "encaminhar",
    "encaminhá": "encaminhar",
    "encaminhámo": "encaminhar",
    "encaminhámos": "encaminhar",
    "encaminháramo": "encaminhar",
    "encaminháramos": "encaminhar",
    "encaminhárei": "encaminhar",
    "encaminháreis": "encaminhar",
    "encaminhásseis": "encaminhar",
    "encaminhássemos": "encaminhar",
    "encaminhávamo": "encaminhar",
    "encaminhávamos": "encaminhar",
    "encaminhávei": "encaminhar",
    "encaminháveis": "encaminhar",
    "encamisa": "encamisar",
    "encamisada": "encamisar",
    "encamisadas": "encamisar",
    "encamisado": "encamisar",
    "encamisados": "encamisar",
    "encamisai": "encamisar",
    "encamisais": "encamisar",
    "encamisam": "encamisar",
    "encamisamo": "encamisar",
    "encamisamos": "encamisar",
    "encamisando": "encamisar",
    "encamisara": "encamisar",
    "encamisaram": "encamisar",
    "encamisaras": "encamisar",
    "encamisarde": "encamisar",
    "encamisardes": "encamisar",
    "encamisare": "encamisar",
    "encamisarei": "encamisar",
    "encamisareis": "encamisar",
    "encamisarem": "encamisar",
    "encamisaremos": "encamisar",
    "encamisares": "encamisar",
    "encamisaria": "encamisar",
    "encamisariam": "encamisar",
    "encamisarias": "encamisar",
    "encamisarmo": "encamisar",
    "encamisarmos": "encamisar",
    "encamisará": "encamisar",
    "encamisarás": "encamisar",
    "encamisarão": "encamisar",
    "encamisaríamos": "encamisar",
    "encamisaríeis": "encamisar",
    "encamisas": "encamisar",
    "encamisasse": "encamisar",
    "encamisassem": "encamisar",
    "encamisasses": "encamisar",
    "encamisaste": "encamisar",
    "encamisastes": "encamisar",
    "encamisava": "encamisar",
    "encamisavam": "encamisar",
    "encamisavas": "encamisar",
    "encamise": "encamisar",
    "encamisei": "encamisar",
    "encamiseis": "encamisar",
    "encamisem": "encamisar",
    "encamisemo": "encamisar",
    "encamisemos": "encamisar",
    "encamises": "encamisar",
    "encamiso": "encamisar",
    "encamisou": "encamisar",
    "encamisá": "encamisar",
    "encamisámo": "encamisar",
    "encamisámos": "encamisar",
    "encamisáramo": "encamisar",
    "encamisáramos": "encamisar",
    "encamisárei": "encamisar",
    "encamisáreis": "encamisar",
    "encamisásseis": "encamisar",
    "encamisássemos": "encamisar",
    "encamisávamo": "encamisar",
    "encamisávamos": "encamisar",
    "encamisávei": "encamisar",
    "encamisáveis": "encamisar",
    "encamo": "encamar",
    "encamou": "encamar",
    "encampa": "encampar",
    "encampada": "encampar",
    "encampadas": "encampar",
    "encampado": "encampar",
    "encampadora": "encampador",
    "encampadoras": "encampador",
    "encampadores": "encampador",
    "encampados": "encampar",
    "encampai": "encampar",
    "encampais": "encampar",
    "encampam": "encampar",
    "encampamentos": "encampamento",
    "encampamo": "encampar",
    "encampamos": "encampar",
    "encampana": "encampanar",
    "encampanada": "encampanar",
    "encampanadas": "encampanar",
    "encampanado": "encampanar",
    "encampanados": "encampanar",
    "encampanai": "encampanar",
    "encampanais": "encampanar",
    "encampanam": "encampanar",
    "encampanamo": "encampanar",
    "encampanamos": "encampanar",
    "encampanando": "encampanar",
    "encampanara": "encampanar",
    "encampanaram": "encampanar",
    "encampanaras": "encampanar",
    "encampanardes": "encampanar",
    "encampanarei": "encampanar",
    "encampanareis": "encampanar",
    "encampanarem": "encampanar",
    "encampanaremos": "encampanar",
    "encampanares": "encampanar",
    "encampanaria": "encampanar",
    "encampanariam": "encampanar",
    "encampanarias": "encampanar",
    "encampanarmo": "encampanar",
    "encampanarmos": "encampanar",
    "encampanará": "encampanar",
    "encampanarás": "encampanar",
    "encampanarão": "encampanar",
    "encampanaríamos": "encampanar",
    "encampanaríeis": "encampanar",
    "encampanas": "encampanar",
    "encampanasse": "encampanar",
    "encampanassem": "encampanar",
    "encampanasses": "encampanar",
    "encampanaste": "encampanar",
    "encampanastes": "encampanar",
    "encampanava": "encampanar",
    "encampanavam": "encampanar",
    "encampanavas": "encampanar",
    "encampando": "encampar",
    "encampane": "encampanar",
    "encampanei": "encampanar",
    "encampaneis": "encampanar",
    "encampanem": "encampanar",
    "encampanemo": "encampanar",
    "encampanemos": "encampanar",
    "encampanes": "encampanar",
    "encampano": "encampanar",
    "encampanou": "encampanar",
    "encampanámo": "encampanar",
    "encampanámos": "encampanar",
    "encampanáramo": "encampanar",
    "encampanáramos": "encampanar",
    "encampanáreis": "encampanar",
    "encampanásseis": "encampanar",
    "encampanássemos": "encampanar",
    "encampanávamo": "encampanar",
    "encampanávamos": "encampanar",
    "encampanáveis": "encampanar",
    "encampara": "encampar",
    "encamparam": "encampar",
    "encamparas": "encampar",
    "encamparde": "encampar",
    "encampardes": "encampar",
    "encampare": "encampar",
    "encamparei": "encampar",
    "encampareis": "encampar",
    "encamparem": "encampar",
    "encamparemos": "encampar",
    "encampares": "encampar",
    "encamparia": "encampar",
    "encampariam": "encampar",
    "encamparias": "encampar",
    "encamparmo": "encampar",
    "encamparmos": "encampar",
    "encampará": "encampar",
    "encamparás": "encampar",
    "encamparão": "encampar",
    "encamparíamos": "encampar",
    "encamparíeis": "encampar",
    "encampas": "encampar",
    "encampasse": "encampar",
    "encampassem": "encampar",
    "encampasses": "encampar",
    "encampaste": "encampar",
    "encampastes": "encampar",
    "encampava": "encampar",
    "encampavam": "encampar",
    "encampavas": "encampar",
    "encampações": "encampação",
    "encampe": "encampar",
    "encampei": "encampar",
    "encampeis": "encampar",
    "encampem": "encampar",
    "encampemo": "encampar",
    "encampemos": "encampar",
    "encampes": "encampar",
    "encampo": "encampar",
    "encampou": "encampar",
    "encampá": "encampar",
    "encampámo": "encampar",
    "encampámos": "encampar",
    "encampáramo": "encampar",
    "encampáramos": "encampar",
    "encampárei": "encampar",
    "encampáreis": "encampar",
    "encampásseis": "encampar",
    "encampássemos": "encampar",
    "encampávamo": "encampar",
    "encampávamos": "encampar",
    "encampávei": "encampar",
    "encampáveis": "encampar",
    "encamurce": "encamurçar",
    "encamurcei": "encamurçar",
    "encamurceis": "encamurçar",
    "encamurcem": "encamurçar",
    "encamurcemo": "encamurçar",
    "encamurcemos": "encamurçar",
    "encamurces": "encamurçar",
    "encamurça": "encamurçar",
    "encamurçada": "encamurçar",
    "encamurçadas": "encamurçar",
    "encamurçado": "encamurçar",
    "encamurçados": "encamurçar",
    "encamurçai": "encamurçar",
    "encamurçais": "encamurçar",
    "encamurçam": "encamurçar",
    "encamurçamo": "encamurçar",
    "encamurçamos": "encamurçar",
    "encamurçando": "encamurçar",
    "encamurçara": "encamurçar",
    "encamurçaram": "encamurçar",
    "encamurçaras": "encamurçar",
    "encamurçarde": "encamurçar",
    "encamurçardes": "encamurçar",
    "encamurçare": "encamurçar",
    "encamurçarei": "encamurçar",
    "encamurçareis": "encamurçar",
    "encamurçarem": "encamurçar",
    "encamurçaremos": "encamurçar",
    "encamurçares": "encamurçar",
    "encamurçaria": "encamurçar",
    "encamurçariam": "encamurçar",
    "encamurçarias": "encamurçar",
    "encamurçarmo": "encamurçar",
    "encamurçarmos": "encamurçar",
    "encamurçará": "encamurçar",
    "encamurçarás": "encamurçar",
    "encamurçarão": "encamurçar",
    "encamurçaríamos": "encamurçar",
    "encamurçaríeis": "encamurçar",
    "encamurças": "encamurçar",
    "encamurçasse": "encamurçar",
    "encamurçassem": "encamurçar",
    "encamurçasses": "encamurçar",
    "encamurçaste": "encamurçar",
    "encamurçastes": "encamurçar",
    "encamurçava": "encamurçar",
    "encamurçavam": "encamurçar",
    "encamurçavas": "encamurçar",
    "encamurço": "encamurçar",
    "encamurçou": "encamurçar",
    "encamurçá": "encamurçar",
    "encamurçámo": "encamurçar",
    "encamurçámos": "encamurçar",
    "encamurçáramo": "encamurçar",
    "encamurçáramos": "encamurçar",
    "encamurçárei": "encamurçar",
    "encamurçáreis": "encamurçar",
    "encamurçásseis": "encamurçar",
    "encamurçássemos": "encamurçar",
    "encamurçávamo": "encamurçar",
    "encamurçávamos": "encamurçar",
    "encamurçávei": "encamurçar",
    "encamurçáveis": "encamurçar",
    "encamá": "encamar",
    "encamámo": "encamar",
    "encamámos": "encamar",
    "encamáramo": "encamar",
    "encamáramos": "encamar",
    "encamárei": "encamar",
    "encamáreis": "encamar",
    "encamásseis": "encamar",
    "encamássemos": "encamar",
    "encamávamo": "encamar",
    "encamávamos": "encamar",
    "encamávei": "encamar",
    "encamáveis": "encamar",
    "encana": "encanar",
    "encanada": "encanar",
    "encanadas": "encanar",
    "encanado": "encanar",
    "encanadora": "encanador",
    "encanadoras": "encanador",
    "encanadores": "encanador",
    "encanados": "encanar",
    "encanai": "encanar",
    "encanais": "encanar",
    "encanam": "encanar",
    "encanamentos": "encanamento",
    "encanamo": "encanar",
    "encanamos": "encanar",
    "encanando": "encanar",
    "encanara": "encanar",
    "encanaram": "encanar",
    "encanaras": "encanar",
    "encanarde": "encanar",
    "encanardes": "encanar",
    "encanare": "encanar",
    "encanarei": "encanar",
    "encanareis": "encanar",
    "encanarem": "encanar",
    "encanaremos": "encanar",
    "encanares": "encanar",
    "encanaria": "encanar",
    "encanariam": "encanar",
    "encanarias": "encanar",
    "encanarmo": "encanar",
    "encanarmos": "encanar",
    "encanará": "encanar",
    "encanarás": "encanar",
    "encanarão": "encanar",
    "encanaríamos": "encanar",
    "encanaríeis": "encanar",
    "encanas": "encanar",
    "encanasse": "encanar",
    "encanassem": "encanar",
    "encanasses": "encanar",
    "encanaste": "encanar",
    "encanastes": "encanar",
    "encanastra": "encanastrar",
    "encanastrada": "encanastrar",
    "encanastradas": "encanastrar",
    "encanastrado": "encanastrar",
    "encanastrados": "encanastrar",
    "encanastrai": "encanastrar",
    "encanastrais": "encanastrar",
    "encanastram": "encanastrar",
    "encanastramo": "encanastrar",
    "encanastramos": "encanastrar",
    "encanastrando": "encanastrar",
    "encanastrara": "encanastrar",
    "encanastraram": "encanastrar",
    "encanastraras": "encanastrar",
    "encanastrarde": "encanastrar",
    "encanastrardes": "encanastrar",
    "encanastrare": "encanastrar",
    "encanastrarei": "encanastrar",
    "encanastrareis": "encanastrar",
    "encanastrarem": "encanastrar",
    "encanastraremos": "encanastrar",
    "encanastrares": "encanastrar",
    "encanastraria": "encanastrar",
    "encanastrariam": "encanastrar",
    "encanastrarias": "encanastrar",
    "encanastrarmo": "encanastrar",
    "encanastrarmos": "encanastrar",
    "encanastrará": "encanastrar",
    "encanastrarás": "encanastrar",
    "encanastrarão": "encanastrar",
    "encanastraríamos": "encanastrar",
    "encanastraríeis": "encanastrar",
    "encanastras": "encanastrar",
    "encanastrasse": "encanastrar",
    "encanastrassem": "encanastrar",
    "encanastrasses": "encanastrar",
    "encanastraste": "encanastrar",
    "encanastrastes": "encanastrar",
    "encanastrava": "encanastrar",
    "encanastravam": "encanastrar",
    "encanastravas": "encanastrar",
    "encanastre": "encanastrar",
    "encanastrei": "encanastrar",
    "encanastreis": "encanastrar",
    "encanastrem": "encanastrar",
    "encanastremo": "encanastrar",
    "encanastremos": "encanastrar",
    "encanastres": "encanastrar",
    "encanastro": "encanastrar",
    "encanastrou": "encanastrar",
    "encanastrá": "encanastrar",
    "encanastrámo": "encanastrar",
    "encanastrámos": "encanastrar",
    "encanastráramo": "encanastrar",
    "encanastráramos": "encanastrar",
    "encanastrárei": "encanastrar",
    "encanastráreis": "encanastrar",
    "encanastrásseis": "encanastrar",
    "encanastrássemos": "encanastrar",
    "encanastrávamo": "encanastrar",
    "encanastrávamos": "encanastrar",
    "encanastrávei": "encanastrar",
    "encanastráveis": "encanastrar",
    "encanava": "encanar",
    "encanavam": "encanar",
    "encanavas": "encanar",
    "encanações": "encanação",
    "encandeada": "encandear",
    "encandeadas": "encandear",
    "encandeado": "encandear",
    "encandeados": "encandear",
    "encandeai": "encandear",
    "encandeais": "encandear",
    "encandeamo": "encandear",
    "encandeamos": "encandear",
    "encandeando": "encandear",
    "encandeara": "encandear",
    "encandearam": "encandear",
    "encandearas": "encandear",
    "encandearde": "encandear",
    "encandeardes": "encandear",
    "encandeare": "encandear",
    "encandearei": "encandear",
    "encandeareis": "encandear",
    "encandearem": "encandear",
    "encandearemos": "encandear",
    "encandeares": "encandear",
    "encandearia": "encandear",
    "encandeariam": "encandear",
    "encandearias": "encandear",
    "encandearmo": "encandear",
    "encandearmos": "encandear",
    "encandeará": "encandear",
    "encandearás": "encandear",
    "encandearão": "encandear",
    "encandearíamos": "encandear",
    "encandearíeis": "encandear",
    "encandeasse": "encandear",
    "encandeassem": "encandear",
    "encandeasses": "encandear",
    "encandeaste": "encandear",
    "encandeastes": "encandear",
    "encandeava": "encandear",
    "encandeavam": "encandear",
    "encandeavas": "encandear",
    "encandece": "encandecer",
    "encandecei": "encandecer",
    "encandeceis": "encandecer",
    "encandecem": "encandecer",
    "encandecemo": "encandecer",
    "encandecemos": "encandecer",
    "encandecendo": "encandecer",
    "encandecera": "encandecer",
    "encandeceram": "encandecer",
    "encandeceras": "encandecer",
    "encandecerde": "encandecer",
    "encandecerdes": "encandecer",
    "encandecere": "encandecer",
    "encandecerei": "encandecer",
    "encandecereis": "encandecer",
    "encandecerem": "encandecer",
    "encandeceremos": "encandecer",
    "encandeceres": "encandecer",
    "encandeceria": "encandecer",
    "encandeceriam": "encandecer",
    "encandecerias": "encandecer",
    "encandecermo": "encandecer",
    "encandecermos": "encandecer",
    "encandecerá": "encandecer",
    "encandecerás": "encandecer",
    "encandecerão": "encandecer",
    "encandeceríamos": "encandecer",
    "encandeceríeis": "encandecer",
    "encandeces": "encandecer",
    "encandecesse": "encandecer",
    "encandecessem": "encandecer",
    "encandecesses": "encandecer",
    "encandeceste": "encandecer",
    "encandecestes": "encandecer",
    "encandeceu": "encandecer",
    "encandeci": "encandecer",
    "encandecia": "encandecer",
    "encandeciam": "encandecer",
    "encandecias": "encandecer",
    "encandecida": "encandecer",
    "encandecidas": "encandecer",
    "encandecido": "encandecer",
    "encandecidos": "encandecer",
    "encandecê": "encandecer",
    "encandecêramo": "encandecer",
    "encandecêramos": "encandecer",
    "encandecêrei": "encandecer",
    "encandecêreis": "encandecer",
    "encandecêsseis": "encandecer",
    "encandecêssemos": "encandecer",
    "encandecíamo": "encandecer",
    "encandecíamos": "encandecer",
    "encandecíei": "encandecer",
    "encandecíeis": "encandecer",
    "encandeei": "encandear",
    "encandeeis": "encandear",
    "encandeemo": "encandear",
    "encandeemos": "encandear",
    "encandeia": "encandear",
    "encandeiam": "encandear",
    "encandeias": "encandear",
    "encandeie": "encandear",
    "encandeiem": "encandear",
    "encandeies": "encandear",
    "encandeio": "encandear",
    "encandeou": "encandear",
    "encandeá": "encandear",
    "encandeámo": "encandear",
    "encandeámos": "encandear",
    "encandeáramo": "encandear",
    "encandeáramos": "encandear",
    "encandeárei": "encandear",
    "encandeáreis": "encandear",
    "encandeásseis": "encandear",
    "encandeássemos": "encandear",
    "encandeávamo": "encandear",
    "encandeávamos": "encandear",
    "encandeávei": "encandear",
    "encandeáveis": "encandear",
    "encandeça": "encandecer",
    "encandeçais": "encandecer",
    "encandeçam": "encandecer",
    "encandeçamo": "encandecer",
    "encandeçamos": "encandecer",
    "encandeças": "encandecer",
    "encandeço": "encandecer",
    "encandila": "encandilar",
    "encandilada": "encandilar",
    "encandiladas": "encandilar",
    "encandilado": "encandilar",
    "encandilados": "encandilar",
    "encandilai": "encandilar",
    "encandilais": "encandilar",
    "encandilam": "encandilar",
    "encandilamo": "encandilar",
    "encandilamos": "encandilar",
    "encandilando": "encandilar",
    "encandilara": "encandilar",
    "encandilaram": "encandilar",
    "encandilaras": "encandilar",
    "encandilarde": "encandilar",
    "encandilardes": "encandilar",
    "encandilare": "encandilar",
    "encandilarei": "encandilar",
    "encandilareis": "encandilar",
    "encandilarem": "encandilar",
    "encandilaremos": "encandilar",
    "encandilares": "encandilar",
    "encandilaria": "encandilar",
    "encandilariam": "encandilar",
    "encandilarias": "encandilar",
    "encandilarmo": "encandilar",
    "encandilarmos": "encandilar",
    "encandilará": "encandilar",
    "encandilarás": "encandilar",
    "encandilarão": "encandilar",
    "encandilaríamos": "encandilar",
    "encandilaríeis": "encandilar",
    "encandilas": "encandilar",
    "encandilasse": "encandilar",
    "encandilassem": "encandilar",
    "encandilasses": "encandilar",
    "encandilaste": "encandilar",
    "encandilastes": "encandilar",
    "encandilava": "encandilar",
    "encandilavam": "encandilar",
    "encandilavas": "encandilar",
    "encandile": "encandilar",
    "encandilei": "encandilar",
    "encandileis": "encandilar",
    "encandilem": "encandilar",
    "encandilemo": "encandilar",
    "encandilemos": "encandilar",
    "encandiles": "encandilar",
    "encandilo": "encandilar",
    "encandilou": "encandilar",
    "encandilá": "encandilar",
    "encandilámo": "encandilar",
    "encandilámos": "encandilar",
    "encandiláramo": "encandilar",
    "encandiláramos": "encandilar",
    "encandilárei": "encandilar",
    "encandiláreis": "encandilar",
    "encandilásseis": "encandilar",
    "encandilássemos": "encandilar",
    "encandilávamo": "encandilar",
    "encandilávamos": "encandilar",
    "encandilávei": "encandilar",
    "encandiláveis": "encandilar",
    "encane": "encanar",
    "encanece": "encanecer",
    "encanecei": "encanecer",
    "encaneceis": "encanecer",
    "encanecem": "encanecer",
    "encanecemo": "encanecer",
    "encanecemos": "encanecer",
    "encanecendo": "encanecer",
    "encanecera": "encanecer",
    "encaneceram": "encanecer",
    "encaneceras": "encanecer",
    "encanecerde": "encanecer",
    "encanecerdes": "encanecer",
    "encanecere": "encanecer",
    "encanecerei": "encanecer",
    "encanecereis": "encanecer",
    "encanecerem": "encanecer",
    "encaneceremos": "encanecer",
    "encaneceres": "encanecer",
    "encaneceria": "encanecer",
    "encaneceriam": "encanecer",
    "encanecerias": "encanecer",
    "encanecermo": "encanecer",
    "encanecermos": "encanecer",
    "encanecerá": "encanecer",
    "encanecerás": "encanecer",
    "encanecerão": "encanecer",
    "encaneceríamos": "encanecer",
    "encaneceríeis": "encanecer",
    "encaneces": "encanecer",
    "encanecesse": "encanecer",
    "encanecessem": "encanecer",
    "encanecesses": "encanecer",
    "encaneceste": "encanecer",
    "encanecestes": "encanecer",
    "encaneceu": "encanecer",
    "encaneci": "encanecer",
    "encanecia": "encanecer",
    "encaneciam": "encanecer",
    "encanecias": "encanecer",
    "encanecida": "encanecido",
    "encanecidas": "encanecido",
    "encanecido": "encanecer",
    "encanecidos": "encanecido",
    "encanecê": "encanecer",
    "encanecêramo": "encanecer",
    "encanecêramos": "encanecer",
    "encanecêrei": "encanecer",
    "encanecêreis": "encanecer",
    "encanecêsseis": "encanecer",
    "encanecêssemos": "encanecer",
    "encanecíamo": "encanecer",
    "encanecíamos": "encanecer",
    "encanecíei": "encanecer",
    "encanecíeis": "encanecer",
    "encanei": "encanar",
    "encaneis": "encanar",
    "encanela": "encanelar",
    "encanelada": "encanelar",
    "encaneladas": "encanelar",
    "encanelado": "encanelar",
    "encanelados": "encanelar",
    "encanelai": "encanelar",
    "encanelais": "encanelar",
    "encanelam": "encanelar",
    "encanelamo": "encanelar",
    "encanelamos": "encanelar",
    "encanelando": "encanelar",
    "encanelara": "encanelar",
    "encanelaram": "encanelar",
    "encanelaras": "encanelar",
    "encanelarde": "encanelar",
    "encanelardes": "encanelar",
    "encanelare": "encanelar",
    "encanelarei": "encanelar",
    "encanelareis": "encanelar",
    "encanelarem": "encanelar",
    "encanelaremos": "encanelar",
    "encanelares": "encanelar",
    "encanelaria": "encanelar",
    "encanelariam": "encanelar",
    "encanelarias": "encanelar",
    "encanelarmo": "encanelar",
    "encanelarmos": "encanelar",
    "encanelará": "encanelar",
    "encanelarás": "encanelar",
    "encanelarão": "encanelar",
    "encanelaríamos": "encanelar",
    "encanelaríeis": "encanelar",
    "encanelas": "encanelar",
    "encanelasse": "encanelar",
    "encanelassem": "encanelar",
    "encanelasses": "encanelar",
    "encanelaste": "encanelar",
    "encanelastes": "encanelar",
    "encanelava": "encanelar",
    "encanelavam": "encanelar",
    "encanelavas": "encanelar",
    "encanele": "encanelar",
    "encanelei": "encanelar",
    "encaneleis": "encanelar",
    "encanelem": "encanelar",
    "encanelemo": "encanelar",
    "encanelemos": "encanelar",
    "encaneles": "encanelar",
    "encanelo": "encanelar",
    "encanelou": "encanelar",
    "encanelá": "encanelar",
    "encanelámo": "encanelar",
    "encanelámos": "encanelar",
    "encaneláramo": "encanelar",
    "encaneláramos": "encanelar",
    "encanelárei": "encanelar",
    "encaneláreis": "encanelar",
    "encanelásseis": "encanelar",
    "encanelássemos": "encanelar",
    "encanelávamo": "encanelar",
    "encanelávamos": "encanelar",
    "encanelávei": "encanelar",
    "encaneláveis": "encanelar",
    "encanem": "encanar",
    "encanemo": "encanar",
    "encanemos": "encanar",
    "encanes": "encanar",
    "encaneça": "encanecer",
    "encaneçais": "encanecer",
    "encaneçam": "encanecer",
    "encaneçamo": "encanecer",
    "encaneçamos": "encanecer",
    "encaneças": "encanecer",
    "encaneço": "encanecer",
    "encanga": "encangar",
    "encangada": "encangar",
    "encangadas": "encangar",
    "encangado": "encangar",
    "encangados": "encangar",
    "encangai": "encangar",
    "encangais": "encangar",
    "encangalha": "encangalhar",
    "encangalhada": "encangalhar",
    "encangalhadas": "encangalhar",
    "encangalhado": "encangalhar",
    "encangalhados": "encangalhar",
    "encangalhai": "encangalhar",
    "encangalhais": "encangalhar",
    "encangalham": "encangalhar",
    "encangalhamo": "encangalhar",
    "encangalhamos": "encangalhar",
    "encangalhando": "encangalhar",
    "encangalhara": "encangalhar",
    "encangalharam": "encangalhar",
    "encangalharas": "encangalhar",
    "encangalharde": "encangalhar",
    "encangalhardes": "encangalhar",
    "encangalhare": "encangalhar",
    "encangalharei": "encangalhar",
    "encangalhareis": "encangalhar",
    "encangalharem": "encangalhar",
    "encangalharemos": "encangalhar",
    "encangalhares": "encangalhar",
    "encangalharia": "encangalhar",
    "encangalhariam": "encangalhar",
    "encangalharias": "encangalhar",
    "encangalharmo": "encangalhar",
    "encangalharmos": "encangalhar",
    "encangalhará": "encangalhar",
    "encangalharás": "encangalhar",
    "encangalharão": "encangalhar",
    "encangalharíamos": "encangalhar",
    "encangalharíeis": "encangalhar",
    "encangalhas": "encangalhar",
    "encangalhasse": "encangalhar",
    "encangalhassem": "encangalhar",
    "encangalhasses": "encangalhar",
    "encangalhaste": "encangalhar",
    "encangalhastes": "encangalhar",
    "encangalhava": "encangalhar",
    "encangalhavam": "encangalhar",
    "encangalhavas": "encangalhar",
    "encangalhe": "encangalhar",
    "encangalhei": "encangalhar",
    "encangalheis": "encangalhar",
    "encangalhem": "encangalhar",
    "encangalhemo": "encangalhar",
    "encangalhemos": "encangalhar",
    "encangalhes": "encangalhar",
    "encangalho": "encangalhar",
    "encangalhou": "encangalhar",
    "encangalhá": "encangalhar",
    "encangalhámo": "encangalhar",
    "encangalhámos": "encangalhar",
    "encangalháramo": "encangalhar",
    "encangalháramos": "encangalhar",
    "encangalhárei": "encangalhar",
    "encangalháreis": "encangalhar",
    "encangalhásseis": "encangalhar",
    "encangalhássemos": "encangalhar",
    "encangalhávamo": "encangalhar",
    "encangalhávamos": "encangalhar",
    "encangalhávei": "encangalhar",
    "encangalháveis": "encangalhar",
    "encangam": "encangar",
    "encangamo": "encangar",
    "encangamos": "encangar",
    "encangando": "encangar",
    "encangara": "encangar",
    "encangaram": "encangar",
    "encangaras": "encangar",
    "encangarde": "encangar",
    "encangardes": "encangar",
    "encangare": "encangar",
    "encangarei": "encangar",
    "encangareis": "encangar",
    "encangarem": "encangar",
    "encangaremos": "encangar",
    "encangares": "encangar",
    "encangaria": "encangar",
    "encangariam": "encangar",
    "encangarias": "encangar",
    "encangarmo": "encangar",
    "encangarmos": "encangar",
    "encangará": "encangar",
    "encangarás": "encangar",
    "encangarão": "encangar",
    "encangaríamos": "encangar",
    "encangaríeis": "encangar",
    "encangas": "encangar",
    "encangasse": "encangar",
    "encangassem": "encangar",
    "encangasses": "encangar",
    "encangaste": "encangar",
    "encangastes": "encangar",
    "encangava": "encangar",
    "encangavam": "encangar",
    "encangavas": "encangar",
    "encango": "encangar",
    "encangota": "encangotar",
    "encangotada": "encangotar",
    "encangotadas": "encangotar",
    "encangotado": "encangotar",
    "encangotados": "encangotar",
    "encangotai": "encangotar",
    "encangotais": "encangotar",
    "encangotam": "encangotar",
    "encangotamo": "encangotar",
    "encangotamos": "encangotar",
    "encangotando": "encangotar",
    "encangotara": "encangotar",
    "encangotaram": "encangotar",
    "encangotaras": "encangotar",
    "encangotarde": "encangotar",
    "encangotardes": "encangotar",
    "encangotare": "encangotar",
    "encangotarei": "encangotar",
    "encangotareis": "encangotar",
    "encangotarem": "encangotar",
    "encangotaremos": "encangotar",
    "encangotares": "encangotar",
    "encangotaria": "encangotar",
    "encangotariam": "encangotar",
    "encangotarias": "encangotar",
    "encangotarmo": "encangotar",
    "encangotarmos": "encangotar",
    "encangotará": "encangotar",
    "encangotarás": "encangotar",
    "encangotarão": "encangotar",
    "encangotaríamos": "encangotar",
    "encangotaríeis": "encangotar",
    "encangotas": "encangotar",
    "encangotasse": "encangotar",
    "encangotassem": "encangotar",
    "encangotasses": "encangotar",
    "encangotaste": "encangotar",
    "encangotastes": "encangotar",
    "encangotava": "encangotar",
    "encangotavam": "encangotar",
    "encangotavas": "encangotar",
    "encangote": "encangotar",
    "encangotei": "encangotar",
    "encangoteis": "encangotar",
    "encangotem": "encangotar",
    "encangotemo": "encangotar",
    "encangotemos": "encangotar",
    "encangotes": "encangotar",
    "encangoto": "encangotar",
    "encangotou": "encangotar",
    "encangotá": "encangotar",
    "encangotámo": "encangotar",
    "encangotámos": "encangotar",
    "encangotáramo": "encangotar",
    "encangotáramos": "encangotar",
    "encangotárei": "encangotar",
    "encangotáreis": "encangotar",
    "encangotásseis": "encangotar",
    "encangotássemos": "encangotar",
    "encangotávamo": "encangotar",
    "encangotávamos": "encangotar",
    "encangotávei": "encangotar",
    "encangotáveis": "encangotar",
    "encangou": "encangar",
    "encangue": "encangar",
    "encanguei": "encangar",
    "encangueis": "encangar",
    "encanguem": "encangar",
    "encanguemo": "encangar",
    "encanguemos": "encangar",
    "encangues": "encangar",
    "encangá": "encangar",
    "encangámo": "encangar",
    "encangámos": "encangar",
    "encangáramo": "encangar",
    "encangáramos": "encangar",
    "encangárei": "encangar",
    "encangáreis": "encangar",
    "encangásseis": "encangar",
    "encangássemos": "encangar",
    "encangávamo": "encangar",
    "encangávamos": "encangar",
    "encangávei": "encangar",
    "encangáveis": "encangar",
    "encanice": "encaniçar",
    "encanicei": "encaniçar",
    "encaniceis": "encaniçar",
    "encanicem": "encaniçar",
    "encanicemo": "encaniçar",
    "encanicemos": "encaniçar",
    "encanices": "encaniçar",
    "encaniça": "encaniçar",
    "encaniçada": "encaniçar",
    "encaniçadas": "encaniçar",
    "encaniçado": "encaniçar",
    "encaniçados": "encaniçar",
    "encaniçai": "encaniçar",
    "encaniçais": "encaniçar",
    "encaniçam": "encaniçar",
    "encaniçamo": "encaniçar",
    "encaniçamos": "encaniçar",
    "encaniçando": "encaniçar",
    "encaniçara": "encaniçar",
    "encaniçaram": "encaniçar",
    "encaniçaras": "encaniçar",
    "encaniçarde": "encaniçar",
    "encaniçardes": "encaniçar",
    "encaniçare": "encaniçar",
    "encaniçarei": "encaniçar",
    "encaniçareis": "encaniçar",
    "encaniçarem": "encaniçar",
    "encaniçaremos": "encaniçar",
    "encaniçares": "encaniçar",
    "encaniçaria": "encaniçar",
    "encaniçariam": "encaniçar",
    "encaniçarias": "encaniçar",
    "encaniçarmo": "encaniçar",
    "encaniçarmos": "encaniçar",
    "encaniçará": "encaniçar",
    "encaniçarás": "encaniçar",
    "encaniçarão": "encaniçar",
    "encaniçaríamos": "encaniçar",
    "encaniçaríeis": "encaniçar",
    "encaniças": "encaniçar",
    "encaniçasse": "encaniçar",
    "encaniçassem": "encaniçar",
    "encaniçasses": "encaniçar",
    "encaniçaste": "encaniçar",
    "encaniçastes": "encaniçar",
    "encaniçava": "encaniçar",
    "encaniçavam": "encaniçar",
    "encaniçavas": "encaniçar",
    "encaniço": "encaniçar",
    "encaniçou": "encaniçar",
    "encaniçá": "encaniçar",
    "encaniçámo": "encaniçar",
    "encaniçámos": "encaniçar",
    "encaniçáramo": "encaniçar",
    "encaniçáramos": "encaniçar",
    "encaniçárei": "encaniçar",
    "encaniçáreis": "encaniçar",
    "encaniçásseis": "encaniçar",
    "encaniçássemos": "encaniçar",
    "encaniçávamo": "encaniçar",
    "encaniçávamos": "encaniçar",
    "encaniçávei": "encaniçar",
    "encaniçáveis": "encaniçar",
    "encano": "encanar",
    "encanou": "encanar",
    "encanta": "encantar",
    "encantada": "encantar",
    "encantadas": "encantar",
    "encantado": "encantar",
    "encantadora": "encantador",
    "encantadoras": "encantador",
    "encantadores": "encantador",
    "encantados": "encantar",
    "encantadíssima": "encantado",
    "encantadíssimas": "encantado",
    "encantadíssimo": "encantado",
    "encantadíssimos": "encantado",
    "encantai": "encantar",
    "encantais": "encantar",
    "encantam": "encantar",
    "encantamentos": "encantamento",
    "encantamo": "encantar",
    "encantamos": "encantar",
    "encantando": "encantar",
    "encantara": "encantar",
    "encantaram": "encantar",
    "encantaras": "encantar",
    "encantarde": "encantar",
    "encantardes": "encantar",
    "encantare": "encantar",
    "encantarei": "encantar",
    "encantareis": "encantar",
    "encantarem": "encantar",
    "encantaremos": "encantar",
    "encantares": "encantar",
    "encantaria": "encantar",
    "encantariam": "encantar",
    "encantarias": "encantar",
    "encantarmo": "encantar",
    "encantarmos": "encantar",
    "encantará": "encantar",
    "encantarás": "encantar",
    "encantarão": "encantar",
    "encantaríamos": "encantar",
    "encantaríeis": "encantar",
    "encantas": "encantar",
    "encantasse": "encantar",
    "encantassem": "encantar",
    "encantasses": "encantar",
    "encantaste": "encantar",
    "encantastes": "encantar",
    "encantatória": "encantatório",
    "encantatórias": "encantatório",
    "encantatórios": "encantatório",
    "encantava": "encantar",
    "encantavam": "encantar",
    "encantavas": "encantar",
    "encantações": "encantação",
    "encante": "encantar",
    "encantei": "encantar",
    "encanteira": "encanteirar",
    "encanteirada": "encanteirar",
    "encanteiradas": "encanteirar",
    "encanteirado": "encanteirar",
    "encanteirados": "encanteirar",
    "encanteirai": "encanteirar",
    "encanteirais": "encanteirar",
    "encanteiram": "encanteirar",
    "encanteiramo": "encanteirar",
    "encanteiramos": "encanteirar",
    "encanteirando": "encanteirar",
    "encanteirara": "encanteirar",
    "encanteiraram": "encanteirar",
    "encanteiraras": "encanteirar",
    "encanteirarde": "encanteirar",
    "encanteirardes": "encanteirar",
    "encanteirare": "encanteirar",
    "encanteirarei": "encanteirar",
    "encanteirareis": "encanteirar",
    "encanteirarem": "encanteirar",
    "encanteiraremos": "encanteirar",
    "encanteirares": "encanteirar",
    "encanteiraria": "encanteirar",
    "encanteirariam": "encanteirar",
    "encanteirarias": "encanteirar",
    "encanteirarmo": "encanteirar",
    "encanteirarmos": "encanteirar",
    "encanteirará": "encanteirar",
    "encanteirarás": "encanteirar",
    "encanteirarão": "encanteirar",
    "encanteiraríamos": "encanteirar",
    "encanteiraríeis": "encanteirar",
    "encanteiras": "encanteirar",
    "encanteirasse": "encanteirar",
    "encanteirassem": "encanteirar",
    "encanteirasses": "encanteirar",
    "encanteiraste": "encanteirar",
    "encanteirastes": "encanteirar",
    "encanteirava": "encanteirar",
    "encanteiravam": "encanteirar",
    "encanteiravas": "encanteirar",
    "encanteire": "encanteirar",
    "encanteirei": "encanteirar",
    "encanteireis": "encanteirar",
    "encanteirem": "encanteirar",
    "encanteiremo": "encanteirar",
    "encanteiremos": "encanteirar",
    "encanteires": "encanteirar",
    "encanteiro": "encanteirar",
    "encanteirou": "encanteirar",
    "encanteirá": "encanteirar",
    "encanteirámo": "encanteirar",
    "encanteirámos": "encanteirar",
    "encanteiráramo": "encanteirar",
    "encanteiráramos": "encanteirar",
    "encanteirárei": "encanteirar",
    "encanteiráreis": "encanteirar",
    "encanteirásseis": "encanteirar",
    "encanteirássemos": "encanteirar",
    "encanteirávamo": "encanteirar",
    "encanteirávamos": "encanteirar",
    "encanteirávei": "encanteirar",
    "encanteiráveis": "encanteirar",
    "encanteis": "encantar",
    "encantem": "encantar",
    "encantemo": "encantar",
    "encantemos": "encantar",
    "encantes": "encantar",
    "encanto": "encantar",
    "encantoa": "encantoar",
    "encantoada": "encantoar",
    "encantoadas": "encantoar",
    "encantoado": "encantoar",
    "encantoados": "encantoar",
    "encantoai": "encantoar",
    "encantoais": "encantoar",
    "encantoam": "encantoar",
    "encantoamo": "encantoar",
    "encantoamos": "encantoar",
    "encantoando": "encantoar",
    "encantoara": "encantoar",
    "encantoaram": "encantoar",
    "encantoaras": "encantoar",
    "encantoarde": "encantoar",
    "encantoardes": "encantoar",
    "encantoare": "encantoar",
    "encantoarei": "encantoar",
    "encantoareis": "encantoar",
    "encantoarem": "encantoar",
    "encantoaremos": "encantoar",
    "encantoares": "encantoar",
    "encantoaria": "encantoar",
    "encantoariam": "encantoar",
    "encantoarias": "encantoar",
    "encantoarmo": "encantoar",
    "encantoarmos": "encantoar",
    "encantoará": "encantoar",
    "encantoarás": "encantoar",
    "encantoarão": "encantoar",
    "encantoaríamos": "encantoar",
    "encantoaríeis": "encantoar",
    "encantoas": "encantoar",
    "encantoasse": "encantoar",
    "encantoassem": "encantoar",
    "encantoasses": "encantoar",
    "encantoaste": "encantoar",
    "encantoastes": "encantoar",
    "encantoava": "encantoar",
    "encantoavam": "encantoar",
    "encantoavas": "encantoar",
    "encantoe": "encantoar",
    "encantoei": "encantoar",
    "encantoeis": "encantoar",
    "encantoem": "encantoar",
    "encantoemo": "encantoar",
    "encantoemos": "encantoar",
    "encantoes": "encantoar",
    "encantona": "encantonar",
    "encantonada": "encantonar",
    "encantonadas": "encantonar",
    "encantonado": "encantonar",
    "encantonados": "encantonar",
    "encantonai": "encantonar",
    "encantonais": "encantonar",
    "encantonam": "encantonar",
    "encantonamo": "encantonar",
    "encantonamos": "encantonar",
    "encantonando": "encantonar",
    "encantonara": "encantonar",
    "encantonaram": "encantonar",
    "encantonaras": "encantonar",
    "encantonarde": "encantonar",
    "encantonardes": "encantonar",
    "encantonare": "encantonar",
    "encantonarei": "encantonar",
    "encantonareis": "encantonar",
    "encantonarem": "encantonar",
    "encantonaremos": "encantonar",
    "encantonares": "encantonar",
    "encantonaria": "encantonar",
    "encantonariam": "encantonar",
    "encantonarias": "encantonar",
    "encantonarmo": "encantonar",
    "encantonarmos": "encantonar",
    "encantonará": "encantonar",
    "encantonarás": "encantonar",
    "encantonarão": "encantonar",
    "encantonaríamos": "encantonar",
    "encantonaríeis": "encantonar",
    "encantonas": "encantonar",
    "encantonasse": "encantonar",
    "encantonassem": "encantonar",
    "encantonasses": "encantonar",
    "encantonaste": "encantonar",
    "encantonastes": "encantonar",
    "encantonava": "encantonar",
    "encantonavam": "encantonar",
    "encantonavas": "encantonar",
    "encantone": "encantonar",
    "encantonei": "encantonar",
    "encantoneis": "encantonar",
    "encantonem": "encantonar",
    "encantonemo": "encantonar",
    "encantonemos": "encantonar",
    "encantones": "encantonar",
    "encantono": "encantonar",
    "encantonou": "encantonar",
    "encantoná": "encantonar",
    "encantonámo": "encantonar",
    "encantonámos": "encantonar",
    "encantonáramo": "encantonar",
    "encantonáramos": "encantonar",
    "encantonárei": "encantonar",
    "encantonáreis": "encantonar",
    "encantonásseis": "encantonar",
    "encantonássemos": "encantonar",
    "encantonávamo": "encantonar",
    "encantonávamos": "encantonar",
    "encantonávei": "encantonar",
    "encantonáveis": "encantonar",
    "encantoo": "encantoar",
    "encantoou": "encantoar",
    "encantos": "encanto",
    "encantou": "encantar",
    "encantoá": "encantoar",
    "encantoámo": "encantoar",
    "encantoámos": "encantoar",
    "encantoáramo": "encantoar",
    "encantoáramos": "encantoar",
    "encantoárei": "encantoar",
    "encantoáreis": "encantoar",
    "encantoásseis": "encantoar",
    "encantoássemos": "encantoar",
    "encantoávamo": "encantoar",
    "encantoávamos": "encantoar",
    "encantoávei": "encantoar",
    "encantoáveis": "encantoar",
    "encantá": "encantar",
    "encantámo": "encantar",
    "encantámos": "encantar",
    "encantáramo": "encantar",
    "encantáramos": "encantar",
    "encantárei": "encantar",
    "encantáreis": "encantar",
    "encantásseis": "encantar",
    "encantássemos": "encantar",
    "encantávamo": "encantar",
    "encantávamos": "encantar",
    "encantávei": "encantar",
    "encantáveis": "encantar",
    "encanuda": "encanudar",
    "encanudada": "encanudar",
    "encanudadas": "encanudar",
    "encanudado": "encanudar",
    "encanudados": "encanudar",
    "encanudai": "encanudar",
    "encanudais": "encanudar",
    "encanudam": "encanudar",
    "encanudamo": "encanudar",
    "encanudamos": "encanudar",
    "encanudando": "encanudar",
    "encanudara": "encanudar",
    "encanudaram": "encanudar",
    "encanudaras": "encanudar",
    "encanudarde": "encanudar",
    "encanudardes": "encanudar",
    "encanudare": "encanudar",
    "encanudarei": "encanudar",
    "encanudareis": "encanudar",
    "encanudarem": "encanudar",
    "encanudaremos": "encanudar",
    "encanudares": "encanudar",
    "encanudaria": "encanudar",
    "encanudariam": "encanudar",
    "encanudarias": "encanudar",
    "encanudarmo": "encanudar",
    "encanudarmos": "encanudar",
    "encanudará": "encanudar",
    "encanudarás": "encanudar",
    "encanudarão": "encanudar",
    "encanudaríamos": "encanudar",
    "encanudaríeis": "encanudar",
    "encanudas": "encanudar",
    "encanudasse": "encanudar",
    "encanudassem": "encanudar",
    "encanudasses": "encanudar",
    "encanudaste": "encanudar",
    "encanudastes": "encanudar",
    "encanudava": "encanudar",
    "encanudavam": "encanudar",
    "encanudavas": "encanudar",
    "encanude": "encanudar",
    "encanudei": "encanudar",
    "encanudeis": "encanudar",
    "encanudem": "encanudar",
    "encanudemo": "encanudar",
    "encanudemos": "encanudar",
    "encanudes": "encanudar",
    "encanudo": "encanudar",
    "encanudou": "encanudar",
    "encanudá": "encanudar",
    "encanudámo": "encanudar",
    "encanudámos": "encanudar",
    "encanudáramo": "encanudar",
    "encanudáramos": "encanudar",
    "encanudárei": "encanudar",
    "encanudáreis": "encanudar",
    "encanudásseis": "encanudar",
    "encanudássemos": "encanudar",
    "encanudávamo": "encanudar",
    "encanudávamos": "encanudar",
    "encanudávei": "encanudar",
    "encanudáveis": "encanudar",
    "encanzina": "encanzinar",
    "encanzinada": "encanzinar",
    "encanzinadas": "encanzinar",
    "encanzinado": "encanzinar",
    "encanzinados": "encanzinar",
    "encanzinai": "encanzinar",
    "encanzinais": "encanzinar",
    "encanzinam": "encanzinar",
    "encanzinamentos": "encanzinamento",
    "encanzinamo": "encanzinar",
    "encanzinamos": "encanzinar",
    "encanzinando": "encanzinar",
    "encanzinara": "encanzinar",
    "encanzinaram": "encanzinar",
    "encanzinaras": "encanzinar",
    "encanzinarde": "encanzinar",
    "encanzinardes": "encanzinar",
    "encanzinare": "encanzinar",
    "encanzinarei": "encanzinar",
    "encanzinareis": "encanzinar",
    "encanzinarem": "encanzinar",
    "encanzinaremos": "encanzinar",
    "encanzinares": "encanzinar",
    "encanzinaria": "encanzinar",
    "encanzinariam": "encanzinar",
    "encanzinarias": "encanzinar",
    "encanzinarmo": "encanzinar",
    "encanzinarmos": "encanzinar",
    "encanzinará": "encanzinar",
    "encanzinarás": "encanzinar",
    "encanzinarão": "encanzinar",
    "encanzinaríamos": "encanzinar",
    "encanzinaríeis": "encanzinar",
    "encanzinas": "encanzinar",
    "encanzinasse": "encanzinar",
    "encanzinassem": "encanzinar",
    "encanzinasses": "encanzinar",
    "encanzinaste": "encanzinar",
    "encanzinastes": "encanzinar",
    "encanzinava": "encanzinar",
    "encanzinavam": "encanzinar",
    "encanzinavas": "encanzinar",
    "encanzine": "encanzinar",
    "encanzinei": "encanzinar",
    "encanzineis": "encanzinar",
    "encanzinem": "encanzinar",
    "encanzinemo": "encanzinar",
    "encanzinemos": "encanzinar",
    "encanzines": "encanzinar",
    "encanzino": "encanzinar",
    "encanzinou": "encanzinar",
    "encanziná": "encanzinar",
    "encanzinámo": "encanzinar",
    "encanzinámos": "encanzinar",
    "encanzináramo": "encanzinar",
    "encanzináramos": "encanzinar",
    "encanzinárei": "encanzinar",
    "encanzináreis": "encanzinar",
    "encanzinásseis": "encanzinar",
    "encanzinássemos": "encanzinar",
    "encanzinávamo": "encanzinar",
    "encanzinávamos": "encanzinar",
    "encanzinávei": "encanzinar",
    "encanzináveis": "encanzinar",
    "encanzoa": "encanzoar",
    "encanzoada": "encanzoar",
    "encanzoadas": "encanzoar",
    "encanzoado": "encanzoar",
    "encanzoados": "encanzoar",
    "encanzoai": "encanzoar",
    "encanzoais": "encanzoar",
    "encanzoam": "encanzoar",
    "encanzoamo": "encanzoar",
    "encanzoamos": "encanzoar",
    "encanzoando": "encanzoar",
    "encanzoara": "encanzoar",
    "encanzoaram": "encanzoar",
    "encanzoaras": "encanzoar",
    "encanzoarde": "encanzoar",
    "encanzoardes": "encanzoar",
    "encanzoare": "encanzoar",
    "encanzoarei": "encanzoar",
    "encanzoareis": "encanzoar",
    "encanzoarem": "encanzoar",
    "encanzoaremos": "encanzoar",
    "encanzoares": "encanzoar",
    "encanzoaria": "encanzoar",
    "encanzoariam": "encanzoar",
    "encanzoarias": "encanzoar",
    "encanzoarmo": "encanzoar",
    "encanzoarmos": "encanzoar",
    "encanzoará": "encanzoar",
    "encanzoarás": "encanzoar",
    "encanzoarão": "encanzoar",
    "encanzoaríamos": "encanzoar",
    "encanzoaríeis": "encanzoar",
    "encanzoas": "encanzoar",
    "encanzoasse": "encanzoar",
    "encanzoassem": "encanzoar",
    "encanzoasses": "encanzoar",
    "encanzoaste": "encanzoar",
    "encanzoastes": "encanzoar",
    "encanzoava": "encanzoar",
    "encanzoavam": "encanzoar",
    "encanzoavas": "encanzoar",
    "encanzoe": "encanzoar",
    "encanzoei": "encanzoar",
    "encanzoeis": "encanzoar",
    "encanzoem": "encanzoar",
    "encanzoemo": "encanzoar",
    "encanzoemos": "encanzoar",
    "encanzoes": "encanzoar",
    "encanzoo": "encanzoar",
    "encanzoou": "encanzoar",
    "encanzoá": "encanzoar",
    "encanzoámo": "encanzoar",
    "encanzoámos": "encanzoar",
    "encanzoáramo": "encanzoar",
    "encanzoáramos": "encanzoar",
    "encanzoárei": "encanzoar",
    "encanzoáreis": "encanzoar",
    "encanzoásseis": "encanzoar",
    "encanzoássemos": "encanzoar",
    "encanzoávamo": "encanzoar",
    "encanzoávamos": "encanzoar",
    "encanzoávei": "encanzoar",
    "encanzoáveis": "encanzoar",
    "encaná": "encanar",
    "encanámo": "encanar",
    "encanámos": "encanar",
    "encanáramo": "encanar",
    "encanáramos": "encanar",
    "encanárei": "encanar",
    "encanáreis": "encanar",
    "encanásseis": "encanar",
    "encanássemos": "encanar",
    "encanávamo": "encanar",
    "encanávamos": "encanar",
    "encanávei": "encanar",
    "encanáveis": "encanar",
    "encapa": "encapar",
    "encapacha": "encapachar",
    "encapachada": "encapachar",
    "encapachadas": "encapachar",
    "encapachado": "encapachar",
    "encapachados": "encapachar",
    "encapachai": "encapachar",
    "encapachais": "encapachar",
    "encapacham": "encapachar",
    "encapachamo": "encapachar",
    "encapachamos": "encapachar",
    "encapachando": "encapachar",
    "encapachara": "encapachar",
    "encapacharam": "encapachar",
    "encapacharas": "encapachar",
    "encapacharde": "encapachar",
    "encapachardes": "encapachar",
    "encapachare": "encapachar",
    "encapacharei": "encapachar",
    "encapachareis": "encapachar",
    "encapacharem": "encapachar",
    "encapacharemos": "encapachar",
    "encapachares": "encapachar",
    "encapacharia": "encapachar",
    "encapachariam": "encapachar",
    "encapacharias": "encapachar",
    "encapacharmo": "encapachar",
    "encapacharmos": "encapachar",
    "encapachará": "encapachar",
    "encapacharás": "encapachar",
    "encapacharão": "encapachar",
    "encapacharíamos": "encapachar",
    "encapacharíeis": "encapachar",
    "encapachas": "encapachar",
    "encapachasse": "encapachar",
    "encapachassem": "encapachar",
    "encapachasses": "encapachar",
    "encapachaste": "encapachar",
    "encapachastes": "encapachar",
    "encapachava": "encapachar",
    "encapachavam": "encapachar",
    "encapachavas": "encapachar",
    "encapache": "encapachar",
    "encapachei": "encapachar",
    "encapacheis": "encapachar",
    "encapachem": "encapachar",
    "encapachemo": "encapachar",
    "encapachemos": "encapachar",
    "encapaches": "encapachar",
    "encapacho": "encapachar",
    "encapachou": "encapachar",
    "encapachá": "encapachar",
    "encapachámo": "encapachar",
    "encapachámos": "encapachar",
    "encapacháramo": "encapachar",
    "encapacháramos": "encapachar",
    "encapachárei": "encapachar",
    "encapacháreis": "encapachar",
    "encapachásseis": "encapachar",
    "encapachássemos": "encapachar",
    "encapachávamo": "encapachar",
    "encapachávamos": "encapachar",
    "encapachávei": "encapachar",
    "encapacháveis": "encapachar",
    "encapada": "encapar",
    "encapadas": "encapar",
    "encapado": "encapar",
    "encapados": "encapar",
    "encapai": "encapar",
    "encapais": "encapar",
    "encapam": "encapar",
    "encapamo": "encapar",
    "encapamos": "encapar",
    "encapando": "encapar",
    "encapara": "encapar",
    "encaparam": "encapar",
    "encaparas": "encapar",
    "encaparde": "encapar",
    "encapardes": "encapar",
    "encapare": "encapar",
    "encaparei": "encapar",
    "encapareis": "encapar",
    "encaparem": "encapar",
    "encaparemos": "encapar",
    "encapares": "encapar",
    "encaparia": "encapar",
    "encapariam": "encapar",
    "encaparias": "encapar",
    "encaparmo": "encapar",
    "encaparmos": "encapar",
    "encapará": "encapar",
    "encaparás": "encapar",
    "encaparão": "encapar",
    "encaparíamos": "encapar",
    "encaparíeis": "encapar",
    "encapas": "encapar",
    "encapasse": "encapar",
    "encapassem": "encapar",
    "encapasses": "encapar",
    "encapaste": "encapar",
    "encapastes": "encapar",
    "encapava": "encapar",
    "encapavam": "encapar",
    "encapavas": "encapar",
    "encape": "encapar",
    "encapei": "encapar",
    "encapeis": "encapar",
    "encapela": "encapelar",
    "encapelada": "encapelar",
    "encapeladas": "encapelar",
    "encapelado": "encapelar",
    "encapelados": "encapelar",
    "encapeladuras": "encapeladura",
    "encapelai": "encapelar",
    "encapelais": "encapelar",
    "encapelam": "encapelar",
    "encapelamo": "encapelar",
    "encapelamos": "encapelar",
    "encapelando": "encapelar",
    "encapelara": "encapelar",
    "encapelaram": "encapelar",
    "encapelaras": "encapelar",
    "encapelarde": "encapelar",
    "encapelardes": "encapelar",
    "encapelare": "encapelar",
    "encapelarei": "encapelar",
    "encapelareis": "encapelar",
    "encapelarem": "encapelar",
    "encapelaremos": "encapelar",
    "encapelares": "encapelar",
    "encapelaria": "encapelar",
    "encapelariam": "encapelar",
    "encapelarias": "encapelar",
    "encapelarmo": "encapelar",
    "encapelarmos": "encapelar",
    "encapelará": "encapelar",
    "encapelarás": "encapelar",
    "encapelarão": "encapelar",
    "encapelaríamos": "encapelar",
    "encapelaríeis": "encapelar",
    "encapelas": "encapelar",
    "encapelasse": "encapelar",
    "encapelassem": "encapelar",
    "encapelasses": "encapelar",
    "encapelaste": "encapelar",
    "encapelastes": "encapelar",
    "encapelava": "encapelar",
    "encapelavam": "encapelar",
    "encapelavas": "encapelar",
    "encapele": "encapelar",
    "encapelei": "encapelar",
    "encapeleis": "encapelar",
    "encapelem": "encapelar",
    "encapelemo": "encapelar",
    "encapelemos": "encapelar",
    "encapeles": "encapelar",
    "encapelo": "encapelar",
    "encapelou": "encapelar",
    "encapelá": "encapelar",
    "encapelámo": "encapelar",
    "encapelámos": "encapelar",
    "encapeláramo": "encapelar",
    "encapeláramos": "encapelar",
    "encapelárei": "encapelar",
    "encapeláreis": "encapelar",
    "encapelásseis": "encapelar",
    "encapelássemos": "encapelar",
    "encapelávamo": "encapelar",
    "encapelávamos": "encapelar",
    "encapelávei": "encapelar",
    "encapeláveis": "encapelar",
    "encapem": "encapar",
    "encapemo": "encapar",
    "encapemos": "encapar",
    "encapes": "encapar",
    "encapo": "encapar",
    "encapoeira": "encapoeirar",
    "encapoeirada": "encapoeirar",
    "encapoeiradas": "encapoeirar",
    "encapoeirado": "encapoeirar",
    "encapoeirados": "encapoeirar",
    "encapoeirai": "encapoeirar",
    "encapoeirais": "encapoeirar",
    "encapoeiram": "encapoeirar",
    "encapoeiramo": "encapoeirar",
    "encapoeiramos": "encapoeirar",
    "encapoeirando": "encapoeirar",
    "encapoeirara": "encapoeirar",
    "encapoeiraram": "encapoeirar",
    "encapoeiraras": "encapoeirar",
    "encapoeirarde": "encapoeirar",
    "encapoeirardes": "encapoeirar",
    "encapoeirare": "encapoeirar",
    "encapoeirarei": "encapoeirar",
    "encapoeirareis": "encapoeirar",
    "encapoeirarem": "encapoeirar",
    "encapoeiraremos": "encapoeirar",
    "encapoeirares": "encapoeirar",
    "encapoeiraria": "encapoeirar",
    "encapoeirariam": "encapoeirar",
    "encapoeirarias": "encapoeirar",
    "encapoeirarmo": "encapoeirar",
    "encapoeirarmos": "encapoeirar",
    "encapoeirará": "encapoeirar",
    "encapoeirarás": "encapoeirar",
    "encapoeirarão": "encapoeirar",
    "encapoeiraríamos": "encapoeirar",
    "encapoeiraríeis": "encapoeirar",
    "encapoeiras": "encapoeirar",
    "encapoeirasse": "encapoeirar",
    "encapoeirassem": "encapoeirar",
    "encapoeirasses": "encapoeirar",
    "encapoeiraste": "encapoeirar",
    "encapoeirastes": "encapoeirar",
    "encapoeirava": "encapoeirar",
    "encapoeiravam": "encapoeirar",
    "encapoeiravas": "encapoeirar",
    "encapoeire": "encapoeirar",
    "encapoeirei": "encapoeirar",
    "encapoeireis": "encapoeirar",
    "encapoeirem": "encapoeirar",
    "encapoeiremo": "encapoeirar",
    "encapoeiremos": "encapoeirar",
    "encapoeires": "encapoeirar",
    "encapoeiro": "encapoeirar",
    "encapoeirou": "encapoeirar",
    "encapoeirá": "encapoeirar",
    "encapoeirámo": "encapoeirar",
    "encapoeirámos": "encapoeirar",
    "encapoeiráramo": "encapoeirar",
    "encapoeiráramos": "encapoeirar",
    "encapoeirárei": "encapoeirar",
    "encapoeiráreis": "encapoeirar",
    "encapoeirásseis": "encapoeirar",
    "encapoeirássemos": "encapoeirar",
    "encapoeirávamo": "encapoeirar",
    "encapoeirávamos": "encapoeirar",
    "encapoeirávei": "encapoeirar",
    "encapoeiráveis": "encapoeirar",
    "encapota": "encapotar",
    "encapotada": "encapotar",
    "encapotadas": "encapotar",
    "encapotado": "encapotar",
    "encapotados": "encapotar",
    "encapotai": "encapotar",
    "encapotais": "encapotar",
    "encapotam": "encapotar",
    "encapotamo": "encapotar",
    "encapotamos": "encapotar",
    "encapotando": "encapotar",
    "encapotara": "encapotar",
    "encapotaram": "encapotar",
    "encapotaras": "encapotar",
    "encapotarde": "encapotar",
    "encapotardes": "encapotar",
    "encapotare": "encapotar",
    "encapotarei": "encapotar",
    "encapotareis": "encapotar",
    "encapotarem": "encapotar",
    "encapotaremos": "encapotar",
    "encapotares": "encapotar",
    "encapotaria": "encapotar",
    "encapotariam": "encapotar",
    "encapotarias": "encapotar",
    "encapotarmo": "encapotar",
    "encapotarmos": "encapotar",
    "encapotará": "encapotar",
    "encapotarás": "encapotar",
    "encapotarão": "encapotar",
    "encapotaríamos": "encapotar",
    "encapotaríeis": "encapotar",
    "encapotas": "encapotar",
    "encapotasse": "encapotar",
    "encapotassem": "encapotar",
    "encapotasses": "encapotar",
    "encapotaste": "encapotar",
    "encapotastes": "encapotar",
    "encapotava": "encapotar",
    "encapotavam": "encapotar",
    "encapotavas": "encapotar",
    "encapote": "encapotar",
    "encapotei": "encapotar",
    "encapoteis": "encapotar",
    "encapotem": "encapotar",
    "encapotemo": "encapotar",
    "encapotemos": "encapotar",
    "encapotes": "encapotar",
    "encapoto": "encapotar",
    "encapotou": "encapotar",
    "encapotá": "encapotar",
    "encapotámo": "encapotar",
    "encapotámos": "encapotar",
    "encapotáramo": "encapotar",
    "encapotáramos": "encapotar",
    "encapotárei": "encapotar",
    "encapotáreis": "encapotar",
    "encapotásseis": "encapotar",
    "encapotássemos": "encapotar",
    "encapotávamo": "encapotar",
    "encapotávamos": "encapotar",
    "encapotávei": "encapotar",
    "encapotáveis": "encapotar",
    "encapou": "encapar",
    "encapricha": "encaprichar",
    "encaprichada": "encaprichar",
    "encaprichadas": "encaprichar",
    "encaprichado": "encaprichar",
    "encaprichados": "encaprichar",
    "encaprichai": "encaprichar",
    "encaprichais": "encaprichar",
    "encapricham": "encaprichar",
    "encaprichamo": "encaprichar",
    "encaprichamos": "encaprichar",
    "encaprichando": "encaprichar",
    "encaprichara": "encaprichar",
    "encapricharam": "encaprichar",
    "encapricharas": "encaprichar",
    "encapricharde": "encaprichar",
    "encaprichardes": "encaprichar",
    "encaprichare": "encaprichar",
    "encapricharei": "encaprichar",
    "encaprichareis": "encaprichar",
    "encapricharem": "encaprichar",
    "encapricharemos": "encaprichar",
    "encaprichares": "encaprichar",
    "encapricharia": "encaprichar",
    "encaprichariam": "encaprichar",
    "encapricharias": "encaprichar",
    "encapricharmo": "encaprichar",
    "encapricharmos": "encaprichar",
    "encaprichará": "encaprichar",
    "encapricharás": "encaprichar",
    "encapricharão": "encaprichar",
    "encapricharíamos": "encaprichar",
    "encapricharíeis": "encaprichar",
    "encaprichas": "encaprichar",
    "encaprichasse": "encaprichar",
    "encaprichassem": "encaprichar",
    "encaprichasses": "encaprichar",
    "encaprichaste": "encaprichar",
    "encaprichastes": "encaprichar",
    "encaprichava": "encaprichar",
    "encaprichavam": "encaprichar",
    "encaprichavas": "encaprichar",
    "encapriche": "encaprichar",
    "encaprichei": "encaprichar",
    "encapricheis": "encaprichar",
    "encaprichem": "encaprichar",
    "encaprichemo": "encaprichar",
    "encaprichemos": "encaprichar",
    "encapriches": "encaprichar",
    "encapricho": "encaprichar",
    "encaprichou": "encaprichar",
    "encaprichá": "encaprichar",
    "encaprichámo": "encaprichar",
    "encaprichámos": "encaprichar",
    "encapricháramo": "encaprichar",
    "encapricháramos": "encaprichar",
    "encaprichárei": "encaprichar",
    "encapricháreis": "encaprichar",
    "encaprichásseis": "encaprichar",
    "encaprichássemos": "encaprichar",
    "encaprichávamo": "encaprichar",
    "encaprichávamos": "encaprichar",
    "encaprichávei": "encaprichar",
    "encapricháveis": "encaprichar",
    "encapsulamentos": "encapsulamento",
    "encapsulações": "encapsulação",
    "encapucha": "encapuchar",
    "encapuchada": "encapuchar",
    "encapuchadas": "encapuchar",
    "encapuchado": "encapuchar",
    "encapuchados": "encapuchar",
    "encapuchai": "encapuchar",
    "encapuchais": "encapuchar",
    "encapucham": "encapuchar",
    "encapuchamo": "encapuchar",
    "encapuchamos": "encapuchar",
    "encapuchando": "encapuchar",
    "encapuchara": "encapuchar",
    "encapucharam": "encapuchar",
    "encapucharas": "encapuchar",
    "encapucharde": "encapuchar",
    "encapuchardes": "encapuchar",
    "encapuchare": "encapuchar",
    "encapucharei": "encapuchar",
    "encapuchareis": "encapuchar",
    "encapucharem": "encapuchar",
    "encapucharemos": "encapuchar",
    "encapuchares": "encapuchar",
    "encapucharia": "encapuchar",
    "encapuchariam": "encapuchar",
    "encapucharias": "encapuchar",
    "encapucharmo": "encapuchar",
    "encapucharmos": "encapuchar",
    "encapuchará": "encapuchar",
    "encapucharás": "encapuchar",
    "encapucharão": "encapuchar",
    "encapucharíamos": "encapuchar",
    "encapucharíeis": "encapuchar",
    "encapuchas": "encapuchar",
    "encapuchasse": "encapuchar",
    "encapuchassem": "encapuchar",
    "encapuchasses": "encapuchar",
    "encapuchaste": "encapuchar",
    "encapuchastes": "encapuchar",
    "encapuchava": "encapuchar",
    "encapuchavam": "encapuchar",
    "encapuchavas": "encapuchar",
    "encapuche": "encapuchar",
    "encapuchei": "encapuchar",
    "encapucheis": "encapuchar",
    "encapuchem": "encapuchar",
    "encapuchemo": "encapuchar",
    "encapuchemos": "encapuchar",
    "encapuches": "encapuchar",
    "encapucho": "encapuchar",
    "encapuchou": "encapuchar",
    "encapuchá": "encapuchar",
    "encapuchámo": "encapuchar",
    "encapuchámos": "encapuchar",
    "encapucháramo": "encapuchar",
    "encapucháramos": "encapuchar",
    "encapuchárei": "encapuchar",
    "encapucháreis": "encapuchar",
    "encapuchásseis": "encapuchar",
    "encapuchássemos": "encapuchar",
    "encapuchávamo": "encapuchar",
    "encapuchávamos": "encapuchar",
    "encapuchávei": "encapuchar",
    "encapucháveis": "encapuchar",
    "encapuza": "encapuzar",
    "encapuzada": "encapuzar",
    "encapuzadas": "encapuzar",
    "encapuzado": "encapuzar",
    "encapuzados": "encapuzar",
    "encapuzai": "encapuzar",
    "encapuzais": "encapuzar",
    "encapuzam": "encapuzar",
    "encapuzamo": "encapuzar",
    "encapuzamos": "encapuzar",
    "encapuzando": "encapuzar",
    "encapuzara": "encapuzar",
    "encapuzaram": "encapuzar",
    "encapuzaras": "encapuzar",
    "encapuzarde": "encapuzar",
    "encapuzardes": "encapuzar",
    "encapuzare": "encapuzar",
    "encapuzarei": "encapuzar",
    "encapuzareis": "encapuzar",
    "encapuzarem": "encapuzar",
    "encapuzaremos": "encapuzar",
    "encapuzares": "encapuzar",
    "encapuzaria": "encapuzar",
    "encapuzariam": "encapuzar",
    "encapuzarias": "encapuzar",
    "encapuzarmo": "encapuzar",
    "encapuzarmos": "encapuzar",
    "encapuzará": "encapuzar",
    "encapuzarás": "encapuzar",
    "encapuzarão": "encapuzar",
    "encapuzaríamos": "encapuzar",
    "encapuzaríeis": "encapuzar",
    "encapuzas": "encapuzar",
    "encapuzasse": "encapuzar",
    "encapuzassem": "encapuzar",
    "encapuzasses": "encapuzar",
    "encapuzaste": "encapuzar",
    "encapuzastes": "encapuzar",
    "encapuzava": "encapuzar",
    "encapuzavam": "encapuzar",
    "encapuzavas": "encapuzar",
    "encapuze": "encapuzar",
    "encapuzei": "encapuzar",
    "encapuzeis": "encapuzar",
    "encapuzem": "encapuzar",
    "encapuzemo": "encapuzar",
    "encapuzemos": "encapuzar",
    "encapuzes": "encapuzar",
    "encapuzo": "encapuzar",
    "encapuzou": "encapuzar",
    "encapuzá": "encapuzar",
    "encapuzámo": "encapuzar",
    "encapuzámos": "encapuzar",
    "encapuzáramo": "encapuzar",
    "encapuzáramos": "encapuzar",
    "encapuzárei": "encapuzar",
    "encapuzáreis": "encapuzar",
    "encapuzásseis": "encapuzar",
    "encapuzássemos": "encapuzar",
    "encapuzávamo": "encapuzar",
    "encapuzávamos": "encapuzar",
    "encapuzávei": "encapuzar",
    "encapuzáveis": "encapuzar",
    "encapuçada": "encapuçado",
    "encapuçadas": "encapuçado",
    "encapuçados": "encapuçado",
    "encapá": "encapar",
    "encapámo": "encapar",
    "encapámos": "encapar",
    "encapáramo": "encapar",
    "encapáramos": "encapar",
    "encapárei": "encapar",
    "encapáreis": "encapar",
    "encapásseis": "encapar",
    "encapássemos": "encapar",
    "encapávamo": "encapar",
    "encapávamos": "encapar",
    "encapávei": "encapar",
    "encapáveis": "encapar",
    "encara": "encarar",
    "encaracola": "encaracolar",
    "encaracolada": "encaracolar",
    "encaracoladas": "encaracolar",
    "encaracolado": "encaracolar",
    "encaracolados": "encaracolar",
    "encaracolai": "encaracolar",
    "encaracolais": "encaracolar",
    "encaracolam": "encaracolar",
    "encaracolamo": "encaracolar",
    "encaracolamos": "encaracolar",
    "encaracolando": "encaracolar",
    "encaracolara": "encaracolar",
    "encaracolaram": "encaracolar",
    "encaracolaras": "encaracolar",
    "encaracolarde": "encaracolar",
    "encaracolardes": "encaracolar",
    "encaracolare": "encaracolar",
    "encaracolarei": "encaracolar",
    "encaracolareis": "encaracolar",
    "encaracolarem": "encaracolar",
    "encaracolaremos": "encaracolar",
    "encaracolares": "encaracolar",
    "encaracolaria": "encaracolar",
    "encaracolariam": "encaracolar",
    "encaracolarias": "encaracolar",
    "encaracolarmo": "encaracolar",
    "encaracolarmos": "encaracolar",
    "encaracolará": "encaracolar",
    "encaracolarás": "encaracolar",
    "encaracolarão": "encaracolar",
    "encaracolaríamos": "encaracolar",
    "encaracolaríeis": "encaracolar",
    "encaracolas": "encaracolar",
    "encaracolasse": "encaracolar",
    "encaracolassem": "encaracolar",
    "encaracolasses": "encaracolar",
    "encaracolaste": "encaracolar",
    "encaracolastes": "encaracolar",
    "encaracolava": "encaracolar",
    "encaracolavam": "encaracolar",
    "encaracolavas": "encaracolar",
    "encaracole": "encaracolar",
    "encaracolei": "encaracolar",
    "encaracoleis": "encaracolar",
    "encaracolem": "encaracolar",
    "encaracolemo": "encaracolar",
    "encaracolemos": "encaracolar",
    "encaracoles": "encaracolar",
    "encaracolo": "encaracolar",
    "encaracolou": "encaracolar",
    "encaracolá": "encaracolar",
    "encaracolámo": "encaracolar",
    "encaracolámos": "encaracolar",
    "encaracoláramo": "encaracolar",
    "encaracoláramos": "encaracolar",
    "encaracolárei": "encaracolar",
    "encaracoláreis": "encaracolar",
    "encaracolásseis": "encaracolar",
    "encaracolássemos": "encaracolar",
    "encaracolávamo": "encaracolar",
    "encaracolávamos": "encaracolar",
    "encaracolávei": "encaracolar",
    "encaracoláveis": "encaracolar",
    "encarada": "encarar",
    "encaradas": "encarar",
    "encarado": "encarar",
    "encarados": "encarar",
    "encarai": "encarar",
    "encarais": "encarar",
    "encaram": "encarar",
    "encaramancha": "encaramanchar",
    "encaramanchada": "encaramanchar",
    "encaramanchadas": "encaramanchar",
    "encaramanchado": "encaramanchar",
    "encaramanchados": "encaramanchar",
    "encaramanchai": "encaramanchar",
    "encaramanchais": "encaramanchar",
    "encaramancham": "encaramanchar",
    "encaramanchamo": "encaramanchar",
    "encaramanchamos": "encaramanchar",
    "encaramanchando": "encaramanchar",
    "encaramanchara": "encaramanchar",
    "encaramancharam": "encaramanchar",
    "encaramancharas": "encaramanchar",
    "encaramancharde": "encaramanchar",
    "encaramanchardes": "encaramanchar",
    "encaramanchare": "encaramanchar",
    "encaramancharei": "encaramanchar",
    "encaramanchareis": "encaramanchar",
    "encaramancharem": "encaramanchar",
    "encaramancharemos": "encaramanchar",
    "encaramanchares": "encaramanchar",
    "encaramancharia": "encaramanchar",
    "encaramanchariam": "encaramanchar",
    "encaramancharias": "encaramanchar",
    "encaramancharmo": "encaramanchar",
    "encaramancharmos": "encaramanchar",
    "encaramanchará": "encaramanchar",
    "encaramancharás": "encaramanchar",
    "encaramancharão": "encaramanchar",
    "encaramancharíamos": "encaramanchar",
    "encaramancharíeis": "encaramanchar",
    "encaramanchas": "encaramanchar",
    "encaramanchasse": "encaramanchar",
    "encaramanchassem": "encaramanchar",
    "encaramanchasses": "encaramanchar",
    "encaramanchaste": "encaramanchar",
    "encaramanchastes": "encaramanchar",
    "encaramanchava": "encaramanchar",
    "encaramanchavam": "encaramanchar",
    "encaramanchavas": "encaramanchar",
    "encaramanche": "encaramanchar",
    "encaramanchei": "encaramanchar",
    "encaramancheis": "encaramanchar",
    "encaramanchem": "encaramanchar",
    "encaramanchemo": "encaramanchar",
    "encaramanchemos": "encaramanchar",
    "encaramanches": "encaramanchar",
    "encaramancho": "encaramanchar",
    "encaramanchou": "encaramanchar",
    "encaramanchá": "encaramanchar",
    "encaramanchámo": "encaramanchar",
    "encaramanchámos": "encaramanchar",
    "encaramancháramo": "encaramanchar",
    "encaramancháramos": "encaramanchar",
    "encaramanchárei": "encaramanchar",
    "encaramancháreis": "encaramanchar",
    "encaramanchásseis": "encaramanchar",
    "encaramanchássemos": "encaramanchar",
    "encaramanchávamo": "encaramanchar",
    "encaramanchávamos": "encaramanchar",
    "encaramanchávei": "encaramanchar",
    "encaramancháveis": "encaramanchar",
    "encaramela": "encaramelar",
    "encaramelada": "encaramelar",
    "encarameladas": "encaramelar",
    "encaramelado": "encaramelar",
    "encaramelados": "encaramelar",
    "encaramelai": "encaramelar",
    "encaramelais": "encaramelar",
    "encaramelam": "encaramelar",
    "encaramelamo": "encaramelar",
    "encaramelamos": "encaramelar",
    "encaramelando": "encaramelar",
    "encaramelara": "encaramelar",
    "encaramelaram": "encaramelar",
    "encaramelaras": "encaramelar",
    "encaramelarde": "encaramelar",
    "encaramelardes": "encaramelar",
    "encaramelare": "encaramelar",
    "encaramelarei": "encaramelar",
    "encaramelareis": "encaramelar",
    "encaramelarem": "encaramelar",
    "encaramelaremos": "encaramelar",
    "encaramelares": "encaramelar",
    "encaramelaria": "encaramelar",
    "encaramelariam": "encaramelar",
    "encaramelarias": "encaramelar",
    "encaramelarmo": "encaramelar",
    "encaramelarmos": "encaramelar",
    "encaramelará": "encaramelar",
    "encaramelarás": "encaramelar",
    "encaramelarão": "encaramelar",
    "encaramelaríamos": "encaramelar",
    "encaramelaríeis": "encaramelar",
    "encaramelas": "encaramelar",
    "encaramelasse": "encaramelar",
    "encaramelassem": "encaramelar",
    "encaramelasses": "encaramelar",
    "encaramelaste": "encaramelar",
    "encaramelastes": "encaramelar",
    "encaramelava": "encaramelar",
    "encaramelavam": "encaramelar",
    "encaramelavas": "encaramelar",
    "encaramele": "encaramelar",
    "encaramelei": "encaramelar",
    "encarameleis": "encaramelar",
    "encaramelem": "encaramelar",
    "encaramelemo": "encaramelar",
    "encaramelemos": "encaramelar",
    "encarameles": "encaramelar",
    "encaramelo": "encaramelar",
    "encaramelou": "encaramelar",
    "encaramelá": "encaramelar",
    "encaramelámo": "encaramelar",
    "encaramelámos": "encaramelar",
    "encarameláramo": "encaramelar",
    "encarameláramos": "encaramelar",
    "encaramelárei": "encaramelar",
    "encarameláreis": "encaramelar",
    "encaramelásseis": "encaramelar",
    "encaramelássemos": "encaramelar",
    "encaramelávamo": "encaramelar",
    "encaramelávamos": "encaramelar",
    "encaramelávei": "encaramelar",
    "encarameláveis": "encaramelar",
    "encaramo": "encarar",
    "encaramona": "encaramonar",
    "encaramonada": "encaramonar",
    "encaramonadas": "encaramonar",
    "encaramonado": "encaramonar",
    "encaramonados": "encaramonar",
    "encaramonai": "encaramonar",
    "encaramonais": "encaramonar",
    "encaramonam": "encaramonar",
    "encaramonamo": "encaramonar",
    "encaramonamos": "encaramonar",
    "encaramonando": "encaramonar",
    "encaramonara": "encaramonar",
    "encaramonaram": "encaramonar",
    "encaramonaras": "encaramonar",
    "encaramonarde": "encaramonar",
    "encaramonardes": "encaramonar",
    "encaramonare": "encaramonar",
    "encaramonarei": "encaramonar",
    "encaramonareis": "encaramonar",
    "encaramonarem": "encaramonar",
    "encaramonaremos": "encaramonar",
    "encaramonares": "encaramonar",
    "encaramonaria": "encaramonar",
    "encaramonariam": "encaramonar",
    "encaramonarias": "encaramonar",
    "encaramonarmo": "encaramonar",
    "encaramonarmos": "encaramonar",
    "encaramonará": "encaramonar",
    "encaramonarás": "encaramonar",
    "encaramonarão": "encaramonar",
    "encaramonaríamos": "encaramonar",
    "encaramonaríeis": "encaramonar",
    "encaramonas": "encaramonar",
    "encaramonasse": "encaramonar",
    "encaramonassem": "encaramonar",
    "encaramonasses": "encaramonar",
    "encaramonaste": "encaramonar",
    "encaramonastes": "encaramonar",
    "encaramonava": "encaramonar",
    "encaramonavam": "encaramonar",
    "encaramonavas": "encaramonar",
    "encaramone": "encaramonar",
    "encaramonei": "encaramonar",
    "encaramoneis": "encaramonar",
    "encaramonem": "encaramonar",
    "encaramonemo": "encaramonar",
    "encaramonemos": "encaramonar",
    "encaramones": "encaramonar",
    "encaramono": "encaramonar",
    "encaramonou": "encaramonar",
    "encaramoná": "encaramonar",
    "encaramonámo": "encaramonar",
    "encaramonámos": "encaramonar",
    "encaramonáramo": "encaramonar",
    "encaramonáramos": "encaramonar",
    "encaramonárei": "encaramonar",
    "encaramonáreis": "encaramonar",
    "encaramonásseis": "encaramonar",
    "encaramonássemos": "encaramonar",
    "encaramonávamo": "encaramonar",
    "encaramonávamos": "encaramonar",
    "encaramonávei": "encaramonar",
    "encaramonáveis": "encaramonar",
    "encaramos": "encarar",
    "encaramuja": "encaramujar",
    "encaramujada": "encaramujar",
    "encaramujadas": "encaramujar",
    "encaramujado": "encaramujar",
    "encaramujados": "encaramujar",
    "encaramujai": "encaramujar",
    "encaramujais": "encaramujar",
    "encaramujam": "encaramujar",
    "encaramujamo": "encaramujar",
    "encaramujamos": "encaramujar",
    "encaramujando": "encaramujar",
    "encaramujara": "encaramujar",
    "encaramujaram": "encaramujar",
    "encaramujaras": "encaramujar",
    "encaramujardes": "encaramujar",
    "encaramujarei": "encaramujar",
    "encaramujareis": "encaramujar",
    "encaramujarem": "encaramujar",
    "encaramujaremos": "encaramujar",
    "encaramujares": "encaramujar",
    "encaramujaria": "encaramujar",
    "encaramujariam": "encaramujar",
    "encaramujarias": "encaramujar",
    "encaramujarmo": "encaramujar",
    "encaramujarmos": "encaramujar",
    "encaramujará": "encaramujar",
    "encaramujarás": "encaramujar",
    "encaramujarão": "encaramujar",
    "encaramujaríamos": "encaramujar",
    "encaramujaríeis": "encaramujar",
    "encaramujas": "encaramujar",
    "encaramujasse": "encaramujar",
    "encaramujassem": "encaramujar",
    "encaramujasses": "encaramujar",
    "encaramujaste": "encaramujar",
    "encaramujastes": "encaramujar",
    "encaramujava": "encaramujar",
    "encaramujavam": "encaramujar",
    "encaramujavas": "encaramujar",
    "encaramuje": "encaramujar",
    "encaramujei": "encaramujar",
    "encaramujeis": "encaramujar",
    "encaramujem": "encaramujar",
    "encaramujemo": "encaramujar",
    "encaramujemos": "encaramujar",
    "encaramujes": "encaramujar",
    "encaramujo": "encaramujar",
    "encaramujou": "encaramujar",
    "encaramujámo": "encaramujar",
    "encaramujámos": "encaramujar",
    "encaramujáramo": "encaramujar",
    "encaramujáramos": "encaramujar",
    "encaramujáreis": "encaramujar",
    "encaramujásseis": "encaramujar",
    "encaramujássemos": "encaramujar",
    "encaramujávamo": "encaramujar",
    "encaramujávamos": "encaramujar",
    "encaramujáveis": "encaramujar",
    "encarando": "encarar",
    "encaranga": "encarangar",
    "encarangada": "encarangar",
    "encarangadas": "encarangar",
    "encarangado": "encarangar",
    "encarangados": "encarangar",
    "encarangai": "encarangar",
    "encarangais": "encarangar",
    "encarangam": "encarangar",
    "encarangamo": "encarangar",
    "encarangamos": "encarangar",
    "encarangando": "encarangar",
    "encarangara": "encarangar",
    "encarangaram": "encarangar",
    "encarangaras": "encarangar",
    "encarangardes": "encarangar",
    "encarangarei": "encarangar",
    "encarangareis": "encarangar",
    "encarangarem": "encarangar",
    "encarangaremos": "encarangar",
    "encarangares": "encarangar",
    "encarangaria": "encarangar",
    "encarangariam": "encarangar",
    "encarangarias": "encarangar",
    "encarangarmo": "encarangar",
    "encarangarmos": "encarangar",
    "encarangará": "encarangar",
    "encarangarás": "encarangar",
    "encarangarão": "encarangar",
    "encarangaríamos": "encarangar",
    "encarangaríeis": "encarangar",
    "encarangas": "encarangar",
    "encarangasse": "encarangar",
    "encarangassem": "encarangar",
    "encarangasses": "encarangar",
    "encarangaste": "encarangar",
    "encarangastes": "encarangar",
    "encarangava": "encarangar",
    "encarangavam": "encarangar",
    "encarangavas": "encarangar",
    "encarango": "encarangar",
    "encarangou": "encarangar",
    "encarangue": "encarangar",
    "encaranguei": "encarangar",
    "encarangueis": "encarangar",
    "encarangueja": "encaranguejar",
    "encaranguejada": "encaranguejar",
    "encaranguejadas": "encaranguejar",
    "encaranguejado": "encaranguejar",
    "encaranguejados": "encaranguejar",
    "encaranguejai": "encaranguejar",
    "encaranguejais": "encaranguejar",
    "encaranguejam": "encaranguejar",
    "encaranguejamo": "encaranguejar",
    "encaranguejamos": "encaranguejar",
    "encaranguejando": "encaranguejar",
    "encaranguejara": "encaranguejar",
    "encaranguejaram": "encaranguejar",
    "encaranguejaras": "encaranguejar",
    "encaranguejarde": "encaranguejar",
    "encaranguejardes": "encaranguejar",
    "encaranguejare": "encaranguejar",
    "encaranguejarei": "encaranguejar",
    "encaranguejareis": "encaranguejar",
    "encaranguejarem": "encaranguejar",
    "encaranguejaremos": "encaranguejar",
    "encaranguejares": "encaranguejar",
    "encaranguejaria": "encaranguejar",
    "encaranguejariam": "encaranguejar",
    "encaranguejarias": "encaranguejar",
    "encaranguejarmo": "encaranguejar",
    "encaranguejarmos": "encaranguejar",
    "encaranguejará": "encaranguejar",
    "encaranguejarás": "encaranguejar",
    "encaranguejarão": "encaranguejar",
    "encaranguejaríamos": "encaranguejar",
    "encaranguejaríeis": "encaranguejar",
    "encaranguejas": "encaranguejar",
    "encaranguejasse": "encaranguejar",
    "encaranguejassem": "encaranguejar",
    "encaranguejasses": "encaranguejar",
    "encaranguejaste": "encaranguejar",
    "encaranguejastes": "encaranguejar",
    "encaranguejava": "encaranguejar",
    "encaranguejavam": "encaranguejar",
    "encaranguejavas": "encaranguejar",
    "encarangueje": "encaranguejar",
    "encaranguejei": "encaranguejar",
    "encaranguejeis": "encaranguejar",
    "encaranguejem": "encaranguejar",
    "encaranguejemo": "encaranguejar",
    "encaranguejemos": "encaranguejar",
    "encaranguejes": "encaranguejar",
    "encaranguejo": "encaranguejar",
    "encaranguejou": "encaranguejar",
    "encaranguejá": "encaranguejar",
    "encaranguejámo": "encaranguejar",
    "encaranguejámos": "encaranguejar",
    "encaranguejáramo": "encaranguejar",
    "encaranguejáramos": "encaranguejar",
    "encaranguejárei": "encaranguejar",
    "encaranguejáreis": "encaranguejar",
    "encaranguejásseis": "encaranguejar",
    "encaranguejássemos": "encaranguejar",
    "encaranguejávamo": "encaranguejar",
    "encaranguejávamos": "encaranguejar",
    "encaranguejávei": "encaranguejar",
    "encaranguejáveis": "encaranguejar",
    "encaranguem": "encarangar",
    "encaranguemo": "encarangar",
    "encaranguemos": "encarangar",
    "encarangues": "encarangar",
    "encarangámo": "encarangar",
    "encarangámos": "encarangar",
    "encarangáramo": "encarangar",
    "encarangáramos": "encarangar",
    "encarangáreis": "encarangar",
    "encarangásseis": "encarangar",
    "encarangássemos": "encarangar",
    "encarangávamo": "encarangar",
    "encarangávamos": "encarangar",
    "encarangáveis": "encarangar",
    "encarapela": "encarapelar",
    "encarapelada": "encarapelar",
    "encarapeladas": "encarapelar",
    "encarapelado": "encarapelar",
    "encarapelados": "encarapelar",
    "encarapelai": "encarapelar",
    "encarapelais": "encarapelar",
    "encarapelam": "encarapelar",
    "encarapelamo": "encarapelar",
    "encarapelamos": "encarapelar",
    "encarapelando": "encarapelar",
    "encarapelara": "encarapelar",
    "encarapelaram": "encarapelar",
    "encarapelaras": "encarapelar",
    "encarapelarde": "encarapelar",
    "encarapelardes": "encarapelar",
    "encarapelare": "encarapelar",
    "encarapelarei": "encarapelar",
    "encarapelareis": "encarapelar",
    "encarapelarem": "encarapelar",
    "encarapelaremos": "encarapelar",
    "encarapelares": "encarapelar",
    "encarapelaria": "encarapelar",
    "encarapelariam": "encarapelar",
    "encarapelarias": "encarapelar",
    "encarapelarmo": "encarapelar",
    "encarapelarmos": "encarapelar",
    "encarapelará": "encarapelar",
    "encarapelarás": "encarapelar",
    "encarapelarão": "encarapelar",
    "encarapelaríamos": "encarapelar",
    "encarapelaríeis": "encarapelar",
    "encarapelas": "encarapelar",
    "encarapelasse": "encarapelar",
    "encarapelassem": "encarapelar",
    "encarapelasses": "encarapelar",
    "encarapelaste": "encarapelar",
    "encarapelastes": "encarapelar",
    "encarapelava": "encarapelar",
    "encarapelavam": "encarapelar",
    "encarapelavas": "encarapelar",
    "encarapele": "encarapelar",
    "encarapelei": "encarapelar",
    "encarapeleis": "encarapelar",
    "encarapelem": "encarapelar",
    "encarapelemo": "encarapelar",
    "encarapelemos": "encarapelar",
    "encarapeles": "encarapelar",
    "encarapelo": "encarapelar",
    "encarapelou": "encarapelar",
    "encarapelá": "encarapelar",
    "encarapelámo": "encarapelar",
    "encarapelámos": "encarapelar",
    "encarapeláramo": "encarapelar",
    "encarapeláramos": "encarapelar",
    "encarapelárei": "encarapelar",
    "encarapeláreis": "encarapelar",
    "encarapelásseis": "encarapelar",
    "encarapelássemos": "encarapelar",
    "encarapelávamo": "encarapelar",
    "encarapelávamos": "encarapelar",
    "encarapelávei": "encarapelar",
    "encarapeláveis": "encarapelar",
    "encarapinha": "encarapinhar",
    "encarapinhada": "encarapinhar",
    "encarapinhadas": "encarapinhar",
    "encarapinhado": "encarapinhar",
    "encarapinhados": "encarapinhar",
    "encarapinhai": "encarapinhar",
    "encarapinhais": "encarapinhar",
    "encarapinham": "encarapinhar",
    "encarapinhamo": "encarapinhar",
    "encarapinhamos": "encarapinhar",
    "encarapinhando": "encarapinhar",
    "encarapinhara": "encarapinhar",
    "encarapinharam": "encarapinhar",
    "encarapinharas": "encarapinhar",
    "encarapinharde": "encarapinhar",
    "encarapinhardes": "encarapinhar",
    "encarapinhare": "encarapinhar",
    "encarapinharei": "encarapinhar",
    "encarapinhareis": "encarapinhar",
    "encarapinharem": "encarapinhar",
    "encarapinharemos": "encarapinhar",
    "encarapinhares": "encarapinhar",
    "encarapinharia": "encarapinhar",
    "encarapinhariam": "encarapinhar",
    "encarapinharias": "encarapinhar",
    "encarapinharmo": "encarapinhar",
    "encarapinharmos": "encarapinhar",
    "encarapinhará": "encarapinhar",
    "encarapinharás": "encarapinhar",
    "encarapinharão": "encarapinhar",
    "encarapinharíamos": "encarapinhar",
    "encarapinharíeis": "encarapinhar",
    "encarapinhas": "encarapinhar",
    "encarapinhasse": "encarapinhar",
    "encarapinhassem": "encarapinhar",
    "encarapinhasses": "encarapinhar",
    "encarapinhaste": "encarapinhar",
    "encarapinhastes": "encarapinhar",
    "encarapinhava": "encarapinhar",
    "encarapinhavam": "encarapinhar",
    "encarapinhavas": "encarapinhar",
    "encarapinhe": "encarapinhar",
    "encarapinhei": "encarapinhar",
    "encarapinheis": "encarapinhar",
    "encarapinhem": "encarapinhar",
    "encarapinhemo": "encarapinhar",
    "encarapinhemos": "encarapinhar",
    "encarapinhes": "encarapinhar",
    "encarapinho": "encarapinhar",
    "encarapinhou": "encarapinhar",
    "encarapinhá": "encarapinhar",
    "encarapinhámo": "encarapinhar",
    "encarapinhámos": "encarapinhar",
    "encarapinháramo": "encarapinhar",
    "encarapinháramos": "encarapinhar",
    "encarapinhárei": "encarapinhar",
    "encarapinháreis": "encarapinhar",
    "encarapinhásseis": "encarapinhar",
    "encarapinhássemos": "encarapinhar",
    "encarapinhávamo": "encarapinhar",
    "encarapinhávamos": "encarapinhar",
    "encarapinhávei": "encarapinhar",
    "encarapinháveis": "encarapinhar",
    "encarapuce": "encarapuçar",
    "encarapucei": "encarapuçar",
    "encarapuceis": "encarapuçar",
    "encarapucem": "encarapuçar",
    "encarapucemo": "encarapuçar",
    "encarapucemos": "encarapuçar",
    "encarapuces": "encarapuçar",
    "encarapuça": "encarapuçar",
    "encarapuçada": "encarapuçar",
    "encarapuçadas": "encarapuçar",
    "encarapuçado": "encarapuçar",
    "encarapuçados": "encarapuçar",
    "encarapuçai": "encarapuçar",
    "encarapuçais": "encarapuçar",
    "encarapuçam": "encarapuçar",
    "encarapuçamo": "encarapuçar",
    "encarapuçamos": "encarapuçar",
    "encarapuçando": "encarapuçar",
    "encarapuçara": "encarapuçar",
    "encarapuçaram": "encarapuçar",
    "encarapuçaras": "encarapuçar",
    "encarapuçarde": "encarapuçar",
    "encarapuçardes": "encarapuçar",
    "encarapuçare": "encarapuçar",
    "encarapuçarei": "encarapuçar",
    "encarapuçareis": "encarapuçar",
    "encarapuçarem": "encarapuçar",
    "encarapuçaremos": "encarapuçar",
    "encarapuçares": "encarapuçar",
    "encarapuçaria": "encarapuçar",
    "encarapuçariam": "encarapuçar",
    "encarapuçarias": "encarapuçar",
    "encarapuçarmo": "encarapuçar",
    "encarapuçarmos": "encarapuçar",
    "encarapuçará": "encarapuçar",
    "encarapuçarás": "encarapuçar",
    "encarapuçarão": "encarapuçar",
    "encarapuçaríamos": "encarapuçar",
    "encarapuçaríeis": "encarapuçar",
    "encarapuças": "encarapuçar",
    "encarapuçasse": "encarapuçar",
    "encarapuçassem": "encarapuçar",
    "encarapuçasses": "encarapuçar",
    "encarapuçaste": "encarapuçar",
    "encarapuçastes": "encarapuçar",
    "encarapuçava": "encarapuçar",
    "encarapuçavam": "encarapuçar",
    "encarapuçavas": "encarapuçar",
    "encarapuço": "encarapuçar",
    "encarapuçou": "encarapuçar",
    "encarapuçá": "encarapuçar",
    "encarapuçámo": "encarapuçar",
    "encarapuçámos": "encarapuçar",
    "encarapuçáramo": "encarapuçar",
    "encarapuçáramos": "encarapuçar",
    "encarapuçárei": "encarapuçar",
    "encarapuçáreis": "encarapuçar",
    "encarapuçásseis": "encarapuçar",
    "encarapuçássemos": "encarapuçar",
    "encarapuçávamo": "encarapuçar",
    "encarapuçávamos": "encarapuçar",
    "encarapuçávei": "encarapuçar",
    "encarapuçáveis": "encarapuçar",
    "encarara": "encarar",
    "encararam": "encarar",
    "encararas": "encarar",
    "encararde": "encarar",
    "encarardes": "encarar",
    "encarare": "encarar",
    "encararei": "encarar",
    "encarareis": "encarar",
    "encararem": "encarar",
    "encararemos": "encarar",
    "encarares": "encarar",
    "encararia": "encarar",
    "encarariam": "encarar",
    "encararias": "encarar",
    "encararmo": "encarar",
    "encararmos": "encarar",
    "encarará": "encarar",
    "encararás": "encarar",
    "encararão": "encarar",
    "encararíamos": "encarar",
    "encararíeis": "encarar",
    "encaras": "encarar",
    "encarasse": "encarar",
    "encarassem": "encarar",
    "encarasses": "encarar",
    "encaraste": "encarar",
    "encarastes": "encarar",
    "encarava": "encarar",
    "encaravam": "encarar",
    "encaravas": "encarar",
    "encaravelha": "encaravelhar",
    "encaravelhada": "encaravelhar",
    "encaravelhadas": "encaravelhar",
    "encaravelhado": "encaravelhar",
    "encaravelhados": "encaravelhar",
    "encaravelhai": "encaravelhar",
    "encaravelhais": "encaravelhar",
    "encaravelham": "encaravelhar",
    "encaravelhamo": "encaravelhar",
    "encaravelhamos": "encaravelhar",
    "encaravelhando": "encaravelhar",
    "encaravelhara": "encaravelhar",
    "encaravelharam": "encaravelhar",
    "encaravelharas": "encaravelhar",
    "encaravelharde": "encaravelhar",
    "encaravelhardes": "encaravelhar",
    "encaravelhare": "encaravelhar",
    "encaravelharei": "encaravelhar",
    "encaravelhareis": "encaravelhar",
    "encaravelharem": "encaravelhar",
    "encaravelharemos": "encaravelhar",
    "encaravelhares": "encaravelhar",
    "encaravelharia": "encaravelhar",
    "encaravelhariam": "encaravelhar",
    "encaravelharias": "encaravelhar",
    "encaravelharmo": "encaravelhar",
    "encaravelharmos": "encaravelhar",
    "encaravelhará": "encaravelhar",
    "encaravelharás": "encaravelhar",
    "encaravelharão": "encaravelhar",
    "encaravelharíamos": "encaravelhar",
    "encaravelharíeis": "encaravelhar",
    "encaravelhas": "encaravelhar",
    "encaravelhasse": "encaravelhar",
    "encaravelhassem": "encaravelhar",
    "encaravelhasses": "encaravelhar",
    "encaravelhaste": "encaravelhar",
    "encaravelhastes": "encaravelhar",
    "encaravelhava": "encaravelhar",
    "encaravelhavam": "encaravelhar",
    "encaravelhavas": "encaravelhar",
    "encaravelhe": "encaravelhar",
    "encaravelhei": "encaravelhar",
    "encaravelheis": "encaravelhar",
    "encaravelhem": "encaravelhar",
    "encaravelhemo": "encaravelhar",
    "encaravelhemos": "encaravelhar",
    "encaravelhes": "encaravelhar",
    "encaravelho": "encaravelhar",
    "encaravelhou": "encaravelhar",
    "encaravelhá": "encaravelhar",
    "encaravelhámo": "encaravelhar",
    "encaravelhámos": "encaravelhar",
    "encaravelháramo": "encaravelhar",
    "encaravelháramos": "encaravelhar",
    "encaravelhárei": "encaravelhar",
    "encaravelháreis": "encaravelhar",
    "encaravelhásseis": "encaravelhar",
    "encaravelhássemos": "encaravelhar",
    "encaravelhávamo": "encaravelhar",
    "encaravelhávamos": "encaravelhar",
    "encaravelhávei": "encaravelhar",
    "encaravelháveis": "encaravelhar",
    "encarcera": "encarcerar",
    "encarcerada": "encarcerar",
    "encarceradas": "encarcerar",
    "encarcerado": "encarcerar",
    "encarcerados": "encarcerar",
    "encarcerai": "encarcerar",
    "encarcerais": "encarcerar",
    "encarceram": "encarcerar",
    "encarceramentos": "encarceramento",
    "encarceramo": "encarcerar",
    "encarceramos": "encarcerar",
    "encarcerando": "encarcerar",
    "encarcerara": "encarcerar",
    "encarceraram": "encarcerar",
    "encarceraras": "encarcerar",
    "encarcerarde": "encarcerar",
    "encarcerardes": "encarcerar",
    "encarcerare": "encarcerar",
    "encarcerarei": "encarcerar",
    "encarcerareis": "encarcerar",
    "encarcerarem": "encarcerar",
    "encarceraremos": "encarcerar",
    "encarcerares": "encarcerar",
    "encarceraria": "encarcerar",
    "encarcerariam": "encarcerar",
    "encarcerarias": "encarcerar",
    "encarcerarmo": "encarcerar",
    "encarcerarmos": "encarcerar",
    "encarcerará": "encarcerar",
    "encarcerarás": "encarcerar",
    "encarcerarão": "encarcerar",
    "encarceraríamos": "encarcerar",
    "encarceraríeis": "encarcerar",
    "encarceras": "encarcerar",
    "encarcerasse": "encarcerar",
    "encarcerassem": "encarcerar",
    "encarcerasses": "encarcerar",
    "encarceraste": "encarcerar",
    "encarcerastes": "encarcerar",
    "encarcerava": "encarcerar",
    "encarceravam": "encarcerar",
    "encarceravas": "encarcerar",
    "encarcerações": "encarceração",
    "encarcere": "encarcerar",
    "encarcerei": "encarcerar",
    "encarcereis": "encarcerar",
    "encarcerem": "encarcerar",
    "encarceremo": "encarcerar",
    "encarceremos": "encarcerar",
    "encarceres": "encarcerar",
    "encarcero": "encarcerar",
    "encarcerou": "encarcerar",
    "encarcerá": "encarcerar",
    "encarcerámo": "encarcerar",
    "encarcerámos": "encarcerar",
    "encarceráramo": "encarcerar",
    "encarceráramos": "encarcerar",
    "encarcerárei": "encarcerar",
    "encarceráreis": "encarcerar",
    "encarcerásseis": "encarcerar",
    "encarcerássemos": "encarcerar",
    "encarcerávamo": "encarcerar",
    "encarcerávamos": "encarcerar",
    "encarcerávei": "encarcerar",
    "encarceráveis": "encarcerar",
    "encarda": "encardir",
    "encardais": "encardir",
    "encardam": "encardir",
    "encardamo": "encardir",
    "encardamos": "encardir",
    "encardas": "encardir",
    "encarde": "encardir",
    "encardem": "encardir",
    "encardes": "encardir",
    "encardi": "encardir",
    "encardia": "encardir",
    "encardiam": "encardir",
    "encardias": "encardir",
    "encardida": "encardir",
    "encardidas": "encardir",
    "encardido": "encardir",
    "encardidos": "encardir",
    "encardimentos": "encardimento",
    "encardimo": "encardir",
    "encardimos": "encardir",
    "encardindo": "encardir",
    "encardira": "encardir",
    "encardiram": "encardir",
    "encardiras": "encardir",
    "encardirde": "encardir",
    "encardirdes": "encardir",
    "encardire": "encardir",
    "encardirei": "encardir",
    "encardireis": "encardir",
    "encardirem": "encardir",
    "encardiremos": "encardir",
    "encardires": "encardir",
    "encardiria": "encardir",
    "encardiriam": "encardir",
    "encardirias": "encardir",
    "encardirmo": "encardir",
    "encardirmos": "encardir",
    "encardirá": "encardir",
    "encardirás": "encardir",
    "encardirão": "encardir",
    "encardiríamos": "encardir",
    "encardiríeis": "encardir",
    "encardis": "encardir",
    "encardisse": "encardir",
    "encardissem": "encardir",
    "encardisses": "encardir",
    "encardiste": "encardir",
    "encardistes": "encardir",
    "encardiu": "encardir",
    "encardo": "encardir",
    "encardíamo": "encardir",
    "encardíamos": "encardir",
    "encardíei": "encardir",
    "encardíeis": "encardir",
    "encardíramo": "encardir",
    "encardíramos": "encardir",
    "encardírei": "encardir",
    "encardíreis": "encardir",
    "encardísseis": "encardir",
    "encardíssemos": "encardir",
    "encare": "encarar",
    "encarece": "encarecer",
    "encarecedora": "encarecedor",
    "encarecedoras": "encarecedor",
    "encarecedores": "encarecedor",
    "encarecei": "encarecer",
    "encareceis": "encarecer",
    "encarecem": "encarecer",
    "encarecemo": "encarecer",
    "encarecemos": "encarecer",
    "encarecendo": "encarecer",
    "encarecera": "encarecer",
    "encareceram": "encarecer",
    "encareceras": "encarecer",
    "encarecerde": "encarecer",
    "encarecerdes": "encarecer",
    "encarecere": "encarecer",
    "encarecerei": "encarecer",
    "encarecereis": "encarecer",
    "encarecerem": "encarecer",
    "encareceremos": "encarecer",
    "encareceres": "encarecer",
    "encareceria": "encarecer",
    "encareceriam": "encarecer",
    "encarecerias": "encarecer",
    "encarecermo": "encarecer",
    "encarecermos": "encarecer",
    "encarecerá": "encarecer",
    "encarecerás": "encarecer",
    "encarecerão": "encarecer",
    "encareceríamos": "encarecer",
    "encareceríeis": "encarecer",
    "encareces": "encarecer",
    "encarecesse": "encarecer",
    "encarecessem": "encarecer",
    "encarecesses": "encarecer",
    "encareceste": "encarecer",
    "encarecestes": "encarecer",
    "encareceu": "encarecer",
    "encareci": "encarecer",
    "encarecia": "encarecer",
    "encareciam": "encarecer",
    "encarecias": "encarecer",
    "encarecida": "encarecido",
    "encarecidas": "encarecido",
    "encarecido": "encarecer",
    "encarecidos": "encarecido",
    "encarecimentos": "encarecimento",
    "encarecê": "encarecer",
    "encarecêramo": "encarecer",
    "encarecêramos": "encarecer",
    "encarecêrei": "encarecer",
    "encarecêreis": "encarecer",
    "encarecêsseis": "encarecer",
    "encarecêssemos": "encarecer",
    "encarecíamo": "encarecer",
    "encarecíamos": "encarecer",
    "encarecíei": "encarecer",
    "encarecíeis": "encarecer",
    "encarei": "encarar",
    "encareis": "encarar",
    "encarem": "encarar",
    "encaremo": "encarar",
    "encaremos": "encarar",
    "encares": "encarar",
    "encareta": "encaretar",
    "encaretada": "encaretar",
    "encaretadas": "encaretar",
    "encaretado": "encaretar",
    "encaretados": "encaretar",
    "encaretai": "encaretar",
    "encaretais": "encaretar",
    "encaretam": "encaretar",
    "encaretamo": "encaretar",
    "encaretamos": "encaretar",
    "encaretando": "encaretar",
    "encaretara": "encaretar",
    "encaretaram": "encaretar",
    "encaretaras": "encaretar",
    "encaretarde": "encaretar",
    "encaretardes": "encaretar",
    "encaretare": "encaretar",
    "encaretarei": "encaretar",
    "encaretareis": "encaretar",
    "encaretarem": "encaretar",
    "encaretaremos": "encaretar",
    "encaretares": "encaretar",
    "encaretaria": "encaretar",
    "encaretariam": "encaretar",
    "encaretarias": "encaretar",
    "encaretarmo": "encaretar",
    "encaretarmos": "encaretar",
    "encaretará": "encaretar",
    "encaretarás": "encaretar",
    "encaretarão": "encaretar",
    "encaretaríamos": "encaretar",
    "encaretaríeis": "encaretar",
    "encaretas": "encaretar",
    "encaretasse": "encaretar",
    "encaretassem": "encaretar",
    "encaretasses": "encaretar",
    "encaretaste": "encaretar",
    "encaretastes": "encaretar",
    "encaretava": "encaretar",
    "encaretavam": "encaretar",
    "encaretavas": "encaretar",
    "encarete": "encaretar",
    "encaretei": "encaretar",
    "encareteis": "encaretar",
    "encaretem": "encaretar",
    "encaretemo": "encaretar",
    "encaretemos": "encaretar",
    "encaretes": "encaretar",
    "encareto": "encaretar",
    "encaretou": "encaretar",
    "encaretá": "encaretar",
    "encaretámo": "encaretar",
    "encaretámos": "encaretar",
    "encaretáramo": "encaretar",
    "encaretáramos": "encaretar",
    "encaretárei": "encaretar",
    "encaretáreis": "encaretar",
    "encaretásseis": "encaretar",
    "encaretássemos": "encaretar",
    "encaretávamo": "encaretar",
    "encaretávamos": "encaretar",
    "encaretávei": "encaretar",
    "encaretáveis": "encaretar",
    "encareça": "encarecer",
    "encareçais": "encarecer",
    "encareçam": "encarecer",
    "encareçamo": "encarecer",
    "encareçamos": "encarecer",
    "encareças": "encarecer",
    "encareço": "encarecer",
    "encarga": "encargar",
    "encargada": "encargar",
    "encargadas": "encargar",
    "encargado": "encargar",
    "encargados": "encargar",
    "encargai": "encargar",
    "encargais": "encargar",
    "encargam": "encargar",
    "encargamo": "encargar",
    "encargamos": "encargar",
    "encargando": "encargar",
    "encargara": "encargar",
    "encargaram": "encargar",
    "encargaras": "encargar",
    "encargarde": "encargar",
    "encargardes": "encargar",
    "encargare": "encargar",
    "encargarei": "encargar",
    "encargareis": "encargar",
    "encargarem": "encargar",
    "encargaremos": "encargar",
    "encargares": "encargar",
    "encargaria": "encargar",
    "encargariam": "encargar",
    "encargarias": "encargar",
    "encargarmo": "encargar",
    "encargarmos": "encargar",
    "encargará": "encargar",
    "encargarás": "encargar",
    "encargarão": "encargar",
    "encargaríamos": "encargar",
    "encargaríeis": "encargar",
    "encargas": "encargar",
    "encargasse": "encargar",
    "encargassem": "encargar",
    "encargasses": "encargar",
    "encargaste": "encargar",
    "encargastes": "encargar",
    "encargava": "encargar",
    "encargavam": "encargar",
    "encargavas": "encargar",
    "encargo": "encargar",
    "encargos": "encargo",
    "encargou": "encargar",
    "encargue": "encargar",
    "encarguei": "encargar",
    "encargueis": "encargar",
    "encarguem": "encargar",
    "encarguemo": "encargar",
    "encarguemos": "encargar",
    "encargues": "encargar",
    "encargá": "encargar",
    "encargámo": "encargar",
    "encargámos": "encargar",
    "encargáramo": "encargar",
    "encargáramos": "encargar",
    "encargárei": "encargar",
    "encargáreis": "encargar",
    "encargásseis": "encargar",
    "encargássemos": "encargar",
    "encargávamo": "encargar",
    "encargávamos": "encargar",
    "encargávei": "encargar",
    "encargáveis": "encargar",
    "encarna": "encarnar",
    "encarnada": "encarnar",
    "encarnadas": "encarnar",
    "encarnado": "encarnar",
    "encarnados": "encarnar",
    "encarnai": "encarnar",
    "encarnais": "encarnar",
    "encarnam": "encarnar",
    "encarnamo": "encarnar",
    "encarnamos": "encarnar",
    "encarnando": "encarnar",
    "encarnara": "encarnar",
    "encarnaram": "encarnar",
    "encarnaras": "encarnar",
    "encarnarde": "encarnar",
    "encarnardes": "encarnar",
    "encarnare": "encarnar",
    "encarnarei": "encarnar",
    "encarnareis": "encarnar",
    "encarnarem": "encarnar",
    "encarnaremos": "encarnar",
    "encarnares": "encarnar",
    "encarnaria": "encarnar",
    "encarnariam": "encarnar",
    "encarnarias": "encarnar",
    "encarnarmo": "encarnar",
    "encarnarmos": "encarnar",
    "encarnará": "encarnar",
    "encarnarás": "encarnar",
    "encarnarão": "encarnar",
    "encarnaríamos": "encarnar",
    "encarnaríeis": "encarnar",
    "encarnas": "encarnar",
    "encarnasse": "encarnar",
    "encarnassem": "encarnar",
    "encarnasses": "encarnar",
    "encarnaste": "encarnar",
    "encarnastes": "encarnar",
    "encarnava": "encarnar",
    "encarnavam": "encarnar",
    "encarnavas": "encarnar",
    "encarnações": "encarnação",
    "encarne": "encarnar",
    "encarnei": "encarnar",
    "encarneira": "encarneirar",
    "encarneirada": "encarneirar",
    "encarneiradas": "encarneirar",
    "encarneirado": "encarneirar",
    "encarneirados": "encarneirar",
    "encarneirai": "encarneirar",
    "encarneirais": "encarneirar",
    "encarneiram": "encarneirar",
    "encarneiramo": "encarneirar",
    "encarneiramos": "encarneirar",
    "encarneirando": "encarneirar",
    "encarneirara": "encarneirar",
    "encarneiraram": "encarneirar",
    "encarneiraras": "encarneirar",
    "encarneirardes": "encarneirar",
    "encarneirarei": "encarneirar",
    "encarneirareis": "encarneirar",
    "encarneirarem": "encarneirar",
    "encarneiraremos": "encarneirar",
    "encarneirares": "encarneirar",
    "encarneiraria": "encarneirar",
    "encarneirariam": "encarneirar",
    "encarneirarias": "encarneirar",
    "encarneirarmo": "encarneirar",
    "encarneirarmos": "encarneirar",
    "encarneirará": "encarneirar",
    "encarneirarás": "encarneirar",
    "encarneirarão": "encarneirar",
    "encarneiraríamos": "encarneirar",
    "encarneiraríeis": "encarneirar",
    "encarneiras": "encarneirar",
    "encarneirasse": "encarneirar",
    "encarneirassem": "encarneirar",
    "encarneirasses": "encarneirar",
    "encarneiraste": "encarneirar",
    "encarneirastes": "encarneirar",
    "encarneirava": "encarneirar",
    "encarneiravam": "encarneirar",
    "encarneiravas": "encarneirar",
    "encarneire": "encarneirar",
    "encarneirei": "encarneirar",
    "encarneireis": "encarneirar",
    "encarneirem": "encarneirar",
    "encarneiremo": "encarneirar",
    "encarneiremos": "encarneirar",
    "encarneires": "encarneirar",
    "encarneiro": "encarneirar",
    "encarneirou": "encarneirar",
    "encarneirámo": "encarneirar",
    "encarneirámos": "encarneirar",
    "encarneiráramo": "encarneirar",
    "encarneiráramos": "encarneirar",
    "encarneiráreis": "encarneirar",
    "encarneirásseis": "encarneirar",
    "encarneirássemos": "encarneirar",
    "encarneirávamo": "encarneirar",
    "encarneirávamos": "encarneirar",
    "encarneiráveis": "encarneirar",
    "encarneis": "encarnar",
    "encarnem": "encarnar",
    "encarnemo": "encarnar",
    "encarnemos": "encarnar",
    "encarnes": "encarne",
    "encarnice": "encarniçar",
    "encarnicei": "encarniçar",
    "encarniceis": "encarniçar",
    "encarnicem": "encarniçar",
    "encarnicemo": "encarniçar",
    "encarnicemos": "encarniçar",
    "encarnices": "encarniçar",
    "encarniça": "encarniçar",
    "encarniçada": "encarniçar",
    "encarniçadas": "encarniçar",
    "encarniçado": "encarniçar",
    "encarniçados": "encarniçar",
    "encarniçai": "encarniçar",
    "encarniçais": "encarniçar",
    "encarniçam": "encarniçar",
    "encarniçamentos": "encarniçamento",
    "encarniçamo": "encarniçar",
    "encarniçamos": "encarniçar",
    "encarniçando": "encarniçar",
    "encarniçara": "encarniçar",
    "encarniçaram": "encarniçar",
    "encarniçaras": "encarniçar",
    "encarniçarde": "encarniçar",
    "encarniçardes": "encarniçar",
    "encarniçare": "encarniçar",
    "encarniçarei": "encarniçar",
    "encarniçareis": "encarniçar",
    "encarniçarem": "encarniçar",
    "encarniçaremos": "encarniçar",
    "encarniçares": "encarniçar",
    "encarniçaria": "encarniçar",
    "encarniçariam": "encarniçar",
    "encarniçarias": "encarniçar",
    "encarniçarmo": "encarniçar",
    "encarniçarmos": "encarniçar",
    "encarniçará": "encarniçar",
    "encarniçarás": "encarniçar",
    "encarniçarão": "encarniçar",
    "encarniçaríamos": "encarniçar",
    "encarniçaríeis": "encarniçar",
    "encarniças": "encarniçar",
    "encarniçasse": "encarniçar",
    "encarniçassem": "encarniçar",
    "encarniçasses": "encarniçar",
    "encarniçaste": "encarniçar",
    "encarniçastes": "encarniçar",
    "encarniçava": "encarniçar",
    "encarniçavam": "encarniçar",
    "encarniçavas": "encarniçar",
    "encarniço": "encarniçar",
    "encarniçou": "encarniçar",
    "encarniçá": "encarniçar",
    "encarniçámo": "encarniçar",
    "encarniçámos": "encarniçar",
    "encarniçáramo": "encarniçar",
    "encarniçáramos": "encarniçar",
    "encarniçárei": "encarniçar",
    "encarniçáreis": "encarniçar",
    "encarniçásseis": "encarniçar",
    "encarniçássemos": "encarniçar",
    "encarniçávamo": "encarniçar",
    "encarniçávamos": "encarniçar",
    "encarniçávei": "encarniçar",
    "encarniçáveis": "encarniçar",
    "encarno": "encarnar",
    "encarnou": "encarnar",
    "encarná": "encarnar",
    "encarnámo": "encarnar",
    "encarnámos": "encarnar",
    "encarnáramo": "encarnar",
    "encarnáramos": "encarnar",
    "encarnárei": "encarnar",
    "encarnáreis": "encarnar",
    "encarnásseis": "encarnar",
    "encarnássemos": "encarnar",
    "encarnávamo": "encarnar",
    "encarnávamos": "encarnar",
    "encarnávei": "encarnar",
    "encarnáveis": "encarnar",
    "encaro": "encarar",
    "encaroce": "encaroçar",
    "encarocei": "encaroçar",
    "encaroceis": "encaroçar",
    "encarocem": "encaroçar",
    "encarocemo": "encaroçar",
    "encarocemos": "encaroçar",
    "encaroces": "encaroçar",
    "encarocha": "encarochar",
    "encarochada": "encarochar",
    "encarochadas": "encarochar",
    "encarochado": "encarochar",
    "encarochados": "encarochar",
    "encarochai": "encarochar",
    "encarochais": "encarochar",
    "encarocham": "encarochar",
    "encarochamo": "encarochar",
    "encarochamos": "encarochar",
    "encarochando": "encarochar",
    "encarochara": "encarochar",
    "encarocharam": "encarochar",
    "encarocharas": "encarochar",
    "encarocharde": "encarochar",
    "encarochardes": "encarochar",
    "encarochare": "encarochar",
    "encarocharei": "encarochar",
    "encarochareis": "encarochar",
    "encarocharem": "encarochar",
    "encarocharemos": "encarochar",
    "encarochares": "encarochar",
    "encarocharia": "encarochar",
    "encarochariam": "encarochar",
    "encarocharias": "encarochar",
    "encarocharmo": "encarochar",
    "encarocharmos": "encarochar",
    "encarochará": "encarochar",
    "encarocharás": "encarochar",
    "encarocharão": "encarochar",
    "encarocharíamos": "encarochar",
    "encarocharíeis": "encarochar",
    "encarochas": "encarochar",
    "encarochasse": "encarochar",
    "encarochassem": "encarochar",
    "encarochasses": "encarochar",
    "encarochaste": "encarochar",
    "encarochastes": "encarochar",
    "encarochava": "encarochar",
    "encarochavam": "encarochar",
    "encarochavas": "encarochar",
    "encaroche": "encarochar",
    "encarochei": "encarochar",
    "encarocheis": "encarochar",
    "encarochem": "encarochar",
    "encarochemo": "encarochar",
    "encarochemos": "encarochar",
    "encaroches": "encarochar",
    "encarocho": "encarochar",
    "encarochou": "encarochar",
    "encarochá": "encarochar",
    "encarochámo": "encarochar",
    "encarochámos": "encarochar",
    "encarocháramo": "encarochar",
    "encarocháramos": "encarochar",
    "encarochárei": "encarochar",
    "encarocháreis": "encarochar",
    "encarochásseis": "encarochar",
    "encarochássemos": "encarochar",
    "encarochávamo": "encarochar",
    "encarochávamos": "encarochar",
    "encarochávei": "encarochar",
    "encarocháveis": "encarochar",
    "encarola": "encarolar",
    "encarolada": "encarolar",
    "encaroladas": "encarolar",
    "encaroladeiras": "encaroladeira",
    "encarolado": "encarolar",
    "encarolados": "encarolar",
    "encarolai": "encarolar",
    "encarolais": "encarolar",
    "encarolam": "encarolar",
    "encarolamo": "encarolar",
    "encarolamos": "encarolar",
    "encarolando": "encarolar",
    "encarolara": "encarolar",
    "encarolaram": "encarolar",
    "encarolaras": "encarolar",
    "encarolarde": "encarolar",
    "encarolardes": "encarolar",
    "encarolare": "encarolar",
    "encarolarei": "encarolar",
    "encarolareis": "encarolar",
    "encarolarem": "encarolar",
    "encarolaremos": "encarolar",
    "encarolares": "encarolar",
    "encarolaria": "encarolar",
    "encarolariam": "encarolar",
    "encarolarias": "encarolar",
    "encarolarmo": "encarolar",
    "encarolarmos": "encarolar",
    "encarolará": "encarolar",
    "encarolarás": "encarolar",
    "encarolarão": "encarolar",
    "encarolaríamos": "encarolar",
    "encarolaríeis": "encarolar",
    "encarolas": "encarolar",
    "encarolasse": "encarolar",
    "encarolassem": "encarolar",
    "encarolasses": "encarolar",
    "encarolaste": "encarolar",
    "encarolastes": "encarolar",
    "encarolava": "encarolar",
    "encarolavam": "encarolar",
    "encarolavas": "encarolar",
    "encarole": "encarolar",
    "encarolei": "encarolar",
    "encaroleis": "encarolar",
    "encarolem": "encarolar",
    "encarolemo": "encarolar",
    "encarolemos": "encarolar",
    "encaroles": "encarolar",
    "encarolo": "encarolar",
    "encarolou": "encarolar",
    "encarolá": "encarolar",
    "encarolámo": "encarolar",
    "encarolámos": "encarolar",
    "encaroláramo": "encarolar",
    "encaroláramos": "encarolar",
    "encarolárei": "encarolar",
    "encaroláreis": "encarolar",
    "encarolásseis": "encarolar",
    "encarolássemos": "encarolar",
    "encarolávamo": "encarolar",
    "encarolávamos": "encarolar",
    "encarolávei": "encarolar",
    "encaroláveis": "encarolar",
    "encarou": "encarar",
    "encaroça": "encaroçar",
    "encaroçada": "encaroçar",
    "encaroçadas": "encaroçar",
    "encaroçado": "encaroçar",
    "encaroçados": "encaroçar",
    "encaroçai": "encaroçar",
    "encaroçais": "encaroçar",
    "encaroçam": "encaroçar",
    "encaroçamo": "encaroçar",
    "encaroçamos": "encaroçar",
    "encaroçando": "encaroçar",
    "encaroçara": "encaroçar",
    "encaroçaram": "encaroçar",
    "encaroçaras": "encaroçar",
    "encaroçardes": "encaroçar",
    "encaroçarei": "encaroçar",
    "encaroçareis": "encaroçar",
    "encaroçarem": "encaroçar",
    "encaroçaremos": "encaroçar",
    "encaroçares": "encaroçar",
    "encaroçaria": "encaroçar",
    "encaroçariam": "encaroçar",
    "encaroçarias": "encaroçar",
    "encaroçarmo": "encaroçar",
    "encaroçarmos": "encaroçar",
    "encaroçará": "encaroçar",
    "encaroçarás": "encaroçar",
    "encaroçarão": "encaroçar",
    "encaroçaríamos": "encaroçar",
    "encaroçaríeis": "encaroçar",
    "encaroças": "encaroçar",
    "encaroçasse": "encaroçar",
    "encaroçassem": "encaroçar",
    "encaroçasses": "encaroçar",
    "encaroçaste": "encaroçar",
    "encaroçastes": "encaroçar",
    "encaroçava": "encaroçar",
    "encaroçavam": "encaroçar",
    "encaroçavas": "encaroçar",
    "encaroço": "encaroçar",
    "encaroçou": "encaroçar",
    "encaroçámo": "encaroçar",
    "encaroçámos": "encaroçar",
    "encaroçáramo": "encaroçar",
    "encaroçáramos": "encaroçar",
    "encaroçáreis": "encaroçar",
    "encaroçásseis": "encaroçar",
    "encaroçássemos": "encaroçar",
    "encaroçávamo": "encaroçar",
    "encaroçávamos": "encaroçar",
    "encaroçáveis": "encaroçar",
    "encarquilha": "encarquilhar",
    "encarquilhada": "encarquilhar",
    "encarquilhadas": "encarquilhar",
    "encarquilhado": "encarquilhar",
    "encarquilhados": "encarquilhar",
    "encarquilhai": "encarquilhar",
    "encarquilhais": "encarquilhar",
    "encarquilham": "encarquilhar",
    "encarquilhamentos": "encarquilhamento",
    "encarquilhamo": "encarquilhar",
    "encarquilhamos": "encarquilhar",
    "encarquilhando": "encarquilhar",
    "encarquilhara": "encarquilhar",
    "encarquilharam": "encarquilhar",
    "encarquilharas": "encarquilhar",
    "encarquilharde": "encarquilhar",
    "encarquilhardes": "encarquilhar",
    "encarquilhare": "encarquilhar",
    "encarquilharei": "encarquilhar",
    "encarquilhareis": "encarquilhar",
    "encarquilharem": "encarquilhar",
    "encarquilharemos": "encarquilhar",
    "encarquilhares": "encarquilhar",
    "encarquilharia": "encarquilhar",
    "encarquilhariam": "encarquilhar",
    "encarquilharias": "encarquilhar",
    "encarquilharmo": "encarquilhar",
    "encarquilharmos": "encarquilhar",
    "encarquilhará": "encarquilhar",
    "encarquilharás": "encarquilhar",
    "encarquilharão": "encarquilhar",
    "encarquilharíamos": "encarquilhar",
    "encarquilharíeis": "encarquilhar",
    "encarquilhas": "encarquilhar",
    "encarquilhasse": "encarquilhar",
    "encarquilhassem": "encarquilhar",
    "encarquilhasses": "encarquilhar",
    "encarquilhaste": "encarquilhar",
    "encarquilhastes": "encarquilhar",
    "encarquilhava": "encarquilhar",
    "encarquilhavam": "encarquilhar",
    "encarquilhavas": "encarquilhar",
    "encarquilhe": "encarquilhar",
    "encarquilhei": "encarquilhar",
    "encarquilheis": "encarquilhar",
    "encarquilhem": "encarquilhar",
    "encarquilhemo": "encarquilhar",
    "encarquilhemos": "encarquilhar",
    "encarquilhes": "encarquilhar",
    "encarquilho": "encarquilhar",
    "encarquilhou": "encarquilhar",
    "encarquilhá": "encarquilhar",
    "encarquilhámo": "encarquilhar",
    "encarquilhámos": "encarquilhar",
    "encarquilháramo": "encarquilhar",
    "encarquilháramos": "encarquilhar",
    "encarquilhárei": "encarquilhar",
    "encarquilháreis": "encarquilhar",
    "encarquilhásseis": "encarquilhar",
    "encarquilhássemos": "encarquilhar",
    "encarquilhávamo": "encarquilhar",
    "encarquilhávamos": "encarquilhar",
    "encarquilhávei": "encarquilhar",
    "encarquilháveis": "encarquilhar",
    "encarra": "encarrar",
    "encarrada": "encarrar",
    "encarradas": "encarrar",
    "encarrado": "encarrar",
    "encarradoiros": "encarradoiro",
    "encarrados": "encarrar",
    "encarradouros": "encarradouro",
    "encarrai": "encarrar",
    "encarrais": "encarrar",
    "encarram": "encarrar",
    "encarramo": "encarrar",
    "encarramos": "encarrar",
    "encarranca": "encarrancar",
    "encarrancada": "encarrancar",
    "encarrancadas": "encarrancar",
    "encarrancado": "encarrancar",
    "encarrancados": "encarrancar",
    "encarrancais": "encarrancar",
    "encarrancam": "encarrancar",
    "encarrancamo": "encarrancar",
    "encarrancamos": "encarrancar",
    "encarrancando": "encarrancar",
    "encarrancara": "encarrancar",
    "encarrancaram": "encarrancar",
    "encarrancaras": "encarrancar",
    "encarrancardes": "encarrancar",
    "encarrancarei": "encarrancar",
    "encarrancareis": "encarrancar",
    "encarrancarem": "encarrancar",
    "encarrancaremos": "encarrancar",
    "encarrancares": "encarrancar",
    "encarrancaria": "encarrancar",
    "encarrancariam": "encarrancar",
    "encarrancarias": "encarrancar",
    "encarrancarmo": "encarrancar",
    "encarrancarmos": "encarrancar",
    "encarrancará": "encarrancar",
    "encarrancarás": "encarrancar",
    "encarrancarão": "encarrancar",
    "encarrancaríamos": "encarrancar",
    "encarrancaríeis": "encarrancar",
    "encarrancas": "encarrancar",
    "encarrancasse": "encarrancar",
    "encarrancassem": "encarrancar",
    "encarrancasses": "encarrancar",
    "encarrancaste": "encarrancar",
    "encarrancastes": "encarrancar",
    "encarrancava": "encarrancar",
    "encarrancavam": "encarrancar",
    "encarrancavas": "encarrancar",
    "encarranco": "encarrancar",
    "encarrancou": "encarrancar",
    "encarrancámo": "encarrancar",
    "encarrancámos": "encarrancar",
    "encarrancáramo": "encarrancar",
    "encarrancáramos": "encarrancar",
    "encarrancáreis": "encarrancar",
    "encarrancásseis": "encarrancar",
    "encarrancássemos": "encarrancar",
    "encarrancávamo": "encarrancar",
    "encarrancávamos": "encarrancar",
    "encarrancáveis": "encarrancar",
    "encarrando": "encarrar",
    "encarranque": "encarrancar",
    "encarranquei": "encarrancar",
    "encarranqueis": "encarrancar",
    "encarranquem": "encarrancar",
    "encarranquemos": "encarrancar",
    "encarranques": "encarrancar",
    "encarrapita": "encarrapitar",
    "encarrapitada": "encarrapitar",
    "encarrapitadas": "encarrapitar",
    "encarrapitado": "encarrapitar",
    "encarrapitados": "encarrapitar",
    "encarrapitai": "encarrapitar",
    "encarrapitais": "encarrapitar",
    "encarrapitam": "encarrapitar",
    "encarrapitamo": "encarrapitar",
    "encarrapitamos": "encarrapitar",
    "encarrapitando": "encarrapitar",
    "encarrapitara": "encarrapitar",
    "encarrapitaram": "encarrapitar",
    "encarrapitaras": "encarrapitar",
    "encarrapitarde": "encarrapitar",
    "encarrapitardes": "encarrapitar",
    "encarrapitare": "encarrapitar",
    "encarrapitarei": "encarrapitar",
    "encarrapitareis": "encarrapitar",
    "encarrapitarem": "encarrapitar",
    "encarrapitaremos": "encarrapitar",
    "encarrapitares": "encarrapitar",
    "encarrapitaria": "encarrapitar",
    "encarrapitariam": "encarrapitar",
    "encarrapitarias": "encarrapitar",
    "encarrapitarmo": "encarrapitar",
    "encarrapitarmos": "encarrapitar",
    "encarrapitará": "encarrapitar",
    "encarrapitarás": "encarrapitar",
    "encarrapitarão": "encarrapitar",
    "encarrapitaríamos": "encarrapitar",
    "encarrapitaríeis": "encarrapitar",
    "encarrapitas": "encarrapitar",
    "encarrapitasse": "encarrapitar",
    "encarrapitassem": "encarrapitar",
    "encarrapitasses": "encarrapitar",
    "encarrapitaste": "encarrapitar",
    "encarrapitastes": "encarrapitar",
    "encarrapitava": "encarrapitar",
    "encarrapitavam": "encarrapitar",
    "encarrapitavas": "encarrapitar",
    "encarrapite": "encarrapitar",
    "encarrapitei": "encarrapitar",
    "encarrapiteis": "encarrapitar",
    "encarrapitem": "encarrapitar",
    "encarrapitemo": "encarrapitar",
    "encarrapitemos": "encarrapitar",
    "encarrapites": "encarrapitar",
    "encarrapito": "encarrapitar",
    "encarrapitou": "encarrapitar",
    "encarrapitá": "encarrapitar",
    "encarrapitámo": "encarrapitar",
    "encarrapitámos": "encarrapitar",
    "encarrapitáramo": "encarrapitar",
    "encarrapitáramos": "encarrapitar",
    "encarrapitárei": "encarrapitar",
    "encarrapitáreis": "encarrapitar",
    "encarrapitásseis": "encarrapitar",
    "encarrapitássemos": "encarrapitar",
    "encarrapitávamo": "encarrapitar",
    "encarrapitávamos": "encarrapitar",
    "encarrapitávei": "encarrapitar",
    "encarrapitáveis": "encarrapitar",
    "encarrara": "encarrar",
    "encarraram": "encarrar",
    "encarraras": "encarrar",
    "encarrarde": "encarrar",
    "encarrardes": "encarrar",
    "encarrare": "encarrar",
    "encarrarei": "encarrar",
    "encarrareis": "encarrar",
    "encarrarem": "encarrar",
    "encarraremos": "encarrar",
    "encarrares": "encarrar",
    "encarraria": "encarrar",
    "encarrariam": "encarrar",
    "encarrarias": "encarrar",
    "encarrarmo": "encarrar",
    "encarrarmos": "encarrar",
    "encarrará": "encarrar",
    "encarrarás": "encarrar",
    "encarrarão": "encarrar",
    "encarraríamos": "encarrar",
    "encarraríeis": "encarrar",
    "encarras": "encarrar",
    "encarrasca": "encarrascar",
    "encarrascada": "encarrascar",
    "encarrascadas": "encarrascar",
    "encarrascado": "encarrascar",
    "encarrascados": "encarrascar",
    "encarrascai": "encarrascar",
    "encarrascais": "encarrascar",
    "encarrascam": "encarrascar",
    "encarrascamo": "encarrascar",
    "encarrascamos": "encarrascar",
    "encarrascando": "encarrascar",
    "encarrascara": "encarrascar",
    "encarrascaram": "encarrascar",
    "encarrascaras": "encarrascar",
    "encarrascarde": "encarrascar",
    "encarrascardes": "encarrascar",
    "encarrascare": "encarrascar",
    "encarrascarei": "encarrascar",
    "encarrascareis": "encarrascar",
    "encarrascarem": "encarrascar",
    "encarrascaremos": "encarrascar",
    "encarrascares": "encarrascar",
    "encarrascaria": "encarrascar",
    "encarrascariam": "encarrascar",
    "encarrascarias": "encarrascar",
    "encarrascarmo": "encarrascar",
    "encarrascarmos": "encarrascar",
    "encarrascará": "encarrascar",
    "encarrascarás": "encarrascar",
    "encarrascarão": "encarrascar",
    "encarrascaríamos": "encarrascar",
    "encarrascaríeis": "encarrascar",
    "encarrascas": "encarrascar",
    "encarrascasse": "encarrascar",
    "encarrascassem": "encarrascar",
    "encarrascasses": "encarrascar",
    "encarrascaste": "encarrascar",
    "encarrascastes": "encarrascar",
    "encarrascava": "encarrascar",
    "encarrascavam": "encarrascar",
    "encarrascavas": "encarrascar",
    "encarrasco": "encarrascar",
    "encarrascou": "encarrascar",
    "encarrascá": "encarrascar",
    "encarrascámo": "encarrascar",
    "encarrascámos": "encarrascar",
    "encarrascáramo": "encarrascar",
    "encarrascáramos": "encarrascar",
    "encarrascárei": "encarrascar",
    "encarrascáreis": "encarrascar",
    "encarrascásseis": "encarrascar",
    "encarrascássemos": "encarrascar",
    "encarrascávamo": "encarrascar",
    "encarrascávamos": "encarrascar",
    "encarrascávei": "encarrascar",
    "encarrascáveis": "encarrascar",
    "encarraspana": "encarraspanar",
    "encarraspanada": "encarraspanar",
    "encarraspanadas": "encarraspanar",
    "encarraspanado": "encarraspanar",
    "encarraspanados": "encarraspanar",
    "encarraspanai": "encarraspanar",
    "encarraspanais": "encarraspanar",
    "encarraspanam": "encarraspanar",
    "encarraspanamo": "encarraspanar",
    "encarraspanamos": "encarraspanar",
    "encarraspanando": "encarraspanar",
    "encarraspanara": "encarraspanar",
    "encarraspanaram": "encarraspanar",
    "encarraspanaras": "encarraspanar",
    "encarraspanarde": "encarraspanar",
    "encarraspanardes": "encarraspanar",
    "encarraspanare": "encarraspanar",
    "encarraspanarei": "encarraspanar",
    "encarraspanareis": "encarraspanar",
    "encarraspanarem": "encarraspanar",
    "encarraspanaremos": "encarraspanar",
    "encarraspanares": "encarraspanar",
    "encarraspanaria": "encarraspanar",
    "encarraspanariam": "encarraspanar",
    "encarraspanarias": "encarraspanar",
    "encarraspanarmo": "encarraspanar",
    "encarraspanarmos": "encarraspanar",
    "encarraspanará": "encarraspanar",
    "encarraspanarás": "encarraspanar",
    "encarraspanarão": "encarraspanar",
    "encarraspanaríamos": "encarraspanar",
    "encarraspanaríeis": "encarraspanar",
    "encarraspanas": "encarraspanar",
    "encarraspanasse": "encarraspanar",
    "encarraspanassem": "encarraspanar",
    "encarraspanasses": "encarraspanar",
    "encarraspanaste": "encarraspanar",
    "encarraspanastes": "encarraspanar",
    "encarraspanava": "encarraspanar",
    "encarraspanavam": "encarraspanar",
    "encarraspanavas": "encarraspanar",
    "encarraspane": "encarraspanar",
    "encarraspanei": "encarraspanar",
    "encarraspaneis": "encarraspanar",
    "encarraspanem": "encarraspanar",
    "encarraspanemo": "encarraspanar",
    "encarraspanemos": "encarraspanar",
    "encarraspanes": "encarraspanar",
    "encarraspano": "encarraspanar",
    "encarraspanou": "encarraspanar",
    "encarraspaná": "encarraspanar",
    "encarraspanámo": "encarraspanar",
    "encarraspanámos": "encarraspanar",
    "encarraspanáramo": "encarraspanar",
    "encarraspanáramos": "encarraspanar",
    "encarraspanárei": "encarraspanar",
    "encarraspanáreis": "encarraspanar",
    "encarraspanásseis": "encarraspanar",
    "encarraspanássemos": "encarraspanar",
    "encarraspanávamo": "encarraspanar",
    "encarraspanávamos": "encarraspanar",
    "encarraspanávei": "encarraspanar",
    "encarraspanáveis": "encarraspanar",
    "encarrasque": "encarrascar",
    "encarrasquei": "encarrascar",
    "encarrasqueis": "encarrascar",
    "encarrasquem": "encarrascar",
    "encarrasquemo": "encarrascar",
    "encarrasquemos": "encarrascar",
    "encarrasques": "encarrascar",
    "encarrasse": "encarrar",
    "encarrassem": "encarrar",
    "encarrasses": "encarrar",
    "encarraste": "encarrar",
    "encarrastes": "encarrar",
    "encarrava": "encarrar",
    "encarravam": "encarrar",
    "encarravas": "encarrar",
    "encarre": "encarrar",
    "encarrega": "encarregar",
    "encarregada": "encarregar",
    "encarregadas": "encarregar",
    "encarregado": "encarregar",
    "encarregados": "encarregar",
    "encarregai": "encarregar",
    "encarregais": "encarregar",
    "encarregam": "encarregar",
    "encarregamo": "encarregar",
    "encarregamos": "encarregar",
    "encarregando": "encarregar",
    "encarregara": "encarregar",
    "encarregaram": "encarregar",
    "encarregaras": "encarregar",
    "encarregarde": "encarregar",
    "encarregardes": "encarregar",
    "encarregare": "encarregar",
    "encarregarei": "encarregar",
    "encarregareis": "encarregar",
    "encarregarem": "encarregar",
    "encarregaremos": "encarregar",
    "encarregares": "encarregar",
    "encarregaria": "encarregar",
    "encarregariam": "encarregar",
    "encarregarias": "encarregar",
    "encarregarmo": "encarregar",
    "encarregarmos": "encarregar",
    "encarregará": "encarregar",
    "encarregarás": "encarregar",
    "encarregarão": "encarregar",
    "encarregaríamos": "encarregar",
    "encarregaríeis": "encarregar",
    "encarregas": "encarregar",
    "encarregasse": "encarregar",
    "encarregassem": "encarregar",
    "encarregasses": "encarregar",
    "encarregaste": "encarregar",
    "encarregastes": "encarregar",
    "encarregava": "encarregar",
    "encarregavam": "encarregar",
    "encarregavas": "encarregar",
    "encarrego": "encarregar",
    "encarregos": "encarrego",
    "encarregou": "encarregar",
    "encarregue": "encarregar",
    "encarreguei": "encarregar",
    "encarregueis": "encarregar",
    "encarreguem": "encarregar",
    "encarreguemo": "encarregar",
    "encarreguemos": "encarregar",
    "encarregues": "encarregue",
    "encarregá": "encarregar",
    "encarregámo": "encarregar",
    "encarregámos": "encarregar",
    "encarregáramo": "encarregar",
    "encarregáramos": "encarregar",
    "encarregárei": "encarregar",
    "encarregáreis": "encarregar",
    "encarregásseis": "encarregar",
    "encarregássemos": "encarregar",
    "encarregávamo": "encarregar",
    "encarregávamos": "encarregar",
    "encarregávei": "encarregar",
    "encarregáveis": "encarregável",
    "encarrei": "encarrar",
    "encarreira": "encarreirar",
    "encarreirada": "encarreirar",
    "encarreiradas": "encarreirar",
    "encarreirado": "encarreirar",
    "encarreirados": "encarreirar",
    "encarreirai": "encarreirar",
    "encarreirais": "encarreirar",
    "encarreiram": "encarreirar",
    "encarreiramentos": "encarreiramento",
    "encarreiramo": "encarreirar",
    "encarreiramos": "encarreirar",
    "encarreirando": "encarreirar",
    "encarreirara": "encarreirar",
    "encarreiraram": "encarreirar",
    "encarreiraras": "encarreirar",
    "encarreirardes": "encarreirar",
    "encarreirarei": "encarreirar",
    "encarreirareis": "encarreirar",
    "encarreirarem": "encarreirar",
    "encarreiraremos": "encarreirar",
    "encarreirares": "encarreirar",
    "encarreiraria": "encarreirar",
    "encarreirariam": "encarreirar",
    "encarreirarias": "encarreirar",
    "encarreirarmo": "encarreirar",
    "encarreirarmos": "encarreirar",
    "encarreirará": "encarreirar",
    "encarreirarás": "encarreirar",
    "encarreirarão": "encarreirar",
    "encarreiraríamos": "encarreirar",
    "encarreiraríeis": "encarreirar",
    "encarreiras": "encarreirar",
    "encarreirasse": "encarreirar",
    "encarreirassem": "encarreirar",
    "encarreirasses": "encarreirar",
    "encarreiraste": "encarreirar",
    "encarreirastes": "encarreirar",
    "encarreirava": "encarreirar",
    "encarreiravam": "encarreirar",
    "encarreiravas": "encarreirar",
    "encarreire": "encarreirar",
    "encarreirei": "encarreirar",
    "encarreireis": "encarreirar",
    "encarreirem": "encarreirar",
    "encarreiremo": "encarreirar",
    "encarreiremos": "encarreirar",
    "encarreires": "encarreirar",
    "encarreiro": "encarreirar",
    "encarreirou": "encarreirar",
    "encarreirámo": "encarreirar",
    "encarreirámos": "encarreirar",
    "encarreiráramo": "encarreirar",
    "encarreiráramos": "encarreirar",
    "encarreiráreis": "encarreirar",
    "encarreirásseis": "encarreirar",
    "encarreirássemos": "encarreirar",
    "encarreirávamo": "encarreirar",
    "encarreirávamos": "encarreirar",
    "encarreiráveis": "encarreirar",
    "encarreis": "encarrar",
    "encarrem": "encarrar",
    "encarremo": "encarrar",
    "encarremos": "encarrar",
    "encarres": "encarrar",
    "encarreta": "encarretar",
    "encarretada": "encarretar",
    "encarretadas": "encarretar",
    "encarretadeiras": "encarretadeira",
    "encarretado": "encarretar",
    "encarretados": "encarretar",
    "encarretai": "encarretar",
    "encarretais": "encarretar",
    "encarretam": "encarretar",
    "encarretamo": "encarretar",
    "encarretamos": "encarretar",
    "encarretando": "encarretar",
    "encarretara": "encarretar",
    "encarretaram": "encarretar",
    "encarretaras": "encarretar",
    "encarretarde": "encarretar",
    "encarretardes": "encarretar",
    "encarretare": "encarretar",
    "encarretarei": "encarretar",
    "encarretareis": "encarretar",
    "encarretarem": "encarretar",
    "encarretaremos": "encarretar",
    "encarretares": "encarretar",
    "encarretaria": "encarretar",
    "encarretariam": "encarretar",
    "encarretarias": "encarretar",
    "encarretarmo": "encarretar",
    "encarretarmos": "encarretar",
    "encarretará": "encarretar",
    "encarretarás": "encarretar",
    "encarretarão": "encarretar",
    "encarretaríamos": "encarretar",
    "encarretaríeis": "encarretar",
    "encarretas": "encarretar",
    "encarretasse": "encarretar",
    "encarretassem": "encarretar",
    "encarretasses": "encarretar",
    "encarretaste": "encarretar",
    "encarretastes": "encarretar",
    "encarretava": "encarretar",
    "encarretavam": "encarretar",
    "encarretavas": "encarretar",
    "encarrete": "encarretar",
    "encarretei": "encarretar",
    "encarreteis": "encarretar",
    "encarretem": "encarretar",
    "encarretemo": "encarretar",
    "encarretemos": "encarretar",
    "encarretes": "encarretar",
    "encarreto": "encarretar",
    "encarretou": "encarretar",
    "encarretá": "encarretar",
    "encarretámo": "encarretar",
    "encarretámos": "encarretar",
    "encarretáramo": "encarretar",
    "encarretáramos": "encarretar",
    "encarretárei": "encarretar",
    "encarretáreis": "encarretar",
    "encarretásseis": "encarretar",
    "encarretássemos": "encarretar",
    "encarretávamo": "encarretar",
    "encarretávamos": "encarretar",
    "encarretávei": "encarretar",
    "encarretáveis": "encarretar",
    "encarrila": "encarrilar",
    "encarrilada": "encarrilar",
    "encarriladas": "encarrilar",
    "encarrilado": "encarrilar",
    "encarrilados": "encarrilar",
    "encarrilai": "encarrilar",
    "encarrilais": "encarrilar",
    "encarrilam": "encarrilar",
    "encarrilamo": "encarrilar",
    "encarrilamos": "encarrilar",
    "encarrilando": "encarrilar",
    "encarrilara": "encarrilar",
    "encarrilaram": "encarrilar",
    "encarrilaras": "encarrilar",
    "encarrilardes": "encarrilar",
    "encarrilarei": "encarrilar",
    "encarrilareis": "encarrilar",
    "encarrilarem": "encarrilar",
    "encarrilaremos": "encarrilar",
    "encarrilares": "encarrilar",
    "encarrilaria": "encarrilar",
    "encarrilariam": "encarrilar",
    "encarrilarias": "encarrilar",
    "encarrilarmo": "encarrilar",
    "encarrilarmos": "encarrilar",
    "encarrilará": "encarrilar",
    "encarrilarás": "encarrilar",
    "encarrilarão": "encarrilar",
    "encarrilaríamos": "encarrilar",
    "encarrilaríeis": "encarrilar",
    "encarrilas": "encarrilar",
    "encarrilasse": "encarrilar",
    "encarrilassem": "encarrilar",
    "encarrilasses": "encarrilar",
    "encarrilaste": "encarrilar",
    "encarrilastes": "encarrilar",
    "encarrilava": "encarrilar",
    "encarrilavam": "encarrilar",
    "encarrilavas": "encarrilar",
    "encarrile": "encarrilar",
    "encarrilei": "encarrilar",
    "encarrileis": "encarrilar",
    "encarrilem": "encarrilar",
    "encarrilemo": "encarrilar",
    "encarrilemos": "encarrilar",
    "encarriles": "encarrilar",
    "encarrilha": "encarrilhar",
    "encarrilhada": "encarrilhar",
    "encarrilhadas": "encarrilhar",
    "encarrilhado": "encarrilhar",
    "encarrilhadora": "encarrilhador",
    "encarrilhadoras": "encarrilhador",
    "encarrilhadores": "encarrilhador",
    "encarrilhados": "encarrilhar",
    "encarrilhai": "encarrilhar",
    "encarrilhais": "encarrilhar",
    "encarrilham": "encarrilhar",
    "encarrilhamo": "encarrilhar",
    "encarrilhamos": "encarrilhar",
    "encarrilhando": "encarrilhar",
    "encarrilhara": "encarrilhar",
    "encarrilharam": "encarrilhar",
    "encarrilharas": "encarrilhar",
    "encarrilhardes": "encarrilhar",
    "encarrilharei": "encarrilhar",
    "encarrilhareis": "encarrilhar",
    "encarrilharem": "encarrilhar",
    "encarrilharemos": "encarrilhar",
    "encarrilhares": "encarrilhar",
    "encarrilharia": "encarrilhar",
    "encarrilhariam": "encarrilhar",
    "encarrilharias": "encarrilhar",
    "encarrilharmo": "encarrilhar",
    "encarrilharmos": "encarrilhar",
    "encarrilhará": "encarrilhar",
    "encarrilharás": "encarrilhar",
    "encarrilharão": "encarrilhar",
    "encarrilharíamos": "encarrilhar",
    "encarrilharíeis": "encarrilhar",
    "encarrilhas": "encarrilhar",
    "encarrilhasse": "encarrilhar",
    "encarrilhassem": "encarrilhar",
    "encarrilhasses": "encarrilhar",
    "encarrilhaste": "encarrilhar",
    "encarrilhastes": "encarrilhar",
    "encarrilhava": "encarrilhar",
    "encarrilhavam": "encarrilhar",
    "encarrilhavas": "encarrilhar",
    "encarrilhe": "encarrilhar",
    "encarrilhei": "encarrilhar",
    "encarrilheis": "encarrilhar",
    "encarrilhem": "encarrilhar",
    "encarrilhemo": "encarrilhar",
    "encarrilhemos": "encarrilhar",
    "encarrilhes": "encarrilhar",
    "encarrilho": "encarrilhar",
    "encarrilhou": "encarrilhar",
    "encarrilhámo": "encarrilhar",
    "encarrilhámos": "encarrilhar",
    "encarrilháramo": "encarrilhar",
    "encarrilháramos": "encarrilhar",
    "encarrilháreis": "encarrilhar",
    "encarrilhásseis": "encarrilhar",
    "encarrilhássemos": "encarrilhar",
    "encarrilhávamo": "encarrilhar",
    "encarrilhávamos": "encarrilhar",
    "encarrilháveis": "encarrilhar",
    "encarrilo": "encarrilar",
    "encarrilou": "encarrilar",
    "encarrilámo": "encarrilar",
    "encarrilámos": "encarrilar",
    "encarriláramo": "encarrilar",
    "encarriláramos": "encarrilar",
    "encarriláreis": "encarrilar",
    "encarrilásseis": "encarrilar",
    "encarrilássemos": "encarrilar",
    "encarrilávamo": "encarrilar",
    "encarrilávamos": "encarrilar",
    "encarriláveis": "encarrilar",
    "encarro": "encarrar",
    "encarrou": "encarrar",
    "encarrá": "encarrar",
    "encarrámo": "encarrar",
    "encarrámos": "encarrar",
    "encarráramo": "encarrar",
    "encarráramos": "encarrar",
    "encarrárei": "encarrar",
    "encarráreis": "encarrar",
    "encarrásseis": "encarrar",
    "encarrássemos": "encarrar",
    "encarrávamo": "encarrar",
    "encarrávamos": "encarrar",
    "encarrávei": "encarrar",
    "encarráveis": "encarrar",
    "encarta": "encartar",
    "encartada": "encartar",
    "encartadas": "encartar",
    "encartadeiras": "encartadeira",
    "encartado": "encartar",
    "encartados": "encartar",
    "encartai": "encartar",
    "encartais": "encartar",
    "encartam": "encartar",
    "encartamentos": "encartamento",
    "encartamo": "encartar",
    "encartamos": "encartar",
    "encartando": "encartar",
    "encartara": "encartar",
    "encartaram": "encartar",
    "encartaras": "encartar",
    "encartarde": "encartar",
    "encartardes": "encartar",
    "encartare": "encartar",
    "encartarei": "encartar",
    "encartareis": "encartar",
    "encartarem": "encartar",
    "encartaremos": "encartar",
    "encartares": "encartar",
    "encartaria": "encartar",
    "encartariam": "encartar",
    "encartarias": "encartar",
    "encartarmo": "encartar",
    "encartarmos": "encartar",
    "encartará": "encartar",
    "encartarás": "encartar",
    "encartarão": "encartar",
    "encartaríamos": "encartar",
    "encartaríeis": "encartar",
    "encartas": "encartar",
    "encartasse": "encartar",
    "encartassem": "encartar",
    "encartasses": "encartar",
    "encartaste": "encartar",
    "encartastes": "encartar",
    "encartava": "encartar",
    "encartavam": "encartar",
    "encartavas": "encartar",
    "encartações": "encartação",
    "encarte": "encartar",
    "encartei": "encartar",
    "encarteis": "encartar",
    "encartem": "encartar",
    "encartemo": "encartar",
    "encartemos": "encartar",
    "encartes": "encarte",
    "encarto": "encartar",
    "encartola": "encartolar",
    "encartolada": "encartolar",
    "encartoladas": "encartolar",
    "encartolado": "encartolar",
    "encartolados": "encartolar",
    "encartolai": "encartolar",
    "encartolais": "encartolar",
    "encartolam": "encartolar",
    "encartolamo": "encartolar",
    "encartolamos": "encartolar",
    "encartolando": "encartolar",
    "encartolara": "encartolar",
    "encartolaram": "encartolar",
    "encartolaras": "encartolar",
    "encartolarde": "encartolar",
    "encartolardes": "encartolar",
    "encartolare": "encartolar",
    "encartolarei": "encartolar",
    "encartolareis": "encartolar",
    "encartolarem": "encartolar",
    "encartolaremos": "encartolar",
    "encartolares": "encartolar",
    "encartolaria": "encartolar",
    "encartolariam": "encartolar",
    "encartolarias": "encartolar",
    "encartolarmo": "encartolar",
    "encartolarmos": "encartolar",
    "encartolará": "encartolar",
    "encartolarás": "encartolar",
    "encartolarão": "encartolar",
    "encartolaríamos": "encartolar",
    "encartolaríeis": "encartolar",
    "encartolas": "encartolar",
    "encartolasse": "encartolar",
    "encartolassem": "encartolar",
    "encartolasses": "encartolar",
    "encartolaste": "encartolar",
    "encartolastes": "encartolar",
    "encartolava": "encartolar",
    "encartolavam": "encartolar",
    "encartolavas": "encartolar",
    "encartole": "encartolar",
    "encartolei": "encartolar",
    "encartoleis": "encartolar",
    "encartolem": "encartolar",
    "encartolemo": "encartolar",
    "encartolemos": "encartolar",
    "encartoles": "encartolar",
    "encartolo": "encartolar",
    "encartolou": "encartolar",
    "encartolá": "encartolar",
    "encartolámo": "encartolar",
    "encartolámos": "encartolar",
    "encartoláramo": "encartolar",
    "encartoláramos": "encartolar",
    "encartolárei": "encartolar",
    "encartoláreis": "encartolar",
    "encartolásseis": "encartolar",
    "encartolássemos": "encartolar",
    "encartolávamo": "encartolar",
    "encartolávamos": "encartolar",
    "encartolávei": "encartolar",
    "encartoláveis": "encartolar",
    "encartou": "encartar",
    "encartucha": "encartuchar",
    "encartuchada": "encartuchar",
    "encartuchadas": "encartuchar",
    "encartuchado": "encartuchar",
    "encartuchados": "encartuchar",
    "encartuchai": "encartuchar",
    "encartuchais": "encartuchar",
    "encartucham": "encartuchar",
    "encartuchamo": "encartuchar",
    "encartuchamos": "encartuchar",
    "encartuchando": "encartuchar",
    "encartuchara": "encartuchar",
    "encartucharam": "encartuchar",
    "encartucharas": "encartuchar",
    "encartucharde": "encartuchar",
    "encartuchardes": "encartuchar",
    "encartuchare": "encartuchar",
    "encartucharei": "encartuchar",
    "encartuchareis": "encartuchar",
    "encartucharem": "encartuchar",
    "encartucharemos": "encartuchar",
    "encartuchares": "encartuchar",
    "encartucharia": "encartuchar",
    "encartuchariam": "encartuchar",
    "encartucharias": "encartuchar",
    "encartucharmo": "encartuchar",
    "encartucharmos": "encartuchar",
    "encartuchará": "encartuchar",
    "encartucharás": "encartuchar",
    "encartucharão": "encartuchar",
    "encartucharíamos": "encartuchar",
    "encartucharíeis": "encartuchar",
    "encartuchas": "encartuchar",
    "encartuchasse": "encartuchar",
    "encartuchassem": "encartuchar",
    "encartuchasses": "encartuchar",
    "encartuchaste": "encartuchar",
    "encartuchastes": "encartuchar",
    "encartuchava": "encartuchar",
    "encartuchavam": "encartuchar",
    "encartuchavas": "encartuchar",
    "encartuche": "encartuchar",
    "encartuchei": "encartuchar",
    "encartucheis": "encartuchar",
    "encartuchem": "encartuchar",
    "encartuchemo": "encartuchar",
    "encartuchemos": "encartuchar",
    "encartuches": "encartuchar",
    "encartucho": "encartuchar",
    "encartuchou": "encartuchar",
    "encartuchá": "encartuchar",
    "encartuchámo": "encartuchar",
    "encartuchámos": "encartuchar",
    "encartucháramo": "encartuchar",
    "encartucháramos": "encartuchar",
    "encartuchárei": "encartuchar",
    "encartucháreis": "encartuchar",
    "encartuchásseis": "encartuchar",
    "encartuchássemos": "encartuchar",
    "encartuchávamo": "encartuchar",
    "encartuchávamos": "encartuchar",
    "encartuchávei": "encartuchar",
    "encartucháveis": "encartuchar",
    "encartá": "encartar",
    "encartámo": "encartar",
    "encartámos": "encartar",
    "encartáramo": "encartar",
    "encartáramos": "encartar",
    "encartárei": "encartar",
    "encartáreis": "encartar",
    "encartásseis": "encartar",
    "encartássemos": "encartar",
    "encartávamo": "encartar",
    "encartávamos": "encartar",
    "encartávei": "encartar",
    "encartáveis": "encartar",
    "encarvoa": "encarvoar",
    "encarvoada": "encarvoar",
    "encarvoadas": "encarvoar",
    "encarvoado": "encarvoar",
    "encarvoados": "encarvoar",
    "encarvoai": "encarvoar",
    "encarvoais": "encarvoar",
    "encarvoam": "encarvoar",
    "encarvoamo": "encarvoar",
    "encarvoamos": "encarvoar",
    "encarvoando": "encarvoar",
    "encarvoara": "encarvoar",
    "encarvoaram": "encarvoar",
    "encarvoaras": "encarvoar",
    "encarvoarde": "encarvoar",
    "encarvoardes": "encarvoar",
    "encarvoare": "encarvoar",
    "encarvoarei": "encarvoar",
    "encarvoareis": "encarvoar",
    "encarvoarem": "encarvoar",
    "encarvoaremos": "encarvoar",
    "encarvoares": "encarvoar",
    "encarvoaria": "encarvoar",
    "encarvoariam": "encarvoar",
    "encarvoarias": "encarvoar",
    "encarvoarmo": "encarvoar",
    "encarvoarmos": "encarvoar",
    "encarvoará": "encarvoar",
    "encarvoarás": "encarvoar",
    "encarvoarão": "encarvoar",
    "encarvoaríamos": "encarvoar",
    "encarvoaríeis": "encarvoar",
    "encarvoas": "encarvoar",
    "encarvoasse": "encarvoar",
    "encarvoassem": "encarvoar",
    "encarvoasses": "encarvoar",
    "encarvoaste": "encarvoar",
    "encarvoastes": "encarvoar",
    "encarvoava": "encarvoar",
    "encarvoavam": "encarvoar",
    "encarvoavas": "encarvoar",
    "encarvoe": "encarvoar",
    "encarvoei": "encarvoar",
    "encarvoeis": "encarvoar",
    "encarvoeja": "encarvoejar",
    "encarvoejada": "encarvoejar",
    "encarvoejadas": "encarvoejar",
    "encarvoejado": "encarvoejar",
    "encarvoejados": "encarvoejar",
    "encarvoejai": "encarvoejar",
    "encarvoejais": "encarvoejar",
    "encarvoejam": "encarvoejar",
    "encarvoejamo": "encarvoejar",
    "encarvoejamos": "encarvoejar",
    "encarvoejando": "encarvoejar",
    "encarvoejara": "encarvoejar",
    "encarvoejaram": "encarvoejar",
    "encarvoejaras": "encarvoejar",
    "encarvoejarde": "encarvoejar",
    "encarvoejardes": "encarvoejar",
    "encarvoejare": "encarvoejar",
    "encarvoejarei": "encarvoejar",
    "encarvoejareis": "encarvoejar",
    "encarvoejarem": "encarvoejar",
    "encarvoejaremos": "encarvoejar",
    "encarvoejares": "encarvoejar",
    "encarvoejaria": "encarvoejar",
    "encarvoejariam": "encarvoejar",
    "encarvoejarias": "encarvoejar",
    "encarvoejarmo": "encarvoejar",
    "encarvoejarmos": "encarvoejar",
    "encarvoejará": "encarvoejar",
    "encarvoejarás": "encarvoejar",
    "encarvoejarão": "encarvoejar",
    "encarvoejaríamos": "encarvoejar",
    "encarvoejaríeis": "encarvoejar",
    "encarvoejas": "encarvoejar",
    "encarvoejasse": "encarvoejar",
    "encarvoejassem": "encarvoejar",
    "encarvoejasses": "encarvoejar",
    "encarvoejaste": "encarvoejar",
    "encarvoejastes": "encarvoejar",
    "encarvoejava": "encarvoejar",
    "encarvoejavam": "encarvoejar",
    "encarvoejavas": "encarvoejar",
    "encarvoeje": "encarvoejar",
    "encarvoejei": "encarvoejar",
    "encarvoejeis": "encarvoejar",
    "encarvoejem": "encarvoejar",
    "encarvoejemo": "encarvoejar",
    "encarvoejemos": "encarvoejar",
    "encarvoejes": "encarvoejar",
    "encarvoejo": "encarvoejar",
    "encarvoejou": "encarvoejar",
    "encarvoejá": "encarvoejar",
    "encarvoejámo": "encarvoejar",
    "encarvoejámos": "encarvoejar",
    "encarvoejáramo": "encarvoejar",
    "encarvoejáramos": "encarvoejar",
    "encarvoejárei": "encarvoejar",
    "encarvoejáreis": "encarvoejar",
    "encarvoejásseis": "encarvoejar",
    "encarvoejássemos": "encarvoejar",
    "encarvoejávamo": "encarvoejar",
    "encarvoejávamos": "encarvoejar",
    "encarvoejávei": "encarvoejar",
    "encarvoejáveis": "encarvoejar",
    "encarvoem": "encarvoar",
    "encarvoemo": "encarvoar",
    "encarvoemos": "encarvoar",
    "encarvoes": "encarvoar",
    "encarvoice": "encarvoiçar",
    "encarvoicei": "encarvoiçar",
    "encarvoiceis": "encarvoiçar",
    "encarvoicem": "encarvoiçar",
    "encarvoicemo": "encarvoiçar",
    "encarvoicemos": "encarvoiçar",
    "encarvoices": "encarvoiçar",
    "encarvoiça": "encarvoiçar",
    "encarvoiçada": "encarvoiçar",
    "encarvoiçadas": "encarvoiçar",
    "encarvoiçado": "encarvoiçar",
    "encarvoiçados": "encarvoiçar",
    "encarvoiçai": "encarvoiçar",
    "encarvoiçais": "encarvoiçar",
    "encarvoiçam": "encarvoiçar",
    "encarvoiçamo": "encarvoiçar",
    "encarvoiçamos": "encarvoiçar",
    "encarvoiçando": "encarvoiçar",
    "encarvoiçara": "encarvoiçar",
    "encarvoiçaram": "encarvoiçar",
    "encarvoiçaras": "encarvoiçar",
    "encarvoiçarde": "encarvoiçar",
    "encarvoiçardes": "encarvoiçar",
    "encarvoiçare": "encarvoiçar",
    "encarvoiçarei": "encarvoiçar",
    "encarvoiçareis": "encarvoiçar",
    "encarvoiçarem": "encarvoiçar",
    "encarvoiçaremos": "encarvoiçar",
    "encarvoiçares": "encarvoiçar",
    "encarvoiçaria": "encarvoiçar",
    "encarvoiçariam": "encarvoiçar",
    "encarvoiçarias": "encarvoiçar",
    "encarvoiçarmo": "encarvoiçar",
    "encarvoiçarmos": "encarvoiçar",
    "encarvoiçará": "encarvoiçar",
    "encarvoiçarás": "encarvoiçar",
    "encarvoiçarão": "encarvoiçar",
    "encarvoiçaríamos": "encarvoiçar",
    "encarvoiçaríeis": "encarvoiçar",
    "encarvoiças": "encarvoiçar",
    "encarvoiçasse": "encarvoiçar",
    "encarvoiçassem": "encarvoiçar",
    "encarvoiçasses": "encarvoiçar",
    "encarvoiçaste": "encarvoiçar",
    "encarvoiçastes": "encarvoiçar",
    "encarvoiçava": "encarvoiçar",
    "encarvoiçavam": "encarvoiçar",
    "encarvoiçavas": "encarvoiçar",
    "encarvoiço": "encarvoiçar",
    "encarvoiçou": "encarvoiçar",
    "encarvoiçá": "encarvoiçar",
    "encarvoiçámo": "encarvoiçar",
    "encarvoiçámos": "encarvoiçar",
    "encarvoiçáramo": "encarvoiçar",
    "encarvoiçáramos": "encarvoiçar",
    "encarvoiçárei": "encarvoiçar",
    "encarvoiçáreis": "encarvoiçar",
    "encarvoiçásseis": "encarvoiçar",
    "encarvoiçássemos": "encarvoiçar",
    "encarvoiçávamo": "encarvoiçar",
    "encarvoiçávamos": "encarvoiçar",
    "encarvoiçávei": "encarvoiçar",
    "encarvoiçáveis": "encarvoiçar",
    "encarvoo": "encarvoar",
    "encarvoou": "encarvoar",
    "encarvoá": "encarvoar",
    "encarvoámo": "encarvoar",
    "encarvoámos": "encarvoar",
    "encarvoáramo": "encarvoar",
    "encarvoáramos": "encarvoar",
    "encarvoárei": "encarvoar",
    "encarvoáreis": "encarvoar",
    "encarvoásseis": "encarvoar",
    "encarvoássemos": "encarvoar",
    "encarvoávamo": "encarvoar",
    "encarvoávamos": "encarvoar",
    "encarvoávei": "encarvoar",
    "encarvoáveis": "encarvoar",
    "encará": "encarar",
    "encarámo": "encarar",
    "encarámos": "encarar",
    "encaráramo": "encarar",
    "encaráramos": "encarar",
    "encarárei": "encarar",
    "encaráreis": "encarar",
    "encarásseis": "encarar",
    "encarássemos": "encarar",
    "encarávamo": "encarar",
    "encarávamos": "encarar",
    "encarávei": "encarar",
    "encaráveis": "encarar",
    "encasa": "encasar",
    "encasaca": "encasacar",
    "encasacada": "encasacar",
    "encasacadas": "encasacar",
    "encasacado": "encasacar",
    "encasacados": "encasacar",
    "encasacai": "encasacar",
    "encasacais": "encasacar",
    "encasacam": "encasacar",
    "encasacamo": "encasacar",
    "encasacamos": "encasacar",
    "encasacando": "encasacar",
    "encasacara": "encasacar",
    "encasacaram": "encasacar",
    "encasacaras": "encasacar",
    "encasacarde": "encasacar",
    "encasacardes": "encasacar",
    "encasacare": "encasacar",
    "encasacarei": "encasacar",
    "encasacareis": "encasacar",
    "encasacarem": "encasacar",
    "encasacaremos": "encasacar",
    "encasacares": "encasacar",
    "encasacaria": "encasacar",
    "encasacariam": "encasacar",
    "encasacarias": "encasacar",
    "encasacarmo": "encasacar",
    "encasacarmos": "encasacar",
    "encasacará": "encasacar",
    "encasacarás": "encasacar",
    "encasacarão": "encasacar",
    "encasacaríamos": "encasacar",
    "encasacaríeis": "encasacar",
    "encasacas": "encasacar",
    "encasacasse": "encasacar",
    "encasacassem": "encasacar",
    "encasacasses": "encasacar",
    "encasacaste": "encasacar",
    "encasacastes": "encasacar",
    "encasacava": "encasacar",
    "encasacavam": "encasacar",
    "encasacavas": "encasacar",
    "encasaco": "encasacar",
    "encasacou": "encasacar",
    "encasacá": "encasacar",
    "encasacámo": "encasacar",
    "encasacámos": "encasacar",
    "encasacáramo": "encasacar",
    "encasacáramos": "encasacar",
    "encasacárei": "encasacar",
    "encasacáreis": "encasacar",
    "encasacásseis": "encasacar",
    "encasacássemos": "encasacar",
    "encasacávamo": "encasacar",
    "encasacávamos": "encasacar",
    "encasacávei": "encasacar",
    "encasacáveis": "encasacar",
    "encasada": "encasar",
    "encasadas": "encasar",
    "encasado": "encasar",
    "encasados": "encasar",
    "encasai": "encasar",
    "encasais": "encasar",
    "encasam": "encasar",
    "encasamentos": "encasamento",
    "encasamo": "encasar",
    "encasamos": "encasar",
    "encasando": "encasar",
    "encasaque": "encasacar",
    "encasaquei": "encasacar",
    "encasaqueis": "encasacar",
    "encasaquem": "encasacar",
    "encasaquemo": "encasacar",
    "encasaquemos": "encasacar",
    "encasaques": "encasacar",
    "encasara": "encasar",
    "encasaram": "encasar",
    "encasaras": "encasar",
    "encasarde": "encasar",
    "encasardes": "encasar",
    "encasare": "encasar",
    "encasarei": "encasar",
    "encasareis": "encasar",
    "encasarem": "encasar",
    "encasaremos": "encasar",
    "encasares": "encasar",
    "encasaria": "encasar",
    "encasariam": "encasar",
    "encasarias": "encasar",
    "encasarmo": "encasar",
    "encasarmos": "encasar",
    "encasará": "encasar",
    "encasarás": "encasar",
    "encasarão": "encasar",
    "encasaríamos": "encasar",
    "encasaríeis": "encasar",
    "encasas": "encasar",
    "encasasse": "encasar",
    "encasassem": "encasar",
    "encasasses": "encasar",
    "encasaste": "encasar",
    "encasastes": "encasar",
    "encasava": "encasar",
    "encasavam": "encasar",
    "encasavas": "encasar",
    "encasca": "encascar",
    "encascada": "encascar",
    "encascadas": "encascar",
    "encascado": "encascar",
    "encascados": "encascar",
    "encascais": "encascar",
    "encascalha": "encascalhar",
    "encascalhada": "encascalhar",
    "encascalhadas": "encascalhar",
    "encascalhado": "encascalhar",
    "encascalhados": "encascalhar",
    "encascalhai": "encascalhar",
    "encascalhais": "encascalhar",
    "encascalham": "encascalhar",
    "encascalhamentos": "encascalhamento",
    "encascalhamo": "encascalhar",
    "encascalhamos": "encascalhar",
    "encascalhando": "encascalhar",
    "encascalhara": "encascalhar",
    "encascalharam": "encascalhar",
    "encascalharas": "encascalhar",
    "encascalharde": "encascalhar",
    "encascalhardes": "encascalhar",
    "encascalhare": "encascalhar",
    "encascalharei": "encascalhar",
    "encascalhareis": "encascalhar",
    "encascalharem": "encascalhar",
    "encascalharemos": "encascalhar",
    "encascalhares": "encascalhar",
    "encascalharia": "encascalhar",
    "encascalhariam": "encascalhar",
    "encascalharias": "encascalhar",
    "encascalharmo": "encascalhar",
    "encascalharmos": "encascalhar",
    "encascalhará": "encascalhar",
    "encascalharás": "encascalhar",
    "encascalharão": "encascalhar",
    "encascalharíamos": "encascalhar",
    "encascalharíeis": "encascalhar",
    "encascalhas": "encascalhar",
    "encascalhasse": "encascalhar",
    "encascalhassem": "encascalhar",
    "encascalhasses": "encascalhar",
    "encascalhaste": "encascalhar",
    "encascalhastes": "encascalhar",
    "encascalhava": "encascalhar",
    "encascalhavam": "encascalhar",
    "encascalhavas": "encascalhar",
    "encascalhe": "encascalhar",
    "encascalhei": "encascalhar",
    "encascalheis": "encascalhar",
    "encascalhem": "encascalhar",
    "encascalhemo": "encascalhar",
    "encascalhemos": "encascalhar",
    "encascalhes": "encascalhar",
    "encascalho": "encascalhar",
    "encascalhou": "encascalhar",
    "encascalhá": "encascalhar",
    "encascalhámo": "encascalhar",
    "encascalhámos": "encascalhar",
    "encascalháramo": "encascalhar",
    "encascalháramos": "encascalhar",
    "encascalhárei": "encascalhar",
    "encascalháreis": "encascalhar",
    "encascalhásseis": "encascalhar",
    "encascalhássemos": "encascalhar",
    "encascalhávamo": "encascalhar",
    "encascalhávamos": "encascalhar",
    "encascalhávei": "encascalhar",
    "encascalháveis": "encascalhar",
    "encascam": "encascar",
    "encascamo": "encascar",
    "encascamos": "encascar",
    "encascando": "encascar",
    "encascara": "encascar",
    "encascaram": "encascar",
    "encascaras": "encascar",
    "encascardes": "encascar",
    "encascarei": "encascar",
    "encascareis": "encascar",
    "encascarem": "encascar",
    "encascaremos": "encascar",
    "encascares": "encascar",
    "encascaria": "encascar",
    "encascariam": "encascar",
    "encascarias": "encascar",
    "encascarmo": "encascar",
    "encascarmos": "encascar",
    "encascará": "encascar",
    "encascarás": "encascar",
    "encascarão": "encascar",
    "encascaríamos": "encascar",
    "encascaríeis": "encascar",
    "encascas": "encascar",
    "encascasse": "encascar",
    "encascassem": "encascar",
    "encascasses": "encascar",
    "encascaste": "encascar",
    "encascastes": "encascar",
    "encascava": "encascar",
    "encascavam": "encascar",
    "encascavas": "encascar",
    "encasco": "encascar",
    "encascou": "encascar",
    "encascámo": "encascar",
    "encascámos": "encascar",
    "encascáramo": "encascar",
    "encascáramos": "encascar",
    "encascáreis": "encascar",
    "encascásseis": "encascar",
    "encascássemos": "encascar",
    "encascávamo": "encascar",
    "encascávamos": "encascar",
    "encascáveis": "encascar",
    "encase": "encasar",
    "encasei": "encasar",
    "encaseis": "encasar",
    "encasem": "encasar",
    "encasemo": "encasar",
    "encasemos": "encasar",
    "encases": "encasar",
    "encasmurra": "encasmurrar",
    "encasmurrada": "encasmurrar",
    "encasmurradas": "encasmurrar",
    "encasmurrado": "encasmurrar",
    "encasmurrados": "encasmurrar",
    "encasmurrai": "encasmurrar",
    "encasmurrais": "encasmurrar",
    "encasmurram": "encasmurrar",
    "encasmurramo": "encasmurrar",
    "encasmurramos": "encasmurrar",
    "encasmurrando": "encasmurrar",
    "encasmurrara": "encasmurrar",
    "encasmurraram": "encasmurrar",
    "encasmurraras": "encasmurrar",
    "encasmurrarde": "encasmurrar",
    "encasmurrardes": "encasmurrar",
    "encasmurrare": "encasmurrar",
    "encasmurrarei": "encasmurrar",
    "encasmurrareis": "encasmurrar",
    "encasmurrarem": "encasmurrar",
    "encasmurraremos": "encasmurrar",
    "encasmurrares": "encasmurrar",
    "encasmurraria": "encasmurrar",
    "encasmurrariam": "encasmurrar",
    "encasmurrarias": "encasmurrar",
    "encasmurrarmo": "encasmurrar",
    "encasmurrarmos": "encasmurrar",
    "encasmurrará": "encasmurrar",
    "encasmurrarás": "encasmurrar",
    "encasmurrarão": "encasmurrar",
    "encasmurraríamos": "encasmurrar",
    "encasmurraríeis": "encasmurrar",
    "encasmurras": "encasmurrar",
    "encasmurrasse": "encasmurrar",
    "encasmurrassem": "encasmurrar",
    "encasmurrasses": "encasmurrar",
    "encasmurraste": "encasmurrar",
    "encasmurrastes": "encasmurrar",
    "encasmurrava": "encasmurrar",
    "encasmurravam": "encasmurrar",
    "encasmurravas": "encasmurrar",
    "encasmurre": "encasmurrar",
    "encasmurrei": "encasmurrar",
    "encasmurreis": "encasmurrar",
    "encasmurrem": "encasmurrar",
    "encasmurremo": "encasmurrar",
    "encasmurremos": "encasmurrar",
    "encasmurres": "encasmurrar",
    "encasmurro": "encasmurrar",
    "encasmurrou": "encasmurrar",
    "encasmurrá": "encasmurrar",
    "encasmurrámo": "encasmurrar",
    "encasmurrámos": "encasmurrar",
    "encasmurráramo": "encasmurrar",
    "encasmurráramos": "encasmurrar",
    "encasmurrárei": "encasmurrar",
    "encasmurráreis": "encasmurrar",
    "encasmurrásseis": "encasmurrar",
    "encasmurrássemos": "encasmurrar",
    "encasmurrávamo": "encasmurrar",
    "encasmurrávamos": "encasmurrar",
    "encasmurrávei": "encasmurrar",
    "encasmurráveis": "encasmurrar",
    "encaso": "encasar",
    "encasou": "encasar",
    "encasque": "encascar",
    "encasquei": "encascar",
    "encasqueis": "encascar",
    "encasquem": "encascar",
    "encasquemos": "encascar",
    "encasques": "encasque",
    "encasqueta": "encasquetar",
    "encasquetada": "encasquetar",
    "encasquetadas": "encasquetar",
    "encasquetado": "encasquetar",
    "encasquetados": "encasquetar",
    "encasquetai": "encasquetar",
    "encasquetais": "encasquetar",
    "encasquetam": "encasquetar",
    "encasquetamo": "encasquetar",
    "encasquetamos": "encasquetar",
    "encasquetando": "encasquetar",
    "encasquetara": "encasquetar",
    "encasquetaram": "encasquetar",
    "encasquetaras": "encasquetar",
    "encasquetarde": "encasquetar",
    "encasquetardes": "encasquetar",
    "encasquetare": "encasquetar",
    "encasquetarei": "encasquetar",
    "encasquetareis": "encasquetar",
    "encasquetarem": "encasquetar",
    "encasquetaremos": "encasquetar",
    "encasquetares": "encasquetar",
    "encasquetaria": "encasquetar",
    "encasquetariam": "encasquetar",
    "encasquetarias": "encasquetar",
    "encasquetarmo": "encasquetar",
    "encasquetarmos": "encasquetar",
    "encasquetará": "encasquetar",
    "encasquetarás": "encasquetar",
    "encasquetarão": "encasquetar",
    "encasquetaríamos": "encasquetar",
    "encasquetaríeis": "encasquetar",
    "encasquetas": "encasquetar",
    "encasquetasse": "encasquetar",
    "encasquetassem": "encasquetar",
    "encasquetasses": "encasquetar",
    "encasquetaste": "encasquetar",
    "encasquetastes": "encasquetar",
    "encasquetava": "encasquetar",
    "encasquetavam": "encasquetar",
    "encasquetavas": "encasquetar",
    "encasquete": "encasquetar",
    "encasquetei": "encasquetar",
    "encasqueteis": "encasquetar",
    "encasquetem": "encasquetar",
    "encasquetemo": "encasquetar",
    "encasquetemos": "encasquetar",
    "encasquetes": "encasquetar",
    "encasqueto": "encasquetar",
    "encasquetou": "encasquetar",
    "encasquetá": "encasquetar",
    "encasquetámo": "encasquetar",
    "encasquetámos": "encasquetar",
    "encasquetáramo": "encasquetar",
    "encasquetáramos": "encasquetar",
    "encasquetárei": "encasquetar",
    "encasquetáreis": "encasquetar",
    "encasquetásseis": "encasquetar",
    "encasquetássemos": "encasquetar",
    "encasquetávamo": "encasquetar",
    "encasquetávamos": "encasquetar",
    "encasquetávei": "encasquetar",
    "encasquetáveis": "encasquetar",
    "encasquilha": "encasquilhar",
    "encasquilhada": "encasquilhar",
    "encasquilhadas": "encasquilhar",
    "encasquilhado": "encasquilhar",
    "encasquilhados": "encasquilhar",
    "encasquilhai": "encasquilhar",
    "encasquilhais": "encasquilhar",
    "encasquilham": "encasquilhar",
    "encasquilhamo": "encasquilhar",
    "encasquilhamos": "encasquilhar",
    "encasquilhando": "encasquilhar",
    "encasquilhara": "encasquilhar",
    "encasquilharam": "encasquilhar",
    "encasquilharas": "encasquilhar",
    "encasquilharde": "encasquilhar",
    "encasquilhardes": "encasquilhar",
    "encasquilhare": "encasquilhar",
    "encasquilharei": "encasquilhar",
    "encasquilhareis": "encasquilhar",
    "encasquilharem": "encasquilhar",
    "encasquilharemos": "encasquilhar",
    "encasquilhares": "encasquilhar",
    "encasquilharia": "encasquilhar",
    "encasquilhariam": "encasquilhar",
    "encasquilharias": "encasquilhar",
    "encasquilharmo": "encasquilhar",
    "encasquilharmos": "encasquilhar",
    "encasquilhará": "encasquilhar",
    "encasquilharás": "encasquilhar",
    "encasquilharão": "encasquilhar",
    "encasquilharíamos": "encasquilhar",
    "encasquilharíeis": "encasquilhar",
    "encasquilhas": "encasquilhar",
    "encasquilhasse": "encasquilhar",
    "encasquilhassem": "encasquilhar",
    "encasquilhasses": "encasquilhar",
    "encasquilhaste": "encasquilhar",
    "encasquilhastes": "encasquilhar",
    "encasquilhava": "encasquilhar",
    "encasquilhavam": "encasquilhar",
    "encasquilhavas": "encasquilhar",
    "encasquilhe": "encasquilhar",
    "encasquilhei": "encasquilhar",
    "encasquilheis": "encasquilhar",
    "encasquilhem": "encasquilhar",
    "encasquilhemo": "encasquilhar",
    "encasquilhemos": "encasquilhar",
    "encasquilhes": "encasquilhar",
    "encasquilho": "encasquilhar",
    "encasquilhou": "encasquilhar",
    "encasquilhá": "encasquilhar",
    "encasquilhámo": "encasquilhar",
    "encasquilhámos": "encasquilhar",
    "encasquilháramo": "encasquilhar",
    "encasquilháramos": "encasquilhar",
    "encasquilhárei": "encasquilhar",
    "encasquilháreis": "encasquilhar",
    "encasquilhásseis": "encasquilhar",
    "encasquilhássemos": "encasquilhar",
    "encasquilhávamo": "encasquilhar",
    "encasquilhávamos": "encasquilhar",
    "encasquilhávei": "encasquilhar",
    "encasquilháveis": "encasquilhar",
    "encastalha": "encastalhar",
    "encastalhada": "encastalhar",
    "encastalhadas": "encastalhar",
    "encastalhado": "encastalhar",
    "encastalhados": "encastalhar",
    "encastalhai": "encastalhar",
    "encastalhais": "encastalhar",
    "encastalham": "encastalhar",
    "encastalhamo": "encastalhar",
    "encastalhamos": "encastalhar",
    "encastalhando": "encastalhar",
    "encastalhara": "encastalhar",
    "encastalharam": "encastalhar",
    "encastalharas": "encastalhar",
    "encastalharde": "encastalhar",
    "encastalhardes": "encastalhar",
    "encastalhare": "encastalhar",
    "encastalharei": "encastalhar",
    "encastalhareis": "encastalhar",
    "encastalharem": "encastalhar",
    "encastalharemos": "encastalhar",
    "encastalhares": "encastalhar",
    "encastalharia": "encastalhar",
    "encastalhariam": "encastalhar",
    "encastalharias": "encastalhar",
    "encastalharmo": "encastalhar",
    "encastalharmos": "encastalhar",
    "encastalhará": "encastalhar",
    "encastalharás": "encastalhar",
    "encastalharão": "encastalhar",
    "encastalharíamos": "encastalhar",
    "encastalharíeis": "encastalhar",
    "encastalhas": "encastalhar",
    "encastalhasse": "encastalhar",
    "encastalhassem": "encastalhar",
    "encastalhasses": "encastalhar",
    "encastalhaste": "encastalhar",
    "encastalhastes": "encastalhar",
    "encastalhava": "encastalhar",
    "encastalhavam": "encastalhar",
    "encastalhavas": "encastalhar",
    "encastalhe": "encastalhar",
    "encastalhei": "encastalhar",
    "encastalheis": "encastalhar",
    "encastalhem": "encastalhar",
    "encastalhemo": "encastalhar",
    "encastalhemos": "encastalhar",
    "encastalhes": "encastalhar",
    "encastalho": "encastalhar",
    "encastalhos": "encastalho",
    "encastalhou": "encastalhar",
    "encastalhá": "encastalhar",
    "encastalhámo": "encastalhar",
    "encastalhámos": "encastalhar",
    "encastalháramo": "encastalhar",
    "encastalháramos": "encastalhar",
    "encastalhárei": "encastalhar",
    "encastalháreis": "encastalhar",
    "encastalhásseis": "encastalhar",
    "encastalhássemos": "encastalhar",
    "encastalhávamo": "encastalhar",
    "encastalhávamos": "encastalhar",
    "encastalhávei": "encastalhar",
    "encastalháveis": "encastalhar",
    "encastela": "encastelar",
    "encastelada": "encastelar",
    "encasteladas": "encastelar",
    "encastelado": "encastelar",
    "encastelados": "encastelar",
    "encastelai": "encastelar",
    "encastelais": "encastelar",
    "encastelam": "encastelar",
    "encastelamentos": "encastelamento",
    "encastelamo": "encastelar",
    "encastelamos": "encastelar",
    "encastelando": "encastelar",
    "encastelara": "encastelar",
    "encastelaram": "encastelar",
    "encastelaras": "encastelar",
    "encastelarde": "encastelar",
    "encastelardes": "encastelar",
    "encastelare": "encastelar",
    "encastelarei": "encastelar",
    "encastelareis": "encastelar",
    "encastelarem": "encastelar",
    "encastelaremos": "encastelar",
    "encastelares": "encastelar",
    "encastelaria": "encastelar",
    "encastelariam": "encastelar",
    "encastelarias": "encastelar",
    "encastelarmo": "encastelar",
    "encastelarmos": "encastelar",
    "encastelará": "encastelar",
    "encastelarás": "encastelar",
    "encastelarão": "encastelar",
    "encastelaríamos": "encastelar",
    "encastelaríeis": "encastelar",
    "encastelas": "encastelar",
    "encastelasse": "encastelar",
    "encastelassem": "encastelar",
    "encastelasses": "encastelar",
    "encastelaste": "encastelar",
    "encastelastes": "encastelar",
    "encastelava": "encastelar",
    "encastelavam": "encastelar",
    "encastelavas": "encastelar",
    "encastele": "encastelar",
    "encastelei": "encastelar",
    "encasteleis": "encastelar",
    "encastelem": "encastelar",
    "encastelemo": "encastelar",
    "encastelemos": "encastelar",
    "encasteles": "encastelar",
    "encastelo": "encastelar",
    "encastelou": "encastelar",
    "encastelá": "encastelar",
    "encastelámo": "encastelar",
    "encastelámos": "encastelar",
    "encasteláramo": "encastelar",
    "encasteláramos": "encastelar",
    "encastelárei": "encastelar",
    "encasteláreis": "encastelar",
    "encastelásseis": "encastelar",
    "encastelássemos": "encastelar",
    "encastelávamo": "encastelar",
    "encastelávamos": "encastelar",
    "encastelávei": "encastelar",
    "encasteláveis": "encastelar",
    "encastoa": "encastoar",
    "encastoada": "encastoar",
    "encastoadas": "encastoar",
    "encastoado": "encastoar",
    "encastoados": "encastoar",
    "encastoai": "encastoar",
    "encastoais": "encastoar",
    "encastoam": "encastoar",
    "encastoamo": "encastoar",
    "encastoamos": "encastoar",
    "encastoando": "encastoar",
    "encastoara": "encastoar",
    "encastoaram": "encastoar",
    "encastoaras": "encastoar",
    "encastoarde": "encastoar",
    "encastoardes": "encastoar",
    "encastoare": "encastoar",
    "encastoarei": "encastoar",
    "encastoareis": "encastoar",
    "encastoarem": "encastoar",
    "encastoaremos": "encastoar",
    "encastoares": "encastoar",
    "encastoaria": "encastoar",
    "encastoariam": "encastoar",
    "encastoarias": "encastoar",
    "encastoarmo": "encastoar",
    "encastoarmos": "encastoar",
    "encastoará": "encastoar",
    "encastoarás": "encastoar",
    "encastoarão": "encastoar",
    "encastoaríamos": "encastoar",
    "encastoaríeis": "encastoar",
    "encastoas": "encastoar",
    "encastoasse": "encastoar",
    "encastoassem": "encastoar",
    "encastoasses": "encastoar",
    "encastoaste": "encastoar",
    "encastoastes": "encastoar",
    "encastoava": "encastoar",
    "encastoavam": "encastoar",
    "encastoavas": "encastoar",
    "encastoe": "encastoar",
    "encastoei": "encastoar",
    "encastoeis": "encastoar",
    "encastoem": "encastoar",
    "encastoemo": "encastoar",
    "encastoemos": "encastoar",
    "encastoes": "encastoar",
    "encastoo": "encastoar",
    "encastoou": "encastoar",
    "encastoá": "encastoar",
    "encastoámo": "encastoar",
    "encastoámos": "encastoar",
    "encastoáramo": "encastoar",
    "encastoáramos": "encastoar",
    "encastoárei": "encastoar",
    "encastoáreis": "encastoar",
    "encastoásseis": "encastoar",
    "encastoássemos": "encastoar",
    "encastoávamo": "encastoar",
    "encastoávamos": "encastoar",
    "encastoávei": "encastoar",
    "encastoáveis": "encastoar",
    "encastrada": "encastrado",
    "encastradas": "encastrado",
    "encastrados": "encastrado",
    "encastramentos": "encastramento",
    "encasula": "encasular",
    "encasulada": "encasular",
    "encasuladas": "encasular",
    "encasulado": "encasular",
    "encasulados": "encasular",
    "encasulai": "encasular",
    "encasulais": "encasular",
    "encasulam": "encasular",
    "encasulamo": "encasular",
    "encasulamos": "encasular",
    "encasulando": "encasular",
    "encasulara": "encasular",
    "encasularam": "encasular",
    "encasularas": "encasular",
    "encasularde": "encasular",
    "encasulardes": "encasular",
    "encasulare": "encasular",
    "encasularei": "encasular",
    "encasulareis": "encasular",
    "encasularem": "encasular",
    "encasularemos": "encasular",
    "encasulares": "encasular",
    "encasularia": "encasular",
    "encasulariam": "encasular",
    "encasularias": "encasular",
    "encasularmo": "encasular",
    "encasularmos": "encasular",
    "encasulará": "encasular",
    "encasularás": "encasular",
    "encasularão": "encasular",
    "encasularíamos": "encasular",
    "encasularíeis": "encasular",
    "encasulas": "encasular",
    "encasulasse": "encasular",
    "encasulassem": "encasular",
    "encasulasses": "encasular",
    "encasulaste": "encasular",
    "encasulastes": "encasular",
    "encasulava": "encasular",
    "encasulavam": "encasular",
    "encasulavas": "encasular",
    "encasule": "encasular",
    "encasulei": "encasular",
    "encasuleis": "encasular",
    "encasulem": "encasular",
    "encasulemo": "encasular",
    "encasulemos": "encasular",
    "encasules": "encasular",
    "encasulo": "encasular",
    "encasulou": "encasular",
    "encasulá": "encasular",
    "encasulámo": "encasular",
    "encasulámos": "encasular",
    "encasuláramo": "encasular",
    "encasuláramos": "encasular",
    "encasulárei": "encasular",
    "encasuláreis": "encasular",
    "encasulásseis": "encasular",
    "encasulássemos": "encasular",
    "encasulávamo": "encasular",
    "encasulávamos": "encasular",
    "encasulávei": "encasular",
    "encasuláveis": "encasular",
    "encasá": "encasar",
    "encasámo": "encasar",
    "encasámos": "encasar",
    "encasáramo": "encasar",
    "encasáramos": "encasar",
    "encasárei": "encasar",
    "encasáreis": "encasar",
    "encasásseis": "encasar",
    "encasássemos": "encasar",
    "encasávamo": "encasar",
    "encasávamos": "encasar",
    "encasávei": "encasar",
    "encasáveis": "encasar",
    "encatarra": "encatarrar",
    "encatarrada": "encatarrar",
    "encatarradas": "encatarrar",
    "encatarrado": "encatarrar",
    "encatarrados": "encatarrar",
    "encatarrai": "encatarrar",
    "encatarrais": "encatarrar",
    "encatarram": "encatarrar",
    "encatarramo": "encatarrar",
    "encatarramos": "encatarrar",
    "encatarrando": "encatarrar",
    "encatarrara": "encatarrar",
    "encatarraram": "encatarrar",
    "encatarraras": "encatarrar",
    "encatarrarde": "encatarrar",
    "encatarrardes": "encatarrar",
    "encatarrare": "encatarrar",
    "encatarrarei": "encatarrar",
    "encatarrareis": "encatarrar",
    "encatarrarem": "encatarrar",
    "encatarraremos": "encatarrar",
    "encatarrares": "encatarrar",
    "encatarraria": "encatarrar",
    "encatarrariam": "encatarrar",
    "encatarrarias": "encatarrar",
    "encatarrarmo": "encatarrar",
    "encatarrarmos": "encatarrar",
    "encatarrará": "encatarrar",
    "encatarrarás": "encatarrar",
    "encatarrarão": "encatarrar",
    "encatarraríamos": "encatarrar",
    "encatarraríeis": "encatarrar",
    "encatarras": "encatarrar",
    "encatarrasse": "encatarrar",
    "encatarrassem": "encatarrar",
    "encatarrasses": "encatarrar",
    "encatarraste": "encatarrar",
    "encatarrastes": "encatarrar",
    "encatarrava": "encatarrar",
    "encatarravam": "encatarrar",
    "encatarravas": "encatarrar",
    "encatarre": "encatarrar",
    "encatarrei": "encatarrar",
    "encatarreis": "encatarrar",
    "encatarrem": "encatarrar",
    "encatarremo": "encatarrar",
    "encatarremos": "encatarrar",
    "encatarres": "encatarrar",
    "encatarro": "encatarrar",
    "encatarroada": "encatarroado",
    "encatarroadas": "encatarroado",
    "encatarroados": "encatarroado",
    "encatarrou": "encatarrar",
    "encatarrá": "encatarrar",
    "encatarrámo": "encatarrar",
    "encatarrámos": "encatarrar",
    "encatarráramo": "encatarrar",
    "encatarráramos": "encatarrar",
    "encatarrárei": "encatarrar",
    "encatarráreis": "encatarrar",
    "encatarrásseis": "encatarrar",
    "encatarrássemos": "encatarrar",
    "encatarrávamo": "encatarrar",
    "encatarrávamos": "encatarrar",
    "encatarrávei": "encatarrar",
    "encatarráveis": "encatarrar",
    "encatrafia": "encatrafiar",
    "encatrafiada": "encatrafiar",
    "encatrafiadas": "encatrafiar",
    "encatrafiado": "encatrafiar",
    "encatrafiados": "encatrafiar",
    "encatrafiai": "encatrafiar",
    "encatrafiais": "encatrafiar",
    "encatrafiam": "encatrafiar",
    "encatrafiamo": "encatrafiar",
    "encatrafiamos": "encatrafiar",
    "encatrafiando": "encatrafiar",
    "encatrafiara": "encatrafiar",
    "encatrafiaram": "encatrafiar",
    "encatrafiaras": "encatrafiar",
    "encatrafiarde": "encatrafiar",
    "encatrafiardes": "encatrafiar",
    "encatrafiare": "encatrafiar",
    "encatrafiarei": "encatrafiar",
    "encatrafiareis": "encatrafiar",
    "encatrafiarem": "encatrafiar",
    "encatrafiaremos": "encatrafiar",
    "encatrafiares": "encatrafiar",
    "encatrafiaria": "encatrafiar",
    "encatrafiariam": "encatrafiar",
    "encatrafiarias": "encatrafiar",
    "encatrafiarmo": "encatrafiar",
    "encatrafiarmos": "encatrafiar",
    "encatrafiará": "encatrafiar",
    "encatrafiarás": "encatrafiar",
    "encatrafiarão": "encatrafiar",
    "encatrafiaríamos": "encatrafiar",
    "encatrafiaríeis": "encatrafiar",
    "encatrafias": "encatrafiar",
    "encatrafiasse": "encatrafiar",
    "encatrafiassem": "encatrafiar",
    "encatrafiasses": "encatrafiar",
    "encatrafiaste": "encatrafiar",
    "encatrafiastes": "encatrafiar",
    "encatrafiava": "encatrafiar",
    "encatrafiavam": "encatrafiar",
    "encatrafiavas": "encatrafiar",
    "encatrafie": "encatrafiar",
    "encatrafiei": "encatrafiar",
    "encatrafieis": "encatrafiar",
    "encatrafiem": "encatrafiar",
    "encatrafiemo": "encatrafiar",
    "encatrafiemos": "encatrafiar",
    "encatrafies": "encatrafiar",
    "encatrafio": "encatrafiar",
    "encatrafiou": "encatrafiar",
    "encatrafiá": "encatrafiar",
    "encatrafiámo": "encatrafiar",
    "encatrafiámos": "encatrafiar",
    "encatrafiáramo": "encatrafiar",
    "encatrafiáramos": "encatrafiar",
    "encatrafiárei": "encatrafiar",
    "encatrafiáreis": "encatrafiar",
    "encatrafiásseis": "encatrafiar",
    "encatrafiássemos": "encatrafiar",
    "encatrafiávamo": "encatrafiar",
    "encatrafiávamos": "encatrafiar",
    "encatrafiávei": "encatrafiar",
    "encatrafiáveis": "encatrafiar",
    "encatramona": "encatramonar",
    "encatramonada": "encatramonar",
    "encatramonadas": "encatramonar",
    "encatramonado": "encatramonar",
    "encatramonados": "encatramonar",
    "encatramonai": "encatramonar",
    "encatramonais": "encatramonar",
    "encatramonam": "encatramonar",
    "encatramonamo": "encatramonar",
    "encatramonamos": "encatramonar",
    "encatramonando": "encatramonar",
    "encatramonara": "encatramonar",
    "encatramonaram": "encatramonar",
    "encatramonaras": "encatramonar",
    "encatramonarde": "encatramonar",
    "encatramonardes": "encatramonar",
    "encatramonare": "encatramonar",
    "encatramonarei": "encatramonar",
    "encatramonareis": "encatramonar",
    "encatramonarem": "encatramonar",
    "encatramonaremos": "encatramonar",
    "encatramonares": "encatramonar",
    "encatramonaria": "encatramonar",
    "encatramonariam": "encatramonar",
    "encatramonarias": "encatramonar",
    "encatramonarmo": "encatramonar",
    "encatramonarmos": "encatramonar",
    "encatramonará": "encatramonar",
    "encatramonarás": "encatramonar",
    "encatramonarão": "encatramonar",
    "encatramonaríamos": "encatramonar",
    "encatramonaríeis": "encatramonar",
    "encatramonas": "encatramonar",
    "encatramonasse": "encatramonar",
    "encatramonassem": "encatramonar",
    "encatramonasses": "encatramonar",
    "encatramonaste": "encatramonar",
    "encatramonastes": "encatramonar",
    "encatramonava": "encatramonar",
    "encatramonavam": "encatramonar",
    "encatramonavas": "encatramonar",
    "encatramone": "encatramonar",
    "encatramonei": "encatramonar",
    "encatramoneis": "encatramonar",
    "encatramonem": "encatramonar",
    "encatramonemo": "encatramonar",
    "encatramonemos": "encatramonar",
    "encatramones": "encatramonar",
    "encatramono": "encatramonar",
    "encatramonou": "encatramonar",
    "encatramoná": "encatramonar",
    "encatramonámo": "encatramonar",
    "encatramonámos": "encatramonar",
    "encatramonáramo": "encatramonar",
    "encatramonáramos": "encatramonar",
    "encatramonárei": "encatramonar",
    "encatramonáreis": "encatramonar",
    "encatramonásseis": "encatramonar",
    "encatramonássemos": "encatramonar",
    "encatramonávamo": "encatramonar",
    "encatramonávamos": "encatramonar",
    "encatramonávei": "encatramonar",
    "encatramonáveis": "encatramonar",
    "encaustas": "encausta",
    "encaustica": "encausticar",
    "encausticada": "encausticar",
    "encausticadas": "encausticar",
    "encausticado": "encausticar",
    "encausticados": "encausticar",
    "encausticai": "encausticar",
    "encausticais": "encausticar",
    "encausticam": "encausticar",
    "encausticamo": "encausticar",
    "encausticamos": "encausticar",
    "encausticando": "encausticar",
    "encausticara": "encausticar",
    "encausticaram": "encausticar",
    "encausticaras": "encausticar",
    "encausticarde": "encausticar",
    "encausticardes": "encausticar",
    "encausticare": "encausticar",
    "encausticarei": "encausticar",
    "encausticareis": "encausticar",
    "encausticarem": "encausticar",
    "encausticaremos": "encausticar",
    "encausticares": "encausticar",
    "encausticaria": "encausticar",
    "encausticariam": "encausticar",
    "encausticarias": "encausticar",
    "encausticarmo": "encausticar",
    "encausticarmos": "encausticar",
    "encausticará": "encausticar",
    "encausticarás": "encausticar",
    "encausticarão": "encausticar",
    "encausticaríamos": "encausticar",
    "encausticaríeis": "encausticar",
    "encausticas": "encausticar",
    "encausticasse": "encausticar",
    "encausticassem": "encausticar",
    "encausticasses": "encausticar",
    "encausticaste": "encausticar",
    "encausticastes": "encausticar",
    "encausticava": "encausticar",
    "encausticavam": "encausticar",
    "encausticavas": "encausticar",
    "encaustico": "encausticar",
    "encausticou": "encausticar",
    "encausticá": "encausticar",
    "encausticámo": "encausticar",
    "encausticámos": "encausticar",
    "encausticáramo": "encausticar",
    "encausticáramos": "encausticar",
    "encausticárei": "encausticar",
    "encausticáreis": "encausticar",
    "encausticásseis": "encausticar",
    "encausticássemos": "encausticar",
    "encausticávamo": "encausticar",
    "encausticávamos": "encausticar",
    "encausticávei": "encausticar",
    "encausticáveis": "encausticar",
    "encaustique": "encausticar",
    "encaustiquei": "encausticar",
    "encaustiqueis": "encausticar",
    "encaustiquem": "encausticar",
    "encaustiquemo": "encausticar",
    "encaustiquemos": "encausticar",
    "encaustiques": "encausticar",
    "encava": "encavar",
    "encavaca": "encavacar",
    "encavacada": "encavacar",
    "encavacadas": "encavacar",
    "encavacadelas": "encavacadela",
    "encavacado": "encavacar",
    "encavacados": "encavacar",
    "encavacadíssima": "encavacado",
    "encavacadíssimas": "encavacado",
    "encavacadíssimo": "encavacado",
    "encavacadíssimos": "encavacado",
    "encavacai": "encavacar",
    "encavacais": "encavacar",
    "encavacam": "encavacar",
    "encavacamo": "encavacar",
    "encavacamos": "encavacar",
    "encavacando": "encavacar",
    "encavacara": "encavacar",
    "encavacaram": "encavacar",
    "encavacaras": "encavacar",
    "encavacarde": "encavacar",
    "encavacardes": "encavacar",
    "encavacare": "encavacar",
    "encavacarei": "encavacar",
    "encavacareis": "encavacar",
    "encavacarem": "encavacar",
    "encavacaremos": "encavacar",
    "encavacares": "encavacar",
    "encavacaria": "encavacar",
    "encavacariam": "encavacar",
    "encavacarias": "encavacar",
    "encavacarmo": "encavacar",
    "encavacarmos": "encavacar",
    "encavacará": "encavacar",
    "encavacarás": "encavacar",
    "encavacarão": "encavacar",
    "encavacaríamos": "encavacar",
    "encavacaríeis": "encavacar",
    "encavacas": "encavacar",
    "encavacasse": "encavacar",
    "encavacassem": "encavacar",
    "encavacasses": "encavacar",
    "encavacaste": "encavacar",
    "encavacastes": "encavacar",
    "encavacava": "encavacar",
    "encavacavam": "encavacar",
    "encavacavas": "encavacar",
    "encavacações": "encavacação",
    "encavaco": "encavacar",
    "encavacou": "encavacar",
    "encavacá": "encavacar",
    "encavacámo": "encavacar",
    "encavacámos": "encavacar",
    "encavacáramo": "encavacar",
    "encavacáramos": "encavacar",
    "encavacárei": "encavacar",
    "encavacáreis": "encavacar",
    "encavacásseis": "encavacar",
    "encavacássemos": "encavacar",
    "encavacávamo": "encavacar",
    "encavacávamos": "encavacar",
    "encavacávei": "encavacar",
    "encavacáveis": "encavacar",
    "encavada": "encavar",
    "encavadas": "encavar",
    "encavadelas": "encavadela",
    "encavado": "encavar",
    "encavados": "encavar",
    "encavai": "encavar",
    "encavais": "encavar",
    "encavala": "encavalar",
    "encavalada": "encavalar",
    "encavaladas": "encavalar",
    "encavalado": "encavalar",
    "encavalados": "encavalar",
    "encavalai": "encavalar",
    "encavalais": "encavalar",
    "encavalam": "encavalar",
    "encavalamo": "encavalar",
    "encavalamos": "encavalar",
    "encavalando": "encavalar",
    "encavalara": "encavalar",
    "encavalaram": "encavalar",
    "encavalaras": "encavalar",
    "encavalarde": "encavalar",
    "encavalardes": "encavalar",
    "encavalare": "encavalar",
    "encavalarei": "encavalar",
    "encavalareis": "encavalar",
    "encavalarem": "encavalar",
    "encavalaremos": "encavalar",
    "encavalares": "encavalar",
    "encavalaria": "encavalar",
    "encavalariam": "encavalar",
    "encavalarias": "encavalar",
    "encavalarmo": "encavalar",
    "encavalarmos": "encavalar",
    "encavalará": "encavalar",
    "encavalarás": "encavalar",
    "encavalarão": "encavalar",
    "encavalaríamos": "encavalar",
    "encavalaríeis": "encavalar",
    "encavalas": "encavalar",
    "encavalasse": "encavalar",
    "encavalassem": "encavalar",
    "encavalasses": "encavalar",
    "encavalaste": "encavalar",
    "encavalastes": "encavalar",
    "encavalava": "encavalar",
    "encavalavam": "encavalar",
    "encavalavas": "encavalar",
    "encavale": "encavalar",
    "encavalei": "encavalar",
    "encavaleira": "encavaleirar",
    "encavaleirada": "encavaleirar",
    "encavaleiradas": "encavaleirar",
    "encavaleirado": "encavaleirar",
    "encavaleirados": "encavaleirar",
    "encavaleirai": "encavaleirar",
    "encavaleirais": "encavaleirar",
    "encavaleiram": "encavaleirar",
    "encavaleiramo": "encavaleirar",
    "encavaleiramos": "encavaleirar",
    "encavaleirando": "encavaleirar",
    "encavaleirara": "encavaleirar",
    "encavaleiraram": "encavaleirar",
    "encavaleiraras": "encavaleirar",
    "encavaleirarde": "encavaleirar",
    "encavaleirardes": "encavaleirar",
    "encavaleirare": "encavaleirar",
    "encavaleirarei": "encavaleirar",
    "encavaleirareis": "encavaleirar",
    "encavaleirarem": "encavaleirar",
    "encavaleiraremos": "encavaleirar",
    "encavaleirares": "encavaleirar",
    "encavaleiraria": "encavaleirar",
    "encavaleirariam": "encavaleirar",
    "encavaleirarias": "encavaleirar",
    "encavaleirarmo": "encavaleirar",
    "encavaleirarmos": "encavaleirar",
    "encavaleirará": "encavaleirar",
    "encavaleirarás": "encavaleirar",
    "encavaleirarão": "encavaleirar",
    "encavaleiraríamos": "encavaleirar",
    "encavaleiraríeis": "encavaleirar",
    "encavaleiras": "encavaleirar",
    "encavaleirasse": "encavaleirar",
    "encavaleirassem": "encavaleirar",
    "encavaleirasses": "encavaleirar",
    "encavaleiraste": "encavaleirar",
    "encavaleirastes": "encavaleirar",
    "encavaleirava": "encavaleirar",
    "encavaleiravam": "encavaleirar",
    "encavaleiravas": "encavaleirar",
    "encavaleire": "encavaleirar",
    "encavaleirei": "encavaleirar",
    "encavaleireis": "encavaleirar",
    "encavaleirem": "encavaleirar",
    "encavaleiremo": "encavaleirar",
    "encavaleiremos": "encavaleirar",
    "encavaleires": "encavaleirar",
    "encavaleiro": "encavaleirar",
    "encavaleirou": "encavaleirar",
    "encavaleirá": "encavaleirar",
    "encavaleirámo": "encavaleirar",
    "encavaleirámos": "encavaleirar",
    "encavaleiráramo": "encavaleirar",
    "encavaleiráramos": "encavaleirar",
    "encavaleirárei": "encavaleirar",
    "encavaleiráreis": "encavaleirar",
    "encavaleirásseis": "encavaleirar",
    "encavaleirássemos": "encavaleirar",
    "encavaleirávamo": "encavaleirar",
    "encavaleirávamos": "encavaleirar",
    "encavaleirávei": "encavaleirar",
    "encavaleiráveis": "encavaleirar",
    "encavaleis": "encavalar",
    "encavalem": "encavalar",
    "encavalemo": "encavalar",
    "encavalemos": "encavalar",
    "encavales": "encavalar",
    "encavalga": "encavalgar",
    "encavalgada": "encavalgar",
    "encavalgadas": "encavalgar",
    "encavalgado": "encavalgar",
    "encavalgados": "encavalgar",
    "encavalgai": "encavalgar",
    "encavalgais": "encavalgar",
    "encavalgam": "encavalgar",
    "encavalgamentos": "encavalgamento",
    "encavalgamo": "encavalgar",
    "encavalgamos": "encavalgar",
    "encavalgando": "encavalgar",
    "encavalgara": "encavalgar",
    "encavalgaram": "encavalgar",
    "encavalgaras": "encavalgar",
    "encavalgarde": "encavalgar",
    "encavalgardes": "encavalgar",
    "encavalgare": "encavalgar",
    "encavalgarei": "encavalgar",
    "encavalgareis": "encavalgar",
    "encavalgarem": "encavalgar",
    "encavalgaremos": "encavalgar",
    "encavalgares": "encavalgar",
    "encavalgaria": "encavalgar",
    "encavalgariam": "encavalgar",
    "encavalgarias": "encavalgar",
    "encavalgarmo": "encavalgar",
    "encavalgarmos": "encavalgar",
    "encavalgará": "encavalgar",
    "encavalgarás": "encavalgar",
    "encavalgarão": "encavalgar",
    "encavalgaríamos": "encavalgar",
    "encavalgaríeis": "encavalgar",
    "encavalgas": "encavalgar",
    "encavalgasse": "encavalgar",
    "encavalgassem": "encavalgar",
    "encavalgasses": "encavalgar",
    "encavalgaste": "encavalgar",
    "encavalgastes": "encavalgar",
    "encavalgava": "encavalgar",
    "encavalgavam": "encavalgar",
    "encavalgavas": "encavalgar",
    "encavalgo": "encavalgar",
    "encavalgou": "encavalgar",
    "encavalgue": "encavalgar",
    "encavalguei": "encavalgar",
    "encavalgueis": "encavalgar",
    "encavalguem": "encavalgar",
    "encavalguemo": "encavalgar",
    "encavalguemos": "encavalgar",
    "encavalgues": "encavalgar",
    "encavalgá": "encavalgar",
    "encavalgámo": "encavalgar",
    "encavalgámos": "encavalgar",
    "encavalgáramo": "encavalgar",
    "encavalgáramos": "encavalgar",
    "encavalgárei": "encavalgar",
    "encavalgáreis": "encavalgar",
    "encavalgásseis": "encavalgar",
    "encavalgássemos": "encavalgar",
    "encavalgávamo": "encavalgar",
    "encavalgávamos": "encavalgar",
    "encavalgávei": "encavalgar",
    "encavalgáveis": "encavalgar",
    "encavalita": "encavalitar",
    "encavalitada": "encavalitar",
    "encavalitadas": "encavalitar",
    "encavalitado": "encavalitar",
    "encavalitados": "encavalitar",
    "encavalitai": "encavalitar",
    "encavalitais": "encavalitar",
    "encavalitam": "encavalitar",
    "encavalitamo": "encavalitar",
    "encavalitamos": "encavalitar",
    "encavalitando": "encavalitar",
    "encavalitara": "encavalitar",
    "encavalitaram": "encavalitar",
    "encavalitaras": "encavalitar",
    "encavalitarde": "encavalitar",
    "encavalitardes": "encavalitar",
    "encavalitare": "encavalitar",
    "encavalitarei": "encavalitar",
    "encavalitareis": "encavalitar",
    "encavalitarem": "encavalitar",
    "encavalitaremos": "encavalitar",
    "encavalitares": "encavalitar",
    "encavalitaria": "encavalitar",
    "encavalitariam": "encavalitar",
    "encavalitarias": "encavalitar",
    "encavalitarmo": "encavalitar",
    "encavalitarmos": "encavalitar",
    "encavalitará": "encavalitar",
    "encavalitarás": "encavalitar",
    "encavalitarão": "encavalitar",
    "encavalitaríamos": "encavalitar",
    "encavalitaríeis": "encavalitar",
    "encavalitas": "encavalitar",
    "encavalitasse": "encavalitar",
    "encavalitassem": "encavalitar",
    "encavalitasses": "encavalitar",
    "encavalitaste": "encavalitar",
    "encavalitastes": "encavalitar",
    "encavalitava": "encavalitar",
    "encavalitavam": "encavalitar",
    "encavalitavas": "encavalitar",
    "encavalite": "encavalitar",
    "encavalitei": "encavalitar",
    "encavaliteis": "encavalitar",
    "encavalitem": "encavalitar",
    "encavalitemo": "encavalitar",
    "encavalitemos": "encavalitar",
    "encavalites": "encavalitar",
    "encavalito": "encavalitar",
    "encavalitou": "encavalitar",
    "encavalitá": "encavalitar",
    "encavalitámo": "encavalitar",
    "encavalitámos": "encavalitar",
    "encavalitáramo": "encavalitar",
    "encavalitáramos": "encavalitar",
    "encavalitárei": "encavalitar",
    "encavalitáreis": "encavalitar",
    "encavalitásseis": "encavalitar",
    "encavalitássemos": "encavalitar",
    "encavalitávamo": "encavalitar",
    "encavalitávamos": "encavalitar",
    "encavalitávei": "encavalitar",
    "encavalitáveis": "encavalitar",
    "encavalo": "encavalar",
    "encavalou": "encavalar",
    "encavalá": "encavalar",
    "encavalámo": "encavalar",
    "encavalámos": "encavalar",
    "encavaláramo": "encavalar",
    "encavaláramos": "encavalar",
    "encavalárei": "encavalar",
    "encavaláreis": "encavalar",
    "encavalásseis": "encavalar",
    "encavalássemos": "encavalar",
    "encavalávamo": "encavalar",
    "encavalávamos": "encavalar",
    "encavalávei": "encavalar",
    "encavaláveis": "encavalar",
    "encavam": "encavar",
    "encavamo": "encavar",
    "encavamos": "encavar",
    "encavando": "encavar",
    "encavaque": "encavacar",
    "encavaquei": "encavacar",
    "encavaqueis": "encavacar",
    "encavaquem": "encavacar",
    "encavaquemo": "encavacar",
    "encavaquemos": "encavacar",
    "encavaques": "encavacar",
    "encavara": "encavar",
    "encavaram": "encavar",
    "encavaras": "encavar",
    "encavarde": "encavar",
    "encavardes": "encavar",
    "encavare": "encavar",
    "encavarei": "encavar",
    "encavareis": "encavar",
    "encavarem": "encavar",
    "encavaremos": "encavar",
    "encavares": "encavar",
    "encavaria": "encavar",
    "encavariam": "encavar",
    "encavarias": "encavar",
    "encavarmo": "encavar",
    "encavarmos": "encavar",
    "encavará": "encavar",
    "encavarás": "encavar",
    "encavarão": "encavar",
    "encavaríamos": "encavar",
    "encavaríeis": "encavar",
    "encavas": "encavar",
    "encavasse": "encavar",
    "encavassem": "encavar",
    "encavasses": "encavar",
    "encavaste": "encavar",
    "encavastes": "encavar",
    "encavava": "encavar",
    "encavavam": "encavar",
    "encavavas": "encavar",
    "encave": "encavar",
    "encavei": "encavar",
    "encaveis": "encavar",
    "encavem": "encavar",
    "encavemo": "encavar",
    "encavemos": "encavar",
    "encaverna": "encavernar",
    "encavernada": "encavernar",
    "encavernadas": "encavernar",
    "encavernado": "encavernar",
    "encavernados": "encavernar",
    "encavernai": "encavernar",
    "encavernais": "encavernar",
    "encavernam": "encavernar",
    "encavernamo": "encavernar",
    "encavernamos": "encavernar",
    "encavernando": "encavernar",
    "encavernara": "encavernar",
    "encavernaram": "encavernar",
    "encavernaras": "encavernar",
    "encavernarde": "encavernar",
    "encavernardes": "encavernar",
    "encavernare": "encavernar",
    "encavernarei": "encavernar",
    "encavernareis": "encavernar",
    "encavernarem": "encavernar",
    "encavernaremos": "encavernar",
    "encavernares": "encavernar",
    "encavernaria": "encavernar",
    "encavernariam": "encavernar",
    "encavernarias": "encavernar",
    "encavernarmo": "encavernar",
    "encavernarmos": "encavernar",
    "encavernará": "encavernar",
    "encavernarás": "encavernar",
    "encavernarão": "encavernar",
    "encavernaríamos": "encavernar",
    "encavernaríeis": "encavernar",
    "encavernas": "encavernar",
    "encavernasse": "encavernar",
    "encavernassem": "encavernar",
    "encavernasses": "encavernar",
    "encavernaste": "encavernar",
    "encavernastes": "encavernar",
    "encavernava": "encavernar",
    "encavernavam": "encavernar",
    "encavernavas": "encavernar",
    "encaverne": "encavernar",
    "encavernei": "encavernar",
    "encaverneis": "encavernar",
    "encavernem": "encavernar",
    "encavernemo": "encavernar",
    "encavernemos": "encavernar",
    "encavernes": "encavernar",
    "encaverno": "encavernar",
    "encavernou": "encavernar",
    "encaverná": "encavernar",
    "encavernámo": "encavernar",
    "encavernámos": "encavernar",
    "encavernáramo": "encavernar",
    "encavernáramos": "encavernar",
    "encavernárei": "encavernar",
    "encavernáreis": "encavernar",
    "encavernásseis": "encavernar",
    "encavernássemos": "encavernar",
    "encavernávamo": "encavernar",
    "encavernávamos": "encavernar",
    "encavernávei": "encavernar",
    "encavernáveis": "encavernar",
    "encaves": "encavar",
    "encavilha": "encavilhar",
    "encavilhada": "encavilhar",
    "encavilhadas": "encavilhar",
    "encavilhado": "encavilhar",
    "encavilhados": "encavilhar",
    "encavilhai": "encavilhar",
    "encavilhais": "encavilhar",
    "encavilham": "encavilhar",
    "encavilhamo": "encavilhar",
    "encavilhamos": "encavilhar",
    "encavilhando": "encavilhar",
    "encavilhara": "encavilhar",
    "encavilharam": "encavilhar",
    "encavilharas": "encavilhar",
    "encavilharde": "encavilhar",
    "encavilhardes": "encavilhar",
    "encavilhare": "encavilhar",
    "encavilharei": "encavilhar",
    "encavilhareis": "encavilhar",
    "encavilharem": "encavilhar",
    "encavilharemos": "encavilhar",
    "encavilhares": "encavilhar",
    "encavilharia": "encavilhar",
    "encavilhariam": "encavilhar",
    "encavilharias": "encavilhar",
    "encavilharmo": "encavilhar",
    "encavilharmos": "encavilhar",
    "encavilhará": "encavilhar",
    "encavilharás": "encavilhar",
    "encavilharão": "encavilhar",
    "encavilharíamos": "encavilhar",
    "encavilharíeis": "encavilhar",
    "encavilhas": "encavilhar",
    "encavilhasse": "encavilhar",
    "encavilhassem": "encavilhar",
    "encavilhasses": "encavilhar",
    "encavilhaste": "encavilhar",
    "encavilhastes": "encavilhar",
    "encavilhava": "encavilhar",
    "encavilhavam": "encavilhar",
    "encavilhavas": "encavilhar",
    "encavilhe": "encavilhar",
    "encavilhei": "encavilhar",
    "encavilheis": "encavilhar",
    "encavilhem": "encavilhar",
    "encavilhemo": "encavilhar",
    "encavilhemos": "encavilhar",
    "encavilhes": "encavilhar",
    "encavilho": "encavilhar",
    "encavilhou": "encavilhar",
    "encavilhá": "encavilhar",
    "encavilhámo": "encavilhar",
    "encavilhámos": "encavilhar",
    "encavilháramo": "encavilhar",
    "encavilháramos": "encavilhar",
    "encavilhárei": "encavilhar",
    "encavilháreis": "encavilhar",
    "encavilhásseis": "encavilhar",
    "encavilhássemos": "encavilhar",
    "encavilhávamo": "encavilhar",
    "encavilhávamos": "encavilhar",
    "encavilhávei": "encavilhar",
    "encavilháveis": "encavilhar",
    "encavo": "encavar",
    "encavos": "encavo",
    "encavou": "encavar",
    "encavá": "encavar",
    "encavámo": "encavar",
    "encavámos": "encavar",
    "encaváramo": "encavar",
    "encaváramos": "encavar",
    "encavárei": "encavar",
    "encaváreis": "encavar",
    "encavásseis": "encavar",
    "encavássemos": "encavar",
    "encavávamo": "encavar",
    "encavávamos": "encavar",
    "encavávei": "encavar",
    "encaváveis": "encavar",
    "encedecimentos": "encedecimento",
    "encefalagias": "encefalagia",
    "encefalias": "encefalia",
    "encefalites": "encefalite",
    "encefaloceles": "encefalocele",
    "encefalografias": "encefalografia",
    "encefalogramas": "encefalograma",
    "encefalográfica": "encefalográfico",
    "encefalográficas": "encefalográfico",
    "encefalográficos": "encefalográfico",
    "encefalologias": "encefalologia",
    "encefalolítica": "encefalolítico",
    "encefalolíticas": "encefalolítico",
    "encefalolíticos": "encefalolítico",
    "encefalológica": "encefalológico",
    "encefalológicas": "encefalológico",
    "encefalológicos": "encefalológico",
    "encefalopatas": "encefalopata",
    "encefalopatias": "encefalopatia",
    "encefalopática": "encefalopático",
    "encefalopáticas": "encefalopático",
    "encefalopáticos": "encefalopático",
    "encefalógrafos": "encefalógrafo",
    "encefalóides": "encefalóide",
    "encefalóloga": "encefalólogo",
    "encefalólogas": "encefalólogo",
    "encefalólogos": "encefalólogo",
    "encefálica": "encefálico",
    "encefálicas": "encefálico",
    "encefálicos": "encefálico",
    "enceguece": "enceguecer",
    "enceguecei": "enceguecer",
    "encegueceis": "enceguecer",
    "enceguecem": "enceguecer",
    "enceguecemo": "enceguecer",
    "enceguecemos": "enceguecer",
    "enceguecendo": "enceguecer",
    "enceguecera": "enceguecer",
    "encegueceram": "enceguecer",
    "encegueceras": "enceguecer",
    "enceguecerde": "enceguecer",
    "enceguecerdes": "enceguecer",
    "enceguecere": "enceguecer",
    "enceguecerei": "enceguecer",
    "enceguecereis": "enceguecer",
    "enceguecerem": "enceguecer",
    "encegueceremos": "enceguecer",
    "encegueceres": "enceguecer",
    "encegueceria": "enceguecer",
    "encegueceriam": "enceguecer",
    "enceguecerias": "enceguecer",
    "enceguecermo": "enceguecer",
    "enceguecermos": "enceguecer",
    "enceguecerá": "enceguecer",
    "enceguecerás": "enceguecer",
    "enceguecerão": "enceguecer",
    "encegueceríamos": "enceguecer",
    "encegueceríeis": "enceguecer",
    "encegueces": "enceguecer",
    "enceguecesse": "enceguecer",
    "enceguecessem": "enceguecer",
    "enceguecesses": "enceguecer",
    "encegueceste": "enceguecer",
    "enceguecestes": "enceguecer",
    "encegueceu": "enceguecer",
    "encegueci": "enceguecer",
    "enceguecia": "enceguecer",
    "encegueciam": "enceguecer",
    "enceguecias": "enceguecer",
    "enceguecida": "enceguecer",
    "enceguecidas": "enceguecer",
    "enceguecido": "enceguecer",
    "enceguecidos": "enceguecer",
    "enceguecê": "enceguecer",
    "enceguecêramo": "enceguecer",
    "enceguecêramos": "enceguecer",
    "enceguecêrei": "enceguecer",
    "enceguecêreis": "enceguecer",
    "enceguecêsseis": "enceguecer",
    "enceguecêssemos": "enceguecer",
    "enceguecíamo": "enceguecer",
    "enceguecíamos": "enceguecer",
    "enceguecíei": "enceguecer",
    "enceguecíeis": "enceguecer",
    "encegueira": "encegueirar",
    "encegueirada": "encegueirar",
    "encegueiradas": "encegueirar",
    "encegueirado": "encegueirar",
    "encegueirados": "encegueirar",
    "encegueirai": "encegueirar",
    "encegueirais": "encegueirar",
    "encegueiram": "encegueirar",
    "encegueiramo": "encegueirar",
    "encegueiramos": "encegueirar",
    "encegueirando": "encegueirar",
    "encegueirara": "encegueirar",
    "encegueiraram": "encegueirar",
    "encegueiraras": "encegueirar",
    "encegueirarde": "encegueirar",
    "encegueirardes": "encegueirar",
    "encegueirare": "encegueirar",
    "encegueirarei": "encegueirar",
    "encegueirareis": "encegueirar",
    "encegueirarem": "encegueirar",
    "encegueiraremos": "encegueirar",
    "encegueirares": "encegueirar",
    "encegueiraria": "encegueirar",
    "encegueirariam": "encegueirar",
    "encegueirarias": "encegueirar",
    "encegueirarmo": "encegueirar",
    "encegueirarmos": "encegueirar",
    "encegueirará": "encegueirar",
    "encegueirarás": "encegueirar",
    "encegueirarão": "encegueirar",
    "encegueiraríamos": "encegueirar",
    "encegueiraríeis": "encegueirar",
    "encegueiras": "encegueirar",
    "encegueirasse": "encegueirar",
    "encegueirassem": "encegueirar",
    "encegueirasses": "encegueirar",
    "encegueiraste": "encegueirar",
    "encegueirastes": "encegueirar",
    "encegueirava": "encegueirar",
    "encegueiravam": "encegueirar",
    "encegueiravas": "encegueirar",
    "encegueire": "encegueirar",
    "encegueirei": "encegueirar",
    "encegueireis": "encegueirar",
    "encegueirem": "encegueirar",
    "encegueiremo": "encegueirar",
    "encegueiremos": "encegueirar",
    "encegueires": "encegueirar",
    "encegueiro": "encegueirar",
    "encegueirou": "encegueirar",
    "encegueirá": "encegueirar",
    "encegueirámo": "encegueirar",
    "encegueirámos": "encegueirar",
    "encegueiráramo": "encegueirar",
    "encegueiráramos": "encegueirar",
    "encegueirárei": "encegueirar",
    "encegueiráreis": "encegueirar",
    "encegueirásseis": "encegueirar",
    "encegueirássemos": "encegueirar",
    "encegueirávamo": "encegueirar",
    "encegueirávamos": "encegueirar",
    "encegueirávei": "encegueirar",
    "encegueiráveis": "encegueirar",
    "encegueça": "enceguecer",
    "encegueçais": "enceguecer",
    "encegueçam": "enceguecer",
    "encegueçamo": "enceguecer",
    "encegueçamos": "enceguecer",
    "encegueças": "enceguecer",
    "encegueço": "enceguecer",
    "encela": "encelar",
    "encelada": "encelar",
    "enceladas": "encelar",
    "encelado": "encelar",
    "encelados": "encelar",
    "encelai": "encelar",
    "encelais": "encelar",
    "encelam": "encelar",
    "encelamo": "encelar",
    "encelamos": "encelar",
    "encelando": "encelar",
    "encelara": "encelar",
    "encelaram": "encelar",
    "encelaras": "encelar",
    "encelarde": "encelar",
    "encelardes": "encelar",
    "encelare": "encelar",
    "encelarei": "encelar",
    "encelareis": "encelar",
    "encelarem": "encelar",
    "encelaremos": "encelar",
    "encelares": "encelar",
    "encelaria": "encelar",
    "encelariam": "encelar",
    "encelarias": "encelar",
    "encelarmo": "encelar",
    "encelarmos": "encelar",
    "encelará": "encelar",
    "encelarás": "encelar",
    "encelarão": "encelar",
    "encelaríamos": "encelar",
    "encelaríeis": "encelar",
    "encelas": "encelar",
    "encelasse": "encelar",
    "encelassem": "encelar",
    "encelasses": "encelar",
    "encelaste": "encelar",
    "encelastes": "encelar",
    "encelava": "encelar",
    "encelavam": "encelar",
    "encelavas": "encelar",
    "encele": "encelar",
    "encelei": "encelar",
    "enceleira": "enceleirar",
    "enceleirada": "enceleirar",
    "enceleiradas": "enceleirar",
    "enceleirado": "enceleirar",
    "enceleirados": "enceleirar",
    "enceleirai": "enceleirar",
    "enceleirais": "enceleirar",
    "enceleiram": "enceleirar",
    "enceleiramentos": "enceleiramento",
    "enceleiramo": "enceleirar",
    "enceleiramos": "enceleirar",
    "enceleirando": "enceleirar",
    "enceleirara": "enceleirar",
    "enceleiraram": "enceleirar",
    "enceleiraras": "enceleirar",
    "enceleirarde": "enceleirar",
    "enceleirardes": "enceleirar",
    "enceleirare": "enceleirar",
    "enceleirarei": "enceleirar",
    "enceleirareis": "enceleirar",
    "enceleirarem": "enceleirar",
    "enceleiraremos": "enceleirar",
    "enceleirares": "enceleirar",
    "enceleiraria": "enceleirar",
    "enceleirariam": "enceleirar",
    "enceleirarias": "enceleirar",
    "enceleirarmo": "enceleirar",
    "enceleirarmos": "enceleirar",
    "enceleirará": "enceleirar",
    "enceleirarás": "enceleirar",
    "enceleirarão": "enceleirar",
    "enceleiraríamos": "enceleirar",
    "enceleiraríeis": "enceleirar",
    "enceleiras": "enceleirar",
    "enceleirasse": "enceleirar",
    "enceleirassem": "enceleirar",
    "enceleirasses": "enceleirar",
    "enceleiraste": "enceleirar",
    "enceleirastes": "enceleirar",
    "enceleirava": "enceleirar",
    "enceleiravam": "enceleirar",
    "enceleiravas": "enceleirar",
    "enceleire": "enceleirar",
    "enceleirei": "enceleirar",
    "enceleireis": "enceleirar",
    "enceleirem": "enceleirar",
    "enceleiremo": "enceleirar",
    "enceleiremos": "enceleirar",
    "enceleires": "enceleirar",
    "enceleiro": "enceleirar",
    "enceleirou": "enceleirar",
    "enceleirá": "enceleirar",
    "enceleirámo": "enceleirar",
    "enceleirámos": "enceleirar",
    "enceleiráramo": "enceleirar",
    "enceleiráramos": "enceleirar",
    "enceleirárei": "enceleirar",
    "enceleiráreis": "enceleirar",
    "enceleirásseis": "enceleirar",
    "enceleirássemos": "enceleirar",
    "enceleirávamo": "enceleirar",
    "enceleirávamos": "enceleirar",
    "enceleirávei": "enceleirar",
    "enceleiráveis": "enceleirar",
    "enceleis": "encelar",
    "encelem": "encelar",
    "encelemo": "encelar",
    "encelemos": "encelar",
    "enceles": "encelar",
    "encelo": "encelar",
    "encelou": "encelar",
    "encelá": "encelar",
    "encelámo": "encelar",
    "encelámos": "encelar",
    "enceláramo": "encelar",
    "enceláramos": "encelar",
    "encelárei": "encelar",
    "enceláreis": "encelar",
    "encelásseis": "encelar",
    "encelássemos": "encelar",
    "encelávamo": "encelar",
    "encelávamos": "encelar",
    "encelávei": "encelar",
    "enceláveis": "encelar",
    "encena": "encenar",
    "encenada": "encenar",
    "encenadas": "encenar",
    "encenado": "encenar",
    "encenadora": "encenador",
    "encenadoras": "encenador",
    "encenadores": "encenador",
    "encenados": "encenar",
    "encenai": "encenar",
    "encenais": "encenar",
    "encenam": "encenar",
    "encenamo": "encenar",
    "encenamos": "encenar",
    "encenando": "encenar",
    "encenara": "encenar",
    "encenaram": "encenar",
    "encenaras": "encenar",
    "encenarde": "encenar",
    "encenardes": "encenar",
    "encenare": "encenar",
    "encenarei": "encenar",
    "encenareis": "encenar",
    "encenarem": "encenar",
    "encenaremos": "encenar",
    "encenares": "encenar",
    "encenaria": "encenar",
    "encenariam": "encenar",
    "encenarias": "encenar",
    "encenarmo": "encenar",
    "encenarmos": "encenar",
    "encenará": "encenar",
    "encenarás": "encenar",
    "encenarão": "encenar",
    "encenaríamos": "encenar",
    "encenaríeis": "encenar",
    "encenas": "encenar",
    "encenasse": "encenar",
    "encenassem": "encenar",
    "encenasses": "encenar",
    "encenaste": "encenar",
    "encenastes": "encenar",
    "encenava": "encenar",
    "encenavam": "encenar",
    "encenavas": "encenar",
    "encenações": "encenação",
    "encenda": "encender",
    "encendais": "encender",
    "encendam": "encender",
    "encendamo": "encender",
    "encendamos": "encender",
    "encendas": "encender",
    "encende": "encender",
    "encendei": "encender",
    "encendeis": "encender",
    "encendem": "encender",
    "encendemo": "encender",
    "encendemos": "encender",
    "encendendo": "encender",
    "encendera": "encender",
    "encenderam": "encender",
    "encenderas": "encender",
    "encenderde": "encender",
    "encenderdes": "encender",
    "encendere": "encender",
    "encenderei": "encender",
    "encendereis": "encender",
    "encenderem": "encender",
    "encenderemos": "encender",
    "encenderes": "encender",
    "encenderia": "encender",
    "encenderiam": "encender",
    "encenderias": "encender",
    "encendermo": "encender",
    "encendermos": "encender",
    "encenderá": "encender",
    "encenderás": "encender",
    "encenderão": "encender",
    "encenderíamos": "encender",
    "encenderíeis": "encender",
    "encendes": "encender",
    "encendesse": "encender",
    "encendessem": "encender",
    "encendesses": "encender",
    "encendeste": "encender",
    "encendestes": "encender",
    "encendeu": "encender",
    "encendi": "encender",
    "encendia": "encender",
    "encendiam": "encender",
    "encendias": "encender",
    "encendida": "encender",
    "encendidas": "encender",
    "encendido": "encender",
    "encendidos": "encender",
    "encendo": "encender",
    "encendê": "encender",
    "encendêramo": "encender",
    "encendêramos": "encender",
    "encendêrei": "encender",
    "encendêreis": "encender",
    "encendêsseis": "encender",
    "encendêssemos": "encender",
    "encendíamo": "encender",
    "encendíamos": "encender",
    "encendíei": "encender",
    "encendíeis": "encender",
    "encene": "encenar",
    "encenei": "encenar",
    "enceneis": "encenar",
    "encenem": "encenar",
    "encenemo": "encenar",
    "encenemos": "encenar",
    "encenes": "encenar",
    "enceno": "encenar",
    "encenou": "encenar",
    "encená": "encenar",
    "encenámo": "encenar",
    "encenámos": "encenar",
    "encenáramo": "encenar",
    "encenáramos": "encenar",
    "encenárei": "encenar",
    "encenáreis": "encenar",
    "encenásseis": "encenar",
    "encenássemos": "encenar",
    "encenávamo": "encenar",
    "encenávamos": "encenar",
    "encenávei": "encenar",
    "encenáveis": "encenável",
    "encera": "encerar",
    "encerada": "encerar",
    "enceradas": "encerar",
    "enceradeiras": "enceradeira",
    "encerado": "encerar",
    "enceradora": "encerador",
    "enceradoras": "enceradora",
    "enceradores": "encerador",
    "encerados": "encerar",
    "enceraduras": "enceradura",
    "encerai": "encerar",
    "encerais": "encerar",
    "enceram": "encerar",
    "enceramentos": "enceramento",
    "enceramo": "encerar",
    "enceramos": "encerar",
    "encerando": "encerar",
    "encerara": "encerar",
    "enceraram": "encerar",
    "enceraras": "encerar",
    "encerarde": "encerar",
    "encerardes": "encerar",
    "encerare": "encerar",
    "encerarei": "encerar",
    "encerareis": "encerar",
    "encerarem": "encerar",
    "enceraremos": "encerar",
    "encerares": "encerar",
    "enceraria": "encerar",
    "encerariam": "encerar",
    "encerarias": "encerar",
    "encerarmo": "encerar",
    "encerarmos": "encerar",
    "encerará": "encerar",
    "encerarás": "encerar",
    "encerarão": "encerar",
    "enceraríamos": "encerar",
    "enceraríeis": "encerar",
    "enceras": "encerar",
    "encerasse": "encerar",
    "encerassem": "encerar",
    "encerasses": "encerar",
    "enceraste": "encerar",
    "encerastes": "encerar",
    "encerava": "encerar",
    "enceravam": "encerar",
    "enceravas": "encerar",
    "encerações": "enceração",
    "encere": "encerar",
    "encerebra": "encerebrar",
    "encerebrada": "encerebrar",
    "encerebradas": "encerebrar",
    "encerebrado": "encerebrar",
    "encerebrados": "encerebrar",
    "encerebrai": "encerebrar",
    "encerebrais": "encerebrar",
    "encerebram": "encerebrar",
    "encerebramo": "encerebrar",
    "encerebramos": "encerebrar",
    "encerebrando": "encerebrar",
    "encerebrara": "encerebrar",
    "encerebraram": "encerebrar",
    "encerebraras": "encerebrar",
    "encerebrarde": "encerebrar",
    "encerebrardes": "encerebrar",
    "encerebrare": "encerebrar",
    "encerebrarei": "encerebrar",
    "encerebrareis": "encerebrar",
    "encerebrarem": "encerebrar",
    "encerebraremos": "encerebrar",
    "encerebrares": "encerebrar",
    "encerebraria": "encerebrar",
    "encerebrariam": "encerebrar",
    "encerebrarias": "encerebrar",
    "encerebrarmo": "encerebrar",
    "encerebrarmos": "encerebrar",
    "encerebrará": "encerebrar",
    "encerebrarás": "encerebrar",
    "encerebrarão": "encerebrar",
    "encerebraríamos": "encerebrar",
    "encerebraríeis": "encerebrar",
    "encerebras": "encerebrar",
    "encerebrasse": "encerebrar",
    "encerebrassem": "encerebrar",
    "encerebrasses": "encerebrar",
    "encerebraste": "encerebrar",
    "encerebrastes": "encerebrar",
    "encerebrava": "encerebrar",
    "encerebravam": "encerebrar",
    "encerebravas": "encerebrar",
    "encerebrações": "encerebração",
    "encerebre": "encerebrar",
    "encerebrei": "encerebrar",
    "encerebreis": "encerebrar",
    "encerebrem": "encerebrar",
    "encerebremo": "encerebrar",
    "encerebremos": "encerebrar",
    "encerebres": "encerebrar",
    "encerebro": "encerebrar",
    "encerebrou": "encerebrar",
    "encerebrá": "encerebrar",
    "encerebrámo": "encerebrar",
    "encerebrámos": "encerebrar",
    "encerebráramo": "encerebrar",
    "encerebráramos": "encerebrar",
    "encerebrárei": "encerebrar",
    "encerebráreis": "encerebrar",
    "encerebrásseis": "encerebrar",
    "encerebrássemos": "encerebrar",
    "encerebrávamo": "encerebrar",
    "encerebrávamos": "encerebrar",
    "encerebrávei": "encerebrar",
    "encerebráveis": "encerebrar",
    "encerei": "encerar",
    "encereis": "encerar",
    "encerem": "encerar",
    "enceremo": "encerar",
    "enceremos": "encerar",
    "enceres": "encerar",
    "encero": "encerar",
    "encerou": "encerar",
    "encerra": "encerrar",
    "encerrada": "encerrar",
    "encerradas": "encerrar",
    "encerrado": "encerrar",
    "encerrados": "encerrar",
    "encerrai": "encerrar",
    "encerrais": "encerrar",
    "encerram": "encerrar",
    "encerramentos": "encerramento",
    "encerramo": "encerrar",
    "encerramos": "encerrar",
    "encerrando": "encerrar",
    "encerrara": "encerrar",
    "encerraram": "encerrar",
    "encerraras": "encerrar",
    "encerrarde": "encerrar",
    "encerrardes": "encerrar",
    "encerrare": "encerrar",
    "encerrarei": "encerrar",
    "encerrareis": "encerrar",
    "encerrarem": "encerrar",
    "encerraremos": "encerrar",
    "encerrares": "encerrar",
    "encerraria": "encerrar",
    "encerrariam": "encerrar",
    "encerrarias": "encerrar",
    "encerrarmo": "encerrar",
    "encerrarmos": "encerrar",
    "encerrará": "encerrar",
    "encerrarás": "encerrar",
    "encerrarão": "encerrar",
    "encerraríamos": "encerrar",
    "encerraríeis": "encerrar",
    "encerras": "encerrar",
    "encerrasse": "encerrar",
    "encerrassem": "encerrar",
    "encerrasses": "encerrar",
    "encerraste": "encerrar",
    "encerrastes": "encerrar",
    "encerrava": "encerrar",
    "encerravam": "encerrar",
    "encerravas": "encerrar",
    "encerre": "encerrar",
    "encerrei": "encerrar",
    "encerreis": "encerrar",
    "encerrem": "encerrar",
    "encerremo": "encerrar",
    "encerremos": "encerrar",
    "encerres": "encerrar",
    "encerro": "encerrar",
    "encerros": "encerro",
    "encerrou": "encerrar",
    "encerrá": "encerrar",
    "encerrámo": "encerrar",
    "encerrámos": "encerrar",
    "encerráramo": "encerrar",
    "encerráramos": "encerrar",
    "encerrárei": "encerrar",
    "encerráreis": "encerrar",
    "encerrásseis": "encerrar",
    "encerrássemos": "encerrar",
    "encerrávamo": "encerrar",
    "encerrávamos": "encerrar",
    "encerrávei": "encerrar",
    "encerráveis": "encerrável",
    "encerá": "encerar",
    "encerámo": "encerar",
    "encerámos": "encerar",
    "enceráramo": "encerar",
    "enceráramos": "encerar",
    "encerárei": "encerar",
    "enceráreis": "encerar",
    "encerásseis": "encerar",
    "encerássemos": "encerar",
    "encerávamo": "encerar",
    "encerávamos": "encerar",
    "encerávei": "encerar",
    "enceráveis": "encerar",
    "encesta": "encestar",
    "encestada": "encestar",
    "encestadas": "encestar",
    "encestado": "encestar",
    "encestados": "encestar",
    "encestai": "encestar",
    "encestais": "encestar",
    "encestam": "encestar",
    "encestamo": "encestar",
    "encestamos": "encestar",
    "encestando": "encestar",
    "encestara": "encestar",
    "encestaram": "encestar",
    "encestaras": "encestar",
    "encestarde": "encestar",
    "encestardes": "encestar",
    "encestare": "encestar",
    "encestarei": "encestar",
    "encestareis": "encestar",
    "encestarem": "encestar",
    "encestaremos": "encestar",
    "encestares": "encestar",
    "encestaria": "encestar",
    "encestariam": "encestar",
    "encestarias": "encestar",
    "encestarmo": "encestar",
    "encestarmos": "encestar",
    "encestará": "encestar",
    "encestarás": "encestar",
    "encestarão": "encestar",
    "encestaríamos": "encestar",
    "encestaríeis": "encestar",
    "encestas": "encestar",
    "encestasse": "encestar",
    "encestassem": "encestar",
    "encestasses": "encestar",
    "encestaste": "encestar",
    "encestastes": "encestar",
    "encestava": "encestar",
    "encestavam": "encestar",
    "encestavas": "encestar",
    "enceste": "encestar",
    "encestei": "encestar",
    "encesteis": "encestar",
    "encestem": "encestar",
    "encestemo": "encestar",
    "encestemos": "encestar",
    "encestes": "encestar",
    "encesto": "encestar",
    "encestou": "encestar",
    "encestá": "encestar",
    "encestámo": "encestar",
    "encestámos": "encestar",
    "encestáramo": "encestar",
    "encestáramos": "encestar",
    "encestárei": "encestar",
    "encestáreis": "encestar",
    "encestásseis": "encestar",
    "encestássemos": "encestar",
    "encestávamo": "encestar",
    "encestávamos": "encestar",
    "encestávei": "encestar",
    "encestáveis": "encestar",
    "enceta": "encetar",
    "encetada": "encetar",
    "encetadas": "encetar",
    "encetado": "encetar",
    "encetados": "encetar",
    "encetaduras": "encetadura",
    "encetai": "encetar",
    "encetais": "encetar",
    "encetam": "encetar",
    "encetamentos": "encetamento",
    "encetamo": "encetar",
    "encetamos": "encetar",
    "encetando": "encetar",
    "encetara": "encetar",
    "encetaram": "encetar",
    "encetaras": "encetar",
    "encetarde": "encetar",
    "encetardes": "encetar",
    "encetare": "encetar",
    "encetarei": "encetar",
    "encetareis": "encetar",
    "encetarem": "encetar",
    "encetaremos": "encetar",
    "encetares": "encetar",
    "encetaria": "encetar",
    "encetariam": "encetar",
    "encetarias": "encetar",
    "encetarmo": "encetar",
    "encetarmos": "encetar",
    "encetará": "encetar",
    "encetarás": "encetar",
    "encetarão": "encetar",
    "encetaríamos": "encetar",
    "encetaríeis": "encetar",
    "encetas": "encetar",
    "encetasse": "encetar",
    "encetassem": "encetar",
    "encetasses": "encetar",
    "encetaste": "encetar",
    "encetastes": "encetar",
    "encetativa": "encetativo",
    "encetativas": "encetativo",
    "encetativos": "encetativo",
    "encetava": "encetar",
    "encetavam": "encetar",
    "encetavas": "encetar",
    "encete": "encetar",
    "encetei": "encetar",
    "enceteis": "encetar",
    "encetem": "encetar",
    "encetemo": "encetar",
    "encetemos": "encetar",
    "encetes": "encetar",
    "enceto": "encetar",
    "encetou": "encetar",
    "encetá": "encetar",
    "encetámo": "encetar",
    "encetámos": "encetar",
    "encetáramo": "encetar",
    "encetáramos": "encetar",
    "encetárei": "encetar",
    "encetáreis": "encetar",
    "encetásseis": "encetar",
    "encetássemos": "encetar",
    "encetávamo": "encetar",
    "encetávamos": "encetar",
    "encetávei": "encetar",
    "encetáveis": "encetar",
    "encha": "encher",
    "enchacota": "enchacotar",
    "enchacotada": "enchacotar",
    "enchacotadas": "enchacotar",
    "enchacotado": "enchacotar",
    "enchacotados": "enchacotar",
    "enchacotai": "enchacotar",
    "enchacotais": "enchacotar",
    "enchacotam": "enchacotar",
    "enchacotamo": "enchacotar",
    "enchacotamos": "enchacotar",
    "enchacotando": "enchacotar",
    "enchacotara": "enchacotar",
    "enchacotaram": "enchacotar",
    "enchacotaras": "enchacotar",
    "enchacotarde": "enchacotar",
    "enchacotardes": "enchacotar",
    "enchacotare": "enchacotar",
    "enchacotarei": "enchacotar",
    "enchacotareis": "enchacotar",
    "enchacotarem": "enchacotar",
    "enchacotaremos": "enchacotar",
    "enchacotares": "enchacotar",
    "enchacotaria": "enchacotar",
    "enchacotariam": "enchacotar",
    "enchacotarias": "enchacotar",
    "enchacotarmo": "enchacotar",
    "enchacotarmos": "enchacotar",
    "enchacotará": "enchacotar",
    "enchacotarás": "enchacotar",
    "enchacotarão": "enchacotar",
    "enchacotaríamos": "enchacotar",
    "enchacotaríeis": "enchacotar",
    "enchacotas": "enchacotar",
    "enchacotasse": "enchacotar",
    "enchacotassem": "enchacotar",
    "enchacotasses": "enchacotar",
    "enchacotaste": "enchacotar",
    "enchacotastes": "enchacotar",
    "enchacotava": "enchacotar",
    "enchacotavam": "enchacotar",
    "enchacotavas": "enchacotar",
    "enchacote": "enchacotar",
    "enchacotei": "enchacotar",
    "enchacoteis": "enchacotar",
    "enchacotem": "enchacotar",
    "enchacotemo": "enchacotar",
    "enchacotemos": "enchacotar",
    "enchacotes": "enchacotar",
    "enchacoto": "enchacotar",
    "enchacotou": "enchacotar",
    "enchacotá": "enchacotar",
    "enchacotámo": "enchacotar",
    "enchacotámos": "enchacotar",
    "enchacotáramo": "enchacotar",
    "enchacotáramos": "enchacotar",
    "enchacotárei": "enchacotar",
    "enchacotáreis": "enchacotar",
    "enchacotásseis": "enchacotar",
    "enchacotássemos": "enchacotar",
    "enchacotávamo": "enchacotar",
    "enchacotávamos": "enchacotar",
    "enchacotávei": "enchacotar",
    "enchacotáveis": "enchacotar",
    "enchafurda": "enchafurdar",
    "enchafurdada": "enchafurdar",
    "enchafurdadas": "enchafurdar",
    "enchafurdado": "enchafurdar",
    "enchafurdados": "enchafurdar",
    "enchafurdai": "enchafurdar",
    "enchafurdais": "enchafurdar",
    "enchafurdam": "enchafurdar",
    "enchafurdamo": "enchafurdar",
    "enchafurdamos": "enchafurdar",
    "enchafurdando": "enchafurdar",
    "enchafurdara": "enchafurdar",
    "enchafurdaram": "enchafurdar",
    "enchafurdaras": "enchafurdar",
    "enchafurdardes": "enchafurdar",
    "enchafurdarei": "enchafurdar",
    "enchafurdareis": "enchafurdar",
    "enchafurdarem": "enchafurdar",
    "enchafurdaremos": "enchafurdar",
    "enchafurdares": "enchafurdar",
    "enchafurdaria": "enchafurdar",
    "enchafurdariam": "enchafurdar",
    "enchafurdarias": "enchafurdar",
    "enchafurdarmo": "enchafurdar",
    "enchafurdarmos": "enchafurdar",
    "enchafurdará": "enchafurdar",
    "enchafurdarás": "enchafurdar",
    "enchafurdarão": "enchafurdar",
    "enchafurdaríamos": "enchafurdar",
    "enchafurdaríeis": "enchafurdar",
    "enchafurdas": "enchafurdar",
    "enchafurdasse": "enchafurdar",
    "enchafurdassem": "enchafurdar",
    "enchafurdasses": "enchafurdar",
    "enchafurdaste": "enchafurdar",
    "enchafurdastes": "enchafurdar",
    "enchafurdava": "enchafurdar",
    "enchafurdavam": "enchafurdar",
    "enchafurdavas": "enchafurdar",
    "enchafurde": "enchafurdar",
    "enchafurdei": "enchafurdar",
    "enchafurdeis": "enchafurdar",
    "enchafurdem": "enchafurdar",
    "enchafurdemo": "enchafurdar",
    "enchafurdemos": "enchafurdar",
    "enchafurdes": "enchafurdar",
    "enchafurdo": "enchafurdar",
    "enchafurdou": "enchafurdar",
    "enchafurdámo": "enchafurdar",
    "enchafurdámos": "enchafurdar",
    "enchafurdáramo": "enchafurdar",
    "enchafurdáramos": "enchafurdar",
    "enchafurdáreis": "enchafurdar",
    "enchafurdásseis": "enchafurdar",
    "enchafurdássemos": "enchafurdar",
    "enchafurdávamo": "enchafurdar",
    "enchafurdávamos": "enchafurdar",
    "enchafurdáveis": "enchafurdar",
    "enchais": "encher",
    "encham": "encher",
    "enchamboada": "enchamboado",
    "enchamboadas": "enchamboado",
    "enchamboados": "enchamboado",
    "enchameja": "enchamejar",
    "enchamejada": "enchamejar",
    "enchamejadas": "enchamejar",
    "enchamejado": "enchamejar",
    "enchamejados": "enchamejar",
    "enchamejai": "enchamejar",
    "enchamejais": "enchamejar",
    "enchamejam": "enchamejar",
    "enchamejamo": "enchamejar",
    "enchamejamos": "enchamejar",
    "enchamejando": "enchamejar",
    "enchamejara": "enchamejar",
    "enchamejaram": "enchamejar",
    "enchamejaras": "enchamejar",
    "enchamejardes": "enchamejar",
    "enchamejarei": "enchamejar",
    "enchamejareis": "enchamejar",
    "enchamejarem": "enchamejar",
    "enchamejaremos": "enchamejar",
    "enchamejares": "enchamejar",
    "enchamejaria": "enchamejar",
    "enchamejariam": "enchamejar",
    "enchamejarias": "enchamejar",
    "enchamejarmo": "enchamejar",
    "enchamejarmos": "enchamejar",
    "enchamejará": "enchamejar",
    "enchamejarás": "enchamejar",
    "enchamejarão": "enchamejar",
    "enchamejaríamos": "enchamejar",
    "enchamejaríeis": "enchamejar",
    "enchamejas": "enchamejar",
    "enchamejasse": "enchamejar",
    "enchamejassem": "enchamejar",
    "enchamejasses": "enchamejar",
    "enchamejaste": "enchamejar",
    "enchamejastes": "enchamejar",
    "enchamejava": "enchamejar",
    "enchamejavam": "enchamejar",
    "enchamejavas": "enchamejar",
    "enchameje": "enchamejar",
    "enchamejei": "enchamejar",
    "enchamejeis": "enchamejar",
    "enchamejem": "enchamejar",
    "enchamejemo": "enchamejar",
    "enchamejemos": "enchamejar",
    "enchamejes": "enchamejar",
    "enchamejo": "enchamejar",
    "enchamejou": "enchamejar",
    "enchamejámo": "enchamejar",
    "enchamejámos": "enchamejar",
    "enchamejáramo": "enchamejar",
    "enchamejáramos": "enchamejar",
    "enchamejáreis": "enchamejar",
    "enchamejásseis": "enchamejar",
    "enchamejássemos": "enchamejar",
    "enchamejávamo": "enchamejar",
    "enchamejávamos": "enchamejar",
    "enchamejáveis": "enchamejar",
    "enchamo": "encher",
    "enchamos": "encher",
    "enchapelada": "enchapelado",
    "enchapeladas": "enchapelado",
    "enchapelados": "enchapelado",
    "encharca": "encharcar",
    "encharcada": "encharcar",
    "encharcadas": "encharcar",
    "encharcadiça": "encharcadiço",
    "encharcadiças": "encharcadiço",
    "encharcadiços": "encharcadiço",
    "encharcado": "encharcar",
    "encharcados": "encharcar",
    "encharcadíssima": "encharcado",
    "encharcadíssimas": "encharcado",
    "encharcadíssimo": "encharcado",
    "encharcadíssimos": "encharcado",
    "encharcai": "encharcar",
    "encharcais": "encharcar",
    "encharcam": "encharcar",
    "encharcamentos": "encharcamento",
    "encharcamo": "encharcar",
    "encharcamos": "encharcar",
    "encharcando": "encharcar",
    "encharcara": "encharcar",
    "encharcaram": "encharcar",
    "encharcaras": "encharcar",
    "encharcarde": "encharcar",
    "encharcardes": "encharcar",
    "encharcare": "encharcar",
    "encharcarei": "encharcar",
    "encharcareis": "encharcar",
    "encharcarem": "encharcar",
    "encharcaremos": "encharcar",
    "encharcares": "encharcar",
    "encharcaria": "encharcar",
    "encharcariam": "encharcar",
    "encharcarias": "encharcar",
    "encharcarmo": "encharcar",
    "encharcarmos": "encharcar",
    "encharcará": "encharcar",
    "encharcarás": "encharcar",
    "encharcarão": "encharcar",
    "encharcaríamos": "encharcar",
    "encharcaríeis": "encharcar",
    "encharcas": "encharcar",
    "encharcasse": "encharcar",
    "encharcassem": "encharcar",
    "encharcasses": "encharcar",
    "encharcaste": "encharcar",
    "encharcastes": "encharcar",
    "encharcava": "encharcar",
    "encharcavam": "encharcar",
    "encharcavas": "encharcar",
    "encharco": "encharcar",
    "encharcou": "encharcar",
    "encharcá": "encharcar",
    "encharcámo": "encharcar",
    "encharcámos": "encharcar",
    "encharcáramo": "encharcar",
    "encharcáramos": "encharcar",
    "encharcárei": "encharcar",
    "encharcáreis": "encharcar",
    "encharcásseis": "encharcar",
    "encharcássemos": "encharcar",
    "encharcávamo": "encharcar",
    "encharcávamos": "encharcar",
    "encharcávei": "encharcar",
    "encharcáveis": "encharcar",
    "encharola": "encharolar",
    "encharolada": "encharolar",
    "encharoladas": "encharolar",
    "encharolado": "encharolar",
    "encharolados": "encharolar",
    "encharolai": "encharolar",
    "encharolais": "encharolar",
    "encharolam": "encharolar",
    "encharolamo": "encharolar",
    "encharolamos": "encharolar",
    "encharolando": "encharolar",
    "encharolara": "encharolar",
    "encharolaram": "encharolar",
    "encharolaras": "encharolar",
    "encharolarde": "encharolar",
    "encharolardes": "encharolar",
    "encharolare": "encharolar",
    "encharolarei": "encharolar",
    "encharolareis": "encharolar",
    "encharolarem": "encharolar",
    "encharolaremos": "encharolar",
    "encharolares": "encharolar",
    "encharolaria": "encharolar",
    "encharolariam": "encharolar",
    "encharolarias": "encharolar",
    "encharolarmo": "encharolar",
    "encharolarmos": "encharolar",
    "encharolará": "encharolar",
    "encharolarás": "encharolar",
    "encharolarão": "encharolar",
    "encharolaríamos": "encharolar",
    "encharolaríeis": "encharolar",
    "encharolas": "encharolar",
    "encharolasse": "encharolar",
    "encharolassem": "encharolar",
    "encharolasses": "encharolar",
    "encharolaste": "encharolar",
    "encharolastes": "encharolar",
    "encharolava": "encharolar",
    "encharolavam": "encharolar",
    "encharolavas": "encharolar",
    "encharole": "encharolar",
    "encharolei": "encharolar",
    "encharoleis": "encharolar",
    "encharolem": "encharolar",
    "encharolemo": "encharolar",
    "encharolemos": "encharolar",
    "encharoles": "encharolar",
    "encharolo": "encharolar",
    "encharolou": "encharolar",
    "encharolá": "encharolar",
    "encharolámo": "encharolar",
    "encharolámos": "encharolar",
    "encharoláramo": "encharolar",
    "encharoláramos": "encharolar",
    "encharolárei": "encharolar",
    "encharoláreis": "encharolar",
    "encharolásseis": "encharolar",
    "encharolássemos": "encharolar",
    "encharolávamo": "encharolar",
    "encharolávamos": "encharolar",
    "encharolávei": "encharolar",
    "encharoláveis": "encharolar",
    "encharque": "encharcar",
    "encharquei": "encharcar",
    "encharqueis": "encharcar",
    "encharquem": "encharcar",
    "encharquemo": "encharcar",
    "encharquemos": "encharcar",
    "encharques": "encharcar",
    "enchas": "encher",
    "enche": "encher",
    "enchedeiras": "enchedeira",
    "enchedelas": "enchedela",
    "enchedora": "enchedor",
    "enchedoras": "enchedor",
    "enchedores": "enchedor",
    "encheduras": "enchedura",
    "enchei": "encher",
    "encheis": "encher",
    "enchem": "encher",
    "enchemo": "encher",
    "enchemos": "encher",
    "enchendo": "encher",
    "enchentes": "enchente",
    "enchera": "encher",
    "encheram": "encher",
    "encheras": "encher",
    "encherde": "encher",
    "encherdes": "encher",
    "enchere": "encher",
    "encherei": "encher",
    "enchereis": "encher",
    "encherem": "encher",
    "encheremos": "encher",
    "encheres": "encher",
    "encheria": "encher",
    "encheriam": "encher",
    "encherias": "encher",
    "enchermo": "encher",
    "enchermos": "encher",
    "encherá": "encher",
    "encherás": "encher",
    "encherão": "encher",
    "encheríamos": "encher",
    "encheríeis": "encher",
    "enches": "encher",
    "enchesse": "encher",
    "enchessem": "encher",
    "enchesses": "encher",
    "encheste": "encher",
    "enchestes": "encher",
    "encheu": "encher",
    "enchi": "encher",
    "enchia": "encher",
    "enchiam": "encher",
    "enchias": "encher",
    "enchida": "enchido",
    "enchidas": "enchido",
    "enchido": "encher",
    "enchidos": "enchido",
    "enchimarra": "enchimarrar",
    "enchimarrada": "enchimarrar",
    "enchimarradas": "enchimarrar",
    "enchimarrado": "enchimarrar",
    "enchimarrados": "enchimarrar",
    "enchimarrai": "enchimarrar",
    "enchimarrais": "enchimarrar",
    "enchimarram": "enchimarrar",
    "enchimarramo": "enchimarrar",
    "enchimarramos": "enchimarrar",
    "enchimarrando": "enchimarrar",
    "enchimarrara": "enchimarrar",
    "enchimarraram": "enchimarrar",
    "enchimarraras": "enchimarrar",
    "enchimarrarde": "enchimarrar",
    "enchimarrardes": "enchimarrar",
    "enchimarrare": "enchimarrar",
    "enchimarrarei": "enchimarrar",
    "enchimarrareis": "enchimarrar",
    "enchimarrarem": "enchimarrar",
    "enchimarraremos": "enchimarrar",
    "enchimarrares": "enchimarrar",
    "enchimarraria": "enchimarrar",
    "enchimarrariam": "enchimarrar",
    "enchimarrarias": "enchimarrar",
    "enchimarrarmo": "enchimarrar",
    "enchimarrarmos": "enchimarrar",
    "enchimarrará": "enchimarrar",
    "enchimarrarás": "enchimarrar",
    "enchimarrarão": "enchimarrar",
    "enchimarraríamos": "enchimarrar",
    "enchimarraríeis": "enchimarrar",
    "enchimarras": "enchimarrar",
    "enchimarrasse": "enchimarrar",
    "enchimarrassem": "enchimarrar",
    "enchimarrasses": "enchimarrar",
    "enchimarraste": "enchimarrar",
    "enchimarrastes": "enchimarrar",
    "enchimarrava": "enchimarrar",
    "enchimarravam": "enchimarrar",
    "enchimarravas": "enchimarrar",
    "enchimarre": "enchimarrar",
    "enchimarrei": "enchimarrar",
    "enchimarreis": "enchimarrar",
    "enchimarrem": "enchimarrar",
    "enchimarremo": "enchimarrar",
    "enchimarremos": "enchimarrar",
    "enchimarres": "enchimarrar",
    "enchimarro": "enchimarrar",
    "enchimarrou": "enchimarrar",
    "enchimarrá": "enchimarrar",
    "enchimarrámo": "enchimarrar",
    "enchimarrámos": "enchimarrar",
    "enchimarráramo": "enchimarrar",
    "enchimarráramos": "enchimarrar",
    "enchimarrárei": "enchimarrar",
    "enchimarráreis": "enchimarrar",
    "enchimarrásseis": "enchimarrar",
    "enchimarrássemos": "enchimarrar",
    "enchimarrávamo": "enchimarrar",
    "enchimarrávamos": "enchimarrar",
    "enchimarrávei": "enchimarrar",
    "enchimarráveis": "enchimarrar",
    "enchimentos": "enchimento",
    "encho": "encher",
    "enchocalha": "enchocalhar",
    "enchocalhada": "enchocalhar",
    "enchocalhadas": "enchocalhar",
    "enchocalhado": "enchocalhar",
    "enchocalhados": "enchocalhar",
    "enchocalhai": "enchocalhar",
    "enchocalhais": "enchocalhar",
    "enchocalham": "enchocalhar",
    "enchocalhamo": "enchocalhar",
    "enchocalhamos": "enchocalhar",
    "enchocalhando": "enchocalhar",
    "enchocalhara": "enchocalhar",
    "enchocalharam": "enchocalhar",
    "enchocalharas": "enchocalhar",
    "enchocalharde": "enchocalhar",
    "enchocalhardes": "enchocalhar",
    "enchocalhare": "enchocalhar",
    "enchocalharei": "enchocalhar",
    "enchocalhareis": "enchocalhar",
    "enchocalharem": "enchocalhar",
    "enchocalharemos": "enchocalhar",
    "enchocalhares": "enchocalhar",
    "enchocalharia": "enchocalhar",
    "enchocalhariam": "enchocalhar",
    "enchocalharias": "enchocalhar",
    "enchocalharmo": "enchocalhar",
    "enchocalharmos": "enchocalhar",
    "enchocalhará": "enchocalhar",
    "enchocalharás": "enchocalhar",
    "enchocalharão": "enchocalhar",
    "enchocalharíamos": "enchocalhar",
    "enchocalharíeis": "enchocalhar",
    "enchocalhas": "enchocalhar",
    "enchocalhasse": "enchocalhar",
    "enchocalhassem": "enchocalhar",
    "enchocalhasses": "enchocalhar",
    "enchocalhaste": "enchocalhar",
    "enchocalhastes": "enchocalhar",
    "enchocalhava": "enchocalhar",
    "enchocalhavam": "enchocalhar",
    "enchocalhavas": "enchocalhar",
    "enchocalhações": "enchocalhação",
    "enchocalhe": "enchocalhar",
    "enchocalhei": "enchocalhar",
    "enchocalheis": "enchocalhar",
    "enchocalhem": "enchocalhar",
    "enchocalhemo": "enchocalhar",
    "enchocalhemos": "enchocalhar",
    "enchocalhes": "enchocalhar",
    "enchocalho": "enchocalhar",
    "enchocalhou": "enchocalhar",
    "enchocalhá": "enchocalhar",
    "enchocalhámo": "enchocalhar",
    "enchocalhámos": "enchocalhar",
    "enchocalháramo": "enchocalhar",
    "enchocalháramos": "enchocalhar",
    "enchocalhárei": "enchocalhar",
    "enchocalháreis": "enchocalhar",
    "enchocalhásseis": "enchocalhar",
    "enchocalhássemos": "enchocalhar",
    "enchocalhávamo": "enchocalhar",
    "enchocalhávamos": "enchocalhar",
    "enchocalhávei": "enchocalhar",
    "enchocalháveis": "enchocalhar",
    "enchoce": "enchoçar",
    "enchocei": "enchoçar",
    "enchoceis": "enchoçar",
    "enchocem": "enchoçar",
    "enchocemo": "enchoçar",
    "enchocemos": "enchoçar",
    "enchoces": "enchoçar",
    "enchoirice": "enchoiriçar",
    "enchoiricei": "enchoiriçar",
    "enchoiriceis": "enchoiriçar",
    "enchoiricem": "enchoiriçar",
    "enchoiricemo": "enchoiriçar",
    "enchoiricemos": "enchoiriçar",
    "enchoirices": "enchoiriçar",
    "enchoiriça": "enchoiriçar",
    "enchoiriçada": "enchoiriçar",
    "enchoiriçadas": "enchoiriçar",
    "enchoiriçado": "enchoiriçar",
    "enchoiriçados": "enchoiriçar",
    "enchoiriçai": "enchoiriçar",
    "enchoiriçais": "enchoiriçar",
    "enchoiriçam": "enchoiriçar",
    "enchoiriçamo": "enchoiriçar",
    "enchoiriçamos": "enchoiriçar",
    "enchoiriçando": "enchoiriçar",
    "enchoiriçara": "enchoiriçar",
    "enchoiriçaram": "enchoiriçar",
    "enchoiriçaras": "enchoiriçar",
    "enchoiriçarde": "enchoiriçar",
    "enchoiriçardes": "enchoiriçar",
    "enchoiriçare": "enchoiriçar",
    "enchoiriçarei": "enchoiriçar",
    "enchoiriçareis": "enchoiriçar",
    "enchoiriçarem": "enchoiriçar",
    "enchoiriçaremos": "enchoiriçar",
    "enchoiriçares": "enchoiriçar",
    "enchoiriçaria": "enchoiriçar",
    "enchoiriçariam": "enchoiriçar",
    "enchoiriçarias": "enchoiriçar",
    "enchoiriçarmo": "enchoiriçar",
    "enchoiriçarmos": "enchoiriçar",
    "enchoiriçará": "enchoiriçar",
    "enchoiriçarás": "enchoiriçar",
    "enchoiriçarão": "enchoiriçar",
    "enchoiriçaríamos": "enchoiriçar",
    "enchoiriçaríeis": "enchoiriçar",
    "enchoiriças": "enchoiriçar",
    "enchoiriçasse": "enchoiriçar",
    "enchoiriçassem": "enchoiriçar",
    "enchoiriçasses": "enchoiriçar",
    "enchoiriçaste": "enchoiriçar",
    "enchoiriçastes": "enchoiriçar",
    "enchoiriçava": "enchoiriçar",
    "enchoiriçavam": "enchoiriçar",
    "enchoiriçavas": "enchoiriçar",
    "enchoiriço": "enchoiriçar",
    "enchoiriçou": "enchoiriçar",
    "enchoiriçá": "enchoiriçar",
    "enchoiriçámo": "enchoiriçar",
    "enchoiriçámos": "enchoiriçar",
    "enchoiriçáramo": "enchoiriçar",
    "enchoiriçáramos": "enchoiriçar",
    "enchoiriçárei": "enchoiriçar",
    "enchoiriçáreis": "enchoiriçar",
    "enchoiriçásseis": "enchoiriçar",
    "enchoiriçássemos": "enchoiriçar",
    "enchoiriçávamo": "enchoiriçar",
    "enchoiriçávamos": "enchoiriçar",
    "enchoiriçávei": "enchoiriçar",
    "enchoiriçáveis": "enchoiriçar",
    "enchourice": "enchouriçar",
    "enchouricei": "enchouriçar",
    "enchouriceis": "enchouriçar",
    "enchouricem": "enchouriçar",
    "enchouricemo": "enchouriçar",
    "enchouricemos": "enchouriçar",
    "enchourices": "enchouriçar",
    "enchouriça": "enchouriçar",
    "enchouriçada": "enchouriçar",
    "enchouriçadas": "enchouriçar",
    "enchouriçado": "enchouriçar",
    "enchouriçados": "enchouriçar",
    "enchouriçai": "enchouriçar",
    "enchouriçais": "enchouriçar",
    "enchouriçam": "enchouriçar",
    "enchouriçamo": "enchouriçar",
    "enchouriçamos": "enchouriçar",
    "enchouriçando": "enchouriçar",
    "enchouriçara": "enchouriçar",
    "enchouriçaram": "enchouriçar",
    "enchouriçaras": "enchouriçar",
    "enchouriçarde": "enchouriçar",
    "enchouriçardes": "enchouriçar",
    "enchouriçare": "enchouriçar",
    "enchouriçarei": "enchouriçar",
    "enchouriçareis": "enchouriçar",
    "enchouriçarem": "enchouriçar",
    "enchouriçaremos": "enchouriçar",
    "enchouriçares": "enchouriçar",
    "enchouriçaria": "enchouriçar",
    "enchouriçariam": "enchouriçar",
    "enchouriçarias": "enchouriçar",
    "enchouriçarmo": "enchouriçar",
    "enchouriçarmos": "enchouriçar",
    "enchouriçará": "enchouriçar",
    "enchouriçarás": "enchouriçar",
    "enchouriçarão": "enchouriçar",
    "enchouriçaríamos": "enchouriçar",
    "enchouriçaríeis": "enchouriçar",
    "enchouriças": "enchouriçar",
    "enchouriçasse": "enchouriçar",
    "enchouriçassem": "enchouriçar",
    "enchouriçasses": "enchouriçar",
    "enchouriçaste": "enchouriçar",
    "enchouriçastes": "enchouriçar",
    "enchouriçava": "enchouriçar",
    "enchouriçavam": "enchouriçar",
    "enchouriçavas": "enchouriçar",
    "enchouriço": "enchouriçar",
    "enchouriçou": "enchouriçar",
    "enchouriçá": "enchouriçar",
    "enchouriçámo": "enchouriçar",
    "enchouriçámos": "enchouriçar",
    "enchouriçáramo": "enchouriçar",
    "enchouriçáramos": "enchouriçar",
    "enchouriçárei": "enchouriçar",
    "enchouriçáreis": "enchouriçar",
    "enchouriçásseis": "enchouriçar",
    "enchouriçássemos": "enchouriçar",
    "enchouriçávamo": "enchouriçar",
    "enchouriçávamos": "enchouriçar",
    "enchouriçávei": "enchouriçar",
    "enchouriçáveis": "enchouriçar",
    "enchousa": "enchousar",
    "enchousada": "enchousar",
    "enchousadas": "enchousar",
    "enchousado": "enchousar",
    "enchousados": "enchousar",
    "enchousai": "enchousar",
    "enchousais": "enchousar",
    "enchousam": "enchousar",
    "enchousamo": "enchousar",
    "enchousamos": "enchousar",
    "enchousando": "enchousar",
    "enchousara": "enchousar",
    "enchousaram": "enchousar",
    "enchousaras": "enchousar",
    "enchousarde": "enchousar",
    "enchousardes": "enchousar",
    "enchousare": "enchousar",
    "enchousarei": "enchousar",
    "enchousareis": "enchousar",
    "enchousarem": "enchousar",
    "enchousaremos": "enchousar",
    "enchousares": "enchousar",
    "enchousaria": "enchousar",
    "enchousariam": "enchousar",
    "enchousarias": "enchousar",
    "enchousarmo": "enchousar",
    "enchousarmos": "enchousar",
    "enchousará": "enchousar",
    "enchousarás": "enchousar",
    "enchousarão": "enchousar",
    "enchousaríamos": "enchousar",
    "enchousaríeis": "enchousar",
    "enchousas": "enchousar",
    "enchousasse": "enchousar",
    "enchousassem": "enchousar",
    "enchousasses": "enchousar",
    "enchousaste": "enchousar",
    "enchousastes": "enchousar",
    "enchousava": "enchousar",
    "enchousavam": "enchousar",
    "enchousavas": "enchousar",
    "enchouse": "enchousar",
    "enchousei": "enchousar",
    "enchouseis": "enchousar",
    "enchousem": "enchousar",
    "enchousemo": "enchousar",
    "enchousemos": "enchousar",
    "enchouses": "enchousar",
    "enchouso": "enchousar",
    "enchousou": "enchousar",
    "enchousá": "enchousar",
    "enchousámo": "enchousar",
    "enchousámos": "enchousar",
    "enchousáramo": "enchousar",
    "enchousáramos": "enchousar",
    "enchousárei": "enchousar",
    "enchousáreis": "enchousar",
    "enchousásseis": "enchousar",
    "enchousássemos": "enchousar",
    "enchousávamo": "enchousar",
    "enchousávamos": "enchousar",
    "enchousávei": "enchousar",
    "enchousáveis": "enchousar",
    "enchovas": "enchova",
    "enchovinha": "enchova",
    "enchovinhas": "enchova",
    "enchovita": "enchova",
    "enchovitas": "enchova",
    "enchoça": "enchoçar",
    "enchoçada": "enchoçar",
    "enchoçadas": "enchoçar",
    "enchoçado": "enchoçar",
    "enchoçados": "enchoçar",
    "enchoçai": "enchoçar",
    "enchoçais": "enchoçar",
    "enchoçam": "enchoçar",
    "enchoçamo": "enchoçar",
    "enchoçamos": "enchoçar",
    "enchoçando": "enchoçar",
    "enchoçara": "enchoçar",
    "enchoçaram": "enchoçar",
    "enchoçaras": "enchoçar",
    "enchoçarde": "enchoçar",
    "enchoçardes": "enchoçar",
    "enchoçare": "enchoçar",
    "enchoçarei": "enchoçar",
    "enchoçareis": "enchoçar",
    "enchoçarem": "enchoçar",
    "enchoçaremos": "enchoçar",
    "enchoçares": "enchoçar",
    "enchoçaria": "enchoçar",
    "enchoçariam": "enchoçar",
    "enchoçarias": "enchoçar",
    "enchoçarmo": "enchoçar",
    "enchoçarmos": "enchoçar",
    "enchoçará": "enchoçar",
    "enchoçarás": "enchoçar",
    "enchoçarão": "enchoçar",
    "enchoçaríamos": "enchoçar",
    "enchoçaríeis": "enchoçar",
    "enchoças": "enchoçar",
    "enchoçasse": "enchoçar",
    "enchoçassem": "enchoçar",
    "enchoçasses": "enchoçar",
    "enchoçaste": "enchoçar",
    "enchoçastes": "enchoçar",
    "enchoçava": "enchoçar",
    "enchoçavam": "enchoçar",
    "enchoçavas": "enchoçar",
    "enchoço": "enchoçar",
    "enchoçou": "enchoçar",
    "enchoçá": "enchoçar",
    "enchoçámo": "enchoçar",
    "enchoçámos": "enchoçar",
    "enchoçáramo": "enchoçar",
    "enchoçáramos": "enchoçar",
    "enchoçárei": "enchoçar",
    "enchoçáreis": "enchoçar",
    "enchoçásseis": "enchoçar",
    "enchoçássemos": "enchoçar",
    "enchoçávamo": "enchoçar",
    "enchoçávamos": "enchoçar",
    "enchoçávei": "enchoçar",
    "enchoçáveis": "enchoçar",
    "enchumace": "enchumaçar",
    "enchumacei": "enchumaçar",
    "enchumaceis": "enchumaçar",
    "enchumacem": "enchumaçar",
    "enchumacemo": "enchumaçar",
    "enchumacemos": "enchumaçar",
    "enchumaces": "enchumaçar",
    "enchumaça": "enchumaçar",
    "enchumaçada": "enchumaçar",
    "enchumaçadas": "enchumaçar",
    "enchumaçado": "enchumaçar",
    "enchumaçados": "enchumaçar",
    "enchumaçai": "enchumaçar",
    "enchumaçais": "enchumaçar",
    "enchumaçam": "enchumaçar",
    "enchumaçamo": "enchumaçar",
    "enchumaçamos": "enchumaçar",
    "enchumaçando": "enchumaçar",
    "enchumaçara": "enchumaçar",
    "enchumaçaram": "enchumaçar",
    "enchumaçaras": "enchumaçar",
    "enchumaçarde": "enchumaçar",
    "enchumaçardes": "enchumaçar",
    "enchumaçare": "enchumaçar",
    "enchumaçarei": "enchumaçar",
    "enchumaçareis": "enchumaçar",
    "enchumaçarem": "enchumaçar",
    "enchumaçaremos": "enchumaçar",
    "enchumaçares": "enchumaçar",
    "enchumaçaria": "enchumaçar",
    "enchumaçariam": "enchumaçar",
    "enchumaçarias": "enchumaçar",
    "enchumaçarmo": "enchumaçar",
    "enchumaçarmos": "enchumaçar",
    "enchumaçará": "enchumaçar",
    "enchumaçarás": "enchumaçar",
    "enchumaçarão": "enchumaçar",
    "enchumaçaríamos": "enchumaçar",
    "enchumaçaríeis": "enchumaçar",
    "enchumaças": "enchumaçar",
    "enchumaçasse": "enchumaçar",
    "enchumaçassem": "enchumaçar",
    "enchumaçasses": "enchumaçar",
    "enchumaçaste": "enchumaçar",
    "enchumaçastes": "enchumaçar",
    "enchumaçava": "enchumaçar",
    "enchumaçavam": "enchumaçar",
    "enchumaçavas": "enchumaçar",
    "enchumaço": "enchumaçar",
    "enchumaços": "enchumaço",
    "enchumaçou": "enchumaçar",
    "enchumaçá": "enchumaçar",
    "enchumaçámo": "enchumaçar",
    "enchumaçámos": "enchumaçar",
    "enchumaçáramo": "enchumaçar",
    "enchumaçáramos": "enchumaçar",
    "enchumaçárei": "enchumaçar",
    "enchumaçáreis": "enchumaçar",
    "enchumaçásseis": "enchumaçar",
    "enchumaçássemos": "enchumaçar",
    "enchumaçávamo": "enchumaçar",
    "enchumaçávamos": "enchumaçar",
    "enchumaçávei": "enchumaçar",
    "enchumaçáveis": "enchumaçar",
    "enchumba": "enchumbar",
    "enchumbada": "enchumbar",
    "enchumbadas": "enchumbar",
    "enchumbado": "enchumbar",
    "enchumbados": "enchumbar",
    "enchumbai": "enchumbar",
    "enchumbais": "enchumbar",
    "enchumbam": "enchumbar",
    "enchumbamo": "enchumbar",
    "enchumbamos": "enchumbar",
    "enchumbando": "enchumbar",
    "enchumbara": "enchumbar",
    "enchumbaram": "enchumbar",
    "enchumbaras": "enchumbar",
    "enchumbarde": "enchumbar",
    "enchumbardes": "enchumbar",
    "enchumbare": "enchumbar",
    "enchumbarei": "enchumbar",
    "enchumbareis": "enchumbar",
    "enchumbarem": "enchumbar",
    "enchumbaremos": "enchumbar",
    "enchumbares": "enchumbar",
    "enchumbaria": "enchumbar",
    "enchumbariam": "enchumbar",
    "enchumbarias": "enchumbar",
    "enchumbarmo": "enchumbar",
    "enchumbarmos": "enchumbar",
    "enchumbará": "enchumbar",
    "enchumbarás": "enchumbar",
    "enchumbarão": "enchumbar",
    "enchumbaríamos": "enchumbar",
    "enchumbaríeis": "enchumbar",
    "enchumbas": "enchumbar",
    "enchumbasse": "enchumbar",
    "enchumbassem": "enchumbar",
    "enchumbasses": "enchumbar",
    "enchumbaste": "enchumbar",
    "enchumbastes": "enchumbar",
    "enchumbava": "enchumbar",
    "enchumbavam": "enchumbar",
    "enchumbavas": "enchumbar",
    "enchumbe": "enchumbar",
    "enchumbei": "enchumbar",
    "enchumbeis": "enchumbar",
    "enchumbem": "enchumbar",
    "enchumbemo": "enchumbar",
    "enchumbemos": "enchumbar",
    "enchumbes": "enchumbar",
    "enchumbo": "enchumbar",
    "enchumbou": "enchumbar",
    "enchumbá": "enchumbar",
    "enchumbámo": "enchumbar",
    "enchumbámos": "enchumbar",
    "enchumbáramo": "enchumbar",
    "enchumbáramos": "enchumbar",
    "enchumbárei": "enchumbar",
    "enchumbáreis": "enchumbar",
    "enchumbásseis": "enchumbar",
    "enchumbássemos": "enchumbar",
    "enchumbávamo": "enchumbar",
    "enchumbávamos": "enchumbar",
    "enchumbávei": "enchumbar",
    "enchumbáveis": "enchumbar",
    "enchusma": "enchusmar",
    "enchusmada": "enchusmar",
    "enchusmadas": "enchusmar",
    "enchusmado": "enchusmar",
    "enchusmados": "enchusmar",
    "enchusmai": "enchusmar",
    "enchusmais": "enchusmar",
    "enchusmam": "enchusmar",
    "enchusmamo": "enchusmar",
    "enchusmamos": "enchusmar",
    "enchusmando": "enchusmar",
    "enchusmara": "enchusmar",
    "enchusmaram": "enchusmar",
    "enchusmaras": "enchusmar",
    "enchusmarde": "enchusmar",
    "enchusmardes": "enchusmar",
    "enchusmare": "enchusmar",
    "enchusmarei": "enchusmar",
    "enchusmareis": "enchusmar",
    "enchusmarem": "enchusmar",
    "enchusmaremos": "enchusmar",
    "enchusmares": "enchusmar",
    "enchusmaria": "enchusmar",
    "enchusmariam": "enchusmar",
    "enchusmarias": "enchusmar",
    "enchusmarmo": "enchusmar",
    "enchusmarmos": "enchusmar",
    "enchusmará": "enchusmar",
    "enchusmarás": "enchusmar",
    "enchusmarão": "enchusmar",
    "enchusmaríamos": "enchusmar",
    "enchusmaríeis": "enchusmar",
    "enchusmas": "enchusmar",
    "enchusmasse": "enchusmar",
    "enchusmassem": "enchusmar",
    "enchusmasses": "enchusmar",
    "enchusmaste": "enchusmar",
    "enchusmastes": "enchusmar",
    "enchusmava": "enchusmar",
    "enchusmavam": "enchusmar",
    "enchusmavas": "enchusmar",
    "enchusme": "enchusmar",
    "enchusmei": "enchusmar",
    "enchusmeis": "enchusmar",
    "enchusmem": "enchusmar",
    "enchusmemo": "enchusmar",
    "enchusmemos": "enchusmar",
    "enchusmes": "enchusmar",
    "enchusmo": "enchusmar",
    "enchusmou": "enchusmar",
    "enchusmá": "enchusmar",
    "enchusmámo": "enchusmar",
    "enchusmámos": "enchusmar",
    "enchusmáramo": "enchusmar",
    "enchusmáramos": "enchusmar",
    "enchusmárei": "enchusmar",
    "enchusmáreis": "enchusmar",
    "enchusmásseis": "enchusmar",
    "enchusmássemos": "enchusmar",
    "enchusmávamo": "enchusmar",
    "enchusmávamos": "enchusmar",
    "enchusmávei": "enchusmar",
    "enchusmáveis": "enchusmar",
    "enchê": "encher",
    "enchêramo": "encher",
    "enchêramos": "encher",
    "enchêrei": "encher",
    "enchêreis": "encher",
    "enchêsseis": "encher",
    "enchêssemos": "encher",
    "enchíamo": "encher",
    "enchíamos": "encher",
    "enchíei": "encher",
    "enchíeis": "encher",
    "enchós": "enchó",
    "enciclias": "enciclia",
    "enciclopedismos": "enciclopedismo",
    "enciclopedistas": "enciclopedista",
    "enciclopédias": "enciclopédia",
    "enciclopédica": "enciclopédico",
    "enciclopédicas": "enciclopédico",
    "enciclopédicos": "enciclopédico",
    "encieira": "encieirar",
    "encieirada": "encieirar",
    "encieiradas": "encieirar",
    "encieirado": "encieirar",
    "encieirados": "encieirar",
    "encieirai": "encieirar",
    "encieirais": "encieirar",
    "encieiram": "encieirar",
    "encieiramo": "encieirar",
    "encieiramos": "encieirar",
    "encieirando": "encieirar",
    "encieirara": "encieirar",
    "encieiraram": "encieirar",
    "encieiraras": "encieirar",
    "encieirarde": "encieirar",
    "encieirardes": "encieirar",
    "encieirare": "encieirar",
    "encieirarei": "encieirar",
    "encieirareis": "encieirar",
    "encieirarem": "encieirar",
    "encieiraremos": "encieirar",
    "encieirares": "encieirar",
    "encieiraria": "encieirar",
    "encieirariam": "encieirar",
    "encieirarias": "encieirar",
    "encieirarmo": "encieirar",
    "encieirarmos": "encieirar",
    "encieirará": "encieirar",
    "encieirarás": "encieirar",
    "encieirarão": "encieirar",
    "encieiraríamos": "encieirar",
    "encieiraríeis": "encieirar",
    "encieiras": "encieirar",
    "encieirasse": "encieirar",
    "encieirassem": "encieirar",
    "encieirasses": "encieirar",
    "encieiraste": "encieirar",
    "encieirastes": "encieirar",
    "encieirava": "encieirar",
    "encieiravam": "encieirar",
    "encieiravas": "encieirar",
    "encieire": "encieirar",
    "encieirei": "encieirar",
    "encieireis": "encieirar",
    "encieirem": "encieirar",
    "encieiremo": "encieirar",
    "encieiremos": "encieirar",
    "encieires": "encieirar",
    "encieiro": "encieirar",
    "encieirou": "encieirar",
    "encieirá": "encieirar",
    "encieirámo": "encieirar",
    "encieirámos": "encieirar",
    "encieiráramo": "encieirar",
    "encieiráramos": "encieirar",
    "encieirárei": "encieirar",
    "encieiráreis": "encieirar",
    "encieirásseis": "encieirar",
    "encieirássemos": "encieirar",
    "encieirávamo": "encieirar",
    "encieirávamos": "encieirar",
    "encieirávei": "encieirar",
    "encieiráveis": "encieirar",
    "encilha": "encilhar",
    "encilhada": "encilhar",
    "encilhadas": "encilhar",
    "encilhado": "encilhar",
    "encilhados": "encilhar",
    "encilhai": "encilhar",
    "encilhais": "encilhar",
    "encilham": "encilhar",
    "encilhamentos": "encilhamento",
    "encilhamo": "encilhar",
    "encilhamos": "encilhar",
    "encilhando": "encilhar",
    "encilhara": "encilhar",
    "encilharam": "encilhar",
    "encilharas": "encilhar",
    "encilharde": "encilhar",
    "encilhardes": "encilhar",
    "encilhare": "encilhar",
    "encilharei": "encilhar",
    "encilhareis": "encilhar",
    "encilharem": "encilhar",
    "encilharemos": "encilhar",
    "encilhares": "encilhar",
    "encilharia": "encilhar",
    "encilhariam": "encilhar",
    "encilharias": "encilhar",
    "encilharmo": "encilhar",
    "encilharmos": "encilhar",
    "encilhará": "encilhar",
    "encilharás": "encilhar",
    "encilharão": "encilhar",
    "encilharíamos": "encilhar",
    "encilharíeis": "encilhar",
    "encilhas": "encilhar",
    "encilhasse": "encilhar",
    "encilhassem": "encilhar",
    "encilhasses": "encilhar",
    "encilhaste": "encilhar",
    "encilhastes": "encilhar",
    "encilhava": "encilhar",
    "encilhavam": "encilhar",
    "encilhavas": "encilhar",
    "encilhe": "encilhar",
    "encilhei": "encilhar",
    "encilheis": "encilhar",
    "encilhem": "encilhar",
    "encilhemo": "encilhar",
    "encilhemos": "encilhar",
    "encilhes": "encilhar",
    "encilho": "encilhar",
    "encilhou": "encilhar",
    "encilhá": "encilhar",
    "encilhámo": "encilhar",
    "encilhámos": "encilhar",
    "encilháramo": "encilhar",
    "encilháramos": "encilhar",
    "encilhárei": "encilhar",
    "encilháreis": "encilhar",
    "encilhásseis": "encilhar",
    "encilhássemos": "encilhar",
    "encilhávamo": "encilhar",
    "encilhávamos": "encilhar",
    "encilhávei": "encilhar",
    "encilháveis": "encilhar",
    "encima": "encimar",
    "encimada": "encimar",
    "encimadas": "encimar",
    "encimado": "encimar",
    "encimados": "encimar",
    "encimai": "encimar",
    "encimais": "encimar",
    "encimam": "encimar",
    "encimamo": "encimar",
    "encimamos": "encimar",
    "encimando": "encimar",
    "encimara": "encimar",
    "encimaram": "encimar",
    "encimaras": "encimar",
    "encimarde": "encimar",
    "encimardes": "encimar",
    "encimare": "encimar",
    "encimarei": "encimar",
    "encimareis": "encimar",
    "encimarem": "encimar",
    "encimaremos": "encimar",
    "encimares": "encimar",
    "encimaria": "encimar",
    "encimariam": "encimar",
    "encimarias": "encimar",
    "encimarmo": "encimar",
    "encimarmos": "encimar",
    "encimará": "encimar",
    "encimarás": "encimar",
    "encimarão": "encimar",
    "encimaríamos": "encimar",
    "encimaríeis": "encimar",
    "encimas": "encimar",
    "encimasse": "encimar",
    "encimassem": "encimar",
    "encimasses": "encimar",
    "encimaste": "encimar",
    "encimastes": "encimar",
    "encimava": "encimar",
    "encimavam": "encimar",
    "encimavas": "encimar",
    "encime": "encimar",
    "encimei": "encimar",
    "encimeis": "encimar",
    "encimem": "encimar",
    "encimemo": "encimar",
    "encimemos": "encimar",
    "encimes": "encimar",
    "encimo": "encimar",
    "encimou": "encimar",
    "encimá": "encimar",
    "encimámo": "encimar",
    "encimámos": "encimar",
    "encimáramo": "encimar",
    "encimáramos": "encimar",
    "encimárei": "encimar",
    "encimáreis": "encimar",
    "encimásseis": "encimar",
    "encimássemos": "encimar",
    "encimávamo": "encimar",
    "encimávamos": "encimar",
    "encimávei": "encimar",
    "encimáveis": "encimar",
    "encincha": "encinchar",
    "encinchada": "encinchar",
    "encinchadas": "encinchar",
    "encinchado": "encinchar",
    "encinchados": "encinchar",
    "encinchai": "encinchar",
    "encinchais": "encinchar",
    "encincham": "encinchar",
    "encinchamentos": "encinchamento",
    "encinchamo": "encinchar",
    "encinchamos": "encinchar",
    "encinchando": "encinchar",
    "encinchara": "encinchar",
    "encincharam": "encinchar",
    "encincharas": "encinchar",
    "encincharde": "encinchar",
    "encinchardes": "encinchar",
    "encinchare": "encinchar",
    "encincharei": "encinchar",
    "encinchareis": "encinchar",
    "encincharem": "encinchar",
    "encincharemos": "encinchar",
    "encinchares": "encinchar",
    "encincharia": "encinchar",
    "encinchariam": "encinchar",
    "encincharias": "encinchar",
    "encincharmo": "encinchar",
    "encincharmos": "encinchar",
    "encinchará": "encinchar",
    "encincharás": "encinchar",
    "encincharão": "encinchar",
    "encincharíamos": "encinchar",
    "encincharíeis": "encinchar",
    "encinchas": "encinchar",
    "encinchasse": "encinchar",
    "encinchassem": "encinchar",
    "encinchasses": "encinchar",
    "encinchaste": "encinchar",
    "encinchastes": "encinchar",
    "encinchava": "encinchar",
    "encinchavam": "encinchar",
    "encinchavas": "encinchar",
    "encinche": "encinchar",
    "encinchei": "encinchar",
    "encincheis": "encinchar",
    "encinchem": "encinchar",
    "encinchemo": "encinchar",
    "encinchemos": "encinchar",
    "encinches": "encinchar",
    "encincho": "encinchar",
    "encinchou": "encinchar",
    "encinchá": "encinchar",
    "encinchámo": "encinchar",
    "encinchámos": "encinchar",
    "encincháramo": "encinchar",
    "encincháramos": "encinchar",
    "encinchárei": "encinchar",
    "encincháreis": "encinchar",
    "encinchásseis": "encinchar",
    "encinchássemos": "encinchar",
    "encinchávamo": "encinchar",
    "encinchávamos": "encinchar",
    "encinchávei": "encinchar",
    "encincháveis": "encinchar",
    "encinha": "encinhar",
    "encinhada": "encinhar",
    "encinhadas": "encinhar",
    "encinhado": "encinhar",
    "encinhados": "encinhar",
    "encinhai": "encinhar",
    "encinhais": "encinhar",
    "encinham": "encinhar",
    "encinhamo": "encinhar",
    "encinhamos": "encinhar",
    "encinhando": "encinhar",
    "encinhara": "encinhar",
    "encinharam": "encinhar",
    "encinharas": "encinhar",
    "encinharde": "encinhar",
    "encinhardes": "encinhar",
    "encinhare": "encinhar",
    "encinharei": "encinhar",
    "encinhareis": "encinhar",
    "encinharem": "encinhar",
    "encinharemos": "encinhar",
    "encinhares": "encinhar",
    "encinharia": "encinhar",
    "encinhariam": "encinhar",
    "encinharias": "encinhar",
    "encinharmo": "encinhar",
    "encinharmos": "encinhar",
    "encinhará": "encinhar",
    "encinharás": "encinhar",
    "encinharão": "encinhar",
    "encinharíamos": "encinhar",
    "encinharíeis": "encinhar",
    "encinhas": "encinhar",
    "encinhasse": "encinhar",
    "encinhassem": "encinhar",
    "encinhasses": "encinhar",
    "encinhaste": "encinhar",
    "encinhastes": "encinhar",
    "encinhava": "encinhar",
    "encinhavam": "encinhar",
    "encinhavas": "encinhar",
    "encinhe": "encinhar",
    "encinhei": "encinhar",
    "encinheis": "encinhar",
    "encinhem": "encinhar",
    "encinhemo": "encinhar",
    "encinhemos": "encinhar",
    "encinhes": "encinhar",
    "encinho": "encinhar",
    "encinhos": "encinho",
    "encinhou": "encinhar",
    "encinhá": "encinhar",
    "encinhámo": "encinhar",
    "encinhámos": "encinhar",
    "encinháramo": "encinhar",
    "encinháramos": "encinhar",
    "encinhárei": "encinhar",
    "encinháreis": "encinhar",
    "encinhásseis": "encinhar",
    "encinhássemos": "encinhar",
    "encinhávamo": "encinhar",
    "encinhávamos": "encinhar",
    "encinhávei": "encinhar",
    "encinháveis": "encinhar",
    "encinta": "encintar",
    "encintada": "encintar",
    "encintadas": "encintar",
    "encintado": "encintar",
    "encintados": "encintar",
    "encintai": "encintar",
    "encintais": "encintar",
    "encintam": "encintar",
    "encintamo": "encintar",
    "encintamos": "encintar",
    "encintando": "encintar",
    "encintara": "encintar",
    "encintaram": "encintar",
    "encintaras": "encintar",
    "encintarde": "encintar",
    "encintardes": "encintar",
    "encintare": "encintar",
    "encintarei": "encintar",
    "encintareis": "encintar",
    "encintarem": "encintar",
    "encintaremos": "encintar",
    "encintares": "encintar",
    "encintaria": "encintar",
    "encintariam": "encintar",
    "encintarias": "encintar",
    "encintarmo": "encintar",
    "encintarmos": "encintar",
    "encintará": "encintar",
    "encintarás": "encintar",
    "encintarão": "encintar",
    "encintaríamos": "encintar",
    "encintaríeis": "encintar",
    "encintas": "encintar",
    "encintasse": "encintar",
    "encintassem": "encintar",
    "encintasses": "encintar",
    "encintaste": "encintar",
    "encintastes": "encintar",
    "encintava": "encintar",
    "encintavam": "encintar",
    "encintavas": "encintar",
    "encinte": "encintar",
    "encintei": "encintar",
    "encinteis": "encintar",
    "encintem": "encintar",
    "encintemo": "encintar",
    "encintemos": "encintar",
    "encintes": "encintar",
    "encinto": "encintar",
    "encintou": "encintar",
    "encintá": "encintar",
    "encintámo": "encintar",
    "encintámos": "encintar",
    "encintáramo": "encintar",
    "encintáramos": "encintar",
    "encintárei": "encintar",
    "encintáreis": "encintar",
    "encintásseis": "encintar",
    "encintássemos": "encintar",
    "encintávamo": "encintar",
    "encintávamos": "encintar",
    "encintávei": "encintar",
    "encintáveis": "encintar",
    "encinza": "encinzar",
    "encinzada": "encinzar",
    "encinzadas": "encinzar",
    "encinzado": "encinzar",
    "encinzados": "encinzar",
    "encinzai": "encinzar",
    "encinzais": "encinzar",
    "encinzam": "encinzar",
    "encinzamo": "encinzar",
    "encinzamos": "encinzar",
    "encinzando": "encinzar",
    "encinzara": "encinzar",
    "encinzaram": "encinzar",
    "encinzaras": "encinzar",
    "encinzarde": "encinzar",
    "encinzardes": "encinzar",
    "encinzare": "encinzar",
    "encinzarei": "encinzar",
    "encinzareis": "encinzar",
    "encinzarem": "encinzar",
    "encinzaremos": "encinzar",
    "encinzares": "encinzar",
    "encinzaria": "encinzar",
    "encinzariam": "encinzar",
    "encinzarias": "encinzar",
    "encinzarmo": "encinzar",
    "encinzarmos": "encinzar",
    "encinzará": "encinzar",
    "encinzarás": "encinzar",
    "encinzarão": "encinzar",
    "encinzaríamos": "encinzar",
    "encinzaríeis": "encinzar",
    "encinzas": "encinzar",
    "encinzasse": "encinzar",
    "encinzassem": "encinzar",
    "encinzasses": "encinzar",
    "encinzaste": "encinzar",
    "encinzastes": "encinzar",
    "encinzava": "encinzar",
    "encinzavam": "encinzar",
    "encinzavas": "encinzar",
    "encinze": "encinzar",
    "encinzei": "encinzar",
    "encinzeis": "encinzar",
    "encinzem": "encinzar",
    "encinzemo": "encinzar",
    "encinzemos": "encinzar",
    "encinzentada": "encinzentado",
    "encinzentadas": "encinzentado",
    "encinzentados": "encinzentado",
    "encinzes": "encinzar",
    "encinzo": "encinzar",
    "encinzou": "encinzar",
    "encinzá": "encinzar",
    "encinzámo": "encinzar",
    "encinzámos": "encinzar",
    "encinzáramo": "encinzar",
    "encinzáramos": "encinzar",
    "encinzárei": "encinzar",
    "encinzáreis": "encinzar",
    "encinzásseis": "encinzar",
    "encinzássemos": "encinzar",
    "encinzávamo": "encinzar",
    "encinzávamos": "encinzar",
    "encinzávei": "encinzar",
    "encinzáveis": "encinzar",
    "enciuma": "enciumar",
    "enciumada": "enciumar",
    "enciumadas": "enciumar",
    "enciumado": "enciumar",
    "enciumados": "enciumar",
    "enciumai": "enciumar",
    "enciumais": "enciumar",
    "enciumam": "enciumar",
    "enciumamo": "enciumar",
    "enciumamos": "enciumar",
    "enciumando": "enciumar",
    "enciumara": "enciumar",
    "enciumaram": "enciumar",
    "enciumaras": "enciumar",
    "enciumarde": "enciumar",
    "enciumardes": "enciumar",
    "enciumare": "enciumar",
    "enciumarei": "enciumar",
    "enciumareis": "enciumar",
    "enciumarem": "enciumar",
    "enciumaremos": "enciumar",
    "enciumares": "enciumar",
    "enciumaria": "enciumar",
    "enciumariam": "enciumar",
    "enciumarias": "enciumar",
    "enciumarmo": "enciumar",
    "enciumarmos": "enciumar",
    "enciumará": "enciumar",
    "enciumarás": "enciumar",
    "enciumarão": "enciumar",
    "enciumaríamos": "enciumar",
    "enciumaríeis": "enciumar",
    "enciumas": "enciumar",
    "enciumasse": "enciumar",
    "enciumassem": "enciumar",
    "enciumasses": "enciumar",
    "enciumaste": "enciumar",
    "enciumastes": "enciumar",
    "enciumava": "enciumar",
    "enciumavam": "enciumar",
    "enciumavas": "enciumar",
    "enciume": "enciumar",
    "enciumei": "enciumar",
    "enciumeis": "enciumar",
    "enciumem": "enciumar",
    "enciumemo": "enciumar",
    "enciumemos": "enciumar",
    "enciumes": "enciumar",
    "enciumo": "enciumar",
    "enciumou": "enciumar",
    "enciumá": "enciumar",
    "enciumámo": "enciumar",
    "enciumámos": "enciumar",
    "enciumáramo": "enciumar",
    "enciumáramos": "enciumar",
    "enciumárei": "enciumar",
    "enciumáreis": "enciumar",
    "enciumásseis": "enciumar",
    "enciumássemos": "enciumar",
    "enciumávamo": "enciumar",
    "enciumávamos": "enciumar",
    "enciumávei": "enciumar",
    "enciumáveis": "enciumar",
    "enclaustra": "enclaustrar",
    "enclaustrada": "enclaustrar",
    "enclaustradas": "enclaustrar",
    "enclaustrado": "enclaustrar",
    "enclaustrados": "enclaustrar",
    "enclaustrai": "enclaustrar",
    "enclaustrais": "enclaustrar",
    "enclaustram": "enclaustrar",
    "enclaustramentos": "enclaustramento",
    "enclaustramo": "enclaustrar",
    "enclaustramos": "enclaustrar",
    "enclaustrando": "enclaustrar",
    "enclaustrara": "enclaustrar",
    "enclaustraram": "enclaustrar",
    "enclaustraras": "enclaustrar",
    "enclaustrarde": "enclaustrar",
    "enclaustrardes": "enclaustrar",
    "enclaustrare": "enclaustrar",
    "enclaustrarei": "enclaustrar",
    "enclaustrareis": "enclaustrar",
    "enclaustrarem": "enclaustrar",
    "enclaustraremos": "enclaustrar",
    "enclaustrares": "enclaustrar",
    "enclaustraria": "enclaustrar",
    "enclaustrariam": "enclaustrar",
    "enclaustrarias": "enclaustrar",
    "enclaustrarmo": "enclaustrar",
    "enclaustrarmos": "enclaustrar",
    "enclaustrará": "enclaustrar",
    "enclaustrarás": "enclaustrar",
    "enclaustrarão": "enclaustrar",
    "enclaustraríamos": "enclaustrar",
    "enclaustraríeis": "enclaustrar",
    "enclaustras": "enclaustrar",
    "enclaustrasse": "enclaustrar",
    "enclaustrassem": "enclaustrar",
    "enclaustrasses": "enclaustrar",
    "enclaustraste": "enclaustrar",
    "enclaustrastes": "enclaustrar",
    "enclaustrava": "enclaustrar",
    "enclaustravam": "enclaustrar",
    "enclaustravas": "enclaustrar",
    "enclaustre": "enclaustrar",
    "enclaustrei": "enclaustrar",
    "enclaustreis": "enclaustrar",
    "enclaustrem": "enclaustrar",
    "enclaustremo": "enclaustrar",
    "enclaustremos": "enclaustrar",
    "enclaustres": "enclaustrar",
    "enclaustro": "enclaustrar",
    "enclaustrou": "enclaustrar",
    "enclaustrá": "enclaustrar",
    "enclaustrámo": "enclaustrar",
    "enclaustrámos": "enclaustrar",
    "enclaustráramo": "enclaustrar",
    "enclaustráramos": "enclaustrar",
    "enclaustrárei": "enclaustrar",
    "enclaustráreis": "enclaustrar",
    "enclaustrásseis": "enclaustrar",
    "enclaustrássemos": "enclaustrar",
    "enclaustrávamo": "enclaustrar",
    "enclaustrávamos": "enclaustrar",
    "enclaustrávei": "enclaustrar",
    "enclaustráveis": "enclaustrar",
    "enclausura": "enclausurar",
    "enclausurada": "enclausurar",
    "enclausuradas": "enclausurar",
    "enclausurado": "enclausurar",
    "enclausurados": "enclausurar",
    "enclausurai": "enclausurar",
    "enclausurais": "enclausurar",
    "enclausuram": "enclausurar",
    "enclausuramentos": "enclausuramento",
    "enclausuramo": "enclausurar",
    "enclausuramos": "enclausurar",
    "enclausurando": "enclausurar",
    "enclausurara": "enclausurar",
    "enclausuraram": "enclausurar",
    "enclausuraras": "enclausurar",
    "enclausurarde": "enclausurar",
    "enclausurardes": "enclausurar",
    "enclausurare": "enclausurar",
    "enclausurarei": "enclausurar",
    "enclausurareis": "enclausurar",
    "enclausurarem": "enclausurar",
    "enclausuraremos": "enclausurar",
    "enclausurares": "enclausurar",
    "enclausuraria": "enclausurar",
    "enclausurariam": "enclausurar",
    "enclausurarias": "enclausurar",
    "enclausurarmo": "enclausurar",
    "enclausurarmos": "enclausurar",
    "enclausurará": "enclausurar",
    "enclausurarás": "enclausurar",
    "enclausurarão": "enclausurar",
    "enclausuraríamos": "enclausurar",
    "enclausuraríeis": "enclausurar",
    "enclausuras": "enclausurar",
    "enclausurasse": "enclausurar",
    "enclausurassem": "enclausurar",
    "enclausurasses": "enclausurar",
    "enclausuraste": "enclausurar",
    "enclausurastes": "enclausurar",
    "enclausurava": "enclausurar",
    "enclausuravam": "enclausurar",
    "enclausuravas": "enclausurar",
    "enclausure": "enclausurar",
    "enclausurei": "enclausurar",
    "enclausureis": "enclausurar",
    "enclausurem": "enclausurar",
    "enclausuremo": "enclausurar",
    "enclausuremos": "enclausurar",
    "enclausures": "enclausurar",
    "enclausuro": "enclausurar",
    "enclausurou": "enclausurar",
    "enclausurá": "enclausurar",
    "enclausurámo": "enclausurar",
    "enclausurámos": "enclausurar",
    "enclausuráramo": "enclausurar",
    "enclausuráramos": "enclausurar",
    "enclausurárei": "enclausurar",
    "enclausuráreis": "enclausurar",
    "enclausurásseis": "enclausurar",
    "enclausurássemos": "enclausurar",
    "enclausurávamo": "enclausurar",
    "enclausurávamos": "enclausurar",
    "enclausurávei": "enclausurar",
    "enclausuráveis": "enclausurar",
    "enclaves": "enclave",
    "enclavinha": "enclavinhar",
    "enclavinhada": "enclavinhar",
    "enclavinhadas": "enclavinhar",
    "enclavinhado": "enclavinhar",
    "enclavinhados": "enclavinhar",
    "enclavinhai": "enclavinhar",
    "enclavinhais": "enclavinhar",
    "enclavinham": "enclavinhar",
    "enclavinhamo": "enclavinhar",
    "enclavinhamos": "enclavinhar",
    "enclavinhando": "enclavinhar",
    "enclavinhara": "enclavinhar",
    "enclavinharam": "enclavinhar",
    "enclavinharas": "enclavinhar",
    "enclavinharde": "enclavinhar",
    "enclavinhardes": "enclavinhar",
    "enclavinhare": "enclavinhar",
    "enclavinharei": "enclavinhar",
    "enclavinhareis": "enclavinhar",
    "enclavinharem": "enclavinhar",
    "enclavinharemos": "enclavinhar",
    "enclavinhares": "enclavinhar",
    "enclavinharia": "enclavinhar",
    "enclavinhariam": "enclavinhar",
    "enclavinharias": "enclavinhar",
    "enclavinharmo": "enclavinhar",
    "enclavinharmos": "enclavinhar",
    "enclavinhará": "enclavinhar",
    "enclavinharás": "enclavinhar",
    "enclavinharão": "enclavinhar",
    "enclavinharíamos": "enclavinhar",
    "enclavinharíeis": "enclavinhar",
    "enclavinhas": "enclavinhar",
    "enclavinhasse": "enclavinhar",
    "enclavinhassem": "enclavinhar",
    "enclavinhasses": "enclavinhar",
    "enclavinhaste": "enclavinhar",
    "enclavinhastes": "enclavinhar",
    "enclavinhava": "enclavinhar",
    "enclavinhavam": "enclavinhar",
    "enclavinhavas": "enclavinhar",
    "enclavinhe": "enclavinhar",
    "enclavinhei": "enclavinhar",
    "enclavinheis": "enclavinhar",
    "enclavinhem": "enclavinhar",
    "enclavinhemo": "enclavinhar",
    "enclavinhemos": "enclavinhar",
    "enclavinhes": "enclavinhar",
    "enclavinho": "enclavinhar",
    "enclavinhou": "enclavinhar",
    "enclavinhá": "enclavinhar",
    "enclavinhámo": "enclavinhar",
    "enclavinhámos": "enclavinhar",
    "enclavinháramo": "enclavinhar",
    "enclavinháramos": "enclavinhar",
    "enclavinhárei": "enclavinhar",
    "enclavinháreis": "enclavinhar",
    "enclavinhásseis": "enclavinhar",
    "enclavinhássemos": "enclavinhar",
    "enclavinhávamo": "enclavinhar",
    "enclavinhávamos": "enclavinhar",
    "enclavinhávei": "enclavinhar",
    "enclavinháveis": "enclavinhar",
    "enclíticas": "enclítica",
    "encoberta": "encobrir",
    "encobertada": "encobertar",
    "encobertadas": "encobertar",
    "encobertado": "encobertar",
    "encobertados": "encobertar",
    "encobertai": "encobertar",
    "encobertais": "encobertar",
    "encobertam": "encobertar",
    "encobertamo": "encobertar",
    "encobertamos": "encobertar",
    "encobertando": "encobertar",
    "encobertara": "encobertar",
    "encobertaram": "encobertar",
    "encobertaras": "encobertar",
    "encobertarde": "encobertar",
    "encobertardes": "encobertar",
    "encobertare": "encobertar",
    "encobertarei": "encobertar",
    "encobertareis": "encobertar",
    "encobertarem": "encobertar",
    "encobertaremos": "encobertar",
    "encobertares": "encobertar",
    "encobertaria": "encobertar",
    "encobertariam": "encobertar",
    "encobertarias": "encobertar",
    "encobertarmo": "encobertar",
    "encobertarmos": "encobertar",
    "encobertará": "encobertar",
    "encobertarás": "encobertar",
    "encobertarão": "encobertar",
    "encobertaríamos": "encobertar",
    "encobertaríeis": "encobertar",
    "encobertas": "encobrir",
    "encobertasse": "encobertar",
    "encobertassem": "encobertar",
    "encobertasses": "encobertar",
    "encobertaste": "encobertar",
    "encobertastes": "encobertar",
    "encobertava": "encobertar",
    "encobertavam": "encobertar",
    "encobertavas": "encobertar",
    "encoberte": "encobertar",
    "encobertei": "encobertar",
    "encoberteis": "encobertar",
    "encobertem": "encobertar",
    "encobertemo": "encobertar",
    "encobertemos": "encobertar",
    "encobertes": "encobertar",
    "encoberto": "encobrir",
    "encobertos": "encobrir",
    "encobertou": "encobertar",
    "encobertá": "encobertar",
    "encobertámo": "encobertar",
    "encobertámos": "encobertar",
    "encobertáramo": "encobertar",
    "encobertáramos": "encobertar",
    "encobertárei": "encobertar",
    "encobertáreis": "encobertar",
    "encobertásseis": "encobertar",
    "encobertássemos": "encobertar",
    "encobertávamo": "encobertar",
    "encobertávamos": "encobertar",
    "encobertávei": "encobertar",
    "encobertáveis": "encobertar",
    "encobre": "encobrir",
    "encobrem": "encobrir",
    "encobres": "encobrir",
    "encobri": "encobrir",
    "encobria": "encobrir",
    "encobriam": "encobrir",
    "encobrias": "encobrir",
    "encobrida": "encobrir",
    "encobridas": "encobrir",
    "encobrideira": "encobridor",
    "encobrideiras": "encobridor",
    "encobrido": "encobrir",
    "encobridoiros": "encobridoiro",
    "encobridora": "encobridor",
    "encobridoras": "encobridor",
    "encobridores": "encobridor",
    "encobridos": "encobrir",
    "encobridouros": "encobridouro",
    "encobrimentos": "encobrimento",
    "encobrimo": "encobrir",
    "encobrimos": "encobrir",
    "encobrindo": "encobrir",
    "encobrira": "encobrir",
    "encobriram": "encobrir",
    "encobriras": "encobrir",
    "encobrirde": "encobrir",
    "encobrirdes": "encobrir",
    "encobrire": "encobrir",
    "encobrirei": "encobrir",
    "encobrireis": "encobrir",
    "encobrirem": "encobrir",
    "encobriremos": "encobrir",
    "encobrires": "encobrir",
    "encobriria": "encobrir",
    "encobririam": "encobrir",
    "encobririas": "encobrir",
    "encobrirmo": "encobrir",
    "encobrirmos": "encobrir",
    "encobrirá": "encobrir",
    "encobrirás": "encobrir",
    "encobrirão": "encobrir",
    "encobriríamos": "encobrir",
    "encobriríeis": "encobrir",
    "encobris": "encobrir",
    "encobrisse": "encobrir",
    "encobrissem": "encobrir",
    "encobrisses": "encobrir",
    "encobriste": "encobrir",
    "encobristes": "encobrir",
    "encobriu": "encobrir",
    "encobríamo": "encobrir",
    "encobríamos": "encobrir",
    "encobríei": "encobrir",
    "encobríeis": "encobrir",
    "encobríramo": "encobrir",
    "encobríramos": "encobrir",
    "encobrírei": "encobrir",
    "encobríreis": "encobrir",
    "encobrísseis": "encobrir",
    "encobríssemos": "encobrir",
    "encobríveis": "encobrível",
    "encocuruta": "encocurutar",
    "encocurutada": "encocurutar",
    "encocurutadas": "encocurutar",
    "encocurutado": "encocurutar",
    "encocurutados": "encocurutar",
    "encocurutai": "encocurutar",
    "encocurutais": "encocurutar",
    "encocurutam": "encocurutar",
    "encocurutamo": "encocurutar",
    "encocurutamos": "encocurutar",
    "encocurutando": "encocurutar",
    "encocurutara": "encocurutar",
    "encocurutaram": "encocurutar",
    "encocurutaras": "encocurutar",
    "encocurutarde": "encocurutar",
    "encocurutardes": "encocurutar",
    "encocurutare": "encocurutar",
    "encocurutarei": "encocurutar",
    "encocurutareis": "encocurutar",
    "encocurutarem": "encocurutar",
    "encocurutaremos": "encocurutar",
    "encocurutares": "encocurutar",
    "encocurutaria": "encocurutar",
    "encocurutariam": "encocurutar",
    "encocurutarias": "encocurutar",
    "encocurutarmo": "encocurutar",
    "encocurutarmos": "encocurutar",
    "encocurutará": "encocurutar",
    "encocurutarás": "encocurutar",
    "encocurutarão": "encocurutar",
    "encocurutaríamos": "encocurutar",
    "encocurutaríeis": "encocurutar",
    "encocurutas": "encocurutar",
    "encocurutasse": "encocurutar",
    "encocurutassem": "encocurutar",
    "encocurutasses": "encocurutar",
    "encocurutaste": "encocurutar",
    "encocurutastes": "encocurutar",
    "encocurutava": "encocurutar",
    "encocurutavam": "encocurutar",
    "encocurutavas": "encocurutar",
    "encocurute": "encocurutar",
    "encocurutei": "encocurutar",
    "encocuruteis": "encocurutar",
    "encocurutem": "encocurutar",
    "encocurutemo": "encocurutar",
    "encocurutemos": "encocurutar",
    "encocurutes": "encocurutar",
    "encocuruto": "encocurutar",
    "encocurutou": "encocurutar",
    "encocurutá": "encocurutar",
    "encocurutámo": "encocurutar",
    "encocurutámos": "encocurutar",
    "encocurutáramo": "encocurutar",
    "encocurutáramos": "encocurutar",
    "encocurutárei": "encocurutar",
    "encocurutáreis": "encocurutar",
    "encocurutásseis": "encocurutar",
    "encocurutássemos": "encocurutar",
    "encocurutávamo": "encocurutar",
    "encocurutávamos": "encocurutar",
    "encocurutávei": "encocurutar",
    "encocurutáveis": "encocurutar",
    "encoda": "encodar",
    "encodada": "encodar",
    "encodadas": "encodar",
    "encodado": "encodar",
    "encodados": "encodar",
    "encodai": "encodar",
    "encodais": "encodar",
    "encodam": "encodar",
    "encodamo": "encodar",
    "encodamos": "encodar",
    "encodando": "encodar",
    "encodara": "encodar",
    "encodaram": "encodar",
    "encodaras": "encodar",
    "encodarde": "encodar",
    "encodardes": "encodar",
    "encodare": "encodar",
    "encodarei": "encodar",
    "encodareis": "encodar",
    "encodarem": "encodar",
    "encodaremos": "encodar",
    "encodares": "encodar",
    "encodaria": "encodar",
    "encodariam": "encodar",
    "encodarias": "encodar",
    "encodarmo": "encodar",
    "encodarmos": "encodar",
    "encodará": "encodar",
    "encodarás": "encodar",
    "encodarão": "encodar",
    "encodaríamos": "encodar",
    "encodaríeis": "encodar",
    "encodas": "encodar",
    "encodasse": "encodar",
    "encodassem": "encodar",
    "encodasses": "encodar",
    "encodaste": "encodar",
    "encodastes": "encodar",
    "encodava": "encodar",
    "encodavam": "encodar",
    "encodavas": "encodar",
    "encode": "encodar",
    "encodeada": "encodear",
    "encodeadas": "encodear",
    "encodeado": "encodear",
    "encodeados": "encodear",
    "encodeai": "encodear",
    "encodeais": "encodear",
    "encodeamentos": "encodeamento",
    "encodeamo": "encodear",
    "encodeamos": "encodear",
    "encodeando": "encodear",
    "encodeara": "encodear",
    "encodearam": "encodear",
    "encodearas": "encodear",
    "encodeardes": "encodear",
    "encodearei": "encodear",
    "encodeareis": "encodear",
    "encodearem": "encodear",
    "encodearemos": "encodear",
    "encodeares": "encodear",
    "encodearia": "encodear",
    "encodeariam": "encodear",
    "encodearias": "encodear",
    "encodearmo": "encodear",
    "encodearmos": "encodear",
    "encodeará": "encodear",
    "encodearás": "encodear",
    "encodearão": "encodear",
    "encodearíamos": "encodear",
    "encodearíeis": "encodear",
    "encodeasse": "encodear",
    "encodeassem": "encodear",
    "encodeasses": "encodear",
    "encodeaste": "encodear",
    "encodeastes": "encodear",
    "encodeava": "encodear",
    "encodeavam": "encodear",
    "encodeavas": "encodear",
    "encodeei": "encodear",
    "encodeeis": "encodear",
    "encodeemo": "encodear",
    "encodeemos": "encodear",
    "encodei": "encodar",
    "encodeia": "encodear",
    "encodeiam": "encodear",
    "encodeias": "encodear",
    "encodeie": "encodear",
    "encodeiem": "encodear",
    "encodeies": "encodear",
    "encodeio": "encodear",
    "encodeis": "encodar",
    "encodem": "encodar",
    "encodemo": "encodar",
    "encodemos": "encodar",
    "encodeou": "encodear",
    "encodes": "encodar",
    "encodeámo": "encodear",
    "encodeámos": "encodear",
    "encodeáramo": "encodear",
    "encodeáramos": "encodear",
    "encodeáreis": "encodear",
    "encodeásseis": "encodear",
    "encodeássemos": "encodear",
    "encodeávamo": "encodear",
    "encodeávamos": "encodear",
    "encodeáveis": "encodear",
    "encodo": "encodar",
    "encodou": "encodar",
    "encodá": "encodar",
    "encodámo": "encodar",
    "encodámos": "encodar",
    "encodáramo": "encodar",
    "encodáramos": "encodar",
    "encodárei": "encodar",
    "encodáreis": "encodar",
    "encodásseis": "encodar",
    "encodássemos": "encodar",
    "encodávamo": "encodar",
    "encodávamos": "encodar",
    "encodávei": "encodar",
    "encodáveis": "encodar",
    "encofra": "encofrar",
    "encofrada": "encofrar",
    "encofradas": "encofrar",
    "encofrado": "encofrar",
    "encofrados": "encofrar",
    "encofrai": "encofrar",
    "encofrais": "encofrar",
    "encofram": "encofrar",
    "encoframo": "encofrar",
    "encoframos": "encofrar",
    "encofrando": "encofrar",
    "encofrara": "encofrar",
    "encofraram": "encofrar",
    "encofraras": "encofrar",
    "encofrarde": "encofrar",
    "encofrardes": "encofrar",
    "encofrare": "encofrar",
    "encofrarei": "encofrar",
    "encofrareis": "encofrar",
    "encofrarem": "encofrar",
    "encofraremos": "encofrar",
    "encofrares": "encofrar",
    "encofraria": "encofrar",
    "encofrariam": "encofrar",
    "encofrarias": "encofrar",
    "encofrarmo": "encofrar",
    "encofrarmos": "encofrar",
    "encofrará": "encofrar",
    "encofrarás": "encofrar",
    "encofrarão": "encofrar",
    "encofraríamos": "encofrar",
    "encofraríeis": "encofrar",
    "encofras": "encofrar",
    "encofrasse": "encofrar",
    "encofrassem": "encofrar",
    "encofrasses": "encofrar",
    "encofraste": "encofrar",
    "encofrastes": "encofrar",
    "encofrava": "encofrar",
    "encofravam": "encofrar",
    "encofravas": "encofrar",
    "encofre": "encofrar",
    "encofrei": "encofrar",
    "encofreis": "encofrar",
    "encofrem": "encofrar",
    "encofremo": "encofrar",
    "encofremos": "encofrar",
    "encofres": "encofrar",
    "encofro": "encofrar",
    "encofrou": "encofrar",
    "encofrá": "encofrar",
    "encofrámo": "encofrar",
    "encofrámos": "encofrar",
    "encofráramo": "encofrar",
    "encofráramos": "encofrar",
    "encofrárei": "encofrar",
    "encofráreis": "encofrar",
    "encofrásseis": "encofrar",
    "encofrássemos": "encofrar",
    "encofrávamo": "encofrar",
    "encofrávamos": "encofrar",
    "encofrávei": "encofrar",
    "encofráveis": "encofrar",
    "encoifa": "encoifar",
    "encoifada": "encoifar",
    "encoifadas": "encoifar",
    "encoifado": "encoifar",
    "encoifados": "encoifar",
    "encoifai": "encoifar",
    "encoifais": "encoifar",
    "encoifam": "encoifar",
    "encoifamo": "encoifar",
    "encoifamos": "encoifar",
    "encoifando": "encoifar",
    "encoifara": "encoifar",
    "encoifaram": "encoifar",
    "encoifaras": "encoifar",
    "encoifarde": "encoifar",
    "encoifardes": "encoifar",
    "encoifare": "encoifar",
    "encoifarei": "encoifar",
    "encoifareis": "encoifar",
    "encoifarem": "encoifar",
    "encoifaremos": "encoifar",
    "encoifares": "encoifar",
    "encoifaria": "encoifar",
    "encoifariam": "encoifar",
    "encoifarias": "encoifar",
    "encoifarmo": "encoifar",
    "encoifarmos": "encoifar",
    "encoifará": "encoifar",
    "encoifarás": "encoifar",
    "encoifarão": "encoifar",
    "encoifaríamos": "encoifar",
    "encoifaríeis": "encoifar",
    "encoifas": "encoifar",
    "encoifasse": "encoifar",
    "encoifassem": "encoifar",
    "encoifasses": "encoifar",
    "encoifaste": "encoifar",
    "encoifastes": "encoifar",
    "encoifava": "encoifar",
    "encoifavam": "encoifar",
    "encoifavas": "encoifar",
    "encoife": "encoifar",
    "encoifei": "encoifar",
    "encoifeis": "encoifar",
    "encoifem": "encoifar",
    "encoifemo": "encoifar",
    "encoifemos": "encoifar",
    "encoifes": "encoifar",
    "encoifo": "encoifar",
    "encoifou": "encoifar",
    "encoifá": "encoifar",
    "encoifámo": "encoifar",
    "encoifámos": "encoifar",
    "encoifáramo": "encoifar",
    "encoifáramos": "encoifar",
    "encoifárei": "encoifar",
    "encoifáreis": "encoifar",
    "encoifásseis": "encoifar",
    "encoifássemos": "encoifar",
    "encoifávamo": "encoifar",
    "encoifávamos": "encoifar",
    "encoifávei": "encoifar",
    "encoifáveis": "encoifar",
    "encoima": "encoimar",
    "encoimada": "encoimar",
    "encoimadas": "encoimar",
    "encoimado": "encoimar",
    "encoimados": "encoimar",
    "encoimai": "encoimar",
    "encoimais": "encoimar",
    "encoimam": "encoimar",
    "encoimamo": "encoimar",
    "encoimamos": "encoimar",
    "encoimando": "encoimar",
    "encoimara": "encoimar",
    "encoimaram": "encoimar",
    "encoimaras": "encoimar",
    "encoimarde": "encoimar",
    "encoimardes": "encoimar",
    "encoimare": "encoimar",
    "encoimarei": "encoimar",
    "encoimareis": "encoimar",
    "encoimarem": "encoimar",
    "encoimaremos": "encoimar",
    "encoimares": "encoimar",
    "encoimaria": "encoimar",
    "encoimariam": "encoimar",
    "encoimarias": "encoimar",
    "encoimarmo": "encoimar",
    "encoimarmos": "encoimar",
    "encoimará": "encoimar",
    "encoimarás": "encoimar",
    "encoimarão": "encoimar",
    "encoimaríamos": "encoimar",
    "encoimaríeis": "encoimar",
    "encoimas": "encoimar",
    "encoimasse": "encoimar",
    "encoimassem": "encoimar",
    "encoimasses": "encoimar",
    "encoimaste": "encoimar",
    "encoimastes": "encoimar",
    "encoimava": "encoimar",
    "encoimavam": "encoimar",
    "encoimavas": "encoimar",
    "encoime": "encoimar",
    "encoimei": "encoimar",
    "encoimeis": "encoimar",
    "encoimem": "encoimar",
    "encoimemo": "encoimar",
    "encoimemos": "encoimar",
    "encoimes": "encoimar",
    "encoimo": "encoimar",
    "encoimou": "encoimar",
    "encoimá": "encoimar",
    "encoimámo": "encoimar",
    "encoimámos": "encoimar",
    "encoimáramo": "encoimar",
    "encoimáramos": "encoimar",
    "encoimárei": "encoimar",
    "encoimáreis": "encoimar",
    "encoimásseis": "encoimar",
    "encoimássemos": "encoimar",
    "encoimávamo": "encoimar",
    "encoimávamos": "encoimar",
    "encoimávei": "encoimar",
    "encoimáveis": "encoimar",
    "encoira": "encoirar",
    "encoirace": "encoiraçar",
    "encoiracei": "encoiraçar",
    "encoiraceis": "encoiraçar",
    "encoiracem": "encoiraçar",
    "encoiracemo": "encoiraçar",
    "encoiracemos": "encoiraçar",
    "encoiraces": "encoiraçar",
    "encoirada": "encoirar",
    "encoiradas": "encoirar",
    "encoirado": "encoirar",
    "encoirados": "encoirar",
    "encoirai": "encoirar",
    "encoirais": "encoirar",
    "encoiram": "encoirar",
    "encoiramo": "encoirar",
    "encoiramos": "encoirar",
    "encoirando": "encoirar",
    "encoirara": "encoirar",
    "encoiraram": "encoirar",
    "encoiraras": "encoirar",
    "encoirarde": "encoirar",
    "encoirardes": "encoirar",
    "encoirare": "encoirar",
    "encoirarei": "encoirar",
    "encoirareis": "encoirar",
    "encoirarem": "encoirar",
    "encoiraremos": "encoirar",
    "encoirares": "encoirar",
    "encoiraria": "encoirar",
    "encoirariam": "encoirar",
    "encoirarias": "encoirar",
    "encoirarmo": "encoirar",
    "encoirarmos": "encoirar",
    "encoirará": "encoirar",
    "encoirarás": "encoirar",
    "encoirarão": "encoirar",
    "encoiraríamos": "encoirar",
    "encoiraríeis": "encoirar",
    "encoiras": "encoirar",
    "encoirasse": "encoirar",
    "encoirassem": "encoirar",
    "encoirasses": "encoirar",
    "encoiraste": "encoirar",
    "encoirastes": "encoirar",
    "encoirava": "encoirar",
    "encoiravam": "encoirar",
    "encoiravas": "encoirar",
    "encoiraça": "encoiraçar",
    "encoiraçada": "encoiraçar",
    "encoiraçadas": "encoiraçar",
    "encoiraçado": "encoiraçar",
    "encoiraçados": "encoiraçar",
    "encoiraçai": "encoiraçar",
    "encoiraçais": "encoiraçar",
    "encoiraçam": "encoiraçar",
    "encoiraçamo": "encoiraçar",
    "encoiraçamos": "encoiraçar",
    "encoiraçando": "encoiraçar",
    "encoiraçara": "encoiraçar",
    "encoiraçaram": "encoiraçar",
    "encoiraçaras": "encoiraçar",
    "encoiraçarde": "encoiraçar",
    "encoiraçardes": "encoiraçar",
    "encoiraçare": "encoiraçar",
    "encoiraçarei": "encoiraçar",
    "encoiraçareis": "encoiraçar",
    "encoiraçarem": "encoiraçar",
    "encoiraçaremos": "encoiraçar",
    "encoiraçares": "encoiraçar",
    "encoiraçaria": "encoiraçar",
    "encoiraçariam": "encoiraçar",
    "encoiraçarias": "encoiraçar",
    "encoiraçarmo": "encoiraçar",
    "encoiraçarmos": "encoiraçar",
    "encoiraçará": "encoiraçar",
    "encoiraçarás": "encoiraçar",
    "encoiraçarão": "encoiraçar",
    "encoiraçaríamos": "encoiraçar",
    "encoiraçaríeis": "encoiraçar",
    "encoiraças": "encoiraçar",
    "encoiraçasse": "encoiraçar",
    "encoiraçassem": "encoiraçar",
    "encoiraçasses": "encoiraçar",
    "encoiraçaste": "encoiraçar",
    "encoiraçastes": "encoiraçar",
    "encoiraçava": "encoiraçar",
    "encoiraçavam": "encoiraçar",
    "encoiraçavas": "encoiraçar",
    "encoiraço": "encoiraçar",
    "encoiraçou": "encoiraçar",
    "encoiraçá": "encoiraçar",
    "encoiraçámo": "encoiraçar",
    "encoiraçámos": "encoiraçar",
    "encoiraçáramo": "encoiraçar",
    "encoiraçáramos": "encoiraçar",
    "encoiraçárei": "encoiraçar",
    "encoiraçáreis": "encoiraçar",
    "encoiraçásseis": "encoiraçar",
    "encoiraçássemos": "encoiraçar",
    "encoiraçávamo": "encoiraçar",
    "encoiraçávamos": "encoiraçar",
    "encoiraçávei": "encoiraçar",
    "encoiraçáveis": "encoiraçar",
    "encoire": "encoirar",
    "encoirei": "encoirar",
    "encoireis": "encoirar",
    "encoirem": "encoirar",
    "encoiremo": "encoirar",
    "encoiremos": "encoirar",
    "encoires": "encoirar",
    "encoiro": "encoirar",
    "encoirou": "encoirar",
    "encoirá": "encoirar",
    "encoirámo": "encoirar",
    "encoirámos": "encoirar",
    "encoiráramo": "encoirar",
    "encoiráramos": "encoirar",
    "encoirárei": "encoirar",
    "encoiráreis": "encoirar",
    "encoirásseis": "encoirar",
    "encoirássemos": "encoirar",
    "encoirávamo": "encoirar",
    "encoirávamos": "encoirar",
    "encoirávei": "encoirar",
    "encoiráveis": "encoirar",
    "encola": "encolar",
    "encolada": "encolar",
    "encoladas": "encolar",
    "encolado": "encolar",
    "encolados": "encolar",
    "encolai": "encolar",
    "encolais": "encolar",
    "encolam": "encolar",
    "encolamo": "encolar",
    "encolamos": "encolar",
    "encolando": "encolar",
    "encolara": "encolar",
    "encolaram": "encolar",
    "encolaras": "encolar",
    "encolarde": "encolar",
    "encolardes": "encolar",
    "encolare": "encolar",
    "encolarei": "encolar",
    "encolareis": "encolar",
    "encolarem": "encolar",
    "encolaremos": "encolar",
    "encolares": "encolar",
    "encolaria": "encolar",
    "encolariam": "encolar",
    "encolarias": "encolar",
    "encolarinhada": "encolarinhado",
    "encolarinhadas": "encolarinhado",
    "encolarinhados": "encolarinhado",
    "encolarmo": "encolar",
    "encolarmos": "encolar",
    "encolará": "encolar",
    "encolarás": "encolar",
    "encolarão": "encolar",
    "encolaríamos": "encolar",
    "encolaríeis": "encolar",
    "encolas": "encolar",
    "encolasse": "encolar",
    "encolassem": "encolar",
    "encolasses": "encolar",
    "encolaste": "encolar",
    "encolastes": "encolar",
    "encolava": "encolar",
    "encolavam": "encolar",
    "encolavas": "encolar",
    "encole": "encolar",
    "encolei": "encolar",
    "encoleira": "encoleirar",
    "encoleirada": "encoleirar",
    "encoleiradas": "encoleirar",
    "encoleirado": "encoleirar",
    "encoleirados": "encoleirar",
    "encoleirai": "encoleirar",
    "encoleirais": "encoleirar",
    "encoleiram": "encoleirar",
    "encoleiramo": "encoleirar",
    "encoleiramos": "encoleirar",
    "encoleirando": "encoleirar",
    "encoleirara": "encoleirar",
    "encoleiraram": "encoleirar",
    "encoleiraras": "encoleirar",
    "encoleirarde": "encoleirar",
    "encoleirardes": "encoleirar",
    "encoleirare": "encoleirar",
    "encoleirarei": "encoleirar",
    "encoleirareis": "encoleirar",
    "encoleirarem": "encoleirar",
    "encoleiraremos": "encoleirar",
    "encoleirares": "encoleirar",
    "encoleiraria": "encoleirar",
    "encoleirariam": "encoleirar",
    "encoleirarias": "encoleirar",
    "encoleirarmo": "encoleirar",
    "encoleirarmos": "encoleirar",
    "encoleirará": "encoleirar",
    "encoleirarás": "encoleirar",
    "encoleirarão": "encoleirar",
    "encoleiraríamos": "encoleirar",
    "encoleiraríeis": "encoleirar",
    "encoleiras": "encoleirar",
    "encoleirasse": "encoleirar",
    "encoleirassem": "encoleirar",
    "encoleirasses": "encoleirar",
    "encoleiraste": "encoleirar",
    "encoleirastes": "encoleirar",
    "encoleirava": "encoleirar",
    "encoleiravam": "encoleirar",
    "encoleiravas": "encoleirar",
    "encoleire": "encoleirar",
    "encoleirei": "encoleirar",
    "encoleireis": "encoleirar",
    "encoleirem": "encoleirar",
    "encoleiremo": "encoleirar",
    "encoleiremos": "encoleirar",
    "encoleires": "encoleirar",
    "encoleiro": "encoleirar",
    "encoleirou": "encoleirar",
    "encoleirá": "encoleirar",
    "encoleirámo": "encoleirar",
    "encoleirámos": "encoleirar",
    "encoleiráramo": "encoleirar",
    "encoleiráramos": "encoleirar",
    "encoleirárei": "encoleirar",
    "encoleiráreis": "encoleirar",
    "encoleirásseis": "encoleirar",
    "encoleirássemos": "encoleirar",
    "encoleirávamo": "encoleirar",
    "encoleirávamos": "encoleirar",
    "encoleirávei": "encoleirar",
    "encoleiráveis": "encoleirar",
    "encoleis": "encolar",
    "encolem": "encolar",
    "encolemo": "encolar",
    "encolemos": "encolar",
    "encoleriza": "encolerizar",
    "encolerizada": "encolerizar",
    "encolerizadas": "encolerizar",
    "encolerizado": "encolerizar",
    "encolerizados": "encolerizar",
    "encolerizai": "encolerizar",
    "encolerizais": "encolerizar",
    "encolerizam": "encolerizar",
    "encolerizamo": "encolerizar",
    "encolerizamos": "encolerizar",
    "encolerizando": "encolerizar",
    "encolerizara": "encolerizar",
    "encolerizaram": "encolerizar",
    "encolerizaras": "encolerizar",
    "encolerizarde": "encolerizar",
    "encolerizardes": "encolerizar",
    "encolerizare": "encolerizar",
    "encolerizarei": "encolerizar",
    "encolerizareis": "encolerizar",
    "encolerizarem": "encolerizar",
    "encolerizaremos": "encolerizar",
    "encolerizares": "encolerizar",
    "encolerizaria": "encolerizar",
    "encolerizariam": "encolerizar",
    "encolerizarias": "encolerizar",
    "encolerizarmo": "encolerizar",
    "encolerizarmos": "encolerizar",
    "encolerizará": "encolerizar",
    "encolerizarás": "encolerizar",
    "encolerizarão": "encolerizar",
    "encolerizaríamos": "encolerizar",
    "encolerizaríeis": "encolerizar",
    "encolerizas": "encolerizar",
    "encolerizasse": "encolerizar",
    "encolerizassem": "encolerizar",
    "encolerizasses": "encolerizar",
    "encolerizaste": "encolerizar",
    "encolerizastes": "encolerizar",
    "encolerizava": "encolerizar",
    "encolerizavam": "encolerizar",
    "encolerizavas": "encolerizar",
    "encolerize": "encolerizar",
    "encolerizei": "encolerizar",
    "encolerizeis": "encolerizar",
    "encolerizem": "encolerizar",
    "encolerizemo": "encolerizar",
    "encolerizemos": "encolerizar",
    "encolerizes": "encolerizar",
    "encolerizo": "encolerizar",
    "encolerizou": "encolerizar",
    "encolerizá": "encolerizar",
    "encolerizámo": "encolerizar",
    "encolerizámos": "encolerizar",
    "encolerizáramo": "encolerizar",
    "encolerizáramos": "encolerizar",
    "encolerizárei": "encolerizar",
    "encolerizáreis": "encolerizar",
    "encolerizásseis": "encolerizar",
    "encolerizássemos": "encolerizar",
    "encolerizávamo": "encolerizar",
    "encolerizávamos": "encolerizar",
    "encolerizávei": "encolerizar",
    "encolerizáveis": "encolerizar",
    "encoles": "encolar",
    "encolha": "encolher",
    "encolhais": "encolher",
    "encolham": "encolher",
    "encolhamo": "encolher",
    "encolhamos": "encolher",
    "encolhas": "encolher",
    "encolhe": "encolher",
    "encolhedelas": "encolhedela",
    "encolhei": "encolher",
    "encolheis": "encolher",
    "encolhem": "encolher",
    "encolhemo": "encolher",
    "encolhemos": "encolher",
    "encolhendo": "encolher",
    "encolhera": "encolher",
    "encolheram": "encolher",
    "encolheras": "encolher",
    "encolherde": "encolher",
    "encolherdes": "encolher",
    "encolhere": "encolher",
    "encolherei": "encolher",
    "encolhereis": "encolher",
    "encolherem": "encolher",
    "encolheremos": "encolher",
    "encolheres": "encolher",
    "encolheria": "encolher",
    "encolheriam": "encolher",
    "encolherias": "encolher",
    "encolhermo": "encolher",
    "encolhermos": "encolher",
    "encolherá": "encolher",
    "encolherás": "encolher",
    "encolherão": "encolher",
    "encolheríamos": "encolher",
    "encolheríeis": "encolher",
    "encolhes": "encolher",
    "encolhesse": "encolher",
    "encolhessem": "encolher",
    "encolhesses": "encolher",
    "encolheste": "encolher",
    "encolhestes": "encolher",
    "encolheu": "encolher",
    "encolhi": "encolher",
    "encolhia": "encolher",
    "encolhiam": "encolher",
    "encolhias": "encolher",
    "encolhida": "encolhido",
    "encolhidas": "encolhido",
    "encolhido": "encolher",
    "encolhidos": "encolhido",
    "encolhidíssima": "encolhido",
    "encolhidíssimas": "encolhido",
    "encolhidíssimo": "encolhido",
    "encolhidíssimos": "encolhido",
    "encolhimentos": "encolhimento",
    "encolho": "encolher",
    "encolhê": "encolher",
    "encolhêramo": "encolher",
    "encolhêramos": "encolher",
    "encolhêrei": "encolher",
    "encolhêreis": "encolher",
    "encolhêsseis": "encolher",
    "encolhêssemos": "encolher",
    "encolhíamo": "encolher",
    "encolhíamos": "encolher",
    "encolhíei": "encolher",
    "encolhíeis": "encolher",
    "encolo": "encolar",
    "encolou": "encolar",
    "encolá": "encolar",
    "encolámo": "encolar",
    "encolámos": "encolar",
    "encoláramo": "encolar",
    "encoláramos": "encolar",
    "encolárei": "encolar",
    "encoláreis": "encolar",
    "encolásseis": "encolar",
    "encolássemos": "encolar",
    "encolávamo": "encolar",
    "encolávamos": "encolar",
    "encolávei": "encolar",
    "encoláveis": "encolar",
    "encomenda": "encomendar",
    "encomendada": "encomendar",
    "encomendadas": "encomendar",
    "encomendado": "encomendar",
    "encomendados": "encomendar",
    "encomendai": "encomendar",
    "encomendais": "encomendar",
    "encomendam": "encomendar",
    "encomendamo": "encomendar",
    "encomendamos": "encomendar",
    "encomendando": "encomendar",
    "encomendara": "encomendar",
    "encomendaram": "encomendar",
    "encomendaras": "encomendar",
    "encomendarde": "encomendar",
    "encomendardes": "encomendar",
    "encomendare": "encomendar",
    "encomendarei": "encomendar",
    "encomendareis": "encomendar",
    "encomendarem": "encomendar",
    "encomendaremos": "encomendar",
    "encomendares": "encomendar",
    "encomendaria": "encomendar",
    "encomendariam": "encomendar",
    "encomendarias": "encomendar",
    "encomendarmo": "encomendar",
    "encomendarmos": "encomendar",
    "encomendará": "encomendar",
    "encomendarás": "encomendar",
    "encomendarão": "encomendar",
    "encomendaríamos": "encomendar",
    "encomendaríeis": "encomendar",
    "encomendas": "encomendar",
    "encomendasse": "encomendar",
    "encomendassem": "encomendar",
    "encomendasses": "encomendar",
    "encomendaste": "encomendar",
    "encomendastes": "encomendar",
    "encomendava": "encomendar",
    "encomendavam": "encomendar",
    "encomendavas": "encomendar",
    "encomendações": "encomendação",
    "encomende": "encomendar",
    "encomendei": "encomendar",
    "encomendeira": "encomendeiro",
    "encomendeiras": "encomendeiro",
    "encomendeiros": "encomendeiro",
    "encomendeis": "encomendar",
    "encomendem": "encomendar",
    "encomendemo": "encomendar",
    "encomendemos": "encomendar",
    "encomendes": "encomendar",
    "encomendinha": "encomenda",
    "encomendinhas": "encomenda",
    "encomendita": "encomenda",
    "encomenditas": "encomenda",
    "encomendo": "encomendar",
    "encomendou": "encomendar",
    "encomendá": "encomendar",
    "encomendámo": "encomendar",
    "encomendámos": "encomendar",
    "encomendáramo": "encomendar",
    "encomendáramos": "encomendar",
    "encomendárei": "encomendar",
    "encomendáreis": "encomendar",
    "encomendásseis": "encomendar",
    "encomendássemos": "encomendar",
    "encomendávamo": "encomendar",
    "encomendávamos": "encomendar",
    "encomendávei": "encomendar",
    "encomendáveis": "encomendar",
    "encomia": "encomiar",
    "encomiada": "encomiar",
    "encomiadas": "encomiar",
    "encomiado": "encomiar",
    "encomiadora": "encomiador",
    "encomiadoras": "encomiador",
    "encomiadores": "encomiador",
    "encomiados": "encomiar",
    "encomiai": "encomiar",
    "encomiais": "encomiar",
    "encomiam": "encomiar",
    "encomiamo": "encomiar",
    "encomiamos": "encomiar",
    "encomiando": "encomiar",
    "encomiara": "encomiar",
    "encomiaram": "encomiar",
    "encomiaras": "encomiar",
    "encomiarde": "encomiar",
    "encomiardes": "encomiar",
    "encomiare": "encomiar",
    "encomiarei": "encomiar",
    "encomiareis": "encomiar",
    "encomiarem": "encomiar",
    "encomiaremos": "encomiar",
    "encomiares": "encomiar",
    "encomiaria": "encomiar",
    "encomiariam": "encomiar",
    "encomiarias": "encomiar",
    "encomiarmo": "encomiar",
    "encomiarmos": "encomiar",
    "encomiará": "encomiar",
    "encomiarás": "encomiar",
    "encomiarão": "encomiar",
    "encomiaríamos": "encomiar",
    "encomiaríeis": "encomiar",
    "encomias": "encomiar",
    "encomiasse": "encomiar",
    "encomiassem": "encomiar",
    "encomiasses": "encomiar",
    "encomiastas": "encomiasta",
    "encomiaste": "encomiar",
    "encomiastes": "encomiar",
    "encomiava": "encomiar",
    "encomiavam": "encomiar",
    "encomiavas": "encomiar",
    "encomie": "encomiar",
    "encomiei": "encomiar",
    "encomieis": "encomiar",
    "encomiem": "encomiar",
    "encomiemo": "encomiar",
    "encomiemos": "encomiar",
    "encomies": "encomiar",
    "encomio": "encomiar",
    "encomiou": "encomiar",
    "encomissa": "encomissar",
    "encomissada": "encomissar",
    "encomissadas": "encomissar",
    "encomissado": "encomissar",
    "encomissados": "encomissar",
    "encomissai": "encomissar",
    "encomissais": "encomissar",
    "encomissam": "encomissar",
    "encomissamo": "encomissar",
    "encomissamos": "encomissar",
    "encomissando": "encomissar",
    "encomissara": "encomissar",
    "encomissaram": "encomissar",
    "encomissaras": "encomissar",
    "encomissardes": "encomissar",
    "encomissarei": "encomissar",
    "encomissareis": "encomissar",
    "encomissarem": "encomissar",
    "encomissaremos": "encomissar",
    "encomissares": "encomissar",
    "encomissaria": "encomissar",
    "encomissariam": "encomissar",
    "encomissarias": "encomissar",
    "encomissarmo": "encomissar",
    "encomissarmos": "encomissar",
    "encomissará": "encomissar",
    "encomissarás": "encomissar",
    "encomissarão": "encomissar",
    "encomissaríamos": "encomissar",
    "encomissaríeis": "encomissar",
    "encomissas": "encomissar",
    "encomissasse": "encomissar",
    "encomissassem": "encomissar",
    "encomissasses": "encomissar",
    "encomissaste": "encomissar",
    "encomissastes": "encomissar",
    "encomissava": "encomissar",
    "encomissavam": "encomissar",
    "encomissavas": "encomissar",
    "encomisse": "encomissar",
    "encomissei": "encomissar",
    "encomisseis": "encomissar",
    "encomissem": "encomissar",
    "encomissemo": "encomissar",
    "encomissemos": "encomissar",
    "encomisses": "encomissar",
    "encomisso": "encomissar",
    "encomissou": "encomissar",
    "encomissámo": "encomissar",
    "encomissámos": "encomissar",
    "encomissáramo": "encomissar",
    "encomissáramos": "encomissar",
    "encomissáreis": "encomissar",
    "encomissásseis": "encomissar",
    "encomissássemos": "encomissar",
    "encomissávamo": "encomissar",
    "encomissávamos": "encomissar",
    "encomissáveis": "encomissar",
    "encomiá": "encomiar",
    "encomiámo": "encomiar",
    "encomiámos": "encomiar",
    "encomiáramo": "encomiar",
    "encomiáramos": "encomiar",
    "encomiárei": "encomiar",
    "encomiáreis": "encomiar",
    "encomiásseis": "encomiar",
    "encomiássemos": "encomiar",
    "encomiástica": "encomiástico",
    "encomiásticas": "encomiástico",
    "encomiásticos": "encomiástico",
    "encomiávamo": "encomiar",
    "encomiávamos": "encomiar",
    "encomiávei": "encomiar",
    "encomiáveis": "encomiar",
    "encomprida": "encompridar",
    "encompridada": "encompridar",
    "encompridadas": "encompridar",
    "encompridado": "encompridar",
    "encompridados": "encompridar",
    "encompridai": "encompridar",
    "encompridais": "encompridar",
    "encompridam": "encompridar",
    "encompridamo": "encompridar",
    "encompridamos": "encompridar",
    "encompridando": "encompridar",
    "encompridara": "encompridar",
    "encompridaram": "encompridar",
    "encompridaras": "encompridar",
    "encompridarde": "encompridar",
    "encompridardes": "encompridar",
    "encompridare": "encompridar",
    "encompridarei": "encompridar",
    "encompridareis": "encompridar",
    "encompridarem": "encompridar",
    "encompridaremos": "encompridar",
    "encompridares": "encompridar",
    "encompridaria": "encompridar",
    "encompridariam": "encompridar",
    "encompridarias": "encompridar",
    "encompridarmo": "encompridar",
    "encompridarmos": "encompridar",
    "encompridará": "encompridar",
    "encompridarás": "encompridar",
    "encompridarão": "encompridar",
    "encompridaríamos": "encompridar",
    "encompridaríeis": "encompridar",
    "encompridas": "encompridar",
    "encompridasse": "encompridar",
    "encompridassem": "encompridar",
    "encompridasses": "encompridar",
    "encompridaste": "encompridar",
    "encompridastes": "encompridar",
    "encompridava": "encompridar",
    "encompridavam": "encompridar",
    "encompridavas": "encompridar",
    "encompride": "encompridar",
    "encompridei": "encompridar",
    "encomprideis": "encompridar",
    "encompridem": "encompridar",
    "encompridemo": "encompridar",
    "encompridemos": "encompridar",
    "encomprides": "encompridar",
    "encomprido": "encompridar",
    "encompridou": "encompridar",
    "encompridá": "encompridar",
    "encompridámo": "encompridar",
    "encompridámos": "encompridar",
    "encompridáramo": "encompridar",
    "encompridáramos": "encompridar",
    "encompridárei": "encompridar",
    "encompridáreis": "encompridar",
    "encompridásseis": "encompridar",
    "encompridássemos": "encompridar",
    "encompridávamo": "encompridar",
    "encompridávamos": "encompridar",
    "encompridávei": "encompridar",
    "encompridáveis": "encompridar",
    "enconca": "enconcar",
    "enconcada": "enconcar",
    "enconcadas": "enconcar",
    "enconcado": "enconcar",
    "enconcados": "enconcar",
    "enconcais": "enconcar",
    "enconcam": "enconcar",
    "enconcamo": "enconcar",
    "enconcamos": "enconcar",
    "enconcando": "enconcar",
    "enconcara": "enconcar",
    "enconcaram": "enconcar",
    "enconcaras": "enconcar",
    "enconcardes": "enconcar",
    "enconcarei": "enconcar",
    "enconcareis": "enconcar",
    "enconcarem": "enconcar",
    "enconcaremos": "enconcar",
    "enconcares": "enconcar",
    "enconcaria": "enconcar",
    "enconcariam": "enconcar",
    "enconcarias": "enconcar",
    "enconcarmo": "enconcar",
    "enconcarmos": "enconcar",
    "enconcará": "enconcar",
    "enconcarás": "enconcar",
    "enconcarão": "enconcar",
    "enconcaríamos": "enconcar",
    "enconcaríeis": "enconcar",
    "enconcas": "enconcar",
    "enconcasse": "enconcar",
    "enconcassem": "enconcar",
    "enconcasses": "enconcar",
    "enconcaste": "enconcar",
    "enconcastes": "enconcar",
    "enconcava": "enconcar",
    "enconcavam": "enconcar",
    "enconcavas": "enconcar",
    "enconcha": "enconchar",
    "enconchada": "enconchar",
    "enconchadas": "enconchar",
    "enconchado": "enconchar",
    "enconchados": "enconchar",
    "enconchai": "enconchar",
    "enconchais": "enconchar",
    "enconcham": "enconchar",
    "enconchamo": "enconchar",
    "enconchamos": "enconchar",
    "enconchando": "enconchar",
    "enconchara": "enconchar",
    "enconcharam": "enconchar",
    "enconcharas": "enconchar",
    "enconchardes": "enconchar",
    "enconcharei": "enconchar",
    "enconchareis": "enconchar",
    "enconcharem": "enconchar",
    "enconcharemos": "enconchar",
    "enconchares": "enconchar",
    "enconcharia": "enconchar",
    "enconchariam": "enconchar",
    "enconcharias": "enconchar",
    "enconcharmo": "enconchar",
    "enconcharmos": "enconchar",
    "enconchará": "enconchar",
    "enconcharás": "enconchar",
    "enconcharão": "enconchar",
    "enconcharíamos": "enconchar",
    "enconcharíeis": "enconchar",
    "enconchas": "enconchar",
    "enconchasse": "enconchar",
    "enconchassem": "enconchar",
    "enconchasses": "enconchar",
    "enconchaste": "enconchar",
    "enconchastes": "enconchar",
    "enconchava": "enconchar",
    "enconchavam": "enconchar",
    "enconchavas": "enconchar",
    "enconche": "enconchar",
    "enconchei": "enconchar",
    "enconcheis": "enconchar",
    "enconchem": "enconchar",
    "enconchemo": "enconchar",
    "enconchemos": "enconchar",
    "enconches": "enconchar",
    "enconcho": "enconchar",
    "enconchou": "enconchar",
    "enconchámo": "enconchar",
    "enconchámos": "enconchar",
    "enconcháramo": "enconchar",
    "enconcháramos": "enconchar",
    "enconcháreis": "enconchar",
    "enconchásseis": "enconchar",
    "enconchássemos": "enconchar",
    "enconchávamo": "enconchar",
    "enconchávamos": "enconchar",
    "enconcháveis": "enconchar",
    "enconco": "enconcar",
    "enconcou": "enconcar",
    "enconcámo": "enconcar",
    "enconcámos": "enconcar",
    "enconcáramo": "enconcar",
    "enconcáramos": "enconcar",
    "enconcáreis": "enconcar",
    "enconcásseis": "enconcar",
    "enconcássemos": "enconcar",
    "enconcávamo": "enconcar",
    "enconcávamos": "enconcar",
    "enconcáveis": "enconcar",
    "enconicada": "enconicado",
    "enconicadas": "enconicado",
    "enconicados": "enconicado",
    "enconque": "enconcar",
    "enconquei": "enconcar",
    "enconqueis": "enconcar",
    "enconquem": "enconcar",
    "enconquemos": "enconcar",
    "enconques": "enconcar",
    "encontra": "encontrar",
    "encontrada": "encontrar",
    "encontradas": "encontrar",
    "encontradiça": "encontradiço",
    "encontradiças": "encontradiço",
    "encontradiços": "encontradiço",
    "encontrado": "encontrar",
    "encontrados": "encontrar",
    "encontrai": "encontrar",
    "encontrais": "encontrar",
    "encontram": "encontrar",
    "encontramo": "encontrar",
    "encontramos": "encontrar",
    "encontrando": "encontrar",
    "encontrara": "encontrar",
    "encontraram": "encontrar",
    "encontraras": "encontrar",
    "encontrarde": "encontrar",
    "encontrardes": "encontrar",
    "encontrare": "encontrar",
    "encontrarei": "encontrar",
    "encontrareis": "encontrar",
    "encontrarem": "encontrar",
    "encontraremos": "encontrar",
    "encontrares": "encontrar",
    "encontraria": "encontrar",
    "encontrariam": "encontrar",
    "encontrarias": "encontrar",
    "encontrarmo": "encontrar",
    "encontrarmos": "encontrar",
    "encontrará": "encontrar",
    "encontrarás": "encontrar",
    "encontrarão": "encontrar",
    "encontraríamos": "encontrar",
    "encontraríeis": "encontrar",
    "encontras": "encontrar",
    "encontrasse": "encontrar",
    "encontrassem": "encontrar",
    "encontrasses": "encontrar",
    "encontraste": "encontrar",
    "encontrastes": "encontrar",
    "encontrava": "encontrar",
    "encontravam": "encontrar",
    "encontravas": "encontrar",
    "encontre": "encontrar",
    "encontrei": "encontrar",
    "encontreis": "encontrar",
    "encontrem": "encontrar",
    "encontremo": "encontrar",
    "encontremos": "encontrar",
    "encontres": "encontrar",
    "encontro": "encontrar",
    "encontroa": "encontroar",
    "encontroada": "encontroar",
    "encontroadas": "encontroar",
    "encontroado": "encontroar",
    "encontroados": "encontroar",
    "encontroai": "encontroar",
    "encontroais": "encontroar",
    "encontroam": "encontroar",
    "encontroamo": "encontroar",
    "encontroamos": "encontroar",
    "encontroando": "encontroar",
    "encontroara": "encontroar",
    "encontroaram": "encontroar",
    "encontroaras": "encontroar",
    "encontroarde": "encontroar",
    "encontroardes": "encontroar",
    "encontroare": "encontroar",
    "encontroarei": "encontroar",
    "encontroareis": "encontroar",
    "encontroarem": "encontroar",
    "encontroaremos": "encontroar",
    "encontroares": "encontroar",
    "encontroaria": "encontroar",
    "encontroariam": "encontroar",
    "encontroarias": "encontroar",
    "encontroarmo": "encontroar",
    "encontroarmos": "encontroar",
    "encontroará": "encontroar",
    "encontroarás": "encontroar",
    "encontroarão": "encontroar",
    "encontroaríamos": "encontroar",
    "encontroaríeis": "encontroar",
    "encontroas": "encontroar",
    "encontroasse": "encontroar",
    "encontroassem": "encontroar",
    "encontroasses": "encontroar",
    "encontroaste": "encontroar",
    "encontroastes": "encontroar",
    "encontroava": "encontroar",
    "encontroavam": "encontroar",
    "encontroavas": "encontroar",
    "encontroe": "encontroar",
    "encontroei": "encontroar",
    "encontroeis": "encontroar",
    "encontroem": "encontroar",
    "encontroemo": "encontroar",
    "encontroemos": "encontroar",
    "encontroes": "encontroar",
    "encontroo": "encontroar",
    "encontroou": "encontroar",
    "encontros": "encontro",
    "encontrou": "encontrar",
    "encontroá": "encontroar",
    "encontroámo": "encontroar",
    "encontroámos": "encontroar",
    "encontroáramo": "encontroar",
    "encontroáramos": "encontroar",
    "encontroárei": "encontroar",
    "encontroáreis": "encontroar",
    "encontroásseis": "encontroar",
    "encontroássemos": "encontroar",
    "encontroávamo": "encontroar",
    "encontroávamos": "encontroar",
    "encontroávei": "encontroar",
    "encontroáveis": "encontroar",
    "encontrá": "encontrar",
    "encontrámo": "encontrar",
    "encontrámos": "encontrar",
    "encontráramo": "encontrar",
    "encontráramos": "encontrar",
    "encontrárei": "encontrar",
    "encontráreis": "encontrar",
    "encontrásseis": "encontrar",
    "encontrássemos": "encontrar",
    "encontrávamo": "encontrar",
    "encontrávamos": "encontrar",
    "encontrávei": "encontrar",
    "encontráveis": "encontrar",
    "encontrões": "encontrão",
    "encopa": "encopar",
    "encopada": "encopar",
    "encopadas": "encopar",
    "encopado": "encopar",
    "encopados": "encopar",
    "encopai": "encopar",
    "encopais": "encopar",
    "encopam": "encopar",
    "encopamo": "encopar",
    "encopamos": "encopar",
    "encopando": "encopar",
    "encopara": "encopar",
    "encoparam": "encopar",
    "encoparas": "encopar",
    "encoparde": "encopar",
    "encopardes": "encopar",
    "encopare": "encopar",
    "encoparei": "encopar",
    "encopareis": "encopar",
    "encoparem": "encopar",
    "encoparemos": "encopar",
    "encopares": "encopar",
    "encoparia": "encopar",
    "encopariam": "encopar",
    "encoparias": "encopar",
    "encoparmo": "encopar",
    "encoparmos": "encopar",
    "encopará": "encopar",
    "encoparás": "encopar",
    "encoparão": "encopar",
    "encoparíamos": "encopar",
    "encoparíeis": "encopar",
    "encopas": "encopar",
    "encopasse": "encopar",
    "encopassem": "encopar",
    "encopasses": "encopar",
    "encopaste": "encopar",
    "encopastes": "encopar",
    "encopava": "encopar",
    "encopavam": "encopar",
    "encopavas": "encopar",
    "encope": "encopar",
    "encopei": "encopar",
    "encopeis": "encopar",
    "encopem": "encopar",
    "encopemo": "encopar",
    "encopemos": "encopar",
    "encopes": "encopar",
    "encopo": "encopar",
    "encopou": "encopar",
    "encoproses": "encoprose",
    "encopá": "encopar",
    "encopámo": "encopar",
    "encopámos": "encopar",
    "encopáramo": "encopar",
    "encopáramos": "encopar",
    "encopárei": "encopar",
    "encopáreis": "encopar",
    "encopásseis": "encopar",
    "encopássemos": "encopar",
    "encopávamo": "encopar",
    "encopávamos": "encopar",
    "encopávei": "encopar",
    "encopáveis": "encopar",
    "encoquina": "encoquinar",
    "encoquinada": "encoquinar",
    "encoquinadas": "encoquinar",
    "encoquinado": "encoquinar",
    "encoquinados": "encoquinar",
    "encoquinai": "encoquinar",
    "encoquinais": "encoquinar",
    "encoquinam": "encoquinar",
    "encoquinamo": "encoquinar",
    "encoquinamos": "encoquinar",
    "encoquinando": "encoquinar",
    "encoquinara": "encoquinar",
    "encoquinaram": "encoquinar",
    "encoquinaras": "encoquinar",
    "encoquinarde": "encoquinar",
    "encoquinardes": "encoquinar",
    "encoquinare": "encoquinar",
    "encoquinarei": "encoquinar",
    "encoquinareis": "encoquinar",
    "encoquinarem": "encoquinar",
    "encoquinaremos": "encoquinar",
    "encoquinares": "encoquinar",
    "encoquinaria": "encoquinar",
    "encoquinariam": "encoquinar",
    "encoquinarias": "encoquinar",
    "encoquinarmo": "encoquinar",
    "encoquinarmos": "encoquinar",
    "encoquinará": "encoquinar",
    "encoquinarás": "encoquinar",
    "encoquinarão": "encoquinar",
    "encoquinaríamos": "encoquinar",
    "encoquinaríeis": "encoquinar",
    "encoquinas": "encoquinar",
    "encoquinasse": "encoquinar",
    "encoquinassem": "encoquinar",
    "encoquinasses": "encoquinar",
    "encoquinaste": "encoquinar",
    "encoquinastes": "encoquinar",
    "encoquinava": "encoquinar",
    "encoquinavam": "encoquinar",
    "encoquinavas": "encoquinar",
    "encoquine": "encoquinar",
    "encoquinei": "encoquinar",
    "encoquineis": "encoquinar",
    "encoquinem": "encoquinar",
    "encoquinemo": "encoquinar",
    "encoquinemos": "encoquinar",
    "encoquines": "encoquinar",
    "encoquinha": "encoquinhar",
    "encoquinhada": "encoquinhar",
    "encoquinhadas": "encoquinhar",
    "encoquinhado": "encoquinhar",
    "encoquinhados": "encoquinhar",
    "encoquinhai": "encoquinhar",
    "encoquinhais": "encoquinhar",
    "encoquinham": "encoquinhar",
    "encoquinhamo": "encoquinhar",
    "encoquinhamos": "encoquinhar",
    "encoquinhando": "encoquinhar",
    "encoquinhara": "encoquinhar",
    "encoquinharam": "encoquinhar",
    "encoquinharas": "encoquinhar",
    "encoquinharde": "encoquinhar",
    "encoquinhardes": "encoquinhar",
    "encoquinhare": "encoquinhar",
    "encoquinharei": "encoquinhar",
    "encoquinhareis": "encoquinhar",
    "encoquinharem": "encoquinhar",
    "encoquinharemos": "encoquinhar",
    "encoquinhares": "encoquinhar",
    "encoquinharia": "encoquinhar",
    "encoquinhariam": "encoquinhar",
    "encoquinharias": "encoquinhar",
    "encoquinharmo": "encoquinhar",
    "encoquinharmos": "encoquinhar",
    "encoquinhará": "encoquinhar",
    "encoquinharás": "encoquinhar",
    "encoquinharão": "encoquinhar",
    "encoquinharíamos": "encoquinhar",
    "encoquinharíeis": "encoquinhar",
    "encoquinhas": "encoquinhar",
    "encoquinhasse": "encoquinhar",
    "encoquinhassem": "encoquinhar",
    "encoquinhasses": "encoquinhar",
    "encoquinhaste": "encoquinhar",
    "encoquinhastes": "encoquinhar",
    "encoquinhava": "encoquinhar",
    "encoquinhavam": "encoquinhar",
    "encoquinhavas": "encoquinhar",
    "encoquinhe": "encoquinhar",
    "encoquinhei": "encoquinhar",
    "encoquinheis": "encoquinhar",
    "encoquinhem": "encoquinhar",
    "encoquinhemo": "encoquinhar",
    "encoquinhemos": "encoquinhar",
    "encoquinhes": "encoquinhar",
    "encoquinho": "encoquinhar",
    "encoquinhou": "encoquinhar",
    "encoquinhá": "encoquinhar",
    "encoquinhámo": "encoquinhar",
    "encoquinhámos": "encoquinhar",
    "encoquinháramo": "encoquinhar",
    "encoquinháramos": "encoquinhar",
    "encoquinhárei": "encoquinhar",
    "encoquinháreis": "encoquinhar",
    "encoquinhásseis": "encoquinhar",
    "encoquinhássemos": "encoquinhar",
    "encoquinhávamo": "encoquinhar",
    "encoquinhávamos": "encoquinhar",
    "encoquinhávei": "encoquinhar",
    "encoquinháveis": "encoquinhar",
    "encoquino": "encoquinar",
    "encoquinou": "encoquinar",
    "encoquiná": "encoquinar",
    "encoquinámo": "encoquinar",
    "encoquinámos": "encoquinar",
    "encoquináramo": "encoquinar",
    "encoquináramos": "encoquinar",
    "encoquinárei": "encoquinar",
    "encoquináreis": "encoquinar",
    "encoquinásseis": "encoquinar",
    "encoquinássemos": "encoquinar",
    "encoquinávamo": "encoquinar",
    "encoquinávamos": "encoquinar",
    "encoquinávei": "encoquinar",
    "encoquináveis": "encoquinar",
    "encoraja": "encorajar",
    "encorajada": "encorajar",
    "encorajadas": "encorajar",
    "encorajado": "encorajar",
    "encorajadora": "encorajador",
    "encorajadoras": "encorajador",
    "encorajadores": "encorajador",
    "encorajados": "encorajar",
    "encorajai": "encorajar",
    "encorajais": "encorajar",
    "encorajam": "encorajar",
    "encorajamentos": "encorajamento",
    "encorajamo": "encorajar",
    "encorajamos": "encorajar",
    "encorajando": "encorajar",
    "encorajantes": "encorajante",
    "encorajara": "encorajar",
    "encorajaram": "encorajar",
    "encorajaras": "encorajar",
    "encorajarde": "encorajar",
    "encorajardes": "encorajar",
    "encorajare": "encorajar",
    "encorajarei": "encorajar",
    "encorajareis": "encorajar",
    "encorajarem": "encorajar",
    "encorajaremos": "encorajar",
    "encorajares": "encorajar",
    "encorajaria": "encorajar",
    "encorajariam": "encorajar",
    "encorajarias": "encorajar",
    "encorajarmo": "encorajar",
    "encorajarmos": "encorajar",
    "encorajará": "encorajar",
    "encorajarás": "encorajar",
    "encorajarão": "encorajar",
    "encorajaríamos": "encorajar",
    "encorajaríeis": "encorajar",
    "encorajas": "encorajar",
    "encorajasse": "encorajar",
    "encorajassem": "encorajar",
    "encorajasses": "encorajar",
    "encorajaste": "encorajar",
    "encorajastes": "encorajar",
    "encorajava": "encorajar",
    "encorajavam": "encorajar",
    "encorajavas": "encorajar",
    "encoraje": "encorajar",
    "encorajei": "encorajar",
    "encorajeis": "encorajar",
    "encorajem": "encorajar",
    "encorajemo": "encorajar",
    "encorajemos": "encorajar",
    "encorajes": "encorajar",
    "encorajo": "encorajar",
    "encorajou": "encorajar",
    "encorajá": "encorajar",
    "encorajámo": "encorajar",
    "encorajámos": "encorajar",
    "encorajáramo": "encorajar",
    "encorajáramos": "encorajar",
    "encorajárei": "encorajar",
    "encorajáreis": "encorajar",
    "encorajásseis": "encorajar",
    "encorajássemos": "encorajar",
    "encorajávamo": "encorajar",
    "encorajávamos": "encorajar",
    "encorajávei": "encorajar",
    "encorajáveis": "encorajar",
    "encordoa": "encordoar",
    "encordoada": "encordoar",
    "encordoadas": "encordoar",
    "encordoado": "encordoar",
    "encordoados": "encordoar",
    "encordoai": "encordoar",
    "encordoais": "encordoar",
    "encordoam": "encordoar",
    "encordoamentos": "encordoamento",
    "encordoamo": "encordoar",
    "encordoamos": "encordoar",
    "encordoando": "encordoar",
    "encordoara": "encordoar",
    "encordoaram": "encordoar",
    "encordoaras": "encordoar",
    "encordoarde": "encordoar",
    "encordoardes": "encordoar",
    "encordoare": "encordoar",
    "encordoarei": "encordoar",
    "encordoareis": "encordoar",
    "encordoarem": "encordoar",
    "encordoaremos": "encordoar",
    "encordoares": "encordoar",
    "encordoaria": "encordoar",
    "encordoariam": "encordoar",
    "encordoarias": "encordoar",
    "encordoarmo": "encordoar",
    "encordoarmos": "encordoar",
    "encordoará": "encordoar",
    "encordoarás": "encordoar",
    "encordoarão": "encordoar",
    "encordoaríamos": "encordoar",
    "encordoaríeis": "encordoar",
    "encordoas": "encordoar",
    "encordoasse": "encordoar",
    "encordoassem": "encordoar",
    "encordoasses": "encordoar",
    "encordoaste": "encordoar",
    "encordoastes": "encordoar",
    "encordoava": "encordoar",
    "encordoavam": "encordoar",
    "encordoavas": "encordoar",
    "encordoações": "encordoação",
    "encordoe": "encordoar",
    "encordoei": "encordoar",
    "encordoeis": "encordoar",
    "encordoem": "encordoar",
    "encordoemo": "encordoar",
    "encordoemos": "encordoar",
    "encordoes": "encordoar",
    "encordoo": "encordoar",
    "encordoou": "encordoar",
    "encordoá": "encordoar",
    "encordoámo": "encordoar",
    "encordoámos": "encordoar",
    "encordoáramo": "encordoar",
    "encordoáramos": "encordoar",
    "encordoárei": "encordoar",
    "encordoáreis": "encordoar",
    "encordoásseis": "encordoar",
    "encordoássemos": "encordoar",
    "encordoávamo": "encordoar",
    "encordoávamos": "encordoar",
    "encordoávei": "encordoar",
    "encordoáveis": "encordoar",
    "encorna": "encornar",
    "encornada": "encornar",
    "encornadas": "encornar",
    "encornado": "encornar",
    "encornados": "encornar",
    "encornai": "encornar",
    "encornais": "encornar",
    "encornam": "encornar",
    "encornamo": "encornar",
    "encornamos": "encornar",
    "encornando": "encornar",
    "encornanços": "encornanço",
    "encornara": "encornar",
    "encornaram": "encornar",
    "encornaras": "encornar",
    "encornarde": "encornar",
    "encornardes": "encornar",
    "encornare": "encornar",
    "encornarei": "encornar",
    "encornareis": "encornar",
    "encornarem": "encornar",
    "encornaremos": "encornar",
    "encornares": "encornar",
    "encornaria": "encornar",
    "encornariam": "encornar",
    "encornarias": "encornar",
    "encornarmo": "encornar",
    "encornarmos": "encornar",
    "encornará": "encornar",
    "encornarás": "encornar",
    "encornarão": "encornar",
    "encornaríamos": "encornar",
    "encornaríeis": "encornar",
    "encornas": "encornar",
    "encornasse": "encornar",
    "encornassem": "encornar",
    "encornasses": "encornar",
    "encornaste": "encornar",
    "encornastes": "encornar",
    "encornava": "encornar",
    "encornavam": "encornar",
    "encornavas": "encornar",
    "encorne": "encornar",
    "encornei": "encornar",
    "encorneis": "encornar",
    "encornem": "encornar",
    "encornemo": "encornar",
    "encornemos": "encornar",
    "encornes": "encornar",
    "encorneta": "encornetar",
    "encornetada": "encornetar",
    "encornetadas": "encornetar",
    "encornetado": "encornetar",
    "encornetados": "encornetar",
    "encornetai": "encornetar",
    "encornetais": "encornetar",
    "encornetam": "encornetar",
    "encornetamo": "encornetar",
    "encornetamos": "encornetar",
    "encornetando": "encornetar",
    "encornetara": "encornetar",
    "encornetaram": "encornetar",
    "encornetaras": "encornetar",
    "encornetarde": "encornetar",
    "encornetardes": "encornetar",
    "encornetare": "encornetar",
    "encornetarei": "encornetar",
    "encornetareis": "encornetar",
    "encornetarem": "encornetar",
    "encornetaremos": "encornetar",
    "encornetares": "encornetar",
    "encornetaria": "encornetar",
    "encornetariam": "encornetar",
    "encornetarias": "encornetar",
    "encornetarmo": "encornetar",
    "encornetarmos": "encornetar",
    "encornetará": "encornetar",
    "encornetarás": "encornetar",
    "encornetarão": "encornetar",
    "encornetaríamos": "encornetar",
    "encornetaríeis": "encornetar",
    "encornetas": "encornetar",
    "encornetasse": "encornetar",
    "encornetassem": "encornetar",
    "encornetasses": "encornetar",
    "encornetaste": "encornetar",
    "encornetastes": "encornetar",
    "encornetava": "encornetar",
    "encornetavam": "encornetar",
    "encornetavas": "encornetar",
    "encornete": "encornetar",
    "encornetei": "encornetar",
    "encorneteis": "encornetar",
    "encornetem": "encornetar",
    "encornetemo": "encornetar",
    "encornetemos": "encornetar",
    "encornetes": "encornetar",
    "encorneto": "encornetar",
    "encornetou": "encornetar",
    "encornetá": "encornetar",
    "encornetámo": "encornetar",
    "encornetámos": "encornetar",
    "encornetáramo": "encornetar",
    "encornetáramos": "encornetar",
    "encornetárei": "encornetar",
    "encornetáreis": "encornetar",
    "encornetásseis": "encornetar",
    "encornetássemos": "encornetar",
    "encornetávamo": "encornetar",
    "encornetávamos": "encornetar",
    "encornetávei": "encornetar",
    "encornetáveis": "encornetar",
    "encorno": "encornar",
    "encornou": "encornar",
    "encorná": "encornar",
    "encornámo": "encornar",
    "encornámos": "encornar",
    "encornáramo": "encornar",
    "encornáramos": "encornar",
    "encornárei": "encornar",
    "encornáreis": "encornar",
    "encornásseis": "encornar",
    "encornássemos": "encornar",
    "encornávamo": "encornar",
    "encornávamos": "encornar",
    "encornávei": "encornar",
    "encornáveis": "encornar",
    "encoronha": "encoronhar",
    "encoronhada": "encoronhar",
    "encoronhadas": "encoronhar",
    "encoronhado": "encoronhar",
    "encoronhados": "encoronhar",
    "encoronhai": "encoronhar",
    "encoronhais": "encoronhar",
    "encoronham": "encoronhar",
    "encoronhamo": "encoronhar",
    "encoronhamos": "encoronhar",
    "encoronhando": "encoronhar",
    "encoronhara": "encoronhar",
    "encoronharam": "encoronhar",
    "encoronharas": "encoronhar",
    "encoronharde": "encoronhar",
    "encoronhardes": "encoronhar",
    "encoronhare": "encoronhar",
    "encoronharei": "encoronhar",
    "encoronhareis": "encoronhar",
    "encoronharem": "encoronhar",
    "encoronharemos": "encoronhar",
    "encoronhares": "encoronhar",
    "encoronharia": "encoronhar",
    "encoronhariam": "encoronhar",
    "encoronharias": "encoronhar",
    "encoronharmo": "encoronhar",
    "encoronharmos": "encoronhar",
    "encoronhará": "encoronhar",
    "encoronharás": "encoronhar",
    "encoronharão": "encoronhar",
    "encoronharíamos": "encoronhar",
    "encoronharíeis": "encoronhar",
    "encoronhas": "encoronhar",
    "encoronhasse": "encoronhar",
    "encoronhassem": "encoronhar",
    "encoronhasses": "encoronhar",
    "encoronhaste": "encoronhar",
    "encoronhastes": "encoronhar",
    "encoronhava": "encoronhar",
    "encoronhavam": "encoronhar",
    "encoronhavas": "encoronhar",
    "encoronhe": "encoronhar",
    "encoronhei": "encoronhar",
    "encoronheis": "encoronhar",
    "encoronhem": "encoronhar",
    "encoronhemo": "encoronhar",
    "encoronhemos": "encoronhar",
    "encoronhes": "encoronhar",
    "encoronho": "encoronhar",
    "encoronhou": "encoronhar",
    "encoronhá": "encoronhar",
    "encoronhámo": "encoronhar",
    "encoronhámos": "encoronhar",
    "encoronháramo": "encoronhar",
    "encoronháramos": "encoronhar",
    "encoronhárei": "encoronhar",
    "encoronháreis": "encoronhar",
    "encoronhásseis": "encoronhar",
    "encoronhássemos": "encoronhar",
    "encoronhávamo": "encoronhar",
    "encoronhávamos": "encoronhar",
    "encoronhávei": "encoronhar",
    "encoronháveis": "encoronhar",
    "encorpa": "encorpar",
    "encorpada": "encorpar",
    "encorpadas": "encorpar",
    "encorpado": "encorpar",
    "encorpados": "encorpar",
    "encorpaduras": "encorpadura",
    "encorpadíssima": "encorpado",
    "encorpadíssimas": "encorpado",
    "encorpadíssimo": "encorpado",
    "encorpadíssimos": "encorpado",
    "encorpai": "encorpar",
    "encorpais": "encorpar",
    "encorpam": "encorpar",
    "encorpamentos": "encorpamento",
    "encorpamo": "encorpar",
    "encorpamos": "encorpar",
    "encorpando": "encorpar",
    "encorpara": "encorpar",
    "encorparam": "encorpar",
    "encorparas": "encorpar",
    "encorparde": "encorpar",
    "encorpardes": "encorpar",
    "encorpare": "encorpar",
    "encorparei": "encorpar",
    "encorpareis": "encorpar",
    "encorparem": "encorpar",
    "encorparemos": "encorpar",
    "encorpares": "encorpar",
    "encorparia": "encorpar",
    "encorpariam": "encorpar",
    "encorparias": "encorpar",
    "encorparmo": "encorpar",
    "encorparmos": "encorpar",
    "encorpará": "encorpar",
    "encorparás": "encorpar",
    "encorparão": "encorpar",
    "encorparíamos": "encorpar",
    "encorparíeis": "encorpar",
    "encorpas": "encorpar",
    "encorpasse": "encorpar",
    "encorpassem": "encorpar",
    "encorpasses": "encorpar",
    "encorpaste": "encorpar",
    "encorpastes": "encorpar",
    "encorpava": "encorpar",
    "encorpavam": "encorpar",
    "encorpavas": "encorpar",
    "encorpe": "encorpar",
    "encorpei": "encorpar",
    "encorpeis": "encorpar",
    "encorpem": "encorpar",
    "encorpemo": "encorpar",
    "encorpemos": "encorpar",
    "encorpes": "encorpar",
    "encorpo": "encorpar",
    "encorpou": "encorpar",
    "encorpá": "encorpar",
    "encorpámo": "encorpar",
    "encorpámos": "encorpar",
    "encorpáramo": "encorpar",
    "encorpáramos": "encorpar",
    "encorpárei": "encorpar",
    "encorpáreis": "encorpar",
    "encorpásseis": "encorpar",
    "encorpássemos": "encorpar",
    "encorpávamo": "encorpar",
    "encorpávamos": "encorpar",
    "encorpávei": "encorpar",
    "encorpáveis": "encorpar",
    "encorreada": "encorrear",
    "encorreadas": "encorrear",
    "encorreado": "encorrear",
    "encorreados": "encorrear",
    "encorreaduras": "encorreadura",
    "encorreai": "encorrear",
    "encorreais": "encorrear",
    "encorreamentos": "encorreamento",
    "encorreamo": "encorrear",
    "encorreamos": "encorrear",
    "encorreando": "encorrear",
    "encorreara": "encorrear",
    "encorrearam": "encorrear",
    "encorrearas": "encorrear",
    "encorrearde": "encorrear",
    "encorreardes": "encorrear",
    "encorreare": "encorrear",
    "encorrearei": "encorrear",
    "encorreareis": "encorrear",
    "encorrearem": "encorrear",
    "encorrearemos": "encorrear",
    "encorreares": "encorrear",
    "encorrearia": "encorrear",
    "encorreariam": "encorrear",
    "encorrearias": "encorrear",
    "encorrearmo": "encorrear",
    "encorrearmos": "encorrear",
    "encorreará": "encorrear",
    "encorrearás": "encorrear",
    "encorrearão": "encorrear",
    "encorrearíamos": "encorrear",
    "encorrearíeis": "encorrear",
    "encorreasse": "encorrear",
    "encorreassem": "encorrear",
    "encorreasses": "encorrear",
    "encorreaste": "encorrear",
    "encorreastes": "encorrear",
    "encorreava": "encorrear",
    "encorreavam": "encorrear",
    "encorreavas": "encorrear",
    "encorreei": "encorrear",
    "encorreeis": "encorrear",
    "encorreemo": "encorrear",
    "encorreemos": "encorrear",
    "encorreia": "encorrear",
    "encorreiam": "encorrear",
    "encorreias": "encorrear",
    "encorreie": "encorrear",
    "encorreiem": "encorrear",
    "encorreies": "encorrear",
    "encorreio": "encorrear",
    "encorreou": "encorrear",
    "encorreá": "encorrear",
    "encorreámo": "encorrear",
    "encorreámos": "encorrear",
    "encorreáramo": "encorrear",
    "encorreáramos": "encorrear",
    "encorreárei": "encorrear",
    "encorreáreis": "encorrear",
    "encorreásseis": "encorrear",
    "encorreássemos": "encorrear",
    "encorreávamo": "encorrear",
    "encorreávamos": "encorrear",
    "encorreávei": "encorrear",
    "encorreáveis": "encorrear",
    "encorrica": "encorricar",
    "encorricada": "encorricar",
    "encorricadas": "encorricar",
    "encorricado": "encorricar",
    "encorricados": "encorricar",
    "encorricais": "encorricar",
    "encorricam": "encorricar",
    "encorricamo": "encorricar",
    "encorricamos": "encorricar",
    "encorricando": "encorricar",
    "encorricara": "encorricar",
    "encorricaram": "encorricar",
    "encorricaras": "encorricar",
    "encorricardes": "encorricar",
    "encorricarei": "encorricar",
    "encorricareis": "encorricar",
    "encorricarem": "encorricar",
    "encorricaremos": "encorricar",
    "encorricares": "encorricar",
    "encorricaria": "encorricar",
    "encorricariam": "encorricar",
    "encorricarias": "encorricar",
    "encorricarmo": "encorricar",
    "encorricarmos": "encorricar",
    "encorricará": "encorricar",
    "encorricarás": "encorricar",
    "encorricarão": "encorricar",
    "encorricaríamos": "encorricar",
    "encorricaríeis": "encorricar",
    "encorricas": "encorricar",
    "encorricasse": "encorricar",
    "encorricassem": "encorricar",
    "encorricasses": "encorricar",
    "encorricaste": "encorricar",
    "encorricastes": "encorricar",
    "encorricava": "encorricar",
    "encorricavam": "encorricar",
    "encorricavas": "encorricar",
    "encorrico": "encorricar",
    "encorricou": "encorricar",
    "encorricámo": "encorricar",
    "encorricámos": "encorricar",
    "encorricáramo": "encorricar",
    "encorricáramos": "encorricar",
    "encorricáreis": "encorricar",
    "encorricásseis": "encorricar",
    "encorricássemos": "encorricar",
    "encorricávamo": "encorricar",
    "encorricávamos": "encorricar",
    "encorricáveis": "encorricar",
    "encorrilha": "encorrilhar",
    "encorrilhada": "encorrilhar",
    "encorrilhadas": "encorrilhar",
    "encorrilhado": "encorrilhar",
    "encorrilhados": "encorrilhar",
    "encorrilhai": "encorrilhar",
    "encorrilhais": "encorrilhar",
    "encorrilham": "encorrilhar",
    "encorrilhamo": "encorrilhar",
    "encorrilhamos": "encorrilhar",
    "encorrilhando": "encorrilhar",
    "encorrilhara": "encorrilhar",
    "encorrilharam": "encorrilhar",
    "encorrilharas": "encorrilhar",
    "encorrilharde": "encorrilhar",
    "encorrilhardes": "encorrilhar",
    "encorrilhare": "encorrilhar",
    "encorrilharei": "encorrilhar",
    "encorrilhareis": "encorrilhar",
    "encorrilharem": "encorrilhar",
    "encorrilharemos": "encorrilhar",
    "encorrilhares": "encorrilhar",
    "encorrilharia": "encorrilhar",
    "encorrilhariam": "encorrilhar",
    "encorrilharias": "encorrilhar",
    "encorrilharmo": "encorrilhar",
    "encorrilharmos": "encorrilhar",
    "encorrilhará": "encorrilhar",
    "encorrilharás": "encorrilhar",
    "encorrilharão": "encorrilhar",
    "encorrilharíamos": "encorrilhar",
    "encorrilharíeis": "encorrilhar",
    "encorrilhas": "encorrilhar",
    "encorrilhasse": "encorrilhar",
    "encorrilhassem": "encorrilhar",
    "encorrilhasses": "encorrilhar",
    "encorrilhaste": "encorrilhar",
    "encorrilhastes": "encorrilhar",
    "encorrilhava": "encorrilhar",
    "encorrilhavam": "encorrilhar",
    "encorrilhavas": "encorrilhar",
    "encorrilhe": "encorrilhar",
    "encorrilhei": "encorrilhar",
    "encorrilheis": "encorrilhar",
    "encorrilhem": "encorrilhar",
    "encorrilhemo": "encorrilhar",
    "encorrilhemos": "encorrilhar",
    "encorrilhes": "encorrilhar",
    "encorrilho": "encorrilhar",
    "encorrilhou": "encorrilhar",
    "encorrilhá": "encorrilhar",
    "encorrilhámo": "encorrilhar",
    "encorrilhámos": "encorrilhar",
    "encorrilháramo": "encorrilhar",
    "encorrilháramos": "encorrilhar",
    "encorrilhárei": "encorrilhar",
    "encorrilháreis": "encorrilhar",
    "encorrilhásseis": "encorrilhar",
    "encorrilhássemos": "encorrilhar",
    "encorrilhávamo": "encorrilhar",
    "encorrilhávamos": "encorrilhar",
    "encorrilhávei": "encorrilhar",
    "encorrilháveis": "encorrilhar",
    "encorrique": "encorricar",
    "encorriquei": "encorricar",
    "encorriqueis": "encorricar",
    "encorriquem": "encorricar",
    "encorriquemos": "encorricar",
    "encorriques": "encorricar",
    "encortelha": "encortelhar",
    "encortelhada": "encortelhar",
    "encortelhadas": "encortelhar",
    "encortelhado": "encortelhar",
    "encortelhados": "encortelhar",
    "encortelhai": "encortelhar",
    "encortelhais": "encortelhar",
    "encortelham": "encortelhar",
    "encortelhamo": "encortelhar",
    "encortelhamos": "encortelhar",
    "encortelhando": "encortelhar",
    "encortelhara": "encortelhar",
    "encortelharam": "encortelhar",
    "encortelharas": "encortelhar",
    "encortelharde": "encortelhar",
    "encortelhardes": "encortelhar",
    "encortelhare": "encortelhar",
    "encortelharei": "encortelhar",
    "encortelhareis": "encortelhar",
    "encortelharem": "encortelhar",
    "encortelharemos": "encortelhar",
    "encortelhares": "encortelhar",
    "encortelharia": "encortelhar",
    "encortelhariam": "encortelhar",
    "encortelharias": "encortelhar",
    "encortelharmo": "encortelhar",
    "encortelharmos": "encortelhar",
    "encortelhará": "encortelhar",
    "encortelharás": "encortelhar",
    "encortelharão": "encortelhar",
    "encortelharíamos": "encortelhar",
    "encortelharíeis": "encortelhar",
    "encortelhas": "encortelhar",
    "encortelhasse": "encortelhar",
    "encortelhassem": "encortelhar",
    "encortelhasses": "encortelhar",
    "encortelhaste": "encortelhar",
    "encortelhastes": "encortelhar",
    "encortelhava": "encortelhar",
    "encortelhavam": "encortelhar",
    "encortelhavas": "encortelhar",
    "encortelhe": "encortelhar",
    "encortelhei": "encortelhar",
    "encortelheis": "encortelhar",
    "encortelhem": "encortelhar",
    "encortelhemo": "encortelhar",
    "encortelhemos": "encortelhar",
    "encortelhes": "encortelhar",
    "encortelho": "encortelhar",
    "encortelhou": "encortelhar",
    "encortelhá": "encortelhar",
    "encortelhámo": "encortelhar",
    "encortelhámos": "encortelhar",
    "encortelháramo": "encortelhar",
    "encortelháramos": "encortelhar",
    "encortelhárei": "encortelhar",
    "encortelháreis": "encortelhar",
    "encortelhásseis": "encortelhar",
    "encortelhássemos": "encortelhar",
    "encortelhávamo": "encortelhar",
    "encortelhávamos": "encortelhar",
    "encortelhávei": "encortelhar",
    "encortelháveis": "encortelhar",
    "encortice": "encortiçar",
    "encorticei": "encortiçar",
    "encorticeis": "encortiçar",
    "encorticem": "encortiçar",
    "encorticemo": "encortiçar",
    "encorticemos": "encortiçar",
    "encortices": "encortiçar",
    "encortina": "encortinar",
    "encortinada": "encortinar",
    "encortinadas": "encortinar",
    "encortinado": "encortinar",
    "encortinados": "encortinar",
    "encortinai": "encortinar",
    "encortinais": "encortinar",
    "encortinam": "encortinar",
    "encortinamo": "encortinar",
    "encortinamos": "encortinar",
    "encortinando": "encortinar",
    "encortinara": "encortinar",
    "encortinaram": "encortinar",
    "encortinaras": "encortinar",
    "encortinarde": "encortinar",
    "encortinardes": "encortinar",
    "encortinare": "encortinar",
    "encortinarei": "encortinar",
    "encortinareis": "encortinar",
    "encortinarem": "encortinar",
    "encortinaremos": "encortinar",
    "encortinares": "encortinar",
    "encortinaria": "encortinar",
    "encortinariam": "encortinar",
    "encortinarias": "encortinar",
    "encortinarmo": "encortinar",
    "encortinarmos": "encortinar",
    "encortinará": "encortinar",
    "encortinarás": "encortinar",
    "encortinarão": "encortinar",
    "encortinaríamos": "encortinar",
    "encortinaríeis": "encortinar",
    "encortinas": "encortinar",
    "encortinasse": "encortinar",
    "encortinassem": "encortinar",
    "encortinasses": "encortinar",
    "encortinaste": "encortinar",
    "encortinastes": "encortinar",
    "encortinava": "encortinar",
    "encortinavam": "encortinar",
    "encortinavas": "encortinar",
    "encortine": "encortinar",
    "encortinei": "encortinar",
    "encortineis": "encortinar",
    "encortinem": "encortinar",
    "encortinemo": "encortinar",
    "encortinemos": "encortinar",
    "encortines": "encortinar",
    "encortino": "encortinar",
    "encortinou": "encortinar",
    "encortiná": "encortinar",
    "encortinámo": "encortinar",
    "encortinámos": "encortinar",
    "encortináramo": "encortinar",
    "encortináramos": "encortinar",
    "encortinárei": "encortinar",
    "encortináreis": "encortinar",
    "encortinásseis": "encortinar",
    "encortinássemos": "encortinar",
    "encortinávamo": "encortinar",
    "encortinávamos": "encortinar",
    "encortinávei": "encortinar",
    "encortináveis": "encortinar",
    "encortiça": "encortiçar",
    "encortiçada": "encortiçar",
    "encortiçadas": "encortiçar",
    "encortiçado": "encortiçar",
    "encortiçados": "encortiçar",
    "encortiçai": "encortiçar",
    "encortiçais": "encortiçar",
    "encortiçam": "encortiçar",
    "encortiçamo": "encortiçar",
    "encortiçamos": "encortiçar",
    "encortiçando": "encortiçar",
    "encortiçara": "encortiçar",
    "encortiçaram": "encortiçar",
    "encortiçaras": "encortiçar",
    "encortiçardes": "encortiçar",
    "encortiçarei": "encortiçar",
    "encortiçareis": "encortiçar",
    "encortiçarem": "encortiçar",
    "encortiçaremos": "encortiçar",
    "encortiçares": "encortiçar",
    "encortiçaria": "encortiçar",
    "encortiçariam": "encortiçar",
    "encortiçarias": "encortiçar",
    "encortiçarmo": "encortiçar",
    "encortiçarmos": "encortiçar",
    "encortiçará": "encortiçar",
    "encortiçarás": "encortiçar",
    "encortiçarão": "encortiçar",
    "encortiçaríamos": "encortiçar",
    "encortiçaríeis": "encortiçar",
    "encortiças": "encortiçar",
    "encortiçasse": "encortiçar",
    "encortiçassem": "encortiçar",
    "encortiçasses": "encortiçar",
    "encortiçaste": "encortiçar",
    "encortiçastes": "encortiçar",
    "encortiçava": "encortiçar",
    "encortiçavam": "encortiçar",
    "encortiçavas": "encortiçar",
    "encortiço": "encortiçar",
    "encortiçou": "encortiçar",
    "encortiçámo": "encortiçar",
    "encortiçámos": "encortiçar",
    "encortiçáramo": "encortiçar",
    "encortiçáramos": "encortiçar",
    "encortiçáreis": "encortiçar",
    "encortiçásseis": "encortiçar",
    "encortiçássemos": "encortiçar",
    "encortiçávamo": "encortiçar",
    "encortiçávamos": "encortiçar",
    "encortiçáveis": "encortiçar",
    "encoruja": "encorujar",
    "encorujada": "encorujar",
    "encorujadas": "encorujar",
    "encorujado": "encorujar",
    "encorujados": "encorujar",
    "encorujai": "encorujar",
    "encorujais": "encorujar",
    "encorujam": "encorujar",
    "encorujamo": "encorujar",
    "encorujamos": "encorujar",
    "encorujando": "encorujar",
    "encorujara": "encorujar",
    "encorujaram": "encorujar",
    "encorujaras": "encorujar",
    "encorujarde": "encorujar",
    "encorujardes": "encorujar",
    "encorujare": "encorujar",
    "encorujarei": "encorujar",
    "encorujareis": "encorujar",
    "encorujarem": "encorujar",
    "encorujaremos": "encorujar",
    "encorujares": "encorujar",
    "encorujaria": "encorujar",
    "encorujariam": "encorujar",
    "encorujarias": "encorujar",
    "encorujarmo": "encorujar",
    "encorujarmos": "encorujar",
    "encorujará": "encorujar",
    "encorujarás": "encorujar",
    "encorujarão": "encorujar",
    "encorujaríamos": "encorujar",
    "encorujaríeis": "encorujar",
    "encorujas": "encorujar",
    "encorujasse": "encorujar",
    "encorujassem": "encorujar",
    "encorujasses": "encorujar",
    "encorujaste": "encorujar",
    "encorujastes": "encorujar",
    "encorujava": "encorujar",
    "encorujavam": "encorujar",
    "encorujavas": "encorujar",
    "encoruje": "encorujar",
    "encorujei": "encorujar",
    "encorujeis": "encorujar",
    "encorujem": "encorujar",
    "encorujemo": "encorujar",
    "encorujemos": "encorujar",
    "encorujes": "encorujar",
    "encorujo": "encorujar",
    "encorujou": "encorujar",
    "encorujá": "encorujar",
    "encorujámo": "encorujar",
    "encorujámos": "encorujar",
    "encorujáramo": "encorujar",
    "encorujáramos": "encorujar",
    "encorujárei": "encorujar",
    "encorujáreis": "encorujar",
    "encorujásseis": "encorujar",
    "encorujássemos": "encorujar",
    "encorujávamo": "encorujar",
    "encorujávamos": "encorujar",
    "encorujávei": "encorujar",
    "encorujáveis": "encorujar",
    "encorunhada": "encorunhado",
    "encorunhadas": "encorunhado",
    "encorunhados": "encorunhado",
    "encosamentos": "encosamento",
    "encoscora": "encoscorar",
    "encoscorada": "encoscorar",
    "encoscoradas": "encoscorar",
    "encoscorado": "encoscorar",
    "encoscorados": "encoscorar",
    "encoscorai": "encoscorar",
    "encoscorais": "encoscorar",
    "encoscoram": "encoscorar",
    "encoscoramentos": "encoscoramento",
    "encoscoramo": "encoscorar",
    "encoscoramos": "encoscorar",
    "encoscorando": "encoscorar",
    "encoscorara": "encoscorar",
    "encoscoraram": "encoscorar",
    "encoscoraras": "encoscorar",
    "encoscorarde": "encoscorar",
    "encoscorardes": "encoscorar",
    "encoscorare": "encoscorar",
    "encoscorarei": "encoscorar",
    "encoscorareis": "encoscorar",
    "encoscorarem": "encoscorar",
    "encoscoraremos": "encoscorar",
    "encoscorares": "encoscorar",
    "encoscoraria": "encoscorar",
    "encoscorariam": "encoscorar",
    "encoscorarias": "encoscorar",
    "encoscorarmo": "encoscorar",
    "encoscorarmos": "encoscorar",
    "encoscorará": "encoscorar",
    "encoscorarás": "encoscorar",
    "encoscorarão": "encoscorar",
    "encoscoraríamos": "encoscorar",
    "encoscoraríeis": "encoscorar",
    "encoscoras": "encoscorar",
    "encoscorasse": "encoscorar",
    "encoscorassem": "encoscorar",
    "encoscorasses": "encoscorar",
    "encoscoraste": "encoscorar",
    "encoscorastes": "encoscorar",
    "encoscorava": "encoscorar",
    "encoscoravam": "encoscorar",
    "encoscoravas": "encoscorar",
    "encoscore": "encoscorar",
    "encoscorei": "encoscorar",
    "encoscoreis": "encoscorar",
    "encoscorem": "encoscorar",
    "encoscoremo": "encoscorar",
    "encoscoremos": "encoscorar",
    "encoscores": "encoscorar",
    "encoscoro": "encoscorar",
    "encoscorou": "encoscorar",
    "encoscorá": "encoscorar",
    "encoscorámo": "encoscorar",
    "encoscorámos": "encoscorar",
    "encoscoráramo": "encoscorar",
    "encoscoráramos": "encoscorar",
    "encoscorárei": "encoscorar",
    "encoscoráreis": "encoscorar",
    "encoscorásseis": "encoscorar",
    "encoscorássemos": "encoscorar",
    "encoscorávamo": "encoscorar",
    "encoscorávamos": "encoscorar",
    "encoscorávei": "encoscorar",
    "encoscoráveis": "encoscorar",
    "encospia": "encospiar",
    "encospiada": "encospiar",
    "encospiadas": "encospiar",
    "encospiado": "encospiar",
    "encospiados": "encospiar",
    "encospiai": "encospiar",
    "encospiais": "encospiar",
    "encospiam": "encospiar",
    "encospiamo": "encospiar",
    "encospiamos": "encospiar",
    "encospiando": "encospiar",
    "encospiara": "encospiar",
    "encospiaram": "encospiar",
    "encospiaras": "encospiar",
    "encospiarde": "encospiar",
    "encospiardes": "encospiar",
    "encospiare": "encospiar",
    "encospiarei": "encospiar",
    "encospiareis": "encospiar",
    "encospiarem": "encospiar",
    "encospiaremos": "encospiar",
    "encospiares": "encospiar",
    "encospiaria": "encospiar",
    "encospiariam": "encospiar",
    "encospiarias": "encospiar",
    "encospiarmo": "encospiar",
    "encospiarmos": "encospiar",
    "encospiará": "encospiar",
    "encospiarás": "encospiar",
    "encospiarão": "encospiar",
    "encospiaríamos": "encospiar",
    "encospiaríeis": "encospiar",
    "encospias": "encospiar",
    "encospiasse": "encospiar",
    "encospiassem": "encospiar",
    "encospiasses": "encospiar",
    "encospiaste": "encospiar",
    "encospiastes": "encospiar",
    "encospiava": "encospiar",
    "encospiavam": "encospiar",
    "encospiavas": "encospiar",
    "encospie": "encospiar",
    "encospiei": "encospiar",
    "encospieis": "encospiar",
    "encospiem": "encospiar",
    "encospiemo": "encospiar",
    "encospiemos": "encospiar",
    "encospies": "encospiar",
    "encospio": "encospiar",
    "encospiou": "encospiar",
    "encospiá": "encospiar",
    "encospiámo": "encospiar",
    "encospiámos": "encospiar",
    "encospiáramo": "encospiar",
    "encospiáramos": "encospiar",
    "encospiárei": "encospiar",
    "encospiáreis": "encospiar",
    "encospiásseis": "encospiar",
    "encospiássemos": "encospiar",
    "encospiávamo": "encospiar",
    "encospiávamos": "encospiar",
    "encospiávei": "encospiar",
    "encospiáveis": "encospiar",
    "encosta": "encostar",
    "encostada": "encostar",
    "encostadas": "encostar",
    "encostadelas": "encostadela",
    "encostado": "encostar",
    "encostadora": "encostador",
    "encostadoras": "encostador",
    "encostadores": "encostador",
    "encostados": "encostar",
    "encostai": "encostar",
    "encostais": "encostar",
    "encostala": "encostalar",
    "encostalada": "encostalar",
    "encostaladas": "encostalar",
    "encostalado": "encostalar",
    "encostalados": "encostalar",
    "encostalai": "encostalar",
    "encostalais": "encostalar",
    "encostalam": "encostalar",
    "encostalamo": "encostalar",
    "encostalamos": "encostalar",
    "encostalando": "encostalar",
    "encostalara": "encostalar",
    "encostalaram": "encostalar",
    "encostalaras": "encostalar",
    "encostalarde": "encostalar",
    "encostalardes": "encostalar",
    "encostalare": "encostalar",
    "encostalarei": "encostalar",
    "encostalareis": "encostalar",
    "encostalarem": "encostalar",
    "encostalaremos": "encostalar",
    "encostalares": "encostalar",
    "encostalaria": "encostalar",
    "encostalariam": "encostalar",
    "encostalarias": "encostalar",
    "encostalarmo": "encostalar",
    "encostalarmos": "encostalar",
    "encostalará": "encostalar",
    "encostalarás": "encostalar",
    "encostalarão": "encostalar",
    "encostalaríamos": "encostalar",
    "encostalaríeis": "encostalar",
    "encostalas": "encostalar",
    "encostalasse": "encostalar",
    "encostalassem": "encostalar",
    "encostalasses": "encostalar",
    "encostalaste": "encostalar",
    "encostalastes": "encostalar",
    "encostalava": "encostalar",
    "encostalavam": "encostalar",
    "encostalavas": "encostalar",
    "encostale": "encostalar",
    "encostalei": "encostalar",
    "encostaleis": "encostalar",
    "encostalem": "encostalar",
    "encostalemo": "encostalar",
    "encostalemos": "encostalar",
    "encostales": "encostalar",
    "encostalo": "encostalar",
    "encostalou": "encostalar",
    "encostalá": "encostalar",
    "encostalámo": "encostalar",
    "encostalámos": "encostalar",
    "encostaláramo": "encostalar",
    "encostaláramos": "encostalar",
    "encostalárei": "encostalar",
    "encostaláreis": "encostalar",
    "encostalásseis": "encostalar",
    "encostalássemos": "encostalar",
    "encostalávamo": "encostalar",
    "encostalávamos": "encostalar",
    "encostalávei": "encostalar",
    "encostaláveis": "encostalar",
    "encostam": "encostar",
    "encostamentos": "encostamento",
    "encostamo": "encostar",
    "encostamos": "encostar",
    "encostando": "encostar",
    "encostara": "encostar",
    "encostaram": "encostar",
    "encostaras": "encostar",
    "encostarde": "encostar",
    "encostardes": "encostar",
    "encostare": "encostar",
    "encostarei": "encostar",
    "encostareis": "encostar",
    "encostarem": "encostar",
    "encostaremos": "encostar",
    "encostares": "encostar",
    "encostaria": "encostar",
    "encostariam": "encostar",
    "encostarias": "encostar",
    "encostarmo": "encostar",
    "encostarmos": "encostar",
    "encostará": "encostar",
    "encostarás": "encostar",
    "encostarão": "encostar",
    "encostaríamos": "encostar",
    "encostaríeis": "encostar",
    "encostas": "encostar",
    "encostasse": "encostar",
    "encostassem": "encostar",
    "encostasses": "encostar",
    "encostaste": "encostar",
    "encostastes": "encostar",
    "encostava": "encostar",
    "encostavam": "encostar",
    "encostavas": "encostar",
    "encoste": "encostar",
    "encostei": "encostar",
    "encosteis": "encostar",
    "encostem": "encostar",
    "encostemo": "encostar",
    "encostemos": "encostar",
    "encostes": "encoste",
    "encosto": "encostar",
    "encostona": "encostão",
    "encostonas": "encostão",
    "encostos": "encosto",
    "encostou": "encostar",
    "encostá": "encostar",
    "encostámo": "encostar",
    "encostámos": "encostar",
    "encostáramo": "encostar",
    "encostáramos": "encostar",
    "encostárei": "encostar",
    "encostáreis": "encostar",
    "encostásseis": "encostar",
    "encostássemos": "encostar",
    "encostávamo": "encostar",
    "encostávamos": "encostar",
    "encostávei": "encostar",
    "encostáveis": "encostar",
    "encostões": "encostão",
    "encoucha": "encouchar",
    "encouchada": "encouchar",
    "encouchadas": "encouchar",
    "encouchado": "encouchar",
    "encouchados": "encouchar",
    "encouchai": "encouchar",
    "encouchais": "encouchar",
    "encoucham": "encouchar",
    "encouchamentos": "encouchamento",
    "encouchamo": "encouchar",
    "encouchamos": "encouchar",
    "encouchando": "encouchar",
    "encouchara": "encouchar",
    "encoucharam": "encouchar",
    "encoucharas": "encouchar",
    "encoucharde": "encouchar",
    "encouchardes": "encouchar",
    "encouchare": "encouchar",
    "encoucharei": "encouchar",
    "encouchareis": "encouchar",
    "encoucharem": "encouchar",
    "encoucharemos": "encouchar",
    "encouchares": "encouchar",
    "encoucharia": "encouchar",
    "encouchariam": "encouchar",
    "encoucharias": "encouchar",
    "encoucharmo": "encouchar",
    "encoucharmos": "encouchar",
    "encouchará": "encouchar",
    "encoucharás": "encouchar",
    "encoucharão": "encouchar",
    "encoucharíamos": "encouchar",
    "encoucharíeis": "encouchar",
    "encouchas": "encouchar",
    "encouchasse": "encouchar",
    "encouchassem": "encouchar",
    "encouchasses": "encouchar",
    "encouchaste": "encouchar",
    "encouchastes": "encouchar",
    "encouchava": "encouchar",
    "encouchavam": "encouchar",
    "encouchavas": "encouchar",
    "encouche": "encouchar",
    "encouchei": "encouchar",
    "encoucheis": "encouchar",
    "encouchem": "encouchar",
    "encouchemo": "encouchar",
    "encouchemos": "encouchar",
    "encouches": "encouchar",
    "encoucho": "encouchar",
    "encouchou": "encouchar",
    "encouchá": "encouchar",
    "encouchámo": "encouchar",
    "encouchámos": "encouchar",
    "encoucháramo": "encouchar",
    "encoucháramos": "encouchar",
    "encouchárei": "encouchar",
    "encoucháreis": "encouchar",
    "encouchásseis": "encouchar",
    "encouchássemos": "encouchar",
    "encouchávamo": "encouchar",
    "encouchávamos": "encouchar",
    "encouchávei": "encouchar",
    "encoucháveis": "encouchar",
    "encoura": "encourar",
    "encourace": "encouraçar",
    "encouracei": "encouraçar",
    "encouraceis": "encouraçar",
    "encouracem": "encouraçar",
    "encouracemo": "encouraçar",
    "encouracemos": "encouraçar",
    "encouraces": "encouraçar",
    "encourada": "encourar",
    "encouradas": "encourar",
    "encourado": "encourar",
    "encourados": "encourar",
    "encourai": "encourar",
    "encourais": "encourar",
    "encouram": "encourar",
    "encouramo": "encourar",
    "encouramos": "encourar",
    "encourando": "encourar",
    "encourara": "encourar",
    "encouraram": "encourar",
    "encouraras": "encourar",
    "encourarde": "encourar",
    "encourardes": "encourar",
    "encourare": "encourar",
    "encourarei": "encourar",
    "encourareis": "encourar",
    "encourarem": "encourar",
    "encouraremos": "encourar",
    "encourares": "encourar",
    "encouraria": "encourar",
    "encourariam": "encourar",
    "encourarias": "encourar",
    "encourarmo": "encourar",
    "encourarmos": "encourar",
    "encourará": "encourar",
    "encourarás": "encourar",
    "encourarão": "encourar",
    "encouraríamos": "encourar",
    "encouraríeis": "encourar",
    "encouras": "encourar",
    "encourasse": "encourar",
    "encourassem": "encourar",
    "encourasses": "encourar",
    "encouraste": "encourar",
    "encourastes": "encourar",
    "encourava": "encourar",
    "encouravam": "encourar",
    "encouravas": "encourar",
    "encouraça": "encouraçar",
    "encouraçada": "encouraçar",
    "encouraçadas": "encouraçar",
    "encouraçado": "encouraçar",
    "encouraçados": "encouraçar",
    "encouraçai": "encouraçar",
    "encouraçais": "encouraçar",
    "encouraçam": "encouraçar",
    "encouraçamo": "encouraçar",
    "encouraçamos": "encouraçar",
    "encouraçando": "encouraçar",
    "encouraçara": "encouraçar",
    "encouraçaram": "encouraçar",
    "encouraçaras": "encouraçar",
    "encouraçarde": "encouraçar",
    "encouraçardes": "encouraçar",
    "encouraçare": "encouraçar",
    "encouraçarei": "encouraçar",
    "encouraçareis": "encouraçar",
    "encouraçarem": "encouraçar",
    "encouraçaremos": "encouraçar",
    "encouraçares": "encouraçar",
    "encouraçaria": "encouraçar",
    "encouraçariam": "encouraçar",
    "encouraçarias": "encouraçar",
    "encouraçarmo": "encouraçar",
    "encouraçarmos": "encouraçar",
    "encouraçará": "encouraçar",
    "encouraçarás": "encouraçar",
    "encouraçarão": "encouraçar",
    "encouraçaríamos": "encouraçar",
    "encouraçaríeis": "encouraçar",
    "encouraças": "encouraçar",
    "encouraçasse": "encouraçar",
    "encouraçassem": "encouraçar",
    "encouraçasses": "encouraçar",
    "encouraçaste": "encouraçar",
    "encouraçastes": "encouraçar",
    "encouraçava": "encouraçar",
    "encouraçavam": "encouraçar",
    "encouraçavas": "encouraçar",
    "encouraço": "encouraçar",
    "encouraçou": "encouraçar",
    "encouraçá": "encouraçar",
    "encouraçámo": "encouraçar",
    "encouraçámos": "encouraçar",
    "encouraçáramo": "encouraçar",
    "encouraçáramos": "encouraçar",
    "encouraçárei": "encouraçar",
    "encouraçáreis": "encouraçar",
    "encouraçásseis": "encouraçar",
    "encouraçássemos": "encouraçar",
    "encouraçávamo": "encouraçar",
    "encouraçávamos": "encouraçar",
    "encouraçávei": "encouraçar",
    "encouraçáveis": "encouraçar",
    "encoure": "encourar",
    "encourei": "encourar",
    "encoureis": "encourar",
    "encourem": "encourar",
    "encouremo": "encourar",
    "encouremos": "encourar",
    "encoures": "encourar",
    "encouro": "encourar",
    "encourou": "encourar",
    "encourá": "encourar",
    "encourámo": "encourar",
    "encourámos": "encourar",
    "encouráramo": "encourar",
    "encouráramos": "encourar",
    "encourárei": "encourar",
    "encouráreis": "encourar",
    "encourásseis": "encourar",
    "encourássemos": "encourar",
    "encourávamo": "encourar",
    "encourávamos": "encourar",
    "encourávei": "encourar",
    "encouráveis": "encourar",
    "encova": "encovar",
    "encovada": "encovar",
    "encovadas": "encovar",
    "encovado": "encovar",
    "encovados": "encovar",
    "encovai": "encovar",
    "encovais": "encovar",
    "encovam": "encovar",
    "encovamo": "encovar",
    "encovamos": "encovar",
    "encovando": "encovar",
    "encovara": "encovar",
    "encovaram": "encovar",
    "encovaras": "encovar",
    "encovarde": "encovar",
    "encovardes": "encovar",
    "encovare": "encovar",
    "encovarei": "encovar",
    "encovareis": "encovar",
    "encovarem": "encovar",
    "encovaremos": "encovar",
    "encovares": "encovar",
    "encovaria": "encovar",
    "encovariam": "encovar",
    "encovarias": "encovar",
    "encovarmo": "encovar",
    "encovarmos": "encovar",
    "encovará": "encovar",
    "encovarás": "encovar",
    "encovarão": "encovar",
    "encovaríamos": "encovar",
    "encovaríeis": "encovar",
    "encovas": "encovar",
    "encovasse": "encovar",
    "encovassem": "encovar",
    "encovasses": "encovar",
    "encovaste": "encovar",
    "encovastes": "encovar",
    "encovava": "encovar",
    "encovavam": "encovar",
    "encovavas": "encovar",
    "encove": "encovar",
    "encovei": "encovar",
    "encoveis": "encovar",
    "encovem": "encovar",
    "encovemo": "encovar",
    "encovemos": "encovar",
    "encoves": "encovar",
    "encovila": "encovilar",
    "encovilada": "encovilar",
    "encoviladas": "encovilar",
    "encovilado": "encovilar",
    "encovilados": "encovilar",
    "encovilai": "encovilar",
    "encovilais": "encovilar",
    "encovilam": "encovilar",
    "encovilamo": "encovilar",
    "encovilamos": "encovilar",
    "encovilando": "encovilar",
    "encovilara": "encovilar",
    "encovilaram": "encovilar",
    "encovilaras": "encovilar",
    "encovilarde": "encovilar",
    "encovilardes": "encovilar",
    "encovilare": "encovilar",
    "encovilarei": "encovilar",
    "encovilareis": "encovilar",
    "encovilarem": "encovilar",
    "encovilaremos": "encovilar",
    "encovilares": "encovilar",
    "encovilaria": "encovilar",
    "encovilariam": "encovilar",
    "encovilarias": "encovilar",
    "encovilarmo": "encovilar",
    "encovilarmos": "encovilar",
    "encovilará": "encovilar",
    "encovilarás": "encovilar",
    "encovilarão": "encovilar",
    "encovilaríamos": "encovilar",
    "encovilaríeis": "encovilar",
    "encovilas": "encovilar",
    "encovilasse": "encovilar",
    "encovilassem": "encovilar",
    "encovilasses": "encovilar",
    "encovilaste": "encovilar",
    "encovilastes": "encovilar",
    "encovilava": "encovilar",
    "encovilavam": "encovilar",
    "encovilavas": "encovilar",
    "encovile": "encovilar",
    "encovilei": "encovilar",
    "encovileis": "encovilar",
    "encovilem": "encovilar",
    "encovilemo": "encovilar",
    "encovilemos": "encovilar",
    "encoviles": "encovilar",
    "encovilo": "encovilar",
    "encovilou": "encovilar",
    "encovilá": "encovilar",
    "encovilámo": "encovilar",
    "encovilámos": "encovilar",
    "encoviláramo": "encovilar",
    "encoviláramos": "encovilar",
    "encovilárei": "encovilar",
    "encoviláreis": "encovilar",
    "encovilásseis": "encovilar",
    "encovilássemos": "encovilar",
    "encovilávamo": "encovilar",
    "encovilávamos": "encovilar",
    "encovilávei": "encovilar",
    "encoviláveis": "encovilar",
    "encovo": "encovar",
    "encovou": "encovar",
    "encová": "encovar",
    "encovámo": "encovar",
    "encovámos": "encovar",
    "encováramo": "encovar",
    "encováramos": "encovar",
    "encovárei": "encovar",
    "encováreis": "encovar",
    "encovásseis": "encovar",
    "encovássemos": "encovar",
    "encovávamo": "encovar",
    "encovávamos": "encovar",
    "encovávei": "encovar",
    "encováveis": "encovar",
    "encratismos": "encratismo",
    "encratitas": "encratita",
    "encratítica": "encratítico",
    "encratíticas": "encratítico",
    "encratíticos": "encratítico",
    "encrava": "encravar",
    "encravada": "encravar",
    "encravadas": "encravar",
    "encravado": "encravar",
    "encravados": "encravar",
    "encravaduras": "encravadura",
    "encravadíssima": "encravado",
    "encravadíssimas": "encravado",
    "encravadíssimo": "encravado",
    "encravadíssimos": "encravado",
    "encravai": "encravar",
    "encravais": "encravar",
    "encravam": "encravar",
    "encravamentos": "encravamento",
    "encravamo": "encravar",
    "encravamos": "encravar",
    "encravando": "encravar",
    "encravara": "encravar",
    "encravaram": "encravar",
    "encravaras": "encravar",
    "encravarde": "encravar",
    "encravardes": "encravar",
    "encravare": "encravar",
    "encravarei": "encravar",
    "encravareis": "encravar",
    "encravarem": "encravar",
    "encravaremos": "encravar",
    "encravares": "encravar",
    "encravaria": "encravar",
    "encravariam": "encravar",
    "encravarias": "encravar",
    "encravarmo": "encravar",
    "encravarmos": "encravar",
    "encravará": "encravar",
    "encravarás": "encravar",
    "encravarão": "encravar",
    "encravaríamos": "encravar",
    "encravaríeis": "encravar",
    "encravas": "encravar",
    "encravasse": "encravar",
    "encravassem": "encravar",
    "encravasses": "encravar",
    "encravaste": "encravar",
    "encravastes": "encravar",
    "encravava": "encravar",
    "encravavam": "encravar",
    "encravavas": "encravar",
    "encravações": "encravação",
    "encrave": "encravar",
    "encravei": "encravar",
    "encraveis": "encravar",
    "encravelha": "encravelhar",
    "encravelhada": "encravelhar",
    "encravelhadas": "encravelhar",
    "encravelhado": "encravelhar",
    "encravelhados": "encravelhar",
    "encravelhai": "encravelhar",
    "encravelhais": "encravelhar",
    "encravelham": "encravelhar",
    "encravelhamo": "encravelhar",
    "encravelhamos": "encravelhar",
    "encravelhando": "encravelhar",
    "encravelhara": "encravelhar",
    "encravelharam": "encravelhar",
    "encravelharas": "encravelhar",
    "encravelharde": "encravelhar",
    "encravelhardes": "encravelhar",
    "encravelhare": "encravelhar",
    "encravelharei": "encravelhar",
    "encravelhareis": "encravelhar",
    "encravelharem": "encravelhar",
    "encravelharemos": "encravelhar",
    "encravelhares": "encravelhar",
    "encravelharia": "encravelhar",
    "encravelhariam": "encravelhar",
    "encravelharias": "encravelhar",
    "encravelharmo": "encravelhar",
    "encravelharmos": "encravelhar",
    "encravelhará": "encravelhar",
    "encravelharás": "encravelhar",
    "encravelharão": "encravelhar",
    "encravelharíamos": "encravelhar",
    "encravelharíeis": "encravelhar",
    "encravelhas": "encravelhar",
    "encravelhasse": "encravelhar",
    "encravelhassem": "encravelhar",
    "encravelhasses": "encravelhar",
    "encravelhaste": "encravelhar",
    "encravelhastes": "encravelhar",
    "encravelhava": "encravelhar",
    "encravelhavam": "encravelhar",
    "encravelhavas": "encravelhar",
    "encravelhações": "encravelhação",
    "encravelhe": "encravelhar",
    "encravelhei": "encravelhar",
    "encravelheis": "encravelhar",
    "encravelhem": "encravelhar",
    "encravelhemo": "encravelhar",
    "encravelhemos": "encravelhar",
    "encravelhes": "encravelhar",
    "encravelho": "encravelhar",
    "encravelhou": "encravelhar",
    "encravelhá": "encravelhar",
    "encravelhámo": "encravelhar",
    "encravelhámos": "encravelhar",
    "encravelháramo": "encravelhar",
    "encravelháramos": "encravelhar",
    "encravelhárei": "encravelhar",
    "encravelháreis": "encravelhar",
    "encravelhásseis": "encravelhar",
    "encravelhássemos": "encravelhar",
    "encravelhávamo": "encravelhar",
    "encravelhávamos": "encravelhar",
    "encravelhávei": "encravelhar",
    "encravelháveis": "encravelhar",
    "encravem": "encravar",
    "encravemo": "encravar",
    "encravemos": "encravar",
    "encraves": "encrave",
    "encravilha": "encravilhar",
    "encravilhada": "encravilhar",
    "encravilhadas": "encravilhar",
    "encravilhado": "encravilhar",
    "encravilhados": "encravilhar",
    "encravilhai": "encravilhar",
    "encravilhais": "encravilhar",
    "encravilham": "encravilhar",
    "encravilhamo": "encravilhar",
    "encravilhamos": "encravilhar",
    "encravilhando": "encravilhar",
    "encravilhara": "encravilhar",
    "encravilharam": "encravilhar",
    "encravilharas": "encravilhar",
    "encravilharde": "encravilhar",
    "encravilhardes": "encravilhar",
    "encravilhare": "encravilhar",
    "encravilharei": "encravilhar",
    "encravilhareis": "encravilhar",
    "encravilharem": "encravilhar",
    "encravilharemos": "encravilhar",
    "encravilhares": "encravilhar",
    "encravilharia": "encravilhar",
    "encravilhariam": "encravilhar",
    "encravilharias": "encravilhar",
    "encravilharmo": "encravilhar",
    "encravilharmos": "encravilhar",
    "encravilhará": "encravilhar",
    "encravilharás": "encravilhar",
    "encravilharão": "encravilhar",
    "encravilharíamos": "encravilhar",
    "encravilharíeis": "encravilhar",
    "encravilhas": "encravilhar",
    "encravilhasse": "encravilhar",
    "encravilhassem": "encravilhar",
    "encravilhasses": "encravilhar",
    "encravilhaste": "encravilhar",
    "encravilhastes": "encravilhar",
    "encravilhava": "encravilhar",
    "encravilhavam": "encravilhar",
    "encravilhavas": "encravilhar",
    "encravilhe": "encravilhar",
    "encravilhei": "encravilhar",
    "encravilheis": "encravilhar",
    "encravilhem": "encravilhar",
    "encravilhemo": "encravilhar",
    "encravilhemos": "encravilhar",
    "encravilhes": "encravilhar",
    "encravilho": "encravilhar",
    "encravilhou": "encravilhar",
    "encravilhá": "encravilhar",
    "encravilhámo": "encravilhar",
    "encravilhámos": "encravilhar",
    "encravilháramo": "encravilhar",
    "encravilháramos": "encravilhar",
    "encravilhárei": "encravilhar",
    "encravilháreis": "encravilhar",
    "encravilhásseis": "encravilhar",
    "encravilhássemos": "encravilhar",
    "encravilhávamo": "encravilhar",
    "encravilhávamos": "encravilhar",
    "encravilhávei": "encravilhar",
    "encravilháveis": "encravilhar",
    "encravo": "encravar",
    "encravos": "encravo",
    "encravou": "encravar",
    "encravá": "encravar",
    "encravámo": "encravar",
    "encravámos": "encravar",
    "encraváramo": "encravar",
    "encraváramos": "encravar",
    "encravárei": "encravar",
    "encraváreis": "encravar",
    "encravásseis": "encravar",
    "encravássemos": "encravar",
    "encravávamo": "encravar",
    "encravávamos": "encravar",
    "encravávei": "encravar",
    "encraváveis": "encravar",
    "encrenca": "encrencar",
    "encrencada": "encrencar",
    "encrencadas": "encrencar",
    "encrencado": "encrencar",
    "encrencados": "encrencar",
    "encrencadíssima": "encrencado",
    "encrencadíssimas": "encrencado",
    "encrencadíssimo": "encrencado",
    "encrencadíssimos": "encrencado",
    "encrencai": "encrencar",
    "encrencais": "encrencar",
    "encrencam": "encrencar",
    "encrencamo": "encrencar",
    "encrencamos": "encrencar",
    "encrencando": "encrencar",
    "encrencara": "encrencar",
    "encrencaram": "encrencar",
    "encrencaras": "encrencar",
    "encrencarde": "encrencar",
    "encrencardes": "encrencar",
    "encrencare": "encrencar",
    "encrencarei": "encrencar",
    "encrencareis": "encrencar",
    "encrencarem": "encrencar",
    "encrencaremos": "encrencar",
    "encrencares": "encrencar",
    "encrencaria": "encrencar",
    "encrencariam": "encrencar",
    "encrencarias": "encrencar",
    "encrencarmo": "encrencar",
    "encrencarmos": "encrencar",
    "encrencará": "encrencar",
    "encrencarás": "encrencar",
    "encrencarão": "encrencar",
    "encrencaríamos": "encrencar",
    "encrencaríeis": "encrencar",
    "encrencas": "encrencar",
    "encrencasse": "encrencar",
    "encrencassem": "encrencar",
    "encrencasses": "encrencar",
    "encrencaste": "encrencar",
    "encrencastes": "encrencar",
    "encrencava": "encrencar",
    "encrencavam": "encrencar",
    "encrencavas": "encrencar",
    "encrenco": "encrencar",
    "encrencou": "encrencar",
    "encrencá": "encrencar",
    "encrencámo": "encrencar",
    "encrencámos": "encrencar",
    "encrencáramo": "encrencar",
    "encrencáramos": "encrencar",
    "encrencárei": "encrencar",
    "encrencáreis": "encrencar",
    "encrencásseis": "encrencar",
    "encrencássemos": "encrencar",
    "encrencávamo": "encrencar",
    "encrencávamos": "encrencar",
    "encrencávei": "encrencar",
    "encrencáveis": "encrencar",
    "encrenque": "encrencar",
    "encrenquei": "encrencar",
    "encrenqueis": "encrencar",
    "encrenquem": "encrencar",
    "encrenquemo": "encrencar",
    "encrenquemos": "encrencar",
    "encrenques": "encrenque",
    "encrespa": "encrespar",
    "encrespada": "encrespar",
    "encrespadas": "encrespar",
    "encrespado": "encrespar",
    "encrespadora": "encrespador",
    "encrespadoras": "encrespador",
    "encrespadores": "encrespador",
    "encrespados": "encrespar",
    "encrespaduras": "encrespadura",
    "encrespadíssima": "encrespado",
    "encrespadíssimas": "encrespado",
    "encrespadíssimo": "encrespado",
    "encrespadíssimos": "encrespado",
    "encrespai": "encrespar",
    "encrespais": "encrespar",
    "encrespam": "encrespar",
    "encrespamentos": "encrespamento",
    "encrespamo": "encrespar",
    "encrespamos": "encrespar",
    "encrespando": "encrespar",
    "encrespara": "encrespar",
    "encresparam": "encrespar",
    "encresparas": "encrespar",
    "encresparde": "encrespar",
    "encrespardes": "encrespar",
    "encrespare": "encrespar",
    "encresparei": "encrespar",
    "encrespareis": "encrespar",
    "encresparem": "encrespar",
    "encresparemos": "encrespar",
    "encrespares": "encrespar",
    "encresparia": "encrespar",
    "encrespariam": "encrespar",
    "encresparias": "encrespar",
    "encresparmo": "encrespar",
    "encresparmos": "encrespar",
    "encrespará": "encrespar",
    "encresparás": "encrespar",
    "encresparão": "encrespar",
    "encresparíamos": "encrespar",
    "encresparíeis": "encrespar",
    "encrespas": "encrespar",
    "encrespasse": "encrespar",
    "encrespassem": "encrespar",
    "encrespasses": "encrespar",
    "encrespaste": "encrespar",
    "encrespastes": "encrespar",
    "encrespava": "encrespar",
    "encrespavam": "encrespar",
    "encrespavas": "encrespar",
    "encrespe": "encrespar",
    "encrespei": "encrespar",
    "encrespeis": "encrespar",
    "encrespem": "encrespar",
    "encrespemo": "encrespar",
    "encrespemos": "encrespar",
    "encrespes": "encrespar",
    "encrespo": "encrespar",
    "encrespou": "encrespar",
    "encrespá": "encrespar",
    "encrespámo": "encrespar",
    "encrespámos": "encrespar",
    "encrespáramo": "encrespar",
    "encrespáramos": "encrespar",
    "encrespárei": "encrespar",
    "encrespáreis": "encrespar",
    "encrespásseis": "encrespar",
    "encrespássemos": "encrespar",
    "encrespávamo": "encrespar",
    "encrespávamos": "encrespar",
    "encrespávei": "encrespar",
    "encrespáveis": "encrespar",
    "encrista": "encristar",
    "encristada": "encristar",
    "encristadas": "encristar",
    "encristado": "encristar",
    "encristados": "encristar",
    "encristai": "encristar",
    "encristais": "encristar",
    "encristam": "encristar",
    "encristamentos": "encristamento",
    "encristamo": "encristar",
    "encristamos": "encristar",
    "encristando": "encristar",
    "encristara": "encristar",
    "encristaram": "encristar",
    "encristaras": "encristar",
    "encristarde": "encristar",
    "encristardes": "encristar",
    "encristare": "encristar",
    "encristarei": "encristar",
    "encristareis": "encristar",
    "encristarem": "encristar",
    "encristaremos": "encristar",
    "encristares": "encristar",
    "encristaria": "encristar",
    "encristariam": "encristar",
    "encristarias": "encristar",
    "encristarmo": "encristar",
    "encristarmos": "encristar",
    "encristará": "encristar",
    "encristarás": "encristar",
    "encristarão": "encristar",
    "encristaríamos": "encristar",
    "encristaríeis": "encristar",
    "encristas": "encristar",
    "encristasse": "encristar",
    "encristassem": "encristar",
    "encristasses": "encristar",
    "encristaste": "encristar",
    "encristastes": "encristar",
    "encristava": "encristar",
    "encristavam": "encristar",
    "encristavas": "encristar",
    "encriste": "encristar",
    "encristei": "encristar",
    "encristeis": "encristar",
    "encristem": "encristar",
    "encristemo": "encristar",
    "encristemos": "encristar",
    "encristes": "encristar",
    "encristo": "encristar",
    "encristou": "encristar",
    "encristá": "encristar",
    "encristámo": "encristar",
    "encristámos": "encristar",
    "encristáramo": "encristar",
    "encristáramos": "encristar",
    "encristárei": "encristar",
    "encristáreis": "encristar",
    "encristásseis": "encristar",
    "encristássemos": "encristar",
    "encristávamo": "encristar",
    "encristávamos": "encristar",
    "encristávei": "encristar",
    "encristáveis": "encristar",
    "encrosta": "encrostar",
    "encrostada": "encrostar",
    "encrostadas": "encrostar",
    "encrostado": "encrostar",
    "encrostados": "encrostar",
    "encrostai": "encrostar",
    "encrostais": "encrostar",
    "encrostam": "encrostar",
    "encrostamo": "encrostar",
    "encrostamos": "encrostar",
    "encrostando": "encrostar",
    "encrostara": "encrostar",
    "encrostaram": "encrostar",
    "encrostaras": "encrostar",
    "encrostarde": "encrostar",
    "encrostardes": "encrostar",
    "encrostare": "encrostar",
    "encrostarei": "encrostar",
    "encrostareis": "encrostar",
    "encrostarem": "encrostar",
    "encrostaremos": "encrostar",
    "encrostares": "encrostar",
    "encrostaria": "encrostar",
    "encrostariam": "encrostar",
    "encrostarias": "encrostar",
    "encrostarmo": "encrostar",
    "encrostarmos": "encrostar",
    "encrostará": "encrostar",
    "encrostarás": "encrostar",
    "encrostarão": "encrostar",
    "encrostaríamos": "encrostar",
    "encrostaríeis": "encrostar",
    "encrostas": "encrostar",
    "encrostasse": "encrostar",
    "encrostassem": "encrostar",
    "encrostasses": "encrostar",
    "encrostaste": "encrostar",
    "encrostastes": "encrostar",
    "encrostava": "encrostar",
    "encrostavam": "encrostar",
    "encrostavas": "encrostar",
    "encroste": "encrostar",
    "encrostei": "encrostar",
    "encrosteis": "encrostar",
    "encrostem": "encrostar",
    "encrostemo": "encrostar",
    "encrostemos": "encrostar",
    "encrostes": "encrostar",
    "encrosto": "encrostar",
    "encrostou": "encrostar",
    "encrostá": "encrostar",
    "encrostámo": "encrostar",
    "encrostámos": "encrostar",
    "encrostáramo": "encrostar",
    "encrostáramos": "encrostar",
    "encrostárei": "encrostar",
    "encrostáreis": "encrostar",
    "encrostásseis": "encrostar",
    "encrostássemos": "encrostar",
    "encrostávamo": "encrostar",
    "encrostávamos": "encrostar",
    "encrostávei": "encrostar",
    "encrostáveis": "encrostar",
    "encrua": "encruar",
    "encruada": "encruar",
    "encruadas": "encruar",
    "encruado": "encruar",
    "encruados": "encruar",
    "encruai": "encruar",
    "encruais": "encruar",
    "encruam": "encruar",
    "encruamentos": "encruamento",
    "encruamo": "encruar",
    "encruamos": "encruar",
    "encruando": "encruar",
    "encruara": "encruar",
    "encruaram": "encruar",
    "encruaras": "encruar",
    "encruardes": "encruar",
    "encruarei": "encruar",
    "encruareis": "encruar",
    "encruarem": "encruar",
    "encruaremos": "encruar",
    "encruares": "encruar",
    "encruaria": "encruar",
    "encruariam": "encruar",
    "encruarias": "encruar",
    "encruarmo": "encruar",
    "encruarmos": "encruar",
    "encruará": "encruar",
    "encruarás": "encruar",
    "encruarão": "encruar",
    "encruaríamos": "encruar",
    "encruaríeis": "encruar",
    "encruas": "encruar",
    "encruasse": "encruar",
    "encruassem": "encruar",
    "encruasses": "encruar",
    "encruaste": "encruar",
    "encruastes": "encruar",
    "encruava": "encruar",
    "encruavam": "encruar",
    "encruavas": "encruar",
    "encrudelece": "encrudelecer",
    "encrudelecei": "encrudelecer",
    "encrudeleceis": "encrudelecer",
    "encrudelecem": "encrudelecer",
    "encrudelecemo": "encrudelecer",
    "encrudelecemos": "encrudelecer",
    "encrudelecendo": "encrudelecer",
    "encrudelecera": "encrudelecer",
    "encrudeleceram": "encrudelecer",
    "encrudeleceras": "encrudelecer",
    "encrudelecerde": "encrudelecer",
    "encrudelecerdes": "encrudelecer",
    "encrudelecere": "encrudelecer",
    "encrudelecerei": "encrudelecer",
    "encrudelecereis": "encrudelecer",
    "encrudelecerem": "encrudelecer",
    "encrudeleceremos": "encrudelecer",
    "encrudeleceres": "encrudelecer",
    "encrudeleceria": "encrudelecer",
    "encrudeleceriam": "encrudelecer",
    "encrudelecerias": "encrudelecer",
    "encrudelecermo": "encrudelecer",
    "encrudelecermos": "encrudelecer",
    "encrudelecerá": "encrudelecer",
    "encrudelecerás": "encrudelecer",
    "encrudelecerão": "encrudelecer",
    "encrudeleceríamos": "encrudelecer",
    "encrudeleceríeis": "encrudelecer",
    "encrudeleces": "encrudelecer",
    "encrudelecesse": "encrudelecer",
    "encrudelecessem": "encrudelecer",
    "encrudelecesses": "encrudelecer",
    "encrudeleceste": "encrudelecer",
    "encrudelecestes": "encrudelecer",
    "encrudeleceu": "encrudelecer",
    "encrudeleci": "encrudelecer",
    "encrudelecia": "encrudelecer",
    "encrudeleciam": "encrudelecer",
    "encrudelecias": "encrudelecer",
    "encrudelecida": "encrudelecer",
    "encrudelecidas": "encrudelecer",
    "encrudelecido": "encrudelecer",
    "encrudelecidos": "encrudelecer",
    "encrudelecimentos": "encrudelecimento",
    "encrudelecê": "encrudelecer",
    "encrudelecêramo": "encrudelecer",
    "encrudelecêramos": "encrudelecer",
    "encrudelecêrei": "encrudelecer",
    "encrudelecêreis": "encrudelecer",
    "encrudelecêsseis": "encrudelecer",
    "encrudelecêssemos": "encrudelecer",
    "encrudelecíamo": "encrudelecer",
    "encrudelecíamos": "encrudelecer",
    "encrudelecíei": "encrudelecer",
    "encrudelecíeis": "encrudelecer",
    "encrudeleça": "encrudelecer",
    "encrudeleçais": "encrudelecer",
    "encrudeleçam": "encrudelecer",
    "encrudeleçamo": "encrudelecer",
    "encrudeleçamos": "encrudelecer",
    "encrudeleças": "encrudelecer",
    "encrudeleço": "encrudelecer",
    "encrudesce": "encrudescer",
    "encrudescei": "encrudescer",
    "encrudesceis": "encrudescer",
    "encrudescem": "encrudescer",
    "encrudescemo": "encrudescer",
    "encrudescemos": "encrudescer",
    "encrudescendo": "encrudescer",
    "encrudescera": "encrudescer",
    "encrudesceram": "encrudescer",
    "encrudesceras": "encrudescer",
    "encrudescerde": "encrudescer",
    "encrudescerdes": "encrudescer",
    "encrudescere": "encrudescer",
    "encrudescerei": "encrudescer",
    "encrudescereis": "encrudescer",
    "encrudescerem": "encrudescer",
    "encrudesceremos": "encrudescer",
    "encrudesceres": "encrudescer",
    "encrudesceria": "encrudescer",
    "encrudesceriam": "encrudescer",
    "encrudescerias": "encrudescer",
    "encrudescermo": "encrudescer",
    "encrudescermos": "encrudescer",
    "encrudescerá": "encrudescer",
    "encrudescerás": "encrudescer",
    "encrudescerão": "encrudescer",
    "encrudesceríamos": "encrudescer",
    "encrudesceríeis": "encrudescer",
    "encrudesces": "encrudescer",
    "encrudescesse": "encrudescer",
    "encrudescessem": "encrudescer",
    "encrudescesses": "encrudescer",
    "encrudesceste": "encrudescer",
    "encrudescestes": "encrudescer",
    "encrudesceu": "encrudescer",
    "encrudesci": "encrudescer",
    "encrudescia": "encrudescer",
    "encrudesciam": "encrudescer",
    "encrudescias": "encrudescer",
    "encrudescida": "encrudescer",
    "encrudescidas": "encrudescer",
    "encrudescido": "encrudescer",
    "encrudescidos": "encrudescer",
    "encrudescimentos": "encrudescimento",
    "encrudescê": "encrudescer",
    "encrudescêramo": "encrudescer",
    "encrudescêramos": "encrudescer",
    "encrudescêrei": "encrudescer",
    "encrudescêreis": "encrudescer",
    "encrudescêsseis": "encrudescer",
    "encrudescêssemos": "encrudescer",
    "encrudescíamo": "encrudescer",
    "encrudescíamos": "encrudescer",
    "encrudescíei": "encrudescer",
    "encrudescíeis": "encrudescer",
    "encrudesça": "encrudescer",
    "encrudesçais": "encrudescer",
    "encrudesçam": "encrudescer",
    "encrudesçamo": "encrudescer",
    "encrudesçamos": "encrudescer",
    "encrudesças": "encrudescer",
    "encrudesço": "encrudescer",
    "encrue": "encruar",
    "encruece": "encruecer",
    "encruecei": "encruecer",
    "encrueceis": "encruecer",
    "encruecem": "encruecer",
    "encruecemo": "encruecer",
    "encruecemos": "encruecer",
    "encruecendo": "encruecer",
    "encruecera": "encruecer",
    "encrueceram": "encruecer",
    "encrueceras": "encruecer",
    "encruecerdes": "encruecer",
    "encruecerei": "encruecer",
    "encruecereis": "encruecer",
    "encruecerem": "encruecer",
    "encrueceremos": "encruecer",
    "encrueceres": "encruecer",
    "encrueceria": "encruecer",
    "encrueceriam": "encruecer",
    "encruecerias": "encruecer",
    "encruecermo": "encruecer",
    "encruecermos": "encruecer",
    "encruecerá": "encruecer",
    "encruecerás": "encruecer",
    "encruecerão": "encruecer",
    "encrueceríamos": "encruecer",
    "encrueceríeis": "encruecer",
    "encrueces": "encruecer",
    "encruecesse": "encruecer",
    "encruecessem": "encruecer",
    "encruecesses": "encruecer",
    "encrueceste": "encruecer",
    "encruecestes": "encruecer",
    "encrueceu": "encruecer",
    "encrueci": "encruecer",
    "encruecia": "encruecer",
    "encrueciam": "encruecer",
    "encruecias": "encruecer",
    "encruecida": "encruecer",
    "encruecidas": "encruecer",
    "encruecido": "encruecer",
    "encruecidos": "encruecer",
    "encruecêramo": "encruecer",
    "encruecêramos": "encruecer",
    "encruecêreis": "encruecer",
    "encruecêsseis": "encruecer",
    "encruecêssemos": "encruecer",
    "encruecíamo": "encruecer",
    "encruecíamos": "encruecer",
    "encruecíeis": "encruecer",
    "encruei": "encruar",
    "encrueis": "encruar",
    "encruem": "encruar",
    "encruemo": "encruar",
    "encruemos": "encruar",
    "encruenta": "encruentar",
    "encruentada": "encruentar",
    "encruentadas": "encruentar",
    "encruentado": "encruentar",
    "encruentados": "encruentar",
    "encruentai": "encruentar",
    "encruentais": "encruentar",
    "encruentam": "encruentar",
    "encruentamentos": "encruentamento",
    "encruentamo": "encruentar",
    "encruentamos": "encruentar",
    "encruentando": "encruentar",
    "encruentara": "encruentar",
    "encruentaram": "encruentar",
    "encruentaras": "encruentar",
    "encruentarde": "encruentar",
    "encruentardes": "encruentar",
    "encruentare": "encruentar",
    "encruentarei": "encruentar",
    "encruentareis": "encruentar",
    "encruentarem": "encruentar",
    "encruentaremos": "encruentar",
    "encruentares": "encruentar",
    "encruentaria": "encruentar",
    "encruentariam": "encruentar",
    "encruentarias": "encruentar",
    "encruentarmo": "encruentar",
    "encruentarmos": "encruentar",
    "encruentará": "encruentar",
    "encruentarás": "encruentar",
    "encruentarão": "encruentar",
    "encruentaríamos": "encruentar",
    "encruentaríeis": "encruentar",
    "encruentas": "encruentar",
    "encruentasse": "encruentar",
    "encruentassem": "encruentar",
    "encruentasses": "encruentar",
    "encruentaste": "encruentar",
    "encruentastes": "encruentar",
    "encruentava": "encruentar",
    "encruentavam": "encruentar",
    "encruentavas": "encruentar",
    "encruente": "encruentar",
    "encruentei": "encruentar",
    "encruenteis": "encruentar",
    "encruentem": "encruentar",
    "encruentemo": "encruentar",
    "encruentemos": "encruentar",
    "encruentes": "encruentar",
    "encruento": "encruentar",
    "encruentou": "encruentar",
    "encruentá": "encruentar",
    "encruentámo": "encruentar",
    "encruentámos": "encruentar",
    "encruentáramo": "encruentar",
    "encruentáramos": "encruentar",
    "encruentárei": "encruentar",
    "encruentáreis": "encruentar",
    "encruentásseis": "encruentar",
    "encruentássemos": "encruentar",
    "encruentávamo": "encruentar",
    "encruentávamos": "encruentar",
    "encruentávei": "encruentar",
    "encruentáveis": "encruentar",
    "encrues": "encruar",
    "encrueça": "encruecer",
    "encrueçais": "encruecer",
    "encrueçam": "encruecer",
    "encrueçamo": "encruecer",
    "encrueçamos": "encruecer",
    "encrueças": "encruecer",
    "encrueço": "encruecer",
    "encruo": "encruar",
    "encruou": "encruar",
    "encruza": "encruzar",
    "encruzada": "encruzar",
    "encruzadas": "encruzar",
    "encruzado": "encruzar",
    "encruzados": "encruzar",
    "encruzai": "encruzar",
    "encruzais": "encruzar",
    "encruzam": "encruzar",
    "encruzamentos": "encruzamento",
    "encruzamo": "encruzar",
    "encruzamos": "encruzar",
    "encruzando": "encruzar",
    "encruzara": "encruzar",
    "encruzaram": "encruzar",
    "encruzaras": "encruzar",
    "encruzarde": "encruzar",
    "encruzardes": "encruzar",
    "encruzare": "encruzar",
    "encruzarei": "encruzar",
    "encruzareis": "encruzar",
    "encruzarem": "encruzar",
    "encruzaremos": "encruzar",
    "encruzares": "encruzar",
    "encruzaria": "encruzar",
    "encruzariam": "encruzar",
    "encruzarias": "encruzar",
    "encruzarmo": "encruzar",
    "encruzarmos": "encruzar",
    "encruzará": "encruzar",
    "encruzarás": "encruzar",
    "encruzarão": "encruzar",
    "encruzaríamos": "encruzar",
    "encruzaríeis": "encruzar",
    "encruzas": "encruzar",
    "encruzasse": "encruzar",
    "encruzassem": "encruzar",
    "encruzasses": "encruzar",
    "encruzaste": "encruzar",
    "encruzastes": "encruzar",
    "encruzava": "encruzar",
    "encruzavam": "encruzar",
    "encruzavas": "encruzar",
    "encruze": "encruzar",
    "encruzei": "encruzar",
    "encruzeis": "encruzar",
    "encruzem": "encruzar",
    "encruzemo": "encruzar",
    "encruzemos": "encruzar",
    "encruzes": "encruzar",
    "encruzilha": "encruzilhar",
    "encruzilhada": "encruzilhar",
    "encruzilhadas": "encruzilhar",
    "encruzilhado": "encruzilhar",
    "encruzilhados": "encruzilhar",
    "encruzilhai": "encruzilhar",
    "encruzilhais": "encruzilhar",
    "encruzilham": "encruzilhar",
    "encruzilhamo": "encruzilhar",
    "encruzilhamos": "encruzilhar",
    "encruzilhando": "encruzilhar",
    "encruzilhara": "encruzilhar",
    "encruzilharam": "encruzilhar",
    "encruzilharas": "encruzilhar",
    "encruzilharde": "encruzilhar",
    "encruzilhardes": "encruzilhar",
    "encruzilhare": "encruzilhar",
    "encruzilharei": "encruzilhar",
    "encruzilhareis": "encruzilhar",
    "encruzilharem": "encruzilhar",
    "encruzilharemos": "encruzilhar",
    "encruzilhares": "encruzilhar",
    "encruzilharia": "encruzilhar",
    "encruzilhariam": "encruzilhar",
    "encruzilharias": "encruzilhar",
    "encruzilharmo": "encruzilhar",
    "encruzilharmos": "encruzilhar",
    "encruzilhará": "encruzilhar",
    "encruzilharás": "encruzilhar",
    "encruzilharão": "encruzilhar",
    "encruzilharíamos": "encruzilhar",
    "encruzilharíeis": "encruzilhar",
    "encruzilhas": "encruzilhar",
    "encruzilhasse": "encruzilhar",
    "encruzilhassem": "encruzilhar",
    "encruzilhasses": "encruzilhar",
    "encruzilhaste": "encruzilhar",
    "encruzilhastes": "encruzilhar",
    "encruzilhava": "encruzilhar",
    "encruzilhavam": "encruzilhar",
    "encruzilhavas": "encruzilhar",
    "encruzilhe": "encruzilhar",
    "encruzilhei": "encruzilhar",
    "encruzilheis": "encruzilhar",
    "encruzilhem": "encruzilhar",
    "encruzilhemo": "encruzilhar",
    "encruzilhemos": "encruzilhar",
    "encruzilhes": "encruzilhar",
    "encruzilho": "encruzilhar",
    "encruzilhou": "encruzilhar",
    "encruzilhá": "encruzilhar",
    "encruzilhámo": "encruzilhar",
    "encruzilhámos": "encruzilhar",
    "encruzilháramo": "encruzilhar",
    "encruzilháramos": "encruzilhar",
    "encruzilhárei": "encruzilhar",
    "encruzilháreis": "encruzilhar",
    "encruzilhásseis": "encruzilhar",
    "encruzilhássemos": "encruzilhar",
    "encruzilhávamo": "encruzilhar",
    "encruzilhávamos": "encruzilhar",
    "encruzilhávei": "encruzilhar",
    "encruzilháveis": "encruzilhar",
    "encruzo": "encruzar",
    "encruzou": "encruzar",
    "encruzá": "encruzar",
    "encruzámo": "encruzar",
    "encruzámos": "encruzar",
    "encruzáramo": "encruzar",
    "encruzáramos": "encruzar",
    "encruzárei": "encruzar",
    "encruzáreis": "encruzar",
    "encruzásseis": "encruzar",
    "encruzássemos": "encruzar",
    "encruzávamo": "encruzar",
    "encruzávamos": "encruzar",
    "encruzávei": "encruzar",
    "encruzáveis": "encruzar",
    "encruámo": "encruar",
    "encruámos": "encruar",
    "encruáramo": "encruar",
    "encruáramos": "encruar",
    "encruáreis": "encruar",
    "encruásseis": "encruar",
    "encruássemos": "encruar",
    "encruávamo": "encruar",
    "encruávamos": "encruar",
    "encruáveis": "encruar",
    "encuba": "encubar",
    "encubada": "encubar",
    "encubadas": "encubar",
    "encubado": "encubar",
    "encubados": "encubar",
    "encubai": "encubar",
    "encubais": "encubar",
    "encubam": "encubar",
    "encubamo": "encubar",
    "encubamos": "encubar",
    "encubando": "encubar",
    "encubara": "encubar",
    "encubaram": "encubar",
    "encubaras": "encubar",
    "encubarde": "encubar",
    "encubardes": "encubar",
    "encubare": "encubar",
    "encubarei": "encubar",
    "encubareis": "encubar",
    "encubarem": "encubar",
    "encubaremos": "encubar",
    "encubares": "encubar",
    "encubaria": "encubar",
    "encubariam": "encubar",
    "encubarias": "encubar",
    "encubarmo": "encubar",
    "encubarmos": "encubar",
    "encubará": "encubar",
    "encubarás": "encubar",
    "encubarão": "encubar",
    "encubaríamos": "encubar",
    "encubaríeis": "encubar",
    "encubas": "encubar",
    "encubasse": "encubar",
    "encubassem": "encubar",
    "encubasses": "encubar",
    "encubaste": "encubar",
    "encubastes": "encubar",
    "encubava": "encubar",
    "encubavam": "encubar",
    "encubavas": "encubar",
    "encubações": "encubação",
    "encube": "encubar",
    "encubei": "encubar",
    "encubeis": "encubar",
    "encubem": "encubar",
    "encubemo": "encubar",
    "encubemos": "encubar",
    "encubes": "encubar",
    "encubo": "encubar",
    "encubou": "encubar",
    "encubra": "encobrir",
    "encubrais": "encobrir",
    "encubram": "encobrir",
    "encubramo": "encobrir",
    "encubramos": "encobrir",
    "encubras": "encobrir",
    "encubro": "encobrir",
    "encubá": "encubar",
    "encubámo": "encubar",
    "encubámos": "encubar",
    "encubáramo": "encubar",
    "encubáramos": "encubar",
    "encubárei": "encubar",
    "encubáreis": "encubar",
    "encubásseis": "encubar",
    "encubássemos": "encubar",
    "encubávamo": "encubar",
    "encubávamos": "encubar",
    "encubávei": "encubar",
    "encubáveis": "encubar",
    "encueira": "encueirar",
    "encueirada": "encueirar",
    "encueiradas": "encueirar",
    "encueirado": "encueirar",
    "encueirados": "encueirar",
    "encueirai": "encueirar",
    "encueirais": "encueirar",
    "encueiram": "encueirar",
    "encueiramo": "encueirar",
    "encueiramos": "encueirar",
    "encueirando": "encueirar",
    "encueirara": "encueirar",
    "encueiraram": "encueirar",
    "encueiraras": "encueirar",
    "encueirarde": "encueirar",
    "encueirardes": "encueirar",
    "encueirare": "encueirar",
    "encueirarei": "encueirar",
    "encueirareis": "encueirar",
    "encueirarem": "encueirar",
    "encueiraremos": "encueirar",
    "encueirares": "encueirar",
    "encueiraria": "encueirar",
    "encueirariam": "encueirar",
    "encueirarias": "encueirar",
    "encueirarmo": "encueirar",
    "encueirarmos": "encueirar",
    "encueirará": "encueirar",
    "encueirarás": "encueirar",
    "encueirarão": "encueirar",
    "encueiraríamos": "encueirar",
    "encueiraríeis": "encueirar",
    "encueiras": "encueirar",
    "encueirasse": "encueirar",
    "encueirassem": "encueirar",
    "encueirasses": "encueirar",
    "encueiraste": "encueirar",
    "encueirastes": "encueirar",
    "encueirava": "encueirar",
    "encueiravam": "encueirar",
    "encueiravas": "encueirar",
    "encueire": "encueirar",
    "encueirei": "encueirar",
    "encueireis": "encueirar",
    "encueirem": "encueirar",
    "encueiremo": "encueirar",
    "encueiremos": "encueirar",
    "encueires": "encueirar",
    "encueiro": "encueirar",
    "encueirou": "encueirar",
    "encueirá": "encueirar",
    "encueirámo": "encueirar",
    "encueirámos": "encueirar",
    "encueiráramo": "encueirar",
    "encueiráramos": "encueirar",
    "encueirárei": "encueirar",
    "encueiráreis": "encueirar",
    "encueirásseis": "encueirar",
    "encueirássemos": "encueirar",
    "encueirávamo": "encueirar",
    "encueirávamos": "encueirar",
    "encueirávei": "encueirar",
    "encueiráveis": "encueirar",
    "encumeada": "encumear",
    "encumeadas": "encumear",
    "encumeado": "encumear",
    "encumeados": "encumear",
    "encumeai": "encumear",
    "encumeais": "encumear",
    "encumeamo": "encumear",
    "encumeamos": "encumear",
    "encumeando": "encumear",
    "encumeara": "encumear",
    "encumearam": "encumear",
    "encumearas": "encumear",
    "encumearde": "encumear",
    "encumeardes": "encumear",
    "encumeare": "encumear",
    "encumearei": "encumear",
    "encumeareis": "encumear",
    "encumearem": "encumear",
    "encumearemos": "encumear",
    "encumeares": "encumear",
    "encumearia": "encumear",
    "encumeariam": "encumear",
    "encumearias": "encumear",
    "encumearmo": "encumear",
    "encumearmos": "encumear",
    "encumeará": "encumear",
    "encumearás": "encumear",
    "encumearão": "encumear",
    "encumearíamos": "encumear",
    "encumearíeis": "encumear",
    "encumeasse": "encumear",
    "encumeassem": "encumear",
    "encumeasses": "encumear",
    "encumeaste": "encumear",
    "encumeastes": "encumear",
    "encumeava": "encumear",
    "encumeavam": "encumear",
    "encumeavas": "encumear",
    "encumeei": "encumear",
    "encumeeis": "encumear",
    "encumeemo": "encumear",
    "encumeemos": "encumear",
    "encumeia": "encumear",
    "encumeiam": "encumear",
    "encumeias": "encumear",
    "encumeie": "encumear",
    "encumeiem": "encumear",
    "encumeies": "encumear",
    "encumeio": "encumear",
    "encumeou": "encumear",
    "encumeá": "encumear",
    "encumeámo": "encumear",
    "encumeámos": "encumear",
    "encumeáramo": "encumear",
    "encumeáramos": "encumear",
    "encumeárei": "encumear",
    "encumeáreis": "encumear",
    "encumeásseis": "encumear",
    "encumeássemos": "encumear",
    "encumeávamo": "encumear",
    "encumeávamos": "encumear",
    "encumeávei": "encumear",
    "encumeáveis": "encumear",
    "encurrala": "encurralar",
    "encurralada": "encurralar",
    "encurraladas": "encurralar",
    "encurralado": "encurralar",
    "encurralados": "encurralar",
    "encurraladíssima": "encurralado",
    "encurraladíssimas": "encurralado",
    "encurraladíssimo": "encurralado",
    "encurraladíssimos": "encurralado",
    "encurralai": "encurralar",
    "encurralais": "encurralar",
    "encurralam": "encurralar",
    "encurralamentos": "encurralamento",
    "encurralamo": "encurralar",
    "encurralamos": "encurralar",
    "encurralando": "encurralar",
    "encurralara": "encurralar",
    "encurralaram": "encurralar",
    "encurralaras": "encurralar",
    "encurralarde": "encurralar",
    "encurralardes": "encurralar",
    "encurralare": "encurralar",
    "encurralarei": "encurralar",
    "encurralareis": "encurralar",
    "encurralarem": "encurralar",
    "encurralaremos": "encurralar",
    "encurralares": "encurralar",
    "encurralaria": "encurralar",
    "encurralariam": "encurralar",
    "encurralarias": "encurralar",
    "encurralarmo": "encurralar",
    "encurralarmos": "encurralar",
    "encurralará": "encurralar",
    "encurralarás": "encurralar",
    "encurralarão": "encurralar",
    "encurralaríamos": "encurralar",
    "encurralaríeis": "encurralar",
    "encurralas": "encurralar",
    "encurralasse": "encurralar",
    "encurralassem": "encurralar",
    "encurralasses": "encurralar",
    "encurralaste": "encurralar",
    "encurralastes": "encurralar",
    "encurralava": "encurralar",
    "encurralavam": "encurralar",
    "encurralavas": "encurralar",
    "encurrale": "encurralar",
    "encurralei": "encurralar",
    "encurraleis": "encurralar",
    "encurralem": "encurralar",
    "encurralemo": "encurralar",
    "encurralemos": "encurralar",
    "encurrales": "encurralar",
    "encurralo": "encurralar",
    "encurralou": "encurralar",
    "encurralá": "encurralar",
    "encurralámo": "encurralar",
    "encurralámos": "encurralar",
    "encurraláramo": "encurralar",
    "encurraláramos": "encurralar",
    "encurralárei": "encurralar",
    "encurraláreis": "encurralar",
    "encurralásseis": "encurralar",
    "encurralássemos": "encurralar",
    "encurralávamo": "encurralar",
    "encurralávamos": "encurralar",
    "encurralávei": "encurralar",
    "encurraláveis": "encurralável",
    "encurta": "encurtar",
    "encurtada": "encurtar",
    "encurtadas": "encurtar",
    "encurtado": "encurtar",
    "encurtadora": "encurtador",
    "encurtadoras": "encurtador",
    "encurtadores": "encurtador",
    "encurtados": "encurtar",
    "encurtai": "encurtar",
    "encurtais": "encurtar",
    "encurtam": "encurtar",
    "encurtamentos": "encurtamento",
    "encurtamo": "encurtar",
    "encurtamos": "encurtar",
    "encurtando": "encurtar",
    "encurtara": "encurtar",
    "encurtaram": "encurtar",
    "encurtaras": "encurtar",
    "encurtarde": "encurtar",
    "encurtardes": "encurtar",
    "encurtare": "encurtar",
    "encurtarei": "encurtar",
    "encurtareis": "encurtar",
    "encurtarem": "encurtar",
    "encurtaremos": "encurtar",
    "encurtares": "encurtar",
    "encurtaria": "encurtar",
    "encurtariam": "encurtar",
    "encurtarias": "encurtar",
    "encurtarmo": "encurtar",
    "encurtarmos": "encurtar",
    "encurtará": "encurtar",
    "encurtarás": "encurtar",
    "encurtarão": "encurtar",
    "encurtaríamos": "encurtar",
    "encurtaríeis": "encurtar",
    "encurtas": "encurtar",
    "encurtasse": "encurtar",
    "encurtassem": "encurtar",
    "encurtasses": "encurtar",
    "encurtaste": "encurtar",
    "encurtastes": "encurtar",
    "encurtava": "encurtar",
    "encurtavam": "encurtar",
    "encurtavas": "encurtar",
    "encurte": "encurtar",
    "encurtei": "encurtar",
    "encurteis": "encurtar",
    "encurtem": "encurtar",
    "encurtemo": "encurtar",
    "encurtemos": "encurtar",
    "encurtes": "encurtar",
    "encurto": "encurtar",
    "encurtou": "encurtar",
    "encurtá": "encurtar",
    "encurtámo": "encurtar",
    "encurtámos": "encurtar",
    "encurtáramo": "encurtar",
    "encurtáramos": "encurtar",
    "encurtárei": "encurtar",
    "encurtáreis": "encurtar",
    "encurtásseis": "encurtar",
    "encurtássemos": "encurtar",
    "encurtávamo": "encurtar",
    "encurtávamos": "encurtar",
    "encurtávei": "encurtar",
    "encurtáveis": "encurtável",
    "encurva": "encurvar",
    "encurvada": "encurvar",
    "encurvadas": "encurvar",
    "encurvado": "encurvar",
    "encurvados": "encurvar",
    "encurvaduras": "encurvadura",
    "encurvai": "encurvar",
    "encurvais": "encurvar",
    "encurvam": "encurvar",
    "encurvamentos": "encurvamento",
    "encurvamo": "encurvar",
    "encurvamos": "encurvar",
    "encurvando": "encurvar",
    "encurvara": "encurvar",
    "encurvaram": "encurvar",
    "encurvaras": "encurvar",
    "encurvarde": "encurvar",
    "encurvardes": "encurvar",
    "encurvare": "encurvar",
    "encurvarei": "encurvar",
    "encurvareis": "encurvar",
    "encurvarem": "encurvar",
    "encurvaremos": "encurvar",
    "encurvares": "encurvar",
    "encurvaria": "encurvar",
    "encurvariam": "encurvar",
    "encurvarias": "encurvar",
    "encurvarmo": "encurvar",
    "encurvarmos": "encurvar",
    "encurvará": "encurvar",
    "encurvarás": "encurvar",
    "encurvarão": "encurvar",
    "encurvaríamos": "encurvar",
    "encurvaríeis": "encurvar",
    "encurvas": "encurvar",
    "encurvasse": "encurvar",
    "encurvassem": "encurvar",
    "encurvasses": "encurvar",
    "encurvaste": "encurvar",
    "encurvastes": "encurvar",
    "encurvava": "encurvar",
    "encurvavam": "encurvar",
    "encurvavas": "encurvar",
    "encurve": "encurvar",
    "encurvei": "encurvar",
    "encurveis": "encurvar",
    "encurvem": "encurvar",
    "encurvemo": "encurvar",
    "encurvemos": "encurvar",
    "encurves": "encurvar",
    "encurvo": "encurvar",
    "encurvou": "encurvar",
    "encurvá": "encurvar",
    "encurvámo": "encurvar",
    "encurvámos": "encurvar",
    "encurváramo": "encurvar",
    "encurváramos": "encurvar",
    "encurvárei": "encurvar",
    "encurváreis": "encurvar",
    "encurvásseis": "encurvar",
    "encurvássemos": "encurvar",
    "encurvávamo": "encurvar",
    "encurvávamos": "encurvar",
    "encurvávei": "encurvar",
    "encurváveis": "encurvar",
    "encáusticas": "encáustica",
    "encéfalos": "encéfalo",
    "encíclica": "encíclico",
    "encíclicas": "encíclico",
    "encíclicos": "encíclico",
    "encómios": "encómio",
    "encórdios": "encórdio",
    "endanebas": "endaneba",
    "endarterites": "endarterite",
    "endartérias": "endartéria",
    "endartérios": "endartério",
    "endecha": "endechar",
    "endechada": "endechar",
    "endechadas": "endechar",
    "endechado": "endechar",
    "endechadora": "endechador",
    "endechadoras": "endechador",
    "endechadores": "endechador",
    "endechados": "endechar",
    "endechai": "endechar",
    "endechais": "endechar",
    "endecham": "endechar",
    "endechamo": "endechar",
    "endechamos": "endechar",
    "endechando": "endechar",
    "endechara": "endechar",
    "endecharam": "endechar",
    "endecharas": "endechar",
    "endechardes": "endechar",
    "endecharei": "endechar",
    "endechareis": "endechar",
    "endecharem": "endechar",
    "endecharemos": "endechar",
    "endechares": "endechar",
    "endecharia": "endechar",
    "endechariam": "endechar",
    "endecharias": "endechar",
    "endecharmo": "endechar",
    "endecharmos": "endechar",
    "endechará": "endechar",
    "endecharás": "endechar",
    "endecharão": "endechar",
    "endecharíamos": "endechar",
    "endecharíeis": "endechar",
    "endechas": "endechar",
    "endechasse": "endechar",
    "endechassem": "endechar",
    "endechasses": "endechar",
    "endechaste": "endechar",
    "endechastes": "endechar",
    "endechava": "endechar",
    "endechavam": "endechar",
    "endechavas": "endechar",
    "endeche": "endechar",
    "endechei": "endechar",
    "endecheis": "endechar",
    "endechem": "endechar",
    "endechemo": "endechar",
    "endechemos": "endechar",
    "endeches": "endechar",
    "endecho": "endechar",
    "endechou": "endechar",
    "endechámo": "endechar",
    "endechámos": "endechar",
    "endecháramo": "endechar",
    "endecháramos": "endechar",
    "endecháreis": "endechar",
    "endechásseis": "endechar",
    "endechássemos": "endechar",
    "endechávamo": "endechar",
    "endechávamos": "endechar",
    "endecháveis": "endechar",
    "endefluxa": "endefluxar",
    "endefluxada": "endefluxar",
    "endefluxadas": "endefluxar",
    "endefluxado": "endefluxar",
    "endefluxados": "endefluxar",
    "endefluxai": "endefluxar",
    "endefluxais": "endefluxar",
    "endefluxam": "endefluxar",
    "endefluxamo": "endefluxar",
    "endefluxamos": "endefluxar",
    "endefluxando": "endefluxar",
    "endefluxara": "endefluxar",
    "endefluxaram": "endefluxar",
    "endefluxaras": "endefluxar",
    "endefluxarde": "endefluxar",
    "endefluxardes": "endefluxar",
    "endefluxare": "endefluxar",
    "endefluxarei": "endefluxar",
    "endefluxareis": "endefluxar",
    "endefluxarem": "endefluxar",
    "endefluxaremos": "endefluxar",
    "endefluxares": "endefluxar",
    "endefluxaria": "endefluxar",
    "endefluxariam": "endefluxar",
    "endefluxarias": "endefluxar",
    "endefluxarmo": "endefluxar",
    "endefluxarmos": "endefluxar",
    "endefluxará": "endefluxar",
    "endefluxarás": "endefluxar",
    "endefluxarão": "endefluxar",
    "endefluxaríamos": "endefluxar",
    "endefluxaríeis": "endefluxar",
    "endefluxas": "endefluxar",
    "endefluxasse": "endefluxar",
    "endefluxassem": "endefluxar",
    "endefluxasses": "endefluxar",
    "endefluxaste": "endefluxar",
    "endefluxastes": "endefluxar",
    "endefluxava": "endefluxar",
    "endefluxavam": "endefluxar",
    "endefluxavas": "endefluxar",
    "endefluxe": "endefluxar",
    "endefluxei": "endefluxar",
    "endefluxeis": "endefluxar",
    "endefluxem": "endefluxar",
    "endefluxemo": "endefluxar",
    "endefluxemos": "endefluxar",
    "endefluxes": "endefluxar",
    "endefluxo": "endefluxar",
    "endefluxou": "endefluxar",
    "endefluxá": "endefluxar",
    "endefluxámo": "endefluxar",
    "endefluxámos": "endefluxar",
    "endefluxáramo": "endefluxar",
    "endefluxáramos": "endefluxar",
    "endefluxárei": "endefluxar",
    "endefluxáreis": "endefluxar",
    "endefluxásseis": "endefluxar",
    "endefluxássemos": "endefluxar",
    "endefluxávamo": "endefluxar",
    "endefluxávamos": "endefluxar",
    "endefluxávei": "endefluxar",
    "endefluxáveis": "endefluxar",
    "endemias": "endemia",
    "endemicidades": "endemicidade",
    "endemiologias": "endemiologia",
    "endemiológica": "endemiológico",
    "endemiológicas": "endemiológico",
    "endemiológicos": "endemiológico",
    "endemismos": "endemismo",
    "endemiza": "endemizar",
    "endemizada": "endemizar",
    "endemizadas": "endemizar",
    "endemizado": "endemizar",
    "endemizados": "endemizar",
    "endemizai": "endemizar",
    "endemizais": "endemizar",
    "endemizam": "endemizar",
    "endemizamo": "endemizar",
    "endemizamos": "endemizar",
    "endemizando": "endemizar",
    "endemizara": "endemizar",
    "endemizaram": "endemizar",
    "endemizaras": "endemizar",
    "endemizarde": "endemizar",
    "endemizardes": "endemizar",
    "endemizare": "endemizar",
    "endemizarei": "endemizar",
    "endemizareis": "endemizar",
    "endemizarem": "endemizar",
    "endemizaremos": "endemizar",
    "endemizares": "endemizar",
    "endemizaria": "endemizar",
    "endemizariam": "endemizar",
    "endemizarias": "endemizar",
    "endemizarmo": "endemizar",
    "endemizarmos": "endemizar",
    "endemizará": "endemizar",
    "endemizarás": "endemizar",
    "endemizarão": "endemizar",
    "endemizaríamos": "endemizar",
    "endemizaríeis": "endemizar",
    "endemizas": "endemizar",
    "endemizasse": "endemizar",
    "endemizassem": "endemizar",
    "endemizasses": "endemizar",
    "endemizaste": "endemizar",
    "endemizastes": "endemizar",
    "endemizava": "endemizar",
    "endemizavam": "endemizar",
    "endemizavas": "endemizar",
    "endemize": "endemizar",
    "endemizei": "endemizar",
    "endemizeis": "endemizar",
    "endemizem": "endemizar",
    "endemizemo": "endemizar",
    "endemizemos": "endemizar",
    "endemizes": "endemizar",
    "endemizo": "endemizar",
    "endemizou": "endemizar",
    "endemizá": "endemizar",
    "endemizámo": "endemizar",
    "endemizámos": "endemizar",
    "endemizáramo": "endemizar",
    "endemizáramos": "endemizar",
    "endemizárei": "endemizar",
    "endemizáreis": "endemizar",
    "endemizásseis": "endemizar",
    "endemizássemos": "endemizar",
    "endemizávamo": "endemizar",
    "endemizávamos": "endemizar",
    "endemizávei": "endemizar",
    "endemizáveis": "endemizar",
    "endemoninha": "endemoninhar",
    "endemoninhada": "endemoninhar",
    "endemoninhadas": "endemoninhar",
    "endemoninhado": "endemoninhar",
    "endemoninhados": "endemoninhar",
    "endemoninhai": "endemoninhar",
    "endemoninhais": "endemoninhar",
    "endemoninham": "endemoninhar",
    "endemoninhamo": "endemoninhar",
    "endemoninhamos": "endemoninhar",
    "endemoninhando": "endemoninhar",
    "endemoninhara": "endemoninhar",
    "endemoninharam": "endemoninhar",
    "endemoninharas": "endemoninhar",
    "endemoninharde": "endemoninhar",
    "endemoninhardes": "endemoninhar",
    "endemoninhare": "endemoninhar",
    "endemoninharei": "endemoninhar",
    "endemoninhareis": "endemoninhar",
    "endemoninharem": "endemoninhar",
    "endemoninharemos": "endemoninhar",
    "endemoninhares": "endemoninhar",
    "endemoninharia": "endemoninhar",
    "endemoninhariam": "endemoninhar",
    "endemoninharias": "endemoninhar",
    "endemoninharmo": "endemoninhar",
    "endemoninharmos": "endemoninhar",
    "endemoninhará": "endemoninhar",
    "endemoninharás": "endemoninhar",
    "endemoninharão": "endemoninhar",
    "endemoninharíamos": "endemoninhar",
    "endemoninharíeis": "endemoninhar",
    "endemoninhas": "endemoninhar",
    "endemoninhasse": "endemoninhar",
    "endemoninhassem": "endemoninhar",
    "endemoninhasses": "endemoninhar",
    "endemoninhaste": "endemoninhar",
    "endemoninhastes": "endemoninhar",
    "endemoninhava": "endemoninhar",
    "endemoninhavam": "endemoninhar",
    "endemoninhavas": "endemoninhar",
    "endemoninhe": "endemoninhar",
    "endemoninhei": "endemoninhar",
    "endemoninheis": "endemoninhar",
    "endemoninhem": "endemoninhar",
    "endemoninhemo": "endemoninhar",
    "endemoninhemos": "endemoninhar",
    "endemoninhes": "endemoninhar",
    "endemoninho": "endemoninhar",
    "endemoninhou": "endemoninhar",
    "endemoninhá": "endemoninhar",
    "endemoninhámo": "endemoninhar",
    "endemoninhámos": "endemoninhar",
    "endemoninháramo": "endemoninhar",
    "endemoninháramos": "endemoninhar",
    "endemoninhárei": "endemoninhar",
    "endemoninháreis": "endemoninhar",
    "endemoninhásseis": "endemoninhar",
    "endemoninhássemos": "endemoninhar",
    "endemoninhávamo": "endemoninhar",
    "endemoninhávamos": "endemoninhar",
    "endemoninhávei": "endemoninhar",
    "endemoninháveis": "endemoninhar",
    "endenta": "endentar",
    "endentada": "endentar",
    "endentadas": "endentar",
    "endentado": "endentar",
    "endentados": "endentar",
    "endentai": "endentar",
    "endentais": "endentar",
    "endentam": "endentar",
    "endentamo": "endentar",
    "endentamos": "endentar",
    "endentando": "endentar",
    "endentara": "endentar",
    "endentaram": "endentar",
    "endentaras": "endentar",
    "endentarde": "endentar",
    "endentardes": "endentar",
    "endentare": "endentar",
    "endentarei": "endentar",
    "endentareis": "endentar",
    "endentarem": "endentar",
    "endentaremos": "endentar",
    "endentares": "endentar",
    "endentaria": "endentar",
    "endentariam": "endentar",
    "endentarias": "endentar",
    "endentarmo": "endentar",
    "endentarmos": "endentar",
    "endentará": "endentar",
    "endentarás": "endentar",
    "endentarão": "endentar",
    "endentaríamos": "endentar",
    "endentaríeis": "endentar",
    "endentas": "endentar",
    "endentasse": "endentar",
    "endentassem": "endentar",
    "endentasses": "endentar",
    "endentaste": "endentar",
    "endentastes": "endentar",
    "endentava": "endentar",
    "endentavam": "endentar",
    "endentavas": "endentar",
    "endentações": "endentação",
    "endente": "endentar",
    "endentece": "endentecer",
    "endentecei": "endentecer",
    "endenteceis": "endentecer",
    "endentecem": "endentecer",
    "endentecemo": "endentecer",
    "endentecemos": "endentecer",
    "endentecendo": "endentecer",
    "endentecera": "endentecer",
    "endenteceram": "endentecer",
    "endenteceras": "endentecer",
    "endentecerdes": "endentecer",
    "endentecerei": "endentecer",
    "endentecereis": "endentecer",
    "endentecerem": "endentecer",
    "endenteceremos": "endentecer",
    "endenteceres": "endentecer",
    "endenteceria": "endentecer",
    "endenteceriam": "endentecer",
    "endentecerias": "endentecer",
    "endentecermo": "endentecer",
    "endentecermos": "endentecer",
    "endentecerá": "endentecer",
    "endentecerás": "endentecer",
    "endentecerão": "endentecer",
    "endenteceríamos": "endentecer",
    "endenteceríeis": "endentecer",
    "endenteces": "endentecer",
    "endentecesse": "endentecer",
    "endentecessem": "endentecer",
    "endentecesses": "endentecer",
    "endenteceste": "endentecer",
    "endentecestes": "endentecer",
    "endenteceu": "endentecer",
    "endenteci": "endentecer",
    "endentecia": "endentecer",
    "endenteciam": "endentecer",
    "endentecias": "endentecer",
    "endentecida": "endentecer",
    "endentecidas": "endentecer",
    "endentecido": "endentecer",
    "endentecidos": "endentecer",
    "endentecêramo": "endentecer",
    "endentecêramos": "endentecer",
    "endentecêreis": "endentecer",
    "endentecêsseis": "endentecer",
    "endentecêssemos": "endentecer",
    "endentecíamo": "endentecer",
    "endentecíamos": "endentecer",
    "endentecíeis": "endentecer",
    "endentei": "endentar",
    "endenteis": "endentar",
    "endentem": "endentar",
    "endentemo": "endentar",
    "endentemos": "endentar",
    "endentes": "endentar",
    "endenteça": "endentecer",
    "endenteçais": "endentecer",
    "endenteçam": "endentecer",
    "endenteçamo": "endentecer",
    "endenteçamos": "endentecer",
    "endenteças": "endentecer",
    "endenteço": "endentecer",
    "endento": "endentar",
    "endentou": "endentar",
    "endentá": "endentar",
    "endentámo": "endentar",
    "endentámos": "endentar",
    "endentáramo": "endentar",
    "endentáramos": "endentar",
    "endentárei": "endentar",
    "endentáreis": "endentar",
    "endentásseis": "endentar",
    "endentássemos": "endentar",
    "endentávamo": "endentar",
    "endentávamos": "endentar",
    "endentávei": "endentar",
    "endentáveis": "endentar",
    "enderece": "endereçar",
    "enderecei": "endereçar",
    "endereceis": "endereçar",
    "enderecem": "endereçar",
    "enderecemo": "endereçar",
    "enderecemos": "endereçar",
    "endereces": "endereçar",
    "endereça": "endereçar",
    "endereçada": "endereçar",
    "endereçadas": "endereçar",
    "endereçado": "endereçar",
    "endereçados": "endereçar",
    "endereçai": "endereçar",
    "endereçais": "endereçar",
    "endereçam": "endereçar",
    "endereçamentos": "endereçamento",
    "endereçamo": "endereçar",
    "endereçamos": "endereçar",
    "endereçando": "endereçar",
    "endereçara": "endereçar",
    "endereçaram": "endereçar",
    "endereçaras": "endereçar",
    "endereçarde": "endereçar",
    "endereçardes": "endereçar",
    "endereçare": "endereçar",
    "endereçarei": "endereçar",
    "endereçareis": "endereçar",
    "endereçarem": "endereçar",
    "endereçaremos": "endereçar",
    "endereçares": "endereçar",
    "endereçaria": "endereçar",
    "endereçariam": "endereçar",
    "endereçarias": "endereçar",
    "endereçarmo": "endereçar",
    "endereçarmos": "endereçar",
    "endereçará": "endereçar",
    "endereçarás": "endereçar",
    "endereçarão": "endereçar",
    "endereçaríamos": "endereçar",
    "endereçaríeis": "endereçar",
    "endereças": "endereçar",
    "endereçasse": "endereçar",
    "endereçassem": "endereçar",
    "endereçasses": "endereçar",
    "endereçaste": "endereçar",
    "endereçastes": "endereçar",
    "endereçava": "endereçar",
    "endereçavam": "endereçar",
    "endereçavas": "endereçar",
    "endereço": "endereçar",
    "endereços": "endereço",
    "endereçou": "endereçar",
    "endereçá": "endereçar",
    "endereçámo": "endereçar",
    "endereçámos": "endereçar",
    "endereçáramo": "endereçar",
    "endereçáramos": "endereçar",
    "endereçárei": "endereçar",
    "endereçáreis": "endereçar",
    "endereçásseis": "endereçar",
    "endereçássemos": "endereçar",
    "endereçávamo": "endereçar",
    "endereçávamos": "endereçar",
    "endereçávei": "endereçar",
    "endereçáveis": "endereçável",
    "endeusa": "endeusar",
    "endeusada": "endeusar",
    "endeusadas": "endeusar",
    "endeusado": "endeusar",
    "endeusadora": "endeusador",
    "endeusadoras": "endeusador",
    "endeusadores": "endeusador",
    "endeusados": "endeusar",
    "endeusai": "endeusar",
    "endeusais": "endeusar",
    "endeusam": "endeusar",
    "endeusamentos": "endeusamento",
    "endeusamo": "endeusar",
    "endeusamos": "endeusar",
    "endeusando": "endeusar",
    "endeusara": "endeusar",
    "endeusaram": "endeusar",
    "endeusaras": "endeusar",
    "endeusarde": "endeusar",
    "endeusardes": "endeusar",
    "endeusare": "endeusar",
    "endeusarei": "endeusar",
    "endeusareis": "endeusar",
    "endeusarem": "endeusar",
    "endeusaremos": "endeusar",
    "endeusares": "endeusar",
    "endeusaria": "endeusar",
    "endeusariam": "endeusar",
    "endeusarias": "endeusar",
    "endeusarmo": "endeusar",
    "endeusarmos": "endeusar",
    "endeusará": "endeusar",
    "endeusarás": "endeusar",
    "endeusarão": "endeusar",
    "endeusaríamos": "endeusar",
    "endeusaríeis": "endeusar",
    "endeusas": "endeusar",
    "endeusasse": "endeusar",
    "endeusassem": "endeusar",
    "endeusasses": "endeusar",
    "endeusaste": "endeusar",
    "endeusastes": "endeusar",
    "endeusava": "endeusar",
    "endeusavam": "endeusar",
    "endeusavas": "endeusar",
    "endeusações": "endeusação",
    "endeuse": "endeusar",
    "endeusei": "endeusar",
    "endeuseis": "endeusar",
    "endeusem": "endeusar",
    "endeusemo": "endeusar",
    "endeusemos": "endeusar",
    "endeuses": "endeusar",
    "endeuso": "endeusar",
    "endeusou": "endeusar",
    "endeusá": "endeusar",
    "endeusámo": "endeusar",
    "endeusámos": "endeusar",
    "endeusáramo": "endeusar",
    "endeusáramos": "endeusar",
    "endeusárei": "endeusar",
    "endeusáreis": "endeusar",
    "endeusásseis": "endeusar",
    "endeusássemos": "endeusar",
    "endeusávamo": "endeusar",
    "endeusávamos": "endeusar",
    "endeusávei": "endeusar",
    "endeusáveis": "endeusável",
    "endexinas": "endexina",
    "endezes": "endez",
    "endiabra": "endiabrar",
    "endiabrada": "endiabrar",
    "endiabradas": "endiabrar",
    "endiabrado": "endiabrar",
    "endiabrados": "endiabrar",
    "endiabradíssima": "endiabrado",
    "endiabradíssimas": "endiabrado",
    "endiabradíssimo": "endiabrado",
    "endiabradíssimos": "endiabrado",
    "endiabrai": "endiabrar",
    "endiabrais": "endiabrar",
    "endiabram": "endiabrar",
    "endiabramo": "endiabrar",
    "endiabramos": "endiabrar",
    "endiabrando": "endiabrar",
    "endiabrara": "endiabrar",
    "endiabraram": "endiabrar",
    "endiabraras": "endiabrar",
    "endiabrarde": "endiabrar",
    "endiabrardes": "endiabrar",
    "endiabrare": "endiabrar",
    "endiabrarei": "endiabrar",
    "endiabrareis": "endiabrar",
    "endiabrarem": "endiabrar",
    "endiabraremos": "endiabrar",
    "endiabrares": "endiabrar",
    "endiabraria": "endiabrar",
    "endiabrariam": "endiabrar",
    "endiabrarias": "endiabrar",
    "endiabrarmo": "endiabrar",
    "endiabrarmos": "endiabrar",
    "endiabrará": "endiabrar",
    "endiabrarás": "endiabrar",
    "endiabrarão": "endiabrar",
    "endiabraríamos": "endiabrar",
    "endiabraríeis": "endiabrar",
    "endiabras": "endiabrar",
    "endiabrasse": "endiabrar",
    "endiabrassem": "endiabrar",
    "endiabrasses": "endiabrar",
    "endiabraste": "endiabrar",
    "endiabrastes": "endiabrar",
    "endiabrava": "endiabrar",
    "endiabravam": "endiabrar",
    "endiabravas": "endiabrar",
    "endiabre": "endiabrar",
    "endiabrei": "endiabrar",
    "endiabreis": "endiabrar",
    "endiabrem": "endiabrar",
    "endiabremo": "endiabrar",
    "endiabremos": "endiabrar",
    "endiabres": "endiabrar",
    "endiabro": "endiabrar",
    "endiabrou": "endiabrar",
    "endiabrá": "endiabrar",
    "endiabrámo": "endiabrar",
    "endiabrámos": "endiabrar",
    "endiabráramo": "endiabrar",
    "endiabráramos": "endiabrar",
    "endiabrárei": "endiabrar",
    "endiabráreis": "endiabrar",
    "endiabrásseis": "endiabrar",
    "endiabrássemos": "endiabrar",
    "endiabrávamo": "endiabrar",
    "endiabrávamos": "endiabrar",
    "endiabrávei": "endiabrar",
    "endiabráveis": "endiabrar",
    "endimeninas": "endimenina",
    "endinheirada": "endinheirado",
    "endinheiradas": "endinheirado",
    "endinheirados": "endinheirado",
    "endireita": "endireitar",
    "endireitada": "endireitar",
    "endireitadas": "endireitar",
    "endireitado": "endireitar",
    "endireitados": "endireitar",
    "endireitai": "endireitar",
    "endireitais": "endireitar",
    "endireitam": "endireitar",
    "endireitamo": "endireitar",
    "endireitamos": "endireitar",
    "endireitando": "endireitar",
    "endireitara": "endireitar",
    "endireitaram": "endireitar",
    "endireitaras": "endireitar",
    "endireitarde": "endireitar",
    "endireitardes": "endireitar",
    "endireitare": "endireitar",
    "endireitarei": "endireitar",
    "endireitareis": "endireitar",
    "endireitarem": "endireitar",
    "endireitaremos": "endireitar",
    "endireitares": "endireitar",
    "endireitaria": "endireitar",
    "endireitariam": "endireitar",
    "endireitarias": "endireitar",
    "endireitarmo": "endireitar",
    "endireitarmos": "endireitar",
    "endireitará": "endireitar",
    "endireitarás": "endireitar",
    "endireitarão": "endireitar",
    "endireitaríamos": "endireitar",
    "endireitaríeis": "endireitar",
    "endireitas": "endireitar",
    "endireitasse": "endireitar",
    "endireitassem": "endireitar",
    "endireitasses": "endireitar",
    "endireitaste": "endireitar",
    "endireitastes": "endireitar",
    "endireitava": "endireitar",
    "endireitavam": "endireitar",
    "endireitavas": "endireitar",
    "endireite": "endireitar",
    "endireitei": "endireitar",
    "endireiteis": "endireitar",
    "endireitem": "endireitar",
    "endireitemo": "endireitar",
    "endireitemos": "endireitar",
    "endireites": "endireitar",
    "endireito": "endireitar",
    "endireitos": "endireito",
    "endireitou": "endireitar",
    "endireitá": "endireitar",
    "endireitámo": "endireitar",
    "endireitámos": "endireitar",
    "endireitáramo": "endireitar",
    "endireitáramos": "endireitar",
    "endireitárei": "endireitar",
    "endireitáreis": "endireitar",
    "endireitásseis": "endireitar",
    "endireitássemos": "endireitar",
    "endireitávamo": "endireitar",
    "endireitávamos": "endireitar",
    "endireitávei": "endireitar",
    "endireitáveis": "endireitável",
    "endivas": "endiva",
    "endivida": "endividar",
    "endividada": "endividar",
    "endividadas": "endividar",
    "endividado": "endividar",
    "endividados": "endividar",
    "endividai": "endividar",
    "endividais": "endividar",
    "endividam": "endividar",
    "endividamentos": "endividamento",
    "endividamo": "endividar",
    "endividamos": "endividar",
    "endividando": "endividar",
    "endividara": "endividar",
    "endividaram": "endividar",
    "endividaras": "endividar",
    "endividarde": "endividar",
    "endividardes": "endividar",
    "endividare": "endividar",
    "endividarei": "endividar",
    "endividareis": "endividar",
    "endividarem": "endividar",
    "endividaremos": "endividar",
    "endividares": "endividar",
    "endividaria": "endividar",
    "endividariam": "endividar",
    "endividarias": "endividar",
    "endividarmo": "endividar",
    "endividarmos": "endividar",
    "endividará": "endividar",
    "endividarás": "endividar",
    "endividarão": "endividar",
    "endividaríamos": "endividar",
    "endividaríeis": "endividar",
    "endividas": "endividar",
    "endividasse": "endividar",
    "endividassem": "endividar",
    "endividasses": "endividar",
    "endividaste": "endividar",
    "endividastes": "endividar",
    "endividava": "endividar",
    "endividavam": "endividar",
    "endividavas": "endividar",
    "endivide": "endividar",
    "endividei": "endividar",
    "endivideis": "endividar",
    "endividem": "endividar",
    "endividemo": "endividar",
    "endividemos": "endividar",
    "endivides": "endividar",
    "endivido": "endividar",
    "endividou": "endividar",
    "endividá": "endividar",
    "endividámo": "endividar",
    "endividámos": "endividar",
    "endividáramo": "endividar",
    "endividáramos": "endividar",
    "endividárei": "endividar",
    "endividáreis": "endividar",
    "endividásseis": "endividar",
    "endividássemos": "endividar",
    "endividávamo": "endividar",
    "endividávamos": "endividar",
    "endividávei": "endividar",
    "endividáveis": "endividar",
    "endlasmática": "endlasmático",
    "endlasmáticas": "endlasmático",
    "endlasmáticos": "endlasmático",
    "endoblastos": "endoblasto",
    "endocardites": "endocardite",
    "endocarpos": "endocarpo",
    "endocefalias": "endocefalia",
    "endocefálica": "endocefálico",
    "endocefálicas": "endocefálico",
    "endocefálicos": "endocefálico",
    "endocraniana": "endocraniano",
    "endocranianas": "endocraniano",
    "endocranianos": "endocraniano",
    "endocrinologias": "endocrinologia",
    "endocrinologistas": "endocrinologista",
    "endocrinológica": "endocrinológico",
    "endocrinológicas": "endocrinológico",
    "endocrinológicos": "endocrinológico",
    "endocrânios": "endocrânio",
    "endocrínica": "endocrínico",
    "endocrínicas": "endocrínico",
    "endocrínicos": "endocrínico",
    "endocárdios": "endocárdio",
    "endocárpios": "endocárpio",
    "endocéfala": "endocéfalo",
    "endocéfalas": "endocéfalo",
    "endocéfalos": "endocéfalo",
    "endocélios": "endocélio",
    "endocíclica": "endocíclico",
    "endocíclicas": "endocíclico",
    "endocíclicos": "endocíclico",
    "endocícliocos": "endocíclioco",
    "endodermas": "endoderma",
    "endodermes": "endoderme",
    "endodérmica": "endodérmico",
    "endodérmicas": "endodérmico",
    "endodérmicos": "endodérmico",
    "endofasias": "endofasia",
    "endofásica": "endofásico",
    "endofásicas": "endofásico",
    "endofásicos": "endofásico",
    "endogamias": "endogamia",
    "endogenias": "endogenia",
    "endogenésica": "endogenésico",
    "endogenésicas": "endogenésico",
    "endogenésicos": "endogenésico",
    "endogâmica": "endogâmico",
    "endogâmicas": "endogâmico",
    "endogâmicos": "endogâmico",
    "endogénica": "endogénico",
    "endogénicas": "endogénico",
    "endogénicos": "endogénico",
    "endoida": "endoidar",
    "endoidada": "endoidar",
    "endoidadas": "endoidar",
    "endoidado": "endoidar",
    "endoidados": "endoidar",
    "endoidai": "endoidar",
    "endoidais": "endoidar",
    "endoidam": "endoidar",
    "endoidamentos": "endoidamento",
    "endoidamo": "endoidar",
    "endoidamos": "endoidar",
    "endoidando": "endoidar",
    "endoidara": "endoidar",
    "endoidaram": "endoidar",
    "endoidaras": "endoidar",
    "endoidarde": "endoidar",
    "endoidardes": "endoidar",
    "endoidare": "endoidar",
    "endoidarei": "endoidar",
    "endoidareis": "endoidar",
    "endoidarem": "endoidar",
    "endoidaremos": "endoidar",
    "endoidares": "endoidar",
    "endoidaria": "endoidar",
    "endoidariam": "endoidar",
    "endoidarias": "endoidar",
    "endoidarmo": "endoidar",
    "endoidarmos": "endoidar",
    "endoidará": "endoidar",
    "endoidarás": "endoidar",
    "endoidarão": "endoidar",
    "endoidaríamos": "endoidar",
    "endoidaríeis": "endoidar",
    "endoidas": "endoidar",
    "endoidasse": "endoidar",
    "endoidassem": "endoidar",
    "endoidasses": "endoidar",
    "endoidaste": "endoidar",
    "endoidastes": "endoidar",
    "endoidava": "endoidar",
    "endoidavam": "endoidar",
    "endoidavas": "endoidar",
    "endoide": "endoidar",
    "endoidece": "endoidecer",
    "endoidecedora": "endoidecedor",
    "endoidecedoras": "endoidecedor",
    "endoidecedores": "endoidecedor",
    "endoidecei": "endoidecer",
    "endoideceis": "endoidecer",
    "endoidecem": "endoidecer",
    "endoidecemo": "endoidecer",
    "endoidecemos": "endoidecer",
    "endoidecendo": "endoidecer",
    "endoidecera": "endoidecer",
    "endoideceram": "endoidecer",
    "endoideceras": "endoidecer",
    "endoidecerde": "endoidecer",
    "endoidecerdes": "endoidecer",
    "endoidecere": "endoidecer",
    "endoidecerei": "endoidecer",
    "endoidecereis": "endoidecer",
    "endoidecerem": "endoidecer",
    "endoideceremos": "endoidecer",
    "endoideceres": "endoidecer",
    "endoideceria": "endoidecer",
    "endoideceriam": "endoidecer",
    "endoidecerias": "endoidecer",
    "endoidecermo": "endoidecer",
    "endoidecermos": "endoidecer",
    "endoidecerá": "endoidecer",
    "endoidecerás": "endoidecer",
    "endoidecerão": "endoidecer",
    "endoideceríamos": "endoidecer",
    "endoideceríeis": "endoidecer",
    "endoideces": "endoidecer",
    "endoidecesse": "endoidecer",
    "endoidecessem": "endoidecer",
    "endoidecesses": "endoidecer",
    "endoideceste": "endoidecer",
    "endoidecestes": "endoidecer",
    "endoideceu": "endoidecer",
    "endoideci": "endoidecer",
    "endoidecia": "endoidecer",
    "endoideciam": "endoidecer",
    "endoidecias": "endoidecer",
    "endoidecida": "endoidecido",
    "endoidecidas": "endoidecido",
    "endoidecido": "endoidecer",
    "endoidecidos": "endoidecido",
    "endoidecimentos": "endoidecimento",
    "endoidecê": "endoidecer",
    "endoidecêramo": "endoidecer",
    "endoidecêramos": "endoidecer",
    "endoidecêrei": "endoidecer",
    "endoidecêreis": "endoidecer",
    "endoidecêsseis": "endoidecer",
    "endoidecêssemos": "endoidecer",
    "endoidecíamo": "endoidecer",
    "endoidecíamos": "endoidecer",
    "endoidecíei": "endoidecer",
    "endoidecíeis": "endoidecer",
    "endoidei": "endoidar",
    "endoideis": "endoidar",
    "endoidem": "endoidar",
    "endoidemo": "endoidar",
    "endoidemos": "endoidar",
    "endoides": "endoidar",
    "endoideça": "endoidecer",
    "endoideçais": "endoidecer",
    "endoideçam": "endoidecer",
    "endoideçamo": "endoidecer",
    "endoideçamos": "endoidecer",
    "endoideças": "endoidecer",
    "endoideço": "endoidecer",
    "endoido": "endoidar",
    "endoidou": "endoidar",
    "endoidá": "endoidar",
    "endoidámo": "endoidar",
    "endoidámos": "endoidar",
    "endoidáramo": "endoidar",
    "endoidáramos": "endoidar",
    "endoidárei": "endoidar",
    "endoidáreis": "endoidar",
    "endoidásseis": "endoidar",
    "endoidássemos": "endoidar",
    "endoidávamo": "endoidar",
    "endoidávamos": "endoidar",
    "endoidávei": "endoidar",
    "endoidáveis": "endoidar",
    "endolinfas": "endolinfa",
    "endolinfática": "endolinfático",
    "endolinfáticas": "endolinfático",
    "endolinfáticos": "endolinfático",
    "endometrites": "endometrite",
    "endomicoses": "endomicose",
    "endomicótica": "endomicótico",
    "endomicóticas": "endomicótico",
    "endomicóticos": "endomicótico",
    "endominga": "endomingar",
    "endomingada": "endomingar",
    "endomingadas": "endomingar",
    "endomingado": "endomingar",
    "endomingados": "endomingar",
    "endomingai": "endomingar",
    "endomingais": "endomingar",
    "endomingam": "endomingar",
    "endomingamo": "endomingar",
    "endomingamos": "endomingar",
    "endomingando": "endomingar",
    "endomingara": "endomingar",
    "endomingaram": "endomingar",
    "endomingaras": "endomingar",
    "endomingarde": "endomingar",
    "endomingardes": "endomingar",
    "endomingare": "endomingar",
    "endomingarei": "endomingar",
    "endomingareis": "endomingar",
    "endomingarem": "endomingar",
    "endomingaremos": "endomingar",
    "endomingares": "endomingar",
    "endomingaria": "endomingar",
    "endomingariam": "endomingar",
    "endomingarias": "endomingar",
    "endomingarmo": "endomingar",
    "endomingarmos": "endomingar",
    "endomingará": "endomingar",
    "endomingarás": "endomingar",
    "endomingarão": "endomingar",
    "endomingaríamos": "endomingar",
    "endomingaríeis": "endomingar",
    "endomingas": "endomingar",
    "endomingasse": "endomingar",
    "endomingassem": "endomingar",
    "endomingasses": "endomingar",
    "endomingaste": "endomingar",
    "endomingastes": "endomingar",
    "endomingava": "endomingar",
    "endomingavam": "endomingar",
    "endomingavas": "endomingar",
    "endomingo": "endomingar",
    "endomingou": "endomingar",
    "endomingue": "endomingar",
    "endominguei": "endomingar",
    "endomingueis": "endomingar",
    "endominguem": "endomingar",
    "endominguemo": "endomingar",
    "endominguemos": "endomingar",
    "endomingues": "endomingar",
    "endomingá": "endomingar",
    "endomingámo": "endomingar",
    "endomingámos": "endomingar",
    "endomingáramo": "endomingar",
    "endomingáramos": "endomingar",
    "endomingárei": "endomingar",
    "endomingáreis": "endomingar",
    "endomingásseis": "endomingar",
    "endomingássemos": "endomingar",
    "endomingávamo": "endomingar",
    "endomingávamos": "endomingar",
    "endomingávei": "endomingar",
    "endomingáveis": "endomingar",
    "endomixias": "endomixia",
    "endomorfismos": "endomorfismo",
    "endométrios": "endométrio",
    "endomórfica": "endomórfico",
    "endomórficas": "endomórfico",
    "endomórficos": "endomórfico",
    "endoneuros": "endoneuro",
    "endoparasitas": "endoparasita",
    "endoparasitismos": "endoparasitismo",
    "endoparasitos": "endoparasito",
    "endoplasmas": "endoplasma",
    "endopleuras": "endopleura",
    "endopódios": "endopódio",
    "endorreica": "endorreico",
    "endorreicas": "endorreico",
    "endorreicos": "endorreico",
    "endorsamentos": "endorsamento",
    "endoscopias": "endoscopia",
    "endoscópica": "endoscópico",
    "endoscópicas": "endoscópico",
    "endoscópicos": "endoscópico",
    "endoscópios": "endoscópio",
    "endosferas": "endosfera",
    "endosférica": "endosférico",
    "endosféricas": "endosférico",
    "endosféricos": "endosférico",
    "endosmometrias": "endosmometria",
    "endosmométrica": "endosmométrico",
    "endosmométricas": "endosmométrico",
    "endosmométricos": "endosmométrico",
    "endosmoses": "endosmose",
    "endosmómetros": "endosmómetro",
    "endosmótica": "endosmótico",
    "endosmóticas": "endosmótico",
    "endosmóticos": "endosmótico",
    "endospermas": "endosperma",
    "endospérmica": "endospérmico",
    "endospérmicas": "endospérmico",
    "endospérmicos": "endospérmico",
    "endosqueletos": "endosqueleto",
    "endosquelética": "endosquelético",
    "endosqueléticas": "endosquelético",
    "endosqueléticos": "endosquelético",
    "endossa": "endossar",
    "endossabilidades": "endossabilidade",
    "endossada": "endossar",
    "endossadas": "endossar",
    "endossado": "endossar",
    "endossadora": "endossador",
    "endossadoras": "endossador",
    "endossadores": "endossador",
    "endossados": "endossar",
    "endossai": "endossar",
    "endossais": "endossar",
    "endossam": "endossar",
    "endossamentos": "endossamento",
    "endossamo": "endossar",
    "endossamos": "endossar",
    "endossando": "endossar",
    "endossantes": "endossante",
    "endossara": "endossar",
    "endossaram": "endossar",
    "endossaras": "endossar",
    "endossarcos": "endossarco",
    "endossarde": "endossar",
    "endossardes": "endossar",
    "endossare": "endossar",
    "endossarei": "endossar",
    "endossareis": "endossar",
    "endossarem": "endossar",
    "endossaremos": "endossar",
    "endossares": "endossar",
    "endossaria": "endossar",
    "endossariam": "endossar",
    "endossarias": "endossar",
    "endossarmo": "endossar",
    "endossarmos": "endossar",
    "endossará": "endossar",
    "endossarás": "endossar",
    "endossarão": "endossar",
    "endossaríamos": "endossar",
    "endossaríeis": "endossar",
    "endossas": "endossar",
    "endossasse": "endossar",
    "endossassem": "endossar",
    "endossasses": "endossar",
    "endossaste": "endossar",
    "endossastes": "endossar",
    "endossatária": "endossatário",
    "endossatárias": "endossatário",
    "endossatários": "endossatário",
    "endossava": "endossar",
    "endossavam": "endossar",
    "endossavas": "endossar",
    "endosse": "endossar",
    "endossei": "endossar",
    "endosseis": "endossar",
    "endossem": "endossar",
    "endossemo": "endossar",
    "endossemos": "endossar",
    "endosses": "endosse",
    "endosso": "endossar",
    "endossos": "endosso",
    "endossou": "endossar",
    "endossá": "endossar",
    "endossámo": "endossar",
    "endossámos": "endossar",
    "endossáramo": "endossar",
    "endossáramos": "endossar",
    "endossárei": "endossar",
    "endossáreis": "endossar",
    "endossásseis": "endossar",
    "endossássemos": "endossar",
    "endossávamo": "endossar",
    "endossávamos": "endossar",
    "endossávei": "endossar",
    "endossáveis": "endossável",
    "endostilos": "endostilo",
    "endoteliais": "endotelial",
    "endotélios": "endotélio",
    "endotérmica": "endotérmico",
    "endotérmicas": "endotérmico",
    "endotérmicos": "endotérmico",
    "endouda": "endoudar",
    "endoudada": "endoudar",
    "endoudadas": "endoudar",
    "endoudado": "endoudar",
    "endoudados": "endoudar",
    "endoudai": "endoudar",
    "endoudais": "endoudar",
    "endoudam": "endoudar",
    "endoudamo": "endoudar",
    "endoudamos": "endoudar",
    "endoudando": "endoudar",
    "endoudara": "endoudar",
    "endoudaram": "endoudar",
    "endoudaras": "endoudar",
    "endoudarde": "endoudar",
    "endoudardes": "endoudar",
    "endoudare": "endoudar",
    "endoudarei": "endoudar",
    "endoudareis": "endoudar",
    "endoudarem": "endoudar",
    "endoudaremos": "endoudar",
    "endoudares": "endoudar",
    "endoudaria": "endoudar",
    "endoudariam": "endoudar",
    "endoudarias": "endoudar",
    "endoudarmo": "endoudar",
    "endoudarmos": "endoudar",
    "endoudará": "endoudar",
    "endoudarás": "endoudar",
    "endoudarão": "endoudar",
    "endoudaríamos": "endoudar",
    "endoudaríeis": "endoudar",
    "endoudas": "endoudar",
    "endoudasse": "endoudar",
    "endoudassem": "endoudar",
    "endoudasses": "endoudar",
    "endoudaste": "endoudar",
    "endoudastes": "endoudar",
    "endoudava": "endoudar",
    "endoudavam": "endoudar",
    "endoudavas": "endoudar",
    "endoude": "endoudar",
    "endoudece": "endoudecer",
    "endoudecei": "endoudecer",
    "endoudeceis": "endoudecer",
    "endoudecem": "endoudecer",
    "endoudecemo": "endoudecer",
    "endoudecemos": "endoudecer",
    "endoudecendo": "endoudecer",
    "endoudecera": "endoudecer",
    "endoudeceram": "endoudecer",
    "endoudeceras": "endoudecer",
    "endoudecerde": "endoudecer",
    "endoudecerdes": "endoudecer",
    "endoudecere": "endoudecer",
    "endoudecerei": "endoudecer",
    "endoudecereis": "endoudecer",
    "endoudecerem": "endoudecer",
    "endoudeceremos": "endoudecer",
    "endoudeceres": "endoudecer",
    "endoudeceria": "endoudecer",
    "endoudeceriam": "endoudecer",
    "endoudecerias": "endoudecer",
    "endoudecermo": "endoudecer",
    "endoudecermos": "endoudecer",
    "endoudecerá": "endoudecer",
    "endoudecerás": "endoudecer",
    "endoudecerão": "endoudecer",
    "endoudeceríamos": "endoudecer",
    "endoudeceríeis": "endoudecer",
    "endoudeces": "endoudecer",
    "endoudecesse": "endoudecer",
    "endoudecessem": "endoudecer",
    "endoudecesses": "endoudecer",
    "endoudeceste": "endoudecer",
    "endoudecestes": "endoudecer",
    "endoudeceu": "endoudecer",
    "endoudeci": "endoudecer",
    "endoudecia": "endoudecer",
    "endoudeciam": "endoudecer",
    "endoudecias": "endoudecer",
    "endoudecida": "endoudecer",
    "endoudecidas": "endoudecer",
    "endoudecido": "endoudecer",
    "endoudecidos": "endoudecer",
    "endoudecimentos": "endoudecimento",
    "endoudecê": "endoudecer",
    "endoudecêramo": "endoudecer",
    "endoudecêramos": "endoudecer",
    "endoudecêrei": "endoudecer",
    "endoudecêreis": "endoudecer",
    "endoudecêsseis": "endoudecer",
    "endoudecêssemos": "endoudecer",
    "endoudecíamo": "endoudecer",
    "endoudecíamos": "endoudecer",
    "endoudecíei": "endoudecer",
    "endoudecíeis": "endoudecer",
    "endoudei": "endoudar",
    "endoudeis": "endoudar",
    "endoudem": "endoudar",
    "endoudemo": "endoudar",
    "endoudemos": "endoudar",
    "endoudes": "endoudar",
    "endoudeça": "endoudecer",
    "endoudeçais": "endoudecer",
    "endoudeçam": "endoudecer",
    "endoudeçamo": "endoudecer",
    "endoudeçamos": "endoudecer",
    "endoudeças": "endoudecer",
    "endoudeço": "endoudecer",
    "endoudo": "endoudar",
    "endoudou": "endoudar",
    "endoudá": "endoudar",
    "endoudámo": "endoudar",
    "endoudámos": "endoudar",
    "endoudáramo": "endoudar",
    "endoudáramos": "endoudar",
    "endoudárei": "endoudar",
    "endoudáreis": "endoudar",
    "endoudásseis": "endoudar",
    "endoudássemos": "endoudar",
    "endoudávamo": "endoudar",
    "endoudávamos": "endoudar",
    "endoudávei": "endoudar",
    "endoudáveis": "endoudar",
    "endovenosa": "endovenoso",
    "endovenosas": "endovenoso",
    "endovenosos": "endovenoso",
    "endozoária": "endozoário",
    "endozoárias": "endozoário",
    "endozoários": "endozoário",
    "endriagos": "endriago",
    "endromina": "endrominar",
    "endrominada": "endrominar",
    "endrominadas": "endrominar",
    "endrominado": "endrominar",
    "endrominados": "endrominar",
    "endrominai": "endrominar",
    "endrominais": "endrominar",
    "endrominam": "endrominar",
    "endrominamo": "endrominar",
    "endrominamos": "endrominar",
    "endrominando": "endrominar",
    "endrominara": "endrominar",
    "endrominaram": "endrominar",
    "endrominaras": "endrominar",
    "endrominarde": "endrominar",
    "endrominardes": "endrominar",
    "endrominare": "endrominar",
    "endrominarei": "endrominar",
    "endrominareis": "endrominar",
    "endrominarem": "endrominar",
    "endrominaremos": "endrominar",
    "endrominares": "endrominar",
    "endrominaria": "endrominar",
    "endrominariam": "endrominar",
    "endrominarias": "endrominar",
    "endrominarmo": "endrominar",
    "endrominarmos": "endrominar",
    "endrominará": "endrominar",
    "endrominarás": "endrominar",
    "endrominarão": "endrominar",
    "endrominaríamos": "endrominar",
    "endrominaríeis": "endrominar",
    "endrominas": "endrominar",
    "endrominasse": "endrominar",
    "endrominassem": "endrominar",
    "endrominasses": "endrominar",
    "endrominaste": "endrominar",
    "endrominastes": "endrominar",
    "endrominava": "endrominar",
    "endrominavam": "endrominar",
    "endrominavas": "endrominar",
    "endromine": "endrominar",
    "endrominei": "endrominar",
    "endromineis": "endrominar",
    "endrominem": "endrominar",
    "endrominemo": "endrominar",
    "endrominemos": "endrominar",
    "endromines": "endrominar",
    "endromino": "endrominar",
    "endrominou": "endrominar",
    "endrominá": "endrominar",
    "endrominámo": "endrominar",
    "endrominámos": "endrominar",
    "endromináramo": "endrominar",
    "endromináramos": "endrominar",
    "endrominárei": "endrominar",
    "endromináreis": "endrominar",
    "endrominásseis": "endrominar",
    "endrominássemos": "endrominar",
    "endrominávamo": "endrominar",
    "endrominávamos": "endrominar",
    "endrominávei": "endrominar",
    "endromináveis": "endrominável",
    "endros": "endro",
    "endróminas": "endrómina",
    "endrões": "endrão",
    "endurações": "enduração",
    "endurece": "endurecer",
    "endurecedora": "endurecedor",
    "endurecedoras": "endurecedor",
    "endurecedores": "endurecedor",
    "endurecei": "endurecer",
    "endureceis": "endurecer",
    "endurecem": "endurecer",
    "endurecemo": "endurecer",
    "endurecemos": "endurecer",
    "endurecendo": "endurecer",
    "endurecera": "endurecer",
    "endureceram": "endurecer",
    "endureceras": "endurecer",
    "endurecerde": "endurecer",
    "endurecerdes": "endurecer",
    "endurecere": "endurecer",
    "endurecerei": "endurecer",
    "endurecereis": "endurecer",
    "endurecerem": "endurecer",
    "endureceremos": "endurecer",
    "endureceres": "endurecer",
    "endureceria": "endurecer",
    "endureceriam": "endurecer",
    "endurecerias": "endurecer",
    "endurecermo": "endurecer",
    "endurecermos": "endurecer",
    "endurecerá": "endurecer",
    "endurecerás": "endurecer",
    "endurecerão": "endurecer",
    "endureceríamos": "endurecer",
    "endureceríeis": "endurecer",
    "endureces": "endurecer",
    "endurecesse": "endurecer",
    "endurecessem": "endurecer",
    "endurecesses": "endurecer",
    "endureceste": "endurecer",
    "endurecestes": "endurecer",
    "endureceu": "endurecer",
    "endureci": "endurecer",
    "endurecia": "endurecer",
    "endureciam": "endurecer",
    "endurecias": "endurecer",
    "endurecida": "endurecido",
    "endurecidas": "endurecido",
    "endurecido": "endurecer",
    "endurecidos": "endurecido",
    "endurecidíssima": "endurecido",
    "endurecidíssimas": "endurecido",
    "endurecidíssimo": "endurecido",
    "endurecidíssimos": "endurecido",
    "endurecimentos": "endurecimento",
    "endurecê": "endurecer",
    "endurecêramo": "endurecer",
    "endurecêramos": "endurecer",
    "endurecêrei": "endurecer",
    "endurecêreis": "endurecer",
    "endurecêsseis": "endurecer",
    "endurecêssemos": "endurecer",
    "endurecíamo": "endurecer",
    "endurecíamos": "endurecer",
    "endurecíei": "endurecer",
    "endurecíeis": "endurecer",
    "endurenta": "endurentar",
    "endurentada": "endurentar",
    "endurentadas": "endurentar",
    "endurentado": "endurentar",
    "endurentados": "endurentar",
    "endurentai": "endurentar",
    "endurentais": "endurentar",
    "endurentam": "endurentar",
    "endurentamo": "endurentar",
    "endurentamos": "endurentar",
    "endurentando": "endurentar",
    "endurentara": "endurentar",
    "endurentaram": "endurentar",
    "endurentaras": "endurentar",
    "endurentarde": "endurentar",
    "endurentardes": "endurentar",
    "endurentare": "endurentar",
    "endurentarei": "endurentar",
    "endurentareis": "endurentar",
    "endurentarem": "endurentar",
    "endurentaremos": "endurentar",
    "endurentares": "endurentar",
    "endurentaria": "endurentar",
    "endurentariam": "endurentar",
    "endurentarias": "endurentar",
    "endurentarmo": "endurentar",
    "endurentarmos": "endurentar",
    "endurentará": "endurentar",
    "endurentarás": "endurentar",
    "endurentarão": "endurentar",
    "endurentaríamos": "endurentar",
    "endurentaríeis": "endurentar",
    "endurentas": "endurentar",
    "endurentasse": "endurentar",
    "endurentassem": "endurentar",
    "endurentasses": "endurentar",
    "endurentaste": "endurentar",
    "endurentastes": "endurentar",
    "endurentava": "endurentar",
    "endurentavam": "endurentar",
    "endurentavas": "endurentar",
    "endurente": "endurentar",
    "endurentei": "endurentar",
    "endurenteis": "endurentar",
    "endurentem": "endurentar",
    "endurentemo": "endurentar",
    "endurentemos": "endurentar",
    "endurentes": "endurentar",
    "endurento": "endurentar",
    "endurentou": "endurentar",
    "endurentá": "endurentar",
    "endurentámo": "endurentar",
    "endurentámos": "endurentar",
    "endurentáramo": "endurentar",
    "endurentáramos": "endurentar",
    "endurentárei": "endurentar",
    "endurentáreis": "endurentar",
    "endurentásseis": "endurentar",
    "endurentássemos": "endurentar",
    "endurentávamo": "endurentar",
    "endurentávamos": "endurentar",
    "endurentávei": "endurentar",
    "endurentáveis": "endurentar",
    "endureça": "endurecer",
    "endureçais": "endurecer",
    "endureçam": "endurecer",
    "endureçamo": "endurecer",
    "endureçamos": "endurecer",
    "endureças": "endurecer",
    "endureço": "endurecer",
    "enduristas": "endurista",
    "enduros": "enduro",
    "endémica": "endémico",
    "endémicas": "endémico",
    "endémicos": "endémico",
    "endérmica": "endérmico",
    "endérmicas": "endérmico",
    "endérmicos": "endérmico",
    "endívias": "endívia",
    "endócrina": "endócrino",
    "endócrinas": "endócrino",
    "endócrinos": "endócrino",
    "endófita": "endófito",
    "endófitas": "endófito",
    "endófitos": "endófito",
    "endógama": "endógamo",
    "endógamas": "endógamo",
    "endógamos": "endógamo",
    "endógea": "endógeo",
    "endógeas": "endógeo",
    "endógena": "endógeno",
    "endógenas": "endógeno",
    "endógenos": "endógeno",
    "endógeos": "endógeo",
    "endópodes": "endópode",
    "endóspora": "endósporo",
    "endósporas": "endósporo",
    "endósporos": "endósporo",
    "endóstomos": "endóstomo",
    "eneagonais": "eneagonal",
    "eneandra": "eneandro",
    "eneandras": "eneandro",
    "eneandrias": "eneandria",
    "eneandros": "eneandro",
    "eneapétala": "eneapétalo",
    "eneapétalas": "eneapétalo",
    "eneapétalos": "eneapétalo",
    "eneassilábica": "eneassilábico",
    "eneassilábicas": "eneassilábico",
    "eneassilábicos": "eneassilábico",
    "eneassépala": "eneassépalo",
    "eneassépalas": "eneassépalo",
    "eneassépalos": "eneassépalo",
    "eneassílaba": "eneassílabo",
    "eneassílabas": "eneassílabo",
    "eneassílabos": "eneassílabo",
    "enegrece": "enegrecer",
    "enegrecei": "enegrecer",
    "enegreceis": "enegrecer",
    "enegrecem": "enegrecer",
    "enegrecemo": "enegrecer",
    "enegrecemos": "enegrecer",
    "enegrecendo": "enegrecer",
    "enegrecera": "enegrecer",
    "enegreceram": "enegrecer",
    "enegreceras": "enegrecer",
    "enegrecerde": "enegrecer",
    "enegrecerdes": "enegrecer",
    "enegrecere": "enegrecer",
    "enegrecerei": "enegrecer",
    "enegrecereis": "enegrecer",
    "enegrecerem": "enegrecer",
    "enegreceremos": "enegrecer",
    "enegreceres": "enegrecer",
    "enegreceria": "enegrecer",
    "enegreceriam": "enegrecer",
    "enegrecerias": "enegrecer",
    "enegrecermo": "enegrecer",
    "enegrecermos": "enegrecer",
    "enegrecerá": "enegrecer",
    "enegrecerás": "enegrecer",
    "enegrecerão": "enegrecer",
    "enegreceríamos": "enegrecer",
    "enegreceríeis": "enegrecer",
    "enegreces": "enegrecer",
    "enegrecesse": "enegrecer",
    "enegrecessem": "enegrecer",
    "enegrecesses": "enegrecer",
    "enegreceste": "enegrecer",
    "enegrecestes": "enegrecer",
    "enegreceu": "enegrecer",
    "enegreci": "enegrecer",
    "enegrecia": "enegrecer",
    "enegreciam": "enegrecer",
    "enegrecias": "enegrecer",
    "enegrecida": "enegrecido",
    "enegrecidas": "enegrecido",
    "enegrecido": "enegrecer",
    "enegrecidos": "enegrecido",
    "enegrecimentos": "enegrecimento",
    "enegrecê": "enegrecer",
    "enegrecêramo": "enegrecer",
    "enegrecêramos": "enegrecer",
    "enegrecêrei": "enegrecer",
    "enegrecêreis": "enegrecer",
    "enegrecêsseis": "enegrecer",
    "enegrecêssemos": "enegrecer",
    "enegrecíamo": "enegrecer",
    "enegrecíamos": "enegrecer",
    "enegrecíei": "enegrecer",
    "enegrecíeis": "enegrecer",
    "enegreça": "enegrecer",
    "enegreçais": "enegrecer",
    "enegreçam": "enegrecer",
    "enegreçamo": "enegrecer",
    "enegreçamos": "enegrecer",
    "enegreças": "enegrecer",
    "enegreço": "enegrecer",
    "eneolítica": "eneolítico",
    "eneolíticas": "eneolítico",
    "eneolíticos": "eneolítico",
    "enequins": "enequim",
    "energetismos": "energetismo",
    "energias": "energia",
    "energética": "energético",
    "energéticas": "energético",
    "energéticos": "energético",
    "energídios": "energídio",
    "energúmena": "energúmeno",
    "energúmenas": "energúmeno",
    "energúmenos": "energúmeno",
    "enerva": "enervar",
    "enervada": "enervar",
    "enervadas": "enervar",
    "enervado": "enervar",
    "enervados": "enervar",
    "enervadíssima": "enervado",
    "enervadíssimas": "enervado",
    "enervadíssimo": "enervado",
    "enervadíssimos": "enervado",
    "enervai": "enervar",
    "enervais": "enervar",
    "enervam": "enervar",
    "enervamentos": "enervamento",
    "enervamo": "enervar",
    "enervamos": "enervar",
    "enervando": "enervar",
    "enervantes": "enervante",
    "enervara": "enervar",
    "enervaram": "enervar",
    "enervaras": "enervar",
    "enervarde": "enervar",
    "enervardes": "enervar",
    "enervare": "enervar",
    "enervarei": "enervar",
    "enervareis": "enervar",
    "enervarem": "enervar",
    "enervaremos": "enervar",
    "enervares": "enervar",
    "enervaria": "enervar",
    "enervariam": "enervar",
    "enervarias": "enervar",
    "enervarmo": "enervar",
    "enervarmos": "enervar",
    "enervará": "enervar",
    "enervarás": "enervar",
    "enervarão": "enervar",
    "enervaríamos": "enervar",
    "enervaríeis": "enervar",
    "enervas": "enervar",
    "enervasse": "enervar",
    "enervassem": "enervar",
    "enervasses": "enervar",
    "enervaste": "enervar",
    "enervastes": "enervar",
    "enervava": "enervar",
    "enervavam": "enervar",
    "enervavas": "enervar",
    "enervações": "enervação",
    "enerve": "enervar",
    "enervei": "enervar",
    "enerveis": "enervar",
    "enervem": "enervar",
    "enervemo": "enervar",
    "enervemos": "enervar",
    "enerves": "enervar",
    "enervo": "enervar",
    "enervou": "enervar",
    "enervá": "enervar",
    "enervámo": "enervar",
    "enervámos": "enervar",
    "enerváramo": "enervar",
    "enerváramos": "enervar",
    "enervárei": "enervar",
    "enerváreis": "enervar",
    "enervásseis": "enervar",
    "enervássemos": "enervar",
    "enervávamo": "enervar",
    "enervávamos": "enervar",
    "enervávei": "enervar",
    "enerváveis": "enervar",
    "enes": "ene",
    "enesga": "enesgar",
    "enesgada": "enesgar",
    "enesgadas": "enesgar",
    "enesgado": "enesgar",
    "enesgados": "enesgar",
    "enesgai": "enesgar",
    "enesgais": "enesgar",
    "enesgam": "enesgar",
    "enesgamo": "enesgar",
    "enesgamos": "enesgar",
    "enesgando": "enesgar",
    "enesgara": "enesgar",
    "enesgaram": "enesgar",
    "enesgaras": "enesgar",
    "enesgarde": "enesgar",
    "enesgardes": "enesgar",
    "enesgare": "enesgar",
    "enesgarei": "enesgar",
    "enesgareis": "enesgar",
    "enesgarem": "enesgar",
    "enesgaremos": "enesgar",
    "enesgares": "enesgar",
    "enesgaria": "enesgar",
    "enesgariam": "enesgar",
    "enesgarias": "enesgar",
    "enesgarmo": "enesgar",
    "enesgarmos": "enesgar",
    "enesgará": "enesgar",
    "enesgarás": "enesgar",
    "enesgarão": "enesgar",
    "enesgaríamos": "enesgar",
    "enesgaríeis": "enesgar",
    "enesgas": "enesgar",
    "enesgasse": "enesgar",
    "enesgassem": "enesgar",
    "enesgasses": "enesgar",
    "enesgaste": "enesgar",
    "enesgastes": "enesgar",
    "enesgava": "enesgar",
    "enesgavam": "enesgar",
    "enesgavas": "enesgar",
    "enesgo": "enesgar",
    "enesgou": "enesgar",
    "enesgue": "enesgar",
    "enesguei": "enesgar",
    "enesgueis": "enesgar",
    "enesguem": "enesgar",
    "enesguemo": "enesgar",
    "enesguemos": "enesgar",
    "enesgues": "enesgar",
    "enesgá": "enesgar",
    "enesgámo": "enesgar",
    "enesgámos": "enesgar",
    "enesgáramo": "enesgar",
    "enesgáramos": "enesgar",
    "enesgárei": "enesgar",
    "enesgáreis": "enesgar",
    "enesgásseis": "enesgar",
    "enesgássemos": "enesgar",
    "enesgávamo": "enesgar",
    "enesgávamos": "enesgar",
    "enesgávei": "enesgar",
    "enesgáveis": "enesgar",
    "enevoa": "enevoar",
    "enevoada": "enevoar",
    "enevoadas": "enevoar",
    "enevoado": "enevoar",
    "enevoados": "enevoar",
    "enevoai": "enevoar",
    "enevoais": "enevoar",
    "enevoam": "enevoar",
    "enevoamentos": "enevoamento",
    "enevoamo": "enevoar",
    "enevoamos": "enevoar",
    "enevoando": "enevoar",
    "enevoara": "enevoar",
    "enevoaram": "enevoar",
    "enevoaras": "enevoar",
    "enevoardes": "enevoar",
    "enevoarei": "enevoar",
    "enevoareis": "enevoar",
    "enevoarem": "enevoar",
    "enevoaremos": "enevoar",
    "enevoares": "enevoar",
    "enevoaria": "enevoar",
    "enevoariam": "enevoar",
    "enevoarias": "enevoar",
    "enevoarmo": "enevoar",
    "enevoarmos": "enevoar",
    "enevoará": "enevoar",
    "enevoarás": "enevoar",
    "enevoarão": "enevoar",
    "enevoaríamos": "enevoar",
    "enevoaríeis": "enevoar",
    "enevoas": "enevoar",
    "enevoasse": "enevoar",
    "enevoassem": "enevoar",
    "enevoasses": "enevoar",
    "enevoaste": "enevoar",
    "enevoastes": "enevoar",
    "enevoava": "enevoar",
    "enevoavam": "enevoar",
    "enevoavas": "enevoar",
    "enevoe": "enevoar",
    "enevoei": "enevoar",
    "enevoeis": "enevoar",
    "enevoem": "enevoar",
    "enevoemo": "enevoar",
    "enevoemos": "enevoar",
    "enevoes": "enevoar",
    "enevoo": "enevoar",
    "enevoou": "enevoar",
    "enevoámo": "enevoar",
    "enevoámos": "enevoar",
    "enevoáramo": "enevoar",
    "enevoáramos": "enevoar",
    "enevoáreis": "enevoar",
    "enevoásseis": "enevoar",
    "enevoássemos": "enevoar",
    "enevoávamo": "enevoar",
    "enevoávamos": "enevoar",
    "enevoáveis": "enevoar",
    "eneágina": "eneágino",
    "eneáginas": "eneágino",
    "eneáginos": "eneágino",
    "eneágonos": "eneágono",
    "eneândrias": "eneândria",
    "eneândrica": "eneândrico",
    "eneândricas": "eneândrico",
    "eneândricos": "eneândrico",
    "enfada": "enfadar",
    "enfadada": "enfadar",
    "enfadadas": "enfadar",
    "enfadadiça": "enfadadiço",
    "enfadadiças": "enfadadiço",
    "enfadadiços": "enfadadiço",
    "enfadado": "enfadar",
    "enfadados": "enfadar",
    "enfadadíssima": "enfadado",
    "enfadadíssimas": "enfadado",
    "enfadadíssimo": "enfadado",
    "enfadadíssimos": "enfadado",
    "enfadai": "enfadar",
    "enfadais": "enfadar",
    "enfadam": "enfadar",
    "enfadamentos": "enfadamento",
    "enfadamo": "enfadar",
    "enfadamos": "enfadar",
    "enfadando": "enfadar",
    "enfadara": "enfadar",
    "enfadaram": "enfadar",
    "enfadaras": "enfadar",
    "enfadarde": "enfadar",
    "enfadardes": "enfadar",
    "enfadare": "enfadar",
    "enfadarei": "enfadar",
    "enfadareis": "enfadar",
    "enfadarem": "enfadar",
    "enfadaremos": "enfadar",
    "enfadares": "enfadar",
    "enfadaria": "enfadar",
    "enfadariam": "enfadar",
    "enfadarias": "enfadar",
    "enfadarmo": "enfadar",
    "enfadarmos": "enfadar",
    "enfadará": "enfadar",
    "enfadarás": "enfadar",
    "enfadarão": "enfadar",
    "enfadaríamos": "enfadar",
    "enfadaríeis": "enfadar",
    "enfadas": "enfadar",
    "enfadasse": "enfadar",
    "enfadassem": "enfadar",
    "enfadasses": "enfadar",
    "enfadaste": "enfadar",
    "enfadastes": "enfadar",
    "enfadava": "enfadar",
    "enfadavam": "enfadar",
    "enfadavas": "enfadar",
    "enfade": "enfadar",
    "enfadei": "enfadar",
    "enfadeis": "enfadar",
    "enfadem": "enfadar",
    "enfademo": "enfadar",
    "enfademos": "enfadar",
    "enfades": "enfadar",
    "enfado": "enfadar",
    "enfadonha": "enfadonho",
    "enfadonhas": "enfadonho",
    "enfadonhos": "enfadonho",
    "enfados": "enfado",
    "enfadou": "enfadar",
    "enfadá": "enfadar",
    "enfadámo": "enfadar",
    "enfadámos": "enfadar",
    "enfadáramo": "enfadar",
    "enfadáramos": "enfadar",
    "enfadárei": "enfadar",
    "enfadáreis": "enfadar",
    "enfadásseis": "enfadar",
    "enfadássemos": "enfadar",
    "enfadávamo": "enfadar",
    "enfadávamos": "enfadar",
    "enfadávei": "enfadar",
    "enfadáveis": "enfadar",
    "enfaixa": "enfaixar",
    "enfaixada": "enfaixar",
    "enfaixadas": "enfaixar",
    "enfaixado": "enfaixar",
    "enfaixados": "enfaixar",
    "enfaixai": "enfaixar",
    "enfaixais": "enfaixar",
    "enfaixam": "enfaixar",
    "enfaixamentos": "enfaixamento",
    "enfaixamo": "enfaixar",
    "enfaixamos": "enfaixar",
    "enfaixando": "enfaixar",
    "enfaixara": "enfaixar",
    "enfaixaram": "enfaixar",
    "enfaixaras": "enfaixar",
    "enfaixarde": "enfaixar",
    "enfaixardes": "enfaixar",
    "enfaixare": "enfaixar",
    "enfaixarei": "enfaixar",
    "enfaixareis": "enfaixar",
    "enfaixarem": "enfaixar",
    "enfaixaremos": "enfaixar",
    "enfaixares": "enfaixar",
    "enfaixaria": "enfaixar",
    "enfaixariam": "enfaixar",
    "enfaixarias": "enfaixar",
    "enfaixarmo": "enfaixar",
    "enfaixarmos": "enfaixar",
    "enfaixará": "enfaixar",
    "enfaixarás": "enfaixar",
    "enfaixarão": "enfaixar",
    "enfaixaríamos": "enfaixar",
    "enfaixaríeis": "enfaixar",
    "enfaixas": "enfaixar",
    "enfaixasse": "enfaixar",
    "enfaixassem": "enfaixar",
    "enfaixasses": "enfaixar",
    "enfaixaste": "enfaixar",
    "enfaixastes": "enfaixar",
    "enfaixava": "enfaixar",
    "enfaixavam": "enfaixar",
    "enfaixavas": "enfaixar",
    "enfaixe": "enfaixar",
    "enfaixei": "enfaixar",
    "enfaixeis": "enfaixar",
    "enfaixem": "enfaixar",
    "enfaixemo": "enfaixar",
    "enfaixemos": "enfaixar",
    "enfaixes": "enfaixe",
    "enfaixo": "enfaixar",
    "enfaixou": "enfaixar",
    "enfaixá": "enfaixar",
    "enfaixámo": "enfaixar",
    "enfaixámos": "enfaixar",
    "enfaixáramo": "enfaixar",
    "enfaixáramos": "enfaixar",
    "enfaixárei": "enfaixar",
    "enfaixáreis": "enfaixar",
    "enfaixásseis": "enfaixar",
    "enfaixássemos": "enfaixar",
    "enfaixávamo": "enfaixar",
    "enfaixávamos": "enfaixar",
    "enfaixávei": "enfaixar",
    "enfaixáveis": "enfaixar",
    "enfanica": "enfanicar",
    "enfanicada": "enfanicar",
    "enfanicadas": "enfanicar",
    "enfanicado": "enfanicar",
    "enfanicados": "enfanicar",
    "enfanicai": "enfanicar",
    "enfanicais": "enfanicar",
    "enfanicam": "enfanicar",
    "enfanicamo": "enfanicar",
    "enfanicamos": "enfanicar",
    "enfanicando": "enfanicar",
    "enfanicara": "enfanicar",
    "enfanicaram": "enfanicar",
    "enfanicaras": "enfanicar",
    "enfanicarde": "enfanicar",
    "enfanicardes": "enfanicar",
    "enfanicare": "enfanicar",
    "enfanicarei": "enfanicar",
    "enfanicareis": "enfanicar",
    "enfanicarem": "enfanicar",
    "enfanicaremos": "enfanicar",
    "enfanicares": "enfanicar",
    "enfanicaria": "enfanicar",
    "enfanicariam": "enfanicar",
    "enfanicarias": "enfanicar",
    "enfanicarmo": "enfanicar",
    "enfanicarmos": "enfanicar",
    "enfanicará": "enfanicar",
    "enfanicarás": "enfanicar",
    "enfanicarão": "enfanicar",
    "enfanicaríamos": "enfanicar",
    "enfanicaríeis": "enfanicar",
    "enfanicas": "enfanicar",
    "enfanicasse": "enfanicar",
    "enfanicassem": "enfanicar",
    "enfanicasses": "enfanicar",
    "enfanicaste": "enfanicar",
    "enfanicastes": "enfanicar",
    "enfanicava": "enfanicar",
    "enfanicavam": "enfanicar",
    "enfanicavas": "enfanicar",
    "enfanico": "enfanicar",
    "enfanicos": "enfanico",
    "enfanicou": "enfanicar",
    "enfanicá": "enfanicar",
    "enfanicámo": "enfanicar",
    "enfanicámos": "enfanicar",
    "enfanicáramo": "enfanicar",
    "enfanicáramos": "enfanicar",
    "enfanicárei": "enfanicar",
    "enfanicáreis": "enfanicar",
    "enfanicásseis": "enfanicar",
    "enfanicássemos": "enfanicar",
    "enfanicávamo": "enfanicar",
    "enfanicávamos": "enfanicar",
    "enfanicávei": "enfanicar",
    "enfanicáveis": "enfanicar",
    "enfanique": "enfanicar",
    "enfaniquei": "enfanicar",
    "enfaniqueis": "enfanicar",
    "enfaniquem": "enfanicar",
    "enfaniquemo": "enfanicar",
    "enfaniquemos": "enfanicar",
    "enfaniques": "enfanicar",
    "enfara": "enfarar",
    "enfarada": "enfarar",
    "enfaradas": "enfarar",
    "enfarado": "enfarar",
    "enfarados": "enfarar",
    "enfarai": "enfarar",
    "enfarais": "enfarar",
    "enfaram": "enfarar",
    "enfaramo": "enfarar",
    "enfaramos": "enfarar",
    "enfarando": "enfarar",
    "enfarara": "enfarar",
    "enfararam": "enfarar",
    "enfararas": "enfarar",
    "enfararde": "enfarar",
    "enfarardes": "enfarar",
    "enfarare": "enfarar",
    "enfararei": "enfarar",
    "enfarareis": "enfarar",
    "enfararem": "enfarar",
    "enfararemos": "enfarar",
    "enfarares": "enfarar",
    "enfararia": "enfarar",
    "enfarariam": "enfarar",
    "enfararias": "enfarar",
    "enfararmo": "enfarar",
    "enfararmos": "enfarar",
    "enfarará": "enfarar",
    "enfararás": "enfarar",
    "enfararão": "enfarar",
    "enfararíamos": "enfarar",
    "enfararíeis": "enfarar",
    "enfaras": "enfarar",
    "enfarasse": "enfarar",
    "enfarassem": "enfarar",
    "enfarasses": "enfarar",
    "enfaraste": "enfarar",
    "enfarastes": "enfarar",
    "enfarava": "enfarar",
    "enfaravam": "enfarar",
    "enfaravas": "enfarar",
    "enfarda": "enfardar",
    "enfardada": "enfardar",
    "enfardadas": "enfardar",
    "enfardadeiras": "enfardadeira",
    "enfardado": "enfardar",
    "enfardadora": "enfardador",
    "enfardadoras": "enfardador",
    "enfardadores": "enfardador",
    "enfardados": "enfardar",
    "enfardai": "enfardar",
    "enfardais": "enfardar",
    "enfardam": "enfardar",
    "enfardamentos": "enfardamento",
    "enfardamo": "enfardar",
    "enfardamos": "enfardar",
    "enfardando": "enfardar",
    "enfardara": "enfardar",
    "enfardaram": "enfardar",
    "enfardaras": "enfardar",
    "enfardarde": "enfardar",
    "enfardardes": "enfardar",
    "enfardare": "enfardar",
    "enfardarei": "enfardar",
    "enfardareis": "enfardar",
    "enfardarem": "enfardar",
    "enfardaremos": "enfardar",
    "enfardares": "enfardar",
    "enfardaria": "enfardar",
    "enfardariam": "enfardar",
    "enfardarias": "enfardar",
    "enfardarmo": "enfardar",
    "enfardarmos": "enfardar",
    "enfardará": "enfardar",
    "enfardarás": "enfardar",
    "enfardarão": "enfardar",
    "enfardaríamos": "enfardar",
    "enfardaríeis": "enfardar",
    "enfardas": "enfardar",
    "enfardasse": "enfardar",
    "enfardassem": "enfardar",
    "enfardasses": "enfardar",
    "enfardaste": "enfardar",
    "enfardastes": "enfardar",
    "enfardava": "enfardar",
    "enfardavam": "enfardar",
    "enfardavas": "enfardar",
    "enfarde": "enfardar",
    "enfardei": "enfardar",
    "enfardeis": "enfardar",
    "enfardela": "enfardelar",
    "enfardelada": "enfardelar",
    "enfardeladas": "enfardelar",
    "enfardelado": "enfardelar",
    "enfardelados": "enfardelar",
    "enfardelai": "enfardelar",
    "enfardelais": "enfardelar",
    "enfardelam": "enfardelar",
    "enfardelamo": "enfardelar",
    "enfardelamos": "enfardelar",
    "enfardelando": "enfardelar",
    "enfardelara": "enfardelar",
    "enfardelaram": "enfardelar",
    "enfardelaras": "enfardelar",
    "enfardelarde": "enfardelar",
    "enfardelardes": "enfardelar",
    "enfardelare": "enfardelar",
    "enfardelarei": "enfardelar",
    "enfardelareis": "enfardelar",
    "enfardelarem": "enfardelar",
    "enfardelaremos": "enfardelar",
    "enfardelares": "enfardelar",
    "enfardelaria": "enfardelar",
    "enfardelariam": "enfardelar",
    "enfardelarias": "enfardelar",
    "enfardelarmo": "enfardelar",
    "enfardelarmos": "enfardelar",
    "enfardelará": "enfardelar",
    "enfardelarás": "enfardelar",
    "enfardelarão": "enfardelar",
    "enfardelaríamos": "enfardelar",
    "enfardelaríeis": "enfardelar",
    "enfardelas": "enfardelar",
    "enfardelasse": "enfardelar",
    "enfardelassem": "enfardelar",
    "enfardelasses": "enfardelar",
    "enfardelaste": "enfardelar",
    "enfardelastes": "enfardelar",
    "enfardelava": "enfardelar",
    "enfardelavam": "enfardelar",
    "enfardelavas": "enfardelar",
    "enfardele": "enfardelar",
    "enfardelei": "enfardelar",
    "enfardeleis": "enfardelar",
    "enfardelem": "enfardelar",
    "enfardelemo": "enfardelar",
    "enfardelemos": "enfardelar",
    "enfardeles": "enfardelar",
    "enfardelo": "enfardelar",
    "enfardelou": "enfardelar",
    "enfardelá": "enfardelar",
    "enfardelámo": "enfardelar",
    "enfardelámos": "enfardelar",
    "enfardeláramo": "enfardelar",
    "enfardeláramos": "enfardelar",
    "enfardelárei": "enfardelar",
    "enfardeláreis": "enfardelar",
    "enfardelásseis": "enfardelar",
    "enfardelássemos": "enfardelar",
    "enfardelávamo": "enfardelar",
    "enfardelávamos": "enfardelar",
    "enfardelávei": "enfardelar",
    "enfardeláveis": "enfardelar",
    "enfardem": "enfardar",
    "enfardemo": "enfardar",
    "enfardemos": "enfardar",
    "enfardes": "enfardar",
    "enfardo": "enfardar",
    "enfardou": "enfardar",
    "enfardá": "enfardar",
    "enfardámo": "enfardar",
    "enfardámos": "enfardar",
    "enfardáramo": "enfardar",
    "enfardáramos": "enfardar",
    "enfardárei": "enfardar",
    "enfardáreis": "enfardar",
    "enfardásseis": "enfardar",
    "enfardássemos": "enfardar",
    "enfardávamo": "enfardar",
    "enfardávamos": "enfardar",
    "enfardávei": "enfardar",
    "enfardáveis": "enfardar",
    "enfare": "enfarar",
    "enfareada": "enfarear",
    "enfareadas": "enfarear",
    "enfareado": "enfarear",
    "enfareados": "enfarear",
    "enfareai": "enfarear",
    "enfareais": "enfarear",
    "enfareamo": "enfarear",
    "enfareamos": "enfarear",
    "enfareando": "enfarear",
    "enfareara": "enfarear",
    "enfarearam": "enfarear",
    "enfarearas": "enfarear",
    "enfarearde": "enfarear",
    "enfareardes": "enfarear",
    "enfareare": "enfarear",
    "enfarearei": "enfarear",
    "enfareareis": "enfarear",
    "enfarearem": "enfarear",
    "enfarearemos": "enfarear",
    "enfareares": "enfarear",
    "enfarearia": "enfarear",
    "enfareariam": "enfarear",
    "enfarearias": "enfarear",
    "enfarearmo": "enfarear",
    "enfarearmos": "enfarear",
    "enfareará": "enfarear",
    "enfarearás": "enfarear",
    "enfarearão": "enfarear",
    "enfarearíamos": "enfarear",
    "enfarearíeis": "enfarear",
    "enfareasse": "enfarear",
    "enfareassem": "enfarear",
    "enfareasses": "enfarear",
    "enfareaste": "enfarear",
    "enfareastes": "enfarear",
    "enfareava": "enfarear",
    "enfareavam": "enfarear",
    "enfareavas": "enfarear",
    "enfareei": "enfarear",
    "enfareeis": "enfarear",
    "enfareemo": "enfarear",
    "enfareemos": "enfarear",
    "enfarei": "enfarar",
    "enfareia": "enfarear",
    "enfareiam": "enfarear",
    "enfareias": "enfarear",
    "enfareie": "enfarear",
    "enfareiem": "enfarear",
    "enfareies": "enfarear",
    "enfareio": "enfarear",
    "enfareis": "enfarar",
    "enfarela": "enfarelar",
    "enfarelada": "enfarelar",
    "enfareladas": "enfarelar",
    "enfarelado": "enfarelar",
    "enfarelados": "enfarelar",
    "enfarelai": "enfarelar",
    "enfarelais": "enfarelar",
    "enfarelam": "enfarelar",
    "enfarelamo": "enfarelar",
    "enfarelamos": "enfarelar",
    "enfarelando": "enfarelar",
    "enfarelara": "enfarelar",
    "enfarelaram": "enfarelar",
    "enfarelaras": "enfarelar",
    "enfarelarde": "enfarelar",
    "enfarelardes": "enfarelar",
    "enfarelare": "enfarelar",
    "enfarelarei": "enfarelar",
    "enfarelareis": "enfarelar",
    "enfarelarem": "enfarelar",
    "enfarelaremos": "enfarelar",
    "enfarelares": "enfarelar",
    "enfarelaria": "enfarelar",
    "enfarelariam": "enfarelar",
    "enfarelarias": "enfarelar",
    "enfarelarmo": "enfarelar",
    "enfarelarmos": "enfarelar",
    "enfarelará": "enfarelar",
    "enfarelarás": "enfarelar",
    "enfarelarão": "enfarelar",
    "enfarelaríamos": "enfarelar",
    "enfarelaríeis": "enfarelar",
    "enfarelas": "enfarelar",
    "enfarelasse": "enfarelar",
    "enfarelassem": "enfarelar",
    "enfarelasses": "enfarelar",
    "enfarelaste": "enfarelar",
    "enfarelastes": "enfarelar",
    "enfarelava": "enfarelar",
    "enfarelavam": "enfarelar",
    "enfarelavas": "enfarelar",
    "enfarele": "enfarelar",
    "enfarelei": "enfarelar",
    "enfareleis": "enfarelar",
    "enfarelem": "enfarelar",
    "enfarelemo": "enfarelar",
    "enfarelemos": "enfarelar",
    "enfareles": "enfarelar",
    "enfarelo": "enfarelar",
    "enfarelou": "enfarelar",
    "enfarelá": "enfarelar",
    "enfarelámo": "enfarelar",
    "enfarelámos": "enfarelar",
    "enfareláramo": "enfarelar",
    "enfareláramos": "enfarelar",
    "enfarelárei": "enfarelar",
    "enfareláreis": "enfarelar",
    "enfarelásseis": "enfarelar",
    "enfarelássemos": "enfarelar",
    "enfarelávamo": "enfarelar",
    "enfarelávamos": "enfarelar",
    "enfarelávei": "enfarelar",
    "enfareláveis": "enfarelar",
    "enfarem": "enfarar",
    "enfaremo": "enfarar",
    "enfaremos": "enfarar",
    "enfareou": "enfarear",
    "enfares": "enfarar",
    "enfareá": "enfarear",
    "enfareámo": "enfarear",
    "enfareámos": "enfarear",
    "enfareáramo": "enfarear",
    "enfareáramos": "enfarear",
    "enfareárei": "enfarear",
    "enfareáreis": "enfarear",
    "enfareásseis": "enfarear",
    "enfareássemos": "enfarear",
    "enfareávamo": "enfarear",
    "enfareávamos": "enfarear",
    "enfareávei": "enfarear",
    "enfareáveis": "enfarear",
    "enfarinha": "enfarinhar",
    "enfarinhada": "enfarinhar",
    "enfarinhadas": "enfarinhar",
    "enfarinhadelas": "enfarinhadela",
    "enfarinhado": "enfarinhar",
    "enfarinhados": "enfarinhar",
    "enfarinhai": "enfarinhar",
    "enfarinhais": "enfarinhar",
    "enfarinham": "enfarinhar",
    "enfarinhamentos": "enfarinhamento",
    "enfarinhamo": "enfarinhar",
    "enfarinhamos": "enfarinhar",
    "enfarinhando": "enfarinhar",
    "enfarinhara": "enfarinhar",
    "enfarinharam": "enfarinhar",
    "enfarinharas": "enfarinhar",
    "enfarinharde": "enfarinhar",
    "enfarinhardes": "enfarinhar",
    "enfarinhare": "enfarinhar",
    "enfarinharei": "enfarinhar",
    "enfarinhareis": "enfarinhar",
    "enfarinharem": "enfarinhar",
    "enfarinharemos": "enfarinhar",
    "enfarinhares": "enfarinhar",
    "enfarinharia": "enfarinhar",
    "enfarinhariam": "enfarinhar",
    "enfarinharias": "enfarinhar",
    "enfarinharmo": "enfarinhar",
    "enfarinharmos": "enfarinhar",
    "enfarinhará": "enfarinhar",
    "enfarinharás": "enfarinhar",
    "enfarinharão": "enfarinhar",
    "enfarinharíamos": "enfarinhar",
    "enfarinharíeis": "enfarinhar",
    "enfarinhas": "enfarinhar",
    "enfarinhasse": "enfarinhar",
    "enfarinhassem": "enfarinhar",
    "enfarinhasses": "enfarinhar",
    "enfarinhaste": "enfarinhar",
    "enfarinhastes": "enfarinhar",
    "enfarinhava": "enfarinhar",
    "enfarinhavam": "enfarinhar",
    "enfarinhavas": "enfarinhar",
    "enfarinhe": "enfarinhar",
    "enfarinhei": "enfarinhar",
    "enfarinheis": "enfarinhar",
    "enfarinhem": "enfarinhar",
    "enfarinhemo": "enfarinhar",
    "enfarinhemos": "enfarinhar",
    "enfarinhes": "enfarinhar",
    "enfarinho": "enfarinhar",
    "enfarinhou": "enfarinhar",
    "enfarinhá": "enfarinhar",
    "enfarinhámo": "enfarinhar",
    "enfarinhámos": "enfarinhar",
    "enfarinháramo": "enfarinhar",
    "enfarinháramos": "enfarinhar",
    "enfarinhárei": "enfarinhar",
    "enfarinháreis": "enfarinhar",
    "enfarinhásseis": "enfarinhar",
    "enfarinhássemos": "enfarinhar",
    "enfarinhávamo": "enfarinhar",
    "enfarinhávamos": "enfarinhar",
    "enfarinhávei": "enfarinhar",
    "enfarinháveis": "enfarinhar",
    "enfaro": "enfarar",
    "enfaroa": "enfaroar",
    "enfaroada": "enfaroar",
    "enfaroadas": "enfaroar",
    "enfaroado": "enfaroar",
    "enfaroados": "enfaroar",
    "enfaroai": "enfaroar",
    "enfaroais": "enfaroar",
    "enfaroam": "enfaroar",
    "enfaroamo": "enfaroar",
    "enfaroamos": "enfaroar",
    "enfaroando": "enfaroar",
    "enfaroara": "enfaroar",
    "enfaroaram": "enfaroar",
    "enfaroaras": "enfaroar",
    "enfaroarde": "enfaroar",
    "enfaroardes": "enfaroar",
    "enfaroare": "enfaroar",
    "enfaroarei": "enfaroar",
    "enfaroareis": "enfaroar",
    "enfaroarem": "enfaroar",
    "enfaroaremos": "enfaroar",
    "enfaroares": "enfaroar",
    "enfaroaria": "enfaroar",
    "enfaroariam": "enfaroar",
    "enfaroarias": "enfaroar",
    "enfaroarmo": "enfaroar",
    "enfaroarmos": "enfaroar",
    "enfaroará": "enfaroar",
    "enfaroarás": "enfaroar",
    "enfaroarão": "enfaroar",
    "enfaroaríamos": "enfaroar",
    "enfaroaríeis": "enfaroar",
    "enfaroas": "enfaroar",
    "enfaroasse": "enfaroar",
    "enfaroassem": "enfaroar",
    "enfaroasses": "enfaroar",
    "enfaroaste": "enfaroar",
    "enfaroastes": "enfaroar",
    "enfaroava": "enfaroar",
    "enfaroavam": "enfaroar",
    "enfaroavas": "enfaroar",
    "enfaroe": "enfaroar",
    "enfaroei": "enfaroar",
    "enfaroeis": "enfaroar",
    "enfaroem": "enfaroar",
    "enfaroemo": "enfaroar",
    "enfaroemos": "enfaroar",
    "enfaroes": "enfaroar",
    "enfaroo": "enfaroar",
    "enfaroou": "enfaroar",
    "enfarou": "enfarar",
    "enfaroá": "enfaroar",
    "enfaroámo": "enfaroar",
    "enfaroámos": "enfaroar",
    "enfaroáramo": "enfaroar",
    "enfaroáramos": "enfaroar",
    "enfaroárei": "enfaroar",
    "enfaroáreis": "enfaroar",
    "enfaroásseis": "enfaroar",
    "enfaroássemos": "enfaroar",
    "enfaroávamo": "enfaroar",
    "enfaroávamos": "enfaroar",
    "enfaroávei": "enfaroar",
    "enfaroáveis": "enfaroar",
    "enfarpela": "enfarpelar",
    "enfarpelada": "enfarpelar",
    "enfarpeladas": "enfarpelar",
    "enfarpelado": "enfarpelar",
    "enfarpelados": "enfarpelar",
    "enfarpelai": "enfarpelar",
    "enfarpelais": "enfarpelar",
    "enfarpelam": "enfarpelar",
    "enfarpelamo": "enfarpelar",
    "enfarpelamos": "enfarpelar",
    "enfarpelando": "enfarpelar",
    "enfarpelara": "enfarpelar",
    "enfarpelaram": "enfarpelar",
    "enfarpelaras": "enfarpelar",
    "enfarpelarde": "enfarpelar",
    "enfarpelardes": "enfarpelar",
    "enfarpelare": "enfarpelar",
    "enfarpelarei": "enfarpelar",
    "enfarpelareis": "enfarpelar",
    "enfarpelarem": "enfarpelar",
    "enfarpelaremos": "enfarpelar",
    "enfarpelares": "enfarpelar",
    "enfarpelaria": "enfarpelar",
    "enfarpelariam": "enfarpelar",
    "enfarpelarias": "enfarpelar",
    "enfarpelarmo": "enfarpelar",
    "enfarpelarmos": "enfarpelar",
    "enfarpelará": "enfarpelar",
    "enfarpelarás": "enfarpelar",
    "enfarpelarão": "enfarpelar",
    "enfarpelaríamos": "enfarpelar",
    "enfarpelaríeis": "enfarpelar",
    "enfarpelas": "enfarpelar",
    "enfarpelasse": "enfarpelar",
    "enfarpelassem": "enfarpelar",
    "enfarpelasses": "enfarpelar",
    "enfarpelaste": "enfarpelar",
    "enfarpelastes": "enfarpelar",
    "enfarpelava": "enfarpelar",
    "enfarpelavam": "enfarpelar",
    "enfarpelavas": "enfarpelar",
    "enfarpele": "enfarpelar",
    "enfarpelei": "enfarpelar",
    "enfarpeleis": "enfarpelar",
    "enfarpelem": "enfarpelar",
    "enfarpelemo": "enfarpelar",
    "enfarpelemos": "enfarpelar",
    "enfarpeles": "enfarpelar",
    "enfarpelo": "enfarpelar",
    "enfarpelou": "enfarpelar",
    "enfarpelá": "enfarpelar",
    "enfarpelámo": "enfarpelar",
    "enfarpelámos": "enfarpelar",
    "enfarpeláramo": "enfarpelar",
    "enfarpeláramos": "enfarpelar",
    "enfarpelárei": "enfarpelar",
    "enfarpeláreis": "enfarpelar",
    "enfarpelásseis": "enfarpelar",
    "enfarpelássemos": "enfarpelar",
    "enfarpelávamo": "enfarpelar",
    "enfarpelávamos": "enfarpelar",
    "enfarpelávei": "enfarpelar",
    "enfarpeláveis": "enfarpelar",
    "enfarrapa": "enfarrapar",
    "enfarrapada": "enfarrapar",
    "enfarrapadas": "enfarrapar",
    "enfarrapado": "enfarrapar",
    "enfarrapados": "enfarrapar",
    "enfarrapai": "enfarrapar",
    "enfarrapais": "enfarrapar",
    "enfarrapam": "enfarrapar",
    "enfarrapamo": "enfarrapar",
    "enfarrapamos": "enfarrapar",
    "enfarrapando": "enfarrapar",
    "enfarrapara": "enfarrapar",
    "enfarraparam": "enfarrapar",
    "enfarraparas": "enfarrapar",
    "enfarraparde": "enfarrapar",
    "enfarrapardes": "enfarrapar",
    "enfarrapare": "enfarrapar",
    "enfarraparei": "enfarrapar",
    "enfarrapareis": "enfarrapar",
    "enfarraparem": "enfarrapar",
    "enfarraparemos": "enfarrapar",
    "enfarrapares": "enfarrapar",
    "enfarraparia": "enfarrapar",
    "enfarrapariam": "enfarrapar",
    "enfarraparias": "enfarrapar",
    "enfarraparmo": "enfarrapar",
    "enfarraparmos": "enfarrapar",
    "enfarrapará": "enfarrapar",
    "enfarraparás": "enfarrapar",
    "enfarraparão": "enfarrapar",
    "enfarraparíamos": "enfarrapar",
    "enfarraparíeis": "enfarrapar",
    "enfarrapas": "enfarrapar",
    "enfarrapasse": "enfarrapar",
    "enfarrapassem": "enfarrapar",
    "enfarrapasses": "enfarrapar",
    "enfarrapaste": "enfarrapar",
    "enfarrapastes": "enfarrapar",
    "enfarrapava": "enfarrapar",
    "enfarrapavam": "enfarrapar",
    "enfarrapavas": "enfarrapar",
    "enfarrape": "enfarrapar",
    "enfarrapei": "enfarrapar",
    "enfarrapeis": "enfarrapar",
    "enfarrapem": "enfarrapar",
    "enfarrapemo": "enfarrapar",
    "enfarrapemos": "enfarrapar",
    "enfarrapes": "enfarrapar",
    "enfarrapo": "enfarrapar",
    "enfarrapou": "enfarrapar",
    "enfarrapá": "enfarrapar",
    "enfarrapámo": "enfarrapar",
    "enfarrapámos": "enfarrapar",
    "enfarrapáramo": "enfarrapar",
    "enfarrapáramos": "enfarrapar",
    "enfarrapárei": "enfarrapar",
    "enfarrapáreis": "enfarrapar",
    "enfarrapásseis": "enfarrapar",
    "enfarrapássemos": "enfarrapar",
    "enfarrapávamo": "enfarrapar",
    "enfarrapávamos": "enfarrapar",
    "enfarrapávei": "enfarrapar",
    "enfarrapáveis": "enfarrapar",
    "enfarripada": "enfarripado",
    "enfarripadas": "enfarripado",
    "enfarripados": "enfarripado",
    "enfarrusca": "enfarruscar",
    "enfarruscada": "enfarruscar",
    "enfarruscadas": "enfarruscar",
    "enfarruscado": "enfarruscar",
    "enfarruscados": "enfarruscar",
    "enfarruscai": "enfarruscar",
    "enfarruscais": "enfarruscar",
    "enfarruscam": "enfarruscar",
    "enfarruscamo": "enfarruscar",
    "enfarruscamos": "enfarruscar",
    "enfarruscando": "enfarruscar",
    "enfarruscara": "enfarruscar",
    "enfarruscaram": "enfarruscar",
    "enfarruscaras": "enfarruscar",
    "enfarruscarde": "enfarruscar",
    "enfarruscardes": "enfarruscar",
    "enfarruscare": "enfarruscar",
    "enfarruscarei": "enfarruscar",
    "enfarruscareis": "enfarruscar",
    "enfarruscarem": "enfarruscar",
    "enfarruscaremos": "enfarruscar",
    "enfarruscares": "enfarruscar",
    "enfarruscaria": "enfarruscar",
    "enfarruscariam": "enfarruscar",
    "enfarruscarias": "enfarruscar",
    "enfarruscarmo": "enfarruscar",
    "enfarruscarmos": "enfarruscar",
    "enfarruscará": "enfarruscar",
    "enfarruscarás": "enfarruscar",
    "enfarruscarão": "enfarruscar",
    "enfarruscaríamos": "enfarruscar",
    "enfarruscaríeis": "enfarruscar",
    "enfarruscas": "enfarruscar",
    "enfarruscasse": "enfarruscar",
    "enfarruscassem": "enfarruscar",
    "enfarruscasses": "enfarruscar",
    "enfarruscaste": "enfarruscar",
    "enfarruscastes": "enfarruscar",
    "enfarruscava": "enfarruscar",
    "enfarruscavam": "enfarruscar",
    "enfarruscavas": "enfarruscar",
    "enfarrusco": "enfarruscar",
    "enfarruscou": "enfarruscar",
    "enfarruscá": "enfarruscar",
    "enfarruscámo": "enfarruscar",
    "enfarruscámos": "enfarruscar",
    "enfarruscáramo": "enfarruscar",
    "enfarruscáramos": "enfarruscar",
    "enfarruscárei": "enfarruscar",
    "enfarruscáreis": "enfarruscar",
    "enfarruscásseis": "enfarruscar",
    "enfarruscássemos": "enfarruscar",
    "enfarruscávamo": "enfarruscar",
    "enfarruscávamos": "enfarruscar",
    "enfarruscávei": "enfarruscar",
    "enfarruscáveis": "enfarruscar",
    "enfarrusque": "enfarruscar",
    "enfarrusquei": "enfarruscar",
    "enfarrusqueis": "enfarruscar",
    "enfarrusquem": "enfarruscar",
    "enfarrusquemo": "enfarruscar",
    "enfarrusquemos": "enfarruscar",
    "enfarrusques": "enfarruscar",
    "enfarta": "enfartar",
    "enfartada": "enfartar",
    "enfartadas": "enfartar",
    "enfartado": "enfartar",
    "enfartados": "enfartar",
    "enfartai": "enfartar",
    "enfartais": "enfartar",
    "enfartam": "enfartar",
    "enfartamentos": "enfartamento",
    "enfartamo": "enfartar",
    "enfartamos": "enfartar",
    "enfartando": "enfartar",
    "enfartara": "enfartar",
    "enfartaram": "enfartar",
    "enfartaras": "enfartar",
    "enfartarde": "enfartar",
    "enfartardes": "enfartar",
    "enfartare": "enfartar",
    "enfartarei": "enfartar",
    "enfartareis": "enfartar",
    "enfartarem": "enfartar",
    "enfartaremos": "enfartar",
    "enfartares": "enfartar",
    "enfartaria": "enfartar",
    "enfartariam": "enfartar",
    "enfartarias": "enfartar",
    "enfartarmo": "enfartar",
    "enfartarmos": "enfartar",
    "enfartará": "enfartar",
    "enfartarás": "enfartar",
    "enfartarão": "enfartar",
    "enfartaríamos": "enfartar",
    "enfartaríeis": "enfartar",
    "enfartas": "enfartar",
    "enfartasse": "enfartar",
    "enfartassem": "enfartar",
    "enfartasses": "enfartar",
    "enfartaste": "enfartar",
    "enfartastes": "enfartar",
    "enfartava": "enfartar",
    "enfartavam": "enfartar",
    "enfartavas": "enfartar",
    "enfarte": "enfartar",
    "enfartei": "enfartar",
    "enfarteis": "enfartar",
    "enfartem": "enfartar",
    "enfartemo": "enfartar",
    "enfartemos": "enfartar",
    "enfartes": "enfarte",
    "enfarto": "enfartar",
    "enfartos": "enfarto",
    "enfartou": "enfartar",
    "enfartá": "enfartar",
    "enfartámo": "enfartar",
    "enfartámos": "enfartar",
    "enfartáramo": "enfartar",
    "enfartáramos": "enfartar",
    "enfartárei": "enfartar",
    "enfartáreis": "enfartar",
    "enfartásseis": "enfartar",
    "enfartássemos": "enfartar",
    "enfartávamo": "enfartar",
    "enfartávamos": "enfartar",
    "enfartávei": "enfartar",
    "enfartáveis": "enfartar",
    "enfará": "enfarar",
    "enfarámo": "enfarar",
    "enfarámos": "enfarar",
    "enfaráramo": "enfarar",
    "enfaráramos": "enfarar",
    "enfarárei": "enfarar",
    "enfaráreis": "enfarar",
    "enfarásseis": "enfarar",
    "enfarássemos": "enfarar",
    "enfarávamo": "enfarar",
    "enfarávamos": "enfarar",
    "enfarávei": "enfarar",
    "enfaráveis": "enfarar",
    "enfasa": "enfasar",
    "enfasada": "enfasar",
    "enfasadas": "enfasar",
    "enfasado": "enfasar",
    "enfasados": "enfasar",
    "enfasai": "enfasar",
    "enfasais": "enfasar",
    "enfasam": "enfasar",
    "enfasamentos": "enfasamento",
    "enfasamo": "enfasar",
    "enfasamos": "enfasar",
    "enfasando": "enfasar",
    "enfasara": "enfasar",
    "enfasaram": "enfasar",
    "enfasaras": "enfasar",
    "enfasarde": "enfasar",
    "enfasardes": "enfasar",
    "enfasare": "enfasar",
    "enfasarei": "enfasar",
    "enfasareis": "enfasar",
    "enfasarem": "enfasar",
    "enfasaremos": "enfasar",
    "enfasares": "enfasar",
    "enfasaria": "enfasar",
    "enfasariam": "enfasar",
    "enfasarias": "enfasar",
    "enfasarmo": "enfasar",
    "enfasarmos": "enfasar",
    "enfasará": "enfasar",
    "enfasarás": "enfasar",
    "enfasarão": "enfasar",
    "enfasaríamos": "enfasar",
    "enfasaríeis": "enfasar",
    "enfasas": "enfasar",
    "enfasasse": "enfasar",
    "enfasassem": "enfasar",
    "enfasasses": "enfasar",
    "enfasaste": "enfasar",
    "enfasastes": "enfasar",
    "enfasava": "enfasar",
    "enfasavam": "enfasar",
    "enfasavas": "enfasar",
    "enfase": "enfasar",
    "enfasei": "enfasar",
    "enfaseis": "enfasar",
    "enfasem": "enfasar",
    "enfasemo": "enfasar",
    "enfasemos": "enfasar",
    "enfases": "enfasar",
    "enfaso": "enfasar",
    "enfasou": "enfasar",
    "enfastia": "enfastiar",
    "enfastiada": "enfastiar",
    "enfastiadas": "enfastiar",
    "enfastiadiça": "enfastiadiço",
    "enfastiadiças": "enfastiadiço",
    "enfastiadiços": "enfastiadiço",
    "enfastiado": "enfastiar",
    "enfastiados": "enfastiar",
    "enfastiai": "enfastiar",
    "enfastiais": "enfastiar",
    "enfastiam": "enfastiar",
    "enfastiamentos": "enfastiamento",
    "enfastiamo": "enfastiar",
    "enfastiamos": "enfastiar",
    "enfastiando": "enfastiar",
    "enfastiantes": "enfastiante",
    "enfastiara": "enfastiar",
    "enfastiaram": "enfastiar",
    "enfastiaras": "enfastiar",
    "enfastiarde": "enfastiar",
    "enfastiardes": "enfastiar",
    "enfastiare": "enfastiar",
    "enfastiarei": "enfastiar",
    "enfastiareis": "enfastiar",
    "enfastiarem": "enfastiar",
    "enfastiaremos": "enfastiar",
    "enfastiares": "enfastiar",
    "enfastiaria": "enfastiar",
    "enfastiariam": "enfastiar",
    "enfastiarias": "enfastiar",
    "enfastiarmo": "enfastiar",
    "enfastiarmos": "enfastiar",
    "enfastiará": "enfastiar",
    "enfastiarás": "enfastiar",
    "enfastiarão": "enfastiar",
    "enfastiaríamos": "enfastiar",
    "enfastiaríeis": "enfastiar",
    "enfastias": "enfastiar",
    "enfastiasse": "enfastiar",
    "enfastiassem": "enfastiar",
    "enfastiasses": "enfastiar",
    "enfastiaste": "enfastiar",
    "enfastiastes": "enfastiar",
    "enfastiava": "enfastiar",
    "enfastiavam": "enfastiar",
    "enfastiavas": "enfastiar",
    "enfastie": "enfastiar",
    "enfastiei": "enfastiar",
    "enfastieis": "enfastiar",
    "enfastiem": "enfastiar",
    "enfastiemo": "enfastiar",
    "enfastiemos": "enfastiar",
    "enfasties": "enfastiar",
    "enfastio": "enfastiar",
    "enfastiosa": "enfastioso",
    "enfastiosas": "enfastioso",
    "enfastiosos": "enfastioso",
    "enfastiou": "enfastiar",
    "enfastiá": "enfastiar",
    "enfastiámo": "enfastiar",
    "enfastiámos": "enfastiar",
    "enfastiáramo": "enfastiar",
    "enfastiáramos": "enfastiar",
    "enfastiárei": "enfastiar",
    "enfastiáreis": "enfastiar",
    "enfastiásseis": "enfastiar",
    "enfastiássemos": "enfastiar",
    "enfastiávamo": "enfastiar",
    "enfastiávamos": "enfastiar",
    "enfastiávei": "enfastiar",
    "enfastiáveis": "enfastiar",
    "enfasá": "enfasar",
    "enfasámo": "enfasar",
    "enfasámos": "enfasar",
    "enfasáramo": "enfasar",
    "enfasáramos": "enfasar",
    "enfasárei": "enfasar",
    "enfasáreis": "enfasar",
    "enfasásseis": "enfasar",
    "enfasássemos": "enfasar",
    "enfasávamo": "enfasar",
    "enfasávamos": "enfasar",
    "enfasávei": "enfasar",
    "enfasáveis": "enfasar",
    "enfatiota": "enfatiotar",
    "enfatiotada": "enfatiotar",
    "enfatiotadas": "enfatiotar",
    "enfatiotado": "enfatiotar",
    "enfatiotados": "enfatiotar",
    "enfatiotai": "enfatiotar",
    "enfatiotais": "enfatiotar",
    "enfatiotam": "enfatiotar",
    "enfatiotamo": "enfatiotar",
    "enfatiotamos": "enfatiotar",
    "enfatiotando": "enfatiotar",
    "enfatiotara": "enfatiotar",
    "enfatiotaram": "enfatiotar",
    "enfatiotaras": "enfatiotar",
    "enfatiotarde": "enfatiotar",
    "enfatiotardes": "enfatiotar",
    "enfatiotare": "enfatiotar",
    "enfatiotarei": "enfatiotar",
    "enfatiotareis": "enfatiotar",
    "enfatiotarem": "enfatiotar",
    "enfatiotaremos": "enfatiotar",
    "enfatiotares": "enfatiotar",
    "enfatiotaria": "enfatiotar",
    "enfatiotariam": "enfatiotar",
    "enfatiotarias": "enfatiotar",
    "enfatiotarmo": "enfatiotar",
    "enfatiotarmos": "enfatiotar",
    "enfatiotará": "enfatiotar",
    "enfatiotarás": "enfatiotar",
    "enfatiotarão": "enfatiotar",
    "enfatiotaríamos": "enfatiotar",
    "enfatiotaríeis": "enfatiotar",
    "enfatiotas": "enfatiotar",
    "enfatiotasse": "enfatiotar",
    "enfatiotassem": "enfatiotar",
    "enfatiotasses": "enfatiotar",
    "enfatiotaste": "enfatiotar",
    "enfatiotastes": "enfatiotar",
    "enfatiotava": "enfatiotar",
    "enfatiotavam": "enfatiotar",
    "enfatiotavas": "enfatiotar",
    "enfatiote": "enfatiotar",
    "enfatiotei": "enfatiotar",
    "enfatioteis": "enfatiotar",
    "enfatiotem": "enfatiotar",
    "enfatiotemo": "enfatiotar",
    "enfatiotemos": "enfatiotar",
    "enfatiotes": "enfatiotar",
    "enfatioto": "enfatiotar",
    "enfatiotou": "enfatiotar",
    "enfatiotá": "enfatiotar",
    "enfatiotámo": "enfatiotar",
    "enfatiotámos": "enfatiotar",
    "enfatiotáramo": "enfatiotar",
    "enfatiotáramos": "enfatiotar",
    "enfatiotárei": "enfatiotar",
    "enfatiotáreis": "enfatiotar",
    "enfatiotásseis": "enfatiotar",
    "enfatiotássemos": "enfatiotar",
    "enfatiotávamo": "enfatiotar",
    "enfatiotávamos": "enfatiotar",
    "enfatiotávei": "enfatiotar",
    "enfatiotáveis": "enfatiotar",
    "enfatiza": "enfatizar",
    "enfatizada": "enfatizar",
    "enfatizadas": "enfatizar",
    "enfatizado": "enfatizar",
    "enfatizados": "enfatizar",
    "enfatizai": "enfatizar",
    "enfatizais": "enfatizar",
    "enfatizam": "enfatizar",
    "enfatizamo": "enfatizar",
    "enfatizamos": "enfatizar",
    "enfatizando": "enfatizar",
    "enfatizara": "enfatizar",
    "enfatizaram": "enfatizar",
    "enfatizaras": "enfatizar",
    "enfatizarde": "enfatizar",
    "enfatizardes": "enfatizar",
    "enfatizare": "enfatizar",
    "enfatizarei": "enfatizar",
    "enfatizareis": "enfatizar",
    "enfatizarem": "enfatizar",
    "enfatizaremos": "enfatizar",
    "enfatizares": "enfatizar",
    "enfatizaria": "enfatizar",
    "enfatizariam": "enfatizar",
    "enfatizarias": "enfatizar",
    "enfatizarmo": "enfatizar",
    "enfatizarmos": "enfatizar",
    "enfatizará": "enfatizar",
    "enfatizarás": "enfatizar",
    "enfatizarão": "enfatizar",
    "enfatizaríamos": "enfatizar",
    "enfatizaríeis": "enfatizar",
    "enfatizas": "enfatizar",
    "enfatizasse": "enfatizar",
    "enfatizassem": "enfatizar",
    "enfatizasses": "enfatizar",
    "enfatizaste": "enfatizar",
    "enfatizastes": "enfatizar",
    "enfatizava": "enfatizar",
    "enfatizavam": "enfatizar",
    "enfatizavas": "enfatizar",
    "enfatize": "enfatizar",
    "enfatizei": "enfatizar",
    "enfatizeis": "enfatizar",
    "enfatizem": "enfatizar",
    "enfatizemo": "enfatizar",
    "enfatizemos": "enfatizar",
    "enfatizes": "enfatizar",
    "enfatizo": "enfatizar",
    "enfatizou": "enfatizar",
    "enfatizá": "enfatizar",
    "enfatizámo": "enfatizar",
    "enfatizámos": "enfatizar",
    "enfatizáramo": "enfatizar",
    "enfatizáramos": "enfatizar",
    "enfatizárei": "enfatizar",
    "enfatizáreis": "enfatizar",
    "enfatizásseis": "enfatizar",
    "enfatizássemos": "enfatizar",
    "enfatizávamo": "enfatizar",
    "enfatizávamos": "enfatizar",
    "enfatizávei": "enfatizar",
    "enfatizáveis": "enfatizar",
    "enfatua": "enfatuar",
    "enfatuada": "enfatuar",
    "enfatuadas": "enfatuar",
    "enfatuado": "enfatuar",
    "enfatuados": "enfatuar",
    "enfatuai": "enfatuar",
    "enfatuais": "enfatuar",
    "enfatuam": "enfatuar",
    "enfatuamentos": "enfatuamento",
    "enfatuamo": "enfatuar",
    "enfatuamos": "enfatuar",
    "enfatuando": "enfatuar",
    "enfatuara": "enfatuar",
    "enfatuaram": "enfatuar",
    "enfatuaras": "enfatuar",
    "enfatuarde": "enfatuar",
    "enfatuardes": "enfatuar",
    "enfatuare": "enfatuar",
    "enfatuarei": "enfatuar",
    "enfatuareis": "enfatuar",
    "enfatuarem": "enfatuar",
    "enfatuaremos": "enfatuar",
    "enfatuares": "enfatuar",
    "enfatuaria": "enfatuar",
    "enfatuariam": "enfatuar",
    "enfatuarias": "enfatuar",
    "enfatuarmo": "enfatuar",
    "enfatuarmos": "enfatuar",
    "enfatuará": "enfatuar",
    "enfatuarás": "enfatuar",
    "enfatuarão": "enfatuar",
    "enfatuaríamos": "enfatuar",
    "enfatuaríeis": "enfatuar",
    "enfatuas": "enfatuar",
    "enfatuasse": "enfatuar",
    "enfatuassem": "enfatuar",
    "enfatuasses": "enfatuar",
    "enfatuaste": "enfatuar",
    "enfatuastes": "enfatuar",
    "enfatuava": "enfatuar",
    "enfatuavam": "enfatuar",
    "enfatuavas": "enfatuar",
    "enfatuações": "enfatuação",
    "enfatue": "enfatuar",
    "enfatuei": "enfatuar",
    "enfatueis": "enfatuar",
    "enfatuem": "enfatuar",
    "enfatuemo": "enfatuar",
    "enfatuemos": "enfatuar",
    "enfatues": "enfatuar",
    "enfatuo": "enfatuar",
    "enfatuou": "enfatuar",
    "enfatuá": "enfatuar",
    "enfatuámo": "enfatuar",
    "enfatuámos": "enfatuar",
    "enfatuáramo": "enfatuar",
    "enfatuáramos": "enfatuar",
    "enfatuárei": "enfatuar",
    "enfatuáreis": "enfatuar",
    "enfatuásseis": "enfatuar",
    "enfatuássemos": "enfatuar",
    "enfatuávamo": "enfatuar",
    "enfatuávamos": "enfatuar",
    "enfatuávei": "enfatuar",
    "enfatuáveis": "enfatuar",
    "enfeada": "enfear",
    "enfeadas": "enfear",
    "enfeado": "enfear",
    "enfeados": "enfear",
    "enfeai": "enfear",
    "enfeais": "enfear",
    "enfeamo": "enfear",
    "enfeamos": "enfear",
    "enfeando": "enfear",
    "enfeara": "enfear",
    "enfearam": "enfear",
    "enfearas": "enfear",
    "enfearde": "enfear",
    "enfeardes": "enfear",
    "enfeare": "enfear",
    "enfearei": "enfear",
    "enfeareis": "enfear",
    "enfearem": "enfear",
    "enfearemos": "enfear",
    "enfeares": "enfear",
    "enfearia": "enfear",
    "enfeariam": "enfear",
    "enfearias": "enfear",
    "enfearmo": "enfear",
    "enfearmos": "enfear",
    "enfeará": "enfear",
    "enfearás": "enfear",
    "enfearão": "enfear",
    "enfearíamos": "enfear",
    "enfearíeis": "enfear",
    "enfeasse": "enfear",
    "enfeassem": "enfear",
    "enfeasses": "enfear",
    "enfeaste": "enfear",
    "enfeastes": "enfear",
    "enfeava": "enfear",
    "enfeavam": "enfear",
    "enfeavas": "enfear",
    "enfebrece": "enfebrecer",
    "enfebrecei": "enfebrecer",
    "enfebreceis": "enfebrecer",
    "enfebrecem": "enfebrecer",
    "enfebrecemo": "enfebrecer",
    "enfebrecemos": "enfebrecer",
    "enfebrecendo": "enfebrecer",
    "enfebrecera": "enfebrecer",
    "enfebreceram": "enfebrecer",
    "enfebreceras": "enfebrecer",
    "enfebrecerdes": "enfebrecer",
    "enfebrecerei": "enfebrecer",
    "enfebrecereis": "enfebrecer",
    "enfebrecerem": "enfebrecer",
    "enfebreceremos": "enfebrecer",
    "enfebreceres": "enfebrecer",
    "enfebreceria": "enfebrecer",
    "enfebreceriam": "enfebrecer",
    "enfebrecerias": "enfebrecer",
    "enfebrecermo": "enfebrecer",
    "enfebrecermos": "enfebrecer",
    "enfebrecerá": "enfebrecer",
    "enfebrecerás": "enfebrecer",
    "enfebrecerão": "enfebrecer",
    "enfebreceríamos": "enfebrecer",
    "enfebreceríeis": "enfebrecer",
    "enfebreces": "enfebrecer",
    "enfebrecesse": "enfebrecer",
    "enfebrecessem": "enfebrecer",
    "enfebrecesses": "enfebrecer",
    "enfebreceste": "enfebrecer",
    "enfebrecestes": "enfebrecer",
    "enfebreceu": "enfebrecer",
    "enfebreci": "enfebrecer",
    "enfebrecia": "enfebrecer",
    "enfebreciam": "enfebrecer",
    "enfebrecias": "enfebrecer",
    "enfebrecida": "enfebrecer",
    "enfebrecidas": "enfebrecer",
    "enfebrecido": "enfebrecer",
    "enfebrecidos": "enfebrecer",
    "enfebrecêramo": "enfebrecer",
    "enfebrecêramos": "enfebrecer",
    "enfebrecêreis": "enfebrecer",
    "enfebrecêsseis": "enfebrecer",
    "enfebrecêssemos": "enfebrecer",
    "enfebrecíamo": "enfebrecer",
    "enfebrecíamos": "enfebrecer",
    "enfebrecíeis": "enfebrecer",
    "enfebreça": "enfebrecer",
    "enfebreçais": "enfebrecer",
    "enfebreçam": "enfebrecer",
    "enfebreçamo": "enfebrecer",
    "enfebreçamos": "enfebrecer",
    "enfebreças": "enfebrecer",
    "enfebreço": "enfebrecer",
    "enfeei": "enfear",
    "enfeeis": "enfear",
    "enfeemo": "enfear",
    "enfeemos": "enfear",
    "enfeia": "enfear",
    "enfeiam": "enfear",
    "enfeias": "enfear",
    "enfeie": "enfear",
    "enfeiem": "enfear",
    "enfeies": "enfear",
    "enfeio": "enfear",
    "enfeira": "enfeirar",
    "enfeirada": "enfeirar",
    "enfeiradas": "enfeirar",
    "enfeirado": "enfeirar",
    "enfeirados": "enfeirar",
    "enfeirai": "enfeirar",
    "enfeirais": "enfeirar",
    "enfeiram": "enfeirar",
    "enfeiramo": "enfeirar",
    "enfeiramos": "enfeirar",
    "enfeirando": "enfeirar",
    "enfeirara": "enfeirar",
    "enfeiraram": "enfeirar",
    "enfeiraras": "enfeirar",
    "enfeirarde": "enfeirar",
    "enfeirardes": "enfeirar",
    "enfeirare": "enfeirar",
    "enfeirarei": "enfeirar",
    "enfeirareis": "enfeirar",
    "enfeirarem": "enfeirar",
    "enfeiraremos": "enfeirar",
    "enfeirares": "enfeirar",
    "enfeiraria": "enfeirar",
    "enfeirariam": "enfeirar",
    "enfeirarias": "enfeirar",
    "enfeirarmo": "enfeirar",
    "enfeirarmos": "enfeirar",
    "enfeirará": "enfeirar",
    "enfeirarás": "enfeirar",
    "enfeirarão": "enfeirar",
    "enfeiraríamos": "enfeirar",
    "enfeiraríeis": "enfeirar",
    "enfeiras": "enfeirar",
    "enfeirasse": "enfeirar",
    "enfeirassem": "enfeirar",
    "enfeirasses": "enfeirar",
    "enfeiraste": "enfeirar",
    "enfeirastes": "enfeirar",
    "enfeirava": "enfeirar",
    "enfeiravam": "enfeirar",
    "enfeiravas": "enfeirar",
    "enfeire": "enfeirar",
    "enfeirei": "enfeirar",
    "enfeireis": "enfeirar",
    "enfeirem": "enfeirar",
    "enfeiremo": "enfeirar",
    "enfeiremos": "enfeirar",
    "enfeires": "enfeirar",
    "enfeiro": "enfeirar",
    "enfeirou": "enfeirar",
    "enfeirá": "enfeirar",
    "enfeirámo": "enfeirar",
    "enfeirámos": "enfeirar",
    "enfeiráramo": "enfeirar",
    "enfeiráramos": "enfeirar",
    "enfeirárei": "enfeirar",
    "enfeiráreis": "enfeirar",
    "enfeirásseis": "enfeirar",
    "enfeirássemos": "enfeirar",
    "enfeirávamo": "enfeirar",
    "enfeirávamos": "enfeirar",
    "enfeirávei": "enfeirar",
    "enfeiráveis": "enfeirar",
    "enfeita": "enfeitar",
    "enfeitada": "enfeitar",
    "enfeitadas": "enfeitar",
    "enfeitado": "enfeitar",
    "enfeitadora": "enfeitador",
    "enfeitadoras": "enfeitador",
    "enfeitadores": "enfeitador",
    "enfeitados": "enfeitar",
    "enfeitadíssima": "enfeitado",
    "enfeitadíssimas": "enfeitado",
    "enfeitadíssimo": "enfeitado",
    "enfeitadíssimos": "enfeitado",
    "enfeitai": "enfeitar",
    "enfeitais": "enfeitar",
    "enfeitam": "enfeitar",
    "enfeitamentos": "enfeitamento",
    "enfeitamo": "enfeitar",
    "enfeitamos": "enfeitar",
    "enfeitando": "enfeitar",
    "enfeitara": "enfeitar",
    "enfeitaram": "enfeitar",
    "enfeitaras": "enfeitar",
    "enfeitarde": "enfeitar",
    "enfeitardes": "enfeitar",
    "enfeitare": "enfeitar",
    "enfeitarei": "enfeitar",
    "enfeitareis": "enfeitar",
    "enfeitarem": "enfeitar",
    "enfeitaremos": "enfeitar",
    "enfeitares": "enfeitar",
    "enfeitaria": "enfeitar",
    "enfeitariam": "enfeitar",
    "enfeitarias": "enfeitar",
    "enfeitarmo": "enfeitar",
    "enfeitarmos": "enfeitar",
    "enfeitará": "enfeitar",
    "enfeitarás": "enfeitar",
    "enfeitarão": "enfeitar",
    "enfeitaríamos": "enfeitar",
    "enfeitaríeis": "enfeitar",
    "enfeitas": "enfeitar",
    "enfeitasse": "enfeitar",
    "enfeitassem": "enfeitar",
    "enfeitasses": "enfeitar",
    "enfeitaste": "enfeitar",
    "enfeitastes": "enfeitar",
    "enfeitava": "enfeitar",
    "enfeitavam": "enfeitar",
    "enfeitavas": "enfeitar",
    "enfeite": "enfeitar",
    "enfeitei": "enfeitar",
    "enfeiteis": "enfeitar",
    "enfeitem": "enfeitar",
    "enfeitemo": "enfeitar",
    "enfeitemos": "enfeitar",
    "enfeites": "enfeite",
    "enfeitice": "enfeitiçar",
    "enfeiticei": "enfeitiçar",
    "enfeiticeis": "enfeitiçar",
    "enfeiticem": "enfeitiçar",
    "enfeiticemo": "enfeitiçar",
    "enfeiticemos": "enfeitiçar",
    "enfeitices": "enfeitiçar",
    "enfeitiça": "enfeitiçar",
    "enfeitiçada": "enfeitiçar",
    "enfeitiçadas": "enfeitiçar",
    "enfeitiçado": "enfeitiçar",
    "enfeitiçadora": "enfeitiçador",
    "enfeitiçadoras": "enfeitiçador",
    "enfeitiçadores": "enfeitiçador",
    "enfeitiçados": "enfeitiçar",
    "enfeitiçai": "enfeitiçar",
    "enfeitiçais": "enfeitiçar",
    "enfeitiçam": "enfeitiçar",
    "enfeitiçamentos": "enfeitiçamento",
    "enfeitiçamo": "enfeitiçar",
    "enfeitiçamos": "enfeitiçar",
    "enfeitiçando": "enfeitiçar",
    "enfeitiçara": "enfeitiçar",
    "enfeitiçaram": "enfeitiçar",
    "enfeitiçaras": "enfeitiçar",
    "enfeitiçarde": "enfeitiçar",
    "enfeitiçardes": "enfeitiçar",
    "enfeitiçare": "enfeitiçar",
    "enfeitiçarei": "enfeitiçar",
    "enfeitiçareis": "enfeitiçar",
    "enfeitiçarem": "enfeitiçar",
    "enfeitiçaremos": "enfeitiçar",
    "enfeitiçares": "enfeitiçar",
    "enfeitiçaria": "enfeitiçar",
    "enfeitiçariam": "enfeitiçar",
    "enfeitiçarias": "enfeitiçar",
    "enfeitiçarmo": "enfeitiçar",
    "enfeitiçarmos": "enfeitiçar",
    "enfeitiçará": "enfeitiçar",
    "enfeitiçarás": "enfeitiçar",
    "enfeitiçarão": "enfeitiçar",
    "enfeitiçaríamos": "enfeitiçar",
    "enfeitiçaríeis": "enfeitiçar",
    "enfeitiças": "enfeitiçar",
    "enfeitiçasse": "enfeitiçar",
    "enfeitiçassem": "enfeitiçar",
    "enfeitiçasses": "enfeitiçar",
    "enfeitiçaste": "enfeitiçar",
    "enfeitiçastes": "enfeitiçar",
    "enfeitiçava": "enfeitiçar",
    "enfeitiçavam": "enfeitiçar",
    "enfeitiçavas": "enfeitiçar",
    "enfeitiço": "enfeitiçar",
    "enfeitiçou": "enfeitiçar",
    "enfeitiçá": "enfeitiçar",
    "enfeitiçámo": "enfeitiçar",
    "enfeitiçámos": "enfeitiçar",
    "enfeitiçáramo": "enfeitiçar",
    "enfeitiçáramos": "enfeitiçar",
    "enfeitiçárei": "enfeitiçar",
    "enfeitiçáreis": "enfeitiçar",
    "enfeitiçásseis": "enfeitiçar",
    "enfeitiçássemos": "enfeitiçar",
    "enfeitiçávamo": "enfeitiçar",
    "enfeitiçávamos": "enfeitiçar",
    "enfeitiçávei": "enfeitiçar",
    "enfeitiçáveis": "enfeitiçar",
    "enfeito": "enfeitar",
    "enfeitou": "enfeitar",
    "enfeitá": "enfeitar",
    "enfeitámo": "enfeitar",
    "enfeitámos": "enfeitar",
    "enfeitáramo": "enfeitar",
    "enfeitáramos": "enfeitar",
    "enfeitárei": "enfeitar",
    "enfeitáreis": "enfeitar",
    "enfeitásseis": "enfeitar",
    "enfeitássemos": "enfeitar",
    "enfeitávamo": "enfeitar",
    "enfeitávamos": "enfeitar",
    "enfeitávei": "enfeitar",
    "enfeitáveis": "enfeitar",
    "enfeixa": "enfeixar",
    "enfeixada": "enfeixar",
    "enfeixadas": "enfeixar",
    "enfeixado": "enfeixar",
    "enfeixados": "enfeixar",
    "enfeixai": "enfeixar",
    "enfeixais": "enfeixar",
    "enfeixam": "enfeixar",
    "enfeixamentos": "enfeixamento",
    "enfeixamo": "enfeixar",
    "enfeixamos": "enfeixar",
    "enfeixando": "enfeixar",
    "enfeixara": "enfeixar",
    "enfeixaram": "enfeixar",
    "enfeixaras": "enfeixar",
    "enfeixarde": "enfeixar",
    "enfeixardes": "enfeixar",
    "enfeixare": "enfeixar",
    "enfeixarei": "enfeixar",
    "enfeixareis": "enfeixar",
    "enfeixarem": "enfeixar",
    "enfeixaremos": "enfeixar",
    "enfeixares": "enfeixar",
    "enfeixaria": "enfeixar",
    "enfeixariam": "enfeixar",
    "enfeixarias": "enfeixar",
    "enfeixarmo": "enfeixar",
    "enfeixarmos": "enfeixar",
    "enfeixará": "enfeixar",
    "enfeixarás": "enfeixar",
    "enfeixarão": "enfeixar",
    "enfeixaríamos": "enfeixar",
    "enfeixaríeis": "enfeixar",
    "enfeixas": "enfeixar",
    "enfeixasse": "enfeixar",
    "enfeixassem": "enfeixar",
    "enfeixasses": "enfeixar",
    "enfeixaste": "enfeixar",
    "enfeixastes": "enfeixar",
    "enfeixava": "enfeixar",
    "enfeixavam": "enfeixar",
    "enfeixavas": "enfeixar",
    "enfeixe": "enfeixar",
    "enfeixei": "enfeixar",
    "enfeixeis": "enfeixar",
    "enfeixem": "enfeixar",
    "enfeixemo": "enfeixar",
    "enfeixemos": "enfeixar",
    "enfeixes": "enfeixar",
    "enfeixo": "enfeixar",
    "enfeixou": "enfeixar",
    "enfeixá": "enfeixar",
    "enfeixámo": "enfeixar",
    "enfeixámos": "enfeixar",
    "enfeixáramo": "enfeixar",
    "enfeixáramos": "enfeixar",
    "enfeixárei": "enfeixar",
    "enfeixáreis": "enfeixar",
    "enfeixásseis": "enfeixar",
    "enfeixássemos": "enfeixar",
    "enfeixávamo": "enfeixar",
    "enfeixávamos": "enfeixar",
    "enfeixávei": "enfeixar",
    "enfeixáveis": "enfeixar",
    "enfeltra": "enfeltrar",
    "enfeltrada": "enfeltrar",
    "enfeltradas": "enfeltrar",
    "enfeltrado": "enfeltrar",
    "enfeltrados": "enfeltrar",
    "enfeltrai": "enfeltrar",
    "enfeltrais": "enfeltrar",
    "enfeltram": "enfeltrar",
    "enfeltramo": "enfeltrar",
    "enfeltramos": "enfeltrar",
    "enfeltrando": "enfeltrar",
    "enfeltrara": "enfeltrar",
    "enfeltraram": "enfeltrar",
    "enfeltraras": "enfeltrar",
    "enfeltrarde": "enfeltrar",
    "enfeltrardes": "enfeltrar",
    "enfeltrare": "enfeltrar",
    "enfeltrarei": "enfeltrar",
    "enfeltrareis": "enfeltrar",
    "enfeltrarem": "enfeltrar",
    "enfeltraremos": "enfeltrar",
    "enfeltrares": "enfeltrar",
    "enfeltraria": "enfeltrar",
    "enfeltrariam": "enfeltrar",
    "enfeltrarias": "enfeltrar",
    "enfeltrarmo": "enfeltrar",
    "enfeltrarmos": "enfeltrar",
    "enfeltrará": "enfeltrar",
    "enfeltrarás": "enfeltrar",
    "enfeltrarão": "enfeltrar",
    "enfeltraríamos": "enfeltrar",
    "enfeltraríeis": "enfeltrar",
    "enfeltras": "enfeltrar",
    "enfeltrasse": "enfeltrar",
    "enfeltrassem": "enfeltrar",
    "enfeltrasses": "enfeltrar",
    "enfeltraste": "enfeltrar",
    "enfeltrastes": "enfeltrar",
    "enfeltrava": "enfeltrar",
    "enfeltravam": "enfeltrar",
    "enfeltravas": "enfeltrar",
    "enfeltre": "enfeltrar",
    "enfeltrei": "enfeltrar",
    "enfeltreis": "enfeltrar",
    "enfeltrem": "enfeltrar",
    "enfeltremo": "enfeltrar",
    "enfeltremos": "enfeltrar",
    "enfeltres": "enfeltrar",
    "enfeltro": "enfeltrar",
    "enfeltrou": "enfeltrar",
    "enfeltrá": "enfeltrar",
    "enfeltrámo": "enfeltrar",
    "enfeltrámos": "enfeltrar",
    "enfeltráramo": "enfeltrar",
    "enfeltráramos": "enfeltrar",
    "enfeltrárei": "enfeltrar",
    "enfeltráreis": "enfeltrar",
    "enfeltrásseis": "enfeltrar",
    "enfeltrássemos": "enfeltrar",
    "enfeltrávamo": "enfeltrar",
    "enfeltrávamos": "enfeltrar",
    "enfeltrávei": "enfeltrar",
    "enfeltráveis": "enfeltrar",
    "enfeluja": "enfelujar",
    "enfelujada": "enfelujar",
    "enfelujadas": "enfelujar",
    "enfelujado": "enfelujar",
    "enfelujados": "enfelujar",
    "enfelujai": "enfelujar",
    "enfelujais": "enfelujar",
    "enfelujam": "enfelujar",
    "enfelujamo": "enfelujar",
    "enfelujamos": "enfelujar",
    "enfelujando": "enfelujar",
    "enfelujara": "enfelujar",
    "enfelujaram": "enfelujar",
    "enfelujaras": "enfelujar",
    "enfelujarde": "enfelujar",
    "enfelujardes": "enfelujar",
    "enfelujare": "enfelujar",
    "enfelujarei": "enfelujar",
    "enfelujareis": "enfelujar",
    "enfelujarem": "enfelujar",
    "enfelujaremos": "enfelujar",
    "enfelujares": "enfelujar",
    "enfelujaria": "enfelujar",
    "enfelujariam": "enfelujar",
    "enfelujarias": "enfelujar",
    "enfelujarmo": "enfelujar",
    "enfelujarmos": "enfelujar",
    "enfelujará": "enfelujar",
    "enfelujarás": "enfelujar",
    "enfelujarão": "enfelujar",
    "enfelujaríamos": "enfelujar",
    "enfelujaríeis": "enfelujar",
    "enfelujas": "enfelujar",
    "enfelujasse": "enfelujar",
    "enfelujassem": "enfelujar",
    "enfelujasses": "enfelujar",
    "enfelujaste": "enfelujar",
    "enfelujastes": "enfelujar",
    "enfelujava": "enfelujar",
    "enfelujavam": "enfelujar",
    "enfelujavas": "enfelujar",
    "enfeluje": "enfelujar",
    "enfelujei": "enfelujar",
    "enfelujeis": "enfelujar",
    "enfelujem": "enfelujar",
    "enfelujemo": "enfelujar",
    "enfelujemos": "enfelujar",
    "enfelujes": "enfelujar",
    "enfelujo": "enfelujar",
    "enfelujou": "enfelujar",
    "enfelujá": "enfelujar",
    "enfelujámo": "enfelujar",
    "enfelujámos": "enfelujar",
    "enfelujáramo": "enfelujar",
    "enfelujáramos": "enfelujar",
    "enfelujárei": "enfelujar",
    "enfelujáreis": "enfelujar",
    "enfelujásseis": "enfelujar",
    "enfelujássemos": "enfelujar",
    "enfelujávamo": "enfelujar",
    "enfelujávamos": "enfelujar",
    "enfelujávei": "enfelujar",
    "enfelujáveis": "enfelujar",
    "enfeou": "enfear",
    "enferma": "enfermo",
    "enfermada": "enfermar",
    "enfermadas": "enfermar",
    "enfermado": "enfermar",
    "enfermados": "enfermar",
    "enfermagens": "enfermagem",
    "enfermai": "enfermar",
    "enfermais": "enfermar",
    "enfermam": "enfermar",
    "enfermamo": "enfermar",
    "enfermamos": "enfermar",
    "enfermando": "enfermar",
    "enfermara": "enfermar",
    "enfermaram": "enfermar",
    "enfermaras": "enfermar",
    "enfermardes": "enfermar",
    "enfermarei": "enfermar",
    "enfermareis": "enfermar",
    "enfermarem": "enfermar",
    "enfermaremos": "enfermar",
    "enfermares": "enfermar",
    "enfermaria": "enfermar",
    "enfermariam": "enfermar",
    "enfermarias": "enfermaria",
    "enfermarmo": "enfermar",
    "enfermarmos": "enfermar",
    "enfermará": "enfermar",
    "enfermarás": "enfermar",
    "enfermarão": "enfermar",
    "enfermaríamos": "enfermar",
    "enfermaríeis": "enfermar",
    "enfermas": "enfermo",
    "enfermasse": "enfermar",
    "enfermassem": "enfermar",
    "enfermasses": "enfermar",
    "enfermaste": "enfermar",
    "enfermastes": "enfermar",
    "enfermava": "enfermar",
    "enfermavam": "enfermar",
    "enfermavas": "enfermar",
    "enferme": "enfermar",
    "enfermei": "enfermar",
    "enfermeira": "enfermeiro",
    "enfermeiras": "enfermeiro",
    "enfermeiros": "enfermeiro",
    "enfermeis": "enfermar",
    "enfermem": "enfermar",
    "enfermemo": "enfermar",
    "enfermemos": "enfermar",
    "enfermes": "enfermar",
    "enfermidades": "enfermidade",
    "enfermiça": "enfermiço",
    "enfermiças": "enfermiço",
    "enfermiços": "enfermiço",
    "enfermo": "enfermar",
    "enfermos": "enfermo",
    "enfermou": "enfermar",
    "enfermámo": "enfermar",
    "enfermámos": "enfermar",
    "enfermáramo": "enfermar",
    "enfermáramos": "enfermar",
    "enfermáreis": "enfermar",
    "enfermásseis": "enfermar",
    "enfermássemos": "enfermar",
    "enfermávamo": "enfermar",
    "enfermávamos": "enfermar",
    "enfermáveis": "enfermar",
    "enferruja": "enferrujar",
    "enferrujada": "enferrujar",
    "enferrujadas": "enferrujar",
    "enferrujado": "enferrujar",
    "enferrujados": "enferrujar",
    "enferrujadota": "enferrujadote",
    "enferrujadotas": "enferrujadote",
    "enferrujadotes": "enferrujadote",
    "enferrujai": "enferrujar",
    "enferrujais": "enferrujar",
    "enferrujam": "enferrujar",
    "enferrujamentos": "enferrujamento",
    "enferrujamo": "enferrujar",
    "enferrujamos": "enferrujar",
    "enferrujando": "enferrujar",
    "enferrujara": "enferrujar",
    "enferrujaram": "enferrujar",
    "enferrujaras": "enferrujar",
    "enferrujarde": "enferrujar",
    "enferrujardes": "enferrujar",
    "enferrujare": "enferrujar",
    "enferrujarei": "enferrujar",
    "enferrujareis": "enferrujar",
    "enferrujarem": "enferrujar",
    "enferrujaremos": "enferrujar",
    "enferrujares": "enferrujar",
    "enferrujaria": "enferrujar",
    "enferrujariam": "enferrujar",
    "enferrujarias": "enferrujar",
    "enferrujarmo": "enferrujar",
    "enferrujarmos": "enferrujar",
    "enferrujará": "enferrujar",
    "enferrujarás": "enferrujar",
    "enferrujarão": "enferrujar",
    "enferrujaríamos": "enferrujar",
    "enferrujaríeis": "enferrujar",
    "enferrujas": "enferrujar",
    "enferrujasse": "enferrujar",
    "enferrujassem": "enferrujar",
    "enferrujasses": "enferrujar",
    "enferrujaste": "enferrujar",
    "enferrujastes": "enferrujar",
    "enferrujava": "enferrujar",
    "enferrujavam": "enferrujar",
    "enferrujavas": "enferrujar",
    "enferruje": "enferrujar",
    "enferrujei": "enferrujar",
    "enferrujeis": "enferrujar",
    "enferrujem": "enferrujar",
    "enferrujemo": "enferrujar",
    "enferrujemos": "enferrujar",
    "enferrujes": "enferrujar",
    "enferrujo": "enferrujar",
    "enferrujou": "enferrujar",
    "enferrujá": "enferrujar",
    "enferrujámo": "enferrujar",
    "enferrujámos": "enferrujar",
    "enferrujáramo": "enferrujar",
    "enferrujáramos": "enferrujar",
    "enferrujárei": "enferrujar",
    "enferrujáreis": "enferrujar",
    "enferrujásseis": "enferrujar",
    "enferrujássemos": "enferrujar",
    "enferrujávamo": "enferrujar",
    "enferrujávamos": "enferrujar",
    "enferrujávei": "enferrujar",
    "enferrujáveis": "enferrujar",
    "enfesta": "enfesto",
    "enfestada": "enfestar",
    "enfestadas": "enfestar",
    "enfestado": "enfestar",
    "enfestados": "enfestar",
    "enfestai": "enfestar",
    "enfestais": "enfestar",
    "enfestam": "enfestar",
    "enfestamentos": "enfestamento",
    "enfestamo": "enfestar",
    "enfestamos": "enfestar",
    "enfestando": "enfestar",
    "enfestara": "enfestar",
    "enfestaram": "enfestar",
    "enfestaras": "enfestar",
    "enfestarde": "enfestar",
    "enfestardes": "enfestar",
    "enfestare": "enfestar",
    "enfestarei": "enfestar",
    "enfestareis": "enfestar",
    "enfestarem": "enfestar",
    "enfestaremos": "enfestar",
    "enfestares": "enfestar",
    "enfestaria": "enfestar",
    "enfestariam": "enfestar",
    "enfestarias": "enfestar",
    "enfestarmo": "enfestar",
    "enfestarmos": "enfestar",
    "enfestará": "enfestar",
    "enfestarás": "enfestar",
    "enfestarão": "enfestar",
    "enfestaríamos": "enfestar",
    "enfestaríeis": "enfestar",
    "enfestas": "enfesto",
    "enfestasse": "enfestar",
    "enfestassem": "enfestar",
    "enfestasses": "enfestar",
    "enfestaste": "enfestar",
    "enfestastes": "enfestar",
    "enfestava": "enfestar",
    "enfestavam": "enfestar",
    "enfestavas": "enfestar",
    "enfestações": "enfestação",
    "enfeste": "enfestar",
    "enfestei": "enfestar",
    "enfesteis": "enfestar",
    "enfestem": "enfestar",
    "enfestemo": "enfestar",
    "enfestemos": "enfestar",
    "enfestes": "enfestar",
    "enfesto": "enfestar",
    "enfestos": "enfesto",
    "enfestou": "enfestar",
    "enfestá": "enfestar",
    "enfestámo": "enfestar",
    "enfestámos": "enfestar",
    "enfestáramo": "enfestar",
    "enfestáramos": "enfestar",
    "enfestárei": "enfestar",
    "enfestáreis": "enfestar",
    "enfestásseis": "enfestar",
    "enfestássemos": "enfestar",
    "enfestávamo": "enfestar",
    "enfestávamos": "enfestar",
    "enfestávei": "enfestar",
    "enfestáveis": "enfestar",
    "enfeuda": "enfeudar",
    "enfeudada": "enfeudar",
    "enfeudadas": "enfeudar",
    "enfeudado": "enfeudar",
    "enfeudados": "enfeudar",
    "enfeudai": "enfeudar",
    "enfeudais": "enfeudar",
    "enfeudam": "enfeudar",
    "enfeudamentos": "enfeudamento",
    "enfeudamo": "enfeudar",
    "enfeudamos": "enfeudar",
    "enfeudando": "enfeudar",
    "enfeudara": "enfeudar",
    "enfeudaram": "enfeudar",
    "enfeudaras": "enfeudar",
    "enfeudarde": "enfeudar",
    "enfeudardes": "enfeudar",
    "enfeudare": "enfeudar",
    "enfeudarei": "enfeudar",
    "enfeudareis": "enfeudar",
    "enfeudarem": "enfeudar",
    "enfeudaremos": "enfeudar",
    "enfeudares": "enfeudar",
    "enfeudaria": "enfeudar",
    "enfeudariam": "enfeudar",
    "enfeudarias": "enfeudar",
    "enfeudarmo": "enfeudar",
    "enfeudarmos": "enfeudar",
    "enfeudará": "enfeudar",
    "enfeudarás": "enfeudar",
    "enfeudarão": "enfeudar",
    "enfeudaríamos": "enfeudar",
    "enfeudaríeis": "enfeudar",
    "enfeudas": "enfeudar",
    "enfeudasse": "enfeudar",
    "enfeudassem": "enfeudar",
    "enfeudasses": "enfeudar",
    "enfeudaste": "enfeudar",
    "enfeudastes": "enfeudar",
    "enfeudava": "enfeudar",
    "enfeudavam": "enfeudar",
    "enfeudavas": "enfeudar",
    "enfeudações": "enfeudação",
    "enfeude": "enfeudar",
    "enfeudei": "enfeudar",
    "enfeudeis": "enfeudar",
    "enfeudem": "enfeudar",
    "enfeudemo": "enfeudar",
    "enfeudemos": "enfeudar",
    "enfeudes": "enfeudar",
    "enfeudo": "enfeudar",
    "enfeudou": "enfeudar",
    "enfeudá": "enfeudar",
    "enfeudámo": "enfeudar",
    "enfeudámos": "enfeudar",
    "enfeudáramo": "enfeudar",
    "enfeudáramos": "enfeudar",
    "enfeudárei": "enfeudar",
    "enfeudáreis": "enfeudar",
    "enfeudásseis": "enfeudar",
    "enfeudássemos": "enfeudar",
    "enfeudávamo": "enfeudar",
    "enfeudávamos": "enfeudar",
    "enfeudávei": "enfeudar",
    "enfeudáveis": "enfeudar",
    "enfeza": "enfezar",
    "enfezada": "enfezar",
    "enfezadas": "enfezar",
    "enfezadinha": "enfezado",
    "enfezadinhas": "enfezado",
    "enfezadinho": "enfezado",
    "enfezadinhos": "enfezado",
    "enfezadita": "enfezado",
    "enfezaditas": "enfezado",
    "enfezadito": "enfezado",
    "enfezaditos": "enfezado",
    "enfezado": "enfezar",
    "enfezados": "enfezar",
    "enfezadíssima": "enfezado",
    "enfezadíssimas": "enfezado",
    "enfezadíssimo": "enfezado",
    "enfezadíssimos": "enfezado",
    "enfezai": "enfezar",
    "enfezais": "enfezar",
    "enfezam": "enfezar",
    "enfezamentos": "enfezamento",
    "enfezamo": "enfezar",
    "enfezamos": "enfezar",
    "enfezando": "enfezar",
    "enfezara": "enfezar",
    "enfezaram": "enfezar",
    "enfezaras": "enfezar",
    "enfezarde": "enfezar",
    "enfezardes": "enfezar",
    "enfezare": "enfezar",
    "enfezarei": "enfezar",
    "enfezareis": "enfezar",
    "enfezarem": "enfezar",
    "enfezaremos": "enfezar",
    "enfezares": "enfezar",
    "enfezaria": "enfezar",
    "enfezariam": "enfezar",
    "enfezarias": "enfezar",
    "enfezarmo": "enfezar",
    "enfezarmos": "enfezar",
    "enfezará": "enfezar",
    "enfezarás": "enfezar",
    "enfezarão": "enfezar",
    "enfezaríamos": "enfezar",
    "enfezaríeis": "enfezar",
    "enfezas": "enfezar",
    "enfezasse": "enfezar",
    "enfezassem": "enfezar",
    "enfezasses": "enfezar",
    "enfezaste": "enfezar",
    "enfezastes": "enfezar",
    "enfezava": "enfezar",
    "enfezavam": "enfezar",
    "enfezavas": "enfezar",
    "enfeze": "enfezar",
    "enfezei": "enfezar",
    "enfezeis": "enfezar",
    "enfezem": "enfezar",
    "enfezemo": "enfezar",
    "enfezemos": "enfezar",
    "enfezes": "enfezar",
    "enfezo": "enfezar",
    "enfezou": "enfezar",
    "enfezá": "enfezar",
    "enfezámo": "enfezar",
    "enfezámos": "enfezar",
    "enfezáramo": "enfezar",
    "enfezáramos": "enfezar",
    "enfezárei": "enfezar",
    "enfezáreis": "enfezar",
    "enfezásseis": "enfezar",
    "enfezássemos": "enfezar",
    "enfezávamo": "enfezar",
    "enfezávamos": "enfezar",
    "enfezávei": "enfezar",
    "enfezáveis": "enfezar",
    "enfeá": "enfear",
    "enfeámo": "enfear",
    "enfeámos": "enfear",
    "enfeáramo": "enfear",
    "enfeáramos": "enfear",
    "enfeárei": "enfear",
    "enfeáreis": "enfear",
    "enfeásseis": "enfear",
    "enfeássemos": "enfear",
    "enfeávamo": "enfear",
    "enfeávamos": "enfear",
    "enfeávei": "enfear",
    "enfeáveis": "enfear",
    "enfia": "enfiar",
    "enfiada": "enfiar",
    "enfiadas": "enfiar",
    "enfiado": "enfiar",
    "enfiados": "enfiar",
    "enfiaduras": "enfiadura",
    "enfiadíssima": "enfiado",
    "enfiadíssimas": "enfiado",
    "enfiadíssimo": "enfiado",
    "enfiadíssimos": "enfiado",
    "enfiai": "enfiar",
    "enfiais": "enfiar",
    "enfiam": "enfiar",
    "enfiamentos": "enfiamento",
    "enfiamo": "enfiar",
    "enfiamos": "enfiar",
    "enfiando": "enfiar",
    "enfiara": "enfiar",
    "enfiaram": "enfiar",
    "enfiaras": "enfiar",
    "enfiarde": "enfiar",
    "enfiardes": "enfiar",
    "enfiare": "enfiar",
    "enfiarei": "enfiar",
    "enfiareis": "enfiar",
    "enfiarem": "enfiar",
    "enfiaremos": "enfiar",
    "enfiares": "enfiar",
    "enfiaria": "enfiar",
    "enfiariam": "enfiar",
    "enfiarias": "enfiar",
    "enfiarmo": "enfiar",
    "enfiarmos": "enfiar",
    "enfiará": "enfiar",
    "enfiarás": "enfiar",
    "enfiarão": "enfiar",
    "enfiaríamos": "enfiar",
    "enfiaríeis": "enfiar",
    "enfias": "enfiar",
    "enfiasse": "enfiar",
    "enfiassem": "enfiar",
    "enfiasses": "enfiar",
    "enfiaste": "enfiar",
    "enfiastes": "enfiar",
    "enfiava": "enfiar",
    "enfiavam": "enfiar",
    "enfiavas": "enfiar",
    "enfiações": "enfiação",
    "enfie": "enfiar",
    "enfiei": "enfiar",
    "enfieis": "enfiar",
    "enfiem": "enfiar",
    "enfiemo": "enfiar",
    "enfiemos": "enfiar",
    "enfies": "enfiar",
    "enfileira": "enfileirar",
    "enfileirada": "enfileirar",
    "enfileiradas": "enfileirar",
    "enfileirado": "enfileirar",
    "enfileirados": "enfileirar",
    "enfileirai": "enfileirar",
    "enfileirais": "enfileirar",
    "enfileiram": "enfileirar",
    "enfileiramentos": "enfileiramento",
    "enfileiramo": "enfileirar",
    "enfileiramos": "enfileirar",
    "enfileirando": "enfileirar",
    "enfileirara": "enfileirar",
    "enfileiraram": "enfileirar",
    "enfileiraras": "enfileirar",
    "enfileirarde": "enfileirar",
    "enfileirardes": "enfileirar",
    "enfileirare": "enfileirar",
    "enfileirarei": "enfileirar",
    "enfileirareis": "enfileirar",
    "enfileirarem": "enfileirar",
    "enfileiraremos": "enfileirar",
    "enfileirares": "enfileirar",
    "enfileiraria": "enfileirar",
    "enfileirariam": "enfileirar",
    "enfileirarias": "enfileirar",
    "enfileirarmo": "enfileirar",
    "enfileirarmos": "enfileirar",
    "enfileirará": "enfileirar",
    "enfileirarás": "enfileirar",
    "enfileirarão": "enfileirar",
    "enfileiraríamos": "enfileirar",
    "enfileiraríeis": "enfileirar",
    "enfileiras": "enfileirar",
    "enfileirasse": "enfileirar",
    "enfileirassem": "enfileirar",
    "enfileirasses": "enfileirar",
    "enfileiraste": "enfileirar",
    "enfileirastes": "enfileirar",
    "enfileirava": "enfileirar",
    "enfileiravam": "enfileirar",
    "enfileiravas": "enfileirar",
    "enfileire": "enfileirar",
    "enfileirei": "enfileirar",
    "enfileireis": "enfileirar",
    "enfileirem": "enfileirar",
    "enfileiremo": "enfileirar",
    "enfileiremos": "enfileirar",
    "enfileires": "enfileirar",
    "enfileiro": "enfileirar",
    "enfileirou": "enfileirar",
    "enfileirá": "enfileirar",
    "enfileirámo": "enfileirar",
    "enfileirámos": "enfileirar",
    "enfileiráramo": "enfileirar",
    "enfileiráramos": "enfileirar",
    "enfileirárei": "enfileirar",
    "enfileiráreis": "enfileirar",
    "enfileirásseis": "enfileirar",
    "enfileirássemos": "enfileirar",
    "enfileirávamo": "enfileirar",
    "enfileirávamos": "enfileirar",
    "enfileirávei": "enfileirar",
    "enfileiráveis": "enfileirar",
    "enfinca": "enfincar",
    "enfincada": "enfincar",
    "enfincadas": "enfincar",
    "enfincado": "enfincar",
    "enfincados": "enfincar",
    "enfincai": "enfincar",
    "enfincais": "enfincar",
    "enfincam": "enfincar",
    "enfincamo": "enfincar",
    "enfincamos": "enfincar",
    "enfincando": "enfincar",
    "enfincara": "enfincar",
    "enfincaram": "enfincar",
    "enfincaras": "enfincar",
    "enfincarde": "enfincar",
    "enfincardes": "enfincar",
    "enfincare": "enfincar",
    "enfincarei": "enfincar",
    "enfincareis": "enfincar",
    "enfincarem": "enfincar",
    "enfincaremos": "enfincar",
    "enfincares": "enfincar",
    "enfincaria": "enfincar",
    "enfincariam": "enfincar",
    "enfincarias": "enfincar",
    "enfincarmo": "enfincar",
    "enfincarmos": "enfincar",
    "enfincará": "enfincar",
    "enfincarás": "enfincar",
    "enfincarão": "enfincar",
    "enfincaríamos": "enfincar",
    "enfincaríeis": "enfincar",
    "enfincas": "enfincar",
    "enfincasse": "enfincar",
    "enfincassem": "enfincar",
    "enfincasses": "enfincar",
    "enfincaste": "enfincar",
    "enfincastes": "enfincar",
    "enfincava": "enfincar",
    "enfincavam": "enfincar",
    "enfincavas": "enfincar",
    "enfinco": "enfincar",
    "enfincou": "enfincar",
    "enfincá": "enfincar",
    "enfincámo": "enfincar",
    "enfincámos": "enfincar",
    "enfincáramo": "enfincar",
    "enfincáramos": "enfincar",
    "enfincárei": "enfincar",
    "enfincáreis": "enfincar",
    "enfincásseis": "enfincar",
    "enfincássemos": "enfincar",
    "enfincávamo": "enfincar",
    "enfincávamos": "enfincar",
    "enfincávei": "enfincar",
    "enfincáveis": "enfincar",
    "enfinque": "enfincar",
    "enfinquei": "enfincar",
    "enfinqueis": "enfincar",
    "enfinquem": "enfincar",
    "enfinquemo": "enfincar",
    "enfinquemos": "enfincar",
    "enfinques": "enfincar",
    "enfio": "enfiar",
    "enfiou": "enfiar",
    "enfisemas": "enfisema",
    "enfistula": "enfistular",
    "enfistulada": "enfistular",
    "enfistuladas": "enfistular",
    "enfistulado": "enfistular",
    "enfistulados": "enfistular",
    "enfistulai": "enfistular",
    "enfistulais": "enfistular",
    "enfistulam": "enfistular",
    "enfistulamo": "enfistular",
    "enfistulamos": "enfistular",
    "enfistulando": "enfistular",
    "enfistulara": "enfistular",
    "enfistularam": "enfistular",
    "enfistularas": "enfistular",
    "enfistulardes": "enfistular",
    "enfistularei": "enfistular",
    "enfistulareis": "enfistular",
    "enfistularem": "enfistular",
    "enfistularemos": "enfistular",
    "enfistulares": "enfistular",
    "enfistularia": "enfistular",
    "enfistulariam": "enfistular",
    "enfistularias": "enfistular",
    "enfistularmo": "enfistular",
    "enfistularmos": "enfistular",
    "enfistulará": "enfistular",
    "enfistularás": "enfistular",
    "enfistularão": "enfistular",
    "enfistularíamos": "enfistular",
    "enfistularíeis": "enfistular",
    "enfistulas": "enfistular",
    "enfistulasse": "enfistular",
    "enfistulassem": "enfistular",
    "enfistulasses": "enfistular",
    "enfistulaste": "enfistular",
    "enfistulastes": "enfistular",
    "enfistulava": "enfistular",
    "enfistulavam": "enfistular",
    "enfistulavas": "enfistular",
    "enfistule": "enfistular",
    "enfistulei": "enfistular",
    "enfistuleis": "enfistular",
    "enfistulem": "enfistular",
    "enfistulemo": "enfistular",
    "enfistulemos": "enfistular",
    "enfistules": "enfistular",
    "enfistulo": "enfistular",
    "enfistulou": "enfistular",
    "enfistulámo": "enfistular",
    "enfistulámos": "enfistular",
    "enfistuláramo": "enfistular",
    "enfistuláramos": "enfistular",
    "enfistuláreis": "enfistular",
    "enfistulásseis": "enfistular",
    "enfistulássemos": "enfistular",
    "enfistulávamo": "enfistular",
    "enfistulávamos": "enfistular",
    "enfistuláveis": "enfistular",
    "enfita": "enfitar",
    "enfitada": "enfitar",
    "enfitadas": "enfitar",
    "enfitado": "enfitar",
    "enfitados": "enfitar",
    "enfitai": "enfitar",
    "enfitais": "enfitar",
    "enfitam": "enfitar",
    "enfitamo": "enfitar",
    "enfitamos": "enfitar",
    "enfitando": "enfitar",
    "enfitara": "enfitar",
    "enfitaram": "enfitar",
    "enfitaras": "enfitar",
    "enfitarde": "enfitar",
    "enfitardes": "enfitar",
    "enfitare": "enfitar",
    "enfitarei": "enfitar",
    "enfitareis": "enfitar",
    "enfitarem": "enfitar",
    "enfitaremos": "enfitar",
    "enfitares": "enfitar",
    "enfitaria": "enfitar",
    "enfitariam": "enfitar",
    "enfitarias": "enfitar",
    "enfitarmo": "enfitar",
    "enfitarmos": "enfitar",
    "enfitará": "enfitar",
    "enfitarás": "enfitar",
    "enfitarão": "enfitar",
    "enfitaríamos": "enfitar",
    "enfitaríeis": "enfitar",
    "enfitas": "enfitar",
    "enfitasse": "enfitar",
    "enfitassem": "enfitar",
    "enfitasses": "enfitar",
    "enfitaste": "enfitar",
    "enfitastes": "enfitar",
    "enfitava": "enfitar",
    "enfitavam": "enfitar",
    "enfitavas": "enfitar",
    "enfite": "enfitar",
    "enfitei": "enfitar",
    "enfiteis": "enfitar",
    "enfitem": "enfitar",
    "enfitemo": "enfitar",
    "enfitemos": "enfitar",
    "enfites": "enfitar",
    "enfiteuses": "enfiteuse",
    "enfiteutas": "enfiteuta",
    "enfiteutica": "enfiteuticar",
    "enfiteuticada": "enfiteuticar",
    "enfiteuticadas": "enfiteuticar",
    "enfiteuticado": "enfiteuticar",
    "enfiteuticados": "enfiteuticar",
    "enfiteuticai": "enfiteuticar",
    "enfiteuticais": "enfiteuticar",
    "enfiteuticam": "enfiteuticar",
    "enfiteuticamo": "enfiteuticar",
    "enfiteuticamos": "enfiteuticar",
    "enfiteuticando": "enfiteuticar",
    "enfiteuticara": "enfiteuticar",
    "enfiteuticaram": "enfiteuticar",
    "enfiteuticaras": "enfiteuticar",
    "enfiteuticarde": "enfiteuticar",
    "enfiteuticardes": "enfiteuticar",
    "enfiteuticare": "enfiteuticar",
    "enfiteuticarei": "enfiteuticar",
    "enfiteuticareis": "enfiteuticar",
    "enfiteuticarem": "enfiteuticar",
    "enfiteuticaremos": "enfiteuticar",
    "enfiteuticares": "enfiteuticar",
    "enfiteuticaria": "enfiteuticar",
    "enfiteuticariam": "enfiteuticar",
    "enfiteuticarias": "enfiteuticar",
    "enfiteuticarmo": "enfiteuticar",
    "enfiteuticarmos": "enfiteuticar",
    "enfiteuticará": "enfiteuticar",
    "enfiteuticarás": "enfiteuticar",
    "enfiteuticarão": "enfiteuticar",
    "enfiteuticaríamos": "enfiteuticar",
    "enfiteuticaríeis": "enfiteuticar",
    "enfiteuticas": "enfiteuticar",
    "enfiteuticasse": "enfiteuticar",
    "enfiteuticassem": "enfiteuticar",
    "enfiteuticasses": "enfiteuticar",
    "enfiteuticaste": "enfiteuticar",
    "enfiteuticastes": "enfiteuticar",
    "enfiteuticava": "enfiteuticar",
    "enfiteuticavam": "enfiteuticar",
    "enfiteuticavas": "enfiteuticar",
    "enfiteutico": "enfiteuticar",
    "enfiteuticou": "enfiteuticar",
    "enfiteuticá": "enfiteuticar",
    "enfiteuticámo": "enfiteuticar",
    "enfiteuticámos": "enfiteuticar",
    "enfiteuticáramo": "enfiteuticar",
    "enfiteuticáramos": "enfiteuticar",
    "enfiteuticárei": "enfiteuticar",
    "enfiteuticáreis": "enfiteuticar",
    "enfiteuticásseis": "enfiteuticar",
    "enfiteuticássemos": "enfiteuticar",
    "enfiteuticávamo": "enfiteuticar",
    "enfiteuticávamos": "enfiteuticar",
    "enfiteuticávei": "enfiteuticar",
    "enfiteuticáveis": "enfiteuticar",
    "enfiteutique": "enfiteuticar",
    "enfiteutiquei": "enfiteuticar",
    "enfiteutiqueis": "enfiteuticar",
    "enfiteutiquem": "enfiteuticar",
    "enfiteutiquemo": "enfiteuticar",
    "enfiteutiquemos": "enfiteuticar",
    "enfiteutiques": "enfiteuticar",
    "enfito": "enfitar",
    "enfitou": "enfitar",
    "enfitá": "enfitar",
    "enfitámo": "enfitar",
    "enfitámos": "enfitar",
    "enfitáramo": "enfitar",
    "enfitáramos": "enfitar",
    "enfitárei": "enfitar",
    "enfitáreis": "enfitar",
    "enfitásseis": "enfitar",
    "enfitássemos": "enfitar",
    "enfitávamo": "enfitar",
    "enfitávamos": "enfitar",
    "enfitávei": "enfitar",
    "enfitáveis": "enfitar",
    "enfitêutica": "enfitêutico",
    "enfitêuticas": "enfitêutico",
    "enfitêuticos": "enfitêutico",
    "enfivela": "enfivelar",
    "enfivelada": "enfivelar",
    "enfiveladas": "enfivelar",
    "enfivelado": "enfivelar",
    "enfivelados": "enfivelar",
    "enfivelai": "enfivelar",
    "enfivelais": "enfivelar",
    "enfivelam": "enfivelar",
    "enfivelamentos": "enfivelamento",
    "enfivelamo": "enfivelar",
    "enfivelamos": "enfivelar",
    "enfivelando": "enfivelar",
    "enfivelara": "enfivelar",
    "enfivelaram": "enfivelar",
    "enfivelaras": "enfivelar",
    "enfivelarde": "enfivelar",
    "enfivelardes": "enfivelar",
    "enfivelare": "enfivelar",
    "enfivelarei": "enfivelar",
    "enfivelareis": "enfivelar",
    "enfivelarem": "enfivelar",
    "enfivelaremos": "enfivelar",
    "enfivelares": "enfivelar",
    "enfivelaria": "enfivelar",
    "enfivelariam": "enfivelar",
    "enfivelarias": "enfivelar",
    "enfivelarmo": "enfivelar",
    "enfivelarmos": "enfivelar",
    "enfivelará": "enfivelar",
    "enfivelarás": "enfivelar",
    "enfivelarão": "enfivelar",
    "enfivelaríamos": "enfivelar",
    "enfivelaríeis": "enfivelar",
    "enfivelas": "enfivelar",
    "enfivelasse": "enfivelar",
    "enfivelassem": "enfivelar",
    "enfivelasses": "enfivelar",
    "enfivelaste": "enfivelar",
    "enfivelastes": "enfivelar",
    "enfivelava": "enfivelar",
    "enfivelavam": "enfivelar",
    "enfivelavas": "enfivelar",
    "enfivele": "enfivelar",
    "enfivelei": "enfivelar",
    "enfiveleis": "enfivelar",
    "enfivelem": "enfivelar",
    "enfivelemo": "enfivelar",
    "enfivelemos": "enfivelar",
    "enfiveles": "enfivelar",
    "enfivelo": "enfivelar",
    "enfivelou": "enfivelar",
    "enfivelá": "enfivelar",
    "enfivelámo": "enfivelar",
    "enfivelámos": "enfivelar",
    "enfiveláramo": "enfivelar",
    "enfiveláramos": "enfivelar",
    "enfivelárei": "enfivelar",
    "enfiveláreis": "enfivelar",
    "enfivelásseis": "enfivelar",
    "enfivelássemos": "enfivelar",
    "enfivelávamo": "enfivelar",
    "enfivelávamos": "enfivelar",
    "enfivelávei": "enfivelar",
    "enfiveláveis": "enfivelar",
    "enfizemática": "enfizemático",
    "enfizemáticas": "enfizemático",
    "enfizemáticos": "enfizemático",
    "enfiá": "enfiar",
    "enfiámo": "enfiar",
    "enfiámos": "enfiar",
    "enfiáramo": "enfiar",
    "enfiáramos": "enfiar",
    "enfiárei": "enfiar",
    "enfiáreis": "enfiar",
    "enfiásseis": "enfiar",
    "enfiássemos": "enfiar",
    "enfiávamo": "enfiar",
    "enfiávamos": "enfiar",
    "enfiávei": "enfiar",
    "enfiáveis": "enfiar",
    "enflora": "enflorar",
    "enflorada": "enflorar",
    "enfloradas": "enflorar",
    "enflorado": "enflorar",
    "enflorados": "enflorar",
    "enfloragens": "enfloragem",
    "enflorai": "enflorar",
    "enflorais": "enflorar",
    "enfloram": "enflorar",
    "enfloramo": "enflorar",
    "enfloramos": "enflorar",
    "enflorando": "enflorar",
    "enflorara": "enflorar",
    "enfloraram": "enflorar",
    "enfloraras": "enflorar",
    "enflorarde": "enflorar",
    "enflorardes": "enflorar",
    "enflorare": "enflorar",
    "enflorarei": "enflorar",
    "enflorareis": "enflorar",
    "enflorarem": "enflorar",
    "enfloraremos": "enflorar",
    "enflorares": "enflorar",
    "enfloraria": "enflorar",
    "enflorariam": "enflorar",
    "enflorarias": "enflorar",
    "enflorarmo": "enflorar",
    "enflorarmos": "enflorar",
    "enflorará": "enflorar",
    "enflorarás": "enflorar",
    "enflorarão": "enflorar",
    "enfloraríamos": "enflorar",
    "enfloraríeis": "enflorar",
    "enfloras": "enflorar",
    "enflorasse": "enflorar",
    "enflorassem": "enflorar",
    "enflorasses": "enflorar",
    "enfloraste": "enflorar",
    "enflorastes": "enflorar",
    "enflorava": "enflorar",
    "enfloravam": "enflorar",
    "enfloravas": "enflorar",
    "enflore": "enflorar",
    "enflorei": "enflorar",
    "enfloreis": "enflorar",
    "enflorem": "enflorar",
    "enfloremo": "enflorar",
    "enfloremos": "enflorar",
    "enflores": "enflorar",
    "enfloresce": "enflorescer",
    "enflorescei": "enflorescer",
    "enfloresceis": "enflorescer",
    "enflorescem": "enflorescer",
    "enflorescemo": "enflorescer",
    "enflorescemos": "enflorescer",
    "enflorescendo": "enflorescer",
    "enflorescera": "enflorescer",
    "enfloresceram": "enflorescer",
    "enfloresceras": "enflorescer",
    "enflorescerdes": "enflorescer",
    "enflorescerei": "enflorescer",
    "enflorescereis": "enflorescer",
    "enflorescerem": "enflorescer",
    "enfloresceremos": "enflorescer",
    "enfloresceres": "enflorescer",
    "enfloresceria": "enflorescer",
    "enfloresceriam": "enflorescer",
    "enflorescerias": "enflorescer",
    "enflorescermo": "enflorescer",
    "enflorescermos": "enflorescer",
    "enflorescerá": "enflorescer",
    "enflorescerás": "enflorescer",
    "enflorescerão": "enflorescer",
    "enfloresceríamos": "enflorescer",
    "enfloresceríeis": "enflorescer",
    "enfloresces": "enflorescer",
    "enflorescesse": "enflorescer",
    "enflorescessem": "enflorescer",
    "enflorescesses": "enflorescer",
    "enfloresceste": "enflorescer",
    "enflorescestes": "enflorescer",
    "enfloresceu": "enflorescer",
    "enfloresci": "enflorescer",
    "enflorescia": "enflorescer",
    "enfloresciam": "enflorescer",
    "enflorescias": "enflorescer",
    "enflorescida": "enflorescido",
    "enflorescidas": "enflorescido",
    "enflorescido": "enflorescer",
    "enflorescidos": "enflorescido",
    "enflorescimentos": "enflorescimento",
    "enflorescêramo": "enflorescer",
    "enflorescêramos": "enflorescer",
    "enflorescêreis": "enflorescer",
    "enflorescêsseis": "enflorescer",
    "enflorescêssemos": "enflorescer",
    "enflorescíamo": "enflorescer",
    "enflorescíamos": "enflorescer",
    "enflorescíeis": "enflorescer",
    "enfloresça": "enflorescer",
    "enfloresçais": "enflorescer",
    "enfloresçam": "enflorescer",
    "enfloresçamo": "enflorescer",
    "enfloresçamos": "enflorescer",
    "enfloresças": "enflorescer",
    "enfloresço": "enflorescer",
    "enfloro": "enflorar",
    "enflorou": "enflorar",
    "enflorá": "enflorar",
    "enflorámo": "enflorar",
    "enflorámos": "enflorar",
    "enfloráramo": "enflorar",
    "enfloráramos": "enflorar",
    "enflorárei": "enflorar",
    "enfloráreis": "enflorar",
    "enflorásseis": "enflorar",
    "enflorássemos": "enflorar",
    "enflorávamo": "enflorar",
    "enflorávamos": "enflorar",
    "enflorávei": "enflorar",
    "enfloráveis": "enflorar",
    "enfocações": "enfocação",
    "enfoga": "enfogar",
    "enfogada": "enfogar",
    "enfogadas": "enfogar",
    "enfogado": "enfogar",
    "enfogados": "enfogar",
    "enfogai": "enfogar",
    "enfogais": "enfogar",
    "enfogam": "enfogar",
    "enfogamo": "enfogar",
    "enfogamos": "enfogar",
    "enfogando": "enfogar",
    "enfogara": "enfogar",
    "enfogaram": "enfogar",
    "enfogaras": "enfogar",
    "enfogarde": "enfogar",
    "enfogardes": "enfogar",
    "enfogare": "enfogar",
    "enfogarei": "enfogar",
    "enfogareis": "enfogar",
    "enfogarem": "enfogar",
    "enfogaremos": "enfogar",
    "enfogares": "enfogar",
    "enfogaria": "enfogar",
    "enfogariam": "enfogar",
    "enfogarias": "enfogar",
    "enfogarmo": "enfogar",
    "enfogarmos": "enfogar",
    "enfogará": "enfogar",
    "enfogarás": "enfogar",
    "enfogarão": "enfogar",
    "enfogaríamos": "enfogar",
    "enfogaríeis": "enfogar",
    "enfogas": "enfogar",
    "enfogasse": "enfogar",
    "enfogassem": "enfogar",
    "enfogasses": "enfogar",
    "enfogaste": "enfogar",
    "enfogastes": "enfogar",
    "enfogava": "enfogar",
    "enfogavam": "enfogar",
    "enfogavas": "enfogar",
    "enfogo": "enfogar",
    "enfogou": "enfogar",
    "enfogue": "enfogar",
    "enfoguei": "enfogar",
    "enfogueis": "enfogar",
    "enfoguem": "enfogar",
    "enfoguemo": "enfogar",
    "enfoguemos": "enfogar",
    "enfogues": "enfogar",
    "enfogá": "enfogar",
    "enfogámo": "enfogar",
    "enfogámos": "enfogar",
    "enfogáramo": "enfogar",
    "enfogáramos": "enfogar",
    "enfogárei": "enfogar",
    "enfogáreis": "enfogar",
    "enfogásseis": "enfogar",
    "enfogássemos": "enfogar",
    "enfogávamo": "enfogar",
    "enfogávamos": "enfogar",
    "enfogávei": "enfogar",
    "enfogáveis": "enfogar",
    "enfola": "enfolar",
    "enfolada": "enfolar",
    "enfoladas": "enfolar",
    "enfolado": "enfolar",
    "enfolados": "enfolar",
    "enfolai": "enfolar",
    "enfolais": "enfolar",
    "enfolam": "enfolar",
    "enfolamo": "enfolar",
    "enfolamos": "enfolar",
    "enfolando": "enfolar",
    "enfolara": "enfolar",
    "enfolaram": "enfolar",
    "enfolaras": "enfolar",
    "enfolarde": "enfolar",
    "enfolardes": "enfolar",
    "enfolare": "enfolar",
    "enfolarei": "enfolar",
    "enfolareis": "enfolar",
    "enfolarem": "enfolar",
    "enfolaremos": "enfolar",
    "enfolares": "enfolar",
    "enfolaria": "enfolar",
    "enfolariam": "enfolar",
    "enfolarias": "enfolar",
    "enfolarmo": "enfolar",
    "enfolarmos": "enfolar",
    "enfolará": "enfolar",
    "enfolarás": "enfolar",
    "enfolarão": "enfolar",
    "enfolaríamos": "enfolar",
    "enfolaríeis": "enfolar",
    "enfolas": "enfolar",
    "enfolasse": "enfolar",
    "enfolassem": "enfolar",
    "enfolasses": "enfolar",
    "enfolaste": "enfolar",
    "enfolastes": "enfolar",
    "enfolava": "enfolar",
    "enfolavam": "enfolar",
    "enfolavas": "enfolar",
    "enfole": "enfolar",
    "enfolecha": "enfolechar",
    "enfolechada": "enfolechar",
    "enfolechadas": "enfolechar",
    "enfolechado": "enfolechar",
    "enfolechados": "enfolechar",
    "enfolechai": "enfolechar",
    "enfolechais": "enfolechar",
    "enfolecham": "enfolechar",
    "enfolechamo": "enfolechar",
    "enfolechamos": "enfolechar",
    "enfolechando": "enfolechar",
    "enfolechara": "enfolechar",
    "enfolecharam": "enfolechar",
    "enfolecharas": "enfolechar",
    "enfolecharde": "enfolechar",
    "enfolechardes": "enfolechar",
    "enfolechare": "enfolechar",
    "enfolecharei": "enfolechar",
    "enfolechareis": "enfolechar",
    "enfolecharem": "enfolechar",
    "enfolecharemos": "enfolechar",
    "enfolechares": "enfolechar",
    "enfolecharia": "enfolechar",
    "enfolechariam": "enfolechar",
    "enfolecharias": "enfolechar",
    "enfolecharmo": "enfolechar",
    "enfolecharmos": "enfolechar",
    "enfolechará": "enfolechar",
    "enfolecharás": "enfolechar",
    "enfolecharão": "enfolechar",
    "enfolecharíamos": "enfolechar",
    "enfolecharíeis": "enfolechar",
    "enfolechas": "enfolechar",
    "enfolechasse": "enfolechar",
    "enfolechassem": "enfolechar",
    "enfolechasses": "enfolechar",
    "enfolechaste": "enfolechar",
    "enfolechastes": "enfolechar",
    "enfolechava": "enfolechar",
    "enfolechavam": "enfolechar",
    "enfolechavas": "enfolechar",
    "enfoleche": "enfolechar",
    "enfolechei": "enfolechar",
    "enfolecheis": "enfolechar",
    "enfolechem": "enfolechar",
    "enfolechemo": "enfolechar",
    "enfolechemos": "enfolechar",
    "enfoleches": "enfolechar",
    "enfolecho": "enfolechar",
    "enfolechou": "enfolechar",
    "enfolechá": "enfolechar",
    "enfolechámo": "enfolechar",
    "enfolechámos": "enfolechar",
    "enfolecháramo": "enfolechar",
    "enfolecháramos": "enfolechar",
    "enfolechárei": "enfolechar",
    "enfolecháreis": "enfolechar",
    "enfolechásseis": "enfolechar",
    "enfolechássemos": "enfolechar",
    "enfolechávamo": "enfolechar",
    "enfolechávamos": "enfolechar",
    "enfolechávei": "enfolechar",
    "enfolecháveis": "enfolechar",
    "enfolei": "enfolar",
    "enfoleis": "enfolar",
    "enfolem": "enfolar",
    "enfolemo": "enfolar",
    "enfolemos": "enfolar",
    "enfoles": "enfolar",
    "enfolha": "enfolhar",
    "enfolhada": "enfolhar",
    "enfolhadas": "enfolhar",
    "enfolhado": "enfolhar",
    "enfolhados": "enfolhar",
    "enfolhai": "enfolhar",
    "enfolhais": "enfolhar",
    "enfolham": "enfolhar",
    "enfolhamentos": "enfolhamento",
    "enfolhamo": "enfolhar",
    "enfolhamos": "enfolhar",
    "enfolhando": "enfolhar",
    "enfolhara": "enfolhar",
    "enfolharam": "enfolhar",
    "enfolharas": "enfolhar",
    "enfolharde": "enfolhar",
    "enfolhardes": "enfolhar",
    "enfolhare": "enfolhar",
    "enfolharei": "enfolhar",
    "enfolhareis": "enfolhar",
    "enfolharem": "enfolhar",
    "enfolharemos": "enfolhar",
    "enfolhares": "enfolhar",
    "enfolharia": "enfolhar",
    "enfolhariam": "enfolhar",
    "enfolharias": "enfolhar",
    "enfolharmo": "enfolhar",
    "enfolharmos": "enfolhar",
    "enfolhará": "enfolhar",
    "enfolharás": "enfolhar",
    "enfolharão": "enfolhar",
    "enfolharíamos": "enfolhar",
    "enfolharíeis": "enfolhar",
    "enfolhas": "enfolhar",
    "enfolhasse": "enfolhar",
    "enfolhassem": "enfolhar",
    "enfolhasses": "enfolhar",
    "enfolhaste": "enfolhar",
    "enfolhastes": "enfolhar",
    "enfolhava": "enfolhar",
    "enfolhavam": "enfolhar",
    "enfolhavas": "enfolhar",
    "enfolhe": "enfolhar",
    "enfolhei": "enfolhar",
    "enfolheis": "enfolhar",
    "enfolhem": "enfolhar",
    "enfolhemo": "enfolhar",
    "enfolhemos": "enfolhar",
    "enfolhes": "enfolhar",
    "enfolho": "enfolhar",
    "enfolhou": "enfolhar",
    "enfolhá": "enfolhar",
    "enfolhámo": "enfolhar",
    "enfolhámos": "enfolhar",
    "enfolháramo": "enfolhar",
    "enfolháramos": "enfolhar",
    "enfolhárei": "enfolhar",
    "enfolháreis": "enfolhar",
    "enfolhásseis": "enfolhar",
    "enfolhássemos": "enfolhar",
    "enfolhávamo": "enfolhar",
    "enfolhávamos": "enfolhar",
    "enfolhávei": "enfolhar",
    "enfolháveis": "enfolhar",
    "enfolipa": "enfolipar",
    "enfolipada": "enfolipar",
    "enfolipadas": "enfolipar",
    "enfolipado": "enfolipar",
    "enfolipados": "enfolipar",
    "enfolipai": "enfolipar",
    "enfolipais": "enfolipar",
    "enfolipam": "enfolipar",
    "enfolipamo": "enfolipar",
    "enfolipamos": "enfolipar",
    "enfolipando": "enfolipar",
    "enfolipara": "enfolipar",
    "enfoliparam": "enfolipar",
    "enfoliparas": "enfolipar",
    "enfoliparde": "enfolipar",
    "enfolipardes": "enfolipar",
    "enfolipare": "enfolipar",
    "enfoliparei": "enfolipar",
    "enfolipareis": "enfolipar",
    "enfoliparem": "enfolipar",
    "enfoliparemos": "enfolipar",
    "enfolipares": "enfolipar",
    "enfoliparia": "enfolipar",
    "enfolipariam": "enfolipar",
    "enfoliparias": "enfolipar",
    "enfoliparmo": "enfolipar",
    "enfoliparmos": "enfolipar",
    "enfolipará": "enfolipar",
    "enfoliparás": "enfolipar",
    "enfoliparão": "enfolipar",
    "enfoliparíamos": "enfolipar",
    "enfoliparíeis": "enfolipar",
    "enfolipas": "enfolipar",
    "enfolipasse": "enfolipar",
    "enfolipassem": "enfolipar",
    "enfolipasses": "enfolipar",
    "enfolipaste": "enfolipar",
    "enfolipastes": "enfolipar",
    "enfolipava": "enfolipar",
    "enfolipavam": "enfolipar",
    "enfolipavas": "enfolipar",
    "enfolipe": "enfolipar",
    "enfolipei": "enfolipar",
    "enfolipeis": "enfolipar",
    "enfolipem": "enfolipar",
    "enfolipemo": "enfolipar",
    "enfolipemos": "enfolipar",
    "enfolipes": "enfolipar",
    "enfolipo": "enfolipar",
    "enfolipou": "enfolipar",
    "enfolipá": "enfolipar",
    "enfolipámo": "enfolipar",
    "enfolipámos": "enfolipar",
    "enfolipáramo": "enfolipar",
    "enfolipáramos": "enfolipar",
    "enfolipárei": "enfolipar",
    "enfolipáreis": "enfolipar",
    "enfolipásseis": "enfolipar",
    "enfolipássemos": "enfolipar",
    "enfolipávamo": "enfolipar",
    "enfolipávamos": "enfolipar",
    "enfolipávei": "enfolipar",
    "enfolipáveis": "enfolipar",
    "enfolo": "enfolar",
    "enfolou": "enfolar",
    "enfolá": "enfolar",
    "enfolámo": "enfolar",
    "enfolámos": "enfolar",
    "enfoláramo": "enfolar",
    "enfoláramos": "enfolar",
    "enfolárei": "enfolar",
    "enfoláreis": "enfolar",
    "enfolásseis": "enfolar",
    "enfolássemos": "enfolar",
    "enfolávamo": "enfolar",
    "enfolávamos": "enfolar",
    "enfolávei": "enfolar",
    "enfoláveis": "enfolar",
    "enfoques": "enfoque",
    "enforca": "enforcar",
    "enforcada": "enforcar",
    "enforcadas": "enforcar",
    "enforcado": "enforcar",
    "enforcados": "enforcar",
    "enforcai": "enforcar",
    "enforcais": "enforcar",
    "enforcam": "enforcar",
    "enforcamentos": "enforcamento",
    "enforcamo": "enforcar",
    "enforcamos": "enforcar",
    "enforcando": "enforcar",
    "enforcara": "enforcar",
    "enforcaram": "enforcar",
    "enforcaras": "enforcar",
    "enforcarde": "enforcar",
    "enforcardes": "enforcar",
    "enforcare": "enforcar",
    "enforcarei": "enforcar",
    "enforcareis": "enforcar",
    "enforcarem": "enforcar",
    "enforcaremos": "enforcar",
    "enforcares": "enforcar",
    "enforcaria": "enforcar",
    "enforcariam": "enforcar",
    "enforcarias": "enforcar",
    "enforcarmo": "enforcar",
    "enforcarmos": "enforcar",
    "enforcará": "enforcar",
    "enforcarás": "enforcar",
    "enforcarão": "enforcar",
    "enforcaríamos": "enforcar",
    "enforcaríeis": "enforcar",
    "enforcas": "enforcar",
    "enforcasse": "enforcar",
    "enforcassem": "enforcar",
    "enforcasses": "enforcar",
    "enforcaste": "enforcar",
    "enforcastes": "enforcar",
    "enforcava": "enforcar",
    "enforcavam": "enforcar",
    "enforcavas": "enforcar",
    "enforco": "enforcar",
    "enforcou": "enforcar",
    "enforcá": "enforcar",
    "enforcámo": "enforcar",
    "enforcámos": "enforcar",
    "enforcáramo": "enforcar",
    "enforcáramos": "enforcar",
    "enforcárei": "enforcar",
    "enforcáreis": "enforcar",
    "enforcásseis": "enforcar",
    "enforcássemos": "enforcar",
    "enforcávamo": "enforcar",
    "enforcávamos": "enforcar",
    "enforcávei": "enforcar",
    "enforcáveis": "enforcar",
    "enforja": "enforjar",
    "enforjada": "enforjar",
    "enforjadas": "enforjar",
    "enforjado": "enforjar",
    "enforjados": "enforjar",
    "enforjai": "enforjar",
    "enforjais": "enforjar",
    "enforjam": "enforjar",
    "enforjamo": "enforjar",
    "enforjamos": "enforjar",
    "enforjando": "enforjar",
    "enforjara": "enforjar",
    "enforjaram": "enforjar",
    "enforjaras": "enforjar",
    "enforjarde": "enforjar",
    "enforjardes": "enforjar",
    "enforjare": "enforjar",
    "enforjarei": "enforjar",
    "enforjareis": "enforjar",
    "enforjarem": "enforjar",
    "enforjaremos": "enforjar",
    "enforjares": "enforjar",
    "enforjaria": "enforjar",
    "enforjariam": "enforjar",
    "enforjarias": "enforjar",
    "enforjarmo": "enforjar",
    "enforjarmos": "enforjar",
    "enforjará": "enforjar",
    "enforjarás": "enforjar",
    "enforjarão": "enforjar",
    "enforjaríamos": "enforjar",
    "enforjaríeis": "enforjar",
    "enforjas": "enforjar",
    "enforjasse": "enforjar",
    "enforjassem": "enforjar",
    "enforjasses": "enforjar",
    "enforjaste": "enforjar",
    "enforjastes": "enforjar",
    "enforjava": "enforjar",
    "enforjavam": "enforjar",
    "enforjavas": "enforjar",
    "enforje": "enforjar",
    "enforjei": "enforjar",
    "enforjeis": "enforjar",
    "enforjem": "enforjar",
    "enforjemo": "enforjar",
    "enforjemos": "enforjar",
    "enforjes": "enforjar",
    "enforjo": "enforjar",
    "enforjou": "enforjar",
    "enforjá": "enforjar",
    "enforjámo": "enforjar",
    "enforjámos": "enforjar",
    "enforjáramo": "enforjar",
    "enforjáramos": "enforjar",
    "enforjárei": "enforjar",
    "enforjáreis": "enforjar",
    "enforjásseis": "enforjar",
    "enforjássemos": "enforjar",
    "enforjávamo": "enforjar",
    "enforjávamos": "enforjar",
    "enforjávei": "enforjar",
    "enforjáveis": "enforjar",
    "enforma": "enformar",
    "enformada": "enformar",
    "enformadas": "enformar",
    "enformadeira": "enformador",
    "enformadeiras": "enformador",
    "enformado": "enformar",
    "enformadora": "enformador",
    "enformadoras": "enformador",
    "enformadores": "enformador",
    "enformados": "enformar",
    "enformai": "enformar",
    "enformais": "enformar",
    "enformam": "enformar",
    "enformamo": "enformar",
    "enformamos": "enformar",
    "enformando": "enformar",
    "enformara": "enformar",
    "enformaram": "enformar",
    "enformaras": "enformar",
    "enformarde": "enformar",
    "enformardes": "enformar",
    "enformare": "enformar",
    "enformarei": "enformar",
    "enformareis": "enformar",
    "enformarem": "enformar",
    "enformaremos": "enformar",
    "enformares": "enformar",
    "enformaria": "enformar",
    "enformariam": "enformar",
    "enformarias": "enformar",
    "enformarmo": "enformar",
    "enformarmos": "enformar",
    "enformará": "enformar",
    "enformarás": "enformar",
    "enformarão": "enformar",
    "enformaríamos": "enformar",
    "enformaríeis": "enformar",
    "enformas": "enformar",
    "enformasse": "enformar",
    "enformassem": "enformar",
    "enformasses": "enformar",
    "enformaste": "enformar",
    "enformastes": "enformar",
    "enformava": "enformar",
    "enformavam": "enformar",
    "enformavas": "enformar",
    "enformações": "enformação",
    "enforme": "enformar",
    "enformei": "enformar",
    "enformeis": "enformar",
    "enformem": "enformar",
    "enformemo": "enformar",
    "enformemos": "enformar",
    "enformes": "enformar",
    "enformo": "enformar",
    "enformou": "enformar",
    "enformá": "enformar",
    "enformámo": "enformar",
    "enformámos": "enformar",
    "enformáramo": "enformar",
    "enformáramos": "enformar",
    "enformárei": "enformar",
    "enformáreis": "enformar",
    "enformásseis": "enformar",
    "enformássemos": "enformar",
    "enformávamo": "enformar",
    "enformávamos": "enformar",
    "enformávei": "enformar",
    "enformáveis": "enformar",
    "enforna": "enfornar",
    "enfornada": "enfornar",
    "enfornadas": "enfornar",
    "enfornado": "enfornar",
    "enfornados": "enfornar",
    "enfornai": "enfornar",
    "enfornais": "enfornar",
    "enfornam": "enfornar",
    "enfornamo": "enfornar",
    "enfornamos": "enfornar",
    "enfornando": "enfornar",
    "enfornara": "enfornar",
    "enfornaram": "enfornar",
    "enfornaras": "enfornar",
    "enfornarde": "enfornar",
    "enfornardes": "enfornar",
    "enfornare": "enfornar",
    "enfornarei": "enfornar",
    "enfornareis": "enfornar",
    "enfornarem": "enfornar",
    "enfornaremos": "enfornar",
    "enfornares": "enfornar",
    "enfornaria": "enfornar",
    "enfornariam": "enfornar",
    "enfornarias": "enfornar",
    "enfornarmo": "enfornar",
    "enfornarmos": "enfornar",
    "enfornará": "enfornar",
    "enfornarás": "enfornar",
    "enfornarão": "enfornar",
    "enfornaríamos": "enfornar",
    "enfornaríeis": "enfornar",
    "enfornas": "enfornar",
    "enfornasse": "enfornar",
    "enfornassem": "enfornar",
    "enfornasses": "enfornar",
    "enfornaste": "enfornar",
    "enfornastes": "enfornar",
    "enfornava": "enfornar",
    "enfornavam": "enfornar",
    "enfornavas": "enfornar",
    "enforne": "enfornar",
    "enfornei": "enfornar",
    "enforneis": "enfornar",
    "enfornem": "enfornar",
    "enfornemo": "enfornar",
    "enfornemos": "enfornar",
    "enfornes": "enfornar",
    "enforno": "enfornar",
    "enfornou": "enfornar",
    "enforná": "enfornar",
    "enfornámo": "enfornar",
    "enfornámos": "enfornar",
    "enfornáramo": "enfornar",
    "enfornáramos": "enfornar",
    "enfornárei": "enfornar",
    "enfornáreis": "enfornar",
    "enfornásseis": "enfornar",
    "enfornássemos": "enfornar",
    "enfornávamo": "enfornar",
    "enfornávamos": "enfornar",
    "enfornávei": "enfornar",
    "enfornáveis": "enfornar",
    "enforque": "enforcar",
    "enforquei": "enforcar",
    "enforqueis": "enforcar",
    "enforquem": "enforcar",
    "enforquemo": "enforcar",
    "enforquemos": "enforcar",
    "enforques": "enforcar",
    "enforquilha": "enforquilhar",
    "enforquilhada": "enforquilhar",
    "enforquilhadas": "enforquilhar",
    "enforquilhado": "enforquilhar",
    "enforquilhados": "enforquilhar",
    "enforquilhai": "enforquilhar",
    "enforquilhais": "enforquilhar",
    "enforquilham": "enforquilhar",
    "enforquilhamentos": "enforquilhamento",
    "enforquilhamo": "enforquilhar",
    "enforquilhamos": "enforquilhar",
    "enforquilhando": "enforquilhar",
    "enforquilhara": "enforquilhar",
    "enforquilharam": "enforquilhar",
    "enforquilharas": "enforquilhar",
    "enforquilharde": "enforquilhar",
    "enforquilhardes": "enforquilhar",
    "enforquilhare": "enforquilhar",
    "enforquilharei": "enforquilhar",
    "enforquilhareis": "enforquilhar",
    "enforquilharem": "enforquilhar",
    "enforquilharemos": "enforquilhar",
    "enforquilhares": "enforquilhar",
    "enforquilharia": "enforquilhar",
    "enforquilhariam": "enforquilhar",
    "enforquilharias": "enforquilhar",
    "enforquilharmo": "enforquilhar",
    "enforquilharmos": "enforquilhar",
    "enforquilhará": "enforquilhar",
    "enforquilharás": "enforquilhar",
    "enforquilharão": "enforquilhar",
    "enforquilharíamos": "enforquilhar",
    "enforquilharíeis": "enforquilhar",
    "enforquilhas": "enforquilhar",
    "enforquilhasse": "enforquilhar",
    "enforquilhassem": "enforquilhar",
    "enforquilhasses": "enforquilhar",
    "enforquilhaste": "enforquilhar",
    "enforquilhastes": "enforquilhar",
    "enforquilhava": "enforquilhar",
    "enforquilhavam": "enforquilhar",
    "enforquilhavas": "enforquilhar",
    "enforquilhe": "enforquilhar",
    "enforquilhei": "enforquilhar",
    "enforquilheis": "enforquilhar",
    "enforquilhem": "enforquilhar",
    "enforquilhemo": "enforquilhar",
    "enforquilhemos": "enforquilhar",
    "enforquilhes": "enforquilhar",
    "enforquilho": "enforquilhar",
    "enforquilhou": "enforquilhar",
    "enforquilhá": "enforquilhar",
    "enforquilhámo": "enforquilhar",
    "enforquilhámos": "enforquilhar",
    "enforquilháramo": "enforquilhar",
    "enforquilháramos": "enforquilhar",
    "enforquilhárei": "enforquilhar",
    "enforquilháreis": "enforquilhar",
    "enforquilhásseis": "enforquilhar",
    "enforquilhássemos": "enforquilhar",
    "enforquilhávamo": "enforquilhar",
    "enforquilhávamos": "enforquilhar",
    "enforquilhávei": "enforquilhar",
    "enforquilháveis": "enforquilhar",
    "enforros": "enforro",
    "enforta": "enfortir",
    "enfortada": "enfortar",
    "enfortadas": "enfortar",
    "enfortado": "enfortar",
    "enfortados": "enfortar",
    "enfortai": "enfortar",
    "enfortais": "enfortir",
    "enfortam": "enfortir",
    "enfortamo": "enfortir",
    "enfortamos": "enfortir",
    "enfortando": "enfortar",
    "enfortara": "enfortar",
    "enfortaram": "enfortar",
    "enfortaras": "enfortar",
    "enfortarde": "enfortar",
    "enfortardes": "enfortar",
    "enfortare": "enfortar",
    "enfortarei": "enfortar",
    "enfortareis": "enfortar",
    "enfortarem": "enfortar",
    "enfortaremos": "enfortar",
    "enfortares": "enfortar",
    "enfortaria": "enfortar",
    "enfortariam": "enfortar",
    "enfortarias": "enfortar",
    "enfortarmo": "enfortar",
    "enfortarmos": "enfortar",
    "enfortará": "enfortar",
    "enfortarás": "enfortar",
    "enfortarão": "enfortar",
    "enfortaríamos": "enfortar",
    "enfortaríeis": "enfortar",
    "enfortas": "enfortir",
    "enfortasse": "enfortar",
    "enfortassem": "enfortar",
    "enfortasses": "enfortar",
    "enfortaste": "enfortar",
    "enfortastes": "enfortar",
    "enfortava": "enfortar",
    "enfortavam": "enfortar",
    "enfortavas": "enfortar",
    "enforte": "enfortir",
    "enfortece": "enfortecer",
    "enfortecei": "enfortecer",
    "enforteceis": "enfortecer",
    "enfortecem": "enfortecer",
    "enfortecemo": "enfortecer",
    "enfortecemos": "enfortecer",
    "enfortecendo": "enfortecer",
    "enfortecera": "enfortecer",
    "enforteceram": "enfortecer",
    "enforteceras": "enfortecer",
    "enfortecerde": "enfortecer",
    "enfortecerdes": "enfortecer",
    "enfortecere": "enfortecer",
    "enfortecerei": "enfortecer",
    "enfortecereis": "enfortecer",
    "enfortecerem": "enfortecer",
    "enforteceremos": "enfortecer",
    "enforteceres": "enfortecer",
    "enforteceria": "enfortecer",
    "enforteceriam": "enfortecer",
    "enfortecerias": "enfortecer",
    "enfortecermo": "enfortecer",
    "enfortecermos": "enfortecer",
    "enfortecerá": "enfortecer",
    "enfortecerás": "enfortecer",
    "enfortecerão": "enfortecer",
    "enforteceríamos": "enfortecer",
    "enforteceríeis": "enfortecer",
    "enforteces": "enfortecer",
    "enfortecesse": "enfortecer",
    "enfortecessem": "enfortecer",
    "enfortecesses": "enfortecer",
    "enforteceste": "enfortecer",
    "enfortecestes": "enfortecer",
    "enforteceu": "enfortecer",
    "enforteci": "enfortecer",
    "enfortecia": "enfortecer",
    "enforteciam": "enfortecer",
    "enfortecias": "enfortecer",
    "enfortecida": "enfortecer",
    "enfortecidas": "enfortecer",
    "enfortecido": "enfortecer",
    "enfortecidos": "enfortecer",
    "enfortecimentos": "enfortecimento",
    "enfortecê": "enfortecer",
    "enfortecêramo": "enfortecer",
    "enfortecêramos": "enfortecer",
    "enfortecêrei": "enfortecer",
    "enfortecêreis": "enfortecer",
    "enfortecêsseis": "enfortecer",
    "enfortecêssemos": "enfortecer",
    "enfortecíamo": "enfortecer",
    "enfortecíamos": "enfortecer",
    "enfortecíei": "enfortecer",
    "enfortecíeis": "enfortecer",
    "enfortei": "enfortar",
    "enforteis": "enfortar",
    "enfortem": "enfortir",
    "enfortemo": "enfortar",
    "enfortemos": "enfortar",
    "enfortes": "enfortir",
    "enforteça": "enfortecer",
    "enforteçais": "enfortecer",
    "enforteçam": "enfortecer",
    "enforteçamo": "enfortecer",
    "enforteçamos": "enfortecer",
    "enforteças": "enfortecer",
    "enforteço": "enfortecer",
    "enforti": "enfortir",
    "enfortia": "enfortir",
    "enfortiam": "enfortir",
    "enfortias": "enfortir",
    "enfortida": "enfortir",
    "enfortidas": "enfortir",
    "enfortido": "enfortir",
    "enfortidos": "enfortir",
    "enfortimo": "enfortir",
    "enfortimos": "enfortir",
    "enfortindo": "enfortir",
    "enfortira": "enfortir",
    "enfortiram": "enfortir",
    "enfortiras": "enfortir",
    "enfortirde": "enfortir",
    "enfortirdes": "enfortir",
    "enfortire": "enfortir",
    "enfortirei": "enfortir",
    "enfortireis": "enfortir",
    "enfortirem": "enfortir",
    "enfortiremos": "enfortir",
    "enfortires": "enfortir",
    "enfortiria": "enfortir",
    "enfortiriam": "enfortir",
    "enfortirias": "enfortir",
    "enfortirmo": "enfortir",
    "enfortirmos": "enfortir",
    "enfortirá": "enfortir",
    "enfortirás": "enfortir",
    "enfortirão": "enfortir",
    "enfortiríamos": "enfortir",
    "enfortiríeis": "enfortir",
    "enfortis": "enfortir",
    "enfortisse": "enfortir",
    "enfortissem": "enfortir",
    "enfortisses": "enfortir",
    "enfortiste": "enfortir",
    "enfortistes": "enfortir",
    "enfortiu": "enfortir",
    "enforto": "enfortir",
    "enfortou": "enfortar",
    "enfortá": "enfortar",
    "enfortámo": "enfortar",
    "enfortámos": "enfortar",
    "enfortáramo": "enfortar",
    "enfortáramos": "enfortar",
    "enfortárei": "enfortar",
    "enfortáreis": "enfortar",
    "enfortásseis": "enfortar",
    "enfortássemos": "enfortar",
    "enfortávamo": "enfortar",
    "enfortávamos": "enfortar",
    "enfortávei": "enfortar",
    "enfortáveis": "enfortar",
    "enfortíamo": "enfortir",
    "enfortíamos": "enfortir",
    "enfortíei": "enfortir",
    "enfortíeis": "enfortir",
    "enfortíramo": "enfortir",
    "enfortíramos": "enfortir",
    "enfortírei": "enfortir",
    "enfortíreis": "enfortir",
    "enfortísseis": "enfortir",
    "enfortíssemos": "enfortir",
    "enfranqueada": "enfranquear",
    "enfranqueadas": "enfranquear",
    "enfranqueado": "enfranquear",
    "enfranqueados": "enfranquear",
    "enfranqueai": "enfranquear",
    "enfranqueais": "enfranquear",
    "enfranqueamo": "enfranquear",
    "enfranqueamos": "enfranquear",
    "enfranqueando": "enfranquear",
    "enfranqueara": "enfranquear",
    "enfranquearam": "enfranquear",
    "enfranquearas": "enfranquear",
    "enfranquearde": "enfranquear",
    "enfranqueardes": "enfranquear",
    "enfranqueare": "enfranquear",
    "enfranquearei": "enfranquear",
    "enfranqueareis": "enfranquear",
    "enfranquearem": "enfranquear",
    "enfranquearemos": "enfranquear",
    "enfranqueares": "enfranquear",
    "enfranquearia": "enfranquear",
    "enfranqueariam": "enfranquear",
    "enfranquearias": "enfranquear",
    "enfranquearmo": "enfranquear",
    "enfranquearmos": "enfranquear",
    "enfranqueará": "enfranquear",
    "enfranquearás": "enfranquear",
    "enfranquearão": "enfranquear",
    "enfranquearíamos": "enfranquear",
    "enfranquearíeis": "enfranquear",
    "enfranqueasse": "enfranquear",
    "enfranqueassem": "enfranquear",
    "enfranqueasses": "enfranquear",
    "enfranqueaste": "enfranquear",
    "enfranqueastes": "enfranquear",
    "enfranqueava": "enfranquear",
    "enfranqueavam": "enfranquear",
    "enfranqueavas": "enfranquear",
    "enfranqueei": "enfranquear",
    "enfranqueeis": "enfranquear",
    "enfranqueemo": "enfranquear",
    "enfranqueemos": "enfranquear",
    "enfranqueia": "enfranquear",
    "enfranqueiam": "enfranquear",
    "enfranqueias": "enfranquear",
    "enfranqueie": "enfranquear",
    "enfranqueiem": "enfranquear",
    "enfranqueies": "enfranquear",
    "enfranqueio": "enfranquear",
    "enfranqueou": "enfranquear",
    "enfranques": "enfranque",
    "enfranqueá": "enfranquear",
    "enfranqueámo": "enfranquear",
    "enfranqueámos": "enfranquear",
    "enfranqueáramo": "enfranquear",
    "enfranqueáramos": "enfranquear",
    "enfranqueárei": "enfranquear",
    "enfranqueáreis": "enfranquear",
    "enfranqueásseis": "enfranquear",
    "enfranqueássemos": "enfranquear",
    "enfranqueávamo": "enfranquear",
    "enfranqueávamos": "enfranquear",
    "enfranqueávei": "enfranquear",
    "enfranqueáveis": "enfranquear",
    "enfraquece": "enfraquecer",
    "enfraquecei": "enfraquecer",
    "enfraqueceis": "enfraquecer",
    "enfraquecem": "enfraquecer",
    "enfraquecemo": "enfraquecer",
    "enfraquecemos": "enfraquecer",
    "enfraquecendo": "enfraquecer",
    "enfraquecera": "enfraquecer",
    "enfraqueceram": "enfraquecer",
    "enfraqueceras": "enfraquecer",
    "enfraquecerde": "enfraquecer",
    "enfraquecerdes": "enfraquecer",
    "enfraquecere": "enfraquecer",
    "enfraquecerei": "enfraquecer",
    "enfraquecereis": "enfraquecer",
    "enfraquecerem": "enfraquecer",
    "enfraqueceremos": "enfraquecer",
    "enfraqueceres": "enfraquecer",
    "enfraqueceria": "enfraquecer",
    "enfraqueceriam": "enfraquecer",
    "enfraquecerias": "enfraquecer",
    "enfraquecermo": "enfraquecer",
    "enfraquecermos": "enfraquecer",
    "enfraquecerá": "enfraquecer",
    "enfraquecerás": "enfraquecer",
    "enfraquecerão": "enfraquecer",
    "enfraqueceríamos": "enfraquecer",
    "enfraqueceríeis": "enfraquecer",
    "enfraqueces": "enfraquecer",
    "enfraquecesse": "enfraquecer",
    "enfraquecessem": "enfraquecer",
    "enfraquecesses": "enfraquecer",
    "enfraqueceste": "enfraquecer",
    "enfraquecestes": "enfraquecer",
    "enfraqueceu": "enfraquecer",
    "enfraqueci": "enfraquecer",
    "enfraquecia": "enfraquecer",
    "enfraqueciam": "enfraquecer",
    "enfraquecias": "enfraquecer",
    "enfraquecida": "enfraquecido",
    "enfraquecidas": "enfraquecido",
    "enfraquecido": "enfraquecer",
    "enfraquecidos": "enfraquecido",
    "enfraquecimentos": "enfraquecimento",
    "enfraquecê": "enfraquecer",
    "enfraquecêramo": "enfraquecer",
    "enfraquecêramos": "enfraquecer",
    "enfraquecêrei": "enfraquecer",
    "enfraquecêreis": "enfraquecer",
    "enfraquecêsseis": "enfraquecer",
    "enfraquecêssemos": "enfraquecer",
    "enfraquecíamo": "enfraquecer",
    "enfraquecíamos": "enfraquecer",
    "enfraquecíei": "enfraquecer",
    "enfraquecíeis": "enfraquecer",
    "enfraquecíveis": "enfraquecível",
    "enfraquenta": "enfraquentar",
    "enfraquentada": "enfraquentar",
    "enfraquentadas": "enfraquentar",
    "enfraquentado": "enfraquentar",
    "enfraquentados": "enfraquentar",
    "enfraquentai": "enfraquentar",
    "enfraquentais": "enfraquentar",
    "enfraquentam": "enfraquentar",
    "enfraquentamo": "enfraquentar",
    "enfraquentamos": "enfraquentar",
    "enfraquentando": "enfraquentar",
    "enfraquentara": "enfraquentar",
    "enfraquentaram": "enfraquentar",
    "enfraquentaras": "enfraquentar",
    "enfraquentarde": "enfraquentar",
    "enfraquentardes": "enfraquentar",
    "enfraquentare": "enfraquentar",
    "enfraquentarei": "enfraquentar",
    "enfraquentareis": "enfraquentar",
    "enfraquentarem": "enfraquentar",
    "enfraquentaremos": "enfraquentar",
    "enfraquentares": "enfraquentar",
    "enfraquentaria": "enfraquentar",
    "enfraquentariam": "enfraquentar",
    "enfraquentarias": "enfraquentar",
    "enfraquentarmo": "enfraquentar",
    "enfraquentarmos": "enfraquentar",
    "enfraquentará": "enfraquentar",
    "enfraquentarás": "enfraquentar",
    "enfraquentarão": "enfraquentar",
    "enfraquentaríamos": "enfraquentar",
    "enfraquentaríeis": "enfraquentar",
    "enfraquentas": "enfraquentar",
    "enfraquentasse": "enfraquentar",
    "enfraquentassem": "enfraquentar",
    "enfraquentasses": "enfraquentar",
    "enfraquentaste": "enfraquentar",
    "enfraquentastes": "enfraquentar",
    "enfraquentava": "enfraquentar",
    "enfraquentavam": "enfraquentar",
    "enfraquentavas": "enfraquentar",
    "enfraquente": "enfraquentar",
    "enfraquentei": "enfraquentar",
    "enfraquenteis": "enfraquentar",
    "enfraquentem": "enfraquentar",
    "enfraquentemo": "enfraquentar",
    "enfraquentemos": "enfraquentar",
    "enfraquentes": "enfraquentar",
    "enfraquento": "enfraquentar",
    "enfraquentou": "enfraquentar",
    "enfraquentá": "enfraquentar",
    "enfraquentámo": "enfraquentar",
    "enfraquentámos": "enfraquentar",
    "enfraquentáramo": "enfraquentar",
    "enfraquentáramos": "enfraquentar",
    "enfraquentárei": "enfraquentar",
    "enfraquentáreis": "enfraquentar",
    "enfraquentásseis": "enfraquentar",
    "enfraquentássemos": "enfraquentar",
    "enfraquentávamo": "enfraquentar",
    "enfraquentávamos": "enfraquentar",
    "enfraquentávei": "enfraquentar",
    "enfraquentáveis": "enfraquentar",
    "enfraqueça": "enfraquecer",
    "enfraqueçais": "enfraquecer",
    "enfraqueçam": "enfraquecer",
    "enfraqueçamo": "enfraquecer",
    "enfraqueçamos": "enfraquecer",
    "enfraqueças": "enfraquecer",
    "enfraqueço": "enfraquecer",
    "enfrasca": "enfrascar",
    "enfrascada": "enfrascar",
    "enfrascadas": "enfrascar",
    "enfrascado": "enfrascar",
    "enfrascados": "enfrascar",
    "enfrascai": "enfrascar",
    "enfrascais": "enfrascar",
    "enfrascam": "enfrascar",
    "enfrascamo": "enfrascar",
    "enfrascamos": "enfrascar",
    "enfrascando": "enfrascar",
    "enfrascara": "enfrascar",
    "enfrascaram": "enfrascar",
    "enfrascaras": "enfrascar",
    "enfrascarde": "enfrascar",
    "enfrascardes": "enfrascar",
    "enfrascare": "enfrascar",
    "enfrascarei": "enfrascar",
    "enfrascareis": "enfrascar",
    "enfrascarem": "enfrascar",
    "enfrascaremos": "enfrascar",
    "enfrascares": "enfrascar",
    "enfrascaria": "enfrascar",
    "enfrascariam": "enfrascar",
    "enfrascarias": "enfrascar",
    "enfrascarmo": "enfrascar",
    "enfrascarmos": "enfrascar",
    "enfrascará": "enfrascar",
    "enfrascarás": "enfrascar",
    "enfrascarão": "enfrascar",
    "enfrascaríamos": "enfrascar",
    "enfrascaríeis": "enfrascar",
    "enfrascas": "enfrascar",
    "enfrascasse": "enfrascar",
    "enfrascassem": "enfrascar",
    "enfrascasses": "enfrascar",
    "enfrascaste": "enfrascar",
    "enfrascastes": "enfrascar",
    "enfrascava": "enfrascar",
    "enfrascavam": "enfrascar",
    "enfrascavas": "enfrascar",
    "enfrasco": "enfrascar",
    "enfrascou": "enfrascar",
    "enfrascá": "enfrascar",
    "enfrascámo": "enfrascar",
    "enfrascámos": "enfrascar",
    "enfrascáramo": "enfrascar",
    "enfrascáramos": "enfrascar",
    "enfrascárei": "enfrascar",
    "enfrascáreis": "enfrascar",
    "enfrascásseis": "enfrascar",
    "enfrascássemos": "enfrascar",
    "enfrascávamo": "enfrascar",
    "enfrascávamos": "enfrascar",
    "enfrascávei": "enfrascar",
    "enfrascáveis": "enfrascar",
    "enfrasque": "enfrascar",
    "enfrasquei": "enfrascar",
    "enfrasqueis": "enfrascar",
    "enfrasquem": "enfrascar",
    "enfrasquemo": "enfrascar",
    "enfrasquemos": "enfrascar",
    "enfrasques": "enfrascar",
    "enfraxias": "enfraxia",
    "enfreada": "enfrear",
    "enfreadas": "enfrear",
    "enfreado": "enfrear",
    "enfreadora": "enfreador",
    "enfreadoras": "enfreador",
    "enfreadores": "enfreador",
    "enfreados": "enfrear",
    "enfreai": "enfrear",
    "enfreais": "enfrear",
    "enfreamentos": "enfreamento",
    "enfreamo": "enfrear",
    "enfreamos": "enfrear",
    "enfreando": "enfrear",
    "enfreara": "enfrear",
    "enfrearam": "enfrear",
    "enfrearas": "enfrear",
    "enfrearde": "enfrear",
    "enfreardes": "enfrear",
    "enfreare": "enfrear",
    "enfrearei": "enfrear",
    "enfreareis": "enfrear",
    "enfrearem": "enfrear",
    "enfrearemos": "enfrear",
    "enfreares": "enfrear",
    "enfrearia": "enfrear",
    "enfreariam": "enfrear",
    "enfrearias": "enfrear",
    "enfrearmo": "enfrear",
    "enfrearmos": "enfrear",
    "enfreará": "enfrear",
    "enfrearás": "enfrear",
    "enfrearão": "enfrear",
    "enfrearíamos": "enfrear",
    "enfrearíeis": "enfrear",
    "enfreasse": "enfrear",
    "enfreassem": "enfrear",
    "enfreasses": "enfrear",
    "enfreaste": "enfrear",
    "enfreastes": "enfrear",
    "enfreava": "enfrear",
    "enfreavam": "enfrear",
    "enfreavas": "enfrear",
    "enfrecha": "enfrechar",
    "enfrechada": "enfrechar",
    "enfrechadas": "enfrechar",
    "enfrechado": "enfrechar",
    "enfrechados": "enfrechar",
    "enfrechaduras": "enfrechadura",
    "enfrechai": "enfrechar",
    "enfrechais": "enfrechar",
    "enfrecham": "enfrechar",
    "enfrechamo": "enfrechar",
    "enfrechamos": "enfrechar",
    "enfrechando": "enfrechar",
    "enfrechara": "enfrechar",
    "enfrecharam": "enfrechar",
    "enfrecharas": "enfrechar",
    "enfrecharde": "enfrechar",
    "enfrechardes": "enfrechar",
    "enfrechare": "enfrechar",
    "enfrecharei": "enfrechar",
    "enfrechareis": "enfrechar",
    "enfrecharem": "enfrechar",
    "enfrecharemos": "enfrechar",
    "enfrechares": "enfrechar",
    "enfrecharia": "enfrechar",
    "enfrechariam": "enfrechar",
    "enfrecharias": "enfrechar",
    "enfrecharmo": "enfrechar",
    "enfrecharmos": "enfrechar",
    "enfrechará": "enfrechar",
    "enfrecharás": "enfrechar",
    "enfrecharão": "enfrechar",
    "enfrecharíamos": "enfrechar",
    "enfrecharíeis": "enfrechar",
    "enfrechas": "enfrechar",
    "enfrechasse": "enfrechar",
    "enfrechassem": "enfrechar",
    "enfrechasses": "enfrechar",
    "enfrechaste": "enfrechar",
    "enfrechastes": "enfrechar",
    "enfrechates": "enfrechate",
    "enfrechava": "enfrechar",
    "enfrechavam": "enfrechar",
    "enfrechavas": "enfrechar",
    "enfreche": "enfrechar",
    "enfrechei": "enfrechar",
    "enfrecheis": "enfrechar",
    "enfrechem": "enfrechar",
    "enfrechemo": "enfrechar",
    "enfrechemos": "enfrechar",
    "enfreches": "enfrechar",
    "enfrecho": "enfrechar",
    "enfrechou": "enfrechar",
    "enfrechá": "enfrechar",
    "enfrechámo": "enfrechar",
    "enfrechámos": "enfrechar",
    "enfrecháramo": "enfrechar",
    "enfrecháramos": "enfrechar",
    "enfrechárei": "enfrechar",
    "enfrecháreis": "enfrechar",
    "enfrechásseis": "enfrechar",
    "enfrechássemos": "enfrechar",
    "enfrechávamo": "enfrechar",
    "enfrechávamos": "enfrechar",
    "enfrechávei": "enfrechar",
    "enfrecháveis": "enfrechar",
    "enfreei": "enfrear",
    "enfreeis": "enfrear",
    "enfreemo": "enfrear",
    "enfreemos": "enfrear",
    "enfreia": "enfrear",
    "enfreiam": "enfrear",
    "enfreias": "enfrear",
    "enfreie": "enfrear",
    "enfreiem": "enfrear",
    "enfreies": "enfrear",
    "enfreio": "enfrear",
    "enfrenesia": "enfrenesiar",
    "enfrenesiada": "enfrenesiar",
    "enfrenesiadas": "enfrenesiar",
    "enfrenesiado": "enfrenesiar",
    "enfrenesiados": "enfrenesiar",
    "enfrenesiai": "enfrenesiar",
    "enfrenesiais": "enfrenesiar",
    "enfrenesiam": "enfrenesiar",
    "enfrenesiamo": "enfrenesiar",
    "enfrenesiamos": "enfrenesiar",
    "enfrenesiando": "enfrenesiar",
    "enfrenesiara": "enfrenesiar",
    "enfrenesiaram": "enfrenesiar",
    "enfrenesiaras": "enfrenesiar",
    "enfrenesiarde": "enfrenesiar",
    "enfrenesiardes": "enfrenesiar",
    "enfrenesiare": "enfrenesiar",
    "enfrenesiarei": "enfrenesiar",
    "enfrenesiareis": "enfrenesiar",
    "enfrenesiarem": "enfrenesiar",
    "enfrenesiaremos": "enfrenesiar",
    "enfrenesiares": "enfrenesiar",
    "enfrenesiaria": "enfrenesiar",
    "enfrenesiariam": "enfrenesiar",
    "enfrenesiarias": "enfrenesiar",
    "enfrenesiarmo": "enfrenesiar",
    "enfrenesiarmos": "enfrenesiar",
    "enfrenesiará": "enfrenesiar",
    "enfrenesiarás": "enfrenesiar",
    "enfrenesiarão": "enfrenesiar",
    "enfrenesiaríamos": "enfrenesiar",
    "enfrenesiaríeis": "enfrenesiar",
    "enfrenesias": "enfrenesiar",
    "enfrenesiasse": "enfrenesiar",
    "enfrenesiassem": "enfrenesiar",
    "enfrenesiasses": "enfrenesiar",
    "enfrenesiaste": "enfrenesiar",
    "enfrenesiastes": "enfrenesiar",
    "enfrenesiava": "enfrenesiar",
    "enfrenesiavam": "enfrenesiar",
    "enfrenesiavas": "enfrenesiar",
    "enfrenesie": "enfrenesiar",
    "enfrenesiei": "enfrenesiar",
    "enfrenesieis": "enfrenesiar",
    "enfrenesiem": "enfrenesiar",
    "enfrenesiemo": "enfrenesiar",
    "enfrenesiemos": "enfrenesiar",
    "enfrenesies": "enfrenesiar",
    "enfrenesio": "enfrenesiar",
    "enfrenesiou": "enfrenesiar",
    "enfrenesiá": "enfrenesiar",
    "enfrenesiámo": "enfrenesiar",
    "enfrenesiámos": "enfrenesiar",
    "enfrenesiáramo": "enfrenesiar",
    "enfrenesiáramos": "enfrenesiar",
    "enfrenesiárei": "enfrenesiar",
    "enfrenesiáreis": "enfrenesiar",
    "enfrenesiásseis": "enfrenesiar",
    "enfrenesiássemos": "enfrenesiar",
    "enfrenesiávamo": "enfrenesiar",
    "enfrenesiávamos": "enfrenesiar",
    "enfrenesiávei": "enfrenesiar",
    "enfrenesiáveis": "enfrenesiar",
    "enfrenta": "enfrentar",
    "enfrentada": "enfrentar",
    "enfrentadas": "enfrentar",
    "enfrentado": "enfrentar",
    "enfrentados": "enfrentar",
    "enfrentai": "enfrentar",
    "enfrentais": "enfrentar",
    "enfrentam": "enfrentar",
    "enfrentamentos": "enfrentamento",
    "enfrentamo": "enfrentar",
    "enfrentamos": "enfrentar",
    "enfrentando": "enfrentar",
    "enfrentara": "enfrentar",
    "enfrentaram": "enfrentar",
    "enfrentaras": "enfrentar",
    "enfrentarde": "enfrentar",
    "enfrentardes": "enfrentar",
    "enfrentare": "enfrentar",
    "enfrentarei": "enfrentar",
    "enfrentareis": "enfrentar",
    "enfrentarem": "enfrentar",
    "enfrentaremos": "enfrentar",
    "enfrentares": "enfrentar",
    "enfrentaria": "enfrentar",
    "enfrentariam": "enfrentar",
    "enfrentarias": "enfrentar",
    "enfrentarmo": "enfrentar",
    "enfrentarmos": "enfrentar",
    "enfrentará": "enfrentar",
    "enfrentarás": "enfrentar",
    "enfrentarão": "enfrentar",
    "enfrentaríamos": "enfrentar",
    "enfrentaríeis": "enfrentar",
    "enfrentas": "enfrentar",
    "enfrentasse": "enfrentar",
    "enfrentassem": "enfrentar",
    "enfrentasses": "enfrentar",
    "enfrentaste": "enfrentar",
    "enfrentastes": "enfrentar",
    "enfrentava": "enfrentar",
    "enfrentavam": "enfrentar",
    "enfrentavas": "enfrentar",
    "enfrente": "enfrentar",
    "enfrentei": "enfrentar",
    "enfrenteis": "enfrentar",
    "enfrentem": "enfrentar",
    "enfrentemo": "enfrentar",
    "enfrentemos": "enfrentar",
    "enfrentes": "enfrentar",
    "enfrento": "enfrentar",
    "enfrentou": "enfrentar",
    "enfrentá": "enfrentar",
    "enfrentámo": "enfrentar",
    "enfrentámos": "enfrentar",
    "enfrentáramo": "enfrentar",
    "enfrentáramos": "enfrentar",
    "enfrentárei": "enfrentar",
    "enfrentáreis": "enfrentar",
    "enfrentásseis": "enfrentar",
    "enfrentássemos": "enfrentar",
    "enfrentávamo": "enfrentar",
    "enfrentávamos": "enfrentar",
    "enfrentávei": "enfrentar",
    "enfrentáveis": "enfrentável",
    "enfreou": "enfrear",
    "enfreá": "enfrear",
    "enfreámo": "enfrear",
    "enfreámos": "enfrear",
    "enfreáramo": "enfrear",
    "enfreáramos": "enfrear",
    "enfreárei": "enfrear",
    "enfreáreis": "enfrear",
    "enfreásseis": "enfrear",
    "enfreássemos": "enfrear",
    "enfreávamo": "enfrear",
    "enfreávamos": "enfrear",
    "enfreávei": "enfrear",
    "enfreáveis": "enfrear",
    "enfria": "enfriar",
    "enfriada": "enfriar",
    "enfriadas": "enfriar",
    "enfriado": "enfriar",
    "enfriados": "enfriar",
    "enfriai": "enfriar",
    "enfriais": "enfriar",
    "enfriam": "enfriar",
    "enfriamo": "enfriar",
    "enfriamos": "enfriar",
    "enfriando": "enfriar",
    "enfriara": "enfriar",
    "enfriaram": "enfriar",
    "enfriaras": "enfriar",
    "enfriarde": "enfriar",
    "enfriardes": "enfriar",
    "enfriare": "enfriar",
    "enfriarei": "enfriar",
    "enfriareis": "enfriar",
    "enfriarem": "enfriar",
    "enfriaremos": "enfriar",
    "enfriares": "enfriar",
    "enfriaria": "enfriar",
    "enfriariam": "enfriar",
    "enfriarias": "enfriar",
    "enfriarmo": "enfriar",
    "enfriarmos": "enfriar",
    "enfriará": "enfriar",
    "enfriarás": "enfriar",
    "enfriarão": "enfriar",
    "enfriaríamos": "enfriar",
    "enfriaríeis": "enfriar",
    "enfrias": "enfriar",
    "enfriasse": "enfriar",
    "enfriassem": "enfriar",
    "enfriasses": "enfriar",
    "enfriaste": "enfriar",
    "enfriastes": "enfriar",
    "enfriava": "enfriar",
    "enfriavam": "enfriar",
    "enfriavas": "enfriar",
    "enfrie": "enfriar",
    "enfriei": "enfriar",
    "enfrieis": "enfriar",
    "enfriem": "enfriar",
    "enfriemo": "enfriar",
    "enfriemos": "enfriar",
    "enfries": "enfriar",
    "enfrio": "enfriar",
    "enfriou": "enfriar",
    "enfriá": "enfriar",
    "enfriámo": "enfriar",
    "enfriámos": "enfriar",
    "enfriáramo": "enfriar",
    "enfriáramos": "enfriar",
    "enfriárei": "enfriar",
    "enfriáreis": "enfriar",
    "enfriásseis": "enfriar",
    "enfriássemos": "enfriar",
    "enfriávamo": "enfriar",
    "enfriávamos": "enfriar",
    "enfriávei": "enfriar",
    "enfriáveis": "enfriar",
    "enfroixece": "enfroixecer",
    "enfroixecei": "enfroixecer",
    "enfroixeceis": "enfroixecer",
    "enfroixecem": "enfroixecer",
    "enfroixecemo": "enfroixecer",
    "enfroixecemos": "enfroixecer",
    "enfroixecendo": "enfroixecer",
    "enfroixecera": "enfroixecer",
    "enfroixeceram": "enfroixecer",
    "enfroixeceras": "enfroixecer",
    "enfroixecerde": "enfroixecer",
    "enfroixecerdes": "enfroixecer",
    "enfroixecere": "enfroixecer",
    "enfroixecerei": "enfroixecer",
    "enfroixecereis": "enfroixecer",
    "enfroixecerem": "enfroixecer",
    "enfroixeceremos": "enfroixecer",
    "enfroixeceres": "enfroixecer",
    "enfroixeceria": "enfroixecer",
    "enfroixeceriam": "enfroixecer",
    "enfroixecerias": "enfroixecer",
    "enfroixecermo": "enfroixecer",
    "enfroixecermos": "enfroixecer",
    "enfroixecerá": "enfroixecer",
    "enfroixecerás": "enfroixecer",
    "enfroixecerão": "enfroixecer",
    "enfroixeceríamos": "enfroixecer",
    "enfroixeceríeis": "enfroixecer",
    "enfroixeces": "enfroixecer",
    "enfroixecesse": "enfroixecer",
    "enfroixecessem": "enfroixecer",
    "enfroixecesses": "enfroixecer",
    "enfroixeceste": "enfroixecer",
    "enfroixecestes": "enfroixecer",
    "enfroixeceu": "enfroixecer",
    "enfroixeci": "enfroixecer",
    "enfroixecia": "enfroixecer",
    "enfroixeciam": "enfroixecer",
    "enfroixecias": "enfroixecer",
    "enfroixecida": "enfroixecer",
    "enfroixecidas": "enfroixecer",
    "enfroixecido": "enfroixecer",
    "enfroixecidos": "enfroixecer",
    "enfroixecê": "enfroixecer",
    "enfroixecêramo": "enfroixecer",
    "enfroixecêramos": "enfroixecer",
    "enfroixecêrei": "enfroixecer",
    "enfroixecêreis": "enfroixecer",
    "enfroixecêsseis": "enfroixecer",
    "enfroixecêssemos": "enfroixecer",
    "enfroixecíamo": "enfroixecer",
    "enfroixecíamos": "enfroixecer",
    "enfroixecíei": "enfroixecer",
    "enfroixecíeis": "enfroixecer",
    "enfroixeça": "enfroixecer",
    "enfroixeçais": "enfroixecer",
    "enfroixeçam": "enfroixecer",
    "enfroixeçamo": "enfroixecer",
    "enfroixeçamos": "enfroixecer",
    "enfroixeças": "enfroixecer",
    "enfroixeço": "enfroixecer",
    "enfronha": "enfronhar",
    "enfronhada": "enfronhar",
    "enfronhadas": "enfronhar",
    "enfronhado": "enfronhar",
    "enfronhados": "enfronhar",
    "enfronhai": "enfronhar",
    "enfronhais": "enfronhar",
    "enfronham": "enfronhar",
    "enfronhamentos": "enfronhamento",
    "enfronhamo": "enfronhar",
    "enfronhamos": "enfronhar",
    "enfronhando": "enfronhar",
    "enfronhara": "enfronhar",
    "enfronharam": "enfronhar",
    "enfronharas": "enfronhar",
    "enfronharde": "enfronhar",
    "enfronhardes": "enfronhar",
    "enfronhare": "enfronhar",
    "enfronharei": "enfronhar",
    "enfronhareis": "enfronhar",
    "enfronharem": "enfronhar",
    "enfronharemos": "enfronhar",
    "enfronhares": "enfronhar",
    "enfronharia": "enfronhar",
    "enfronhariam": "enfronhar",
    "enfronharias": "enfronhar",
    "enfronharmo": "enfronhar",
    "enfronharmos": "enfronhar",
    "enfronhará": "enfronhar",
    "enfronharás": "enfronhar",
    "enfronharão": "enfronhar",
    "enfronharíamos": "enfronhar",
    "enfronharíeis": "enfronhar",
    "enfronhas": "enfronhar",
    "enfronhasse": "enfronhar",
    "enfronhassem": "enfronhar",
    "enfronhasses": "enfronhar",
    "enfronhaste": "enfronhar",
    "enfronhastes": "enfronhar",
    "enfronhava": "enfronhar",
    "enfronhavam": "enfronhar",
    "enfronhavas": "enfronhar",
    "enfronhe": "enfronhar",
    "enfronhei": "enfronhar",
    "enfronheis": "enfronhar",
    "enfronhem": "enfronhar",
    "enfronhemo": "enfronhar",
    "enfronhemos": "enfronhar",
    "enfronhes": "enfronhar",
    "enfronho": "enfronhar",
    "enfronhou": "enfronhar",
    "enfronhá": "enfronhar",
    "enfronhámo": "enfronhar",
    "enfronhámos": "enfronhar",
    "enfronháramo": "enfronhar",
    "enfronháramos": "enfronhar",
    "enfronhárei": "enfronhar",
    "enfronháreis": "enfronhar",
    "enfronhásseis": "enfronhar",
    "enfronhássemos": "enfronhar",
    "enfronhávamo": "enfronhar",
    "enfronhávamos": "enfronhar",
    "enfronhávei": "enfronhar",
    "enfronháveis": "enfronhar",
    "enfrouxece": "enfrouxecer",
    "enfrouxecei": "enfrouxecer",
    "enfrouxeceis": "enfrouxecer",
    "enfrouxecem": "enfrouxecer",
    "enfrouxecemo": "enfrouxecer",
    "enfrouxecemos": "enfrouxecer",
    "enfrouxecendo": "enfrouxecer",
    "enfrouxecera": "enfrouxecer",
    "enfrouxeceram": "enfrouxecer",
    "enfrouxeceras": "enfrouxecer",
    "enfrouxecerde": "enfrouxecer",
    "enfrouxecerdes": "enfrouxecer",
    "enfrouxecere": "enfrouxecer",
    "enfrouxecerei": "enfrouxecer",
    "enfrouxecereis": "enfrouxecer",
    "enfrouxecerem": "enfrouxecer",
    "enfrouxeceremos": "enfrouxecer",
    "enfrouxeceres": "enfrouxecer",
    "enfrouxeceria": "enfrouxecer",
    "enfrouxeceriam": "enfrouxecer",
    "enfrouxecerias": "enfrouxecer",
    "enfrouxecermo": "enfrouxecer",
    "enfrouxecermos": "enfrouxecer",
    "enfrouxecerá": "enfrouxecer",
    "enfrouxecerás": "enfrouxecer",
    "enfrouxecerão": "enfrouxecer",
    "enfrouxeceríamos": "enfrouxecer",
    "enfrouxeceríeis": "enfrouxecer",
    "enfrouxeces": "enfrouxecer",
    "enfrouxecesse": "enfrouxecer",
    "enfrouxecessem": "enfrouxecer",
    "enfrouxecesses": "enfrouxecer",
    "enfrouxeceste": "enfrouxecer",
    "enfrouxecestes": "enfrouxecer",
    "enfrouxeceu": "enfrouxecer",
    "enfrouxeci": "enfrouxecer",
    "enfrouxecia": "enfrouxecer",
    "enfrouxeciam": "enfrouxecer",
    "enfrouxecias": "enfrouxecer",
    "enfrouxecida": "enfrouxecer",
    "enfrouxecidas": "enfrouxecer",
    "enfrouxecido": "enfrouxecer",
    "enfrouxecidos": "enfrouxecer",
    "enfrouxecê": "enfrouxecer",
    "enfrouxecêramo": "enfrouxecer",
    "enfrouxecêramos": "enfrouxecer",
    "enfrouxecêrei": "enfrouxecer",
    "enfrouxecêreis": "enfrouxecer",
    "enfrouxecêsseis": "enfrouxecer",
    "enfrouxecêssemos": "enfrouxecer",
    "enfrouxecíamo": "enfrouxecer",
    "enfrouxecíamos": "enfrouxecer",
    "enfrouxecíei": "enfrouxecer",
    "enfrouxecíeis": "enfrouxecer",
    "enfrouxeça": "enfrouxecer",
    "enfrouxeçais": "enfrouxecer",
    "enfrouxeçam": "enfrouxecer",
    "enfrouxeçamo": "enfrouxecer",
    "enfrouxeçamos": "enfrouxecer",
    "enfrouxeças": "enfrouxecer",
    "enfrouxeço": "enfrouxecer",
    "enfrunhada": "enfrunhado",
    "enfrunhadas": "enfrunhado",
    "enfrunhados": "enfrunhado",
    "enfrutece": "enfrutecer",
    "enfrutecei": "enfrutecer",
    "enfruteceis": "enfrutecer",
    "enfrutecem": "enfrutecer",
    "enfrutecemo": "enfrutecer",
    "enfrutecemos": "enfrutecer",
    "enfrutecendo": "enfrutecer",
    "enfrutecera": "enfrutecer",
    "enfruteceram": "enfrutecer",
    "enfruteceras": "enfrutecer",
    "enfrutecerdes": "enfrutecer",
    "enfrutecerei": "enfrutecer",
    "enfrutecereis": "enfrutecer",
    "enfrutecerem": "enfrutecer",
    "enfruteceremos": "enfrutecer",
    "enfruteceres": "enfrutecer",
    "enfruteceria": "enfrutecer",
    "enfruteceriam": "enfrutecer",
    "enfrutecerias": "enfrutecer",
    "enfrutecermo": "enfrutecer",
    "enfrutecermos": "enfrutecer",
    "enfrutecerá": "enfrutecer",
    "enfrutecerás": "enfrutecer",
    "enfrutecerão": "enfrutecer",
    "enfruteceríamos": "enfrutecer",
    "enfruteceríeis": "enfrutecer",
    "enfruteces": "enfrutecer",
    "enfrutecesse": "enfrutecer",
    "enfrutecessem": "enfrutecer",
    "enfrutecesses": "enfrutecer",
    "enfruteceste": "enfrutecer",
    "enfrutecestes": "enfrutecer",
    "enfruteceu": "enfrutecer",
    "enfruteci": "enfrutecer",
    "enfrutecia": "enfrutecer",
    "enfruteciam": "enfrutecer",
    "enfrutecias": "enfrutecer",
    "enfrutecida": "enfrutecido",
    "enfrutecidas": "enfrutecido",
    "enfrutecido": "enfrutecer",
    "enfrutecidos": "enfrutecido",
    "enfrutecimentos": "enfrutecimento",
    "enfrutecêramo": "enfrutecer",
    "enfrutecêramos": "enfrutecer",
    "enfrutecêreis": "enfrutecer",
    "enfrutecêsseis": "enfrutecer",
    "enfrutecêssemos": "enfrutecer",
    "enfrutecíamo": "enfrutecer",
    "enfrutecíamos": "enfrutecer",
    "enfrutecíeis": "enfrutecer",
    "enfruteça": "enfrutecer",
    "enfruteçais": "enfrutecer",
    "enfruteçam": "enfrutecer",
    "enfruteçamo": "enfrutecer",
    "enfruteçamos": "enfrutecer",
    "enfruteças": "enfrutecer",
    "enfruteço": "enfrutecer",
    "enfráctica": "enfráctico",
    "enfrácticas": "enfráctico",
    "enfrácticos": "enfráctico",
    "enfrática": "enfrático",
    "enfráticas": "enfrático",
    "enfráticos": "enfrático",
    "enfueira": "enfueirar",
    "enfueirada": "enfueirar",
    "enfueiradas": "enfueirar",
    "enfueirado": "enfueirar",
    "enfueirados": "enfueirar",
    "enfueirai": "enfueirar",
    "enfueirais": "enfueirar",
    "enfueiram": "enfueirar",
    "enfueiramo": "enfueirar",
    "enfueiramos": "enfueirar",
    "enfueirando": "enfueirar",
    "enfueirara": "enfueirar",
    "enfueiraram": "enfueirar",
    "enfueiraras": "enfueirar",
    "enfueirarde": "enfueirar",
    "enfueirardes": "enfueirar",
    "enfueirare": "enfueirar",
    "enfueirarei": "enfueirar",
    "enfueirareis": "enfueirar",
    "enfueirarem": "enfueirar",
    "enfueiraremos": "enfueirar",
    "enfueirares": "enfueirar",
    "enfueiraria": "enfueirar",
    "enfueirariam": "enfueirar",
    "enfueirarias": "enfueirar",
    "enfueirarmo": "enfueirar",
    "enfueirarmos": "enfueirar",
    "enfueirará": "enfueirar",
    "enfueirarás": "enfueirar",
    "enfueirarão": "enfueirar",
    "enfueiraríamos": "enfueirar",
    "enfueiraríeis": "enfueirar",
    "enfueiras": "enfueirar",
    "enfueirasse": "enfueirar",
    "enfueirassem": "enfueirar",
    "enfueirasses": "enfueirar",
    "enfueiraste": "enfueirar",
    "enfueirastes": "enfueirar",
    "enfueirava": "enfueirar",
    "enfueiravam": "enfueirar",
    "enfueiravas": "enfueirar",
    "enfueire": "enfueirar",
    "enfueirei": "enfueirar",
    "enfueireis": "enfueirar",
    "enfueirem": "enfueirar",
    "enfueiremo": "enfueirar",
    "enfueiremos": "enfueirar",
    "enfueires": "enfueirar",
    "enfueiro": "enfueirar",
    "enfueirou": "enfueirar",
    "enfueirá": "enfueirar",
    "enfueirámo": "enfueirar",
    "enfueirámos": "enfueirar",
    "enfueiráramo": "enfueirar",
    "enfueiráramos": "enfueirar",
    "enfueirárei": "enfueirar",
    "enfueiráreis": "enfueirar",
    "enfueirásseis": "enfueirar",
    "enfueirássemos": "enfueirar",
    "enfueirávamo": "enfueirar",
    "enfueirávamos": "enfueirar",
    "enfueirávei": "enfueirar",
    "enfueiráveis": "enfueirar",
    "enfulija": "enfulijar",
    "enfulijada": "enfulijar",
    "enfulijadas": "enfulijar",
    "enfulijado": "enfulijar",
    "enfulijados": "enfulijar",
    "enfulijai": "enfulijar",
    "enfulijais": "enfulijar",
    "enfulijam": "enfulijar",
    "enfulijamo": "enfulijar",
    "enfulijamos": "enfulijar",
    "enfulijando": "enfulijar",
    "enfulijara": "enfulijar",
    "enfulijaram": "enfulijar",
    "enfulijaras": "enfulijar",
    "enfulijarde": "enfulijar",
    "enfulijardes": "enfulijar",
    "enfulijare": "enfulijar",
    "enfulijarei": "enfulijar",
    "enfulijareis": "enfulijar",
    "enfulijarem": "enfulijar",
    "enfulijaremos": "enfulijar",
    "enfulijares": "enfulijar",
    "enfulijaria": "enfulijar",
    "enfulijariam": "enfulijar",
    "enfulijarias": "enfulijar",
    "enfulijarmo": "enfulijar",
    "enfulijarmos": "enfulijar",
    "enfulijará": "enfulijar",
    "enfulijarás": "enfulijar",
    "enfulijarão": "enfulijar",
    "enfulijaríamos": "enfulijar",
    "enfulijaríeis": "enfulijar",
    "enfulijas": "enfulijar",
    "enfulijasse": "enfulijar",
    "enfulijassem": "enfulijar",
    "enfulijasses": "enfulijar",
    "enfulijaste": "enfulijar",
    "enfulijastes": "enfulijar",
    "enfulijava": "enfulijar",
    "enfulijavam": "enfulijar",
    "enfulijavas": "enfulijar",
    "enfulije": "enfulijar",
    "enfulijei": "enfulijar",
    "enfulijeis": "enfulijar",
    "enfulijem": "enfulijar",
    "enfulijemo": "enfulijar",
    "enfulijemos": "enfulijar",
    "enfulijes": "enfulijar",
    "enfulijo": "enfulijar",
    "enfulijou": "enfulijar",
    "enfulijá": "enfulijar",
    "enfulijámo": "enfulijar",
    "enfulijámos": "enfulijar",
    "enfulijáramo": "enfulijar",
    "enfulijáramos": "enfulijar",
    "enfulijárei": "enfulijar",
    "enfulijáreis": "enfulijar",
    "enfulijásseis": "enfulijar",
    "enfulijássemos": "enfulijar",
    "enfulijávamo": "enfulijar",
    "enfulijávamos": "enfulijar",
    "enfulijávei": "enfulijar",
    "enfulijáveis": "enfulijar",
    "enfumace": "enfumaçar",
    "enfumacei": "enfumaçar",
    "enfumaceis": "enfumaçar",
    "enfumacem": "enfumaçar",
    "enfumacemo": "enfumaçar",
    "enfumacemos": "enfumaçar",
    "enfumaces": "enfumaçar",
    "enfumara": "enfumarar",
    "enfumarada": "enfumarar",
    "enfumaradas": "enfumarar",
    "enfumarado": "enfumarar",
    "enfumarados": "enfumarar",
    "enfumarai": "enfumarar",
    "enfumarais": "enfumarar",
    "enfumaram": "enfumarar",
    "enfumaramo": "enfumarar",
    "enfumaramos": "enfumarar",
    "enfumarando": "enfumarar",
    "enfumarara": "enfumarar",
    "enfumararam": "enfumarar",
    "enfumararas": "enfumarar",
    "enfumararde": "enfumarar",
    "enfumarardes": "enfumarar",
    "enfumarare": "enfumarar",
    "enfumararei": "enfumarar",
    "enfumarareis": "enfumarar",
    "enfumararem": "enfumarar",
    "enfumararemos": "enfumarar",
    "enfumarares": "enfumarar",
    "enfumararia": "enfumarar",
    "enfumarariam": "enfumarar",
    "enfumararias": "enfumarar",
    "enfumararmo": "enfumarar",
    "enfumararmos": "enfumarar",
    "enfumarará": "enfumarar",
    "enfumararás": "enfumarar",
    "enfumararão": "enfumarar",
    "enfumararíamos": "enfumarar",
    "enfumararíeis": "enfumarar",
    "enfumaras": "enfumarar",
    "enfumarasse": "enfumarar",
    "enfumarassem": "enfumarar",
    "enfumarasses": "enfumarar",
    "enfumaraste": "enfumarar",
    "enfumarastes": "enfumarar",
    "enfumarava": "enfumarar",
    "enfumaravam": "enfumarar",
    "enfumaravas": "enfumarar",
    "enfumare": "enfumarar",
    "enfumarei": "enfumarar",
    "enfumareis": "enfumarar",
    "enfumarem": "enfumarar",
    "enfumaremo": "enfumarar",
    "enfumaremos": "enfumarar",
    "enfumares": "enfumarar",
    "enfumaro": "enfumarar",
    "enfumarou": "enfumarar",
    "enfumará": "enfumarar",
    "enfumarámo": "enfumarar",
    "enfumarámos": "enfumarar",
    "enfumaráramo": "enfumarar",
    "enfumaráramos": "enfumarar",
    "enfumarárei": "enfumarar",
    "enfumaráreis": "enfumarar",
    "enfumarásseis": "enfumarar",
    "enfumarássemos": "enfumarar",
    "enfumarávamo": "enfumarar",
    "enfumarávamos": "enfumarar",
    "enfumarávei": "enfumarar",
    "enfumaráveis": "enfumarar",
    "enfumaça": "enfumaçar",
    "enfumaçada": "enfumaçar",
    "enfumaçadas": "enfumaçar",
    "enfumaçado": "enfumaçar",
    "enfumaçados": "enfumaçar",
    "enfumaçai": "enfumaçar",
    "enfumaçais": "enfumaçar",
    "enfumaçam": "enfumaçar",
    "enfumaçamo": "enfumaçar",
    "enfumaçamos": "enfumaçar",
    "enfumaçando": "enfumaçar",
    "enfumaçara": "enfumaçar",
    "enfumaçaram": "enfumaçar",
    "enfumaçaras": "enfumaçar",
    "enfumaçarde": "enfumaçar",
    "enfumaçardes": "enfumaçar",
    "enfumaçare": "enfumaçar",
    "enfumaçarei": "enfumaçar",
    "enfumaçareis": "enfumaçar",
    "enfumaçarem": "enfumaçar",
    "enfumaçaremos": "enfumaçar",
    "enfumaçares": "enfumaçar",
    "enfumaçaria": "enfumaçar",
    "enfumaçariam": "enfumaçar",
    "enfumaçarias": "enfumaçar",
    "enfumaçarmo": "enfumaçar",
    "enfumaçarmos": "enfumaçar",
    "enfumaçará": "enfumaçar",
    "enfumaçarás": "enfumaçar",
    "enfumaçarão": "enfumaçar",
    "enfumaçaríamos": "enfumaçar",
    "enfumaçaríeis": "enfumaçar",
    "enfumaças": "enfumaçar",
    "enfumaçasse": "enfumaçar",
    "enfumaçassem": "enfumaçar",
    "enfumaçasses": "enfumaçar",
    "enfumaçaste": "enfumaçar",
    "enfumaçastes": "enfumaçar",
    "enfumaçava": "enfumaçar",
    "enfumaçavam": "enfumaçar",
    "enfumaçavas": "enfumaçar",
    "enfumaço": "enfumaçar",
    "enfumaçou": "enfumaçar",
    "enfumaçá": "enfumaçar",
    "enfumaçámo": "enfumaçar",
    "enfumaçámos": "enfumaçar",
    "enfumaçáramo": "enfumaçar",
    "enfumaçáramos": "enfumaçar",
    "enfumaçárei": "enfumaçar",
    "enfumaçáreis": "enfumaçar",
    "enfumaçásseis": "enfumaçar",
    "enfumaçássemos": "enfumaçar",
    "enfumaçávamo": "enfumaçar",
    "enfumaçávamos": "enfumaçar",
    "enfumaçávei": "enfumaçar",
    "enfumaçáveis": "enfumaçar",
    "enfuna": "enfunar",
    "enfunada": "enfunar",
    "enfunadas": "enfunar",
    "enfunado": "enfunar",
    "enfunados": "enfunar",
    "enfunai": "enfunar",
    "enfunais": "enfunar",
    "enfunam": "enfunar",
    "enfunamo": "enfunar",
    "enfunamos": "enfunar",
    "enfunando": "enfunar",
    "enfunara": "enfunar",
    "enfunaram": "enfunar",
    "enfunaras": "enfunar",
    "enfunarde": "enfunar",
    "enfunardes": "enfunar",
    "enfunare": "enfunar",
    "enfunarei": "enfunar",
    "enfunareis": "enfunar",
    "enfunarem": "enfunar",
    "enfunaremos": "enfunar",
    "enfunares": "enfunar",
    "enfunaria": "enfunar",
    "enfunariam": "enfunar",
    "enfunarias": "enfunar",
    "enfunarmo": "enfunar",
    "enfunarmos": "enfunar",
    "enfunará": "enfunar",
    "enfunarás": "enfunar",
    "enfunarão": "enfunar",
    "enfunaríamos": "enfunar",
    "enfunaríeis": "enfunar",
    "enfunas": "enfunar",
    "enfunasse": "enfunar",
    "enfunassem": "enfunar",
    "enfunasses": "enfunar",
    "enfunaste": "enfunar",
    "enfunastes": "enfunar",
    "enfunava": "enfunar",
    "enfunavam": "enfunar",
    "enfunavas": "enfunar",
    "enfune": "enfunar",
    "enfunei": "enfunar",
    "enfuneis": "enfunar",
    "enfunem": "enfunar",
    "enfunemo": "enfunar",
    "enfunemos": "enfunar",
    "enfunes": "enfunar",
    "enfunila": "enfunilar",
    "enfunilada": "enfunilar",
    "enfuniladas": "enfunilar",
    "enfunilado": "enfunilar",
    "enfunilados": "enfunilar",
    "enfunilai": "enfunilar",
    "enfunilais": "enfunilar",
    "enfunilam": "enfunilar",
    "enfunilamentos": "enfunilamento",
    "enfunilamo": "enfunilar",
    "enfunilamos": "enfunilar",
    "enfunilando": "enfunilar",
    "enfunilara": "enfunilar",
    "enfunilaram": "enfunilar",
    "enfunilaras": "enfunilar",
    "enfunilarde": "enfunilar",
    "enfunilardes": "enfunilar",
    "enfunilare": "enfunilar",
    "enfunilarei": "enfunilar",
    "enfunilareis": "enfunilar",
    "enfunilarem": "enfunilar",
    "enfunilaremos": "enfunilar",
    "enfunilares": "enfunilar",
    "enfunilaria": "enfunilar",
    "enfunilariam": "enfunilar",
    "enfunilarias": "enfunilar",
    "enfunilarmo": "enfunilar",
    "enfunilarmos": "enfunilar",
    "enfunilará": "enfunilar",
    "enfunilarás": "enfunilar",
    "enfunilarão": "enfunilar",
    "enfunilaríamos": "enfunilar",
    "enfunilaríeis": "enfunilar",
    "enfunilas": "enfunilar",
    "enfunilasse": "enfunilar",
    "enfunilassem": "enfunilar",
    "enfunilasses": "enfunilar",
    "enfunilaste": "enfunilar",
    "enfunilastes": "enfunilar",
    "enfunilava": "enfunilar",
    "enfunilavam": "enfunilar",
    "enfunilavas": "enfunilar",
    "enfunile": "enfunilar",
    "enfunilei": "enfunilar",
    "enfunileis": "enfunilar",
    "enfunilem": "enfunilar",
    "enfunilemo": "enfunilar",
    "enfunilemos": "enfunilar",
    "enfuniles": "enfunilar",
    "enfunilo": "enfunilar",
    "enfunilou": "enfunilar",
    "enfunilá": "enfunilar",
    "enfunilámo": "enfunilar",
    "enfunilámos": "enfunilar",
    "enfuniláramo": "enfunilar",
    "enfuniláramos": "enfunilar",
    "enfunilárei": "enfunilar",
    "enfuniláreis": "enfunilar",
    "enfunilásseis": "enfunilar",
    "enfunilássemos": "enfunilar",
    "enfunilávamo": "enfunilar",
    "enfunilávamos": "enfunilar",
    "enfunilávei": "enfunilar",
    "enfuniláveis": "enfunilar",
    "enfuno": "enfunar",
    "enfunou": "enfunar",
    "enfuná": "enfunar",
    "enfunámo": "enfunar",
    "enfunámos": "enfunar",
    "enfunáramo": "enfunar",
    "enfunáramos": "enfunar",
    "enfunárei": "enfunar",
    "enfunáreis": "enfunar",
    "enfunásseis": "enfunar",
    "enfunássemos": "enfunar",
    "enfunávamo": "enfunar",
    "enfunávamos": "enfunar",
    "enfunávei": "enfunar",
    "enfunáveis": "enfunar",
    "enfurece": "enfurecer",
    "enfurecei": "enfurecer",
    "enfureceis": "enfurecer",
    "enfurecem": "enfurecer",
    "enfurecemo": "enfurecer",
    "enfurecemos": "enfurecer",
    "enfurecendo": "enfurecer",
    "enfurecera": "enfurecer",
    "enfureceram": "enfurecer",
    "enfureceras": "enfurecer",
    "enfurecerde": "enfurecer",
    "enfurecerdes": "enfurecer",
    "enfurecere": "enfurecer",
    "enfurecerei": "enfurecer",
    "enfurecereis": "enfurecer",
    "enfurecerem": "enfurecer",
    "enfureceremos": "enfurecer",
    "enfureceres": "enfurecer",
    "enfureceria": "enfurecer",
    "enfureceriam": "enfurecer",
    "enfurecerias": "enfurecer",
    "enfurecermo": "enfurecer",
    "enfurecermos": "enfurecer",
    "enfurecerá": "enfurecer",
    "enfurecerás": "enfurecer",
    "enfurecerão": "enfurecer",
    "enfureceríamos": "enfurecer",
    "enfureceríeis": "enfurecer",
    "enfureces": "enfurecer",
    "enfurecesse": "enfurecer",
    "enfurecessem": "enfurecer",
    "enfurecesses": "enfurecer",
    "enfureceste": "enfurecer",
    "enfurecestes": "enfurecer",
    "enfureceu": "enfurecer",
    "enfureci": "enfurecer",
    "enfurecia": "enfurecer",
    "enfureciam": "enfurecer",
    "enfurecias": "enfurecer",
    "enfurecida": "enfurecido",
    "enfurecidas": "enfurecido",
    "enfurecido": "enfurecer",
    "enfurecidos": "enfurecido",
    "enfurecimentos": "enfurecimento",
    "enfurecê": "enfurecer",
    "enfurecêramo": "enfurecer",
    "enfurecêramos": "enfurecer",
    "enfurecêrei": "enfurecer",
    "enfurecêreis": "enfurecer",
    "enfurecêsseis": "enfurecer",
    "enfurecêssemos": "enfurecer",
    "enfurecíamo": "enfurecer",
    "enfurecíamos": "enfurecer",
    "enfurecíei": "enfurecer",
    "enfurecíeis": "enfurecer",
    "enfureça": "enfurecer",
    "enfureçais": "enfurecer",
    "enfureçam": "enfurecer",
    "enfureçamo": "enfurecer",
    "enfureçamos": "enfurecer",
    "enfureças": "enfurecer",
    "enfureço": "enfurecer",
    "enfuria": "enfuriar",
    "enfuriada": "enfuriar",
    "enfuriadas": "enfuriar",
    "enfuriado": "enfuriar",
    "enfuriados": "enfuriar",
    "enfuriai": "enfuriar",
    "enfuriais": "enfuriar",
    "enfuriam": "enfuriar",
    "enfuriamo": "enfuriar",
    "enfuriamos": "enfuriar",
    "enfuriando": "enfuriar",
    "enfuriara": "enfuriar",
    "enfuriaram": "enfuriar",
    "enfuriaras": "enfuriar",
    "enfuriarde": "enfuriar",
    "enfuriardes": "enfuriar",
    "enfuriare": "enfuriar",
    "enfuriarei": "enfuriar",
    "enfuriareis": "enfuriar",
    "enfuriarem": "enfuriar",
    "enfuriaremos": "enfuriar",
    "enfuriares": "enfuriar",
    "enfuriaria": "enfuriar",
    "enfuriariam": "enfuriar",
    "enfuriarias": "enfuriar",
    "enfuriarmo": "enfuriar",
    "enfuriarmos": "enfuriar",
    "enfuriará": "enfuriar",
    "enfuriarás": "enfuriar",
    "enfuriarão": "enfuriar",
    "enfuriaríamos": "enfuriar",
    "enfuriaríeis": "enfuriar",
    "enfurias": "enfuriar",
    "enfuriasse": "enfuriar",
    "enfuriassem": "enfuriar",
    "enfuriasses": "enfuriar",
    "enfuriaste": "enfuriar",
    "enfuriastes": "enfuriar",
    "enfuriava": "enfuriar",
    "enfuriavam": "enfuriar",
    "enfuriavas": "enfuriar",
    "enfurie": "enfuriar",
    "enfuriei": "enfuriar",
    "enfurieis": "enfuriar",
    "enfuriem": "enfuriar",
    "enfuriemo": "enfuriar",
    "enfuriemos": "enfuriar",
    "enfuries": "enfuriar",
    "enfurio": "enfuriar",
    "enfuriou": "enfuriar",
    "enfuriá": "enfuriar",
    "enfuriámo": "enfuriar",
    "enfuriámos": "enfuriar",
    "enfuriáramo": "enfuriar",
    "enfuriáramos": "enfuriar",
    "enfuriárei": "enfuriar",
    "enfuriáreis": "enfuriar",
    "enfuriásseis": "enfuriar",
    "enfuriássemos": "enfuriar",
    "enfuriávamo": "enfuriar",
    "enfuriávamos": "enfuriar",
    "enfuriávei": "enfuriar",
    "enfuriáveis": "enfuriar",
    "enfurna": "enfurnar",
    "enfurnada": "enfurnar",
    "enfurnadas": "enfurnar",
    "enfurnado": "enfurnar",
    "enfurnados": "enfurnar",
    "enfurnai": "enfurnar",
    "enfurnais": "enfurnar",
    "enfurnam": "enfurnar",
    "enfurnamo": "enfurnar",
    "enfurnamos": "enfurnar",
    "enfurnando": "enfurnar",
    "enfurnara": "enfurnar",
    "enfurnaram": "enfurnar",
    "enfurnaras": "enfurnar",
    "enfurnarde": "enfurnar",
    "enfurnardes": "enfurnar",
    "enfurnare": "enfurnar",
    "enfurnarei": "enfurnar",
    "enfurnareis": "enfurnar",
    "enfurnarem": "enfurnar",
    "enfurnaremos": "enfurnar",
    "enfurnares": "enfurnar",
    "enfurnaria": "enfurnar",
    "enfurnariam": "enfurnar",
    "enfurnarias": "enfurnar",
    "enfurnarmo": "enfurnar",
    "enfurnarmos": "enfurnar",
    "enfurnará": "enfurnar",
    "enfurnarás": "enfurnar",
    "enfurnarão": "enfurnar",
    "enfurnaríamos": "enfurnar",
    "enfurnaríeis": "enfurnar",
    "enfurnas": "enfurnar",
    "enfurnasse": "enfurnar",
    "enfurnassem": "enfurnar",
    "enfurnasses": "enfurnar",
    "enfurnaste": "enfurnar",
    "enfurnastes": "enfurnar",
    "enfurnava": "enfurnar",
    "enfurnavam": "enfurnar",
    "enfurnavas": "enfurnar",
    "enfurne": "enfurnar",
    "enfurnei": "enfurnar",
    "enfurneis": "enfurnar",
    "enfurnem": "enfurnar",
    "enfurnemo": "enfurnar",
    "enfurnemos": "enfurnar",
    "enfurnes": "enfurnar",
    "enfurno": "enfurnar",
    "enfurnou": "enfurnar",
    "enfurná": "enfurnar",
    "enfurnámo": "enfurnar",
    "enfurnámos": "enfurnar",
    "enfurnáramo": "enfurnar",
    "enfurnáramos": "enfurnar",
    "enfurnárei": "enfurnar",
    "enfurnáreis": "enfurnar",
    "enfurnásseis": "enfurnar",
    "enfurnássemos": "enfurnar",
    "enfurnávamo": "enfurnar",
    "enfurnávamos": "enfurnar",
    "enfurnávei": "enfurnar",
    "enfurnáveis": "enfurnar",
    "enfusca": "enfuscar",
    "enfuscada": "enfuscar",
    "enfuscadas": "enfuscar",
    "enfuscado": "enfuscar",
    "enfuscados": "enfuscar",
    "enfuscai": "enfuscar",
    "enfuscais": "enfuscar",
    "enfuscam": "enfuscar",
    "enfuscamo": "enfuscar",
    "enfuscamos": "enfuscar",
    "enfuscando": "enfuscar",
    "enfuscara": "enfuscar",
    "enfuscaram": "enfuscar",
    "enfuscaras": "enfuscar",
    "enfuscarde": "enfuscar",
    "enfuscardes": "enfuscar",
    "enfuscare": "enfuscar",
    "enfuscarei": "enfuscar",
    "enfuscareis": "enfuscar",
    "enfuscarem": "enfuscar",
    "enfuscaremos": "enfuscar",
    "enfuscares": "enfuscar",
    "enfuscaria": "enfuscar",
    "enfuscariam": "enfuscar",
    "enfuscarias": "enfuscar",
    "enfuscarmo": "enfuscar",
    "enfuscarmos": "enfuscar",
    "enfuscará": "enfuscar",
    "enfuscarás": "enfuscar",
    "enfuscarão": "enfuscar",
    "enfuscaríamos": "enfuscar",
    "enfuscaríeis": "enfuscar",
    "enfuscas": "enfuscar",
    "enfuscasse": "enfuscar",
    "enfuscassem": "enfuscar",
    "enfuscasses": "enfuscar",
    "enfuscaste": "enfuscar",
    "enfuscastes": "enfuscar",
    "enfuscava": "enfuscar",
    "enfuscavam": "enfuscar",
    "enfuscavas": "enfuscar",
    "enfusco": "enfuscar",
    "enfuscou": "enfuscar",
    "enfuscá": "enfuscar",
    "enfuscámo": "enfuscar",
    "enfuscámos": "enfuscar",
    "enfuscáramo": "enfuscar",
    "enfuscáramos": "enfuscar",
    "enfuscárei": "enfuscar",
    "enfuscáreis": "enfuscar",
    "enfuscásseis": "enfuscar",
    "enfuscássemos": "enfuscar",
    "enfuscávamo": "enfuscar",
    "enfuscávamos": "enfuscar",
    "enfuscávei": "enfuscar",
    "enfuscáveis": "enfuscar",
    "enfusque": "enfuscar",
    "enfusquei": "enfuscar",
    "enfusqueis": "enfuscar",
    "enfusquem": "enfuscar",
    "enfusquemo": "enfuscar",
    "enfusquemos": "enfuscar",
    "enfusques": "enfuscar",
    "enfusta": "enfustar",
    "enfustada": "enfustar",
    "enfustadas": "enfustar",
    "enfustado": "enfustar",
    "enfustados": "enfustar",
    "enfustai": "enfustar",
    "enfustais": "enfustar",
    "enfustam": "enfustar",
    "enfustamentos": "enfustamento",
    "enfustamo": "enfustar",
    "enfustamos": "enfustar",
    "enfustando": "enfustar",
    "enfustara": "enfustar",
    "enfustaram": "enfustar",
    "enfustaras": "enfustar",
    "enfustarde": "enfustar",
    "enfustardes": "enfustar",
    "enfustare": "enfustar",
    "enfustarei": "enfustar",
    "enfustareis": "enfustar",
    "enfustarem": "enfustar",
    "enfustaremos": "enfustar",
    "enfustares": "enfustar",
    "enfustaria": "enfustar",
    "enfustariam": "enfustar",
    "enfustarias": "enfustar",
    "enfustarmo": "enfustar",
    "enfustarmos": "enfustar",
    "enfustará": "enfustar",
    "enfustarás": "enfustar",
    "enfustarão": "enfustar",
    "enfustaríamos": "enfustar",
    "enfustaríeis": "enfustar",
    "enfustas": "enfustar",
    "enfustasse": "enfustar",
    "enfustassem": "enfustar",
    "enfustasses": "enfustar",
    "enfustaste": "enfustar",
    "enfustastes": "enfustar",
    "enfustava": "enfustar",
    "enfustavam": "enfustar",
    "enfustavas": "enfustar",
    "enfuste": "enfustar",
    "enfustei": "enfustar",
    "enfusteis": "enfustar",
    "enfustem": "enfustar",
    "enfustemo": "enfustar",
    "enfustemos": "enfustar",
    "enfustes": "enfuste",
    "enfusto": "enfustar",
    "enfustou": "enfustar",
    "enfustá": "enfustar",
    "enfustámo": "enfustar",
    "enfustámos": "enfustar",
    "enfustáramo": "enfustar",
    "enfustáramos": "enfustar",
    "enfustárei": "enfustar",
    "enfustáreis": "enfustar",
    "enfustásseis": "enfustar",
    "enfustássemos": "enfustar",
    "enfustávamo": "enfustar",
    "enfustávamos": "enfustar",
    "enfustávei": "enfustar",
    "enfustáveis": "enfustar",
    "enfática": "enfático",
    "enfáticas": "enfático",
    "enfáticos": "enfático",
    "enfístulas": "enfístula",
    "enga": "engar",
    "engabela": "engabelar",
    "engabelada": "engabelar",
    "engabeladas": "engabelar",
    "engabelado": "engabelar",
    "engabelados": "engabelar",
    "engabelai": "engabelar",
    "engabelais": "engabelar",
    "engabelam": "engabelar",
    "engabelamo": "engabelar",
    "engabelamos": "engabelar",
    "engabelando": "engabelar",
    "engabelara": "engabelar",
    "engabelaram": "engabelar",
    "engabelaras": "engabelar",
    "engabelarde": "engabelar",
    "engabelardes": "engabelar",
    "engabelare": "engabelar",
    "engabelarei": "engabelar",
    "engabelareis": "engabelar",
    "engabelarem": "engabelar",
    "engabelaremos": "engabelar",
    "engabelares": "engabelar",
    "engabelaria": "engabelar",
    "engabelariam": "engabelar",
    "engabelarias": "engabelar",
    "engabelarmo": "engabelar",
    "engabelarmos": "engabelar",
    "engabelará": "engabelar",
    "engabelarás": "engabelar",
    "engabelarão": "engabelar",
    "engabelaríamos": "engabelar",
    "engabelaríeis": "engabelar",
    "engabelas": "engabelar",
    "engabelasse": "engabelar",
    "engabelassem": "engabelar",
    "engabelasses": "engabelar",
    "engabelaste": "engabelar",
    "engabelastes": "engabelar",
    "engabelava": "engabelar",
    "engabelavam": "engabelar",
    "engabelavas": "engabelar",
    "engabele": "engabelar",
    "engabelei": "engabelar",
    "engabeleis": "engabelar",
    "engabelem": "engabelar",
    "engabelemo": "engabelar",
    "engabelemos": "engabelar",
    "engabeles": "engabelar",
    "engabelo": "engabelar",
    "engabelos": "engabelo",
    "engabelou": "engabelar",
    "engabelá": "engabelar",
    "engabelámo": "engabelar",
    "engabelámos": "engabelar",
    "engabeláramo": "engabelar",
    "engabeláramos": "engabelar",
    "engabelárei": "engabelar",
    "engabeláreis": "engabelar",
    "engabelásseis": "engabelar",
    "engabelássemos": "engabelar",
    "engabelávamo": "engabelar",
    "engabelávamos": "engabelar",
    "engabelávei": "engabelar",
    "engabeláveis": "engabelar",
    "engace": "engaçar",
    "engacei": "engaçar",
    "engaceis": "engaçar",
    "engacem": "engaçar",
    "engacemo": "engaçar",
    "engacemos": "engaçar",
    "engaces": "engaçar",
    "engada": "engar",
    "engadanha": "engadanhar",
    "engadanhada": "engadanhar",
    "engadanhadas": "engadanhar",
    "engadanhado": "engadanhar",
    "engadanhados": "engadanhar",
    "engadanhai": "engadanhar",
    "engadanhais": "engadanhar",
    "engadanham": "engadanhar",
    "engadanhamo": "engadanhar",
    "engadanhamos": "engadanhar",
    "engadanhando": "engadanhar",
    "engadanhara": "engadanhar",
    "engadanharam": "engadanhar",
    "engadanharas": "engadanhar",
    "engadanharde": "engadanhar",
    "engadanhardes": "engadanhar",
    "engadanhare": "engadanhar",
    "engadanharei": "engadanhar",
    "engadanhareis": "engadanhar",
    "engadanharem": "engadanhar",
    "engadanharemos": "engadanhar",
    "engadanhares": "engadanhar",
    "engadanharia": "engadanhar",
    "engadanhariam": "engadanhar",
    "engadanharias": "engadanhar",
    "engadanharmo": "engadanhar",
    "engadanharmos": "engadanhar",
    "engadanhará": "engadanhar",
    "engadanharás": "engadanhar",
    "engadanharão": "engadanhar",
    "engadanharíamos": "engadanhar",
    "engadanharíeis": "engadanhar",
    "engadanhas": "engadanhar",
    "engadanhasse": "engadanhar",
    "engadanhassem": "engadanhar",
    "engadanhasses": "engadanhar",
    "engadanhaste": "engadanhar",
    "engadanhastes": "engadanhar",
    "engadanhava": "engadanhar",
    "engadanhavam": "engadanhar",
    "engadanhavas": "engadanhar",
    "engadanhe": "engadanhar",
    "engadanhei": "engadanhar",
    "engadanheis": "engadanhar",
    "engadanhem": "engadanhar",
    "engadanhemo": "engadanhar",
    "engadanhemos": "engadanhar",
    "engadanhes": "engadanhar",
    "engadanho": "engadanhar",
    "engadanhou": "engadanhar",
    "engadanhá": "engadanhar",
    "engadanhámo": "engadanhar",
    "engadanhámos": "engadanhar",
    "engadanháramo": "engadanhar",
    "engadanháramos": "engadanhar",
    "engadanhárei": "engadanhar",
    "engadanháreis": "engadanhar",
    "engadanhásseis": "engadanhar",
    "engadanhássemos": "engadanhar",
    "engadanhávamo": "engadanhar",
    "engadanhávamos": "engadanhar",
    "engadanhávei": "engadanhar",
    "engadanháveis": "engadanhar",
    "engadas": "engar",
    "engadelha": "engadelhar",
    "engadelhada": "engadelhar",
    "engadelhadas": "engadelhar",
    "engadelhado": "engadelhar",
    "engadelhados": "engadelhar",
    "engadelhai": "engadelhar",
    "engadelhais": "engadelhar",
    "engadelham": "engadelhar",
    "engadelhamo": "engadelhar",
    "engadelhamos": "engadelhar",
    "engadelhando": "engadelhar",
    "engadelhara": "engadelhar",
    "engadelharam": "engadelhar",
    "engadelharas": "engadelhar",
    "engadelharde": "engadelhar",
    "engadelhardes": "engadelhar",
    "engadelhare": "engadelhar",
    "engadelharei": "engadelhar",
    "engadelhareis": "engadelhar",
    "engadelharem": "engadelhar",
    "engadelharemos": "engadelhar",
    "engadelhares": "engadelhar",
    "engadelharia": "engadelhar",
    "engadelhariam": "engadelhar",
    "engadelharias": "engadelhar",
    "engadelharmo": "engadelhar",
    "engadelharmos": "engadelhar",
    "engadelhará": "engadelhar",
    "engadelharás": "engadelhar",
    "engadelharão": "engadelhar",
    "engadelharíamos": "engadelhar",
    "engadelharíeis": "engadelhar",
    "engadelhas": "engadelhar",
    "engadelhasse": "engadelhar",
    "engadelhassem": "engadelhar",
    "engadelhasses": "engadelhar",
    "engadelhaste": "engadelhar",
    "engadelhastes": "engadelhar",
    "engadelhava": "engadelhar",
    "engadelhavam": "engadelhar",
    "engadelhavas": "engadelhar",
    "engadelhe": "engadelhar",
    "engadelhei": "engadelhar",
    "engadelheis": "engadelhar",
    "engadelhem": "engadelhar",
    "engadelhemo": "engadelhar",
    "engadelhemos": "engadelhar",
    "engadelhes": "engadelhar",
    "engadelho": "engadelhar",
    "engadelhou": "engadelhar",
    "engadelhá": "engadelhar",
    "engadelhámo": "engadelhar",
    "engadelhámos": "engadelhar",
    "engadelháramo": "engadelhar",
    "engadelháramos": "engadelhar",
    "engadelhárei": "engadelhar",
    "engadelháreis": "engadelhar",
    "engadelhásseis": "engadelhar",
    "engadelhássemos": "engadelhar",
    "engadelhávamo": "engadelhar",
    "engadelhávamos": "engadelhar",
    "engadelhávei": "engadelhar",
    "engadelháveis": "engadelhar",
    "engado": "engar",
    "engados": "engar",
    "engafece": "engafecer",
    "engafecei": "engafecer",
    "engafeceis": "engafecer",
    "engafecem": "engafecer",
    "engafecemo": "engafecer",
    "engafecemos": "engafecer",
    "engafecendo": "engafecer",
    "engafecera": "engafecer",
    "engafeceram": "engafecer",
    "engafeceras": "engafecer",
    "engafecerde": "engafecer",
    "engafecerdes": "engafecer",
    "engafecere": "engafecer",
    "engafecerei": "engafecer",
    "engafecereis": "engafecer",
    "engafecerem": "engafecer",
    "engafeceremos": "engafecer",
    "engafeceres": "engafecer",
    "engafeceria": "engafecer",
    "engafeceriam": "engafecer",
    "engafecerias": "engafecer",
    "engafecermo": "engafecer",
    "engafecermos": "engafecer",
    "engafecerá": "engafecer",
    "engafecerás": "engafecer",
    "engafecerão": "engafecer",
    "engafeceríamos": "engafecer",
    "engafeceríeis": "engafecer",
    "engafeces": "engafecer",
    "engafecesse": "engafecer",
    "engafecessem": "engafecer",
    "engafecesses": "engafecer",
    "engafeceste": "engafecer",
    "engafecestes": "engafecer",
    "engafeceu": "engafecer",
    "engafeci": "engafecer",
    "engafecia": "engafecer",
    "engafeciam": "engafecer",
    "engafecias": "engafecer",
    "engafecida": "engafecer",
    "engafecidas": "engafecer",
    "engafecido": "engafecer",
    "engafecidos": "engafecer",
    "engafecê": "engafecer",
    "engafecêramo": "engafecer",
    "engafecêramos": "engafecer",
    "engafecêrei": "engafecer",
    "engafecêreis": "engafecer",
    "engafecêsseis": "engafecer",
    "engafecêssemos": "engafecer",
    "engafecíamo": "engafecer",
    "engafecíamos": "engafecer",
    "engafecíei": "engafecer",
    "engafecíeis": "engafecer",
    "engafeça": "engafecer",
    "engafeçais": "engafecer",
    "engafeçam": "engafecer",
    "engafeçamo": "engafecer",
    "engafeçamos": "engafecer",
    "engafeças": "engafecer",
    "engafeço": "engafecer",
    "engai": "engar",
    "engaiola": "engaiolar",
    "engaiolada": "engaiolar",
    "engaioladas": "engaiolar",
    "engaiolado": "engaiolar",
    "engaiolados": "engaiolar",
    "engaiolai": "engaiolar",
    "engaiolais": "engaiolar",
    "engaiolam": "engaiolar",
    "engaiolamentos": "engaiolamento",
    "engaiolamo": "engaiolar",
    "engaiolamos": "engaiolar",
    "engaiolando": "engaiolar",
    "engaiolara": "engaiolar",
    "engaiolaram": "engaiolar",
    "engaiolaras": "engaiolar",
    "engaiolarde": "engaiolar",
    "engaiolardes": "engaiolar",
    "engaiolare": "engaiolar",
    "engaiolarei": "engaiolar",
    "engaiolareis": "engaiolar",
    "engaiolarem": "engaiolar",
    "engaiolaremos": "engaiolar",
    "engaiolares": "engaiolar",
    "engaiolaria": "engaiolar",
    "engaiolariam": "engaiolar",
    "engaiolarias": "engaiolar",
    "engaiolarmo": "engaiolar",
    "engaiolarmos": "engaiolar",
    "engaiolará": "engaiolar",
    "engaiolarás": "engaiolar",
    "engaiolarão": "engaiolar",
    "engaiolaríamos": "engaiolar",
    "engaiolaríeis": "engaiolar",
    "engaiolas": "engaiolar",
    "engaiolasse": "engaiolar",
    "engaiolassem": "engaiolar",
    "engaiolasses": "engaiolar",
    "engaiolaste": "engaiolar",
    "engaiolastes": "engaiolar",
    "engaiolava": "engaiolar",
    "engaiolavam": "engaiolar",
    "engaiolavas": "engaiolar",
    "engaiole": "engaiolar",
    "engaiolei": "engaiolar",
    "engaioleis": "engaiolar",
    "engaiolem": "engaiolar",
    "engaiolemo": "engaiolar",
    "engaiolemos": "engaiolar",
    "engaioles": "engaiolar",
    "engaiolo": "engaiolar",
    "engaiolou": "engaiolar",
    "engaiolá": "engaiolar",
    "engaiolámo": "engaiolar",
    "engaiolámos": "engaiolar",
    "engaioláramo": "engaiolar",
    "engaioláramos": "engaiolar",
    "engaiolárei": "engaiolar",
    "engaioláreis": "engaiolar",
    "engaiolásseis": "engaiolar",
    "engaiolássemos": "engaiolar",
    "engaiolávamo": "engaiolar",
    "engaiolávamos": "engaiolar",
    "engaiolávei": "engaiolar",
    "engaioláveis": "engaiolar",
    "engais": "engar",
    "engaja": "engajar",
    "engajada": "engajar",
    "engajadas": "engajar",
    "engajado": "engajar",
    "engajadora": "engajador",
    "engajadoras": "engajador",
    "engajadores": "engajador",
    "engajados": "engajar",
    "engajai": "engajar",
    "engajais": "engajar",
    "engajam": "engajar",
    "engajamentos": "engajamento",
    "engajamo": "engajar",
    "engajamos": "engajar",
    "engajando": "engajar",
    "engajara": "engajar",
    "engajaram": "engajar",
    "engajaras": "engajar",
    "engajarde": "engajar",
    "engajardes": "engajar",
    "engajare": "engajar",
    "engajarei": "engajar",
    "engajareis": "engajar",
    "engajarem": "engajar",
    "engajaremos": "engajar",
    "engajares": "engajar",
    "engajaria": "engajar",
    "engajariam": "engajar",
    "engajarias": "engajar",
    "engajarmo": "engajar",
    "engajarmos": "engajar",
    "engajará": "engajar",
    "engajarás": "engajar",
    "engajarão": "engajar",
    "engajaríamos": "engajar",
    "engajaríeis": "engajar",
    "engajas": "engajar",
    "engajasse": "engajar",
    "engajassem": "engajar",
    "engajasses": "engajar",
    "engajaste": "engajar",
    "engajastes": "engajar",
    "engajatada": "engajatado",
    "engajatadas": "engajatado",
    "engajatados": "engajatado",
    "engajava": "engajar",
    "engajavam": "engajar",
    "engajavas": "engajar",
    "engajavatada": "engajavatado",
    "engajavatadas": "engajavatado",
    "engajavatados": "engajavatado",
    "engaje": "engajar",
    "engajeada": "engajeado",
    "engajeadas": "engajeado",
    "engajeados": "engajeado",
    "engajei": "engajar",
    "engajeis": "engajar",
    "engajem": "engajar",
    "engajemo": "engajar",
    "engajemos": "engajar",
    "engajes": "engajar",
    "engajo": "engajar",
    "engajou": "engajar",
    "engajá": "engajar",
    "engajámo": "engajar",
    "engajámos": "engajar",
    "engajáramo": "engajar",
    "engajáramos": "engajar",
    "engajárei": "engajar",
    "engajáreis": "engajar",
    "engajásseis": "engajar",
    "engajássemos": "engajar",
    "engajávamo": "engajar",
    "engajávamos": "engajar",
    "engajávei": "engajar",
    "engajáveis": "engajar",
    "engalana": "engalanar",
    "engalanada": "engalanar",
    "engalanadas": "engalanar",
    "engalanado": "engalanar",
    "engalanados": "engalanar",
    "engalanadíssima": "engalanado",
    "engalanadíssimas": "engalanado",
    "engalanadíssimo": "engalanado",
    "engalanadíssimos": "engalanado",
    "engalanai": "engalanar",
    "engalanais": "engalanar",
    "engalanam": "engalanar",
    "engalanamo": "engalanar",
    "engalanamos": "engalanar",
    "engalanando": "engalanar",
    "engalanara": "engalanar",
    "engalanaram": "engalanar",
    "engalanaras": "engalanar",
    "engalanarde": "engalanar",
    "engalanardes": "engalanar",
    "engalanare": "engalanar",
    "engalanarei": "engalanar",
    "engalanareis": "engalanar",
    "engalanarem": "engalanar",
    "engalanaremos": "engalanar",
    "engalanares": "engalanar",
    "engalanaria": "engalanar",
    "engalanariam": "engalanar",
    "engalanarias": "engalanar",
    "engalanarmo": "engalanar",
    "engalanarmos": "engalanar",
    "engalanará": "engalanar",
    "engalanarás": "engalanar",
    "engalanarão": "engalanar",
    "engalanaríamos": "engalanar",
    "engalanaríeis": "engalanar",
    "engalanas": "engalanar",
    "engalanasse": "engalanar",
    "engalanassem": "engalanar",
    "engalanasses": "engalanar",
    "engalanaste": "engalanar",
    "engalanastes": "engalanar",
    "engalanava": "engalanar",
    "engalanavam": "engalanar",
    "engalanavas": "engalanar",
    "engalane": "engalanar",
    "engalanei": "engalanar",
    "engalaneis": "engalanar",
    "engalanem": "engalanar",
    "engalanemo": "engalanar",
    "engalanemos": "engalanar",
    "engalanes": "engalanar",
    "engalano": "engalanar",
    "engalanou": "engalanar",
    "engalaná": "engalanar",
    "engalanámo": "engalanar",
    "engalanámos": "engalanar",
    "engalanáramo": "engalanar",
    "engalanáramos": "engalanar",
    "engalanárei": "engalanar",
    "engalanáreis": "engalanar",
    "engalanásseis": "engalanar",
    "engalanássemos": "engalanar",
    "engalanávamo": "engalanar",
    "engalanávamos": "engalanar",
    "engalanávei": "engalanar",
    "engalanáveis": "engalanar",
    "engalfinha": "engalfinhar",
    "engalfinhada": "engalfinhar",
    "engalfinhadas": "engalfinhar",
    "engalfinhado": "engalfinhar",
    "engalfinhados": "engalfinhar",
    "engalfinhai": "engalfinhar",
    "engalfinhais": "engalfinhar",
    "engalfinham": "engalfinhar",
    "engalfinhamentos": "engalfinhamento",
    "engalfinhamo": "engalfinhar",
    "engalfinhamos": "engalfinhar",
    "engalfinhando": "engalfinhar",
    "engalfinhara": "engalfinhar",
    "engalfinharam": "engalfinhar",
    "engalfinharas": "engalfinhar",
    "engalfinharde": "engalfinhar",
    "engalfinhardes": "engalfinhar",
    "engalfinhare": "engalfinhar",
    "engalfinharei": "engalfinhar",
    "engalfinhareis": "engalfinhar",
    "engalfinharem": "engalfinhar",
    "engalfinharemos": "engalfinhar",
    "engalfinhares": "engalfinhar",
    "engalfinharia": "engalfinhar",
    "engalfinhariam": "engalfinhar",
    "engalfinharias": "engalfinhar",
    "engalfinharmo": "engalfinhar",
    "engalfinharmos": "engalfinhar",
    "engalfinhará": "engalfinhar",
    "engalfinharás": "engalfinhar",
    "engalfinharão": "engalfinhar",
    "engalfinharíamos": "engalfinhar",
    "engalfinharíeis": "engalfinhar",
    "engalfinhas": "engalfinhar",
    "engalfinhasse": "engalfinhar",
    "engalfinhassem": "engalfinhar",
    "engalfinhasses": "engalfinhar",
    "engalfinhaste": "engalfinhar",
    "engalfinhastes": "engalfinhar",
    "engalfinhava": "engalfinhar",
    "engalfinhavam": "engalfinhar",
    "engalfinhavas": "engalfinhar",
    "engalfinhe": "engalfinhar",
    "engalfinhei": "engalfinhar",
    "engalfinheis": "engalfinhar",
    "engalfinhem": "engalfinhar",
    "engalfinhemo": "engalfinhar",
    "engalfinhemos": "engalfinhar",
    "engalfinhes": "engalfinhar",
    "engalfinho": "engalfinhar",
    "engalfinhou": "engalfinhar",
    "engalfinhá": "engalfinhar",
    "engalfinhámo": "engalfinhar",
    "engalfinhámos": "engalfinhar",
    "engalfinháramo": "engalfinhar",
    "engalfinháramos": "engalfinhar",
    "engalfinhárei": "engalfinhar",
    "engalfinháreis": "engalfinhar",
    "engalfinhásseis": "engalfinhar",
    "engalfinhássemos": "engalfinhar",
    "engalfinhávamo": "engalfinhar",
    "engalfinhávamos": "engalfinhar",
    "engalfinhávei": "engalfinhar",
    "engalfinháveis": "engalfinhar",
    "engalha": "engalhar",
    "engalhada": "engalhar",
    "engalhadas": "engalhar",
    "engalhado": "engalhar",
    "engalhados": "engalhar",
    "engalhai": "engalhar",
    "engalhais": "engalhar",
    "engalham": "engalhar",
    "engalhamo": "engalhar",
    "engalhamos": "engalhar",
    "engalhando": "engalhar",
    "engalhara": "engalhar",
    "engalharam": "engalhar",
    "engalharas": "engalhar",
    "engalharde": "engalhar",
    "engalhardeada": "engalhardear",
    "engalhardeadas": "engalhardear",
    "engalhardeado": "engalhardear",
    "engalhardeados": "engalhardear",
    "engalhardeai": "engalhardear",
    "engalhardeais": "engalhardear",
    "engalhardeamo": "engalhardear",
    "engalhardeamos": "engalhardear",
    "engalhardeando": "engalhardear",
    "engalhardeara": "engalhardear",
    "engalhardearam": "engalhardear",
    "engalhardearas": "engalhardear",
    "engalhardearde": "engalhardear",
    "engalhardeardes": "engalhardear",
    "engalhardeare": "engalhardear",
    "engalhardearei": "engalhardear",
    "engalhardeareis": "engalhardear",
    "engalhardearem": "engalhardear",
    "engalhardearemos": "engalhardear",
    "engalhardeares": "engalhardear",
    "engalhardearia": "engalhardear",
    "engalhardeariam": "engalhardear",
    "engalhardearias": "engalhardear",
    "engalhardearmo": "engalhardear",
    "engalhardearmos": "engalhardear",
    "engalhardeará": "engalhardear",
    "engalhardearás": "engalhardear",
    "engalhardearão": "engalhardear",
    "engalhardearíamos": "engalhardear",
    "engalhardearíeis": "engalhardear",
    "engalhardeasse": "engalhardear",
    "engalhardeassem": "engalhardear",
    "engalhardeasses": "engalhardear",
    "engalhardeaste": "engalhardear",
    "engalhardeastes": "engalhardear",
    "engalhardeava": "engalhardear",
    "engalhardeavam": "engalhardear",
    "engalhardeavas": "engalhardear",
    "engalhardeei": "engalhardear",
    "engalhardeeis": "engalhardear",
    "engalhardeemo": "engalhardear",
    "engalhardeemos": "engalhardear",
    "engalhardeia": "engalhardear",
    "engalhardeiam": "engalhardear",
    "engalhardeias": "engalhardear",
    "engalhardeie": "engalhardear",
    "engalhardeiem": "engalhardear",
    "engalhardeies": "engalhardear",
    "engalhardeio": "engalhardear",
    "engalhardeou": "engalhardear",
    "engalhardes": "engalhar",
    "engalhardeta": "engalhardetar",
    "engalhardetada": "engalhardetar",
    "engalhardetadas": "engalhardetar",
    "engalhardetado": "engalhardetar",
    "engalhardetados": "engalhardetar",
    "engalhardetai": "engalhardetar",
    "engalhardetais": "engalhardetar",
    "engalhardetam": "engalhardetar",
    "engalhardetamo": "engalhardetar",
    "engalhardetamos": "engalhardetar",
    "engalhardetando": "engalhardetar",
    "engalhardetara": "engalhardetar",
    "engalhardetaram": "engalhardetar",
    "engalhardetaras": "engalhardetar",
    "engalhardetarde": "engalhardetar",
    "engalhardetardes": "engalhardetar",
    "engalhardetare": "engalhardetar",
    "engalhardetarei": "engalhardetar",
    "engalhardetareis": "engalhardetar",
    "engalhardetarem": "engalhardetar",
    "engalhardetaremos": "engalhardetar",
    "engalhardetares": "engalhardetar",
    "engalhardetaria": "engalhardetar",
    "engalhardetariam": "engalhardetar",
    "engalhardetarias": "engalhardetar",
    "engalhardetarmo": "engalhardetar",
    "engalhardetarmos": "engalhardetar",
    "engalhardetará": "engalhardetar",
    "engalhardetarás": "engalhardetar",
    "engalhardetarão": "engalhardetar",
    "engalhardetaríamos": "engalhardetar",
    "engalhardetaríeis": "engalhardetar",
    "engalhardetas": "engalhardetar",
    "engalhardetasse": "engalhardetar",
    "engalhardetassem": "engalhardetar",
    "engalhardetasses": "engalhardetar",
    "engalhardetaste": "engalhardetar",
    "engalhardetastes": "engalhardetar",
    "engalhardetava": "engalhardetar",
    "engalhardetavam": "engalhardetar",
    "engalhardetavas": "engalhardetar",
    "engalhardete": "engalhardetar",
    "engalhardetei": "engalhardetar",
    "engalhardeteis": "engalhardetar",
    "engalhardetem": "engalhardetar",
    "engalhardetemo": "engalhardetar",
    "engalhardetemos": "engalhardetar",
    "engalhardetes": "engalhardetar",
    "engalhardeto": "engalhardetar",
    "engalhardetou": "engalhardetar",
    "engalhardetá": "engalhardetar",
    "engalhardetámo": "engalhardetar",
    "engalhardetámos": "engalhardetar",
    "engalhardetáramo": "engalhardetar",
    "engalhardetáramos": "engalhardetar",
    "engalhardetárei": "engalhardetar",
    "engalhardetáreis": "engalhardetar",
    "engalhardetásseis": "engalhardetar",
    "engalhardetássemos": "engalhardetar",
    "engalhardetávamo": "engalhardetar",
    "engalhardetávamos": "engalhardetar",
    "engalhardetávei": "engalhardetar",
    "engalhardetáveis": "engalhardetar",
    "engalhardeá": "engalhardear",
    "engalhardeámo": "engalhardear",
    "engalhardeámos": "engalhardear",
    "engalhardeáramo": "engalhardear",
    "engalhardeáramos": "engalhardear",
    "engalhardeárei": "engalhardear",
    "engalhardeáreis": "engalhardear",
    "engalhardeásseis": "engalhardear",
    "engalhardeássemos": "engalhardear",
    "engalhardeávamo": "engalhardear",
    "engalhardeávamos": "engalhardear",
    "engalhardeávei": "engalhardear",
    "engalhardeáveis": "engalhardear",
    "engalhare": "engalhar",
    "engalharei": "engalhar",
    "engalhareis": "engalhar",
    "engalharem": "engalhar",
    "engalharemos": "engalhar",
    "engalhares": "engalhar",
    "engalharia": "engalhar",
    "engalhariam": "engalhar",
    "engalharias": "engalhar",
    "engalharmo": "engalhar",
    "engalharmos": "engalhar",
    "engalhará": "engalhar",
    "engalharás": "engalhar",
    "engalharão": "engalhar",
    "engalharíamos": "engalhar",
    "engalharíeis": "engalhar",
    "engalhas": "engalhar",
    "engalhasse": "engalhar",
    "engalhassem": "engalhar",
    "engalhasses": "engalhar",
    "engalhaste": "engalhar",
    "engalhastes": "engalhar",
    "engalhava": "engalhar",
    "engalhavam": "engalhar",
    "engalhavas": "engalhar",
    "engalhe": "engalhar",
    "engalhei": "engalhar",
    "engalheis": "engalhar",
    "engalhem": "engalhar",
    "engalhemo": "engalhar",
    "engalhemos": "engalhar",
    "engalhes": "engalhar",
    "engalho": "engalhar",
    "engalhou": "engalhar",
    "engalhá": "engalhar",
    "engalhámo": "engalhar",
    "engalhámos": "engalhar",
    "engalháramo": "engalhar",
    "engalháramos": "engalhar",
    "engalhárei": "engalhar",
    "engalháreis": "engalhar",
    "engalhásseis": "engalhar",
    "engalhássemos": "engalhar",
    "engalhávamo": "engalhar",
    "engalhávamos": "engalhar",
    "engalhávei": "engalhar",
    "engalháveis": "engalhar",
    "engalinha": "engalinhar",
    "engalinhada": "engalinhar",
    "engalinhadas": "engalinhar",
    "engalinhado": "engalinhar",
    "engalinhados": "engalinhar",
    "engalinhai": "engalinhar",
    "engalinhais": "engalinhar",
    "engalinham": "engalinhar",
    "engalinhamo": "engalinhar",
    "engalinhamos": "engalinhar",
    "engalinhando": "engalinhar",
    "engalinhara": "engalinhar",
    "engalinharam": "engalinhar",
    "engalinharas": "engalinhar",
    "engalinharde": "engalinhar",
    "engalinhardes": "engalinhar",
    "engalinhare": "engalinhar",
    "engalinharei": "engalinhar",
    "engalinhareis": "engalinhar",
    "engalinharem": "engalinhar",
    "engalinharemos": "engalinhar",
    "engalinhares": "engalinhar",
    "engalinharia": "engalinhar",
    "engalinhariam": "engalinhar",
    "engalinharias": "engalinhar",
    "engalinharmo": "engalinhar",
    "engalinharmos": "engalinhar",
    "engalinhará": "engalinhar",
    "engalinharás": "engalinhar",
    "engalinharão": "engalinhar",
    "engalinharíamos": "engalinhar",
    "engalinharíeis": "engalinhar",
    "engalinhas": "engalinhar",
    "engalinhasse": "engalinhar",
    "engalinhassem": "engalinhar",
    "engalinhasses": "engalinhar",
    "engalinhaste": "engalinhar",
    "engalinhastes": "engalinhar",
    "engalinhava": "engalinhar",
    "engalinhavam": "engalinhar",
    "engalinhavas": "engalinhar",
    "engalinhe": "engalinhar",
    "engalinhei": "engalinhar",
    "engalinheis": "engalinhar",
    "engalinhem": "engalinhar",
    "engalinhemo": "engalinhar",
    "engalinhemos": "engalinhar",
    "engalinhes": "engalinhar",
    "engalinho": "engalinhar",
    "engalinhou": "engalinhar",
    "engalinhá": "engalinhar",
    "engalinhámo": "engalinhar",
    "engalinhámos": "engalinhar",
    "engalinháramo": "engalinhar",
    "engalinháramos": "engalinhar",
    "engalinhárei": "engalinhar",
    "engalinháreis": "engalinhar",
    "engalinhásseis": "engalinhar",
    "engalinhássemos": "engalinhar",
    "engalinhávamo": "engalinhar",
    "engalinhávamos": "engalinhar",
    "engalinhávei": "engalinhar",
    "engalinháveis": "engalinhar",
    "engalispa": "engalispar",
    "engalispada": "engalispar",
    "engalispadas": "engalispar",
    "engalispado": "engalispar",
    "engalispados": "engalispar",
    "engalispai": "engalispar",
    "engalispais": "engalispar",
    "engalispam": "engalispar",
    "engalispamo": "engalispar",
    "engalispamos": "engalispar",
    "engalispando": "engalispar",
    "engalispara": "engalispar",
    "engalisparam": "engalispar",
    "engalisparas": "engalispar",
    "engalisparde": "engalispar",
    "engalispardes": "engalispar",
    "engalispare": "engalispar",
    "engalisparei": "engalispar",
    "engalispareis": "engalispar",
    "engalisparem": "engalispar",
    "engalisparemos": "engalispar",
    "engalispares": "engalispar",
    "engalisparia": "engalispar",
    "engalispariam": "engalispar",
    "engalisparias": "engalispar",
    "engalisparmo": "engalispar",
    "engalisparmos": "engalispar",
    "engalispará": "engalispar",
    "engalisparás": "engalispar",
    "engalisparão": "engalispar",
    "engalisparíamos": "engalispar",
    "engalisparíeis": "engalispar",
    "engalispas": "engalispar",
    "engalispasse": "engalispar",
    "engalispassem": "engalispar",
    "engalispasses": "engalispar",
    "engalispaste": "engalispar",
    "engalispastes": "engalispar",
    "engalispava": "engalispar",
    "engalispavam": "engalispar",
    "engalispavas": "engalispar",
    "engalispe": "engalispar",
    "engalispei": "engalispar",
    "engalispeis": "engalispar",
    "engalispem": "engalispar",
    "engalispemo": "engalispar",
    "engalispemos": "engalispar",
    "engalispes": "engalispar",
    "engalispo": "engalispar",
    "engalispou": "engalispar",
    "engalispá": "engalispar",
    "engalispámo": "engalispar",
    "engalispámos": "engalispar",
    "engalispáramo": "engalispar",
    "engalispáramos": "engalispar",
    "engalispárei": "engalispar",
    "engalispáreis": "engalispar",
    "engalispásseis": "engalispar",
    "engalispássemos": "engalispar",
    "engalispávamo": "engalispar",
    "engalispávamos": "engalispar",
    "engalispávei": "engalispar",
    "engalispáveis": "engalispar",
    "engalrice": "engalriçar",
    "engalricei": "engalriçar",
    "engalriceis": "engalriçar",
    "engalricem": "engalriçar",
    "engalricemo": "engalriçar",
    "engalricemos": "engalriçar",
    "engalrices": "engalriçar",
    "engalriça": "engalriçar",
    "engalriçada": "engalriçar",
    "engalriçadas": "engalriçar",
    "engalriçado": "engalriçar",
    "engalriçados": "engalriçar",
    "engalriçai": "engalriçar",
    "engalriçais": "engalriçar",
    "engalriçam": "engalriçar",
    "engalriçamo": "engalriçar",
    "engalriçamos": "engalriçar",
    "engalriçando": "engalriçar",
    "engalriçara": "engalriçar",
    "engalriçaram": "engalriçar",
    "engalriçaras": "engalriçar",
    "engalriçarde": "engalriçar",
    "engalriçardes": "engalriçar",
    "engalriçare": "engalriçar",
    "engalriçarei": "engalriçar",
    "engalriçareis": "engalriçar",
    "engalriçarem": "engalriçar",
    "engalriçaremos": "engalriçar",
    "engalriçares": "engalriçar",
    "engalriçaria": "engalriçar",
    "engalriçariam": "engalriçar",
    "engalriçarias": "engalriçar",
    "engalriçarmo": "engalriçar",
    "engalriçarmos": "engalriçar",
    "engalriçará": "engalriçar",
    "engalriçarás": "engalriçar",
    "engalriçarão": "engalriçar",
    "engalriçaríamos": "engalriçar",
    "engalriçaríeis": "engalriçar",
    "engalriças": "engalriçar",
    "engalriçasse": "engalriçar",
    "engalriçassem": "engalriçar",
    "engalriçasses": "engalriçar",
    "engalriçaste": "engalriçar",
    "engalriçastes": "engalriçar",
    "engalriçava": "engalriçar",
    "engalriçavam": "engalriçar",
    "engalriçavas": "engalriçar",
    "engalriço": "engalriçar",
    "engalriçou": "engalriçar",
    "engalriçá": "engalriçar",
    "engalriçámo": "engalriçar",
    "engalriçámos": "engalriçar",
    "engalriçáramo": "engalriçar",
    "engalriçáramos": "engalriçar",
    "engalriçárei": "engalriçar",
    "engalriçáreis": "engalriçar",
    "engalriçásseis": "engalriçar",
    "engalriçássemos": "engalriçar",
    "engalriçávamo": "engalriçar",
    "engalriçávamos": "engalriçar",
    "engalriçávei": "engalriçar",
    "engalriçáveis": "engalriçar",
    "engam": "engar",
    "engambela": "engambelar",
    "engambelada": "engambelar",
    "engambeladas": "engambelar",
    "engambelado": "engambelar",
    "engambelados": "engambelar",
    "engambelai": "engambelar",
    "engambelais": "engambelar",
    "engambelam": "engambelar",
    "engambelamo": "engambelar",
    "engambelamos": "engambelar",
    "engambelando": "engambelar",
    "engambelara": "engambelar",
    "engambelaram": "engambelar",
    "engambelaras": "engambelar",
    "engambelarde": "engambelar",
    "engambelardes": "engambelar",
    "engambelare": "engambelar",
    "engambelarei": "engambelar",
    "engambelareis": "engambelar",
    "engambelarem": "engambelar",
    "engambelaremos": "engambelar",
    "engambelares": "engambelar",
    "engambelaria": "engambelar",
    "engambelariam": "engambelar",
    "engambelarias": "engambelar",
    "engambelarmo": "engambelar",
    "engambelarmos": "engambelar",
    "engambelará": "engambelar",
    "engambelarás": "engambelar",
    "engambelarão": "engambelar",
    "engambelaríamos": "engambelar",
    "engambelaríeis": "engambelar",
    "engambelas": "engambelar",
    "engambelasse": "engambelar",
    "engambelassem": "engambelar",
    "engambelasses": "engambelar",
    "engambelaste": "engambelar",
    "engambelastes": "engambelar",
    "engambelava": "engambelar",
    "engambelavam": "engambelar",
    "engambelavas": "engambelar",
    "engambele": "engambelar",
    "engambelei": "engambelar",
    "engambeleis": "engambelar",
    "engambelem": "engambelar",
    "engambelemo": "engambelar",
    "engambelemos": "engambelar",
    "engambeles": "engambelar",
    "engambelo": "engambelar",
    "engambelos": "engambelo",
    "engambelou": "engambelar",
    "engambelá": "engambelar",
    "engambelámo": "engambelar",
    "engambelámos": "engambelar",
    "engambeláramo": "engambelar",
    "engambeláramos": "engambelar",
    "engambelárei": "engambelar",
    "engambeláreis": "engambelar",
    "engambelásseis": "engambelar",
    "engambelássemos": "engambelar",
    "engambelávamo": "engambelar",
    "engambelávamos": "engambelar",
    "engambelávei": "engambelar",
    "engambeláveis": "engambelar",
    "engamo": "engar",
    "engamos": "engar",
    "engana": "enganir",
    "enganada": "enganar",
    "enganadas": "enganar",
    "enganadiça": "enganadiço",
    "enganadiças": "enganadiço",
    "enganadiços": "enganadiço",
    "enganado": "enganar",
    "enganadora": "enganador",
    "enganadoras": "enganador",
    "enganadores": "enganador",
    "enganados": "enganar",
    "enganadíssima": "enganado",
    "enganadíssimas": "enganado",
    "enganadíssimo": "enganado",
    "enganadíssimos": "enganado",
    "enganai": "enganar",
    "enganais": "enganir",
    "enganam": "enganir",
    "enganamo": "enganir",
    "enganamos": "enganir",
    "enganando": "enganar",
    "enganara": "enganar",
    "enganaram": "enganar",
    "enganaras": "enganar",
    "enganarde": "enganar",
    "enganardes": "enganar",
    "enganare": "enganar",
    "enganarei": "enganar",
    "enganareis": "enganar",
    "enganarem": "enganar",
    "enganaremos": "enganar",
    "enganares": "enganar",
    "enganaria": "enganar",
    "enganariam": "enganar",
    "enganarias": "enganar",
    "enganarmo": "enganar",
    "enganarmos": "enganar",
    "enganará": "enganar",
    "enganarás": "enganar",
    "enganarão": "enganar",
    "enganaríamos": "enganar",
    "enganaríeis": "enganar",
    "enganas": "enganir",
    "enganasse": "enganar",
    "enganassem": "enganar",
    "enganasses": "enganar",
    "enganaste": "enganar",
    "enganastes": "enganar",
    "enganava": "enganar",
    "enganavam": "enganar",
    "enganavas": "enganar",
    "enganações": "enganação",
    "engancha": "enganchar",
    "enganchada": "enganchar",
    "enganchadas": "enganchar",
    "enganchado": "enganchar",
    "enganchados": "enganchar",
    "enganchai": "enganchar",
    "enganchais": "enganchar",
    "engancham": "enganchar",
    "enganchamo": "enganchar",
    "enganchamos": "enganchar",
    "enganchando": "enganchar",
    "enganchara": "enganchar",
    "engancharam": "enganchar",
    "engancharas": "enganchar",
    "engancharde": "enganchar",
    "enganchardes": "enganchar",
    "enganchare": "enganchar",
    "engancharei": "enganchar",
    "enganchareis": "enganchar",
    "engancharem": "enganchar",
    "engancharemos": "enganchar",
    "enganchares": "enganchar",
    "engancharia": "enganchar",
    "enganchariam": "enganchar",
    "engancharias": "enganchar",
    "engancharmo": "enganchar",
    "engancharmos": "enganchar",
    "enganchará": "enganchar",
    "engancharás": "enganchar",
    "engancharão": "enganchar",
    "engancharíamos": "enganchar",
    "engancharíeis": "enganchar",
    "enganchas": "enganchar",
    "enganchasse": "enganchar",
    "enganchassem": "enganchar",
    "enganchasses": "enganchar",
    "enganchaste": "enganchar",
    "enganchastes": "enganchar",
    "enganchava": "enganchar",
    "enganchavam": "enganchar",
    "enganchavas": "enganchar",
    "enganche": "enganchar",
    "enganchei": "enganchar",
    "engancheis": "enganchar",
    "enganchem": "enganchar",
    "enganchemo": "enganchar",
    "enganchemos": "enganchar",
    "enganches": "enganchar",
    "engancho": "enganchar",
    "enganchou": "enganchar",
    "enganchá": "enganchar",
    "enganchámo": "enganchar",
    "enganchámos": "enganchar",
    "engancháramo": "enganchar",
    "engancháramos": "enganchar",
    "enganchárei": "enganchar",
    "engancháreis": "enganchar",
    "enganchásseis": "enganchar",
    "enganchássemos": "enganchar",
    "enganchávamo": "enganchar",
    "enganchávamos": "enganchar",
    "enganchávei": "enganchar",
    "engancháveis": "enganchar",
    "engando": "engar",
    "engane": "enganir",
    "enganei": "enganar",
    "enganeis": "enganar",
    "enganem": "enganir",
    "enganemo": "enganar",
    "enganemos": "enganar",
    "enganes": "enganir",
    "engani": "enganir",
    "engania": "enganir",
    "enganiam": "enganir",
    "enganias": "enganir",
    "enganida": "enganir",
    "enganidas": "enganir",
    "enganido": "enganir",
    "enganidos": "enganir",
    "enganimo": "enganir",
    "enganimos": "enganir",
    "enganindo": "enganir",
    "enganira": "enganir",
    "enganiram": "enganir",
    "enganiras": "enganir",
    "enganirdes": "enganir",
    "enganirei": "enganir",
    "enganireis": "enganir",
    "enganirem": "enganir",
    "enganiremos": "enganir",
    "enganires": "enganir",
    "enganiria": "enganir",
    "enganiriam": "enganir",
    "enganirias": "enganir",
    "enganirmo": "enganir",
    "enganirmos": "enganir",
    "enganirá": "enganir",
    "enganirás": "enganir",
    "enganirão": "enganir",
    "enganiríamos": "enganir",
    "enganiríeis": "enganir",
    "enganis": "enganir",
    "enganisse": "enganir",
    "enganissem": "enganir",
    "enganisses": "enganir",
    "enganiste": "enganir",
    "enganistes": "enganir",
    "enganiu": "enganir",
    "engano": "enganir",
    "enganos": "engano",
    "enganosa": "enganoso",
    "enganosas": "enganoso",
    "enganosos": "enganoso",
    "enganou": "enganar",
    "enganzupa": "enganzupar",
    "enganzupada": "enganzupar",
    "enganzupadas": "enganzupar",
    "enganzupado": "enganzupar",
    "enganzupados": "enganzupar",
    "enganzupai": "enganzupar",
    "enganzupais": "enganzupar",
    "enganzupam": "enganzupar",
    "enganzupamo": "enganzupar",
    "enganzupamos": "enganzupar",
    "enganzupando": "enganzupar",
    "enganzupara": "enganzupar",
    "enganzuparam": "enganzupar",
    "enganzuparas": "enganzupar",
    "enganzuparde": "enganzupar",
    "enganzupardes": "enganzupar",
    "enganzupare": "enganzupar",
    "enganzuparei": "enganzupar",
    "enganzupareis": "enganzupar",
    "enganzuparem": "enganzupar",
    "enganzuparemos": "enganzupar",
    "enganzupares": "enganzupar",
    "enganzuparia": "enganzupar",
    "enganzupariam": "enganzupar",
    "enganzuparias": "enganzupar",
    "enganzuparmo": "enganzupar",
    "enganzuparmos": "enganzupar",
    "enganzupará": "enganzupar",
    "enganzuparás": "enganzupar",
    "enganzuparão": "enganzupar",
    "enganzuparíamos": "enganzupar",
    "enganzuparíeis": "enganzupar",
    "enganzupas": "enganzupar",
    "enganzupasse": "enganzupar",
    "enganzupassem": "enganzupar",
    "enganzupasses": "enganzupar",
    "enganzupaste": "enganzupar",
    "enganzupastes": "enganzupar",
    "enganzupava": "enganzupar",
    "enganzupavam": "enganzupar",
    "enganzupavas": "enganzupar",
    "enganzupe": "enganzupar",
    "enganzupei": "enganzupar",
    "enganzupeis": "enganzupar",
    "enganzupem": "enganzupar",
    "enganzupemo": "enganzupar",
    "enganzupemos": "enganzupar",
    "enganzupes": "enganzupar",
    "enganzupo": "enganzupar",
    "enganzupou": "enganzupar",
    "enganzupá": "enganzupar",
    "enganzupámo": "enganzupar",
    "enganzupámos": "enganzupar",
    "enganzupáramo": "enganzupar",
    "enganzupáramos": "enganzupar",
    "enganzupárei": "enganzupar",
    "enganzupáreis": "enganzupar",
    "enganzupásseis": "enganzupar",
    "enganzupássemos": "enganzupar",
    "enganzupávamo": "enganzupar",
    "enganzupávamos": "enganzupar",
    "enganzupávei": "enganzupar",
    "enganzupáveis": "enganzupar",
    "enganá": "enganar",
    "enganámo": "enganar",
    "enganámos": "enganar",
    "enganáramo": "enganar",
    "enganáramos": "enganar",
    "enganárei": "enganar",
    "enganáreis": "enganar",
    "enganásseis": "enganar",
    "enganássemos": "enganar",
    "enganávamo": "enganar",
    "enganávamos": "enganar",
    "enganávei": "enganar",
    "enganáveis": "enganável",
    "enganíamo": "enganir",
    "enganíamos": "enganir",
    "enganíeis": "enganir",
    "enganíramo": "enganir",
    "enganíramos": "enganir",
    "enganíreis": "enganir",
    "enganísseis": "enganir",
    "enganíssemos": "enganir",
    "engara": "engar",
    "engaram": "engar",
    "engaranha": "engaranhar",
    "engaranhada": "engaranhar",
    "engaranhadas": "engaranhar",
    "engaranhado": "engaranhar",
    "engaranhados": "engaranhar",
    "engaranhai": "engaranhar",
    "engaranhais": "engaranhar",
    "engaranham": "engaranhar",
    "engaranhamo": "engaranhar",
    "engaranhamos": "engaranhar",
    "engaranhando": "engaranhar",
    "engaranhara": "engaranhar",
    "engaranharam": "engaranhar",
    "engaranharas": "engaranhar",
    "engaranharde": "engaranhar",
    "engaranhardes": "engaranhar",
    "engaranhare": "engaranhar",
    "engaranharei": "engaranhar",
    "engaranhareis": "engaranhar",
    "engaranharem": "engaranhar",
    "engaranharemos": "engaranhar",
    "engaranhares": "engaranhar",
    "engaranharia": "engaranhar",
    "engaranhariam": "engaranhar",
    "engaranharias": "engaranhar",
    "engaranharmo": "engaranhar",
    "engaranharmos": "engaranhar",
    "engaranhará": "engaranhar",
    "engaranharás": "engaranhar",
    "engaranharão": "engaranhar",
    "engaranharíamos": "engaranhar",
    "engaranharíeis": "engaranhar",
    "engaranhas": "engaranhar",
    "engaranhasse": "engaranhar",
    "engaranhassem": "engaranhar",
    "engaranhasses": "engaranhar",
    "engaranhaste": "engaranhar",
    "engaranhastes": "engaranhar",
    "engaranhava": "engaranhar",
    "engaranhavam": "engaranhar",
    "engaranhavas": "engaranhar",
    "engaranhe": "engaranhar",
    "engaranhei": "engaranhar",
    "engaranheis": "engaranhar",
    "engaranhem": "engaranhar",
    "engaranhemo": "engaranhar",
    "engaranhemos": "engaranhar",
    "engaranhes": "engaranhar",
    "engaranho": "engaranhar",
    "engaranhou": "engaranhar",
    "engaranhá": "engaranhar",
    "engaranhámo": "engaranhar",
    "engaranhámos": "engaranhar",
    "engaranháramo": "engaranhar",
    "engaranháramos": "engaranhar",
    "engaranhárei": "engaranhar",
    "engaranháreis": "engaranhar",
    "engaranhásseis": "engaranhar",
    "engaranhássemos": "engaranhar",
    "engaranhávamo": "engaranhar",
    "engaranhávamos": "engaranhar",
    "engaranhávei": "engaranhar",
    "engaranháveis": "engaranhar",
    "engarapa": "engarapar",
    "engarapada": "engarapar",
    "engarapadas": "engarapar",
    "engarapado": "engarapar",
    "engarapados": "engarapar",
    "engarapai": "engarapar",
    "engarapais": "engarapar",
    "engarapam": "engarapar",
    "engarapamo": "engarapar",
    "engarapamos": "engarapar",
    "engarapando": "engarapar",
    "engarapara": "engarapar",
    "engaraparam": "engarapar",
    "engaraparas": "engarapar",
    "engaraparde": "engarapar",
    "engarapardes": "engarapar",
    "engarapare": "engarapar",
    "engaraparei": "engarapar",
    "engarapareis": "engarapar",
    "engaraparem": "engarapar",
    "engaraparemos": "engarapar",
    "engarapares": "engarapar",
    "engaraparia": "engarapar",
    "engarapariam": "engarapar",
    "engaraparias": "engarapar",
    "engaraparmo": "engarapar",
    "engaraparmos": "engarapar",
    "engarapará": "engarapar",
    "engaraparás": "engarapar",
    "engaraparão": "engarapar",
    "engaraparíamos": "engarapar",
    "engaraparíeis": "engarapar",
    "engarapas": "engarapar",
    "engarapasse": "engarapar",
    "engarapassem": "engarapar",
    "engarapasses": "engarapar",
    "engarapaste": "engarapar",
    "engarapastes": "engarapar",
    "engarapava": "engarapar",
    "engarapavam": "engarapar",
    "engarapavas": "engarapar",
    "engarape": "engarapar",
    "engarapei": "engarapar",
    "engarapeis": "engarapar",
    "engarapem": "engarapar",
    "engarapemo": "engarapar",
    "engarapemos": "engarapar",
    "engarapes": "engarapar",
    "engarapo": "engarapar",
    "engarapou": "engarapar",
    "engarapá": "engarapar",
    "engarapámo": "engarapar",
    "engarapámos": "engarapar",
    "engarapáramo": "engarapar",
    "engarapáramos": "engarapar",
    "engarapárei": "engarapar",
    "engarapáreis": "engarapar",
    "engarapásseis": "engarapar",
    "engarapássemos": "engarapar",
    "engarapávamo": "engarapar",
    "engarapávamos": "engarapar",
    "engarapávei": "engarapar",
    "engarapáveis": "engarapar",
    "engaras": "engar",
    "engaravita": "engaravitar",
    "engaravitada": "engaravitar",
    "engaravitadas": "engaravitar",
    "engaravitado": "engaravitar",
    "engaravitados": "engaravitar",
    "engaravitai": "engaravitar",
    "engaravitais": "engaravitar",
    "engaravitam": "engaravitar",
    "engaravitamo": "engaravitar",
    "engaravitamos": "engaravitar",
    "engaravitando": "engaravitar",
    "engaravitara": "engaravitar",
    "engaravitaram": "engaravitar",
    "engaravitaras": "engaravitar",
    "engaravitarde": "engaravitar",
    "engaravitardes": "engaravitar",
    "engaravitare": "engaravitar",
    "engaravitarei": "engaravitar",
    "engaravitareis": "engaravitar",
    "engaravitarem": "engaravitar",
    "engaravitaremos": "engaravitar",
    "engaravitares": "engaravitar",
    "engaravitaria": "engaravitar",
    "engaravitariam": "engaravitar",
    "engaravitarias": "engaravitar",
    "engaravitarmo": "engaravitar",
    "engaravitarmos": "engaravitar",
    "engaravitará": "engaravitar",
    "engaravitarás": "engaravitar",
    "engaravitarão": "engaravitar",
    "engaravitaríamos": "engaravitar",
    "engaravitaríeis": "engaravitar",
    "engaravitas": "engaravitar",
    "engaravitasse": "engaravitar",
    "engaravitassem": "engaravitar",
    "engaravitasses": "engaravitar",
    "engaravitaste": "engaravitar",
    "engaravitastes": "engaravitar",
    "engaravitava": "engaravitar",
    "engaravitavam": "engaravitar",
    "engaravitavas": "engaravitar",
    "engaravite": "engaravitar",
    "engaravitei": "engaravitar",
    "engaraviteis": "engaravitar",
    "engaravitem": "engaravitar",
    "engaravitemo": "engaravitar",
    "engaravitemos": "engaravitar",
    "engaravites": "engaravitar",
    "engaravito": "engaravitar",
    "engaravitou": "engaravitar",
    "engaravitá": "engaravitar",
    "engaravitámo": "engaravitar",
    "engaravitámos": "engaravitar",
    "engaravitáramo": "engaravitar",
    "engaravitáramos": "engaravitar",
    "engaravitárei": "engaravitar",
    "engaravitáreis": "engaravitar",
    "engaravitásseis": "engaravitar",
    "engaravitássemos": "engaravitar",
    "engaravitávamo": "engaravitar",
    "engaravitávamos": "engaravitar",
    "engaravitávei": "engaravitar",
    "engaravitáveis": "engaravitar",
    "engardes": "engar",
    "engarei": "engar",
    "engareis": "engar",
    "engarelas": "engarela",
    "engarem": "engar",
    "engaremos": "engar",
    "engares": "engar",
    "engargalha": "engargalhar",
    "engargalhada": "engargalhar",
    "engargalhadas": "engargalhar",
    "engargalhado": "engargalhar",
    "engargalhados": "engargalhar",
    "engargalhai": "engargalhar",
    "engargalhais": "engargalhar",
    "engargalham": "engargalhar",
    "engargalhamo": "engargalhar",
    "engargalhamos": "engargalhar",
    "engargalhando": "engargalhar",
    "engargalhara": "engargalhar",
    "engargalharam": "engargalhar",
    "engargalharas": "engargalhar",
    "engargalharde": "engargalhar",
    "engargalhardes": "engargalhar",
    "engargalhare": "engargalhar",
    "engargalharei": "engargalhar",
    "engargalhareis": "engargalhar",
    "engargalharem": "engargalhar",
    "engargalharemos": "engargalhar",
    "engargalhares": "engargalhar",
    "engargalharia": "engargalhar",
    "engargalhariam": "engargalhar",
    "engargalharias": "engargalhar",
    "engargalharmo": "engargalhar",
    "engargalharmos": "engargalhar",
    "engargalhará": "engargalhar",
    "engargalharás": "engargalhar",
    "engargalharão": "engargalhar",
    "engargalharíamos": "engargalhar",
    "engargalharíeis": "engargalhar",
    "engargalhas": "engargalhar",
    "engargalhasse": "engargalhar",
    "engargalhassem": "engargalhar",
    "engargalhasses": "engargalhar",
    "engargalhaste": "engargalhar",
    "engargalhastes": "engargalhar",
    "engargalhava": "engargalhar",
    "engargalhavam": "engargalhar",
    "engargalhavas": "engargalhar",
    "engargalhe": "engargalhar",
    "engargalhei": "engargalhar",
    "engargalheis": "engargalhar",
    "engargalhem": "engargalhar",
    "engargalhemo": "engargalhar",
    "engargalhemos": "engargalhar",
    "engargalhes": "engargalhar",
    "engargalho": "engargalhar",
    "engargalhou": "engargalhar",
    "engargalhá": "engargalhar",
    "engargalhámo": "engargalhar",
    "engargalhámos": "engargalhar",
    "engargalháramo": "engargalhar",
    "engargalháramos": "engargalhar",
    "engargalhárei": "engargalhar",
    "engargalháreis": "engargalhar",
    "engargalhásseis": "engargalhar",
    "engargalhássemos": "engargalhar",
    "engargalhávamo": "engargalhar",
    "engargalhávamos": "engargalhar",
    "engargalhávei": "engargalhar",
    "engargalháveis": "engargalhar",
    "engarganta": "engargantar",
    "engargantada": "engargantar",
    "engargantadas": "engargantar",
    "engargantado": "engargantar",
    "engargantados": "engargantar",
    "engargantai": "engargantar",
    "engargantais": "engargantar",
    "engargantam": "engargantar",
    "engargantamo": "engargantar",
    "engargantamos": "engargantar",
    "engargantando": "engargantar",
    "engargantara": "engargantar",
    "engargantaram": "engargantar",
    "engargantaras": "engargantar",
    "engargantarde": "engargantar",
    "engargantardes": "engargantar",
    "engargantare": "engargantar",
    "engargantarei": "engargantar",
    "engargantareis": "engargantar",
    "engargantarem": "engargantar",
    "engargantaremos": "engargantar",
    "engargantares": "engargantar",
    "engargantaria": "engargantar",
    "engargantariam": "engargantar",
    "engargantarias": "engargantar",
    "engargantarmo": "engargantar",
    "engargantarmos": "engargantar",
    "engargantará": "engargantar",
    "engargantarás": "engargantar",
    "engargantarão": "engargantar",
    "engargantaríamos": "engargantar",
    "engargantaríeis": "engargantar",
    "engargantas": "engargantar",
    "engargantasse": "engargantar",
    "engargantassem": "engargantar",
    "engargantasses": "engargantar",
    "engargantaste": "engargantar",
    "engargantastes": "engargantar",
    "engargantava": "engargantar",
    "engargantavam": "engargantar",
    "engargantavas": "engargantar",
    "engargante": "engargantar",
    "engargantei": "engargantar",
    "engarganteis": "engargantar",
    "engargantem": "engargantar",
    "engargantemo": "engargantar",
    "engargantemos": "engargantar",
    "engargantes": "engargantar",
    "engarganto": "engargantar",
    "engargantou": "engargantar",
    "engargantá": "engargantar",
    "engargantámo": "engargantar",
    "engargantámos": "engargantar",
    "engargantáramo": "engargantar",
    "engargantáramos": "engargantar",
    "engargantárei": "engargantar",
    "engargantáreis": "engargantar",
    "engargantásseis": "engargantar",
    "engargantássemos": "engargantar",
    "engargantávamo": "engargantar",
    "engargantávamos": "engargantar",
    "engargantávei": "engargantar",
    "engargantáveis": "engargantar",
    "engaria": "engar",
    "engariam": "engar",
    "engarias": "engar",
    "engarilhos": "engarilho",
    "engarmo": "engar",
    "engarmos": "engar",
    "engarnacha": "engarnachar",
    "engarnachada": "engarnachar",
    "engarnachadas": "engarnachar",
    "engarnachado": "engarnachar",
    "engarnachados": "engarnachar",
    "engarnachai": "engarnachar",
    "engarnachais": "engarnachar",
    "engarnacham": "engarnachar",
    "engarnachamo": "engarnachar",
    "engarnachamos": "engarnachar",
    "engarnachando": "engarnachar",
    "engarnachara": "engarnachar",
    "engarnacharam": "engarnachar",
    "engarnacharas": "engarnachar",
    "engarnacharde": "engarnachar",
    "engarnachardes": "engarnachar",
    "engarnachare": "engarnachar",
    "engarnacharei": "engarnachar",
    "engarnachareis": "engarnachar",
    "engarnacharem": "engarnachar",
    "engarnacharemos": "engarnachar",
    "engarnachares": "engarnachar",
    "engarnacharia": "engarnachar",
    "engarnachariam": "engarnachar",
    "engarnacharias": "engarnachar",
    "engarnacharmo": "engarnachar",
    "engarnacharmos": "engarnachar",
    "engarnachará": "engarnachar",
    "engarnacharás": "engarnachar",
    "engarnacharão": "engarnachar",
    "engarnacharíamos": "engarnachar",
    "engarnacharíeis": "engarnachar",
    "engarnachas": "engarnachar",
    "engarnachasse": "engarnachar",
    "engarnachassem": "engarnachar",
    "engarnachasses": "engarnachar",
    "engarnachaste": "engarnachar",
    "engarnachastes": "engarnachar",
    "engarnachava": "engarnachar",
    "engarnachavam": "engarnachar",
    "engarnachavas": "engarnachar",
    "engarnache": "engarnachar",
    "engarnachei": "engarnachar",
    "engarnacheis": "engarnachar",
    "engarnachem": "engarnachar",
    "engarnachemo": "engarnachar",
    "engarnachemos": "engarnachar",
    "engarnaches": "engarnachar",
    "engarnacho": "engarnachar",
    "engarnachou": "engarnachar",
    "engarnachá": "engarnachar",
    "engarnachámo": "engarnachar",
    "engarnachámos": "engarnachar",
    "engarnacháramo": "engarnachar",
    "engarnacháramos": "engarnachar",
    "engarnachárei": "engarnachar",
    "engarnacháreis": "engarnachar",
    "engarnachásseis": "engarnachar",
    "engarnachássemos": "engarnachar",
    "engarnachávamo": "engarnachar",
    "engarnachávamos": "engarnachar",
    "engarnachávei": "engarnachar",
    "engarnacháveis": "engarnachar",
    "engarradeiras": "engarradeira",
    "engarrafa": "engarrafar",
    "engarrafada": "engarrafar",
    "engarrafadas": "engarrafar",
    "engarrafadeira": "engarrafador",
    "engarrafadeiras": "engarrafador",
    "engarrafadelas": "engarrafadela",
    "engarrafado": "engarrafar",
    "engarrafadora": "engarrafador",
    "engarrafadoras": "engarrafador",
    "engarrafadores": "engarrafador",
    "engarrafados": "engarrafar",
    "engarrafadíssima": "engarrafado",
    "engarrafadíssimas": "engarrafado",
    "engarrafadíssimo": "engarrafado",
    "engarrafadíssimos": "engarrafado",
    "engarrafagens": "engarrafagem",
    "engarrafai": "engarrafar",
    "engarrafais": "engarrafar",
    "engarrafam": "engarrafar",
    "engarrafamentos": "engarrafamento",
    "engarrafamo": "engarrafar",
    "engarrafamos": "engarrafar",
    "engarrafando": "engarrafar",
    "engarrafara": "engarrafar",
    "engarrafaram": "engarrafar",
    "engarrafaras": "engarrafar",
    "engarrafarde": "engarrafar",
    "engarrafardes": "engarrafar",
    "engarrafare": "engarrafar",
    "engarrafarei": "engarrafar",
    "engarrafareis": "engarrafar",
    "engarrafarem": "engarrafar",
    "engarrafaremos": "engarrafar",
    "engarrafares": "engarrafar",
    "engarrafaria": "engarrafar",
    "engarrafariam": "engarrafar",
    "engarrafarias": "engarrafar",
    "engarrafarmo": "engarrafar",
    "engarrafarmos": "engarrafar",
    "engarrafará": "engarrafar",
    "engarrafarás": "engarrafar",
    "engarrafarão": "engarrafar",
    "engarrafaríamos": "engarrafar",
    "engarrafaríeis": "engarrafar",
    "engarrafas": "engarrafar",
    "engarrafasse": "engarrafar",
    "engarrafassem": "engarrafar",
    "engarrafasses": "engarrafar",
    "engarrafaste": "engarrafar",
    "engarrafastes": "engarrafar",
    "engarrafava": "engarrafar",
    "engarrafavam": "engarrafar",
    "engarrafavas": "engarrafar",
    "engarrafe": "engarrafar",
    "engarrafei": "engarrafar",
    "engarrafeis": "engarrafar",
    "engarrafem": "engarrafar",
    "engarrafemo": "engarrafar",
    "engarrafemos": "engarrafar",
    "engarrafes": "engarrafar",
    "engarrafo": "engarrafar",
    "engarrafou": "engarrafar",
    "engarrafá": "engarrafar",
    "engarrafámo": "engarrafar",
    "engarrafámos": "engarrafar",
    "engarrafáramo": "engarrafar",
    "engarrafáramos": "engarrafar",
    "engarrafárei": "engarrafar",
    "engarrafáreis": "engarrafar",
    "engarrafásseis": "engarrafar",
    "engarrafássemos": "engarrafar",
    "engarrafávamo": "engarrafar",
    "engarrafávamos": "engarrafar",
    "engarrafávei": "engarrafar",
    "engarrafáveis": "engarrafar",
    "engarupa": "engarupar",
    "engarupada": "engarupar",
    "engarupadas": "engarupar",
    "engarupado": "engarupar",
    "engarupados": "engarupar",
    "engarupai": "engarupar",
    "engarupais": "engarupar",
    "engarupam": "engarupar",
    "engarupamo": "engarupar",
    "engarupamos": "engarupar",
    "engarupando": "engarupar",
    "engarupara": "engarupar",
    "engaruparam": "engarupar",
    "engaruparas": "engarupar",
    "engaruparde": "engarupar",
    "engarupardes": "engarupar",
    "engarupare": "engarupar",
    "engaruparei": "engarupar",
    "engarupareis": "engarupar",
    "engaruparem": "engarupar",
    "engaruparemos": "engarupar",
    "engarupares": "engarupar",
    "engaruparia": "engarupar",
    "engarupariam": "engarupar",
    "engaruparias": "engarupar",
    "engaruparmo": "engarupar",
    "engaruparmos": "engarupar",
    "engarupará": "engarupar",
    "engaruparás": "engarupar",
    "engaruparão": "engarupar",
    "engaruparíamos": "engarupar",
    "engaruparíeis": "engarupar",
    "engarupas": "engarupar",
    "engarupasse": "engarupar",
    "engarupassem": "engarupar",
    "engarupasses": "engarupar",
    "engarupaste": "engarupar",
    "engarupastes": "engarupar",
    "engarupava": "engarupar",
    "engarupavam": "engarupar",
    "engarupavas": "engarupar",
    "engarupe": "engarupar",
    "engarupei": "engarupar",
    "engarupeis": "engarupar",
    "engarupem": "engarupar",
    "engarupemo": "engarupar",
    "engarupemos": "engarupar",
    "engarupes": "engarupar",
    "engarupo": "engarupar",
    "engarupou": "engarupar",
    "engarupá": "engarupar",
    "engarupámo": "engarupar",
    "engarupámos": "engarupar",
    "engarupáramo": "engarupar",
    "engarupáramos": "engarupar",
    "engarupárei": "engarupar",
    "engarupáreis": "engarupar",
    "engarupásseis": "engarupar",
    "engarupássemos": "engarupar",
    "engarupávamo": "engarupar",
    "engarupávamos": "engarupar",
    "engarupávei": "engarupar",
    "engarupáveis": "engarupar",
    "engará": "engar",
    "engarás": "engar",
    "engarão": "engar",
    "engaríamos": "engar",
    "engaríeis": "engar",
    "engas": "engar",
    "engasga": "engasgar",
    "engasgada": "engasgar",
    "engasgadas": "engasgar",
    "engasgado": "engasgar",
    "engasgados": "engasgar",
    "engasgai": "engasgar",
    "engasgais": "engasgar",
    "engasgalha": "engasgalhar",
    "engasgalhada": "engasgalhar",
    "engasgalhadas": "engasgalhar",
    "engasgalhado": "engasgalhar",
    "engasgalhados": "engasgalhar",
    "engasgalhai": "engasgalhar",
    "engasgalhais": "engasgalhar",
    "engasgalham": "engasgalhar",
    "engasgalhamo": "engasgalhar",
    "engasgalhamos": "engasgalhar",
    "engasgalhando": "engasgalhar",
    "engasgalhara": "engasgalhar",
    "engasgalharam": "engasgalhar",
    "engasgalharas": "engasgalhar",
    "engasgalharde": "engasgalhar",
    "engasgalhardes": "engasgalhar",
    "engasgalhare": "engasgalhar",
    "engasgalharei": "engasgalhar",
    "engasgalhareis": "engasgalhar",
    "engasgalharem": "engasgalhar",
    "engasgalharemos": "engasgalhar",
    "engasgalhares": "engasgalhar",
    "engasgalharia": "engasgalhar",
    "engasgalhariam": "engasgalhar",
    "engasgalharias": "engasgalhar",
    "engasgalharmo": "engasgalhar",
    "engasgalharmos": "engasgalhar",
    "engasgalhará": "engasgalhar",
    "engasgalharás": "engasgalhar",
    "engasgalharão": "engasgalhar",
    "engasgalharíamos": "engasgalhar",
    "engasgalharíeis": "engasgalhar",
    "engasgalhas": "engasgalhar",
    "engasgalhasse": "engasgalhar",
    "engasgalhassem": "engasgalhar",
    "engasgalhasses": "engasgalhar",
    "engasgalhaste": "engasgalhar",
    "engasgalhastes": "engasgalhar",
    "engasgalhava": "engasgalhar",
    "engasgalhavam": "engasgalhar",
    "engasgalhavas": "engasgalhar",
    "engasgalhe": "engasgalhar",
    "engasgalhei": "engasgalhar",
    "engasgalheis": "engasgalhar",
    "engasgalhem": "engasgalhar",
    "engasgalhemo": "engasgalhar",
    "engasgalhemos": "engasgalhar",
    "engasgalhes": "engasgalhar",
    "engasgalho": "engasgalhar",
    "engasgalhou": "engasgalhar",
    "engasgalhá": "engasgalhar",
    "engasgalhámo": "engasgalhar",
    "engasgalhámos": "engasgalhar",
    "engasgalháramo": "engasgalhar",
    "engasgalháramos": "engasgalhar",
    "engasgalhárei": "engasgalhar",
    "engasgalháreis": "engasgalhar",
    "engasgalhásseis": "engasgalhar",
    "engasgalhássemos": "engasgalhar",
    "engasgalhávamo": "engasgalhar",
    "engasgalhávamos": "engasgalhar",
    "engasgalhávei": "engasgalhar",
    "engasgalháveis": "engasgalhar",
    "engasgam": "engasgar",
    "engasgamentos": "engasgamento",
    "engasgamo": "engasgar",
    "engasgamos": "engasgar",
    "engasgando": "engasgar",
    "engasgara": "engasgar",
    "engasgaram": "engasgar",
    "engasgaras": "engasgar",
    "engasgarde": "engasgar",
    "engasgardes": "engasgar",
    "engasgare": "engasgar",
    "engasgarei": "engasgar",
    "engasgareis": "engasgar",
    "engasgarem": "engasgar",
    "engasgaremos": "engasgar",
    "engasgares": "engasgar",
    "engasgaria": "engasgar",
    "engasgariam": "engasgar",
    "engasgarias": "engasgar",
    "engasgarmo": "engasgar",
    "engasgarmos": "engasgar",
    "engasgará": "engasgar",
    "engasgarás": "engasgar",
    "engasgarão": "engasgar",
    "engasgaríamos": "engasgar",
    "engasgaríeis": "engasgar",
    "engasgas": "engasgar",
    "engasgasse": "engasgar",
    "engasgassem": "engasgar",
    "engasgasses": "engasgar",
    "engasgaste": "engasgar",
    "engasgastes": "engasgar",
    "engasgava": "engasgar",
    "engasgavam": "engasgar",
    "engasgavas": "engasgar",
    "engasgo": "engasgar",
    "engasgos": "engasgo",
    "engasgou": "engasgar",
    "engasgue": "engasgar",
    "engasguei": "engasgar",
    "engasgueis": "engasgar",
    "engasguem": "engasgar",
    "engasguemo": "engasgar",
    "engasguemos": "engasgar",
    "engasgues": "engasgue",
    "engasgá": "engasgar",
    "engasgámo": "engasgar",
    "engasgámos": "engasgar",
    "engasgáramo": "engasgar",
    "engasgáramos": "engasgar",
    "engasgárei": "engasgar",
    "engasgáreis": "engasgar",
    "engasgásseis": "engasgar",
    "engasgássemos": "engasgar",
    "engasgávamo": "engasgar",
    "engasgávamos": "engasgar",
    "engasgávei": "engasgar",
    "engasgáveis": "engasgar",
    "engasse": "engar",
    "engassem": "engar",
    "engasses": "engar",
    "engasta": "engastar",
    "engastada": "engastar",
    "engastadas": "engastar",
    "engastado": "engastar",
    "engastadora": "engastador",
    "engastadoras": "engastador",
    "engastadores": "engastador",
    "engastados": "engastar",
    "engastai": "engastar",
    "engastais": "engastar",
    "engastalha": "engastalhar",
    "engastalhada": "engastalhar",
    "engastalhadas": "engastalhar",
    "engastalhado": "engastalhar",
    "engastalhados": "engastalhar",
    "engastalhai": "engastalhar",
    "engastalhais": "engastalhar",
    "engastalham": "engastalhar",
    "engastalhamo": "engastalhar",
    "engastalhamos": "engastalhar",
    "engastalhando": "engastalhar",
    "engastalhara": "engastalhar",
    "engastalharam": "engastalhar",
    "engastalharas": "engastalhar",
    "engastalharde": "engastalhar",
    "engastalhardes": "engastalhar",
    "engastalhare": "engastalhar",
    "engastalharei": "engastalhar",
    "engastalhareis": "engastalhar",
    "engastalharem": "engastalhar",
    "engastalharemos": "engastalhar",
    "engastalhares": "engastalhar",
    "engastalharia": "engastalhar",
    "engastalhariam": "engastalhar",
    "engastalharias": "engastalhar",
    "engastalharmo": "engastalhar",
    "engastalharmos": "engastalhar",
    "engastalhará": "engastalhar",
    "engastalharás": "engastalhar",
    "engastalharão": "engastalhar",
    "engastalharíamos": "engastalhar",
    "engastalharíeis": "engastalhar",
    "engastalhas": "engastalhar",
    "engastalhasse": "engastalhar",
    "engastalhassem": "engastalhar",
    "engastalhasses": "engastalhar",
    "engastalhaste": "engastalhar",
    "engastalhastes": "engastalhar",
    "engastalhava": "engastalhar",
    "engastalhavam": "engastalhar",
    "engastalhavas": "engastalhar",
    "engastalhe": "engastalhar",
    "engastalhei": "engastalhar",
    "engastalheis": "engastalhar",
    "engastalhem": "engastalhar",
    "engastalhemo": "engastalhar",
    "engastalhemos": "engastalhar",
    "engastalhes": "engastalhar",
    "engastalho": "engastalhar",
    "engastalhou": "engastalhar",
    "engastalhá": "engastalhar",
    "engastalhámo": "engastalhar",
    "engastalhámos": "engastalhar",
    "engastalháramo": "engastalhar",
    "engastalháramos": "engastalhar",
    "engastalhárei": "engastalhar",
    "engastalháreis": "engastalhar",
    "engastalhásseis": "engastalhar",
    "engastalhássemos": "engastalhar",
    "engastalhávamo": "engastalhar",
    "engastalhávamos": "engastalhar",
    "engastalhávei": "engastalhar",
    "engastalháveis": "engastalhar",
    "engastam": "engastar",
    "engastamo": "engastar",
    "engastamos": "engastar",
    "engastando": "engastar",
    "engastara": "engastar",
    "engastaram": "engastar",
    "engastaras": "engastar",
    "engastarde": "engastar",
    "engastardes": "engastar",
    "engastare": "engastar",
    "engastarei": "engastar",
    "engastareis": "engastar",
    "engastarem": "engastar",
    "engastaremos": "engastar",
    "engastares": "engastar",
    "engastaria": "engastar",
    "engastariam": "engastar",
    "engastarias": "engastar",
    "engastarmo": "engastar",
    "engastarmos": "engastar",
    "engastará": "engastar",
    "engastarás": "engastar",
    "engastarão": "engastar",
    "engastaríamos": "engastar",
    "engastaríeis": "engastar",
    "engastas": "engastar",
    "engastasse": "engastar",
    "engastassem": "engastar",
    "engastasses": "engastar",
    "engastaste": "engastar",
    "engastastes": "engastar",
    "engastava": "engastar",
    "engastavam": "engastar",
    "engastavas": "engastar",
    "engaste": "engastar",
    "engastei": "engastar",
    "engasteis": "engastar",
    "engastem": "engastar",
    "engastemo": "engastar",
    "engastemos": "engastar",
    "engastes": "engaste",
    "engasto": "engastar",
    "engastou": "engastar",
    "engastá": "engastar",
    "engastámo": "engastar",
    "engastámos": "engastar",
    "engastáramo": "engastar",
    "engastáramos": "engastar",
    "engastárei": "engastar",
    "engastáreis": "engastar",
    "engastásseis": "engastar",
    "engastássemos": "engastar",
    "engastávamo": "engastar",
    "engastávamos": "engastar",
    "engastávei": "engastar",
    "engastáveis": "engastável",
    "engata": "engatar",
    "engatada": "engatar",
    "engatadas": "engatar",
    "engatadeiras": "engatadeira",
    "engatado": "engatar",
    "engatadora": "engatador",
    "engatadoras": "engatador",
    "engatadores": "engatador",
    "engatados": "engatar",
    "engatai": "engatar",
    "engatais": "engatar",
    "engatam": "engatar",
    "engatamentos": "engatamento",
    "engatamo": "engatar",
    "engatamos": "engatar",
    "engatando": "engatar",
    "engatara": "engatar",
    "engataram": "engatar",
    "engataras": "engatar",
    "engatarde": "engatar",
    "engatardes": "engatar",
    "engatare": "engatar",
    "engatarei": "engatar",
    "engatareis": "engatar",
    "engatarem": "engatar",
    "engataremos": "engatar",
    "engatares": "engatar",
    "engataria": "engatar",
    "engatariam": "engatar",
    "engatarias": "engatar",
    "engatarmo": "engatar",
    "engatarmos": "engatar",
    "engatará": "engatar",
    "engatarás": "engatar",
    "engatarão": "engatar",
    "engataríamos": "engatar",
    "engataríeis": "engatar",
    "engatas": "engatar",
    "engatasse": "engatar",
    "engatassem": "engatar",
    "engatasses": "engatar",
    "engataste": "engatar",
    "engatastes": "engatar",
    "engatatona": "engatatão",
    "engatatonas": "engatatão",
    "engatatões": "engatatão",
    "engatava": "engatar",
    "engatavam": "engatar",
    "engatavas": "engatar",
    "engate": "engatar",
    "engatei": "engatar",
    "engateis": "engatar",
    "engatem": "engatar",
    "engatemo": "engatar",
    "engatemos": "engatar",
    "engates": "engate",
    "engatilha": "engatilhar",
    "engatilhada": "engatilhar",
    "engatilhadas": "engatilhar",
    "engatilhado": "engatilhar",
    "engatilhados": "engatilhar",
    "engatilhai": "engatilhar",
    "engatilhais": "engatilhar",
    "engatilham": "engatilhar",
    "engatilhamo": "engatilhar",
    "engatilhamos": "engatilhar",
    "engatilhando": "engatilhar",
    "engatilhara": "engatilhar",
    "engatilharam": "engatilhar",
    "engatilharas": "engatilhar",
    "engatilharde": "engatilhar",
    "engatilhardes": "engatilhar",
    "engatilhare": "engatilhar",
    "engatilharei": "engatilhar",
    "engatilhareis": "engatilhar",
    "engatilharem": "engatilhar",
    "engatilharemos": "engatilhar",
    "engatilhares": "engatilhar",
    "engatilharia": "engatilhar",
    "engatilhariam": "engatilhar",
    "engatilharias": "engatilhar",
    "engatilharmo": "engatilhar",
    "engatilharmos": "engatilhar",
    "engatilhará": "engatilhar",
    "engatilharás": "engatilhar",
    "engatilharão": "engatilhar",
    "engatilharíamos": "engatilhar",
    "engatilharíeis": "engatilhar",
    "engatilhas": "engatilhar",
    "engatilhasse": "engatilhar",
    "engatilhassem": "engatilhar",
    "engatilhasses": "engatilhar",
    "engatilhaste": "engatilhar",
    "engatilhastes": "engatilhar",
    "engatilhava": "engatilhar",
    "engatilhavam": "engatilhar",
    "engatilhavas": "engatilhar",
    "engatilhe": "engatilhar",
    "engatilhei": "engatilhar",
    "engatilheis": "engatilhar",
    "engatilhem": "engatilhar",
    "engatilhemo": "engatilhar",
    "engatilhemos": "engatilhar",
    "engatilhes": "engatilhar",
    "engatilho": "engatilhar",
    "engatilhou": "engatilhar",
    "engatilhá": "engatilhar",
    "engatilhámo": "engatilhar",
    "engatilhámos": "engatilhar",
    "engatilháramo": "engatilhar",
    "engatilháramos": "engatilhar",
    "engatilhárei": "engatilhar",
    "engatilháreis": "engatilhar",
    "engatilhásseis": "engatilhar",
    "engatilhássemos": "engatilhar",
    "engatilhávamo": "engatilhar",
    "engatilhávamos": "engatilhar",
    "engatilhávei": "engatilhar",
    "engatilháveis": "engatilhar",
    "engatinha": "engatinhar",
    "engatinhada": "engatinhar",
    "engatinhadas": "engatinhar",
    "engatinhadeiras": "engatinhadeira",
    "engatinhado": "engatinhar",
    "engatinhados": "engatinhar",
    "engatinhai": "engatinhar",
    "engatinhais": "engatinhar",
    "engatinham": "engatinhar",
    "engatinhamo": "engatinhar",
    "engatinhamos": "engatinhar",
    "engatinhando": "engatinhar",
    "engatinhara": "engatinhar",
    "engatinharam": "engatinhar",
    "engatinharas": "engatinhar",
    "engatinharde": "engatinhar",
    "engatinhardes": "engatinhar",
    "engatinhare": "engatinhar",
    "engatinharei": "engatinhar",
    "engatinhareis": "engatinhar",
    "engatinharem": "engatinhar",
    "engatinharemos": "engatinhar",
    "engatinhares": "engatinhar",
    "engatinharia": "engatinhar",
    "engatinhariam": "engatinhar",
    "engatinharias": "engatinhar",
    "engatinharmo": "engatinhar",
    "engatinharmos": "engatinhar",
    "engatinhará": "engatinhar",
    "engatinharás": "engatinhar",
    "engatinharão": "engatinhar",
    "engatinharíamos": "engatinhar",
    "engatinharíeis": "engatinhar",
    "engatinhas": "engatinhar",
    "engatinhasse": "engatinhar",
    "engatinhassem": "engatinhar",
    "engatinhasses": "engatinhar",
    "engatinhaste": "engatinhar",
    "engatinhastes": "engatinhar",
    "engatinhava": "engatinhar",
    "engatinhavam": "engatinhar",
    "engatinhavas": "engatinhar",
    "engatinhe": "engatinhar",
    "engatinhei": "engatinhar",
    "engatinheis": "engatinhar",
    "engatinhem": "engatinhar",
    "engatinhemo": "engatinhar",
    "engatinhemos": "engatinhar",
    "engatinhes": "engatinhar",
    "engatinho": "engatinhar",
    "engatinhou": "engatinhar",
    "engatinhá": "engatinhar",
    "engatinhámo": "engatinhar",
    "engatinhámos": "engatinhar",
    "engatinháramo": "engatinhar",
    "engatinháramos": "engatinhar",
    "engatinhárei": "engatinhar",
    "engatinháreis": "engatinhar",
    "engatinhásseis": "engatinhar",
    "engatinhássemos": "engatinhar",
    "engatinhávamo": "engatinhar",
    "engatinhávamos": "engatinhar",
    "engatinhávei": "engatinhar",
    "engatinháveis": "engatinhar",
    "engato": "engatar",
    "engatou": "engatar",
    "engatá": "engatar",
    "engatámo": "engatar",
    "engatámos": "engatar",
    "engatáramo": "engatar",
    "engatáramos": "engatar",
    "engatárei": "engatar",
    "engatáreis": "engatar",
    "engatásseis": "engatar",
    "engatássemos": "engatar",
    "engatávamo": "engatar",
    "engatávamos": "engatar",
    "engatávei": "engatar",
    "engatáveis": "engatar",
    "engava": "engar",
    "engavam": "engar",
    "engavas": "engar",
    "engavela": "engavelar",
    "engavelada": "engavelar",
    "engaveladas": "engavelar",
    "engavelado": "engavelar",
    "engavelados": "engavelar",
    "engavelai": "engavelar",
    "engavelais": "engavelar",
    "engavelam": "engavelar",
    "engavelamo": "engavelar",
    "engavelamos": "engavelar",
    "engavelando": "engavelar",
    "engavelara": "engavelar",
    "engavelaram": "engavelar",
    "engavelaras": "engavelar",
    "engavelarde": "engavelar",
    "engavelardes": "engavelar",
    "engavelare": "engavelar",
    "engavelarei": "engavelar",
    "engavelareis": "engavelar",
    "engavelarem": "engavelar",
    "engavelaremos": "engavelar",
    "engavelares": "engavelar",
    "engavelaria": "engavelar",
    "engavelariam": "engavelar",
    "engavelarias": "engavelar",
    "engavelarmo": "engavelar",
    "engavelarmos": "engavelar",
    "engavelará": "engavelar",
    "engavelarás": "engavelar",
    "engavelarão": "engavelar",
    "engavelaríamos": "engavelar",
    "engavelaríeis": "engavelar",
    "engavelas": "engavelar",
    "engavelasse": "engavelar",
    "engavelassem": "engavelar",
    "engavelasses": "engavelar",
    "engavelaste": "engavelar",
    "engavelastes": "engavelar",
    "engavelava": "engavelar",
    "engavelavam": "engavelar",
    "engavelavas": "engavelar",
    "engavele": "engavelar",
    "engavelei": "engavelar",
    "engaveleis": "engavelar",
    "engavelem": "engavelar",
    "engavelemo": "engavelar",
    "engavelemos": "engavelar",
    "engaveles": "engavelar",
    "engavelo": "engavelar",
    "engavelou": "engavelar",
    "engavelá": "engavelar",
    "engavelámo": "engavelar",
    "engavelámos": "engavelar",
    "engaveláramo": "engavelar",
    "engaveláramos": "engavelar",
    "engavelárei": "engavelar",
    "engaveláreis": "engavelar",
    "engavelásseis": "engavelar",
    "engavelássemos": "engavelar",
    "engavelávamo": "engavelar",
    "engavelávamos": "engavelar",
    "engavelávei": "engavelar",
    "engaveláveis": "engavelar",
    "engaveta": "engavetar",
    "engavetada": "engavetar",
    "engavetadas": "engavetar",
    "engavetado": "engavetar",
    "engavetados": "engavetar",
    "engavetai": "engavetar",
    "engavetais": "engavetar",
    "engavetam": "engavetar",
    "engavetamentos": "engavetamento",
    "engavetamo": "engavetar",
    "engavetamos": "engavetar",
    "engavetando": "engavetar",
    "engavetara": "engavetar",
    "engavetaram": "engavetar",
    "engavetaras": "engavetar",
    "engavetarde": "engavetar",
    "engavetardes": "engavetar",
    "engavetare": "engavetar",
    "engavetarei": "engavetar",
    "engavetareis": "engavetar",
    "engavetarem": "engavetar",
    "engavetaremos": "engavetar",
    "engavetares": "engavetar",
    "engavetaria": "engavetar",
    "engavetariam": "engavetar",
    "engavetarias": "engavetar",
    "engavetarmo": "engavetar",
    "engavetarmos": "engavetar",
    "engavetará": "engavetar",
    "engavetarás": "engavetar",
    "engavetarão": "engavetar",
    "engavetaríamos": "engavetar",
    "engavetaríeis": "engavetar",
    "engavetas": "engavetar",
    "engavetasse": "engavetar",
    "engavetassem": "engavetar",
    "engavetasses": "engavetar",
    "engavetaste": "engavetar",
    "engavetastes": "engavetar",
    "engavetava": "engavetar",
    "engavetavam": "engavetar",
    "engavetavas": "engavetar",
    "engavete": "engavetar",
    "engavetei": "engavetar",
    "engaveteis": "engavetar",
    "engavetem": "engavetar",
    "engavetemo": "engavetar",
    "engavetemos": "engavetar",
    "engavetes": "engavetar",
    "engaveto": "engavetar",
    "engavetou": "engavetar",
    "engavetá": "engavetar",
    "engavetámo": "engavetar",
    "engavetámos": "engavetar",
    "engavetáramo": "engavetar",
    "engavetáramos": "engavetar",
    "engavetárei": "engavetar",
    "engavetáreis": "engavetar",
    "engavetásseis": "engavetar",
    "engavetássemos": "engavetar",
    "engavetávamo": "engavetar",
    "engavetávamos": "engavetar",
    "engavetávei": "engavetar",
    "engavetáveis": "engavetar",
    "engavinha": "engavinhar",
    "engavinhada": "engavinhar",
    "engavinhadas": "engavinhar",
    "engavinhado": "engavinhar",
    "engavinhados": "engavinhar",
    "engavinhai": "engavinhar",
    "engavinhais": "engavinhar",
    "engavinham": "engavinhar",
    "engavinhamo": "engavinhar",
    "engavinhamos": "engavinhar",
    "engavinhando": "engavinhar",
    "engavinhara": "engavinhar",
    "engavinharam": "engavinhar",
    "engavinharas": "engavinhar",
    "engavinharde": "engavinhar",
    "engavinhardes": "engavinhar",
    "engavinhare": "engavinhar",
    "engavinharei": "engavinhar",
    "engavinhareis": "engavinhar",
    "engavinharem": "engavinhar",
    "engavinharemos": "engavinhar",
    "engavinhares": "engavinhar",
    "engavinharia": "engavinhar",
    "engavinhariam": "engavinhar",
    "engavinharias": "engavinhar",
    "engavinharmo": "engavinhar",
    "engavinharmos": "engavinhar",
    "engavinhará": "engavinhar",
    "engavinharás": "engavinhar",
    "engavinharão": "engavinhar",
    "engavinharíamos": "engavinhar",
    "engavinharíeis": "engavinhar",
    "engavinhas": "engavinhar",
    "engavinhasse": "engavinhar",
    "engavinhassem": "engavinhar",
    "engavinhasses": "engavinhar",
    "engavinhaste": "engavinhar",
    "engavinhastes": "engavinhar",
    "engavinhava": "engavinhar",
    "engavinhavam": "engavinhar",
    "engavinhavas": "engavinhar",
    "engavinhe": "engavinhar",
    "engavinhei": "engavinhar",
    "engavinheis": "engavinhar",
    "engavinhem": "engavinhar",
    "engavinhemo": "engavinhar",
    "engavinhemos": "engavinhar",
    "engavinhes": "engavinhar",
    "engavinho": "engavinhar",
    "engavinhou": "engavinhar",
    "engavinhá": "engavinhar",
    "engavinhámo": "engavinhar",
    "engavinhámos": "engavinhar",
    "engavinháramo": "engavinhar",
    "engavinháramos": "engavinhar",
    "engavinhárei": "engavinhar",
    "engavinháreis": "engavinhar",
    "engavinhásseis": "engavinhar",
    "engavinhássemos": "engavinhar",
    "engavinhávamo": "engavinhar",
    "engavinhávamos": "engavinhar",
    "engavinhávei": "engavinhar",
    "engavinháveis": "engavinhar",
    "engazofila": "engazofilar",
    "engazofilada": "engazofilar",
    "engazofiladas": "engazofilar",
    "engazofilado": "engazofilar",
    "engazofilados": "engazofilar",
    "engazofilai": "engazofilar",
    "engazofilais": "engazofilar",
    "engazofilam": "engazofilar",
    "engazofilamo": "engazofilar",
    "engazofilamos": "engazofilar",
    "engazofilando": "engazofilar",
    "engazofilara": "engazofilar",
    "engazofilaram": "engazofilar",
    "engazofilaras": "engazofilar",
    "engazofilarde": "engazofilar",
    "engazofilardes": "engazofilar",
    "engazofilare": "engazofilar",
    "engazofilarei": "engazofilar",
    "engazofilareis": "engazofilar",
    "engazofilarem": "engazofilar",
    "engazofilaremos": "engazofilar",
    "engazofilares": "engazofilar",
    "engazofilaria": "engazofilar",
    "engazofilariam": "engazofilar",
    "engazofilarias": "engazofilar",
    "engazofilarmo": "engazofilar",
    "engazofilarmos": "engazofilar",
    "engazofilará": "engazofilar",
    "engazofilarás": "engazofilar",
    "engazofilarão": "engazofilar",
    "engazofilaríamos": "engazofilar",
    "engazofilaríeis": "engazofilar",
    "engazofilas": "engazofilar",
    "engazofilasse": "engazofilar",
    "engazofilassem": "engazofilar",
    "engazofilasses": "engazofilar",
    "engazofilaste": "engazofilar",
    "engazofilastes": "engazofilar",
    "engazofilava": "engazofilar",
    "engazofilavam": "engazofilar",
    "engazofilavas": "engazofilar",
    "engazofile": "engazofilar",
    "engazofilei": "engazofilar",
    "engazofileis": "engazofilar",
    "engazofilem": "engazofilar",
    "engazofilemo": "engazofilar",
    "engazofilemos": "engazofilar",
    "engazofiles": "engazofilar",
    "engazofilo": "engazofilar",
    "engazofilou": "engazofilar",
    "engazofilá": "engazofilar",
    "engazofilámo": "engazofilar",
    "engazofilámos": "engazofilar",
    "engazofiláramo": "engazofilar",
    "engazofiláramos": "engazofilar",
    "engazofilárei": "engazofilar",
    "engazofiláreis": "engazofilar",
    "engazofilásseis": "engazofilar",
    "engazofilássemos": "engazofilar",
    "engazofilávamo": "engazofilar",
    "engazofilávamos": "engazofilar",
    "engazofilávei": "engazofilar",
    "engazofiláveis": "engazofilar",
    "engazopa": "engazopar",
    "engazopada": "engazopar",
    "engazopadas": "engazopar",
    "engazopado": "engazopar",
    "engazopadora": "engazopador",
    "engazopadoras": "engazopador",
    "engazopadores": "engazopador",
    "engazopados": "engazopar",
    "engazopai": "engazopar",
    "engazopais": "engazopar",
    "engazopam": "engazopar",
    "engazopamentos": "engazopamento",
    "engazopamo": "engazopar",
    "engazopamos": "engazopar",
    "engazopando": "engazopar",
    "engazopara": "engazopar",
    "engazoparam": "engazopar",
    "engazoparas": "engazopar",
    "engazoparde": "engazopar",
    "engazopardes": "engazopar",
    "engazopare": "engazopar",
    "engazoparei": "engazopar",
    "engazopareis": "engazopar",
    "engazoparem": "engazopar",
    "engazoparemos": "engazopar",
    "engazopares": "engazopar",
    "engazoparia": "engazopar",
    "engazopariam": "engazopar",
    "engazoparias": "engazopar",
    "engazoparmo": "engazopar",
    "engazoparmos": "engazopar",
    "engazopará": "engazopar",
    "engazoparás": "engazopar",
    "engazoparão": "engazopar",
    "engazoparíamos": "engazopar",
    "engazoparíeis": "engazopar",
    "engazopas": "engazopar",
    "engazopasse": "engazopar",
    "engazopassem": "engazopar",
    "engazopasses": "engazopar",
    "engazopaste": "engazopar",
    "engazopastes": "engazopar",
    "engazopava": "engazopar",
    "engazopavam": "engazopar",
    "engazopavas": "engazopar",
    "engazope": "engazopar",
    "engazopei": "engazopar",
    "engazopeis": "engazopar",
    "engazopem": "engazopar",
    "engazopemo": "engazopar",
    "engazopemos": "engazopar",
    "engazopes": "engazopar",
    "engazopo": "engazopar",
    "engazopou": "engazopar",
    "engazopá": "engazopar",
    "engazopámo": "engazopar",
    "engazopámos": "engazopar",
    "engazopáramo": "engazopar",
    "engazopáramos": "engazopar",
    "engazopárei": "engazopar",
    "engazopáreis": "engazopar",
    "engazopásseis": "engazopar",
    "engazopássemos": "engazopar",
    "engazopávamo": "engazopar",
    "engazopávamos": "engazopar",
    "engazopávei": "engazopar",
    "engazopáveis": "engazopar",
    "engazupada": "engazupado",
    "engazupadas": "engazupado",
    "engazupadora": "engazupador",
    "engazupadoras": "engazupador",
    "engazupadores": "engazupador",
    "engazupados": "engazupado",
    "engazupamentos": "engazupamento",
    "engaça": "engaçar",
    "engaçada": "engaçar",
    "engaçadas": "engaçar",
    "engaçado": "engaçar",
    "engaçados": "engaçar",
    "engaçai": "engaçar",
    "engaçais": "engaçar",
    "engaçam": "engaçar",
    "engaçamo": "engaçar",
    "engaçamos": "engaçar",
    "engaçando": "engaçar",
    "engaçara": "engaçar",
    "engaçaram": "engaçar",
    "engaçaras": "engaçar",
    "engaçarde": "engaçar",
    "engaçardes": "engaçar",
    "engaçare": "engaçar",
    "engaçarei": "engaçar",
    "engaçareis": "engaçar",
    "engaçarem": "engaçar",
    "engaçaremos": "engaçar",
    "engaçares": "engaçar",
    "engaçaria": "engaçar",
    "engaçariam": "engaçar",
    "engaçarias": "engaçar",
    "engaçarmo": "engaçar",
    "engaçarmos": "engaçar",
    "engaçará": "engaçar",
    "engaçarás": "engaçar",
    "engaçarão": "engaçar",
    "engaçaríamos": "engaçar",
    "engaçaríeis": "engaçar",
    "engaças": "engaçar",
    "engaçasse": "engaçar",
    "engaçassem": "engaçar",
    "engaçasses": "engaçar",
    "engaçaste": "engaçar",
    "engaçastes": "engaçar",
    "engaçava": "engaçar",
    "engaçavam": "engaçar",
    "engaçavas": "engaçar",
    "engaço": "engaçar",
    "engaços": "engaço",
    "engaçou": "engaçar",
    "engaçá": "engaçar",
    "engaçámo": "engaçar",
    "engaçámos": "engaçar",
    "engaçáramo": "engaçar",
    "engaçáramos": "engaçar",
    "engaçárei": "engaçar",
    "engaçáreis": "engaçar",
    "engaçásseis": "engaçar",
    "engaçássemos": "engaçar",
    "engaçávamo": "engaçar",
    "engaçávamos": "engaçar",
    "engaçávei": "engaçar",
    "engaçáveis": "engaçar",
    "engelha": "engelhar",
    "engelhada": "engelhar",
    "engelhadas": "engelhar",
    "engelhado": "engelhar",
    "engelhados": "engelhar",
    "engelhai": "engelhar",
    "engelhais": "engelhar",
    "engelham": "engelhar",
    "engelhamentos": "engelhamento",
    "engelhamo": "engelhar",
    "engelhamos": "engelhar",
    "engelhando": "engelhar",
    "engelhara": "engelhar",
    "engelharam": "engelhar",
    "engelharas": "engelhar",
    "engelharde": "engelhar",
    "engelhardes": "engelhar",
    "engelhare": "engelhar",
    "engelharei": "engelhar",
    "engelhareis": "engelhar",
    "engelharem": "engelhar",
    "engelharemos": "engelhar",
    "engelhares": "engelhar",
    "engelharia": "engelhar",
    "engelhariam": "engelhar",
    "engelharias": "engelhar",
    "engelharmo": "engelhar",
    "engelharmos": "engelhar",
    "engelhará": "engelhar",
    "engelharás": "engelhar",
    "engelharão": "engelhar",
    "engelharíamos": "engelhar",
    "engelharíeis": "engelhar",
    "engelhas": "engelhar",
    "engelhasse": "engelhar",
    "engelhassem": "engelhar",
    "engelhasses": "engelhar",
    "engelhaste": "engelhar",
    "engelhastes": "engelhar",
    "engelhava": "engelhar",
    "engelhavam": "engelhar",
    "engelhavas": "engelhar",
    "engelhe": "engelhar",
    "engelhei": "engelhar",
    "engelheis": "engelhar",
    "engelhem": "engelhar",
    "engelhemo": "engelhar",
    "engelhemos": "engelhar",
    "engelhes": "engelhar",
    "engelho": "engelhar",
    "engelhou": "engelhar",
    "engelhá": "engelhar",
    "engelhámo": "engelhar",
    "engelhámos": "engelhar",
    "engelháramo": "engelhar",
    "engelháramos": "engelhar",
    "engelhárei": "engelhar",
    "engelháreis": "engelhar",
    "engelhásseis": "engelhar",
    "engelhássemos": "engelhar",
    "engelhávamo": "engelhar",
    "engelhávamos": "engelhar",
    "engelhávei": "engelhar",
    "engelháveis": "engelhar",
    "engendra": "engendrar",
    "engendrada": "engendrar",
    "engendradas": "engendrar",
    "engendrado": "engendrar",
    "engendrados": "engendrar",
    "engendrai": "engendrar",
    "engendrais": "engendrar",
    "engendram": "engendrar",
    "engendramentos": "engendramento",
    "engendramo": "engendrar",
    "engendramos": "engendrar",
    "engendrando": "engendrar",
    "engendrara": "engendrar",
    "engendraram": "engendrar",
    "engendraras": "engendrar",
    "engendrarde": "engendrar",
    "engendrardes": "engendrar",
    "engendrare": "engendrar",
    "engendrarei": "engendrar",
    "engendrareis": "engendrar",
    "engendrarem": "engendrar",
    "engendraremos": "engendrar",
    "engendrares": "engendrar",
    "engendraria": "engendrar",
    "engendrariam": "engendrar",
    "engendrarias": "engendrar",
    "engendrarmo": "engendrar",
    "engendrarmos": "engendrar",
    "engendrará": "engendrar",
    "engendrarás": "engendrar",
    "engendrarão": "engendrar",
    "engendraríamos": "engendrar",
    "engendraríeis": "engendrar",
    "engendras": "engendrar",
    "engendrasse": "engendrar",
    "engendrassem": "engendrar",
    "engendrasses": "engendrar",
    "engendraste": "engendrar",
    "engendrastes": "engendrar",
    "engendrava": "engendrar",
    "engendravam": "engendrar",
    "engendravas": "engendrar",
    "engendrações": "engendração",
    "engendre": "engendrar",
    "engendrei": "engendrar",
    "engendreis": "engendrar",
    "engendrem": "engendrar",
    "engendremo": "engendrar",
    "engendremos": "engendrar",
    "engendres": "engendrar",
    "engendro": "engendrar",
    "engendrou": "engendrar",
    "engendrá": "engendrar",
    "engendrámo": "engendrar",
    "engendrámos": "engendrar",
    "engendráramo": "engendrar",
    "engendráramos": "engendrar",
    "engendrárei": "engendrar",
    "engendráreis": "engendrar",
    "engendrásseis": "engendrar",
    "engendrássemos": "engendrar",
    "engendrávamo": "engendrar",
    "engendrávamos": "engendrar",
    "engendrávei": "engendrar",
    "engendráveis": "engendrar",
    "engenha": "engenhar",
    "engenhada": "engenhar",
    "engenhadas": "engenhar",
    "engenhado": "engenhar",
    "engenhados": "engenhar",
    "engenhai": "engenhar",
    "engenhais": "engenhar",
    "engenham": "engenhar",
    "engenhamo": "engenhar",
    "engenhamos": "engenhar",
    "engenhando": "engenhar",
    "engenhara": "engenhar",
    "engenharam": "engenhar",
    "engenharas": "engenhar",
    "engenharde": "engenhar",
    "engenhardes": "engenhar",
    "engenhare": "engenhar",
    "engenharei": "engenhar",
    "engenhareis": "engenhar",
    "engenharem": "engenhar",
    "engenharemos": "engenhar",
    "engenhares": "engenhar",
    "engenharia": "engenhar",
    "engenhariam": "engenhar",
    "engenharias": "engenharia",
    "engenharmo": "engenhar",
    "engenharmos": "engenhar",
    "engenhará": "engenhar",
    "engenharás": "engenhar",
    "engenharão": "engenhar",
    "engenharíamos": "engenhar",
    "engenharíeis": "engenhar",
    "engenhas": "engenhar",
    "engenhasse": "engenhar",
    "engenhassem": "engenhar",
    "engenhasses": "engenhar",
    "engenhaste": "engenhar",
    "engenhastes": "engenhar",
    "engenhava": "engenhar",
    "engenhavam": "engenhar",
    "engenhavas": "engenhar",
    "engenhe": "engenhar",
    "engenhei": "engenhar",
    "engenheira": "engenheiro",
    "engenheiras": "engenheiro",
    "engenheirazinha": "engenheiro",
    "engenheirazinhas": "engenheiro",
    "engenheirazita": "engenheiro",
    "engenheirazitas": "engenheiro",
    "engenheiros": "engenheiro",
    "engenheirozinho": "engenheiro",
    "engenheirozinhos": "engenheiro",
    "engenheirozito": "engenheiro",
    "engenheirozitos": "engenheiro",
    "engenheis": "engenhar",
    "engenhem": "engenhar",
    "engenhemo": "engenhar",
    "engenhemos": "engenhar",
    "engenhes": "engenhar",
    "engenho": "engenhar",
    "engenhocas": "engenhoca",
    "engenhoqueira": "engenhoqueiro",
    "engenhoqueiras": "engenhoqueiro",
    "engenhoqueiros": "engenhoqueiro",
    "engenhos": "engenho",
    "engenhosa": "engenhoso",
    "engenhosas": "engenhoso",
    "engenhosidades": "engenhosidade",
    "engenhosos": "engenhoso",
    "engenhou": "engenhar",
    "engenhá": "engenhar",
    "engenhámo": "engenhar",
    "engenhámos": "engenhar",
    "engenháramo": "engenhar",
    "engenháramos": "engenhar",
    "engenhárei": "engenhar",
    "engenháreis": "engenhar",
    "engenhásseis": "engenhar",
    "engenhássemos": "engenhar",
    "engenhávamo": "engenhar",
    "engenhávamos": "engenhar",
    "engenhávei": "engenhar",
    "engenháveis": "engenhar",
    "engessa": "engessar",
    "engessada": "engessar",
    "engessadas": "engessar",
    "engessado": "engessar",
    "engessadora": "engessador",
    "engessadoras": "engessador",
    "engessadores": "engessador",
    "engessados": "engessar",
    "engessaduras": "engessadura",
    "engessai": "engessar",
    "engessais": "engessar",
    "engessam": "engessar",
    "engessamentos": "engessamento",
    "engessamo": "engessar",
    "engessamos": "engessar",
    "engessando": "engessar",
    "engessara": "engessar",
    "engessaram": "engessar",
    "engessaras": "engessar",
    "engessarde": "engessar",
    "engessardes": "engessar",
    "engessare": "engessar",
    "engessarei": "engessar",
    "engessareis": "engessar",
    "engessarem": "engessar",
    "engessaremos": "engessar",
    "engessares": "engessar",
    "engessaria": "engessar",
    "engessariam": "engessar",
    "engessarias": "engessar",
    "engessarmo": "engessar",
    "engessarmos": "engessar",
    "engessará": "engessar",
    "engessarás": "engessar",
    "engessarão": "engessar",
    "engessaríamos": "engessar",
    "engessaríeis": "engessar",
    "engessas": "engessar",
    "engessasse": "engessar",
    "engessassem": "engessar",
    "engessasses": "engessar",
    "engessaste": "engessar",
    "engessastes": "engessar",
    "engessava": "engessar",
    "engessavam": "engessar",
    "engessavas": "engessar",
    "engesse": "engessar",
    "engessei": "engessar",
    "engesseis": "engessar",
    "engessem": "engessar",
    "engessemo": "engessar",
    "engessemos": "engessar",
    "engesses": "engessar",
    "engesso": "engessar",
    "engessou": "engessar",
    "engessá": "engessar",
    "engessámo": "engessar",
    "engessámos": "engessar",
    "engessáramo": "engessar",
    "engessáramos": "engessar",
    "engessárei": "engessar",
    "engessáreis": "engessar",
    "engessásseis": "engessar",
    "engessássemos": "engessar",
    "engessávamo": "engessar",
    "engessávamos": "engessar",
    "engessávei": "engessar",
    "engessáveis": "engessar",
    "engiga": "engigar",
    "engigada": "engigar",
    "engigadas": "engigar",
    "engigado": "engigar",
    "engigados": "engigar",
    "engigai": "engigar",
    "engigais": "engigar",
    "engigam": "engigar",
    "engigamo": "engigar",
    "engigamos": "engigar",
    "engigando": "engigar",
    "engigara": "engigar",
    "engigaram": "engigar",
    "engigaras": "engigar",
    "engigarde": "engigar",
    "engigardes": "engigar",
    "engigare": "engigar",
    "engigarei": "engigar",
    "engigareis": "engigar",
    "engigarem": "engigar",
    "engigaremos": "engigar",
    "engigares": "engigar",
    "engigaria": "engigar",
    "engigariam": "engigar",
    "engigarias": "engigar",
    "engigarmo": "engigar",
    "engigarmos": "engigar",
    "engigará": "engigar",
    "engigarás": "engigar",
    "engigarão": "engigar",
    "engigaríamos": "engigar",
    "engigaríeis": "engigar",
    "engigas": "engigar",
    "engigasse": "engigar",
    "engigassem": "engigar",
    "engigasses": "engigar",
    "engigaste": "engigar",
    "engigastes": "engigar",
    "engigava": "engigar",
    "engigavam": "engigar",
    "engigavas": "engigar",
    "engigo": "engigar",
    "engigou": "engigar",
    "engigue": "engigar",
    "engiguei": "engigar",
    "engigueis": "engigar",
    "engiguem": "engigar",
    "engiguemo": "engigar",
    "engiguemos": "engigar",
    "engigues": "engigar",
    "engigá": "engigar",
    "engigámo": "engigar",
    "engigámos": "engigar",
    "engigáramo": "engigar",
    "engigáramos": "engigar",
    "engigárei": "engigar",
    "engigáreis": "engigar",
    "engigásseis": "engigar",
    "engigássemos": "engigar",
    "engigávamo": "engigar",
    "engigávamos": "engigar",
    "engigávei": "engigar",
    "engigáveis": "engigar",
    "engivas": "engiva",
    "engloba": "englobar",
    "englobada": "englobar",
    "englobadas": "englobar",
    "englobado": "englobar",
    "englobados": "englobar",
    "englobai": "englobar",
    "englobais": "englobar",
    "englobam": "englobar",
    "englobamentos": "englobamento",
    "englobamo": "englobar",
    "englobamos": "englobar",
    "englobando": "englobar",
    "englobantes": "englobante",
    "englobara": "englobar",
    "englobaram": "englobar",
    "englobaras": "englobar",
    "englobarde": "englobar",
    "englobardes": "englobar",
    "englobare": "englobar",
    "englobarei": "englobar",
    "englobareis": "englobar",
    "englobarem": "englobar",
    "englobaremos": "englobar",
    "englobares": "englobar",
    "englobaria": "englobar",
    "englobariam": "englobar",
    "englobarias": "englobar",
    "englobarmo": "englobar",
    "englobarmos": "englobar",
    "englobará": "englobar",
    "englobarás": "englobar",
    "englobarão": "englobar",
    "englobaríamos": "englobar",
    "englobaríeis": "englobar",
    "englobas": "englobar",
    "englobasse": "englobar",
    "englobassem": "englobar",
    "englobasses": "englobar",
    "englobaste": "englobar",
    "englobastes": "englobar",
    "englobava": "englobar",
    "englobavam": "englobar",
    "englobavas": "englobar",
    "englobe": "englobar",
    "englobei": "englobar",
    "englobeis": "englobar",
    "englobem": "englobar",
    "englobemo": "englobar",
    "englobemos": "englobar",
    "englobes": "englobar",
    "englobo": "englobar",
    "englobou": "englobar",
    "englobá": "englobar",
    "englobámo": "englobar",
    "englobámos": "englobar",
    "englobáramo": "englobar",
    "englobáramos": "englobar",
    "englobárei": "englobar",
    "englobáreis": "englobar",
    "englobásseis": "englobar",
    "englobássemos": "englobar",
    "englobávamo": "englobar",
    "englobávamos": "englobar",
    "englobávei": "englobar",
    "englobáveis": "englobar",
    "engo": "engar",
    "engobos": "engobo",
    "engoda": "engodar",
    "engodada": "engodar",
    "engodadas": "engodar",
    "engodado": "engodar",
    "engodadora": "engodador",
    "engodadoras": "engodador",
    "engodadores": "engodador",
    "engodados": "engodar",
    "engodai": "engodar",
    "engodais": "engodar",
    "engodam": "engodar",
    "engodamentos": "engodamento",
    "engodamo": "engodar",
    "engodamos": "engodar",
    "engodando": "engodar",
    "engodara": "engodar",
    "engodaram": "engodar",
    "engodaras": "engodar",
    "engodarde": "engodar",
    "engodardes": "engodar",
    "engodare": "engodar",
    "engodarei": "engodar",
    "engodareis": "engodar",
    "engodarem": "engodar",
    "engodaremos": "engodar",
    "engodares": "engodar",
    "engodaria": "engodar",
    "engodariam": "engodar",
    "engodarias": "engodar",
    "engodarmo": "engodar",
    "engodarmos": "engodar",
    "engodará": "engodar",
    "engodarás": "engodar",
    "engodarão": "engodar",
    "engodaríamos": "engodar",
    "engodaríeis": "engodar",
    "engodas": "engodar",
    "engodasse": "engodar",
    "engodassem": "engodar",
    "engodasses": "engodar",
    "engodaste": "engodar",
    "engodastes": "engodar",
    "engodativa": "engodativo",
    "engodativas": "engodativo",
    "engodativos": "engodativo",
    "engodava": "engodar",
    "engodavam": "engodar",
    "engodavas": "engodar",
    "engode": "engodar",
    "engodei": "engodar",
    "engodeis": "engodar",
    "engodem": "engodar",
    "engodemo": "engodar",
    "engodemos": "engodar",
    "engodes": "engodar",
    "engodilha": "engodilhar",
    "engodilhada": "engodilhar",
    "engodilhadas": "engodilhar",
    "engodilhado": "engodilhar",
    "engodilhados": "engodilhar",
    "engodilhai": "engodilhar",
    "engodilhais": "engodilhar",
    "engodilham": "engodilhar",
    "engodilhamo": "engodilhar",
    "engodilhamos": "engodilhar",
    "engodilhando": "engodilhar",
    "engodilhara": "engodilhar",
    "engodilharam": "engodilhar",
    "engodilharas": "engodilhar",
    "engodilharde": "engodilhar",
    "engodilhardes": "engodilhar",
    "engodilhare": "engodilhar",
    "engodilharei": "engodilhar",
    "engodilhareis": "engodilhar",
    "engodilharem": "engodilhar",
    "engodilharemos": "engodilhar",
    "engodilhares": "engodilhar",
    "engodilharia": "engodilhar",
    "engodilhariam": "engodilhar",
    "engodilharias": "engodilhar",
    "engodilharmo": "engodilhar",
    "engodilharmos": "engodilhar",
    "engodilhará": "engodilhar",
    "engodilharás": "engodilhar",
    "engodilharão": "engodilhar",
    "engodilharíamos": "engodilhar",
    "engodilharíeis": "engodilhar",
    "engodilhas": "engodilhar",
    "engodilhasse": "engodilhar",
    "engodilhassem": "engodilhar",
    "engodilhasses": "engodilhar",
    "engodilhaste": "engodilhar",
    "engodilhastes": "engodilhar",
    "engodilhava": "engodilhar",
    "engodilhavam": "engodilhar",
    "engodilhavas": "engodilhar",
    "engodilhe": "engodilhar",
    "engodilhei": "engodilhar",
    "engodilheis": "engodilhar",
    "engodilhem": "engodilhar",
    "engodilhemo": "engodilhar",
    "engodilhemos": "engodilhar",
    "engodilhes": "engodilhar",
    "engodilho": "engodilhar",
    "engodilhou": "engodilhar",
    "engodilhá": "engodilhar",
    "engodilhámo": "engodilhar",
    "engodilhámos": "engodilhar",
    "engodilháramo": "engodilhar",
    "engodilháramos": "engodilhar",
    "engodilhárei": "engodilhar",
    "engodilháreis": "engodilhar",
    "engodilhásseis": "engodilhar",
    "engodilhássemos": "engodilhar",
    "engodilhávamo": "engodilhar",
    "engodilhávamos": "engodilhar",
    "engodilhávei": "engodilhar",
    "engodilháveis": "engodilhar",
    "engodo": "engodar",
    "engodos": "engodo",
    "engodou": "engodar",
    "engodá": "engodar",
    "engodámo": "engodar",
    "engodámos": "engodar",
    "engodáramo": "engodar",
    "engodáramos": "engodar",
    "engodárei": "engodar",
    "engodáreis": "engodar",
    "engodásseis": "engodar",
    "engodássemos": "engodar",
    "engodávamo": "engodar",
    "engodávamos": "engodar",
    "engodávei": "engodar",
    "engodáveis": "engodar",
    "engoia": "engoiar",
    "engoiada": "engoiar",
    "engoiadas": "engoiar",
    "engoiado": "engoiar",
    "engoiados": "engoiar",
    "engoiai": "engoiar",
    "engoiais": "engoiar",
    "engoiam": "engoiar",
    "engoiamo": "engoiar",
    "engoiamos": "engoiar",
    "engoiando": "engoiar",
    "engoiara": "engoiar",
    "engoiaram": "engoiar",
    "engoiaras": "engoiar",
    "engoiarde": "engoiar",
    "engoiardes": "engoiar",
    "engoiare": "engoiar",
    "engoiarei": "engoiar",
    "engoiareis": "engoiar",
    "engoiarem": "engoiar",
    "engoiaremos": "engoiar",
    "engoiares": "engoiar",
    "engoiaria": "engoiar",
    "engoiariam": "engoiar",
    "engoiarias": "engoiar",
    "engoiarmo": "engoiar",
    "engoiarmos": "engoiar",
    "engoiará": "engoiar",
    "engoiarás": "engoiar",
    "engoiarão": "engoiar",
    "engoiaríamos": "engoiar",
    "engoiaríeis": "engoiar",
    "engoias": "engoiar",
    "engoiasse": "engoiar",
    "engoiassem": "engoiar",
    "engoiasses": "engoiar",
    "engoiaste": "engoiar",
    "engoiastes": "engoiar",
    "engoiava": "engoiar",
    "engoiavam": "engoiar",
    "engoiavas": "engoiar",
    "engoie": "engoiar",
    "engoiei": "engoiar",
    "engoieis": "engoiar",
    "engoiem": "engoiar",
    "engoiemo": "engoiar",
    "engoiemos": "engoiar",
    "engoies": "engoiar",
    "engoio": "engoiar",
    "engoiou": "engoiar",
    "engoiá": "engoiar",
    "engoiámo": "engoiar",
    "engoiámos": "engoiar",
    "engoiáramo": "engoiar",
    "engoiáramos": "engoiar",
    "engoiárei": "engoiar",
    "engoiáreis": "engoiar",
    "engoiásseis": "engoiar",
    "engoiássemos": "engoiar",
    "engoiávamo": "engoiar",
    "engoiávamos": "engoiar",
    "engoiávei": "engoiar",
    "engoiáveis": "engoiar",
    "engole": "engolir",
    "engolem": "engolir",
    "engoles": "engolir",
    "engolfa": "engolfar",
    "engolfada": "engolfar",
    "engolfadas": "engolfar",
    "engolfado": "engolfar",
    "engolfados": "engolfar",
    "engolfai": "engolfar",
    "engolfais": "engolfar",
    "engolfam": "engolfar",
    "engolfamo": "engolfar",
    "engolfamos": "engolfar",
    "engolfando": "engolfar",
    "engolfara": "engolfar",
    "engolfaram": "engolfar",
    "engolfaras": "engolfar",
    "engolfarde": "engolfar",
    "engolfardes": "engolfar",
    "engolfare": "engolfar",
    "engolfarei": "engolfar",
    "engolfareis": "engolfar",
    "engolfarem": "engolfar",
    "engolfaremos": "engolfar",
    "engolfares": "engolfar",
    "engolfaria": "engolfar",
    "engolfariam": "engolfar",
    "engolfarias": "engolfar",
    "engolfarmo": "engolfar",
    "engolfarmos": "engolfar",
    "engolfará": "engolfar",
    "engolfarás": "engolfar",
    "engolfarão": "engolfar",
    "engolfaríamos": "engolfar",
    "engolfaríeis": "engolfar",
    "engolfas": "engolfar",
    "engolfasse": "engolfar",
    "engolfassem": "engolfar",
    "engolfasses": "engolfar",
    "engolfaste": "engolfar",
    "engolfastes": "engolfar",
    "engolfava": "engolfar",
    "engolfavam": "engolfar",
    "engolfavas": "engolfar",
    "engolfe": "engolfar",
    "engolfei": "engolfar",
    "engolfeis": "engolfar",
    "engolfem": "engolfar",
    "engolfemo": "engolfar",
    "engolfemos": "engolfar",
    "engolfes": "engolfar",
    "engolfo": "engolfar",
    "engolfou": "engolfar",
    "engolfá": "engolfar",
    "engolfámo": "engolfar",
    "engolfámos": "engolfar",
    "engolfáramo": "engolfar",
    "engolfáramos": "engolfar",
    "engolfárei": "engolfar",
    "engolfáreis": "engolfar",
    "engolfásseis": "engolfar",
    "engolfássemos": "engolfar",
    "engolfávamo": "engolfar",
    "engolfávamos": "engolfar",
    "engolfávei": "engolfar",
    "engolfáveis": "engolfar",
    "engoli": "engolir",
    "engolia": "engolir",
    "engoliam": "engolir",
    "engolias": "engolir",
    "engolida": "engolir",
    "engolidas": "engolir",
    "engolido": "engolir",
    "engolidora": "engolidor",
    "engolidoras": "engolidor",
    "engolidores": "engolidor",
    "engolidos": "engolir",
    "engolimo": "engolir",
    "engolimos": "engolir",
    "engolindo": "engolir",
    "engolira": "engolir",
    "engoliram": "engolir",
    "engoliras": "engolir",
    "engolirde": "engolir",
    "engolirdes": "engolir",
    "engolire": "engolir",
    "engolirei": "engolir",
    "engolireis": "engolir",
    "engolirem": "engolir",
    "engoliremos": "engolir",
    "engolires": "engolir",
    "engoliria": "engolir",
    "engoliriam": "engolir",
    "engolirias": "engolir",
    "engolirmo": "engolir",
    "engolirmos": "engolir",
    "engolirá": "engolir",
    "engolirás": "engolir",
    "engolirão": "engolir",
    "engoliríamos": "engolir",
    "engoliríeis": "engolir",
    "engolis": "engolir",
    "engolisse": "engolir",
    "engolissem": "engolir",
    "engolisses": "engolir",
    "engoliste": "engolir",
    "engolistes": "engolir",
    "engoliu": "engolir",
    "engolições": "engolição",
    "engolíamo": "engolir",
    "engolíamos": "engolir",
    "engolíei": "engolir",
    "engolíeis": "engolir",
    "engolíramo": "engolir",
    "engolíramos": "engolir",
    "engolírei": "engolir",
    "engolíreis": "engolir",
    "engolísseis": "engolir",
    "engolíssemos": "engolir",
    "engolíveis": "engolível",
    "engoma": "engomar",
    "engomada": "engomar",
    "engomadas": "engomar",
    "engomadeira": "engomadeiro",
    "engomadeiras": "engomadeiro",
    "engomadeiros": "engomadeiro",
    "engomadelas": "engomadela",
    "engomado": "engomar",
    "engomadorias": "engomadoria",
    "engomados": "engomar",
    "engomadíssima": "engomado",
    "engomadíssimas": "engomado",
    "engomadíssimo": "engomado",
    "engomadíssimos": "engomado",
    "engomagens": "engomagem",
    "engomai": "engomar",
    "engomais": "engomar",
    "engomam": "engomar",
    "engomamo": "engomar",
    "engomamos": "engomar",
    "engomando": "engomar",
    "engomara": "engomar",
    "engomaram": "engomar",
    "engomaras": "engomar",
    "engomarde": "engomar",
    "engomardes": "engomar",
    "engomare": "engomar",
    "engomarei": "engomar",
    "engomareis": "engomar",
    "engomarem": "engomar",
    "engomaremos": "engomar",
    "engomares": "engomar",
    "engomaria": "engomar",
    "engomariam": "engomar",
    "engomarias": "engomar",
    "engomarmo": "engomar",
    "engomarmos": "engomar",
    "engomará": "engomar",
    "engomarás": "engomar",
    "engomarão": "engomar",
    "engomaríamos": "engomar",
    "engomaríeis": "engomar",
    "engomas": "engomar",
    "engomasse": "engomar",
    "engomassem": "engomar",
    "engomasses": "engomar",
    "engomaste": "engomar",
    "engomastes": "engomar",
    "engomava": "engomar",
    "engomavam": "engomar",
    "engomavas": "engomar",
    "engome": "engomar",
    "engomei": "engomar",
    "engomeis": "engomar",
    "engomem": "engomar",
    "engomemo": "engomar",
    "engomemos": "engomar",
    "engomes": "engomar",
    "engomo": "engomar",
    "engomou": "engomar",
    "engomá": "engomar",
    "engomámo": "engomar",
    "engomámos": "engomar",
    "engomáramo": "engomar",
    "engomáramos": "engomar",
    "engomárei": "engomar",
    "engomáreis": "engomar",
    "engomásseis": "engomar",
    "engomássemos": "engomar",
    "engomávamo": "engomar",
    "engomávamos": "engomar",
    "engomávei": "engomar",
    "engomáveis": "engomar",
    "engonatões": "engonatão",
    "engonce": "engonçar",
    "engoncei": "engonçar",
    "engonceis": "engonçar",
    "engoncem": "engonçar",
    "engoncemo": "engonçar",
    "engoncemos": "engonçar",
    "engonces": "engonçar",
    "engonha": "engonhar",
    "engonhada": "engonhar",
    "engonhadas": "engonhar",
    "engonhado": "engonhar",
    "engonhados": "engonhar",
    "engonhai": "engonhar",
    "engonhais": "engonhar",
    "engonham": "engonhar",
    "engonhamo": "engonhar",
    "engonhamos": "engonhar",
    "engonhando": "engonhar",
    "engonhara": "engonhar",
    "engonharam": "engonhar",
    "engonharas": "engonhar",
    "engonharde": "engonhar",
    "engonhardes": "engonhar",
    "engonhare": "engonhar",
    "engonharei": "engonhar",
    "engonhareis": "engonhar",
    "engonharem": "engonhar",
    "engonharemos": "engonhar",
    "engonhares": "engonhar",
    "engonharia": "engonhar",
    "engonhariam": "engonhar",
    "engonharias": "engonhar",
    "engonharmo": "engonhar",
    "engonharmos": "engonhar",
    "engonhará": "engonhar",
    "engonharás": "engonhar",
    "engonharão": "engonhar",
    "engonharíamos": "engonhar",
    "engonharíeis": "engonhar",
    "engonhas": "engonhar",
    "engonhasse": "engonhar",
    "engonhassem": "engonhar",
    "engonhasses": "engonhar",
    "engonhaste": "engonhar",
    "engonhastes": "engonhar",
    "engonhava": "engonhar",
    "engonhavam": "engonhar",
    "engonhavas": "engonhar",
    "engonhe": "engonhar",
    "engonhei": "engonhar",
    "engonheis": "engonhar",
    "engonhem": "engonhar",
    "engonhemo": "engonhar",
    "engonhemos": "engonhar",
    "engonhes": "engonhar",
    "engonho": "engonhar",
    "engonhou": "engonhar",
    "engonhá": "engonhar",
    "engonhámo": "engonhar",
    "engonhámos": "engonhar",
    "engonháramo": "engonhar",
    "engonháramos": "engonhar",
    "engonhárei": "engonhar",
    "engonháreis": "engonhar",
    "engonhásseis": "engonhar",
    "engonhássemos": "engonhar",
    "engonhávamo": "engonhar",
    "engonhávamos": "engonhar",
    "engonhávei": "engonhar",
    "engonháveis": "engonhar",
    "engonça": "engonçar",
    "engonçada": "engonçar",
    "engonçadas": "engonçar",
    "engonçado": "engonçar",
    "engonçados": "engonçar",
    "engonçadíssima": "engonçado",
    "engonçadíssimas": "engonçado",
    "engonçadíssimo": "engonçado",
    "engonçadíssimos": "engonçado",
    "engonçai": "engonçar",
    "engonçais": "engonçar",
    "engonçam": "engonçar",
    "engonçamo": "engonçar",
    "engonçamos": "engonçar",
    "engonçando": "engonçar",
    "engonçara": "engonçar",
    "engonçaram": "engonçar",
    "engonçaras": "engonçar",
    "engonçarde": "engonçar",
    "engonçardes": "engonçar",
    "engonçare": "engonçar",
    "engonçarei": "engonçar",
    "engonçareis": "engonçar",
    "engonçarem": "engonçar",
    "engonçaremos": "engonçar",
    "engonçares": "engonçar",
    "engonçaria": "engonçar",
    "engonçariam": "engonçar",
    "engonçarias": "engonçar",
    "engonçarmo": "engonçar",
    "engonçarmos": "engonçar",
    "engonçará": "engonçar",
    "engonçarás": "engonçar",
    "engonçarão": "engonçar",
    "engonçaríamos": "engonçar",
    "engonçaríeis": "engonçar",
    "engonças": "engonçar",
    "engonçasse": "engonçar",
    "engonçassem": "engonçar",
    "engonçasses": "engonçar",
    "engonçaste": "engonçar",
    "engonçastes": "engonçar",
    "engonçava": "engonçar",
    "engonçavam": "engonçar",
    "engonçavas": "engonçar",
    "engonço": "engonçar",
    "engonços": "engonço",
    "engonçou": "engonçar",
    "engonçá": "engonçar",
    "engonçámo": "engonçar",
    "engonçámos": "engonçar",
    "engonçáramo": "engonçar",
    "engonçáramos": "engonçar",
    "engonçárei": "engonçar",
    "engonçáreis": "engonçar",
    "engonçásseis": "engonçar",
    "engonçássemos": "engonçar",
    "engonçávamo": "engonçar",
    "engonçávamos": "engonçar",
    "engonçávei": "engonçar",
    "engonçáveis": "engonçar",
    "engorda": "engordar",
    "engordada": "engordar",
    "engordadas": "engordar",
    "engordado": "engordar",
    "engordados": "engordar",
    "engordai": "engordar",
    "engordais": "engordar",
    "engordam": "engordar",
    "engordamo": "engordar",
    "engordamos": "engordar",
    "engordando": "engordar",
    "engordara": "engordar",
    "engordaram": "engordar",
    "engordaras": "engordar",
    "engordarde": "engordar",
    "engordardes": "engordar",
    "engordare": "engordar",
    "engordarei": "engordar",
    "engordareis": "engordar",
    "engordarem": "engordar",
    "engordaremos": "engordar",
    "engordares": "engordar",
    "engordaria": "engordar",
    "engordariam": "engordar",
    "engordarias": "engordar",
    "engordarmo": "engordar",
    "engordarmos": "engordar",
    "engordará": "engordar",
    "engordarás": "engordar",
    "engordarão": "engordar",
    "engordaríamos": "engordar",
    "engordaríeis": "engordar",
    "engordas": "engordar",
    "engordasse": "engordar",
    "engordassem": "engordar",
    "engordasses": "engordar",
    "engordaste": "engordar",
    "engordastes": "engordar",
    "engordava": "engordar",
    "engordavam": "engordar",
    "engordavas": "engordar",
    "engorde": "engordar",
    "engordei": "engordar",
    "engordeis": "engordar",
    "engordem": "engordar",
    "engordemo": "engordar",
    "engordemos": "engordar",
    "engordes": "engordar",
    "engordo": "engordar",
    "engordos": "engordo",
    "engordou": "engordar",
    "engordura": "engordurar",
    "engordurada": "engordurar",
    "engorduradas": "engordurar",
    "engordurado": "engordurar",
    "engordurados": "engordurar",
    "engordurai": "engordurar",
    "engordurais": "engordurar",
    "engorduram": "engordurar",
    "engorduramentos": "engorduramento",
    "engorduramo": "engordurar",
    "engorduramos": "engordurar",
    "engordurando": "engordurar",
    "engordurara": "engordurar",
    "engorduraram": "engordurar",
    "engorduraras": "engordurar",
    "engordurarde": "engordurar",
    "engordurardes": "engordurar",
    "engordurare": "engordurar",
    "engordurarei": "engordurar",
    "engordurareis": "engordurar",
    "engordurarem": "engordurar",
    "engorduraremos": "engordurar",
    "engordurares": "engordurar",
    "engorduraria": "engordurar",
    "engordurariam": "engordurar",
    "engordurarias": "engordurar",
    "engordurarmo": "engordurar",
    "engordurarmos": "engordurar",
    "engordurará": "engordurar",
    "engordurarás": "engordurar",
    "engordurarão": "engordurar",
    "engorduraríamos": "engordurar",
    "engorduraríeis": "engordurar",
    "engorduras": "engordurar",
    "engordurasse": "engordurar",
    "engordurassem": "engordurar",
    "engordurasses": "engordurar",
    "engorduraste": "engordurar",
    "engordurastes": "engordurar",
    "engordurava": "engordurar",
    "engorduravam": "engordurar",
    "engorduravas": "engordurar",
    "engordure": "engordurar",
    "engordurei": "engordurar",
    "engordureis": "engordurar",
    "engordurem": "engordurar",
    "engorduremo": "engordurar",
    "engorduremos": "engordurar",
    "engordures": "engordurar",
    "engorduro": "engordurar",
    "engordurou": "engordurar",
    "engordurá": "engordurar",
    "engordurámo": "engordurar",
    "engordurámos": "engordurar",
    "engorduráramo": "engordurar",
    "engorduráramos": "engordurar",
    "engordurárei": "engordurar",
    "engorduráreis": "engordurar",
    "engordurásseis": "engordurar",
    "engordurássemos": "engordurar",
    "engordurávamo": "engordurar",
    "engordurávamos": "engordurar",
    "engordurávei": "engordurar",
    "engorduráveis": "engordurar",
    "engordá": "engordar",
    "engordámo": "engordar",
    "engordámos": "engordar",
    "engordáramo": "engordar",
    "engordáramos": "engordar",
    "engordárei": "engordar",
    "engordáreis": "engordar",
    "engordásseis": "engordar",
    "engordássemos": "engordar",
    "engordávamo": "engordar",
    "engordávamos": "engordar",
    "engordávei": "engordar",
    "engordáveis": "engordar",
    "engorgida": "engorgido",
    "engorgidas": "engorgido",
    "engorgidos": "engorgido",
    "engorovinhada": "engorovinhado",
    "engorovinhadas": "engorovinhado",
    "engorovinhados": "engorovinhado",
    "engorra": "engorrar",
    "engorrada": "engorrar",
    "engorradas": "engorrar",
    "engorrado": "engorrar",
    "engorrados": "engorrar",
    "engorrai": "engorrar",
    "engorrais": "engorrar",
    "engorram": "engorrar",
    "engorramo": "engorrar",
    "engorramos": "engorrar",
    "engorrando": "engorrar",
    "engorrara": "engorrar",
    "engorraram": "engorrar",
    "engorraras": "engorrar",
    "engorrarde": "engorrar",
    "engorrardes": "engorrar",
    "engorrare": "engorrar",
    "engorrarei": "engorrar",
    "engorrareis": "engorrar",
    "engorrarem": "engorrar",
    "engorraremos": "engorrar",
    "engorrares": "engorrar",
    "engorraria": "engorrar",
    "engorrariam": "engorrar",
    "engorrarias": "engorrar",
    "engorrarmo": "engorrar",
    "engorrarmos": "engorrar",
    "engorrará": "engorrar",
    "engorrarás": "engorrar",
    "engorrarão": "engorrar",
    "engorraríamos": "engorrar",
    "engorraríeis": "engorrar",
    "engorras": "engorrar",
    "engorrasse": "engorrar",
    "engorrassem": "engorrar",
    "engorrasses": "engorrar",
    "engorraste": "engorrar",
    "engorrastes": "engorrar",
    "engorrava": "engorrar",
    "engorravam": "engorrar",
    "engorravas": "engorrar",
    "engorre": "engorrar",
    "engorrei": "engorrar",
    "engorreis": "engorrar",
    "engorrem": "engorrar",
    "engorremo": "engorrar",
    "engorremos": "engorrar",
    "engorres": "engorrar",
    "engorro": "engorrar",
    "engorrou": "engorrar",
    "engorrá": "engorrar",
    "engorrámo": "engorrar",
    "engorrámos": "engorrar",
    "engorráramo": "engorrar",
    "engorráramos": "engorrar",
    "engorrárei": "engorrar",
    "engorráreis": "engorrar",
    "engorrásseis": "engorrar",
    "engorrássemos": "engorrar",
    "engorrávamo": "engorrar",
    "engorrávamos": "engorrar",
    "engorrávei": "engorrar",
    "engorráveis": "engorrar",
    "engou": "engar",
    "engrace": "engraçar",
    "engracei": "engraçar",
    "engraceis": "engraçar",
    "engracem": "engraçar",
    "engracemo": "engraçar",
    "engracemos": "engraçar",
    "engraces": "engraçar",
    "engrada": "engradar",
    "engradada": "engradar",
    "engradadas": "engradar",
    "engradado": "engradar",
    "engradados": "engradar",
    "engradai": "engradar",
    "engradais": "engradar",
    "engradam": "engradar",
    "engradamentos": "engradamento",
    "engradamo": "engradar",
    "engradamos": "engradar",
    "engradando": "engradar",
    "engradara": "engradar",
    "engradaram": "engradar",
    "engradaras": "engradar",
    "engradarde": "engradar",
    "engradardes": "engradar",
    "engradare": "engradar",
    "engradarei": "engradar",
    "engradareis": "engradar",
    "engradarem": "engradar",
    "engradaremos": "engradar",
    "engradares": "engradar",
    "engradaria": "engradar",
    "engradariam": "engradar",
    "engradarias": "engradar",
    "engradarmo": "engradar",
    "engradarmos": "engradar",
    "engradará": "engradar",
    "engradarás": "engradar",
    "engradarão": "engradar",
    "engradaríamos": "engradar",
    "engradaríeis": "engradar",
    "engradas": "engradar",
    "engradasse": "engradar",
    "engradassem": "engradar",
    "engradasses": "engradar",
    "engradaste": "engradar",
    "engradastes": "engradar",
    "engradava": "engradar",
    "engradavam": "engradar",
    "engradavas": "engradar",
    "engrade": "engradar",
    "engradeada": "engradear",
    "engradeadas": "engradear",
    "engradeado": "engradear",
    "engradeados": "engradear",
    "engradeai": "engradear",
    "engradeais": "engradear",
    "engradeamentos": "engradeamento",
    "engradeamo": "engradear",
    "engradeamos": "engradear",
    "engradeando": "engradear",
    "engradeara": "engradear",
    "engradearam": "engradear",
    "engradearas": "engradear",
    "engradearde": "engradear",
    "engradeardes": "engradear",
    "engradeare": "engradear",
    "engradearei": "engradear",
    "engradeareis": "engradear",
    "engradearem": "engradear",
    "engradearemos": "engradear",
    "engradeares": "engradear",
    "engradearia": "engradear",
    "engradeariam": "engradear",
    "engradearias": "engradear",
    "engradearmo": "engradear",
    "engradearmos": "engradear",
    "engradeará": "engradear",
    "engradearás": "engradear",
    "engradearão": "engradear",
    "engradearíamos": "engradear",
    "engradearíeis": "engradear",
    "engradeasse": "engradear",
    "engradeassem": "engradear",
    "engradeasses": "engradear",
    "engradeaste": "engradear",
    "engradeastes": "engradear",
    "engradeava": "engradear",
    "engradeavam": "engradear",
    "engradeavas": "engradear",
    "engradece": "engradecer",
    "engradecei": "engradecer",
    "engradeceis": "engradecer",
    "engradecem": "engradecer",
    "engradecemo": "engradecer",
    "engradecemos": "engradecer",
    "engradecendo": "engradecer",
    "engradecera": "engradecer",
    "engradeceram": "engradecer",
    "engradeceras": "engradecer",
    "engradecerde": "engradecer",
    "engradecerdes": "engradecer",
    "engradecere": "engradecer",
    "engradecerei": "engradecer",
    "engradecereis": "engradecer",
    "engradecerem": "engradecer",
    "engradeceremos": "engradecer",
    "engradeceres": "engradecer",
    "engradeceria": "engradecer",
    "engradeceriam": "engradecer",
    "engradecerias": "engradecer",
    "engradecermo": "engradecer",
    "engradecermos": "engradecer",
    "engradecerá": "engradecer",
    "engradecerás": "engradecer",
    "engradecerão": "engradecer",
    "engradeceríamos": "engradecer",
    "engradeceríeis": "engradecer",
    "engradeces": "engradecer",
    "engradecesse": "engradecer",
    "engradecessem": "engradecer",
    "engradecesses": "engradecer",
    "engradeceste": "engradecer",
    "engradecestes": "engradecer",
    "engradeceu": "engradecer",
    "engradeci": "engradecer",
    "engradecia": "engradecer",
    "engradeciam": "engradecer",
    "engradecias": "engradecer",
    "engradecida": "engradecer",
    "engradecidas": "engradecer",
    "engradecido": "engradecer",
    "engradecidos": "engradecer",
    "engradecê": "engradecer",
    "engradecêramo": "engradecer",
    "engradecêramos": "engradecer",
    "engradecêrei": "engradecer",
    "engradecêreis": "engradecer",
    "engradecêsseis": "engradecer",
    "engradecêssemos": "engradecer",
    "engradecíamo": "engradecer",
    "engradecíamos": "engradecer",
    "engradecíei": "engradecer",
    "engradecíeis": "engradecer",
    "engradeei": "engradear",
    "engradeeis": "engradear",
    "engradeemo": "engradear",
    "engradeemos": "engradear",
    "engradei": "engradar",
    "engradeia": "engradear",
    "engradeiam": "engradear",
    "engradeias": "engradear",
    "engradeie": "engradear",
    "engradeiem": "engradear",
    "engradeies": "engradear",
    "engradeio": "engradear",
    "engradeis": "engradar",
    "engradem": "engradar",
    "engrademo": "engradar",
    "engrademos": "engradar",
    "engradeou": "engradear",
    "engrades": "engradar",
    "engradeá": "engradear",
    "engradeámo": "engradear",
    "engradeámos": "engradear",
    "engradeáramo": "engradear",
    "engradeáramos": "engradear",
    "engradeárei": "engradear",
    "engradeáreis": "engradear",
    "engradeásseis": "engradear",
    "engradeássemos": "engradear",
    "engradeávamo": "engradear",
    "engradeávamos": "engradear",
    "engradeávei": "engradear",
    "engradeáveis": "engradear",
    "engradeça": "engradecer",
    "engradeçais": "engradecer",
    "engradeçam": "engradecer",
    "engradeçamo": "engradecer",
    "engradeçamos": "engradecer",
    "engradeças": "engradecer",
    "engradeço": "engradecer",
    "engrado": "engradar",
    "engradou": "engradar",
    "engradá": "engradar",
    "engradámo": "engradar",
    "engradámos": "engradar",
    "engradáramo": "engradar",
    "engradáramos": "engradar",
    "engradárei": "engradar",
    "engradáreis": "engradar",
    "engradásseis": "engradar",
    "engradássemos": "engradar",
    "engradávamo": "engradar",
    "engradávamos": "engradar",
    "engradávei": "engradar",
    "engradáveis": "engradar",
    "engraece": "engraecer",
    "engraecei": "engraecer",
    "engraeceis": "engraecer",
    "engraecem": "engraecer",
    "engraecemo": "engraecer",
    "engraecemos": "engraecer",
    "engraecendo": "engraecer",
    "engraecera": "engraecer",
    "engraeceram": "engraecer",
    "engraeceras": "engraecer",
    "engraecerdes": "engraecer",
    "engraecerei": "engraecer",
    "engraecereis": "engraecer",
    "engraecerem": "engraecer",
    "engraeceremos": "engraecer",
    "engraeceres": "engraecer",
    "engraeceria": "engraecer",
    "engraeceriam": "engraecer",
    "engraecerias": "engraecer",
    "engraecermo": "engraecer",
    "engraecermos": "engraecer",
    "engraecerá": "engraecer",
    "engraecerás": "engraecer",
    "engraecerão": "engraecer",
    "engraeceríamos": "engraecer",
    "engraeceríeis": "engraecer",
    "engraeces": "engraecer",
    "engraecesse": "engraecer",
    "engraecessem": "engraecer",
    "engraecesses": "engraecer",
    "engraeceste": "engraecer",
    "engraecestes": "engraecer",
    "engraeceu": "engraecer",
    "engraeci": "engraecer",
    "engraecia": "engraecer",
    "engraeciam": "engraecer",
    "engraecias": "engraecer",
    "engraecida": "engraecer",
    "engraecidas": "engraecer",
    "engraecido": "engraecer",
    "engraecidos": "engraecer",
    "engraecêramo": "engraecer",
    "engraecêramos": "engraecer",
    "engraecêreis": "engraecer",
    "engraecêsseis": "engraecer",
    "engraecêssemos": "engraecer",
    "engraecíamo": "engraecer",
    "engraecíamos": "engraecer",
    "engraecíeis": "engraecer",
    "engraeça": "engraecer",
    "engraeçais": "engraecer",
    "engraeçam": "engraecer",
    "engraeçamo": "engraecer",
    "engraeçamos": "engraecer",
    "engraeças": "engraecer",
    "engraeço": "engraecer",
    "engramas": "engrama",
    "engrampa": "engrampar",
    "engrampada": "engrampar",
    "engrampadas": "engrampar",
    "engrampado": "engrampar",
    "engrampadora": "engrampador",
    "engrampadoras": "engrampador",
    "engrampadores": "engrampador",
    "engrampados": "engrampar",
    "engrampai": "engrampar",
    "engrampais": "engrampar",
    "engrampam": "engrampar",
    "engrampamo": "engrampar",
    "engrampamos": "engrampar",
    "engrampando": "engrampar",
    "engrampara": "engrampar",
    "engramparam": "engrampar",
    "engramparas": "engrampar",
    "engramparde": "engrampar",
    "engrampardes": "engrampar",
    "engrampare": "engrampar",
    "engramparei": "engrampar",
    "engrampareis": "engrampar",
    "engramparem": "engrampar",
    "engramparemos": "engrampar",
    "engrampares": "engrampar",
    "engramparia": "engrampar",
    "engrampariam": "engrampar",
    "engramparias": "engrampar",
    "engramparmo": "engrampar",
    "engramparmos": "engrampar",
    "engrampará": "engrampar",
    "engramparás": "engrampar",
    "engramparão": "engrampar",
    "engramparíamos": "engrampar",
    "engramparíeis": "engrampar",
    "engrampas": "engrampar",
    "engrampasse": "engrampar",
    "engrampassem": "engrampar",
    "engrampasses": "engrampar",
    "engrampaste": "engrampar",
    "engrampastes": "engrampar",
    "engrampava": "engrampar",
    "engrampavam": "engrampar",
    "engrampavas": "engrampar",
    "engrampe": "engrampar",
    "engrampei": "engrampar",
    "engrampeis": "engrampar",
    "engrampem": "engrampar",
    "engrampemo": "engrampar",
    "engrampemos": "engrampar",
    "engrampes": "engrampar",
    "engrampo": "engrampar",
    "engrampona": "engramponar",
    "engramponada": "engramponar",
    "engramponadas": "engramponar",
    "engramponado": "engramponar",
    "engramponados": "engramponar",
    "engramponai": "engramponar",
    "engramponais": "engramponar",
    "engramponam": "engramponar",
    "engramponamo": "engramponar",
    "engramponamos": "engramponar",
    "engramponando": "engramponar",
    "engramponara": "engramponar",
    "engramponaram": "engramponar",
    "engramponaras": "engramponar",
    "engramponarde": "engramponar",
    "engramponardes": "engramponar",
    "engramponare": "engramponar",
    "engramponarei": "engramponar",
    "engramponareis": "engramponar",
    "engramponarem": "engramponar",
    "engramponaremos": "engramponar",
    "engramponares": "engramponar",
    "engramponaria": "engramponar",
    "engramponariam": "engramponar",
    "engramponarias": "engramponar",
    "engramponarmo": "engramponar",
    "engramponarmos": "engramponar",
    "engramponará": "engramponar",
    "engramponarás": "engramponar",
    "engramponarão": "engramponar",
    "engramponaríamos": "engramponar",
    "engramponaríeis": "engramponar",
    "engramponas": "engramponar",
    "engramponasse": "engramponar",
    "engramponassem": "engramponar",
    "engramponasses": "engramponar",
    "engramponaste": "engramponar",
    "engramponastes": "engramponar",
    "engramponava": "engramponar",
    "engramponavam": "engramponar",
    "engramponavas": "engramponar",
    "engrampone": "engramponar",
    "engramponei": "engramponar",
    "engramponeis": "engramponar",
    "engramponem": "engramponar",
    "engramponemo": "engramponar",
    "engramponemos": "engramponar",
    "engrampones": "engramponar",
    "engrampono": "engramponar",
    "engramponou": "engramponar",
    "engramponá": "engramponar",
    "engramponámo": "engramponar",
    "engramponámos": "engramponar",
    "engramponáramo": "engramponar",
    "engramponáramos": "engramponar",
    "engramponárei": "engramponar",
    "engramponáreis": "engramponar",
    "engramponásseis": "engramponar",
    "engramponássemos": "engramponar",
    "engramponávamo": "engramponar",
    "engramponávamos": "engramponar",
    "engramponávei": "engramponar",
    "engramponáveis": "engramponar",
    "engrampou": "engrampar",
    "engrampá": "engrampar",
    "engrampámo": "engrampar",
    "engrampámos": "engrampar",
    "engrampáramo": "engrampar",
    "engrampáramos": "engrampar",
    "engrampárei": "engrampar",
    "engrampáreis": "engrampar",
    "engrampásseis": "engrampar",
    "engrampássemos": "engrampar",
    "engrampávamo": "engrampar",
    "engrampávamos": "engrampar",
    "engrampávei": "engrampar",
    "engrampáveis": "engrampar",
    "engrandece": "engrandecer",
    "engrandecedora": "engrandecedor",
    "engrandecedoras": "engrandecedor",
    "engrandecedores": "engrandecedor",
    "engrandecei": "engrandecer",
    "engrandeceis": "engrandecer",
    "engrandecem": "engrandecer",
    "engrandecemo": "engrandecer",
    "engrandecemos": "engrandecer",
    "engrandecendo": "engrandecer",
    "engrandecera": "engrandecer",
    "engrandeceram": "engrandecer",
    "engrandeceras": "engrandecer",
    "engrandecerdes": "engrandecer",
    "engrandecerei": "engrandecer",
    "engrandecereis": "engrandecer",
    "engrandecerem": "engrandecer",
    "engrandeceremos": "engrandecer",
    "engrandeceres": "engrandecer",
    "engrandeceria": "engrandecer",
    "engrandeceriam": "engrandecer",
    "engrandecerias": "engrandecer",
    "engrandecermo": "engrandecer",
    "engrandecermos": "engrandecer",
    "engrandecerá": "engrandecer",
    "engrandecerás": "engrandecer",
    "engrandecerão": "engrandecer",
    "engrandeceríamos": "engrandecer",
    "engrandeceríeis": "engrandecer",
    "engrandeces": "engrandecer",
    "engrandecesse": "engrandecer",
    "engrandecessem": "engrandecer",
    "engrandecesses": "engrandecer",
    "engrandeceste": "engrandecer",
    "engrandecestes": "engrandecer",
    "engrandeceu": "engrandecer",
    "engrandeci": "engrandecer",
    "engrandecia": "engrandecer",
    "engrandeciam": "engrandecer",
    "engrandecias": "engrandecer",
    "engrandecida": "engrandecido",
    "engrandecidas": "engrandecido",
    "engrandecido": "engrandecer",
    "engrandecidos": "engrandecido",
    "engrandecimentos": "engrandecimento",
    "engrandecêramo": "engrandecer",
    "engrandecêramos": "engrandecer",
    "engrandecêreis": "engrandecer",
    "engrandecêsseis": "engrandecer",
    "engrandecêssemos": "engrandecer",
    "engrandecíamo": "engrandecer",
    "engrandecíamos": "engrandecer",
    "engrandecíeis": "engrandecer",
    "engrandeça": "engrandecer",
    "engrandeçais": "engrandecer",
    "engrandeçam": "engrandecer",
    "engrandeçamo": "engrandecer",
    "engrandeçamos": "engrandecer",
    "engrandeças": "engrandecer",
    "engrandeço": "engrandecer",
    "engranza": "engranzar",
    "engranzada": "engranzar",
    "engranzadas": "engranzar",
    "engranzado": "engranzar",
    "engranzadora": "engranzador",
    "engranzadoras": "engranzador",
    "engranzadores": "engranzador",
    "engranzados": "engranzar",
    "engranzai": "engranzar",
    "engranzais": "engranzar",
    "engranzam": "engranzar",
    "engranzamentos": "engranzamento",
    "engranzamo": "engranzar",
    "engranzamos": "engranzar",
    "engranzando": "engranzar",
    "engranzara": "engranzar",
    "engranzaram": "engranzar",
    "engranzaras": "engranzar",
    "engranzarde": "engranzar",
    "engranzardes": "engranzar",
    "engranzare": "engranzar",
    "engranzarei": "engranzar",
    "engranzareis": "engranzar",
    "engranzarem": "engranzar",
    "engranzaremos": "engranzar",
    "engranzares": "engranzar",
    "engranzaria": "engranzar",
    "engranzariam": "engranzar",
    "engranzarias": "engranzar",
    "engranzarmo": "engranzar",
    "engranzarmos": "engranzar",
    "engranzará": "engranzar",
    "engranzarás": "engranzar",
    "engranzarão": "engranzar",
    "engranzaríamos": "engranzar",
    "engranzaríeis": "engranzar",
    "engranzas": "engranzar",
    "engranzasse": "engranzar",
    "engranzassem": "engranzar",
    "engranzasses": "engranzar",
    "engranzaste": "engranzar",
    "engranzastes": "engranzar",
    "engranzava": "engranzar",
    "engranzavam": "engranzar",
    "engranzavas": "engranzar",
    "engranze": "engranzar",
    "engranzei": "engranzar",
    "engranzeis": "engranzar",
    "engranzem": "engranzar",
    "engranzemo": "engranzar",
    "engranzemos": "engranzar",
    "engranzes": "engranzar",
    "engranzo": "engranzar",
    "engranzou": "engranzar",
    "engranzá": "engranzar",
    "engranzámo": "engranzar",
    "engranzámos": "engranzar",
    "engranzáramo": "engranzar",
    "engranzáramos": "engranzar",
    "engranzárei": "engranzar",
    "engranzáreis": "engranzar",
    "engranzásseis": "engranzar",
    "engranzássemos": "engranzar",
    "engranzávamo": "engranzar",
    "engranzávamos": "engranzar",
    "engranzávei": "engranzar",
    "engranzáveis": "engranzar",
    "engravata": "engravatar",
    "engravatada": "engravatar",
    "engravatadas": "engravatar",
    "engravatado": "engravatar",
    "engravatados": "engravatar",
    "engravatadíssima": "engravatado",
    "engravatadíssimas": "engravatado",
    "engravatadíssimo": "engravatado",
    "engravatadíssimos": "engravatado",
    "engravatai": "engravatar",
    "engravatais": "engravatar",
    "engravatam": "engravatar",
    "engravatamo": "engravatar",
    "engravatamos": "engravatar",
    "engravatando": "engravatar",
    "engravatara": "engravatar",
    "engravataram": "engravatar",
    "engravataras": "engravatar",
    "engravatarde": "engravatar",
    "engravatardes": "engravatar",
    "engravatare": "engravatar",
    "engravatarei": "engravatar",
    "engravatareis": "engravatar",
    "engravatarem": "engravatar",
    "engravataremos": "engravatar",
    "engravatares": "engravatar",
    "engravataria": "engravatar",
    "engravatariam": "engravatar",
    "engravatarias": "engravatar",
    "engravatarmo": "engravatar",
    "engravatarmos": "engravatar",
    "engravatará": "engravatar",
    "engravatarás": "engravatar",
    "engravatarão": "engravatar",
    "engravataríamos": "engravatar",
    "engravataríeis": "engravatar",
    "engravatas": "engravatar",
    "engravatasse": "engravatar",
    "engravatassem": "engravatar",
    "engravatasses": "engravatar",
    "engravataste": "engravatar",
    "engravatastes": "engravatar",
    "engravatava": "engravatar",
    "engravatavam": "engravatar",
    "engravatavas": "engravatar",
    "engravate": "engravatar",
    "engravatei": "engravatar",
    "engravateis": "engravatar",
    "engravatem": "engravatar",
    "engravatemo": "engravatar",
    "engravatemos": "engravatar",
    "engravates": "engravatar",
    "engravato": "engravatar",
    "engravatou": "engravatar",
    "engravatá": "engravatar",
    "engravatámo": "engravatar",
    "engravatámos": "engravatar",
    "engravatáramo": "engravatar",
    "engravatáramos": "engravatar",
    "engravatárei": "engravatar",
    "engravatáreis": "engravatar",
    "engravatásseis": "engravatar",
    "engravatássemos": "engravatar",
    "engravatávamo": "engravatar",
    "engravatávamos": "engravatar",
    "engravatávei": "engravatar",
    "engravatáveis": "engravatar",
    "engravesce": "engravescer",
    "engravescei": "engravescer",
    "engravesceis": "engravescer",
    "engravescem": "engravescer",
    "engravescemo": "engravescer",
    "engravescemos": "engravescer",
    "engravescendo": "engravescer",
    "engravescera": "engravescer",
    "engravesceram": "engravescer",
    "engravesceras": "engravescer",
    "engravescerdes": "engravescer",
    "engravescerei": "engravescer",
    "engravescereis": "engravescer",
    "engravescerem": "engravescer",
    "engravesceremos": "engravescer",
    "engravesceres": "engravescer",
    "engravesceria": "engravescer",
    "engravesceriam": "engravescer",
    "engravescerias": "engravescer",
    "engravescermo": "engravescer",
    "engravescermos": "engravescer",
    "engravescerá": "engravescer",
    "engravescerás": "engravescer",
    "engravescerão": "engravescer",
    "engravesceríamos": "engravescer",
    "engravesceríeis": "engravescer",
    "engravesces": "engravescer",
    "engravescesse": "engravescer",
    "engravescessem": "engravescer",
    "engravescesses": "engravescer",
    "engravesceste": "engravescer",
    "engravescestes": "engravescer",
    "engravesceu": "engravescer",
    "engravesci": "engravescer",
    "engravescia": "engravescer",
    "engravesciam": "engravescer",
    "engravescias": "engravescer",
    "engravescida": "engravescer",
    "engravescidas": "engravescer",
    "engravescido": "engravescer",
    "engravescidos": "engravescer",
    "engravescêramo": "engravescer",
    "engravescêramos": "engravescer",
    "engravescêreis": "engravescer",
    "engravescêsseis": "engravescer",
    "engravescêssemos": "engravescer",
    "engravescíamo": "engravescer",
    "engravescíamos": "engravescer",
    "engravescíeis": "engravescer",
    "engravesça": "engravescer",
    "engravesçais": "engravescer",
    "engravesçam": "engravescer",
    "engravesçamo": "engravescer",
    "engravesçamos": "engravescer",
    "engravesças": "engravescer",
    "engravesço": "engravescer",
    "engravida": "engravidar",
    "engravidada": "engravidar",
    "engravidadas": "engravidar",
    "engravidado": "engravidar",
    "engravidados": "engravidar",
    "engravidai": "engravidar",
    "engravidais": "engravidar",
    "engravidam": "engravidar",
    "engravidamo": "engravidar",
    "engravidamos": "engravidar",
    "engravidando": "engravidar",
    "engravidara": "engravidar",
    "engravidaram": "engravidar",
    "engravidaras": "engravidar",
    "engravidarde": "engravidar",
    "engravidardes": "engravidar",
    "engravidare": "engravidar",
    "engravidarei": "engravidar",
    "engravidareis": "engravidar",
    "engravidarem": "engravidar",
    "engravidaremos": "engravidar",
    "engravidares": "engravidar",
    "engravidaria": "engravidar",
    "engravidariam": "engravidar",
    "engravidarias": "engravidar",
    "engravidarmo": "engravidar",
    "engravidarmos": "engravidar",
    "engravidará": "engravidar",
    "engravidarás": "engravidar",
    "engravidarão": "engravidar",
    "engravidaríamos": "engravidar",
    "engravidaríeis": "engravidar",
    "engravidas": "engravidar",
    "engravidasse": "engravidar",
    "engravidassem": "engravidar",
    "engravidasses": "engravidar",
    "engravidaste": "engravidar",
    "engravidastes": "engravidar",
    "engravidava": "engravidar",
    "engravidavam": "engravidar",
    "engravidavas": "engravidar",
    "engravide": "engravidar",
    "engravidece": "engravidecer",
    "engravidecei": "engravidecer",
    "engravideceis": "engravidecer",
    "engravidecem": "engravidecer",
    "engravidecemo": "engravidecer",
    "engravidecemos": "engravidecer",
    "engravidecendo": "engravidecer",
    "engravidecera": "engravidecer",
    "engravideceram": "engravidecer",
    "engravideceras": "engravidecer",
    "engravidecerde": "engravidecer",
    "engravidecerdes": "engravidecer",
    "engravidecere": "engravidecer",
    "engravidecerei": "engravidecer",
    "engravidecereis": "engravidecer",
    "engravidecerem": "engravidecer",
    "engravideceremos": "engravidecer",
    "engravideceres": "engravidecer",
    "engravideceria": "engravidecer",
    "engravideceriam": "engravidecer",
    "engravidecerias": "engravidecer",
    "engravidecermo": "engravidecer",
    "engravidecermos": "engravidecer",
    "engravidecerá": "engravidecer",
    "engravidecerás": "engravidecer",
    "engravidecerão": "engravidecer",
    "engravideceríamos": "engravidecer",
    "engravideceríeis": "engravidecer",
    "engravideces": "engravidecer",
    "engravidecesse": "engravidecer",
    "engravidecessem": "engravidecer",
    "engravidecesses": "engravidecer",
    "engravideceste": "engravidecer",
    "engravidecestes": "engravidecer",
    "engravideceu": "engravidecer",
    "engravideci": "engravidecer",
    "engravidecia": "engravidecer",
    "engravideciam": "engravidecer",
    "engravidecias": "engravidecer",
    "engravidecida": "engravidecer",
    "engravidecidas": "engravidecer",
    "engravidecido": "engravidecer",
    "engravidecidos": "engravidecer",
    "engravidecê": "engravidecer",
    "engravidecêramo": "engravidecer",
    "engravidecêramos": "engravidecer",
    "engravidecêrei": "engravidecer",
    "engravidecêreis": "engravidecer",
    "engravidecêsseis": "engravidecer",
    "engravidecêssemos": "engravidecer",
    "engravidecíamo": "engravidecer",
    "engravidecíamos": "engravidecer",
    "engravidecíei": "engravidecer",
    "engravidecíeis": "engravidecer",
    "engravidei": "engravidar",
    "engravideis": "engravidar",
    "engravidem": "engravidar",
    "engravidemo": "engravidar",
    "engravidemos": "engravidar",
    "engravides": "engravidar",
    "engravideça": "engravidecer",
    "engravideçais": "engravidecer",
    "engravideçam": "engravidecer",
    "engravideçamo": "engravidecer",
    "engravideçamos": "engravidecer",
    "engravideças": "engravidecer",
    "engravideço": "engravidecer",
    "engravido": "engravidar",
    "engravidou": "engravidar",
    "engravidá": "engravidar",
    "engravidámo": "engravidar",
    "engravidámos": "engravidar",
    "engravidáramo": "engravidar",
    "engravidáramos": "engravidar",
    "engravidárei": "engravidar",
    "engravidáreis": "engravidar",
    "engravidásseis": "engravidar",
    "engravidássemos": "engravidar",
    "engravidávamo": "engravidar",
    "engravidávamos": "engravidar",
    "engravidávei": "engravidar",
    "engravidáveis": "engravidar",
    "engravita": "engravitar",
    "engravitada": "engravitar",
    "engravitadas": "engravitar",
    "engravitado": "engravitar",
    "engravitados": "engravitar",
    "engravitai": "engravitar",
    "engravitais": "engravitar",
    "engravitam": "engravitar",
    "engravitamo": "engravitar",
    "engravitamos": "engravitar",
    "engravitando": "engravitar",
    "engravitara": "engravitar",
    "engravitaram": "engravitar",
    "engravitaras": "engravitar",
    "engravitarde": "engravitar",
    "engravitardes": "engravitar",
    "engravitare": "engravitar",
    "engravitarei": "engravitar",
    "engravitareis": "engravitar",
    "engravitarem": "engravitar",
    "engravitaremos": "engravitar",
    "engravitares": "engravitar",
    "engravitaria": "engravitar",
    "engravitariam": "engravitar",
    "engravitarias": "engravitar",
    "engravitarmo": "engravitar",
    "engravitarmos": "engravitar",
    "engravitará": "engravitar",
    "engravitarás": "engravitar",
    "engravitarão": "engravitar",
    "engravitaríamos": "engravitar",
    "engravitaríeis": "engravitar",
    "engravitas": "engravitar",
    "engravitasse": "engravitar",
    "engravitassem": "engravitar",
    "engravitasses": "engravitar",
    "engravitaste": "engravitar",
    "engravitastes": "engravitar",
    "engravitava": "engravitar",
    "engravitavam": "engravitar",
    "engravitavas": "engravitar",
    "engravite": "engravitar",
    "engravitei": "engravitar",
    "engraviteis": "engravitar",
    "engravitem": "engravitar",
    "engravitemo": "engravitar",
    "engravitemos": "engravitar",
    "engravites": "engravitar",
    "engravito": "engravitar",
    "engravitou": "engravitar",
    "engravitá": "engravitar",
    "engravitámo": "engravitar",
    "engravitámos": "engravitar",
    "engravitáramo": "engravitar",
    "engravitáramos": "engravitar",
    "engravitárei": "engravitar",
    "engravitáreis": "engravitar",
    "engravitásseis": "engravitar",
    "engravitássemos": "engravitar",
    "engravitávamo": "engravitar",
    "engravitávamos": "engravitar",
    "engravitávei": "engravitar",
    "engravitáveis": "engravitar",
    "engraxa": "engraxar",
    "engraxada": "engraxar",
    "engraxadas": "engraxar",
    "engraxadelas": "engraxadela",
    "engraxado": "engraxar",
    "engraxadora": "engraxador",
    "engraxadoras": "engraxador",
    "engraxadores": "engraxador",
    "engraxadorias": "engraxadoria",
    "engraxados": "engraxar",
    "engraxai": "engraxar",
    "engraxais": "engraxar",
    "engraxam": "engraxar",
    "engraxamentos": "engraxamento",
    "engraxamo": "engraxar",
    "engraxamos": "engraxar",
    "engraxando": "engraxar",
    "engraxara": "engraxar",
    "engraxaram": "engraxar",
    "engraxaras": "engraxar",
    "engraxarde": "engraxar",
    "engraxardes": "engraxar",
    "engraxare": "engraxar",
    "engraxarei": "engraxar",
    "engraxareis": "engraxar",
    "engraxarem": "engraxar",
    "engraxaremos": "engraxar",
    "engraxares": "engraxar",
    "engraxaria": "engraxar",
    "engraxariam": "engraxar",
    "engraxarias": "engraxar",
    "engraxarmo": "engraxar",
    "engraxarmos": "engraxar",
    "engraxará": "engraxar",
    "engraxarás": "engraxar",
    "engraxarão": "engraxar",
    "engraxaríamos": "engraxar",
    "engraxaríeis": "engraxar",
    "engraxas": "engraxar",
    "engraxasse": "engraxar",
    "engraxassem": "engraxar",
    "engraxasses": "engraxar",
    "engraxaste": "engraxar",
    "engraxastes": "engraxar",
    "engraxava": "engraxar",
    "engraxavam": "engraxar",
    "engraxavas": "engraxar",
    "engraxe": "engraxar",
    "engraxei": "engraxar",
    "engraxeis": "engraxar",
    "engraxem": "engraxar",
    "engraxemo": "engraxar",
    "engraxemos": "engraxar",
    "engraxes": "engraxar",
    "engraxo": "engraxar",
    "engraxou": "engraxar",
    "engraxá": "engraxar",
    "engraxámo": "engraxar",
    "engraxámos": "engraxar",
    "engraxáramo": "engraxar",
    "engraxáramos": "engraxar",
    "engraxárei": "engraxar",
    "engraxáreis": "engraxar",
    "engraxásseis": "engraxar",
    "engraxássemos": "engraxar",
    "engraxávamo": "engraxar",
    "engraxávamos": "engraxar",
    "engraxávei": "engraxar",
    "engraxáveis": "engraxar",
    "engrazula": "engrazular",
    "engrazulada": "engrazular",
    "engrazuladas": "engrazular",
    "engrazulado": "engrazular",
    "engrazulados": "engrazular",
    "engrazulai": "engrazular",
    "engrazulais": "engrazular",
    "engrazulam": "engrazular",
    "engrazulamo": "engrazular",
    "engrazulamos": "engrazular",
    "engrazulando": "engrazular",
    "engrazulara": "engrazular",
    "engrazularam": "engrazular",
    "engrazularas": "engrazular",
    "engrazularde": "engrazular",
    "engrazulardes": "engrazular",
    "engrazulare": "engrazular",
    "engrazularei": "engrazular",
    "engrazulareis": "engrazular",
    "engrazularem": "engrazular",
    "engrazularemos": "engrazular",
    "engrazulares": "engrazular",
    "engrazularia": "engrazular",
    "engrazulariam": "engrazular",
    "engrazularias": "engrazular",
    "engrazularmo": "engrazular",
    "engrazularmos": "engrazular",
    "engrazulará": "engrazular",
    "engrazularás": "engrazular",
    "engrazularão": "engrazular",
    "engrazularíamos": "engrazular",
    "engrazularíeis": "engrazular",
    "engrazulas": "engrazular",
    "engrazulasse": "engrazular",
    "engrazulassem": "engrazular",
    "engrazulasses": "engrazular",
    "engrazulaste": "engrazular",
    "engrazulastes": "engrazular",
    "engrazulava": "engrazular",
    "engrazulavam": "engrazular",
    "engrazulavas": "engrazular",
    "engrazule": "engrazular",
    "engrazulei": "engrazular",
    "engrazuleis": "engrazular",
    "engrazulem": "engrazular",
    "engrazulemo": "engrazular",
    "engrazulemos": "engrazular",
    "engrazules": "engrazular",
    "engrazulo": "engrazular",
    "engrazulou": "engrazular",
    "engrazulá": "engrazular",
    "engrazulámo": "engrazular",
    "engrazulámos": "engrazular",
    "engrazuláramo": "engrazular",
    "engrazuláramos": "engrazular",
    "engrazulárei": "engrazular",
    "engrazuláreis": "engrazular",
    "engrazulásseis": "engrazular",
    "engrazulássemos": "engrazular",
    "engrazulávamo": "engrazular",
    "engrazulávamos": "engrazular",
    "engrazulávei": "engrazular",
    "engrazuláveis": "engrazular",
    "engraça": "engraçar",
    "engraçada": "engraçar",
    "engraçadas": "engraçar",
    "engraçadinha": "engraçado",
    "engraçadinhas": "engraçado",
    "engraçadinho": "engraçado",
    "engraçadinhos": "engraçado",
    "engraçadita": "engraçado",
    "engraçaditas": "engraçado",
    "engraçadito": "engraçado",
    "engraçaditos": "engraçado",
    "engraçado": "engraçar",
    "engraçados": "engraçar",
    "engraçadíssima": "engraçado",
    "engraçadíssimas": "engraçado",
    "engraçadíssimo": "engraçado",
    "engraçadíssimos": "engraçado",
    "engraçai": "engraçar",
    "engraçais": "engraçar",
    "engraçam": "engraçar",
    "engraçamo": "engraçar",
    "engraçamos": "engraçar",
    "engraçando": "engraçar",
    "engraçara": "engraçar",
    "engraçaram": "engraçar",
    "engraçaras": "engraçar",
    "engraçarde": "engraçar",
    "engraçardes": "engraçar",
    "engraçare": "engraçar",
    "engraçarei": "engraçar",
    "engraçareis": "engraçar",
    "engraçarem": "engraçar",
    "engraçaremos": "engraçar",
    "engraçares": "engraçar",
    "engraçaria": "engraçar",
    "engraçariam": "engraçar",
    "engraçarias": "engraçar",
    "engraçarmo": "engraçar",
    "engraçarmos": "engraçar",
    "engraçará": "engraçar",
    "engraçarás": "engraçar",
    "engraçarão": "engraçar",
    "engraçaríamos": "engraçar",
    "engraçaríeis": "engraçar",
    "engraças": "engraçar",
    "engraçasse": "engraçar",
    "engraçassem": "engraçar",
    "engraçasses": "engraçar",
    "engraçaste": "engraçar",
    "engraçastes": "engraçar",
    "engraçava": "engraçar",
    "engraçavam": "engraçar",
    "engraçavas": "engraçar",
    "engraço": "engraçar",
    "engraçou": "engraçar",
    "engraçá": "engraçar",
    "engraçámo": "engraçar",
    "engraçámos": "engraçar",
    "engraçáramo": "engraçar",
    "engraçáramos": "engraçar",
    "engraçárei": "engraçar",
    "engraçáreis": "engraçar",
    "engraçásseis": "engraçar",
    "engraçássemos": "engraçar",
    "engraçávamo": "engraçar",
    "engraçávamos": "engraçar",
    "engraçávei": "engraçar",
    "engraçáveis": "engraçar",
    "engrela": "engrelar",
    "engrelada": "engrelar",
    "engreladas": "engrelar",
    "engrelado": "engrelar",
    "engrelados": "engrelar",
    "engrelai": "engrelar",
    "engrelais": "engrelar",
    "engrelam": "engrelar",
    "engrelamo": "engrelar",
    "engrelamos": "engrelar",
    "engrelando": "engrelar",
    "engrelara": "engrelar",
    "engrelaram": "engrelar",
    "engrelaras": "engrelar",
    "engrelarde": "engrelar",
    "engrelardes": "engrelar",
    "engrelare": "engrelar",
    "engrelarei": "engrelar",
    "engrelareis": "engrelar",
    "engrelarem": "engrelar",
    "engrelaremos": "engrelar",
    "engrelares": "engrelar",
    "engrelaria": "engrelar",
    "engrelariam": "engrelar",
    "engrelarias": "engrelar",
    "engrelarmo": "engrelar",
    "engrelarmos": "engrelar",
    "engrelará": "engrelar",
    "engrelarás": "engrelar",
    "engrelarão": "engrelar",
    "engrelaríamos": "engrelar",
    "engrelaríeis": "engrelar",
    "engrelas": "engrelar",
    "engrelasse": "engrelar",
    "engrelassem": "engrelar",
    "engrelasses": "engrelar",
    "engrelaste": "engrelar",
    "engrelastes": "engrelar",
    "engrelava": "engrelar",
    "engrelavam": "engrelar",
    "engrelavas": "engrelar",
    "engrele": "engrelar",
    "engrelei": "engrelar",
    "engreleis": "engrelar",
    "engrelem": "engrelar",
    "engrelemo": "engrelar",
    "engrelemos": "engrelar",
    "engreles": "engrelar",
    "engrelo": "engrelar",
    "engrelou": "engrelar",
    "engrelá": "engrelar",
    "engrelámo": "engrelar",
    "engrelámos": "engrelar",
    "engreláramo": "engrelar",
    "engreláramos": "engrelar",
    "engrelárei": "engrelar",
    "engreláreis": "engrelar",
    "engrelásseis": "engrelar",
    "engrelássemos": "engrelar",
    "engrelávamo": "engrelar",
    "engrelávamos": "engrelar",
    "engrelávei": "engrelar",
    "engreláveis": "engrelar",
    "engrena": "engrenar",
    "engrenada": "engrenar",
    "engrenadas": "engrenar",
    "engrenado": "engrenar",
    "engrenados": "engrenar",
    "engrenagens": "engrenagem",
    "engrenai": "engrenar",
    "engrenais": "engrenar",
    "engrenam": "engrenar",
    "engrenamentos": "engrenamento",
    "engrenamo": "engrenar",
    "engrenamos": "engrenar",
    "engrenando": "engrenar",
    "engrenara": "engrenar",
    "engrenaram": "engrenar",
    "engrenaras": "engrenar",
    "engrenarde": "engrenar",
    "engrenardes": "engrenar",
    "engrenare": "engrenar",
    "engrenarei": "engrenar",
    "engrenareis": "engrenar",
    "engrenarem": "engrenar",
    "engrenaremos": "engrenar",
    "engrenares": "engrenar",
    "engrenaria": "engrenar",
    "engrenariam": "engrenar",
    "engrenarias": "engrenar",
    "engrenarmo": "engrenar",
    "engrenarmos": "engrenar",
    "engrenará": "engrenar",
    "engrenarás": "engrenar",
    "engrenarão": "engrenar",
    "engrenaríamos": "engrenar",
    "engrenaríeis": "engrenar",
    "engrenas": "engrenar",
    "engrenasse": "engrenar",
    "engrenassem": "engrenar",
    "engrenasses": "engrenar",
    "engrenaste": "engrenar",
    "engrenastes": "engrenar",
    "engrenava": "engrenar",
    "engrenavam": "engrenar",
    "engrenavas": "engrenar",
    "engrene": "engrenar",
    "engrenei": "engrenar",
    "engreneis": "engrenar",
    "engrenem": "engrenar",
    "engrenemo": "engrenar",
    "engrenemos": "engrenar",
    "engrenes": "engrenar",
    "engrenha": "engrenhar",
    "engrenhada": "engrenhar",
    "engrenhadas": "engrenhar",
    "engrenhado": "engrenhar",
    "engrenhados": "engrenhar",
    "engrenhai": "engrenhar",
    "engrenhais": "engrenhar",
    "engrenham": "engrenhar",
    "engrenhamentos": "engrenhamento",
    "engrenhamo": "engrenhar",
    "engrenhamos": "engrenhar",
    "engrenhando": "engrenhar",
    "engrenhara": "engrenhar",
    "engrenharam": "engrenhar",
    "engrenharas": "engrenhar",
    "engrenharde": "engrenhar",
    "engrenhardes": "engrenhar",
    "engrenhare": "engrenhar",
    "engrenharei": "engrenhar",
    "engrenhareis": "engrenhar",
    "engrenharem": "engrenhar",
    "engrenharemos": "engrenhar",
    "engrenhares": "engrenhar",
    "engrenharia": "engrenhar",
    "engrenhariam": "engrenhar",
    "engrenharias": "engrenhar",
    "engrenharmo": "engrenhar",
    "engrenharmos": "engrenhar",
    "engrenhará": "engrenhar",
    "engrenharás": "engrenhar",
    "engrenharão": "engrenhar",
    "engrenharíamos": "engrenhar",
    "engrenharíeis": "engrenhar",
    "engrenhas": "engrenhar",
    "engrenhasse": "engrenhar",
    "engrenhassem": "engrenhar",
    "engrenhasses": "engrenhar",
    "engrenhaste": "engrenhar",
    "engrenhastes": "engrenhar",
    "engrenhava": "engrenhar",
    "engrenhavam": "engrenhar",
    "engrenhavas": "engrenhar",
    "engrenhe": "engrenhar",
    "engrenhei": "engrenhar",
    "engrenheis": "engrenhar",
    "engrenhem": "engrenhar",
    "engrenhemo": "engrenhar",
    "engrenhemos": "engrenhar",
    "engrenhes": "engrenhar",
    "engrenho": "engrenhar",
    "engrenhou": "engrenhar",
    "engrenhá": "engrenhar",
    "engrenhámo": "engrenhar",
    "engrenhámos": "engrenhar",
    "engrenháramo": "engrenhar",
    "engrenháramos": "engrenhar",
    "engrenhárei": "engrenhar",
    "engrenháreis": "engrenhar",
    "engrenhásseis": "engrenhar",
    "engrenhássemos": "engrenhar",
    "engrenhávamo": "engrenhar",
    "engrenhávamos": "engrenhar",
    "engrenhávei": "engrenhar",
    "engrenháveis": "engrenhar",
    "engreno": "engrenar",
    "engrenou": "engrenar",
    "engrená": "engrenar",
    "engrenámo": "engrenar",
    "engrenámos": "engrenar",
    "engrenáramo": "engrenar",
    "engrenáramos": "engrenar",
    "engrenárei": "engrenar",
    "engrenáreis": "engrenar",
    "engrenásseis": "engrenar",
    "engrenássemos": "engrenar",
    "engrenávamo": "engrenar",
    "engrenávamos": "engrenar",
    "engrenávei": "engrenar",
    "engrenáveis": "engrenar",
    "engrifa": "engrifar",
    "engrifada": "engrifar",
    "engrifadas": "engrifar",
    "engrifado": "engrifar",
    "engrifados": "engrifar",
    "engrifai": "engrifar",
    "engrifais": "engrifar",
    "engrifam": "engrifar",
    "engrifamo": "engrifar",
    "engrifamos": "engrifar",
    "engrifando": "engrifar",
    "engrifara": "engrifar",
    "engrifaram": "engrifar",
    "engrifaras": "engrifar",
    "engrifarde": "engrifar",
    "engrifardes": "engrifar",
    "engrifare": "engrifar",
    "engrifarei": "engrifar",
    "engrifareis": "engrifar",
    "engrifarem": "engrifar",
    "engrifaremos": "engrifar",
    "engrifares": "engrifar",
    "engrifaria": "engrifar",
    "engrifariam": "engrifar",
    "engrifarias": "engrifar",
    "engrifarmo": "engrifar",
    "engrifarmos": "engrifar",
    "engrifará": "engrifar",
    "engrifarás": "engrifar",
    "engrifarão": "engrifar",
    "engrifaríamos": "engrifar",
    "engrifaríeis": "engrifar",
    "engrifas": "engrifar",
    "engrifasse": "engrifar",
    "engrifassem": "engrifar",
    "engrifasses": "engrifar",
    "engrifaste": "engrifar",
    "engrifastes": "engrifar",
    "engrifava": "engrifar",
    "engrifavam": "engrifar",
    "engrifavas": "engrifar",
    "engrife": "engrifar",
    "engrifei": "engrifar",
    "engrifeis": "engrifar",
    "engrifem": "engrifar",
    "engrifemo": "engrifar",
    "engrifemos": "engrifar",
    "engrifes": "engrifar",
    "engrifo": "engrifar",
    "engrifou": "engrifar",
    "engrifá": "engrifar",
    "engrifámo": "engrifar",
    "engrifámos": "engrifar",
    "engrifáramo": "engrifar",
    "engrifáramos": "engrifar",
    "engrifárei": "engrifar",
    "engrifáreis": "engrifar",
    "engrifásseis": "engrifar",
    "engrifássemos": "engrifar",
    "engrifávamo": "engrifar",
    "engrifávamos": "engrifar",
    "engrifávei": "engrifar",
    "engrifáveis": "engrifar",
    "engrila": "engrilar",
    "engrilada": "engrilar",
    "engriladas": "engrilar",
    "engrilado": "engrilar",
    "engrilados": "engrilar",
    "engrilai": "engrilar",
    "engrilais": "engrilar",
    "engrilam": "engrilar",
    "engrilamo": "engrilar",
    "engrilamos": "engrilar",
    "engrilando": "engrilar",
    "engrilara": "engrilar",
    "engrilaram": "engrilar",
    "engrilaras": "engrilar",
    "engrilarde": "engrilar",
    "engrilardes": "engrilar",
    "engrilare": "engrilar",
    "engrilarei": "engrilar",
    "engrilareis": "engrilar",
    "engrilarem": "engrilar",
    "engrilaremos": "engrilar",
    "engrilares": "engrilar",
    "engrilaria": "engrilar",
    "engrilariam": "engrilar",
    "engrilarias": "engrilar",
    "engrilarmo": "engrilar",
    "engrilarmos": "engrilar",
    "engrilará": "engrilar",
    "engrilarás": "engrilar",
    "engrilarão": "engrilar",
    "engrilaríamos": "engrilar",
    "engrilaríeis": "engrilar",
    "engrilas": "engrilar",
    "engrilasse": "engrilar",
    "engrilassem": "engrilar",
    "engrilasses": "engrilar",
    "engrilaste": "engrilar",
    "engrilastes": "engrilar",
    "engrilava": "engrilar",
    "engrilavam": "engrilar",
    "engrilavas": "engrilar",
    "engrile": "engrilar",
    "engrilei": "engrilar",
    "engrileis": "engrilar",
    "engrilem": "engrilar",
    "engrilemo": "engrilar",
    "engrilemos": "engrilar",
    "engriles": "engrilar",
    "engrilo": "engrilar",
    "engrilou": "engrilar",
    "engrilá": "engrilar",
    "engrilámo": "engrilar",
    "engrilámos": "engrilar",
    "engriláramo": "engrilar",
    "engriláramos": "engrilar",
    "engrilárei": "engrilar",
    "engriláreis": "engrilar",
    "engrilásseis": "engrilar",
    "engrilássemos": "engrilar",
    "engrilávamo": "engrilar",
    "engrilávamos": "engrilar",
    "engrilávei": "engrilar",
    "engriláveis": "engrilar",
    "engrimanços": "engrimanço",
    "engrimpa": "engrimpar",
    "engrimpada": "engrimpar",
    "engrimpadas": "engrimpar",
    "engrimpado": "engrimpar",
    "engrimpados": "engrimpar",
    "engrimpai": "engrimpar",
    "engrimpais": "engrimpar",
    "engrimpam": "engrimpar",
    "engrimpamo": "engrimpar",
    "engrimpamos": "engrimpar",
    "engrimpando": "engrimpar",
    "engrimpara": "engrimpar",
    "engrimparam": "engrimpar",
    "engrimparas": "engrimpar",
    "engrimparde": "engrimpar",
    "engrimpardes": "engrimpar",
    "engrimpare": "engrimpar",
    "engrimparei": "engrimpar",
    "engrimpareis": "engrimpar",
    "engrimparem": "engrimpar",
    "engrimparemos": "engrimpar",
    "engrimpares": "engrimpar",
    "engrimparia": "engrimpar",
    "engrimpariam": "engrimpar",
    "engrimparias": "engrimpar",
    "engrimparmo": "engrimpar",
    "engrimparmos": "engrimpar",
    "engrimpará": "engrimpar",
    "engrimparás": "engrimpar",
    "engrimparão": "engrimpar",
    "engrimparíamos": "engrimpar",
    "engrimparíeis": "engrimpar",
    "engrimpas": "engrimpar",
    "engrimpasse": "engrimpar",
    "engrimpassem": "engrimpar",
    "engrimpasses": "engrimpar",
    "engrimpaste": "engrimpar",
    "engrimpastes": "engrimpar",
    "engrimpava": "engrimpar",
    "engrimpavam": "engrimpar",
    "engrimpavas": "engrimpar",
    "engrimpe": "engrimpar",
    "engrimpei": "engrimpar",
    "engrimpeis": "engrimpar",
    "engrimpem": "engrimpar",
    "engrimpemo": "engrimpar",
    "engrimpemos": "engrimpar",
    "engrimpes": "engrimpar",
    "engrimpina": "engrimpinar",
    "engrimpinada": "engrimpinar",
    "engrimpinadas": "engrimpinar",
    "engrimpinado": "engrimpinar",
    "engrimpinados": "engrimpinar",
    "engrimpinai": "engrimpinar",
    "engrimpinais": "engrimpinar",
    "engrimpinam": "engrimpinar",
    "engrimpinamo": "engrimpinar",
    "engrimpinamos": "engrimpinar",
    "engrimpinando": "engrimpinar",
    "engrimpinara": "engrimpinar",
    "engrimpinaram": "engrimpinar",
    "engrimpinaras": "engrimpinar",
    "engrimpinarde": "engrimpinar",
    "engrimpinardes": "engrimpinar",
    "engrimpinare": "engrimpinar",
    "engrimpinarei": "engrimpinar",
    "engrimpinareis": "engrimpinar",
    "engrimpinarem": "engrimpinar",
    "engrimpinaremos": "engrimpinar",
    "engrimpinares": "engrimpinar",
    "engrimpinaria": "engrimpinar",
    "engrimpinariam": "engrimpinar",
    "engrimpinarias": "engrimpinar",
    "engrimpinarmo": "engrimpinar",
    "engrimpinarmos": "engrimpinar",
    "engrimpinará": "engrimpinar",
    "engrimpinarás": "engrimpinar",
    "engrimpinarão": "engrimpinar",
    "engrimpinaríamos": "engrimpinar",
    "engrimpinaríeis": "engrimpinar",
    "engrimpinas": "engrimpinar",
    "engrimpinasse": "engrimpinar",
    "engrimpinassem": "engrimpinar",
    "engrimpinasses": "engrimpinar",
    "engrimpinaste": "engrimpinar",
    "engrimpinastes": "engrimpinar",
    "engrimpinava": "engrimpinar",
    "engrimpinavam": "engrimpinar",
    "engrimpinavas": "engrimpinar",
    "engrimpine": "engrimpinar",
    "engrimpinei": "engrimpinar",
    "engrimpineis": "engrimpinar",
    "engrimpinem": "engrimpinar",
    "engrimpinemo": "engrimpinar",
    "engrimpinemos": "engrimpinar",
    "engrimpines": "engrimpinar",
    "engrimpino": "engrimpinar",
    "engrimpinou": "engrimpinar",
    "engrimpiná": "engrimpinar",
    "engrimpinámo": "engrimpinar",
    "engrimpinámos": "engrimpinar",
    "engrimpináramo": "engrimpinar",
    "engrimpináramos": "engrimpinar",
    "engrimpinárei": "engrimpinar",
    "engrimpináreis": "engrimpinar",
    "engrimpinásseis": "engrimpinar",
    "engrimpinássemos": "engrimpinar",
    "engrimpinávamo": "engrimpinar",
    "engrimpinávamos": "engrimpinar",
    "engrimpinávei": "engrimpinar",
    "engrimpináveis": "engrimpinar",
    "engrimpo": "engrimpar",
    "engrimpona": "engrimponar",
    "engrimponada": "engrimponar",
    "engrimponadas": "engrimponar",
    "engrimponado": "engrimponar",
    "engrimponados": "engrimponar",
    "engrimponai": "engrimponar",
    "engrimponais": "engrimponar",
    "engrimponam": "engrimponar",
    "engrimponamo": "engrimponar",
    "engrimponamos": "engrimponar",
    "engrimponando": "engrimponar",
    "engrimponara": "engrimponar",
    "engrimponaram": "engrimponar",
    "engrimponaras": "engrimponar",
    "engrimponarde": "engrimponar",
    "engrimponardes": "engrimponar",
    "engrimponare": "engrimponar",
    "engrimponarei": "engrimponar",
    "engrimponareis": "engrimponar",
    "engrimponarem": "engrimponar",
    "engrimponaremos": "engrimponar",
    "engrimponares": "engrimponar",
    "engrimponaria": "engrimponar",
    "engrimponariam": "engrimponar",
    "engrimponarias": "engrimponar",
    "engrimponarmo": "engrimponar",
    "engrimponarmos": "engrimponar",
    "engrimponará": "engrimponar",
    "engrimponarás": "engrimponar",
    "engrimponarão": "engrimponar",
    "engrimponaríamos": "engrimponar",
    "engrimponaríeis": "engrimponar",
    "engrimponas": "engrimponar",
    "engrimponasse": "engrimponar",
    "engrimponassem": "engrimponar",
    "engrimponasses": "engrimponar",
    "engrimponaste": "engrimponar",
    "engrimponastes": "engrimponar",
    "engrimponava": "engrimponar",
    "engrimponavam": "engrimponar",
    "engrimponavas": "engrimponar",
    "engrimpone": "engrimponar",
    "engrimponei": "engrimponar",
    "engrimponeis": "engrimponar",
    "engrimponem": "engrimponar",
    "engrimponemo": "engrimponar",
    "engrimponemos": "engrimponar",
    "engrimpones": "engrimponar",
    "engrimpono": "engrimponar",
    "engrimponou": "engrimponar",
    "engrimponá": "engrimponar",
    "engrimponámo": "engrimponar",
    "engrimponámos": "engrimponar",
    "engrimponáramo": "engrimponar",
    "engrimponáramos": "engrimponar",
    "engrimponárei": "engrimponar",
    "engrimponáreis": "engrimponar",
    "engrimponásseis": "engrimponar",
    "engrimponássemos": "engrimponar",
    "engrimponávamo": "engrimponar",
    "engrimponávamos": "engrimponar",
    "engrimponávei": "engrimponar",
    "engrimponáveis": "engrimponar",
    "engrimpou": "engrimpar",
    "engrimpá": "engrimpar",
    "engrimpámo": "engrimpar",
    "engrimpámos": "engrimpar",
    "engrimpáramo": "engrimpar",
    "engrimpáramos": "engrimpar",
    "engrimpárei": "engrimpar",
    "engrimpáreis": "engrimpar",
    "engrimpásseis": "engrimpar",
    "engrimpássemos": "engrimpar",
    "engrimpávamo": "engrimpar",
    "engrimpávamos": "engrimpar",
    "engrimpávei": "engrimpar",
    "engrimpáveis": "engrimpar",
    "engrinalda": "engrinaldar",
    "engrinaldada": "engrinaldar",
    "engrinaldadas": "engrinaldar",
    "engrinaldado": "engrinaldar",
    "engrinaldados": "engrinaldar",
    "engrinaldai": "engrinaldar",
    "engrinaldais": "engrinaldar",
    "engrinaldam": "engrinaldar",
    "engrinaldamo": "engrinaldar",
    "engrinaldamos": "engrinaldar",
    "engrinaldando": "engrinaldar",
    "engrinaldara": "engrinaldar",
    "engrinaldaram": "engrinaldar",
    "engrinaldaras": "engrinaldar",
    "engrinaldarde": "engrinaldar",
    "engrinaldardes": "engrinaldar",
    "engrinaldare": "engrinaldar",
    "engrinaldarei": "engrinaldar",
    "engrinaldareis": "engrinaldar",
    "engrinaldarem": "engrinaldar",
    "engrinaldaremos": "engrinaldar",
    "engrinaldares": "engrinaldar",
    "engrinaldaria": "engrinaldar",
    "engrinaldariam": "engrinaldar",
    "engrinaldarias": "engrinaldar",
    "engrinaldarmo": "engrinaldar",
    "engrinaldarmos": "engrinaldar",
    "engrinaldará": "engrinaldar",
    "engrinaldarás": "engrinaldar",
    "engrinaldarão": "engrinaldar",
    "engrinaldaríamos": "engrinaldar",
    "engrinaldaríeis": "engrinaldar",
    "engrinaldas": "engrinaldar",
    "engrinaldasse": "engrinaldar",
    "engrinaldassem": "engrinaldar",
    "engrinaldasses": "engrinaldar",
    "engrinaldaste": "engrinaldar",
    "engrinaldastes": "engrinaldar",
    "engrinaldava": "engrinaldar",
    "engrinaldavam": "engrinaldar",
    "engrinaldavas": "engrinaldar",
    "engrinalde": "engrinaldar",
    "engrinaldei": "engrinaldar",
    "engrinaldeis": "engrinaldar",
    "engrinaldem": "engrinaldar",
    "engrinaldemo": "engrinaldar",
    "engrinaldemos": "engrinaldar",
    "engrinaldes": "engrinaldar",
    "engrinaldo": "engrinaldar",
    "engrinaldou": "engrinaldar",
    "engrinaldá": "engrinaldar",
    "engrinaldámo": "engrinaldar",
    "engrinaldámos": "engrinaldar",
    "engrinaldáramo": "engrinaldar",
    "engrinaldáramos": "engrinaldar",
    "engrinaldárei": "engrinaldar",
    "engrinaldáreis": "engrinaldar",
    "engrinaldásseis": "engrinaldar",
    "engrinaldássemos": "engrinaldar",
    "engrinaldávamo": "engrinaldar",
    "engrinaldávamos": "engrinaldar",
    "engrinaldávei": "engrinaldar",
    "engrinaldáveis": "engrinaldar",
    "engripa": "engripar",
    "engripada": "engripar",
    "engripadas": "engripar",
    "engripado": "engripar",
    "engripados": "engripar",
    "engripadíssima": "engripado",
    "engripadíssimas": "engripado",
    "engripadíssimo": "engripado",
    "engripadíssimos": "engripado",
    "engripai": "engripar",
    "engripais": "engripar",
    "engripam": "engripar",
    "engripamo": "engripar",
    "engripamos": "engripar",
    "engripando": "engripar",
    "engripara": "engripar",
    "engriparam": "engripar",
    "engriparas": "engripar",
    "engriparde": "engripar",
    "engripardes": "engripar",
    "engripare": "engripar",
    "engriparei": "engripar",
    "engripareis": "engripar",
    "engriparem": "engripar",
    "engriparemos": "engripar",
    "engripares": "engripar",
    "engriparia": "engripar",
    "engripariam": "engripar",
    "engriparias": "engripar",
    "engriparmo": "engripar",
    "engriparmos": "engripar",
    "engripará": "engripar",
    "engriparás": "engripar",
    "engriparão": "engripar",
    "engriparíamos": "engripar",
    "engriparíeis": "engripar",
    "engripas": "engripar",
    "engripasse": "engripar",
    "engripassem": "engripar",
    "engripasses": "engripar",
    "engripaste": "engripar",
    "engripastes": "engripar",
    "engripava": "engripar",
    "engripavam": "engripar",
    "engripavas": "engripar",
    "engripe": "engripar",
    "engripei": "engripar",
    "engripeis": "engripar",
    "engripem": "engripar",
    "engripemo": "engripar",
    "engripemos": "engripar",
    "engripes": "engripar",
    "engripo": "engripar",
    "engripou": "engripar",
    "engripá": "engripar",
    "engripámo": "engripar",
    "engripámos": "engripar",
    "engripáramo": "engripar",
    "engripáramos": "engripar",
    "engripárei": "engripar",
    "engripáreis": "engripar",
    "engripásseis": "engripar",
    "engripássemos": "engripar",
    "engripávamo": "engripar",
    "engripávamos": "engripar",
    "engripávei": "engripar",
    "engripáveis": "engripar",
    "engrola": "engrolar",
    "engrolada": "engrolar",
    "engroladas": "engrolar",
    "engrolado": "engrolar",
    "engroladora": "engrolador",
    "engroladoras": "engrolador",
    "engroladores": "engrolador",
    "engrolados": "engrolar",
    "engrolai": "engrolar",
    "engrolais": "engrolar",
    "engrolam": "engrolar",
    "engrolamo": "engrolar",
    "engrolamos": "engrolar",
    "engrolando": "engrolar",
    "engrolara": "engrolar",
    "engrolaram": "engrolar",
    "engrolaras": "engrolar",
    "engrolarde": "engrolar",
    "engrolardes": "engrolar",
    "engrolare": "engrolar",
    "engrolarei": "engrolar",
    "engrolareis": "engrolar",
    "engrolarem": "engrolar",
    "engrolaremos": "engrolar",
    "engrolares": "engrolar",
    "engrolaria": "engrolar",
    "engrolariam": "engrolar",
    "engrolarias": "engrolar",
    "engrolarmo": "engrolar",
    "engrolarmos": "engrolar",
    "engrolará": "engrolar",
    "engrolarás": "engrolar",
    "engrolarão": "engrolar",
    "engrolaríamos": "engrolar",
    "engrolaríeis": "engrolar",
    "engrolas": "engrolar",
    "engrolasse": "engrolar",
    "engrolassem": "engrolar",
    "engrolasses": "engrolar",
    "engrolaste": "engrolar",
    "engrolastes": "engrolar",
    "engrolava": "engrolar",
    "engrolavam": "engrolar",
    "engrolavas": "engrolar",
    "engrole": "engrolar",
    "engrolei": "engrolar",
    "engroleis": "engrolar",
    "engrolem": "engrolar",
    "engrolemo": "engrolar",
    "engrolemos": "engrolar",
    "engroles": "engrolar",
    "engrolo": "engrolar",
    "engrolos": "engrolo",
    "engrolou": "engrolar",
    "engrolá": "engrolar",
    "engrolámo": "engrolar",
    "engrolámos": "engrolar",
    "engroláramo": "engrolar",
    "engroláramos": "engrolar",
    "engrolárei": "engrolar",
    "engroláreis": "engrolar",
    "engrolásseis": "engrolar",
    "engrolássemos": "engrolar",
    "engrolávamo": "engrolar",
    "engrolávamos": "engrolar",
    "engrolávei": "engrolar",
    "engroláveis": "engrolar",
    "engroselhada": "engroselhado",
    "engroselhadas": "engroselhado",
    "engroselhados": "engroselhado",
    "engrossa": "engrossar",
    "engrossada": "engrossar",
    "engrossadas": "engrossar",
    "engrossado": "engrossar",
    "engrossadora": "engrossador",
    "engrossadoras": "engrossador",
    "engrossadores": "engrossador",
    "engrossados": "engrossar",
    "engrossai": "engrossar",
    "engrossais": "engrossar",
    "engrossam": "engrossar",
    "engrossamentos": "engrossamento",
    "engrossamo": "engrossar",
    "engrossamos": "engrossar",
    "engrossando": "engrossar",
    "engrossantes": "engrossante",
    "engrossara": "engrossar",
    "engrossaram": "engrossar",
    "engrossaras": "engrossar",
    "engrossarde": "engrossar",
    "engrossardes": "engrossar",
    "engrossare": "engrossar",
    "engrossarei": "engrossar",
    "engrossareis": "engrossar",
    "engrossarem": "engrossar",
    "engrossaremos": "engrossar",
    "engrossares": "engrossar",
    "engrossaria": "engrossar",
    "engrossariam": "engrossar",
    "engrossarias": "engrossar",
    "engrossarmo": "engrossar",
    "engrossarmos": "engrossar",
    "engrossará": "engrossar",
    "engrossarás": "engrossar",
    "engrossarão": "engrossar",
    "engrossaríamos": "engrossar",
    "engrossaríeis": "engrossar",
    "engrossas": "engrossar",
    "engrossasse": "engrossar",
    "engrossassem": "engrossar",
    "engrossasses": "engrossar",
    "engrossaste": "engrossar",
    "engrossastes": "engrossar",
    "engrossava": "engrossar",
    "engrossavam": "engrossar",
    "engrossavas": "engrossar",
    "engrosse": "engrossar",
    "engrossei": "engrossar",
    "engrosseis": "engrossar",
    "engrossem": "engrossar",
    "engrossemo": "engrossar",
    "engrossemos": "engrossar",
    "engrosses": "engrossar",
    "engrosso": "engrossar",
    "engrossou": "engrossar",
    "engrossá": "engrossar",
    "engrossámo": "engrossar",
    "engrossámos": "engrossar",
    "engrossáramo": "engrossar",
    "engrossáramos": "engrossar",
    "engrossárei": "engrossar",
    "engrossáreis": "engrossar",
    "engrossásseis": "engrossar",
    "engrossássemos": "engrossar",
    "engrossávamo": "engrossar",
    "engrossávamos": "engrossar",
    "engrossávei": "engrossar",
    "engrossáveis": "engrossar",
    "engruma": "engrumar",
    "engrumada": "engrumar",
    "engrumadas": "engrumar",
    "engrumado": "engrumar",
    "engrumados": "engrumar",
    "engrumai": "engrumar",
    "engrumais": "engrumar",
    "engrumam": "engrumar",
    "engrumamo": "engrumar",
    "engrumamos": "engrumar",
    "engrumando": "engrumar",
    "engrumara": "engrumar",
    "engrumaram": "engrumar",
    "engrumaras": "engrumar",
    "engrumardes": "engrumar",
    "engrumarei": "engrumar",
    "engrumareis": "engrumar",
    "engrumarem": "engrumar",
    "engrumaremos": "engrumar",
    "engrumares": "engrumar",
    "engrumaria": "engrumar",
    "engrumariam": "engrumar",
    "engrumarias": "engrumar",
    "engrumarmo": "engrumar",
    "engrumarmos": "engrumar",
    "engrumará": "engrumar",
    "engrumarás": "engrumar",
    "engrumarão": "engrumar",
    "engrumaríamos": "engrumar",
    "engrumaríeis": "engrumar",
    "engrumas": "engrumar",
    "engrumasse": "engrumar",
    "engrumassem": "engrumar",
    "engrumasses": "engrumar",
    "engrumaste": "engrumar",
    "engrumastes": "engrumar",
    "engrumava": "engrumar",
    "engrumavam": "engrumar",
    "engrumavas": "engrumar",
    "engrume": "engrumar",
    "engrumece": "engrumecer",
    "engrumecei": "engrumecer",
    "engrumeceis": "engrumecer",
    "engrumecem": "engrumecer",
    "engrumecemo": "engrumecer",
    "engrumecemos": "engrumecer",
    "engrumecendo": "engrumecer",
    "engrumecera": "engrumecer",
    "engrumeceram": "engrumecer",
    "engrumeceras": "engrumecer",
    "engrumecerdes": "engrumecer",
    "engrumecerei": "engrumecer",
    "engrumecereis": "engrumecer",
    "engrumecerem": "engrumecer",
    "engrumeceremos": "engrumecer",
    "engrumeceres": "engrumecer",
    "engrumeceria": "engrumecer",
    "engrumeceriam": "engrumecer",
    "engrumecerias": "engrumecer",
    "engrumecermo": "engrumecer",
    "engrumecermos": "engrumecer",
    "engrumecerá": "engrumecer",
    "engrumecerás": "engrumecer",
    "engrumecerão": "engrumecer",
    "engrumeceríamos": "engrumecer",
    "engrumeceríeis": "engrumecer",
    "engrumeces": "engrumecer",
    "engrumecesse": "engrumecer",
    "engrumecessem": "engrumecer",
    "engrumecesses": "engrumecer",
    "engrumeceste": "engrumecer",
    "engrumecestes": "engrumecer",
    "engrumeceu": "engrumecer",
    "engrumeci": "engrumecer",
    "engrumecia": "engrumecer",
    "engrumeciam": "engrumecer",
    "engrumecias": "engrumecer",
    "engrumecida": "engrumecer",
    "engrumecidas": "engrumecer",
    "engrumecido": "engrumecer",
    "engrumecidos": "engrumecer",
    "engrumecêramo": "engrumecer",
    "engrumecêramos": "engrumecer",
    "engrumecêreis": "engrumecer",
    "engrumecêsseis": "engrumecer",
    "engrumecêssemos": "engrumecer",
    "engrumecíamo": "engrumecer",
    "engrumecíamos": "engrumecer",
    "engrumecíeis": "engrumecer",
    "engrumei": "engrumar",
    "engrumeis": "engrumar",
    "engrumem": "engrumar",
    "engrumemo": "engrumar",
    "engrumemos": "engrumar",
    "engrumes": "engrumar",
    "engrumeça": "engrumecer",
    "engrumeçais": "engrumecer",
    "engrumeçam": "engrumecer",
    "engrumeçamo": "engrumecer",
    "engrumeçamos": "engrumecer",
    "engrumeças": "engrumecer",
    "engrumeço": "engrumecer",
    "engrumo": "engrumar",
    "engrumou": "engrumar",
    "engrumámo": "engrumar",
    "engrumámos": "engrumar",
    "engrumáramo": "engrumar",
    "engrumáramos": "engrumar",
    "engrumáreis": "engrumar",
    "engrumásseis": "engrumar",
    "engrumássemos": "engrumar",
    "engrumávamo": "engrumar",
    "engrumávamos": "engrumar",
    "engrumáveis": "engrumar",
    "engrunações": "engrunação",
    "engrunha": "engrunhir",
    "engrunhais": "engrunhir",
    "engrunham": "engrunhir",
    "engrunhamo": "engrunhir",
    "engrunhamos": "engrunhir",
    "engrunhas": "engrunhir",
    "engrunhe": "engrunhir",
    "engrunhem": "engrunhir",
    "engrunhes": "engrunhir",
    "engrunhi": "engrunhir",
    "engrunhia": "engrunhir",
    "engrunhiam": "engrunhir",
    "engrunhias": "engrunhir",
    "engrunhida": "engrunhir",
    "engrunhidas": "engrunhir",
    "engrunhido": "engrunhir",
    "engrunhidos": "engrunhir",
    "engrunhimo": "engrunhir",
    "engrunhimos": "engrunhir",
    "engrunhindo": "engrunhir",
    "engrunhira": "engrunhir",
    "engrunhiram": "engrunhir",
    "engrunhiras": "engrunhir",
    "engrunhirdes": "engrunhir",
    "engrunhirei": "engrunhir",
    "engrunhireis": "engrunhir",
    "engrunhirem": "engrunhir",
    "engrunhiremos": "engrunhir",
    "engrunhires": "engrunhir",
    "engrunhiria": "engrunhir",
    "engrunhiriam": "engrunhir",
    "engrunhirias": "engrunhir",
    "engrunhirmo": "engrunhir",
    "engrunhirmos": "engrunhir",
    "engrunhirá": "engrunhir",
    "engrunhirás": "engrunhir",
    "engrunhirão": "engrunhir",
    "engrunhiríamos": "engrunhir",
    "engrunhiríeis": "engrunhir",
    "engrunhis": "engrunhir",
    "engrunhisse": "engrunhir",
    "engrunhissem": "engrunhir",
    "engrunhisses": "engrunhir",
    "engrunhiste": "engrunhir",
    "engrunhistes": "engrunhir",
    "engrunhiu": "engrunhir",
    "engrunho": "engrunhir",
    "engrunhíamo": "engrunhir",
    "engrunhíamos": "engrunhir",
    "engrunhíeis": "engrunhir",
    "engrunhíramo": "engrunhir",
    "engrunhíramos": "engrunhir",
    "engrunhíreis": "engrunhir",
    "engrunhísseis": "engrunhir",
    "engrunhíssemos": "engrunhir",
    "engue": "engar",
    "enguedelha": "enguedelhar",
    "enguedelhada": "enguedelhar",
    "enguedelhadas": "enguedelhar",
    "enguedelhado": "enguedelhar",
    "enguedelhados": "enguedelhar",
    "enguedelhai": "enguedelhar",
    "enguedelhais": "enguedelhar",
    "enguedelham": "enguedelhar",
    "enguedelhamo": "enguedelhar",
    "enguedelhamos": "enguedelhar",
    "enguedelhando": "enguedelhar",
    "enguedelhara": "enguedelhar",
    "enguedelharam": "enguedelhar",
    "enguedelharas": "enguedelhar",
    "enguedelharde": "enguedelhar",
    "enguedelhardes": "enguedelhar",
    "enguedelhare": "enguedelhar",
    "enguedelharei": "enguedelhar",
    "enguedelhareis": "enguedelhar",
    "enguedelharem": "enguedelhar",
    "enguedelharemos": "enguedelhar",
    "enguedelhares": "enguedelhar",
    "enguedelharia": "enguedelhar",
    "enguedelhariam": "enguedelhar",
    "enguedelharias": "enguedelhar",
    "enguedelharmo": "enguedelhar",
    "enguedelharmos": "enguedelhar",
    "enguedelhará": "enguedelhar",
    "enguedelharás": "enguedelhar",
    "enguedelharão": "enguedelhar",
    "enguedelharíamos": "enguedelhar",
    "enguedelharíeis": "enguedelhar",
    "enguedelhas": "enguedelhar",
    "enguedelhasse": "enguedelhar",
    "enguedelhassem": "enguedelhar",
    "enguedelhasses": "enguedelhar",
    "enguedelhaste": "enguedelhar",
    "enguedelhastes": "enguedelhar",
    "enguedelhava": "enguedelhar",
    "enguedelhavam": "enguedelhar",
    "enguedelhavas": "enguedelhar",
    "enguedelhe": "enguedelhar",
    "enguedelhei": "enguedelhar",
    "enguedelheis": "enguedelhar",
    "enguedelhem": "enguedelhar",
    "enguedelhemo": "enguedelhar",
    "enguedelhemos": "enguedelhar",
    "enguedelhes": "enguedelhar",
    "enguedelho": "enguedelhar",
    "enguedelhou": "enguedelhar",
    "enguedelhá": "enguedelhar",
    "enguedelhámo": "enguedelhar",
    "enguedelhámos": "enguedelhar",
    "enguedelháramo": "enguedelhar",
    "enguedelháramos": "enguedelhar",
    "enguedelhárei": "enguedelhar",
    "enguedelháreis": "enguedelhar",
    "enguedelhásseis": "enguedelhar",
    "enguedelhássemos": "enguedelhar",
    "enguedelhávamo": "enguedelhar",
    "enguedelhávamos": "enguedelhar",
    "enguedelhávei": "enguedelhar",
    "enguedelháveis": "enguedelhar",
    "enguei": "engar",
    "engueis": "engar",
    "enguem": "engar",
    "enguemo": "engar",
    "enguemos": "engar",
    "engues": "engar",
    "enguias": "enguia",
    "enguice": "enguiçar",
    "enguicei": "enguiçar",
    "enguiceis": "enguiçar",
    "enguicem": "enguiçar",
    "enguicemo": "enguiçar",
    "enguicemos": "enguiçar",
    "enguices": "enguiçar",
    "enguizalha": "enguizalhar",
    "enguizalhada": "enguizalhar",
    "enguizalhadas": "enguizalhar",
    "enguizalhado": "enguizalhar",
    "enguizalhados": "enguizalhar",
    "enguizalhai": "enguizalhar",
    "enguizalhais": "enguizalhar",
    "enguizalham": "enguizalhar",
    "enguizalhamo": "enguizalhar",
    "enguizalhamos": "enguizalhar",
    "enguizalhando": "enguizalhar",
    "enguizalhara": "enguizalhar",
    "enguizalharam": "enguizalhar",
    "enguizalharas": "enguizalhar",
    "enguizalharde": "enguizalhar",
    "enguizalhardes": "enguizalhar",
    "enguizalhare": "enguizalhar",
    "enguizalharei": "enguizalhar",
    "enguizalhareis": "enguizalhar",
    "enguizalharem": "enguizalhar",
    "enguizalharemos": "enguizalhar",
    "enguizalhares": "enguizalhar",
    "enguizalharia": "enguizalhar",
    "enguizalhariam": "enguizalhar",
    "enguizalharias": "enguizalhar",
    "enguizalharmo": "enguizalhar",
    "enguizalharmos": "enguizalhar",
    "enguizalhará": "enguizalhar",
    "enguizalharás": "enguizalhar",
    "enguizalharão": "enguizalhar",
    "enguizalharíamos": "enguizalhar",
    "enguizalharíeis": "enguizalhar",
    "enguizalhas": "enguizalhar",
    "enguizalhasse": "enguizalhar",
    "enguizalhassem": "enguizalhar",
    "enguizalhasses": "enguizalhar",
    "enguizalhaste": "enguizalhar",
    "enguizalhastes": "enguizalhar",
    "enguizalhava": "enguizalhar",
    "enguizalhavam": "enguizalhar",
    "enguizalhavas": "enguizalhar",
    "enguizalhe": "enguizalhar",
    "enguizalhei": "enguizalhar",
    "enguizalheis": "enguizalhar",
    "enguizalhem": "enguizalhar",
    "enguizalhemo": "enguizalhar",
    "enguizalhemos": "enguizalhar",
    "enguizalhes": "enguizalhar",
    "enguizalho": "enguizalhar",
    "enguizalhou": "enguizalhar",
    "enguizalhá": "enguizalhar",
    "enguizalhámo": "enguizalhar",
    "enguizalhámos": "enguizalhar",
    "enguizalháramo": "enguizalhar",
    "enguizalháramos": "enguizalhar",
    "enguizalhárei": "enguizalhar",
    "enguizalháreis": "enguizalhar",
    "enguizalhásseis": "enguizalhar",
    "enguizalhássemos": "enguizalhar",
    "enguizalhávamo": "enguizalhar",
    "enguizalhávamos": "enguizalhar",
    "enguizalhávei": "enguizalhar",
    "enguizalháveis": "enguizalhar",
    "enguiça": "enguiçar",
    "enguiçada": "enguiçar",
    "enguiçadas": "enguiçar",
    "enguiçado": "enguiçar",
    "enguiçadora": "enguiçador",
    "enguiçadoras": "enguiçador",
    "enguiçadores": "enguiçador",
    "enguiçados": "enguiçar",
    "enguiçai": "enguiçar",
    "enguiçais": "enguiçar",
    "enguiçam": "enguiçar",
    "enguiçamentos": "enguiçamento",
    "enguiçamo": "enguiçar",
    "enguiçamos": "enguiçar",
    "enguiçando": "enguiçar",
    "enguiçara": "enguiçar",
    "enguiçaram": "enguiçar",
    "enguiçaras": "enguiçar",
    "enguiçarde": "enguiçar",
    "enguiçardes": "enguiçar",
    "enguiçare": "enguiçar",
    "enguiçarei": "enguiçar",
    "enguiçareis": "enguiçar",
    "enguiçarem": "enguiçar",
    "enguiçaremos": "enguiçar",
    "enguiçares": "enguiçar",
    "enguiçaria": "enguiçar",
    "enguiçariam": "enguiçar",
    "enguiçarias": "enguiçar",
    "enguiçarmo": "enguiçar",
    "enguiçarmos": "enguiçar",
    "enguiçará": "enguiçar",
    "enguiçarás": "enguiçar",
    "enguiçarão": "enguiçar",
    "enguiçaríamos": "enguiçar",
    "enguiçaríeis": "enguiçar",
    "enguiças": "enguiçar",
    "enguiçasse": "enguiçar",
    "enguiçassem": "enguiçar",
    "enguiçasses": "enguiçar",
    "enguiçaste": "enguiçar",
    "enguiçastes": "enguiçar",
    "enguiçava": "enguiçar",
    "enguiçavam": "enguiçar",
    "enguiçavas": "enguiçar",
    "enguiço": "enguiçar",
    "enguiços": "enguiço",
    "enguiçou": "enguiçar",
    "enguiçá": "enguiçar",
    "enguiçámo": "enguiçar",
    "enguiçámos": "enguiçar",
    "enguiçáramo": "enguiçar",
    "enguiçáramos": "enguiçar",
    "enguiçárei": "enguiçar",
    "enguiçáreis": "enguiçar",
    "enguiçásseis": "enguiçar",
    "enguiçássemos": "enguiçar",
    "enguiçávamo": "enguiçar",
    "enguiçávamos": "enguiçar",
    "enguiçávei": "enguiçar",
    "enguiçáveis": "enguiçar",
    "engula": "engolir",
    "engulais": "engolir",
    "engulam": "engolir",
    "engulamo": "engolir",
    "engulamos": "engolir",
    "engulas": "engolir",
    "engulha": "engulhar",
    "engulhada": "engulhar",
    "engulhadas": "engulhar",
    "engulhado": "engulhar",
    "engulhados": "engulhar",
    "engulhai": "engulhar",
    "engulhais": "engulhar",
    "engulham": "engulhar",
    "engulhamentos": "engulhamento",
    "engulhamo": "engulhar",
    "engulhamos": "engulhar",
    "engulhando": "engulhar",
    "engulhara": "engulhar",
    "engulharam": "engulhar",
    "engulharas": "engulhar",
    "engulharde": "engulhar",
    "engulhardes": "engulhar",
    "engulhare": "engulhar",
    "engulharei": "engulhar",
    "engulhareis": "engulhar",
    "engulharem": "engulhar",
    "engulharemos": "engulhar",
    "engulhares": "engulhar",
    "engulharia": "engulhar",
    "engulhariam": "engulhar",
    "engulharias": "engulhar",
    "engulharmo": "engulhar",
    "engulharmos": "engulhar",
    "engulhará": "engulhar",
    "engulharás": "engulhar",
    "engulharão": "engulhar",
    "engulharíamos": "engulhar",
    "engulharíeis": "engulhar",
    "engulhas": "engulhar",
    "engulhasse": "engulhar",
    "engulhassem": "engulhar",
    "engulhasses": "engulhar",
    "engulhaste": "engulhar",
    "engulhastes": "engulhar",
    "engulhava": "engulhar",
    "engulhavam": "engulhar",
    "engulhavas": "engulhar",
    "engulhe": "engulhar",
    "engulhei": "engulhar",
    "engulheis": "engulhar",
    "engulhem": "engulhar",
    "engulhemo": "engulhar",
    "engulhemos": "engulhar",
    "engulhes": "engulhar",
    "engulho": "engulhar",
    "engulhos": "engulho",
    "engulhosa": "engulhoso",
    "engulhosas": "engulhoso",
    "engulhosos": "engulhoso",
    "engulhou": "engulhar",
    "engulhá": "engulhar",
    "engulhámo": "engulhar",
    "engulhámos": "engulhar",
    "engulháramo": "engulhar",
    "engulháramos": "engulhar",
    "engulhárei": "engulhar",
    "engulháreis": "engulhar",
    "engulhásseis": "engulhar",
    "engulhássemos": "engulhar",
    "engulhávamo": "engulhar",
    "engulhávamos": "engulhar",
    "engulhávei": "engulhar",
    "engulháveis": "engulhar",
    "enguli": "engolir",
    "engulipa": "engulipar",
    "engulipada": "engulipar",
    "engulipadas": "engulipar",
    "engulipado": "engulipar",
    "engulipados": "engulipar",
    "engulipai": "engulipar",
    "engulipais": "engulipar",
    "engulipam": "engulipar",
    "engulipamo": "engulipar",
    "engulipamos": "engulipar",
    "engulipando": "engulipar",
    "engulipara": "engulipar",
    "enguliparam": "engulipar",
    "enguliparas": "engulipar",
    "enguliparde": "engulipar",
    "engulipardes": "engulipar",
    "engulipare": "engulipar",
    "enguliparei": "engulipar",
    "engulipareis": "engulipar",
    "enguliparem": "engulipar",
    "enguliparemos": "engulipar",
    "engulipares": "engulipar",
    "enguliparia": "engulipar",
    "engulipariam": "engulipar",
    "enguliparias": "engulipar",
    "enguliparmo": "engulipar",
    "enguliparmos": "engulipar",
    "engulipará": "engulipar",
    "enguliparás": "engulipar",
    "enguliparão": "engulipar",
    "enguliparíamos": "engulipar",
    "enguliparíeis": "engulipar",
    "engulipas": "engulipar",
    "engulipasse": "engulipar",
    "engulipassem": "engulipar",
    "engulipasses": "engulipar",
    "engulipaste": "engulipar",
    "engulipastes": "engulipar",
    "engulipava": "engulipar",
    "engulipavam": "engulipar",
    "engulipavas": "engulipar",
    "engulipe": "engulipar",
    "engulipei": "engulipar",
    "engulipeis": "engulipar",
    "engulipem": "engulipar",
    "engulipemo": "engulipar",
    "engulipemos": "engulipar",
    "engulipes": "engulipar",
    "engulipo": "engulipar",
    "engulipou": "engulipar",
    "engulipá": "engulipar",
    "engulipámo": "engulipar",
    "engulipámos": "engulipar",
    "engulipáramo": "engulipar",
    "engulipáramos": "engulipar",
    "engulipárei": "engulipar",
    "engulipáreis": "engulipar",
    "engulipásseis": "engulipar",
    "engulipássemos": "engulipar",
    "engulipávamo": "engulipar",
    "engulipávamos": "engulipar",
    "engulipávei": "engulipar",
    "engulipáveis": "engulipar",
    "engulo": "engolir",
    "engulosina": "engulosinar",
    "engulosinada": "engulosinar",
    "engulosinadas": "engulosinar",
    "engulosinado": "engulosinar",
    "engulosinados": "engulosinar",
    "engulosinai": "engulosinar",
    "engulosinais": "engulosinar",
    "engulosinam": "engulosinar",
    "engulosinamo": "engulosinar",
    "engulosinamos": "engulosinar",
    "engulosinando": "engulosinar",
    "engulosinara": "engulosinar",
    "engulosinaram": "engulosinar",
    "engulosinaras": "engulosinar",
    "engulosinarde": "engulosinar",
    "engulosinardes": "engulosinar",
    "engulosinare": "engulosinar",
    "engulosinarei": "engulosinar",
    "engulosinareis": "engulosinar",
    "engulosinarem": "engulosinar",
    "engulosinaremos": "engulosinar",
    "engulosinares": "engulosinar",
    "engulosinaria": "engulosinar",
    "engulosinariam": "engulosinar",
    "engulosinarias": "engulosinar",
    "engulosinarmo": "engulosinar",
    "engulosinarmos": "engulosinar",
    "engulosinará": "engulosinar",
    "engulosinarás": "engulosinar",
    "engulosinarão": "engulosinar",
    "engulosinaríamos": "engulosinar",
    "engulosinaríeis": "engulosinar",
    "engulosinas": "engulosinar",
    "engulosinasse": "engulosinar",
    "engulosinassem": "engulosinar",
    "engulosinasses": "engulosinar",
    "engulosinaste": "engulosinar",
    "engulosinastes": "engulosinar",
    "engulosinava": "engulosinar",
    "engulosinavam": "engulosinar",
    "engulosinavas": "engulosinar",
    "engulosine": "engulosinar",
    "engulosinei": "engulosinar",
    "engulosineis": "engulosinar",
    "engulosinem": "engulosinar",
    "engulosinemo": "engulosinar",
    "engulosinemos": "engulosinar",
    "engulosines": "engulosinar",
    "engulosino": "engulosinar",
    "engulosinou": "engulosinar",
    "engulosiná": "engulosinar",
    "engulosinámo": "engulosinar",
    "engulosinámos": "engulosinar",
    "engulosináramo": "engulosinar",
    "engulosináramos": "engulosinar",
    "engulosinárei": "engulosinar",
    "engulosináreis": "engulosinar",
    "engulosinásseis": "engulosinar",
    "engulosinássemos": "engulosinar",
    "engulosinávamo": "engulosinar",
    "engulosinávamos": "engulosinar",
    "engulosinávei": "engulosinar",
    "engulosináveis": "engulosinar",
    "engunha": "engunhar",
    "engunhada": "engunhar",
    "engunhadas": "engunhar",
    "engunhado": "engunhar",
    "engunhados": "engunhar",
    "engunhai": "engunhar",
    "engunhais": "engunhar",
    "engunham": "engunhar",
    "engunhamo": "engunhar",
    "engunhamos": "engunhar",
    "engunhando": "engunhar",
    "engunhara": "engunhar",
    "engunharam": "engunhar",
    "engunharas": "engunhar",
    "engunhardes": "engunhar",
    "engunharei": "engunhar",
    "engunhareis": "engunhar",
    "engunharem": "engunhar",
    "engunharemos": "engunhar",
    "engunhares": "engunhar",
    "engunharia": "engunhar",
    "engunhariam": "engunhar",
    "engunharias": "engunhar",
    "engunharmo": "engunhar",
    "engunharmos": "engunhar",
    "engunhará": "engunhar",
    "engunharás": "engunhar",
    "engunharão": "engunhar",
    "engunharíamos": "engunhar",
    "engunharíeis": "engunhar",
    "engunhas": "engunhar",
    "engunhasse": "engunhar",
    "engunhassem": "engunhar",
    "engunhasses": "engunhar",
    "engunhaste": "engunhar",
    "engunhastes": "engunhar",
    "engunhava": "engunhar",
    "engunhavam": "engunhar",
    "engunhavas": "engunhar",
    "engunhe": "engunhar",
    "engunhei": "engunhar",
    "engunheis": "engunhar",
    "engunhem": "engunhar",
    "engunhemo": "engunhar",
    "engunhemos": "engunhar",
    "engunhes": "engunhar",
    "engunho": "engunhar",
    "engunhou": "engunhar",
    "engunhámo": "engunhar",
    "engunhámos": "engunhar",
    "engunháramo": "engunhar",
    "engunháramos": "engunhar",
    "engunháreis": "engunhar",
    "engunhásseis": "engunhar",
    "engunhássemos": "engunhar",
    "engunhávamo": "engunhar",
    "engunhávamos": "engunhar",
    "engunháveis": "engunhar",
    "engámo": "engar",
    "engámos": "engar",
    "engáramo": "engar",
    "engáramos": "engar",
    "engáreis": "engar",
    "engásseis": "engar",
    "engássemos": "engar",
    "engávamo": "engar",
    "engávamos": "engar",
    "engáveis": "engar",
    "enhos": "enho",
    "enigma": "enigmar",
    "enigmada": "enigmar",
    "enigmadas": "enigmar",
    "enigmado": "enigmar",
    "enigmados": "enigmar",
    "enigmai": "enigmar",
    "enigmais": "enigmar",
    "enigmam": "enigmar",
    "enigmamo": "enigmar",
    "enigmamos": "enigmar",
    "enigmando": "enigmar",
    "enigmara": "enigmar",
    "enigmaram": "enigmar",
    "enigmaras": "enigmar",
    "enigmarde": "enigmar",
    "enigmardes": "enigmar",
    "enigmare": "enigmar",
    "enigmarei": "enigmar",
    "enigmareis": "enigmar",
    "enigmarem": "enigmar",
    "enigmaremos": "enigmar",
    "enigmares": "enigmar",
    "enigmaria": "enigmar",
    "enigmariam": "enigmar",
    "enigmarias": "enigmar",
    "enigmarmo": "enigmar",
    "enigmarmos": "enigmar",
    "enigmará": "enigmar",
    "enigmarás": "enigmar",
    "enigmarão": "enigmar",
    "enigmaríamos": "enigmar",
    "enigmaríeis": "enigmar",
    "enigmas": "enigmar",
    "enigmasse": "enigmar",
    "enigmassem": "enigmar",
    "enigmasses": "enigmar",
    "enigmaste": "enigmar",
    "enigmastes": "enigmar",
    "enigmatistas": "enigmatista",
    "enigmava": "enigmar",
    "enigmavam": "enigmar",
    "enigmavas": "enigmar",
    "enigme": "enigmar",
    "enigmei": "enigmar",
    "enigmeis": "enigmar",
    "enigmem": "enigmar",
    "enigmemo": "enigmar",
    "enigmemos": "enigmar",
    "enigmes": "enigmar",
    "enigmistas": "enigmista",
    "enigmo": "enigmar",
    "enigmou": "enigmar",
    "enigmá": "enigmar",
    "enigmámo": "enigmar",
    "enigmámos": "enigmar",
    "enigmáramo": "enigmar",
    "enigmáramos": "enigmar",
    "enigmárei": "enigmar",
    "enigmáreis": "enigmar",
    "enigmásseis": "enigmar",
    "enigmássemos": "enigmar",
    "enigmática": "enigmático",
    "enigmáticas": "enigmático",
    "enigmáticos": "enigmático",
    "enigmávamo": "enigmar",
    "enigmávamos": "enigmar",
    "enigmávei": "enigmar",
    "enigmáveis": "enigmar",
    "eniores": "iró",
    "enjambra": "enjambrar",
    "enjambrada": "enjambrar",
    "enjambradas": "enjambrar",
    "enjambrado": "enjambrar",
    "enjambrados": "enjambrar",
    "enjambrai": "enjambrar",
    "enjambrais": "enjambrar",
    "enjambram": "enjambrar",
    "enjambramo": "enjambrar",
    "enjambramos": "enjambrar",
    "enjambrando": "enjambrar",
    "enjambrara": "enjambrar",
    "enjambraram": "enjambrar",
    "enjambraras": "enjambrar",
    "enjambrardes": "enjambrar",
    "enjambrarei": "enjambrar",
    "enjambrareis": "enjambrar",
    "enjambrarem": "enjambrar",
    "enjambraremos": "enjambrar",
    "enjambrares": "enjambrar",
    "enjambraria": "enjambrar",
    "enjambrariam": "enjambrar",
    "enjambrarias": "enjambrar",
    "enjambrarmo": "enjambrar",
    "enjambrarmos": "enjambrar",
    "enjambrará": "enjambrar",
    "enjambrarás": "enjambrar",
    "enjambrarão": "enjambrar",
    "enjambraríamos": "enjambrar",
    "enjambraríeis": "enjambrar",
    "enjambras": "enjambrar",
    "enjambrasse": "enjambrar",
    "enjambrassem": "enjambrar",
    "enjambrasses": "enjambrar",
    "enjambraste": "enjambrar",
    "enjambrastes": "enjambrar",
    "enjambrava": "enjambrar",
    "enjambravam": "enjambrar",
    "enjambravas": "enjambrar",
    "enjambre": "enjambrar",
    "enjambrei": "enjambrar",
    "enjambreis": "enjambrar",
    "enjambrem": "enjambrar",
    "enjambremo": "enjambrar",
    "enjambremos": "enjambrar",
    "enjambres": "enjambrar",
    "enjambro": "enjambrar",
    "enjambrou": "enjambrar",
    "enjambrámo": "enjambrar",
    "enjambrámos": "enjambrar",
    "enjambráramo": "enjambrar",
    "enjambráramos": "enjambrar",
    "enjambráreis": "enjambrar",
    "enjambrásseis": "enjambrar",
    "enjambrássemos": "enjambrar",
    "enjambrávamo": "enjambrar",
    "enjambrávamos": "enjambrar",
    "enjambráveis": "enjambrar",
    "enjanga": "enjangar",
    "enjangada": "enjangar",
    "enjangadas": "enjangar",
    "enjangado": "enjangar",
    "enjangados": "enjangar",
    "enjangai": "enjangar",
    "enjangais": "enjangar",
    "enjangam": "enjangar",
    "enjangamo": "enjangar",
    "enjangamos": "enjangar",
    "enjangando": "enjangar",
    "enjangara": "enjangar",
    "enjangaram": "enjangar",
    "enjangaras": "enjangar",
    "enjangarde": "enjangar",
    "enjangardes": "enjangar",
    "enjangare": "enjangar",
    "enjangarei": "enjangar",
    "enjangareis": "enjangar",
    "enjangarem": "enjangar",
    "enjangaremos": "enjangar",
    "enjangares": "enjangar",
    "enjangaria": "enjangar",
    "enjangariam": "enjangar",
    "enjangarias": "enjangar",
    "enjangarmo": "enjangar",
    "enjangarmos": "enjangar",
    "enjangará": "enjangar",
    "enjangarás": "enjangar",
    "enjangarão": "enjangar",
    "enjangaríamos": "enjangar",
    "enjangaríeis": "enjangar",
    "enjangas": "enjangar",
    "enjangasse": "enjangar",
    "enjangassem": "enjangar",
    "enjangasses": "enjangar",
    "enjangaste": "enjangar",
    "enjangastes": "enjangar",
    "enjangava": "enjangar",
    "enjangavam": "enjangar",
    "enjangavas": "enjangar",
    "enjango": "enjangar",
    "enjangou": "enjangar",
    "enjangue": "enjangar",
    "enjanguei": "enjangar",
    "enjangueis": "enjangar",
    "enjanguem": "enjangar",
    "enjanguemo": "enjangar",
    "enjanguemos": "enjangar",
    "enjangues": "enjangar",
    "enjangá": "enjangar",
    "enjangámo": "enjangar",
    "enjangámos": "enjangar",
    "enjangáramo": "enjangar",
    "enjangáramos": "enjangar",
    "enjangárei": "enjangar",
    "enjangáreis": "enjangar",
    "enjangásseis": "enjangar",
    "enjangássemos": "enjangar",
    "enjangávamo": "enjangar",
    "enjangávamos": "enjangar",
    "enjangávei": "enjangar",
    "enjangáveis": "enjangar",
    "enjaula": "enjaular",
    "enjaulada": "enjaular",
    "enjauladas": "enjaular",
    "enjaulado": "enjaular",
    "enjaulados": "enjaular",
    "enjaulai": "enjaular",
    "enjaulais": "enjaular",
    "enjaulam": "enjaular",
    "enjaulamentos": "enjaulamento",
    "enjaulamo": "enjaular",
    "enjaulamos": "enjaular",
    "enjaulando": "enjaular",
    "enjaulara": "enjaular",
    "enjaularam": "enjaular",
    "enjaularas": "enjaular",
    "enjaularde": "enjaular",
    "enjaulardes": "enjaular",
    "enjaulare": "enjaular",
    "enjaularei": "enjaular",
    "enjaulareis": "enjaular",
    "enjaularem": "enjaular",
    "enjaularemos": "enjaular",
    "enjaulares": "enjaular",
    "enjaularia": "enjaular",
    "enjaulariam": "enjaular",
    "enjaularias": "enjaular",
    "enjaularmo": "enjaular",
    "enjaularmos": "enjaular",
    "enjaulará": "enjaular",
    "enjaularás": "enjaular",
    "enjaularão": "enjaular",
    "enjaularíamos": "enjaular",
    "enjaularíeis": "enjaular",
    "enjaulas": "enjaular",
    "enjaulasse": "enjaular",
    "enjaulassem": "enjaular",
    "enjaulasses": "enjaular",
    "enjaulaste": "enjaular",
    "enjaulastes": "enjaular",
    "enjaulava": "enjaular",
    "enjaulavam": "enjaular",
    "enjaulavas": "enjaular",
    "enjaule": "enjaular",
    "enjaulei": "enjaular",
    "enjauleis": "enjaular",
    "enjaulem": "enjaular",
    "enjaulemo": "enjaular",
    "enjaulemos": "enjaular",
    "enjaules": "enjaular",
    "enjaulo": "enjaular",
    "enjaulou": "enjaular",
    "enjaulá": "enjaular",
    "enjaulámo": "enjaular",
    "enjaulámos": "enjaular",
    "enjauláramo": "enjaular",
    "enjauláramos": "enjaular",
    "enjaulárei": "enjaular",
    "enjauláreis": "enjaular",
    "enjaulásseis": "enjaular",
    "enjaulássemos": "enjaular",
    "enjaulávamo": "enjaular",
    "enjaulávamos": "enjaular",
    "enjaulávei": "enjaular",
    "enjauláveis": "enjaular",
    "enjeira": "enjeirar",
    "enjeirada": "enjeirar",
    "enjeiradas": "enjeirar",
    "enjeirado": "enjeirar",
    "enjeirados": "enjeirar",
    "enjeirai": "enjeirar",
    "enjeirais": "enjeirar",
    "enjeiram": "enjeirar",
    "enjeiramo": "enjeirar",
    "enjeiramos": "enjeirar",
    "enjeirando": "enjeirar",
    "enjeirara": "enjeirar",
    "enjeiraram": "enjeirar",
    "enjeiraras": "enjeirar",
    "enjeirarde": "enjeirar",
    "enjeirardes": "enjeirar",
    "enjeirare": "enjeirar",
    "enjeirarei": "enjeirar",
    "enjeirareis": "enjeirar",
    "enjeirarem": "enjeirar",
    "enjeiraremos": "enjeirar",
    "enjeirares": "enjeirar",
    "enjeiraria": "enjeirar",
    "enjeirariam": "enjeirar",
    "enjeirarias": "enjeirar",
    "enjeirarmo": "enjeirar",
    "enjeirarmos": "enjeirar",
    "enjeirará": "enjeirar",
    "enjeirarás": "enjeirar",
    "enjeirarão": "enjeirar",
    "enjeiraríamos": "enjeirar",
    "enjeiraríeis": "enjeirar",
    "enjeiras": "enjeirar",
    "enjeirasse": "enjeirar",
    "enjeirassem": "enjeirar",
    "enjeirasses": "enjeirar",
    "enjeiraste": "enjeirar",
    "enjeirastes": "enjeirar",
    "enjeirava": "enjeirar",
    "enjeiravam": "enjeirar",
    "enjeiravas": "enjeirar",
    "enjeire": "enjeirar",
    "enjeirei": "enjeirar",
    "enjeireis": "enjeirar",
    "enjeirem": "enjeirar",
    "enjeiremo": "enjeirar",
    "enjeiremos": "enjeirar",
    "enjeires": "enjeirar",
    "enjeiro": "enjeirar",
    "enjeirou": "enjeirar",
    "enjeirá": "enjeirar",
    "enjeirámo": "enjeirar",
    "enjeirámos": "enjeirar",
    "enjeiráramo": "enjeirar",
    "enjeiráramos": "enjeirar",
    "enjeirárei": "enjeirar",
    "enjeiráreis": "enjeirar",
    "enjeirásseis": "enjeirar",
    "enjeirássemos": "enjeirar",
    "enjeirávamo": "enjeirar",
    "enjeirávamos": "enjeirar",
    "enjeirávei": "enjeirar",
    "enjeiráveis": "enjeirar",
    "enjeita": "enjeitar",
    "enjeitada": "enjeitar",
    "enjeitadas": "enjeitar",
    "enjeitado": "enjeitar",
    "enjeitados": "enjeitar",
    "enjeitai": "enjeitar",
    "enjeitais": "enjeitar",
    "enjeitam": "enjeitar",
    "enjeitamentos": "enjeitamento",
    "enjeitamo": "enjeitar",
    "enjeitamos": "enjeitar",
    "enjeitando": "enjeitar",
    "enjeitara": "enjeitar",
    "enjeitaram": "enjeitar",
    "enjeitaras": "enjeitar",
    "enjeitarde": "enjeitar",
    "enjeitardes": "enjeitar",
    "enjeitare": "enjeitar",
    "enjeitarei": "enjeitar",
    "enjeitareis": "enjeitar",
    "enjeitarem": "enjeitar",
    "enjeitaremos": "enjeitar",
    "enjeitares": "enjeitar",
    "enjeitaria": "enjeitar",
    "enjeitariam": "enjeitar",
    "enjeitarias": "enjeitar",
    "enjeitarmo": "enjeitar",
    "enjeitarmos": "enjeitar",
    "enjeitará": "enjeitar",
    "enjeitarás": "enjeitar",
    "enjeitarão": "enjeitar",
    "enjeitaríamos": "enjeitar",
    "enjeitaríeis": "enjeitar",
    "enjeitas": "enjeitar",
    "enjeitasse": "enjeitar",
    "enjeitassem": "enjeitar",
    "enjeitasses": "enjeitar",
    "enjeitaste": "enjeitar",
    "enjeitastes": "enjeitar",
    "enjeitava": "enjeitar",
    "enjeitavam": "enjeitar",
    "enjeitavas": "enjeitar",
    "enjeite": "enjeitar",
    "enjeitei": "enjeitar",
    "enjeiteis": "enjeitar",
    "enjeitem": "enjeitar",
    "enjeitemo": "enjeitar",
    "enjeitemos": "enjeitar",
    "enjeites": "enjeitar",
    "enjeito": "enjeitar",
    "enjeitou": "enjeitar",
    "enjeitá": "enjeitar",
    "enjeitámo": "enjeitar",
    "enjeitámos": "enjeitar",
    "enjeitáramo": "enjeitar",
    "enjeitáramos": "enjeitar",
    "enjeitárei": "enjeitar",
    "enjeitáreis": "enjeitar",
    "enjeitásseis": "enjeitar",
    "enjeitássemos": "enjeitar",
    "enjeitávamo": "enjeitar",
    "enjeitávamos": "enjeitar",
    "enjeitávei": "enjeitar",
    "enjeitáveis": "enjeitar",
    "enjera": "enjerir",
    "enjerais": "enjerir",
    "enjeram": "enjerir",
    "enjeramo": "enjerir",
    "enjeramos": "enjerir",
    "enjeras": "enjerir",
    "enjere": "enjerir",
    "enjerem": "enjerir",
    "enjeres": "enjerir",
    "enjeri": "enjerir",
    "enjeria": "enjerir",
    "enjeriam": "enjerir",
    "enjerias": "enjerir",
    "enjerida": "enjerir",
    "enjeridas": "enjerir",
    "enjerido": "enjerir",
    "enjeridos": "enjerir",
    "enjerimo": "enjerir",
    "enjerimos": "enjerir",
    "enjerindo": "enjerir",
    "enjerira": "enjerir",
    "enjeriram": "enjerir",
    "enjeriras": "enjerir",
    "enjerirde": "enjerir",
    "enjerirdes": "enjerir",
    "enjerire": "enjerir",
    "enjerirei": "enjerir",
    "enjerireis": "enjerir",
    "enjerirem": "enjerir",
    "enjeriremos": "enjerir",
    "enjerires": "enjerir",
    "enjeriria": "enjerir",
    "enjeririam": "enjerir",
    "enjeririas": "enjerir",
    "enjerirmo": "enjerir",
    "enjerirmos": "enjerir",
    "enjerirá": "enjerir",
    "enjerirás": "enjerir",
    "enjerirão": "enjerir",
    "enjeriríamos": "enjerir",
    "enjeriríeis": "enjerir",
    "enjeris": "enjerir",
    "enjerisse": "enjerir",
    "enjerissem": "enjerir",
    "enjerisses": "enjerir",
    "enjeriste": "enjerir",
    "enjeristes": "enjerir",
    "enjeriu": "enjerir",
    "enjero": "enjerir",
    "enjeríamo": "enjerir",
    "enjeríamos": "enjerir",
    "enjeríei": "enjerir",
    "enjeríeis": "enjerir",
    "enjeríramo": "enjerir",
    "enjeríramos": "enjerir",
    "enjerírei": "enjerir",
    "enjeríreis": "enjerir",
    "enjerísseis": "enjerir",
    "enjeríssemos": "enjerir",
    "enjoa": "enjoar",
    "enjoada": "enjoar",
    "enjoadas": "enjoar",
    "enjoadiça": "enjoadiço",
    "enjoadiças": "enjoadiço",
    "enjoadiços": "enjoadiço",
    "enjoado": "enjoar",
    "enjoados": "enjoar",
    "enjoadíssima": "enjoado",
    "enjoadíssimas": "enjoado",
    "enjoadíssimo": "enjoado",
    "enjoadíssimos": "enjoado",
    "enjoai": "enjoar",
    "enjoais": "enjoar",
    "enjoam": "enjoar",
    "enjoamentos": "enjoamento",
    "enjoamo": "enjoar",
    "enjoamos": "enjoar",
    "enjoando": "enjoar",
    "enjoara": "enjoar",
    "enjoaram": "enjoar",
    "enjoaras": "enjoar",
    "enjoarde": "enjoar",
    "enjoardes": "enjoar",
    "enjoare": "enjoar",
    "enjoarei": "enjoar",
    "enjoareis": "enjoar",
    "enjoarem": "enjoar",
    "enjoaremos": "enjoar",
    "enjoares": "enjoar",
    "enjoaria": "enjoar",
    "enjoariam": "enjoar",
    "enjoarias": "enjoar",
    "enjoarmo": "enjoar",
    "enjoarmos": "enjoar",
    "enjoará": "enjoar",
    "enjoarás": "enjoar",
    "enjoarão": "enjoar",
    "enjoaríamos": "enjoar",
    "enjoaríeis": "enjoar",
    "enjoas": "enjoar",
    "enjoasse": "enjoar",
    "enjoassem": "enjoar",
    "enjoasses": "enjoar",
    "enjoaste": "enjoar",
    "enjoastes": "enjoar",
    "enjoativa": "enjoativo",
    "enjoativas": "enjoativo",
    "enjoativos": "enjoativo",
    "enjoava": "enjoar",
    "enjoavam": "enjoar",
    "enjoavas": "enjoar",
    "enjoe": "enjoar",
    "enjoei": "enjoar",
    "enjoeis": "enjoar",
    "enjoem": "enjoar",
    "enjoemo": "enjoar",
    "enjoemos": "enjoar",
    "enjoes": "enjoar",
    "enjoia": "enjoiar",
    "enjoiada": "enjoiar",
    "enjoiadas": "enjoiar",
    "enjoiado": "enjoiar",
    "enjoiados": "enjoiar",
    "enjoiai": "enjoiar",
    "enjoiais": "enjoiar",
    "enjoiam": "enjoiar",
    "enjoiamo": "enjoiar",
    "enjoiamos": "enjoiar",
    "enjoiando": "enjoiar",
    "enjoiara": "enjoiar",
    "enjoiaram": "enjoiar",
    "enjoiaras": "enjoiar",
    "enjoiarde": "enjoiar",
    "enjoiardes": "enjoiar",
    "enjoiare": "enjoiar",
    "enjoiarei": "enjoiar",
    "enjoiareis": "enjoiar",
    "enjoiarem": "enjoiar",
    "enjoiaremos": "enjoiar",
    "enjoiares": "enjoiar",
    "enjoiaria": "enjoiar",
    "enjoiariam": "enjoiar",
    "enjoiarias": "enjoiar",
    "enjoiarmo": "enjoiar",
    "enjoiarmos": "enjoiar",
    "enjoiará": "enjoiar",
    "enjoiarás": "enjoiar",
    "enjoiarão": "enjoiar",
    "enjoiaríamos": "enjoiar",
    "enjoiaríeis": "enjoiar",
    "enjoias": "enjoiar",
    "enjoiasse": "enjoiar",
    "enjoiassem": "enjoiar",
    "enjoiasses": "enjoiar",
    "enjoiaste": "enjoiar",
    "enjoiastes": "enjoiar",
    "enjoiava": "enjoiar",
    "enjoiavam": "enjoiar",
    "enjoiavas": "enjoiar",
    "enjoie": "enjoiar",
    "enjoiei": "enjoiar",
    "enjoieis": "enjoiar",
    "enjoiem": "enjoiar",
    "enjoiemo": "enjoiar",
    "enjoiemos": "enjoiar",
    "enjoies": "enjoiar",
    "enjoio": "enjoiar",
    "enjoiou": "enjoiar",
    "enjoiá": "enjoiar",
    "enjoiámo": "enjoiar",
    "enjoiámos": "enjoiar",
    "enjoiáramo": "enjoiar",
    "enjoiáramos": "enjoiar",
    "enjoiárei": "enjoiar",
    "enjoiáreis": "enjoiar",
    "enjoiásseis": "enjoiar",
    "enjoiássemos": "enjoiar",
    "enjoiávamo": "enjoiar",
    "enjoiávamos": "enjoiar",
    "enjoiávei": "enjoiar",
    "enjoiáveis": "enjoiar",
    "enjoo": "enjoar",
    "enjoos": "enjoo",
    "enjoou": "enjoar",
    "enjoá": "enjoar",
    "enjoámo": "enjoar",
    "enjoámos": "enjoar",
    "enjoáramo": "enjoar",
    "enjoáramos": "enjoar",
    "enjoárei": "enjoar",
    "enjoáreis": "enjoar",
    "enjoásseis": "enjoar",
    "enjoássemos": "enjoar",
    "enjoávamo": "enjoar",
    "enjoávamos": "enjoar",
    "enjoávei": "enjoar",
    "enjoáveis": "enjoar",
    "enjuga": "enjugar",
    "enjugada": "enjugar",
    "enjugadas": "enjugar",
    "enjugado": "enjugar",
    "enjugados": "enjugar",
    "enjugai": "enjugar",
    "enjugais": "enjugar",
    "enjugam": "enjugar",
    "enjugamentos": "enjugamento",
    "enjugamo": "enjugar",
    "enjugamos": "enjugar",
    "enjugando": "enjugar",
    "enjugara": "enjugar",
    "enjugaram": "enjugar",
    "enjugaras": "enjugar",
    "enjugarde": "enjugar",
    "enjugardes": "enjugar",
    "enjugare": "enjugar",
    "enjugarei": "enjugar",
    "enjugareis": "enjugar",
    "enjugarem": "enjugar",
    "enjugaremos": "enjugar",
    "enjugares": "enjugar",
    "enjugaria": "enjugar",
    "enjugariam": "enjugar",
    "enjugarias": "enjugar",
    "enjugarmo": "enjugar",
    "enjugarmos": "enjugar",
    "enjugará": "enjugar",
    "enjugarás": "enjugar",
    "enjugarão": "enjugar",
    "enjugaríamos": "enjugar",
    "enjugaríeis": "enjugar",
    "enjugas": "enjugar",
    "enjugasse": "enjugar",
    "enjugassem": "enjugar",
    "enjugasses": "enjugar",
    "enjugaste": "enjugar",
    "enjugastes": "enjugar",
    "enjugava": "enjugar",
    "enjugavam": "enjugar",
    "enjugavas": "enjugar",
    "enjugo": "enjugar",
    "enjugou": "enjugar",
    "enjugue": "enjugar",
    "enjuguei": "enjugar",
    "enjugueis": "enjugar",
    "enjuguem": "enjugar",
    "enjuguemo": "enjugar",
    "enjuguemos": "enjugar",
    "enjugues": "enjugar",
    "enjugá": "enjugar",
    "enjugámo": "enjugar",
    "enjugámos": "enjugar",
    "enjugáramo": "enjugar",
    "enjugáramos": "enjugar",
    "enjugárei": "enjugar",
    "enjugáreis": "enjugar",
    "enjugásseis": "enjugar",
    "enjugássemos": "enjugar",
    "enjugávamo": "enjugar",
    "enjugávamos": "enjugar",
    "enjugávei": "enjugar",
    "enjugáveis": "enjugar",
    "enlace": "enlaçar",
    "enlacei": "enlaçar",
    "enlaceis": "enlaçar",
    "enlacem": "enlaçar",
    "enlacemo": "enlaçar",
    "enlacemos": "enlaçar",
    "enlaces": "enlace",
    "enladeirada": "enladeirado",
    "enladeiradas": "enladeirado",
    "enladeirados": "enladeirado",
    "enlaga": "enlagar",
    "enlagada": "enlagar",
    "enlagadas": "enlagar",
    "enlagado": "enlagar",
    "enlagados": "enlagar",
    "enlagai": "enlagar",
    "enlagais": "enlagar",
    "enlagam": "enlagar",
    "enlagamo": "enlagar",
    "enlagamos": "enlagar",
    "enlagando": "enlagar",
    "enlagara": "enlagar",
    "enlagaram": "enlagar",
    "enlagaras": "enlagar",
    "enlagarde": "enlagar",
    "enlagardes": "enlagar",
    "enlagare": "enlagar",
    "enlagarei": "enlagar",
    "enlagareis": "enlagar",
    "enlagarem": "enlagar",
    "enlagaremos": "enlagar",
    "enlagares": "enlagar",
    "enlagaria": "enlagar",
    "enlagariam": "enlagar",
    "enlagarias": "enlagar",
    "enlagarmo": "enlagar",
    "enlagarmos": "enlagar",
    "enlagará": "enlagar",
    "enlagarás": "enlagar",
    "enlagarão": "enlagar",
    "enlagaríamos": "enlagar",
    "enlagaríeis": "enlagar",
    "enlagas": "enlagar",
    "enlagasse": "enlagar",
    "enlagassem": "enlagar",
    "enlagasses": "enlagar",
    "enlagaste": "enlagar",
    "enlagastes": "enlagar",
    "enlagava": "enlagar",
    "enlagavam": "enlagar",
    "enlagavas": "enlagar",
    "enlago": "enlagar",
    "enlagou": "enlagar",
    "enlague": "enlagar",
    "enlaguei": "enlagar",
    "enlagueis": "enlagar",
    "enlaguem": "enlagar",
    "enlaguemo": "enlagar",
    "enlaguemos": "enlagar",
    "enlagues": "enlagar",
    "enlagá": "enlagar",
    "enlagámo": "enlagar",
    "enlagámos": "enlagar",
    "enlagáramo": "enlagar",
    "enlagáramos": "enlagar",
    "enlagárei": "enlagar",
    "enlagáreis": "enlagar",
    "enlagásseis": "enlagar",
    "enlagássemos": "enlagar",
    "enlagávamo": "enlagar",
    "enlagávamos": "enlagar",
    "enlagávei": "enlagar",
    "enlagáveis": "enlagar",
    "enlaiva": "enlaivar",
    "enlaivada": "enlaivar",
    "enlaivadas": "enlaivar",
    "enlaivado": "enlaivar",
    "enlaivados": "enlaivar",
    "enlaivai": "enlaivar",
    "enlaivais": "enlaivar",
    "enlaivam": "enlaivar",
    "enlaivamo": "enlaivar",
    "enlaivamos": "enlaivar",
    "enlaivando": "enlaivar",
    "enlaivara": "enlaivar",
    "enlaivaram": "enlaivar",
    "enlaivaras": "enlaivar",
    "enlaivarde": "enlaivar",
    "enlaivardes": "enlaivar",
    "enlaivare": "enlaivar",
    "enlaivarei": "enlaivar",
    "enlaivareis": "enlaivar",
    "enlaivarem": "enlaivar",
    "enlaivaremos": "enlaivar",
    "enlaivares": "enlaivar",
    "enlaivaria": "enlaivar",
    "enlaivariam": "enlaivar",
    "enlaivarias": "enlaivar",
    "enlaivarmo": "enlaivar",
    "enlaivarmos": "enlaivar",
    "enlaivará": "enlaivar",
    "enlaivarás": "enlaivar",
    "enlaivarão": "enlaivar",
    "enlaivaríamos": "enlaivar",
    "enlaivaríeis": "enlaivar",
    "enlaivas": "enlaivar",
    "enlaivasse": "enlaivar",
    "enlaivassem": "enlaivar",
    "enlaivasses": "enlaivar",
    "enlaivaste": "enlaivar",
    "enlaivastes": "enlaivar",
    "enlaivava": "enlaivar",
    "enlaivavam": "enlaivar",
    "enlaivavas": "enlaivar",
    "enlaive": "enlaivar",
    "enlaivei": "enlaivar",
    "enlaiveis": "enlaivar",
    "enlaivem": "enlaivar",
    "enlaivemo": "enlaivar",
    "enlaivemos": "enlaivar",
    "enlaives": "enlaivar",
    "enlaivo": "enlaivar",
    "enlaivou": "enlaivar",
    "enlaivá": "enlaivar",
    "enlaivámo": "enlaivar",
    "enlaivámos": "enlaivar",
    "enlaiváramo": "enlaivar",
    "enlaiváramos": "enlaivar",
    "enlaivárei": "enlaivar",
    "enlaiváreis": "enlaivar",
    "enlaivásseis": "enlaivar",
    "enlaivássemos": "enlaivar",
    "enlaivávamo": "enlaivar",
    "enlaivávamos": "enlaivar",
    "enlaivávei": "enlaivar",
    "enlaiváveis": "enlaivar",
    "enlambuja": "enlambujar",
    "enlambujada": "enlambujar",
    "enlambujadas": "enlambujar",
    "enlambujado": "enlambujar",
    "enlambujados": "enlambujar",
    "enlambujai": "enlambujar",
    "enlambujais": "enlambujar",
    "enlambujam": "enlambujar",
    "enlambujamo": "enlambujar",
    "enlambujamos": "enlambujar",
    "enlambujando": "enlambujar",
    "enlambujara": "enlambujar",
    "enlambujaram": "enlambujar",
    "enlambujaras": "enlambujar",
    "enlambujarde": "enlambujar",
    "enlambujardes": "enlambujar",
    "enlambujare": "enlambujar",
    "enlambujarei": "enlambujar",
    "enlambujareis": "enlambujar",
    "enlambujarem": "enlambujar",
    "enlambujaremos": "enlambujar",
    "enlambujares": "enlambujar",
    "enlambujaria": "enlambujar",
    "enlambujariam": "enlambujar",
    "enlambujarias": "enlambujar",
    "enlambujarmo": "enlambujar",
    "enlambujarmos": "enlambujar",
    "enlambujará": "enlambujar",
    "enlambujarás": "enlambujar",
    "enlambujarão": "enlambujar",
    "enlambujaríamos": "enlambujar",
    "enlambujaríeis": "enlambujar",
    "enlambujas": "enlambujar",
    "enlambujasse": "enlambujar",
    "enlambujassem": "enlambujar",
    "enlambujasses": "enlambujar",
    "enlambujaste": "enlambujar",
    "enlambujastes": "enlambujar",
    "enlambujava": "enlambujar",
    "enlambujavam": "enlambujar",
    "enlambujavas": "enlambujar",
    "enlambuje": "enlambujar",
    "enlambujei": "enlambujar",
    "enlambujeis": "enlambujar",
    "enlambujem": "enlambujar",
    "enlambujemo": "enlambujar",
    "enlambujemos": "enlambujar",
    "enlambujes": "enlambujar",
    "enlambujo": "enlambujar",
    "enlambujou": "enlambujar",
    "enlambujá": "enlambujar",
    "enlambujámo": "enlambujar",
    "enlambujámos": "enlambujar",
    "enlambujáramo": "enlambujar",
    "enlambujáramos": "enlambujar",
    "enlambujárei": "enlambujar",
    "enlambujáreis": "enlambujar",
    "enlambujásseis": "enlambujar",
    "enlambujássemos": "enlambujar",
    "enlambujávamo": "enlambujar",
    "enlambujávamos": "enlambujar",
    "enlambujávei": "enlambujar",
    "enlambujáveis": "enlambujar",
    "enlambuza": "enlambuzar",
    "enlambuzada": "enlambuzar",
    "enlambuzadas": "enlambuzar",
    "enlambuzadelas": "enlambuzadela",
    "enlambuzado": "enlambuzar",
    "enlambuzados": "enlambuzar",
    "enlambuzai": "enlambuzar",
    "enlambuzais": "enlambuzar",
    "enlambuzam": "enlambuzar",
    "enlambuzamo": "enlambuzar",
    "enlambuzamos": "enlambuzar",
    "enlambuzando": "enlambuzar",
    "enlambuzara": "enlambuzar",
    "enlambuzaram": "enlambuzar",
    "enlambuzaras": "enlambuzar",
    "enlambuzarde": "enlambuzar",
    "enlambuzardes": "enlambuzar",
    "enlambuzare": "enlambuzar",
    "enlambuzarei": "enlambuzar",
    "enlambuzareis": "enlambuzar",
    "enlambuzarem": "enlambuzar",
    "enlambuzaremos": "enlambuzar",
    "enlambuzares": "enlambuzar",
    "enlambuzaria": "enlambuzar",
    "enlambuzariam": "enlambuzar",
    "enlambuzarias": "enlambuzar",
    "enlambuzarmo": "enlambuzar",
    "enlambuzarmos": "enlambuzar",
    "enlambuzará": "enlambuzar",
    "enlambuzarás": "enlambuzar",
    "enlambuzarão": "enlambuzar",
    "enlambuzaríamos": "enlambuzar",
    "enlambuzaríeis": "enlambuzar",
    "enlambuzas": "enlambuzar",
    "enlambuzasse": "enlambuzar",
    "enlambuzassem": "enlambuzar",
    "enlambuzasses": "enlambuzar",
    "enlambuzaste": "enlambuzar",
    "enlambuzastes": "enlambuzar",
    "enlambuzava": "enlambuzar",
    "enlambuzavam": "enlambuzar",
    "enlambuzavas": "enlambuzar",
    "enlambuze": "enlambuzar",
    "enlambuzei": "enlambuzar",
    "enlambuzeis": "enlambuzar",
    "enlambuzem": "enlambuzar",
    "enlambuzemo": "enlambuzar",
    "enlambuzemos": "enlambuzar",
    "enlambuzes": "enlambuzar",
    "enlambuzo": "enlambuzar",
    "enlambuzou": "enlambuzar",
    "enlambuzá": "enlambuzar",
    "enlambuzámo": "enlambuzar",
    "enlambuzámos": "enlambuzar",
    "enlambuzáramo": "enlambuzar",
    "enlambuzáramos": "enlambuzar",
    "enlambuzárei": "enlambuzar",
    "enlambuzáreis": "enlambuzar",
    "enlambuzásseis": "enlambuzar",
    "enlambuzássemos": "enlambuzar",
    "enlambuzávamo": "enlambuzar",
    "enlambuzávamos": "enlambuzar",
    "enlambuzávei": "enlambuzar",
    "enlambuzáveis": "enlambuzar",
    "enlameada": "enlamear",
    "enlameadas": "enlamear",
    "enlameado": "enlamear",
    "enlameados": "enlamear",
    "enlameaduras": "enlameadura",
    "enlameai": "enlamear",
    "enlameais": "enlamear",
    "enlameamo": "enlamear",
    "enlameamos": "enlamear",
    "enlameando": "enlamear",
    "enlameara": "enlamear",
    "enlamearam": "enlamear",
    "enlamearas": "enlamear",
    "enlamearde": "enlamear",
    "enlameardes": "enlamear",
    "enlameare": "enlamear",
    "enlamearei": "enlamear",
    "enlameareis": "enlamear",
    "enlamearem": "enlamear",
    "enlamearemos": "enlamear",
    "enlameares": "enlamear",
    "enlamearia": "enlamear",
    "enlameariam": "enlamear",
    "enlamearias": "enlamear",
    "enlamearmo": "enlamear",
    "enlamearmos": "enlamear",
    "enlameará": "enlamear",
    "enlamearás": "enlamear",
    "enlamearão": "enlamear",
    "enlamearíamos": "enlamear",
    "enlamearíeis": "enlamear",
    "enlameasse": "enlamear",
    "enlameassem": "enlamear",
    "enlameasses": "enlamear",
    "enlameaste": "enlamear",
    "enlameastes": "enlamear",
    "enlameava": "enlamear",
    "enlameavam": "enlamear",
    "enlameavas": "enlamear",
    "enlameei": "enlamear",
    "enlameeis": "enlamear",
    "enlameemo": "enlamear",
    "enlameemos": "enlamear",
    "enlameia": "enlamear",
    "enlameiam": "enlamear",
    "enlameias": "enlamear",
    "enlameie": "enlamear",
    "enlameiem": "enlamear",
    "enlameies": "enlamear",
    "enlameio": "enlamear",
    "enlameou": "enlamear",
    "enlameá": "enlamear",
    "enlameámo": "enlamear",
    "enlameámos": "enlamear",
    "enlameáramo": "enlamear",
    "enlameáramos": "enlamear",
    "enlameárei": "enlamear",
    "enlameáreis": "enlamear",
    "enlameásseis": "enlamear",
    "enlameássemos": "enlamear",
    "enlameávamo": "enlamear",
    "enlameávamos": "enlamear",
    "enlameávei": "enlamear",
    "enlameáveis": "enlamear",
    "enlamina": "enlaminar",
    "enlaminada": "enlaminar",
    "enlaminadas": "enlaminar",
    "enlaminado": "enlaminar",
    "enlaminados": "enlaminar",
    "enlaminai": "enlaminar",
    "enlaminais": "enlaminar",
    "enlaminam": "enlaminar",
    "enlaminamo": "enlaminar",
    "enlaminamos": "enlaminar",
    "enlaminando": "enlaminar",
    "enlaminara": "enlaminar",
    "enlaminaram": "enlaminar",
    "enlaminaras": "enlaminar",
    "enlaminarde": "enlaminar",
    "enlaminardes": "enlaminar",
    "enlaminare": "enlaminar",
    "enlaminarei": "enlaminar",
    "enlaminareis": "enlaminar",
    "enlaminarem": "enlaminar",
    "enlaminaremos": "enlaminar",
    "enlaminares": "enlaminar",
    "enlaminaria": "enlaminar",
    "enlaminariam": "enlaminar",
    "enlaminarias": "enlaminar",
    "enlaminarmo": "enlaminar",
    "enlaminarmos": "enlaminar",
    "enlaminará": "enlaminar",
    "enlaminarás": "enlaminar",
    "enlaminarão": "enlaminar",
    "enlaminaríamos": "enlaminar",
    "enlaminaríeis": "enlaminar",
    "enlaminas": "enlaminar",
    "enlaminasse": "enlaminar",
    "enlaminassem": "enlaminar",
    "enlaminasses": "enlaminar",
    "enlaminaste": "enlaminar",
    "enlaminastes": "enlaminar",
    "enlaminava": "enlaminar",
    "enlaminavam": "enlaminar",
    "enlaminavas": "enlaminar",
    "enlamine": "enlaminar",
    "enlaminei": "enlaminar",
    "enlamineis": "enlaminar",
    "enlaminem": "enlaminar",
    "enlaminemo": "enlaminar",
    "enlaminemos": "enlaminar",
    "enlamines": "enlaminar",
    "enlamino": "enlaminar",
    "enlaminou": "enlaminar",
    "enlaminá": "enlaminar",
    "enlaminámo": "enlaminar",
    "enlaminámos": "enlaminar",
    "enlamináramo": "enlaminar",
    "enlamináramos": "enlaminar",
    "enlaminárei": "enlaminar",
    "enlamináreis": "enlaminar",
    "enlaminásseis": "enlaminar",
    "enlaminássemos": "enlaminar",
    "enlaminávamo": "enlaminar",
    "enlaminávamos": "enlaminar",
    "enlaminávei": "enlaminar",
    "enlamináveis": "enlaminar",
    "enlanguesce": "enlanguescer",
    "enlanguescei": "enlanguescer",
    "enlanguesceis": "enlanguescer",
    "enlanguescem": "enlanguescer",
    "enlanguescemo": "enlanguescer",
    "enlanguescemos": "enlanguescer",
    "enlanguescendo": "enlanguescer",
    "enlanguescentes": "enlanguescente",
    "enlanguescera": "enlanguescer",
    "enlanguesceram": "enlanguescer",
    "enlanguesceras": "enlanguescer",
    "enlanguescerdes": "enlanguescer",
    "enlanguescerei": "enlanguescer",
    "enlanguescereis": "enlanguescer",
    "enlanguescerem": "enlanguescer",
    "enlanguesceremos": "enlanguescer",
    "enlanguesceres": "enlanguescer",
    "enlanguesceria": "enlanguescer",
    "enlanguesceriam": "enlanguescer",
    "enlanguescerias": "enlanguescer",
    "enlanguescermo": "enlanguescer",
    "enlanguescermos": "enlanguescer",
    "enlanguescerá": "enlanguescer",
    "enlanguescerás": "enlanguescer",
    "enlanguescerão": "enlanguescer",
    "enlanguesceríamos": "enlanguescer",
    "enlanguesceríeis": "enlanguescer",
    "enlanguesces": "enlanguescer",
    "enlanguescesse": "enlanguescer",
    "enlanguescessem": "enlanguescer",
    "enlanguescesses": "enlanguescer",
    "enlanguesceste": "enlanguescer",
    "enlanguescestes": "enlanguescer",
    "enlanguesceu": "enlanguescer",
    "enlanguesci": "enlanguescer",
    "enlanguescia": "enlanguescer",
    "enlanguesciam": "enlanguescer",
    "enlanguescias": "enlanguescer",
    "enlanguescida": "enlanguescido",
    "enlanguescidas": "enlanguescido",
    "enlanguescido": "enlanguescer",
    "enlanguescidos": "enlanguescido",
    "enlanguescências": "enlanguescência",
    "enlanguescêramo": "enlanguescer",
    "enlanguescêramos": "enlanguescer",
    "enlanguescêreis": "enlanguescer",
    "enlanguescêsseis": "enlanguescer",
    "enlanguescêssemos": "enlanguescer",
    "enlanguescíamo": "enlanguescer",
    "enlanguescíamos": "enlanguescer",
    "enlanguescíeis": "enlanguescer",
    "enlanguesça": "enlanguescer",
    "enlanguesçais": "enlanguescer",
    "enlanguesçam": "enlanguescer",
    "enlanguesçamo": "enlanguescer",
    "enlanguesçamos": "enlanguescer",
    "enlanguesças": "enlanguescer",
    "enlanguesço": "enlanguescer",
    "enlapa": "enlapar",
    "enlapada": "enlapar",
    "enlapadas": "enlapar",
    "enlapado": "enlapar",
    "enlapados": "enlapar",
    "enlapai": "enlapar",
    "enlapais": "enlapar",
    "enlapam": "enlapar",
    "enlapamo": "enlapar",
    "enlapamos": "enlapar",
    "enlapando": "enlapar",
    "enlapara": "enlapar",
    "enlaparam": "enlapar",
    "enlaparas": "enlapar",
    "enlaparde": "enlapar",
    "enlapardes": "enlapar",
    "enlapare": "enlapar",
    "enlaparei": "enlapar",
    "enlapareis": "enlapar",
    "enlaparem": "enlapar",
    "enlaparemos": "enlapar",
    "enlapares": "enlapar",
    "enlaparia": "enlapar",
    "enlapariam": "enlapar",
    "enlaparias": "enlapar",
    "enlaparmo": "enlapar",
    "enlaparmos": "enlapar",
    "enlapará": "enlapar",
    "enlaparás": "enlapar",
    "enlaparão": "enlapar",
    "enlaparíamos": "enlapar",
    "enlaparíeis": "enlapar",
    "enlapas": "enlapar",
    "enlapasse": "enlapar",
    "enlapassem": "enlapar",
    "enlapasses": "enlapar",
    "enlapaste": "enlapar",
    "enlapastes": "enlapar",
    "enlapava": "enlapar",
    "enlapavam": "enlapar",
    "enlapavas": "enlapar",
    "enlape": "enlapar",
    "enlapei": "enlapar",
    "enlapeis": "enlapar",
    "enlapem": "enlapar",
    "enlapemo": "enlapar",
    "enlapemos": "enlapar",
    "enlapes": "enlapar",
    "enlapo": "enlapar",
    "enlapou": "enlapar",
    "enlapá": "enlapar",
    "enlapámo": "enlapar",
    "enlapámos": "enlapar",
    "enlapáramo": "enlapar",
    "enlapáramos": "enlapar",
    "enlapárei": "enlapar",
    "enlapáreis": "enlapar",
    "enlapásseis": "enlapar",
    "enlapássemos": "enlapar",
    "enlapávamo": "enlapar",
    "enlapávamos": "enlapar",
    "enlapávei": "enlapar",
    "enlapáveis": "enlapar",
    "enlata": "enlatar",
    "enlatada": "enlatar",
    "enlatadas": "enlatar",
    "enlatado": "enlatar",
    "enlatados": "enlatar",
    "enlatai": "enlatar",
    "enlatais": "enlatar",
    "enlatam": "enlatar",
    "enlatamentos": "enlatamento",
    "enlatamo": "enlatar",
    "enlatamos": "enlatar",
    "enlatando": "enlatar",
    "enlatara": "enlatar",
    "enlataram": "enlatar",
    "enlataras": "enlatar",
    "enlatarde": "enlatar",
    "enlatardes": "enlatar",
    "enlatare": "enlatar",
    "enlatarei": "enlatar",
    "enlatareis": "enlatar",
    "enlatarem": "enlatar",
    "enlataremos": "enlatar",
    "enlatares": "enlatar",
    "enlataria": "enlatar",
    "enlatariam": "enlatar",
    "enlatarias": "enlatar",
    "enlatarmo": "enlatar",
    "enlatarmos": "enlatar",
    "enlatará": "enlatar",
    "enlatarás": "enlatar",
    "enlatarão": "enlatar",
    "enlataríamos": "enlatar",
    "enlataríeis": "enlatar",
    "enlatas": "enlatar",
    "enlatasse": "enlatar",
    "enlatassem": "enlatar",
    "enlatasses": "enlatar",
    "enlataste": "enlatar",
    "enlatastes": "enlatar",
    "enlatava": "enlatar",
    "enlatavam": "enlatar",
    "enlatavas": "enlatar",
    "enlate": "enlatar",
    "enlatei": "enlatar",
    "enlateis": "enlatar",
    "enlatem": "enlatar",
    "enlatemo": "enlatar",
    "enlatemos": "enlatar",
    "enlates": "enlatar",
    "enlato": "enlatar",
    "enlatou": "enlatar",
    "enlatá": "enlatar",
    "enlatámo": "enlatar",
    "enlatámos": "enlatar",
    "enlatáramo": "enlatar",
    "enlatáramos": "enlatar",
    "enlatárei": "enlatar",
    "enlatáreis": "enlatar",
    "enlatásseis": "enlatar",
    "enlatássemos": "enlatar",
    "enlatávamo": "enlatar",
    "enlatávamos": "enlatar",
    "enlatávei": "enlatar",
    "enlatáveis": "enlatar",
    "enlaça": "enlaçar",
    "enlaçada": "enlaçar",
    "enlaçadas": "enlaçar",
    "enlaçado": "enlaçar",
    "enlaçados": "enlaçar",
    "enlaçaduras": "enlaçadura",
    "enlaçadíssima": "enlaçado",
    "enlaçadíssimas": "enlaçado",
    "enlaçadíssimo": "enlaçado",
    "enlaçadíssimos": "enlaçado",
    "enlaçai": "enlaçar",
    "enlaçais": "enlaçar",
    "enlaçam": "enlaçar",
    "enlaçamentos": "enlaçamento",
    "enlaçamo": "enlaçar",
    "enlaçamos": "enlaçar",
    "enlaçando": "enlaçar",
    "enlaçara": "enlaçar",
    "enlaçaram": "enlaçar",
    "enlaçaras": "enlaçar",
    "enlaçarde": "enlaçar",
    "enlaçardes": "enlaçar",
    "enlaçare": "enlaçar",
    "enlaçarei": "enlaçar",
    "enlaçareis": "enlaçar",
    "enlaçarem": "enlaçar",
    "enlaçaremos": "enlaçar",
    "enlaçares": "enlaçar",
    "enlaçaria": "enlaçar",
    "enlaçariam": "enlaçar",
    "enlaçarias": "enlaçar",
    "enlaçarmo": "enlaçar",
    "enlaçarmos": "enlaçar",
    "enlaçará": "enlaçar",
    "enlaçarás": "enlaçar",
    "enlaçarão": "enlaçar",
    "enlaçaríamos": "enlaçar",
    "enlaçaríeis": "enlaçar",
    "enlaças": "enlaçar",
    "enlaçasse": "enlaçar",
    "enlaçassem": "enlaçar",
    "enlaçasses": "enlaçar",
    "enlaçaste": "enlaçar",
    "enlaçastes": "enlaçar",
    "enlaçava": "enlaçar",
    "enlaçavam": "enlaçar",
    "enlaçavas": "enlaçar",
    "enlaço": "enlaçar",
    "enlaçou": "enlaçar",
    "enlaçá": "enlaçar",
    "enlaçámo": "enlaçar",
    "enlaçámos": "enlaçar",
    "enlaçáramo": "enlaçar",
    "enlaçáramos": "enlaçar",
    "enlaçárei": "enlaçar",
    "enlaçáreis": "enlaçar",
    "enlaçásseis": "enlaçar",
    "enlaçássemos": "enlaçar",
    "enlaçávamo": "enlaçar",
    "enlaçávamos": "enlaçar",
    "enlaçávei": "enlaçar",
    "enlaçáveis": "enlaçar",
    "enleada": "enlear",
    "enleadas": "enlear",
    "enleadeira": "enleador",
    "enleadeiras": "enleador",
    "enleado": "enlear",
    "enleadora": "enleador",
    "enleadoras": "enleador",
    "enleadores": "enleador",
    "enleados": "enlear",
    "enleadíssima": "enleado",
    "enleadíssimas": "enleado",
    "enleadíssimo": "enleado",
    "enleadíssimos": "enleado",
    "enleai": "enlear",
    "enleais": "enlear",
    "enleamentos": "enleamento",
    "enleamo": "enlear",
    "enleamos": "enlear",
    "enleando": "enlear",
    "enleantes": "enleante",
    "enleara": "enlear",
    "enlearam": "enlear",
    "enlearas": "enlear",
    "enlearde": "enlear",
    "enleardes": "enlear",
    "enleare": "enlear",
    "enlearei": "enlear",
    "enleareis": "enlear",
    "enlearem": "enlear",
    "enlearemos": "enlear",
    "enleares": "enlear",
    "enlearia": "enlear",
    "enleariam": "enlear",
    "enlearias": "enlear",
    "enlearmo": "enlear",
    "enlearmos": "enlear",
    "enleará": "enlear",
    "enlearás": "enlear",
    "enlearão": "enlear",
    "enlearíamos": "enlear",
    "enlearíeis": "enlear",
    "enleasse": "enlear",
    "enleassem": "enlear",
    "enleasses": "enlear",
    "enleaste": "enlear",
    "enleastes": "enlear",
    "enleava": "enlear",
    "enleavam": "enlear",
    "enleavas": "enlear",
    "enleei": "enlear",
    "enleeis": "enlear",
    "enleemo": "enlear",
    "enleemos": "enlear",
    "enleia": "enlear",
    "enleiam": "enlear",
    "enleias": "enleia",
    "enleie": "enlear",
    "enleiem": "enlear",
    "enleies": "enlear",
    "enleio": "enlear",
    "enleios": "enleio",
    "enleita": "enleitar",
    "enleitada": "enleitar",
    "enleitadas": "enleitar",
    "enleitado": "enleitar",
    "enleitados": "enleitar",
    "enleitai": "enleitar",
    "enleitais": "enleitar",
    "enleitam": "enleitar",
    "enleitamo": "enleitar",
    "enleitamos": "enleitar",
    "enleitando": "enleitar",
    "enleitara": "enleitar",
    "enleitaram": "enleitar",
    "enleitaras": "enleitar",
    "enleitarde": "enleitar",
    "enleitardes": "enleitar",
    "enleitare": "enleitar",
    "enleitarei": "enleitar",
    "enleitareis": "enleitar",
    "enleitarem": "enleitar",
    "enleitaremos": "enleitar",
    "enleitares": "enleitar",
    "enleitaria": "enleitar",
    "enleitariam": "enleitar",
    "enleitarias": "enleitar",
    "enleitarmo": "enleitar",
    "enleitarmos": "enleitar",
    "enleitará": "enleitar",
    "enleitarás": "enleitar",
    "enleitarão": "enleitar",
    "enleitaríamos": "enleitar",
    "enleitaríeis": "enleitar",
    "enleitas": "enleitar",
    "enleitasse": "enleitar",
    "enleitassem": "enleitar",
    "enleitasses": "enleitar",
    "enleitaste": "enleitar",
    "enleitastes": "enleitar",
    "enleitava": "enleitar",
    "enleitavam": "enleitar",
    "enleitavas": "enleitar",
    "enleite": "enleitar",
    "enleitei": "enleitar",
    "enleiteis": "enleitar",
    "enleitem": "enleitar",
    "enleitemo": "enleitar",
    "enleitemos": "enleitar",
    "enleites": "enleitar",
    "enleito": "enleitar",
    "enleitou": "enleitar",
    "enleitá": "enleitar",
    "enleitámo": "enleitar",
    "enleitámos": "enleitar",
    "enleitáramo": "enleitar",
    "enleitáramos": "enleitar",
    "enleitárei": "enleitar",
    "enleitáreis": "enleitar",
    "enleitásseis": "enleitar",
    "enleitássemos": "enleitar",
    "enleitávamo": "enleitar",
    "enleitávamos": "enleitar",
    "enleitávei": "enleitar",
    "enleitáveis": "enleitar",
    "enleou": "enlear",
    "enlerda": "enlerdar",
    "enlerdada": "enlerdar",
    "enlerdadas": "enlerdar",
    "enlerdado": "enlerdar",
    "enlerdados": "enlerdar",
    "enlerdai": "enlerdar",
    "enlerdais": "enlerdar",
    "enlerdam": "enlerdar",
    "enlerdamo": "enlerdar",
    "enlerdamos": "enlerdar",
    "enlerdando": "enlerdar",
    "enlerdara": "enlerdar",
    "enlerdaram": "enlerdar",
    "enlerdaras": "enlerdar",
    "enlerdarde": "enlerdar",
    "enlerdardes": "enlerdar",
    "enlerdare": "enlerdar",
    "enlerdarei": "enlerdar",
    "enlerdareis": "enlerdar",
    "enlerdarem": "enlerdar",
    "enlerdaremos": "enlerdar",
    "enlerdares": "enlerdar",
    "enlerdaria": "enlerdar",
    "enlerdariam": "enlerdar",
    "enlerdarias": "enlerdar",
    "enlerdarmo": "enlerdar",
    "enlerdarmos": "enlerdar",
    "enlerdará": "enlerdar",
    "enlerdarás": "enlerdar",
    "enlerdarão": "enlerdar",
    "enlerdaríamos": "enlerdar",
    "enlerdaríeis": "enlerdar",
    "enlerdas": "enlerdar",
    "enlerdasse": "enlerdar",
    "enlerdassem": "enlerdar",
    "enlerdasses": "enlerdar",
    "enlerdaste": "enlerdar",
    "enlerdastes": "enlerdar",
    "enlerdava": "enlerdar",
    "enlerdavam": "enlerdar",
    "enlerdavas": "enlerdar",
    "enlerde": "enlerdar",
    "enlerdei": "enlerdar",
    "enlerdeis": "enlerdar",
    "enlerdem": "enlerdar",
    "enlerdemo": "enlerdar",
    "enlerdemos": "enlerdar",
    "enlerdes": "enlerdar",
    "enlerdo": "enlerdar",
    "enlerdou": "enlerdar",
    "enlerdá": "enlerdar",
    "enlerdámo": "enlerdar",
    "enlerdámos": "enlerdar",
    "enlerdáramo": "enlerdar",
    "enlerdáramos": "enlerdar",
    "enlerdárei": "enlerdar",
    "enlerdáreis": "enlerdar",
    "enlerdásseis": "enlerdar",
    "enlerdássemos": "enlerdar",
    "enlerdávamo": "enlerdar",
    "enlerdávamos": "enlerdar",
    "enlerdávei": "enlerdar",
    "enlerdáveis": "enlerdar",
    "enleva": "enlevar",
    "enlevada": "enlevar",
    "enlevadas": "enlevar",
    "enlevado": "enlevar",
    "enlevados": "enlevar",
    "enlevai": "enlevar",
    "enlevais": "enlevar",
    "enlevam": "enlevar",
    "enlevamentos": "enlevamento",
    "enlevamo": "enlevar",
    "enlevamos": "enlevar",
    "enlevando": "enlevar",
    "enlevara": "enlevar",
    "enlevaram": "enlevar",
    "enlevaras": "enlevar",
    "enlevarde": "enlevar",
    "enlevardes": "enlevar",
    "enlevare": "enlevar",
    "enlevarei": "enlevar",
    "enlevareis": "enlevar",
    "enlevarem": "enlevar",
    "enlevaremos": "enlevar",
    "enlevares": "enlevar",
    "enlevaria": "enlevar",
    "enlevariam": "enlevar",
    "enlevarias": "enlevar",
    "enlevarmo": "enlevar",
    "enlevarmos": "enlevar",
    "enlevará": "enlevar",
    "enlevarás": "enlevar",
    "enlevarão": "enlevar",
    "enlevaríamos": "enlevar",
    "enlevaríeis": "enlevar",
    "enlevas": "enlevar",
    "enlevasse": "enlevar",
    "enlevassem": "enlevar",
    "enlevasses": "enlevar",
    "enlevaste": "enlevar",
    "enlevastes": "enlevar",
    "enlevava": "enlevar",
    "enlevavam": "enlevar",
    "enlevavas": "enlevar",
    "enlevações": "enlevação",
    "enleve": "enlevar",
    "enlevei": "enlevar",
    "enleveis": "enlevar",
    "enlevem": "enlevar",
    "enlevemo": "enlevar",
    "enlevemos": "enlevar",
    "enleves": "enlevar",
    "enlevo": "enlevar",
    "enlevos": "enlevo",
    "enlevou": "enlevar",
    "enlevá": "enlevar",
    "enlevámo": "enlevar",
    "enlevámos": "enlevar",
    "enleváramo": "enlevar",
    "enleváramos": "enlevar",
    "enlevárei": "enlevar",
    "enleváreis": "enlevar",
    "enlevásseis": "enlevar",
    "enlevássemos": "enlevar",
    "enlevávamo": "enlevar",
    "enlevávamos": "enlevar",
    "enlevávei": "enlevar",
    "enleváveis": "enlevar",
    "enleá": "enlear",
    "enleámo": "enlear",
    "enleámos": "enlear",
    "enleáramo": "enlear",
    "enleáramos": "enlear",
    "enleárei": "enlear",
    "enleáreis": "enlear",
    "enleásseis": "enlear",
    "enleássemos": "enlear",
    "enleávamo": "enlear",
    "enleávamos": "enlear",
    "enleávei": "enlear",
    "enleáveis": "enlear",
    "enlice": "enliçar",
    "enlicei": "enliçar",
    "enliceis": "enliçar",
    "enlicem": "enliçar",
    "enlicemo": "enliçar",
    "enlicemos": "enliçar",
    "enlices": "enliçar",
    "enlividece": "enlividecer",
    "enlividecei": "enlividecer",
    "enlivideceis": "enlividecer",
    "enlividecem": "enlividecer",
    "enlividecemo": "enlividecer",
    "enlividecemos": "enlividecer",
    "enlividecendo": "enlividecer",
    "enlividecera": "enlividecer",
    "enlivideceram": "enlividecer",
    "enlivideceras": "enlividecer",
    "enlividecerdes": "enlividecer",
    "enlividecerei": "enlividecer",
    "enlividecereis": "enlividecer",
    "enlividecerem": "enlividecer",
    "enlivideceremos": "enlividecer",
    "enlivideceres": "enlividecer",
    "enlivideceria": "enlividecer",
    "enlivideceriam": "enlividecer",
    "enlividecerias": "enlividecer",
    "enlividecermo": "enlividecer",
    "enlividecermos": "enlividecer",
    "enlividecerá": "enlividecer",
    "enlividecerás": "enlividecer",
    "enlividecerão": "enlividecer",
    "enlivideceríamos": "enlividecer",
    "enlivideceríeis": "enlividecer",
    "enlivideces": "enlividecer",
    "enlividecesse": "enlividecer",
    "enlividecessem": "enlividecer",
    "enlividecesses": "enlividecer",
    "enlivideceste": "enlividecer",
    "enlividecestes": "enlividecer",
    "enlivideceu": "enlividecer",
    "enlivideci": "enlividecer",
    "enlividecia": "enlividecer",
    "enlivideciam": "enlividecer",
    "enlividecias": "enlividecer",
    "enlividecida": "enlividecer",
    "enlividecidas": "enlividecer",
    "enlividecido": "enlividecer",
    "enlividecidos": "enlividecer",
    "enlividecêramo": "enlividecer",
    "enlividecêramos": "enlividecer",
    "enlividecêreis": "enlividecer",
    "enlividecêsseis": "enlividecer",
    "enlividecêssemos": "enlividecer",
    "enlividecíamo": "enlividecer",
    "enlividecíamos": "enlividecer",
    "enlividecíeis": "enlividecer",
    "enlivideça": "enlividecer",
    "enlivideçais": "enlividecer",
    "enlivideçam": "enlividecer",
    "enlivideçamo": "enlividecer",
    "enlivideçamos": "enlividecer",
    "enlivideças": "enlividecer",
    "enlivideço": "enlividecer",
    "enliça": "enliçar",
    "enliçada": "enliçar",
    "enliçadas": "enliçar",
    "enliçado": "enliçar",
    "enliçadora": "enliçador",
    "enliçadoras": "enliçador",
    "enliçadores": "enliçador",
    "enliçados": "enliçar",
    "enliçai": "enliçar",
    "enliçais": "enliçar",
    "enliçam": "enliçar",
    "enliçamentos": "enliçamento",
    "enliçamo": "enliçar",
    "enliçamos": "enliçar",
    "enliçando": "enliçar",
    "enliçara": "enliçar",
    "enliçaram": "enliçar",
    "enliçaras": "enliçar",
    "enliçarde": "enliçar",
    "enliçardes": "enliçar",
    "enliçare": "enliçar",
    "enliçarei": "enliçar",
    "enliçareis": "enliçar",
    "enliçarem": "enliçar",
    "enliçaremos": "enliçar",
    "enliçares": "enliçar",
    "enliçaria": "enliçar",
    "enliçariam": "enliçar",
    "enliçarias": "enliçar",
    "enliçarmo": "enliçar",
    "enliçarmos": "enliçar",
    "enliçará": "enliçar",
    "enliçarás": "enliçar",
    "enliçarão": "enliçar",
    "enliçaríamos": "enliçar",
    "enliçaríeis": "enliçar",
    "enliças": "enliçar",
    "enliçasse": "enliçar",
    "enliçassem": "enliçar",
    "enliçasses": "enliçar",
    "enliçaste": "enliçar",
    "enliçastes": "enliçar",
    "enliçava": "enliçar",
    "enliçavam": "enliçar",
    "enliçavas": "enliçar",
    "enliço": "enliçar",
    "enliços": "enliço",
    "enliçou": "enliçar",
    "enliçá": "enliçar",
    "enliçámo": "enliçar",
    "enliçámos": "enliçar",
    "enliçáramo": "enliçar",
    "enliçáramos": "enliçar",
    "enliçárei": "enliçar",
    "enliçáreis": "enliçar",
    "enliçásseis": "enliçar",
    "enliçássemos": "enliçar",
    "enliçávamo": "enliçar",
    "enliçávamos": "enliçar",
    "enliçávei": "enliçar",
    "enliçáveis": "enliçar",
    "enloca": "enlocar",
    "enlocada": "enlocar",
    "enlocadas": "enlocar",
    "enlocado": "enlocar",
    "enlocados": "enlocar",
    "enlocai": "enlocar",
    "enlocais": "enlocar",
    "enlocam": "enlocar",
    "enlocamo": "enlocar",
    "enlocamos": "enlocar",
    "enlocando": "enlocar",
    "enlocara": "enlocar",
    "enlocaram": "enlocar",
    "enlocaras": "enlocar",
    "enlocarde": "enlocar",
    "enlocardes": "enlocar",
    "enlocare": "enlocar",
    "enlocarei": "enlocar",
    "enlocareis": "enlocar",
    "enlocarem": "enlocar",
    "enlocaremos": "enlocar",
    "enlocares": "enlocar",
    "enlocaria": "enlocar",
    "enlocariam": "enlocar",
    "enlocarias": "enlocar",
    "enlocarmo": "enlocar",
    "enlocarmos": "enlocar",
    "enlocará": "enlocar",
    "enlocarás": "enlocar",
    "enlocarão": "enlocar",
    "enlocaríamos": "enlocar",
    "enlocaríeis": "enlocar",
    "enlocas": "enlocar",
    "enlocasse": "enlocar",
    "enlocassem": "enlocar",
    "enlocasses": "enlocar",
    "enlocaste": "enlocar",
    "enlocastes": "enlocar",
    "enlocava": "enlocar",
    "enlocavam": "enlocar",
    "enlocavas": "enlocar",
    "enloco": "enlocar",
    "enlocou": "enlocar",
    "enlocá": "enlocar",
    "enlocámo": "enlocar",
    "enlocámos": "enlocar",
    "enlocáramo": "enlocar",
    "enlocáramos": "enlocar",
    "enlocárei": "enlocar",
    "enlocáreis": "enlocar",
    "enlocásseis": "enlocar",
    "enlocássemos": "enlocar",
    "enlocávamo": "enlocar",
    "enlocávamos": "enlocar",
    "enlocávei": "enlocar",
    "enlocáveis": "enlocar",
    "enloda": "enlodar",
    "enlodace": "enlodaçar",
    "enlodacei": "enlodaçar",
    "enlodaceis": "enlodaçar",
    "enlodacem": "enlodaçar",
    "enlodacemo": "enlodaçar",
    "enlodacemos": "enlodaçar",
    "enlodaces": "enlodaçar",
    "enlodada": "enlodar",
    "enlodadas": "enlodar",
    "enlodado": "enlodar",
    "enlodados": "enlodar",
    "enlodai": "enlodar",
    "enlodais": "enlodar",
    "enlodam": "enlodar",
    "enlodamo": "enlodar",
    "enlodamos": "enlodar",
    "enlodando": "enlodar",
    "enlodara": "enlodar",
    "enlodaram": "enlodar",
    "enlodaras": "enlodar",
    "enlodarde": "enlodar",
    "enlodardes": "enlodar",
    "enlodare": "enlodar",
    "enlodarei": "enlodar",
    "enlodareis": "enlodar",
    "enlodarem": "enlodar",
    "enlodaremos": "enlodar",
    "enlodares": "enlodar",
    "enlodaria": "enlodar",
    "enlodariam": "enlodar",
    "enlodarias": "enlodar",
    "enlodarmo": "enlodar",
    "enlodarmos": "enlodar",
    "enlodará": "enlodar",
    "enlodarás": "enlodar",
    "enlodarão": "enlodar",
    "enlodaríamos": "enlodar",
    "enlodaríeis": "enlodar",
    "enlodas": "enlodar",
    "enlodasse": "enlodar",
    "enlodassem": "enlodar",
    "enlodasses": "enlodar",
    "enlodaste": "enlodar",
    "enlodastes": "enlodar",
    "enlodava": "enlodar",
    "enlodavam": "enlodar",
    "enlodavas": "enlodar",
    "enlodaça": "enlodaçar",
    "enlodaçada": "enlodaçar",
    "enlodaçadas": "enlodaçar",
    "enlodaçado": "enlodaçar",
    "enlodaçados": "enlodaçar",
    "enlodaçai": "enlodaçar",
    "enlodaçais": "enlodaçar",
    "enlodaçam": "enlodaçar",
    "enlodaçamo": "enlodaçar",
    "enlodaçamos": "enlodaçar",
    "enlodaçando": "enlodaçar",
    "enlodaçara": "enlodaçar",
    "enlodaçaram": "enlodaçar",
    "enlodaçaras": "enlodaçar",
    "enlodaçarde": "enlodaçar",
    "enlodaçardes": "enlodaçar",
    "enlodaçare": "enlodaçar",
    "enlodaçarei": "enlodaçar",
    "enlodaçareis": "enlodaçar",
    "enlodaçarem": "enlodaçar",
    "enlodaçaremos": "enlodaçar",
    "enlodaçares": "enlodaçar",
    "enlodaçaria": "enlodaçar",
    "enlodaçariam": "enlodaçar",
    "enlodaçarias": "enlodaçar",
    "enlodaçarmo": "enlodaçar",
    "enlodaçarmos": "enlodaçar",
    "enlodaçará": "enlodaçar",
    "enlodaçarás": "enlodaçar",
    "enlodaçarão": "enlodaçar",
    "enlodaçaríamos": "enlodaçar",
    "enlodaçaríeis": "enlodaçar",
    "enlodaças": "enlodaçar",
    "enlodaçasse": "enlodaçar",
    "enlodaçassem": "enlodaçar",
    "enlodaçasses": "enlodaçar",
    "enlodaçaste": "enlodaçar",
    "enlodaçastes": "enlodaçar",
    "enlodaçava": "enlodaçar",
    "enlodaçavam": "enlodaçar",
    "enlodaçavas": "enlodaçar",
    "enlodaço": "enlodaçar",
    "enlodaçou": "enlodaçar",
    "enlodaçá": "enlodaçar",
    "enlodaçámo": "enlodaçar",
    "enlodaçámos": "enlodaçar",
    "enlodaçáramo": "enlodaçar",
    "enlodaçáramos": "enlodaçar",
    "enlodaçárei": "enlodaçar",
    "enlodaçáreis": "enlodaçar",
    "enlodaçásseis": "enlodaçar",
    "enlodaçássemos": "enlodaçar",
    "enlodaçávamo": "enlodaçar",
    "enlodaçávamos": "enlodaçar",
    "enlodaçávei": "enlodaçar",
    "enlodaçáveis": "enlodaçar",
    "enlode": "enlodar",
    "enlodei": "enlodar",
    "enlodeis": "enlodar",
    "enlodem": "enlodar",
    "enlodemo": "enlodar",
    "enlodemos": "enlodar",
    "enlodes": "enlodar",
    "enlodo": "enlodar",
    "enlodou": "enlodar",
    "enlodá": "enlodar",
    "enlodámo": "enlodar",
    "enlodámos": "enlodar",
    "enlodáramo": "enlodar",
    "enlodáramos": "enlodar",
    "enlodárei": "enlodar",
    "enlodáreis": "enlodar",
    "enlodásseis": "enlodar",
    "enlodássemos": "enlodar",
    "enlodávamo": "enlodar",
    "enlodávamos": "enlodar",
    "enlodávei": "enlodar",
    "enlodáveis": "enlodar",
    "enloice": "enloiçar",
    "enloicei": "enloiçar",
    "enloiceis": "enloiçar",
    "enloicem": "enloiçar",
    "enloicemo": "enloiçar",
    "enloicemos": "enloiçar",
    "enloices": "enloiçar",
    "enloira": "enloirar",
    "enloirada": "enloirar",
    "enloiradas": "enloirar",
    "enloirado": "enloirar",
    "enloirados": "enloirar",
    "enloirai": "enloirar",
    "enloirais": "enloirar",
    "enloiram": "enloirar",
    "enloiramo": "enloirar",
    "enloiramos": "enloirar",
    "enloirando": "enloirar",
    "enloirara": "enloirar",
    "enloiraram": "enloirar",
    "enloiraras": "enloirar",
    "enloirarde": "enloirar",
    "enloirardes": "enloirar",
    "enloirare": "enloirar",
    "enloirarei": "enloirar",
    "enloirareis": "enloirar",
    "enloirarem": "enloirar",
    "enloiraremos": "enloirar",
    "enloirares": "enloirar",
    "enloiraria": "enloirar",
    "enloirariam": "enloirar",
    "enloirarias": "enloirar",
    "enloirarmo": "enloirar",
    "enloirarmos": "enloirar",
    "enloirará": "enloirar",
    "enloirarás": "enloirar",
    "enloirarão": "enloirar",
    "enloiraríamos": "enloirar",
    "enloiraríeis": "enloirar",
    "enloiras": "enloirar",
    "enloirasse": "enloirar",
    "enloirassem": "enloirar",
    "enloirasses": "enloirar",
    "enloiraste": "enloirar",
    "enloirastes": "enloirar",
    "enloirava": "enloirar",
    "enloiravam": "enloirar",
    "enloiravas": "enloirar",
    "enloire": "enloirar",
    "enloirece": "enloirecer",
    "enloirecei": "enloirecer",
    "enloireceis": "enloirecer",
    "enloirecem": "enloirecer",
    "enloirecemo": "enloirecer",
    "enloirecemos": "enloirecer",
    "enloirecendo": "enloirecer",
    "enloirecera": "enloirecer",
    "enloireceram": "enloirecer",
    "enloireceras": "enloirecer",
    "enloirecerdes": "enloirecer",
    "enloirecerei": "enloirecer",
    "enloirecereis": "enloirecer",
    "enloirecerem": "enloirecer",
    "enloireceremos": "enloirecer",
    "enloireceres": "enloirecer",
    "enloireceria": "enloirecer",
    "enloireceriam": "enloirecer",
    "enloirecerias": "enloirecer",
    "enloirecermo": "enloirecer",
    "enloirecermos": "enloirecer",
    "enloirecerá": "enloirecer",
    "enloirecerás": "enloirecer",
    "enloirecerão": "enloirecer",
    "enloireceríamos": "enloirecer",
    "enloireceríeis": "enloirecer",
    "enloireces": "enloirecer",
    "enloirecesse": "enloirecer",
    "enloirecessem": "enloirecer",
    "enloirecesses": "enloirecer",
    "enloireceste": "enloirecer",
    "enloirecestes": "enloirecer",
    "enloireceu": "enloirecer",
    "enloireci": "enloirecer",
    "enloirecia": "enloirecer",
    "enloireciam": "enloirecer",
    "enloirecias": "enloirecer",
    "enloirecida": "enloirecer",
    "enloirecidas": "enloirecer",
    "enloirecido": "enloirecer",
    "enloirecidos": "enloirecer",
    "enloirecêramo": "enloirecer",
    "enloirecêramos": "enloirecer",
    "enloirecêreis": "enloirecer",
    "enloirecêsseis": "enloirecer",
    "enloirecêssemos": "enloirecer",
    "enloirecíamo": "enloirecer",
    "enloirecíamos": "enloirecer",
    "enloirecíeis": "enloirecer",
    "enloirei": "enloirar",
    "enloireis": "enloirar",
    "enloirem": "enloirar",
    "enloiremo": "enloirar",
    "enloiremos": "enloirar",
    "enloires": "enloirar",
    "enloireça": "enloirecer",
    "enloireçais": "enloirecer",
    "enloireçam": "enloirecer",
    "enloireçamo": "enloirecer",
    "enloireçamos": "enloirecer",
    "enloireças": "enloirecer",
    "enloireço": "enloirecer",
    "enloiro": "enloirar",
    "enloirou": "enloirar",
    "enloirá": "enloirar",
    "enloirámo": "enloirar",
    "enloirámos": "enloirar",
    "enloiráramo": "enloirar",
    "enloiráramos": "enloirar",
    "enloirárei": "enloirar",
    "enloiráreis": "enloirar",
    "enloirásseis": "enloirar",
    "enloirássemos": "enloirar",
    "enloirávamo": "enloirar",
    "enloirávamos": "enloirar",
    "enloirávei": "enloirar",
    "enloiráveis": "enloirar",
    "enloisa": "enloisar",
    "enloisada": "enloisar",
    "enloisadas": "enloisar",
    "enloisado": "enloisar",
    "enloisados": "enloisar",
    "enloisai": "enloisar",
    "enloisais": "enloisar",
    "enloisam": "enloisar",
    "enloisamentos": "enloisamento",
    "enloisamo": "enloisar",
    "enloisamos": "enloisar",
    "enloisando": "enloisar",
    "enloisara": "enloisar",
    "enloisaram": "enloisar",
    "enloisaras": "enloisar",
    "enloisarde": "enloisar",
    "enloisardes": "enloisar",
    "enloisare": "enloisar",
    "enloisarei": "enloisar",
    "enloisareis": "enloisar",
    "enloisarem": "enloisar",
    "enloisaremos": "enloisar",
    "enloisares": "enloisar",
    "enloisaria": "enloisar",
    "enloisariam": "enloisar",
    "enloisarias": "enloisar",
    "enloisarmo": "enloisar",
    "enloisarmos": "enloisar",
    "enloisará": "enloisar",
    "enloisarás": "enloisar",
    "enloisarão": "enloisar",
    "enloisaríamos": "enloisar",
    "enloisaríeis": "enloisar",
    "enloisas": "enloisar",
    "enloisasse": "enloisar",
    "enloisassem": "enloisar",
    "enloisasses": "enloisar",
    "enloisaste": "enloisar",
    "enloisastes": "enloisar",
    "enloisava": "enloisar",
    "enloisavam": "enloisar",
    "enloisavas": "enloisar",
    "enloise": "enloisar",
    "enloisei": "enloisar",
    "enloiseis": "enloisar",
    "enloisem": "enloisar",
    "enloisemo": "enloisar",
    "enloisemos": "enloisar",
    "enloises": "enloisar",
    "enloiso": "enloisar",
    "enloisou": "enloisar",
    "enloisá": "enloisar",
    "enloisámo": "enloisar",
    "enloisámos": "enloisar",
    "enloisáramo": "enloisar",
    "enloisáramos": "enloisar",
    "enloisárei": "enloisar",
    "enloisáreis": "enloisar",
    "enloisásseis": "enloisar",
    "enloisássemos": "enloisar",
    "enloisávamo": "enloisar",
    "enloisávamos": "enloisar",
    "enloisávei": "enloisar",
    "enloisáveis": "enloisar",
    "enloiça": "enloiçar",
    "enloiçada": "enloiçar",
    "enloiçadas": "enloiçar",
    "enloiçado": "enloiçar",
    "enloiçados": "enloiçar",
    "enloiçai": "enloiçar",
    "enloiçais": "enloiçar",
    "enloiçam": "enloiçar",
    "enloiçamo": "enloiçar",
    "enloiçamos": "enloiçar",
    "enloiçando": "enloiçar",
    "enloiçara": "enloiçar",
    "enloiçaram": "enloiçar",
    "enloiçaras": "enloiçar",
    "enloiçarde": "enloiçar",
    "enloiçardes": "enloiçar",
    "enloiçare": "enloiçar",
    "enloiçarei": "enloiçar",
    "enloiçareis": "enloiçar",
    "enloiçarem": "enloiçar",
    "enloiçaremos": "enloiçar",
    "enloiçares": "enloiçar",
    "enloiçaria": "enloiçar",
    "enloiçariam": "enloiçar",
    "enloiçarias": "enloiçar",
    "enloiçarmo": "enloiçar",
    "enloiçarmos": "enloiçar",
    "enloiçará": "enloiçar",
    "enloiçarás": "enloiçar",
    "enloiçarão": "enloiçar",
    "enloiçaríamos": "enloiçar",
    "enloiçaríeis": "enloiçar",
    "enloiças": "enloiçar",
    "enloiçasse": "enloiçar",
    "enloiçassem": "enloiçar",
    "enloiçasses": "enloiçar",
    "enloiçaste": "enloiçar",
    "enloiçastes": "enloiçar",
    "enloiçava": "enloiçar",
    "enloiçavam": "enloiçar",
    "enloiçavas": "enloiçar",
    "enloiço": "enloiçar",
    "enloiçou": "enloiçar",
    "enloiçá": "enloiçar",
    "enloiçámo": "enloiçar",
    "enloiçámos": "enloiçar",
    "enloiçáramo": "enloiçar",
    "enloiçáramos": "enloiçar",
    "enloiçárei": "enloiçar",
    "enloiçáreis": "enloiçar",
    "enloiçásseis": "enloiçar",
    "enloiçássemos": "enloiçar",
    "enloiçávamo": "enloiçar",
    "enloiçávamos": "enloiçar",
    "enloiçávei": "enloiçar",
    "enloiçáveis": "enloiçar",
    "enloque": "enlocar",
    "enloquei": "enlocar",
    "enloqueis": "enlocar",
    "enloquem": "enlocar",
    "enloquemo": "enlocar",
    "enloquemos": "enlocar",
    "enloques": "enlocar",
    "enlorpece": "enlorpecer",
    "enlorpecei": "enlorpecer",
    "enlorpeceis": "enlorpecer",
    "enlorpecem": "enlorpecer",
    "enlorpecemo": "enlorpecer",
    "enlorpecemos": "enlorpecer",
    "enlorpecendo": "enlorpecer",
    "enlorpecera": "enlorpecer",
    "enlorpeceram": "enlorpecer",
    "enlorpeceras": "enlorpecer",
    "enlorpecerdes": "enlorpecer",
    "enlorpecerei": "enlorpecer",
    "enlorpecereis": "enlorpecer",
    "enlorpecerem": "enlorpecer",
    "enlorpeceremos": "enlorpecer",
    "enlorpeceres": "enlorpecer",
    "enlorpeceria": "enlorpecer",
    "enlorpeceriam": "enlorpecer",
    "enlorpecerias": "enlorpecer",
    "enlorpecermo": "enlorpecer",
    "enlorpecermos": "enlorpecer",
    "enlorpecerá": "enlorpecer",
    "enlorpecerás": "enlorpecer",
    "enlorpecerão": "enlorpecer",
    "enlorpeceríamos": "enlorpecer",
    "enlorpeceríeis": "enlorpecer",
    "enlorpeces": "enlorpecer",
    "enlorpecesse": "enlorpecer",
    "enlorpecessem": "enlorpecer",
    "enlorpecesses": "enlorpecer",
    "enlorpeceste": "enlorpecer",
    "enlorpecestes": "enlorpecer",
    "enlorpeceu": "enlorpecer",
    "enlorpeci": "enlorpecer",
    "enlorpecia": "enlorpecer",
    "enlorpeciam": "enlorpecer",
    "enlorpecias": "enlorpecer",
    "enlorpecida": "enlorpecer",
    "enlorpecidas": "enlorpecer",
    "enlorpecido": "enlorpecer",
    "enlorpecidos": "enlorpecer",
    "enlorpecêramo": "enlorpecer",
    "enlorpecêramos": "enlorpecer",
    "enlorpecêreis": "enlorpecer",
    "enlorpecêsseis": "enlorpecer",
    "enlorpecêssemos": "enlorpecer",
    "enlorpecíamo": "enlorpecer",
    "enlorpecíamos": "enlorpecer",
    "enlorpecíeis": "enlorpecer",
    "enlorpeça": "enlorpecer",
    "enlorpeçais": "enlorpecer",
    "enlorpeçam": "enlorpecer",
    "enlorpeçamo": "enlorpecer",
    "enlorpeçamos": "enlorpecer",
    "enlorpeças": "enlorpecer",
    "enlorpeço": "enlorpecer",
    "enlouca": "enloucar",
    "enloucada": "enloucar",
    "enloucadas": "enloucar",
    "enloucado": "enloucar",
    "enloucados": "enloucar",
    "enloucai": "enloucar",
    "enloucais": "enloucar",
    "enloucam": "enloucar",
    "enloucamentos": "enloucamento",
    "enloucamo": "enloucar",
    "enloucamos": "enloucar",
    "enloucando": "enloucar",
    "enloucara": "enloucar",
    "enloucaram": "enloucar",
    "enloucaras": "enloucar",
    "enloucarde": "enloucar",
    "enloucardes": "enloucar",
    "enloucare": "enloucar",
    "enloucarei": "enloucar",
    "enloucareis": "enloucar",
    "enloucarem": "enloucar",
    "enloucaremos": "enloucar",
    "enloucares": "enloucar",
    "enloucaria": "enloucar",
    "enloucariam": "enloucar",
    "enloucarias": "enloucar",
    "enloucarmo": "enloucar",
    "enloucarmos": "enloucar",
    "enloucará": "enloucar",
    "enloucarás": "enloucar",
    "enloucarão": "enloucar",
    "enloucaríamos": "enloucar",
    "enloucaríeis": "enloucar",
    "enloucas": "enloucar",
    "enloucasse": "enloucar",
    "enloucassem": "enloucar",
    "enloucasses": "enloucar",
    "enloucaste": "enloucar",
    "enloucastes": "enloucar",
    "enloucava": "enloucar",
    "enloucavam": "enloucar",
    "enloucavas": "enloucar",
    "enlouce": "enlouçar",
    "enloucei": "enlouçar",
    "enlouceis": "enlouçar",
    "enloucem": "enlouçar",
    "enloucemo": "enlouçar",
    "enloucemos": "enlouçar",
    "enlouces": "enlouçar",
    "enlouco": "enloucar",
    "enloucou": "enloucar",
    "enloucá": "enloucar",
    "enloucámo": "enloucar",
    "enloucámos": "enloucar",
    "enloucáramo": "enloucar",
    "enloucáramos": "enloucar",
    "enloucárei": "enloucar",
    "enloucáreis": "enloucar",
    "enloucásseis": "enloucar",
    "enloucássemos": "enloucar",
    "enloucávamo": "enloucar",
    "enloucávamos": "enloucar",
    "enloucávei": "enloucar",
    "enloucáveis": "enloucar",
    "enlouque": "enloucar",
    "enlouquece": "enlouquecer",
    "enlouquecedora": "enlouquecedor",
    "enlouquecedoras": "enlouquecedor",
    "enlouquecedores": "enlouquecedor",
    "enlouquecei": "enlouquecer",
    "enlouqueceis": "enlouquecer",
    "enlouquecem": "enlouquecer",
    "enlouquecemo": "enlouquecer",
    "enlouquecemos": "enlouquecer",
    "enlouquecendo": "enlouquecer",
    "enlouquecera": "enlouquecer",
    "enlouqueceram": "enlouquecer",
    "enlouqueceras": "enlouquecer",
    "enlouquecerde": "enlouquecer",
    "enlouquecerdes": "enlouquecer",
    "enlouquecere": "enlouquecer",
    "enlouquecerei": "enlouquecer",
    "enlouquecereis": "enlouquecer",
    "enlouquecerem": "enlouquecer",
    "enlouqueceremos": "enlouquecer",
    "enlouqueceres": "enlouquecer",
    "enlouqueceria": "enlouquecer",
    "enlouqueceriam": "enlouquecer",
    "enlouquecerias": "enlouquecer",
    "enlouquecermo": "enlouquecer",
    "enlouquecermos": "enlouquecer",
    "enlouquecerá": "enlouquecer",
    "enlouquecerás": "enlouquecer",
    "enlouquecerão": "enlouquecer",
    "enlouqueceríamos": "enlouquecer",
    "enlouqueceríeis": "enlouquecer",
    "enlouqueces": "enlouquecer",
    "enlouquecesse": "enlouquecer",
    "enlouquecessem": "enlouquecer",
    "enlouquecesses": "enlouquecer",
    "enlouqueceste": "enlouquecer",
    "enlouquecestes": "enlouquecer",
    "enlouqueceu": "enlouquecer",
    "enlouqueci": "enlouquecer",
    "enlouquecia": "enlouquecer",
    "enlouqueciam": "enlouquecer",
    "enlouquecias": "enlouquecer",
    "enlouquecida": "enlouquecido",
    "enlouquecidas": "enlouquecido",
    "enlouquecido": "enlouquecer",
    "enlouquecidos": "enlouquecido",
    "enlouquecimentos": "enlouquecimento",
    "enlouquecê": "enlouquecer",
    "enlouquecêramo": "enlouquecer",
    "enlouquecêramos": "enlouquecer",
    "enlouquecêrei": "enlouquecer",
    "enlouquecêreis": "enlouquecer",
    "enlouquecêsseis": "enlouquecer",
    "enlouquecêssemos": "enlouquecer",
    "enlouquecíamo": "enlouquecer",
    "enlouquecíamos": "enlouquecer",
    "enlouquecíei": "enlouquecer",
    "enlouquecíeis": "enlouquecer",
    "enlouquei": "enloucar",
    "enlouqueis": "enloucar",
    "enlouquem": "enloucar",
    "enlouquemo": "enloucar",
    "enlouquemos": "enloucar",
    "enlouques": "enloucar",
    "enlouqueça": "enlouquecer",
    "enlouqueçais": "enlouquecer",
    "enlouqueçam": "enlouquecer",
    "enlouqueçamo": "enlouquecer",
    "enlouqueçamos": "enlouquecer",
    "enlouqueças": "enlouquecer",
    "enlouqueço": "enlouquecer",
    "enloura": "enlourar",
    "enlourada": "enlourar",
    "enlouradas": "enlourar",
    "enlourado": "enlourar",
    "enlourados": "enlourar",
    "enlourai": "enlourar",
    "enlourais": "enlourar",
    "enlouram": "enlourar",
    "enlouramo": "enlourar",
    "enlouramos": "enlourar",
    "enlourando": "enlourar",
    "enlourara": "enlourar",
    "enlouraram": "enlourar",
    "enlouraras": "enlourar",
    "enlourarde": "enlourar",
    "enlourardes": "enlourar",
    "enlourare": "enlourar",
    "enlourarei": "enlourar",
    "enlourareis": "enlourar",
    "enlourarem": "enlourar",
    "enlouraremos": "enlourar",
    "enlourares": "enlourar",
    "enlouraria": "enlourar",
    "enlourariam": "enlourar",
    "enlourarias": "enlourar",
    "enlourarmo": "enlourar",
    "enlourarmos": "enlourar",
    "enlourará": "enlourar",
    "enlourarás": "enlourar",
    "enlourarão": "enlourar",
    "enlouraríamos": "enlourar",
    "enlouraríeis": "enlourar",
    "enlouras": "enlourar",
    "enlourasse": "enlourar",
    "enlourassem": "enlourar",
    "enlourasses": "enlourar",
    "enlouraste": "enlourar",
    "enlourastes": "enlourar",
    "enlourava": "enlourar",
    "enlouravam": "enlourar",
    "enlouravas": "enlourar",
    "enloure": "enlourar",
    "enlourece": "enlourecer",
    "enlourecei": "enlourecer",
    "enloureceis": "enlourecer",
    "enlourecem": "enlourecer",
    "enlourecemo": "enlourecer",
    "enlourecemos": "enlourecer",
    "enlourecendo": "enlourecer",
    "enlourecera": "enlourecer",
    "enloureceram": "enlourecer",
    "enloureceras": "enlourecer",
    "enlourecerdes": "enlourecer",
    "enlourecerei": "enlourecer",
    "enlourecereis": "enlourecer",
    "enlourecerem": "enlourecer",
    "enloureceremos": "enlourecer",
    "enloureceres": "enlourecer",
    "enloureceria": "enlourecer",
    "enloureceriam": "enlourecer",
    "enlourecerias": "enlourecer",
    "enlourecermo": "enlourecer",
    "enlourecermos": "enlourecer",
    "enlourecerá": "enlourecer",
    "enlourecerás": "enlourecer",
    "enlourecerão": "enlourecer",
    "enloureceríamos": "enlourecer",
    "enloureceríeis": "enlourecer",
    "enloureces": "enlourecer",
    "enlourecesse": "enlourecer",
    "enlourecessem": "enlourecer",
    "enlourecesses": "enlourecer",
    "enloureceste": "enlourecer",
    "enlourecestes": "enlourecer",
    "enloureceu": "enlourecer",
    "enloureci": "enlourecer",
    "enlourecia": "enlourecer",
    "enloureciam": "enlourecer",
    "enlourecias": "enlourecer",
    "enlourecida": "enlourecer",
    "enlourecidas": "enlourecer",
    "enlourecido": "enlourecer",
    "enlourecidos": "enlourecer",
    "enlourecêramo": "enlourecer",
    "enlourecêramos": "enlourecer",
    "enlourecêreis": "enlourecer",
    "enlourecêsseis": "enlourecer",
    "enlourecêssemos": "enlourecer",
    "enlourecíamo": "enlourecer",
    "enlourecíamos": "enlourecer",
    "enlourecíeis": "enlourecer",
    "enlourei": "enlourar",
    "enloureis": "enlourar",
    "enlourem": "enlourar",
    "enlouremo": "enlourar",
    "enlouremos": "enlourar",
    "enloures": "enlourar",
    "enloureça": "enlourecer",
    "enloureçais": "enlourecer",
    "enloureçam": "enlourecer",
    "enloureçamo": "enlourecer",
    "enloureçamos": "enlourecer",
    "enloureças": "enlourecer",
    "enloureço": "enlourecer",
    "enlouro": "enlourar",
    "enlourou": "enlourar",
    "enlourá": "enlourar",
    "enlourámo": "enlourar",
    "enlourámos": "enlourar",
    "enlouráramo": "enlourar",
    "enlouráramos": "enlourar",
    "enlourárei": "enlourar",
    "enlouráreis": "enlourar",
    "enlourásseis": "enlourar",
    "enlourássemos": "enlourar",
    "enlourávamo": "enlourar",
    "enlourávamos": "enlourar",
    "enlourávei": "enlourar",
    "enlouráveis": "enlourar",
    "enlousa": "enlousar",
    "enlousada": "enlousar",
    "enlousadas": "enlousar",
    "enlousado": "enlousar",
    "enlousados": "enlousar",
    "enlousai": "enlousar",
    "enlousais": "enlousar",
    "enlousam": "enlousar",
    "enlousamentos": "enlousamento",
    "enlousamo": "enlousar",
    "enlousamos": "enlousar",
    "enlousando": "enlousar",
    "enlousara": "enlousar",
    "enlousaram": "enlousar",
    "enlousaras": "enlousar",
    "enlousarde": "enlousar",
    "enlousardes": "enlousar",
    "enlousare": "enlousar",
    "enlousarei": "enlousar",
    "enlousareis": "enlousar",
    "enlousarem": "enlousar",
    "enlousaremos": "enlousar",
    "enlousares": "enlousar",
    "enlousaria": "enlousar",
    "enlousariam": "enlousar",
    "enlousarias": "enlousar",
    "enlousarmo": "enlousar",
    "enlousarmos": "enlousar",
    "enlousará": "enlousar",
    "enlousarás": "enlousar",
    "enlousarão": "enlousar",
    "enlousaríamos": "enlousar",
    "enlousaríeis": "enlousar",
    "enlousas": "enlousar",
    "enlousasse": "enlousar",
    "enlousassem": "enlousar",
    "enlousasses": "enlousar",
    "enlousaste": "enlousar",
    "enlousastes": "enlousar",
    "enlousava": "enlousar",
    "enlousavam": "enlousar",
    "enlousavas": "enlousar",
    "enlouse": "enlousar",
    "enlousei": "enlousar",
    "enlouseis": "enlousar",
    "enlousem": "enlousar",
    "enlousemo": "enlousar",
    "enlousemos": "enlousar",
    "enlouses": "enlousar",
    "enlouso": "enlousar",
    "enlousou": "enlousar",
    "enlousá": "enlousar",
    "enlousámo": "enlousar",
    "enlousámos": "enlousar",
    "enlousáramo": "enlousar",
    "enlousáramos": "enlousar",
    "enlousárei": "enlousar",
    "enlousáreis": "enlousar",
    "enlousásseis": "enlousar",
    "enlousássemos": "enlousar",
    "enlousávamo": "enlousar",
    "enlousávamos": "enlousar",
    "enlousávei": "enlousar",
    "enlousáveis": "enlousar",
    "enlouça": "enlouçar",
    "enlouçada": "enlouçar",
    "enlouçadas": "enlouçar",
    "enlouçado": "enlouçar",
    "enlouçados": "enlouçar",
    "enlouçai": "enlouçar",
    "enlouçais": "enlouçar",
    "enlouçam": "enlouçar",
    "enlouçamo": "enlouçar",
    "enlouçamos": "enlouçar",
    "enlouçando": "enlouçar",
    "enlouçara": "enlouçar",
    "enlouçaram": "enlouçar",
    "enlouçaras": "enlouçar",
    "enlouçarde": "enlouçar",
    "enlouçardes": "enlouçar",
    "enlouçare": "enlouçar",
    "enlouçarei": "enlouçar",
    "enlouçareis": "enlouçar",
    "enlouçarem": "enlouçar",
    "enlouçaremos": "enlouçar",
    "enlouçares": "enlouçar",
    "enlouçaria": "enlouçar",
    "enlouçariam": "enlouçar",
    "enlouçarias": "enlouçar",
    "enlouçarmo": "enlouçar",
    "enlouçarmos": "enlouçar",
    "enlouçará": "enlouçar",
    "enlouçarás": "enlouçar",
    "enlouçarão": "enlouçar",
    "enlouçaríamos": "enlouçar",
    "enlouçaríeis": "enlouçar",
    "enlouças": "enlouçar",
    "enlouçasse": "enlouçar",
    "enlouçassem": "enlouçar",
    "enlouçasses": "enlouçar",
    "enlouçaste": "enlouçar",
    "enlouçastes": "enlouçar",
    "enlouçava": "enlouçar",
    "enlouçavam": "enlouçar",
    "enlouçavas": "enlouçar",
    "enlouço": "enlouçar",
    "enlouçou": "enlouçar",
    "enlouçá": "enlouçar",
    "enlouçámo": "enlouçar",
    "enlouçámos": "enlouçar",
    "enlouçáramo": "enlouçar",
    "enlouçáramos": "enlouçar",
    "enlouçárei": "enlouçar",
    "enlouçáreis": "enlouçar",
    "enlouçásseis": "enlouçar",
    "enlouçássemos": "enlouçar",
    "enlouçávamo": "enlouçar",
    "enlouçávamos": "enlouçar",
    "enlouçávei": "enlouçar",
    "enlouçáveis": "enlouçar",
    "enluara": "enluarar",
    "enluarada": "enluarar",
    "enluaradas": "enluarar",
    "enluarado": "enluarar",
    "enluarados": "enluarar",
    "enluarai": "enluarar",
    "enluarais": "enluarar",
    "enluaram": "enluarar",
    "enluaramo": "enluarar",
    "enluaramos": "enluarar",
    "enluarando": "enluarar",
    "enluarara": "enluarar",
    "enluararam": "enluarar",
    "enluararas": "enluarar",
    "enluarardes": "enluarar",
    "enluararei": "enluarar",
    "enluarareis": "enluarar",
    "enluararem": "enluarar",
    "enluararemos": "enluarar",
    "enluarares": "enluarar",
    "enluararia": "enluarar",
    "enluarariam": "enluarar",
    "enluararias": "enluarar",
    "enluararmo": "enluarar",
    "enluararmos": "enluarar",
    "enluarará": "enluarar",
    "enluararás": "enluarar",
    "enluararão": "enluarar",
    "enluararíamos": "enluarar",
    "enluararíeis": "enluarar",
    "enluaras": "enluarar",
    "enluarasse": "enluarar",
    "enluarassem": "enluarar",
    "enluarasses": "enluarar",
    "enluaraste": "enluarar",
    "enluarastes": "enluarar",
    "enluarava": "enluarar",
    "enluaravam": "enluarar",
    "enluaravas": "enluarar",
    "enluare": "enluarar",
    "enluarei": "enluarar",
    "enluareis": "enluarar",
    "enluarem": "enluarar",
    "enluaremo": "enluarar",
    "enluaremos": "enluarar",
    "enluares": "enluarar",
    "enluaro": "enluarar",
    "enluarou": "enluarar",
    "enluarámo": "enluarar",
    "enluarámos": "enluarar",
    "enluaráramo": "enluarar",
    "enluaráramos": "enluarar",
    "enluaráreis": "enluarar",
    "enluarásseis": "enluarar",
    "enluarássemos": "enluarar",
    "enluarávamo": "enluarar",
    "enluarávamos": "enluarar",
    "enluaráveis": "enluarar",
    "enludra": "enludrar",
    "enludrada": "enludrar",
    "enludradas": "enludrar",
    "enludrado": "enludrar",
    "enludrados": "enludrar",
    "enludrai": "enludrar",
    "enludrais": "enludrar",
    "enludram": "enludrar",
    "enludramo": "enludrar",
    "enludramos": "enludrar",
    "enludrando": "enludrar",
    "enludrara": "enludrar",
    "enludraram": "enludrar",
    "enludraras": "enludrar",
    "enludrarde": "enludrar",
    "enludrardes": "enludrar",
    "enludrare": "enludrar",
    "enludrarei": "enludrar",
    "enludrareis": "enludrar",
    "enludrarem": "enludrar",
    "enludraremos": "enludrar",
    "enludrares": "enludrar",
    "enludraria": "enludrar",
    "enludrariam": "enludrar",
    "enludrarias": "enludrar",
    "enludrarmo": "enludrar",
    "enludrarmos": "enludrar",
    "enludrará": "enludrar",
    "enludrarás": "enludrar",
    "enludrarão": "enludrar",
    "enludraríamos": "enludrar",
    "enludraríeis": "enludrar",
    "enludras": "enludrar",
    "enludrasse": "enludrar",
    "enludrassem": "enludrar",
    "enludrasses": "enludrar",
    "enludraste": "enludrar",
    "enludrastes": "enludrar",
    "enludrava": "enludrar",
    "enludravam": "enludrar",
    "enludravas": "enludrar",
    "enludre": "enludrar",
    "enludrei": "enludrar",
    "enludreis": "enludrar",
    "enludrem": "enludrar",
    "enludremo": "enludrar",
    "enludremos": "enludrar",
    "enludres": "enludrar",
    "enludro": "enludrar",
    "enludrou": "enludrar",
    "enludrá": "enludrar",
    "enludrámo": "enludrar",
    "enludrámos": "enludrar",
    "enludráramo": "enludrar",
    "enludráramos": "enludrar",
    "enludrárei": "enludrar",
    "enludráreis": "enludrar",
    "enludrásseis": "enludrar",
    "enludrássemos": "enludrar",
    "enludrávamo": "enludrar",
    "enludrávamos": "enludrar",
    "enludrávei": "enludrar",
    "enludráveis": "enludrar",
    "enlura": "enlurar",
    "enlurada": "enlurar",
    "enluradas": "enlurar",
    "enlurado": "enlurar",
    "enlurados": "enlurar",
    "enlurai": "enlurar",
    "enlurais": "enlurar",
    "enluram": "enlurar",
    "enluramo": "enlurar",
    "enluramos": "enlurar",
    "enlurando": "enlurar",
    "enlurara": "enlurar",
    "enluraram": "enlurar",
    "enluraras": "enlurar",
    "enlurarde": "enlurar",
    "enlurardes": "enlurar",
    "enlurare": "enlurar",
    "enlurarei": "enlurar",
    "enlurareis": "enlurar",
    "enlurarem": "enlurar",
    "enluraremos": "enlurar",
    "enlurares": "enlurar",
    "enluraria": "enlurar",
    "enlurariam": "enlurar",
    "enlurarias": "enlurar",
    "enlurarmo": "enlurar",
    "enlurarmos": "enlurar",
    "enlurará": "enlurar",
    "enlurarás": "enlurar",
    "enlurarão": "enlurar",
    "enluraríamos": "enlurar",
    "enluraríeis": "enlurar",
    "enluras": "enlurar",
    "enlurasse": "enlurar",
    "enlurassem": "enlurar",
    "enlurasses": "enlurar",
    "enluraste": "enlurar",
    "enlurastes": "enlurar",
    "enlurava": "enlurar",
    "enluravam": "enlurar",
    "enluravas": "enlurar",
    "enlure": "enlurar",
    "enlurei": "enlurar",
    "enlureis": "enlurar",
    "enlurem": "enlurar",
    "enluremo": "enlurar",
    "enluremos": "enlurar",
    "enlures": "enlurar",
    "enluro": "enlurar",
    "enlurou": "enlurar",
    "enlurá": "enlurar",
    "enlurámo": "enlurar",
    "enlurámos": "enlurar",
    "enluráramo": "enlurar",
    "enluráramos": "enlurar",
    "enlurárei": "enlurar",
    "enluráreis": "enlurar",
    "enlurásseis": "enlurar",
    "enlurássemos": "enlurar",
    "enlurávamo": "enlurar",
    "enlurávamos": "enlurar",
    "enlurávei": "enlurar",
    "enluráveis": "enlurar",
    "enluta": "enlutar",
    "enlutada": "enlutar",
    "enlutadas": "enlutar",
    "enlutado": "enlutar",
    "enlutados": "enlutar",
    "enlutai": "enlutar",
    "enlutais": "enlutar",
    "enlutam": "enlutar",
    "enlutamo": "enlutar",
    "enlutamos": "enlutar",
    "enlutando": "enlutar",
    "enlutara": "enlutar",
    "enlutaram": "enlutar",
    "enlutaras": "enlutar",
    "enlutarde": "enlutar",
    "enlutardes": "enlutar",
    "enlutare": "enlutar",
    "enlutarei": "enlutar",
    "enlutareis": "enlutar",
    "enlutarem": "enlutar",
    "enlutaremos": "enlutar",
    "enlutares": "enlutar",
    "enlutaria": "enlutar",
    "enlutariam": "enlutar",
    "enlutarias": "enlutar",
    "enlutarmo": "enlutar",
    "enlutarmos": "enlutar",
    "enlutará": "enlutar",
    "enlutarás": "enlutar",
    "enlutarão": "enlutar",
    "enlutaríamos": "enlutar",
    "enlutaríeis": "enlutar",
    "enlutas": "enlutar",
    "enlutasse": "enlutar",
    "enlutassem": "enlutar",
    "enlutasses": "enlutar",
    "enlutaste": "enlutar",
    "enlutastes": "enlutar",
    "enlutava": "enlutar",
    "enlutavam": "enlutar",
    "enlutavas": "enlutar",
    "enlute": "enlutar",
    "enlutei": "enlutar",
    "enluteis": "enlutar",
    "enlutem": "enlutar",
    "enlutemo": "enlutar",
    "enlutemos": "enlutar",
    "enlutes": "enlutar",
    "enluto": "enlutar",
    "enlutou": "enlutar",
    "enlutá": "enlutar",
    "enlutámo": "enlutar",
    "enlutámos": "enlutar",
    "enlutáramo": "enlutar",
    "enlutáramos": "enlutar",
    "enlutárei": "enlutar",
    "enlutáreis": "enlutar",
    "enlutásseis": "enlutar",
    "enlutássemos": "enlutar",
    "enlutávamo": "enlutar",
    "enlutávamos": "enlutar",
    "enlutávei": "enlutar",
    "enlutáveis": "enlutar",
    "enluva": "enluvar",
    "enluvada": "enluvar",
    "enluvadas": "enluvar",
    "enluvado": "enluvar",
    "enluvados": "enluvar",
    "enluvai": "enluvar",
    "enluvais": "enluvar",
    "enluvam": "enluvar",
    "enluvamo": "enluvar",
    "enluvamos": "enluvar",
    "enluvando": "enluvar",
    "enluvara": "enluvar",
    "enluvaram": "enluvar",
    "enluvaras": "enluvar",
    "enluvarde": "enluvar",
    "enluvardes": "enluvar",
    "enluvare": "enluvar",
    "enluvarei": "enluvar",
    "enluvareis": "enluvar",
    "enluvarem": "enluvar",
    "enluvaremos": "enluvar",
    "enluvares": "enluvar",
    "enluvaria": "enluvar",
    "enluvariam": "enluvar",
    "enluvarias": "enluvar",
    "enluvarmo": "enluvar",
    "enluvarmos": "enluvar",
    "enluvará": "enluvar",
    "enluvarás": "enluvar",
    "enluvarão": "enluvar",
    "enluvaríamos": "enluvar",
    "enluvaríeis": "enluvar",
    "enluvas": "enluvar",
    "enluvasse": "enluvar",
    "enluvassem": "enluvar",
    "enluvasses": "enluvar",
    "enluvaste": "enluvar",
    "enluvastes": "enluvar",
    "enluvava": "enluvar",
    "enluvavam": "enluvar",
    "enluvavas": "enluvar",
    "enluve": "enluvar",
    "enluvei": "enluvar",
    "enluveis": "enluvar",
    "enluvem": "enluvar",
    "enluvemo": "enluvar",
    "enluvemos": "enluvar",
    "enluves": "enluvar",
    "enluvo": "enluvar",
    "enluvou": "enluvar",
    "enluvá": "enluvar",
    "enluvámo": "enluvar",
    "enluvámos": "enluvar",
    "enluváramo": "enluvar",
    "enluváramos": "enluvar",
    "enluvárei": "enluvar",
    "enluváreis": "enluvar",
    "enluvásseis": "enluvar",
    "enluvássemos": "enluvar",
    "enluvávamo": "enluvar",
    "enluvávamos": "enluvar",
    "enluvávei": "enluvar",
    "enluváveis": "enluvar",
    "enlítica": "enlítico",
    "enlíticas": "enlítico",
    "enlíticos": "enlítico",
    "ennoda": "ennodar",
    "ennodada": "ennodar",
    "ennodadas": "ennodar",
    "ennodado": "ennodar",
    "ennodados": "ennodar",
    "ennodai": "ennodar",
    "ennodais": "ennodar",
    "ennodam": "ennodar",
    "ennodamo": "ennodar",
    "ennodamos": "ennodar",
    "ennodando": "ennodar",
    "ennodara": "ennodar",
    "ennodaram": "ennodar",
    "ennodaras": "ennodar",
    "ennodarde": "ennodar",
    "ennodardes": "ennodar",
    "ennodare": "ennodar",
    "ennodarei": "ennodar",
    "ennodareis": "ennodar",
    "ennodarem": "ennodar",
    "ennodaremos": "ennodar",
    "ennodares": "ennodar",
    "ennodaria": "ennodar",
    "ennodariam": "ennodar",
    "ennodarias": "ennodar",
    "ennodarmo": "ennodar",
    "ennodarmos": "ennodar",
    "ennodará": "ennodar",
    "ennodarás": "ennodar",
    "ennodarão": "ennodar",
    "ennodaríamos": "ennodar",
    "ennodaríeis": "ennodar",
    "ennodas": "ennodar",
    "ennodasse": "ennodar",
    "ennodassem": "ennodar",
    "ennodasses": "ennodar",
    "ennodaste": "ennodar",
    "ennodastes": "ennodar",
    "ennodava": "ennodar",
    "ennodavam": "ennodar",
    "ennodavas": "ennodar",
    "ennode": "ennodar",
    "ennodei": "ennodar",
    "ennodeis": "ennodar",
    "ennodem": "ennodar",
    "ennodemo": "ennodar",
    "ennodemos": "ennodar",
    "ennodes": "ennodar",
    "ennodo": "ennodar",
    "ennodou": "ennodar",
    "ennodá": "ennodar",
    "ennodámo": "ennodar",
    "ennodámos": "ennodar",
    "ennodáramo": "ennodar",
    "ennodáramos": "ennodar",
    "ennodárei": "ennodar",
    "ennodáreis": "ennodar",
    "ennodásseis": "ennodar",
    "ennodássemos": "ennodar",
    "ennodávamo": "ennodar",
    "ennodávamos": "ennodar",
    "ennodávei": "ennodar",
    "ennodáveis": "ennodar",
    "enobrece": "enobrecer",
    "enobrecedora": "enobrecedor",
    "enobrecedoras": "enobrecedor",
    "enobrecedores": "enobrecedor",
    "enobrecei": "enobrecer",
    "enobreceis": "enobrecer",
    "enobrecem": "enobrecer",
    "enobrecemo": "enobrecer",
    "enobrecemos": "enobrecer",
    "enobrecendo": "enobrecer",
    "enobrecera": "enobrecer",
    "enobreceram": "enobrecer",
    "enobreceras": "enobrecer",
    "enobrecerde": "enobrecer",
    "enobrecerdes": "enobrecer",
    "enobrecere": "enobrecer",
    "enobrecerei": "enobrecer",
    "enobrecereis": "enobrecer",
    "enobrecerem": "enobrecer",
    "enobreceremos": "enobrecer",
    "enobreceres": "enobrecer",
    "enobreceria": "enobrecer",
    "enobreceriam": "enobrecer",
    "enobrecerias": "enobrecer",
    "enobrecermo": "enobrecer",
    "enobrecermos": "enobrecer",
    "enobrecerá": "enobrecer",
    "enobrecerás": "enobrecer",
    "enobrecerão": "enobrecer",
    "enobreceríamos": "enobrecer",
    "enobreceríeis": "enobrecer",
    "enobreces": "enobrecer",
    "enobrecesse": "enobrecer",
    "enobrecessem": "enobrecer",
    "enobrecesses": "enobrecer",
    "enobreceste": "enobrecer",
    "enobrecestes": "enobrecer",
    "enobreceu": "enobrecer",
    "enobreci": "enobrecer",
    "enobrecia": "enobrecer",
    "enobreciam": "enobrecer",
    "enobrecias": "enobrecer",
    "enobrecida": "enobrecido",
    "enobrecidas": "enobrecido",
    "enobrecido": "enobrecer",
    "enobrecidos": "enobrecido",
    "enobrecimentos": "enobrecimento",
    "enobrecê": "enobrecer",
    "enobrecêramo": "enobrecer",
    "enobrecêramos": "enobrecer",
    "enobrecêrei": "enobrecer",
    "enobrecêreis": "enobrecer",
    "enobrecêsseis": "enobrecer",
    "enobrecêssemos": "enobrecer",
    "enobrecíamo": "enobrecer",
    "enobrecíamos": "enobrecer",
    "enobrecíei": "enobrecer",
    "enobrecíeis": "enobrecer",
    "enobreça": "enobrecer",
    "enobreçais": "enobrecer",
    "enobreçam": "enobrecer",
    "enobreçamo": "enobrecer",
    "enobreçamos": "enobrecer",
    "enobreças": "enobrecer",
    "enobreço": "enobrecer",
    "enoda": "enodo",
    "enodada": "enodar",
    "enodadas": "enodar",
    "enodado": "enodar",
    "enodados": "enodar",
    "enodai": "enodar",
    "enodais": "enodar",
    "enodam": "enodar",
    "enodamo": "enodar",
    "enodamos": "enodar",
    "enodando": "enodar",
    "enodara": "enodar",
    "enodaram": "enodar",
    "enodaras": "enodar",
    "enodarde": "enodar",
    "enodardes": "enodar",
    "enodare": "enodar",
    "enodarei": "enodar",
    "enodareis": "enodar",
    "enodarem": "enodar",
    "enodaremos": "enodar",
    "enodares": "enodar",
    "enodaria": "enodar",
    "enodariam": "enodar",
    "enodarias": "enodar",
    "enodarmo": "enodar",
    "enodarmos": "enodar",
    "enodará": "enodar",
    "enodarás": "enodar",
    "enodarão": "enodar",
    "enodaríamos": "enodar",
    "enodaríeis": "enodar",
    "enodas": "enodo",
    "enodasse": "enodar",
    "enodassem": "enodar",
    "enodasses": "enodar",
    "enodaste": "enodar",
    "enodastes": "enodar",
    "enodava": "enodar",
    "enodavam": "enodar",
    "enodavas": "enodar",
    "enode": "enodar",
    "enodei": "enodar",
    "enodeis": "enodar",
    "enodem": "enodar",
    "enodemo": "enodar",
    "enodemos": "enodar",
    "enodes": "enode",
    "enodo": "enodar",
    "enodoa": "enodoar",
    "enodoada": "enodoar",
    "enodoadas": "enodoar",
    "enodoado": "enodoar",
    "enodoados": "enodoar",
    "enodoai": "enodoar",
    "enodoais": "enodoar",
    "enodoam": "enodoar",
    "enodoamentos": "enodoamento",
    "enodoamo": "enodoar",
    "enodoamos": "enodoar",
    "enodoando": "enodoar",
    "enodoara": "enodoar",
    "enodoaram": "enodoar",
    "enodoaras": "enodoar",
    "enodoarde": "enodoar",
    "enodoardes": "enodoar",
    "enodoare": "enodoar",
    "enodoarei": "enodoar",
    "enodoareis": "enodoar",
    "enodoarem": "enodoar",
    "enodoaremos": "enodoar",
    "enodoares": "enodoar",
    "enodoaria": "enodoar",
    "enodoariam": "enodoar",
    "enodoarias": "enodoar",
    "enodoarmo": "enodoar",
    "enodoarmos": "enodoar",
    "enodoará": "enodoar",
    "enodoarás": "enodoar",
    "enodoarão": "enodoar",
    "enodoaríamos": "enodoar",
    "enodoaríeis": "enodoar",
    "enodoas": "enodoar",
    "enodoasse": "enodoar",
    "enodoassem": "enodoar",
    "enodoasses": "enodoar",
    "enodoaste": "enodoar",
    "enodoastes": "enodoar",
    "enodoava": "enodoar",
    "enodoavam": "enodoar",
    "enodoavas": "enodoar",
    "enodoações": "enodoação",
    "enodoe": "enodoar",
    "enodoei": "enodoar",
    "enodoeis": "enodoar",
    "enodoem": "enodoar",
    "enodoemo": "enodoar",
    "enodoemos": "enodoar",
    "enodoes": "enodoar",
    "enodoo": "enodoar",
    "enodoou": "enodoar",
    "enodos": "enodo",
    "enodou": "enodar",
    "enodoá": "enodoar",
    "enodoámo": "enodoar",
    "enodoámos": "enodoar",
    "enodoáramo": "enodoar",
    "enodoáramos": "enodoar",
    "enodoárei": "enodoar",
    "enodoáreis": "enodoar",
    "enodoásseis": "enodoar",
    "enodoássemos": "enodoar",
    "enodoávamo": "enodoar",
    "enodoávamos": "enodoar",
    "enodoávei": "enodoar",
    "enodoáveis": "enodoar",
    "enodá": "enodar",
    "enodámo": "enodar",
    "enodámos": "enodar",
    "enodáramo": "enodar",
    "enodáramos": "enodar",
    "enodárei": "enodar",
    "enodáreis": "enodar",
    "enodásseis": "enodar",
    "enodássemos": "enodar",
    "enodávamo": "enodar",
    "enodávamos": "enodar",
    "enodávei": "enodar",
    "enodáveis": "enodar",
    "enofilias": "enofilia",
    "enoftalmias": "enoftalmia",
    "enoftálmica": "enoftálmico",
    "enoftálmicas": "enoftálmico",
    "enoftálmicos": "enoftálmico",
    "enofílica": "enofílico",
    "enofílicas": "enofílico",
    "enofílicos": "enofílico",
    "enografias": "enografia",
    "enográfica": "enográfico",
    "enográficas": "enográfico",
    "enográficos": "enográfico",
    "enoita": "enoitar",
    "enoitada": "enoitar",
    "enoitadas": "enoitar",
    "enoitado": "enoitar",
    "enoitados": "enoitar",
    "enoitai": "enoitar",
    "enoitais": "enoitar",
    "enoitam": "enoitar",
    "enoitamo": "enoitar",
    "enoitamos": "enoitar",
    "enoitando": "enoitar",
    "enoitara": "enoitar",
    "enoitaram": "enoitar",
    "enoitaras": "enoitar",
    "enoitarde": "enoitar",
    "enoitardes": "enoitar",
    "enoitare": "enoitar",
    "enoitarei": "enoitar",
    "enoitareis": "enoitar",
    "enoitarem": "enoitar",
    "enoitaremos": "enoitar",
    "enoitares": "enoitar",
    "enoitaria": "enoitar",
    "enoitariam": "enoitar",
    "enoitarias": "enoitar",
    "enoitarmo": "enoitar",
    "enoitarmos": "enoitar",
    "enoitará": "enoitar",
    "enoitarás": "enoitar",
    "enoitarão": "enoitar",
    "enoitaríamos": "enoitar",
    "enoitaríeis": "enoitar",
    "enoitas": "enoitar",
    "enoitasse": "enoitar",
    "enoitassem": "enoitar",
    "enoitasses": "enoitar",
    "enoitaste": "enoitar",
    "enoitastes": "enoitar",
    "enoitava": "enoitar",
    "enoitavam": "enoitar",
    "enoitavas": "enoitar",
    "enoite": "enoitar",
    "enoitece": "enoitecer",
    "enoitecei": "enoitecer",
    "enoiteceis": "enoitecer",
    "enoitecem": "enoitecer",
    "enoitecemo": "enoitecer",
    "enoitecemos": "enoitecer",
    "enoitecendo": "enoitecer",
    "enoitecera": "enoitecer",
    "enoiteceram": "enoitecer",
    "enoiteceras": "enoitecer",
    "enoitecerdes": "enoitecer",
    "enoitecerei": "enoitecer",
    "enoitecereis": "enoitecer",
    "enoitecerem": "enoitecer",
    "enoiteceremos": "enoitecer",
    "enoiteceres": "enoitecer",
    "enoiteceria": "enoitecer",
    "enoiteceriam": "enoitecer",
    "enoitecerias": "enoitecer",
    "enoitecermo": "enoitecer",
    "enoitecermos": "enoitecer",
    "enoitecerá": "enoitecer",
    "enoitecerás": "enoitecer",
    "enoitecerão": "enoitecer",
    "enoiteceríamos": "enoitecer",
    "enoiteceríeis": "enoitecer",
    "enoiteces": "enoitecer",
    "enoitecesse": "enoitecer",
    "enoitecessem": "enoitecer",
    "enoitecesses": "enoitecer",
    "enoiteceste": "enoitecer",
    "enoitecestes": "enoitecer",
    "enoiteceu": "enoitecer",
    "enoiteci": "enoitecer",
    "enoitecia": "enoitecer",
    "enoiteciam": "enoitecer",
    "enoitecias": "enoitecer",
    "enoitecida": "enoitecer",
    "enoitecidas": "enoitecer",
    "enoitecido": "enoitecer",
    "enoitecidos": "enoitecer",
    "enoitecêramo": "enoitecer",
    "enoitecêramos": "enoitecer",
    "enoitecêreis": "enoitecer",
    "enoitecêsseis": "enoitecer",
    "enoitecêssemos": "enoitecer",
    "enoitecíamo": "enoitecer",
    "enoitecíamos": "enoitecer",
    "enoitecíeis": "enoitecer",
    "enoitei": "enoitar",
    "enoiteis": "enoitar",
    "enoitem": "enoitar",
    "enoitemo": "enoitar",
    "enoitemos": "enoitar",
    "enoites": "enoitar",
    "enoiteça": "enoitecer",
    "enoiteçais": "enoitecer",
    "enoiteçam": "enoitecer",
    "enoiteçamo": "enoitecer",
    "enoiteçamos": "enoitecer",
    "enoiteças": "enoitecer",
    "enoiteço": "enoitecer",
    "enoito": "enoitar",
    "enoitou": "enoitar",
    "enoitá": "enoitar",
    "enoitámo": "enoitar",
    "enoitámos": "enoitar",
    "enoitáramo": "enoitar",
    "enoitáramos": "enoitar",
    "enoitárei": "enoitar",
    "enoitáreis": "enoitar",
    "enoitásseis": "enoitar",
    "enoitássemos": "enoitar",
    "enoitávamo": "enoitar",
    "enoitávamos": "enoitar",
    "enoitávei": "enoitar",
    "enoitáveis": "enoitar",
    "enoja": "enojar",
    "enojada": "enojar",
    "enojadas": "enojar",
    "enojadiça": "enojadiço",
    "enojadiças": "enojadiço",
    "enojadiços": "enojadiço",
    "enojado": "enojar",
    "enojadora": "enojador",
    "enojadoras": "enojador",
    "enojadores": "enojador",
    "enojados": "enojar",
    "enojai": "enojar",
    "enojais": "enojar",
    "enojam": "enojar",
    "enojamentos": "enojamento",
    "enojamo": "enojar",
    "enojamos": "enojar",
    "enojando": "enojar",
    "enojara": "enojar",
    "enojaram": "enojar",
    "enojaras": "enojar",
    "enojarde": "enojar",
    "enojardes": "enojar",
    "enojare": "enojar",
    "enojarei": "enojar",
    "enojareis": "enojar",
    "enojarem": "enojar",
    "enojaremos": "enojar",
    "enojares": "enojar",
    "enojaria": "enojar",
    "enojariam": "enojar",
    "enojarias": "enojar",
    "enojarmo": "enojar",
    "enojarmos": "enojar",
    "enojará": "enojar",
    "enojarás": "enojar",
    "enojarão": "enojar",
    "enojaríamos": "enojar",
    "enojaríeis": "enojar",
    "enojas": "enojar",
    "enojasse": "enojar",
    "enojassem": "enojar",
    "enojasses": "enojar",
    "enojaste": "enojar",
    "enojastes": "enojar",
    "enojava": "enojar",
    "enojavam": "enojar",
    "enojavas": "enojar",
    "enoje": "enojar",
    "enojei": "enojar",
    "enojeis": "enojar",
    "enojem": "enojar",
    "enojemo": "enojar",
    "enojemos": "enojar",
    "enojes": "enojar",
    "enojo": "enojar",
    "enojos": "enojo",
    "enojou": "enojar",
    "enojá": "enojar",
    "enojámo": "enojar",
    "enojámos": "enojar",
    "enojáramo": "enojar",
    "enojáramos": "enojar",
    "enojárei": "enojar",
    "enojáreis": "enojar",
    "enojásseis": "enojar",
    "enojássemos": "enojar",
    "enojávamo": "enojar",
    "enojávamos": "enojar",
    "enojávei": "enojar",
    "enojáveis": "enojar",
    "enolinas": "enolina",
    "enolismos": "enolismo",
    "enologias": "enologia",
    "enologistas": "enologista",
    "enológica": "enológico",
    "enológicas": "enológico",
    "enológicos": "enológico",
    "enomancias": "enomancia",
    "enomanias": "enomania",
    "enomantes": "enomante",
    "enomaníaca": "enomaníaco",
    "enomaníacas": "enomaníaco",
    "enomaníacos": "enomaníaco",
    "enomeles": "enomel",
    "enometrias": "enometria",
    "enomântica": "enomântico",
    "enomânticas": "enomântico",
    "enomânticos": "enomântico",
    "enoméis": "enomel",
    "enométrica": "enométrico",
    "enométricas": "enométrico",
    "enométricos": "enométrico",
    "enoques": "enoque",
    "enoras": "enora",
    "enormes": "enorme",
    "enormidades": "enormidade",
    "enormíssima": "enorme",
    "enormíssimas": "enorme",
    "enormíssimo": "enorme",
    "enormíssimos": "enorme",
    "enosilha": "enosilhar",
    "enosilhada": "enosilhar",
    "enosilhadas": "enosilhar",
    "enosilhado": "enosilhar",
    "enosilhados": "enosilhar",
    "enosilhai": "enosilhar",
    "enosilhais": "enosilhar",
    "enosilham": "enosilhar",
    "enosilhamo": "enosilhar",
    "enosilhamos": "enosilhar",
    "enosilhando": "enosilhar",
    "enosilhara": "enosilhar",
    "enosilharam": "enosilhar",
    "enosilharas": "enosilhar",
    "enosilhardes": "enosilhar",
    "enosilharei": "enosilhar",
    "enosilhareis": "enosilhar",
    "enosilharem": "enosilhar",
    "enosilharemos": "enosilhar",
    "enosilhares": "enosilhar",
    "enosilharia": "enosilhar",
    "enosilhariam": "enosilhar",
    "enosilharias": "enosilhar",
    "enosilharmo": "enosilhar",
    "enosilharmos": "enosilhar",
    "enosilhará": "enosilhar",
    "enosilharás": "enosilhar",
    "enosilharão": "enosilhar",
    "enosilharíamos": "enosilhar",
    "enosilharíeis": "enosilhar",
    "enosilhas": "enosilhar",
    "enosilhasse": "enosilhar",
    "enosilhassem": "enosilhar",
    "enosilhasses": "enosilhar",
    "enosilhaste": "enosilhar",
    "enosilhastes": "enosilhar",
    "enosilhava": "enosilhar",
    "enosilhavam": "enosilhar",
    "enosilhavas": "enosilhar",
    "enosilhe": "enosilhar",
    "enosilhei": "enosilhar",
    "enosilheis": "enosilhar",
    "enosilhem": "enosilhar",
    "enosilhemo": "enosilhar",
    "enosilhemos": "enosilhar",
    "enosilhes": "enosilhar",
    "enosilho": "enosilhar",
    "enosilhou": "enosilhar",
    "enosilhámo": "enosilhar",
    "enosilhámos": "enosilhar",
    "enosilháramo": "enosilhar",
    "enosilháramos": "enosilhar",
    "enosilháreis": "enosilhar",
    "enosilhásseis": "enosilhar",
    "enosilhássemos": "enosilhar",
    "enosilhávamo": "enosilhar",
    "enosilhávamos": "enosilhar",
    "enosilháveis": "enosilhar",
    "enosteoses": "enosteose",
    "enostoses": "enostose",
    "enotecnias": "enotecnia",
    "enotermos": "enotermo",
    "enoteráceas": "enoterácea",
    "enotécnica": "enotécnico",
    "enotécnicas": "enotécnico",
    "enotécnicos": "enotécnico",
    "enourice": "enouriçar",
    "enouricei": "enouriçar",
    "enouriceis": "enouriçar",
    "enouricem": "enouriçar",
    "enouricemo": "enouriçar",
    "enouricemos": "enouriçar",
    "enourices": "enouriçar",
    "enouriça": "enouriçar",
    "enouriçada": "enouriçar",
    "enouriçadas": "enouriçar",
    "enouriçado": "enouriçar",
    "enouriçados": "enouriçar",
    "enouriçai": "enouriçar",
    "enouriçais": "enouriçar",
    "enouriçam": "enouriçar",
    "enouriçamo": "enouriçar",
    "enouriçamos": "enouriçar",
    "enouriçando": "enouriçar",
    "enouriçara": "enouriçar",
    "enouriçaram": "enouriçar",
    "enouriçaras": "enouriçar",
    "enouriçardes": "enouriçar",
    "enouriçarei": "enouriçar",
    "enouriçareis": "enouriçar",
    "enouriçarem": "enouriçar",
    "enouriçaremos": "enouriçar",
    "enouriçares": "enouriçar",
    "enouriçaria": "enouriçar",
    "enouriçariam": "enouriçar",
    "enouriçarias": "enouriçar",
    "enouriçarmo": "enouriçar",
    "enouriçarmos": "enouriçar",
    "enouriçará": "enouriçar",
    "enouriçarás": "enouriçar",
    "enouriçarão": "enouriçar",
    "enouriçaríamos": "enouriçar",
    "enouriçaríeis": "enouriçar",
    "enouriças": "enouriçar",
    "enouriçasse": "enouriçar",
    "enouriçassem": "enouriçar",
    "enouriçasses": "enouriçar",
    "enouriçaste": "enouriçar",
    "enouriçastes": "enouriçar",
    "enouriçava": "enouriçar",
    "enouriçavam": "enouriçar",
    "enouriçavas": "enouriçar",
    "enouriço": "enouriçar",
    "enouriçou": "enouriçar",
    "enouriçámo": "enouriçar",
    "enouriçámos": "enouriçar",
    "enouriçáramo": "enouriçar",
    "enouriçáramos": "enouriçar",
    "enouriçáreis": "enouriçar",
    "enouriçásseis": "enouriçar",
    "enouriçássemos": "enouriçar",
    "enouriçávamo": "enouriçar",
    "enouriçávamos": "enouriçar",
    "enouriçáveis": "enouriçar",
    "enouta": "enoutar",
    "enoutada": "enoutar",
    "enoutadas": "enoutar",
    "enoutado": "enoutar",
    "enoutados": "enoutar",
    "enoutai": "enoutar",
    "enoutais": "enoutar",
    "enoutam": "enoutar",
    "enoutamo": "enoutar",
    "enoutamos": "enoutar",
    "enoutando": "enoutar",
    "enoutara": "enoutar",
    "enoutaram": "enoutar",
    "enoutaras": "enoutar",
    "enoutarde": "enoutar",
    "enoutardes": "enoutar",
    "enoutare": "enoutar",
    "enoutarei": "enoutar",
    "enoutareis": "enoutar",
    "enoutarem": "enoutar",
    "enoutaremos": "enoutar",
    "enoutares": "enoutar",
    "enoutaria": "enoutar",
    "enoutariam": "enoutar",
    "enoutarias": "enoutar",
    "enoutarmo": "enoutar",
    "enoutarmos": "enoutar",
    "enoutará": "enoutar",
    "enoutarás": "enoutar",
    "enoutarão": "enoutar",
    "enoutaríamos": "enoutar",
    "enoutaríeis": "enoutar",
    "enoutas": "enoutar",
    "enoutasse": "enoutar",
    "enoutassem": "enoutar",
    "enoutasses": "enoutar",
    "enoutaste": "enoutar",
    "enoutastes": "enoutar",
    "enoutava": "enoutar",
    "enoutavam": "enoutar",
    "enoutavas": "enoutar",
    "enoute": "enoutar",
    "enoutece": "enoutecer",
    "enoutecei": "enoutecer",
    "enouteceis": "enoutecer",
    "enoutecem": "enoutecer",
    "enoutecemo": "enoutecer",
    "enoutecemos": "enoutecer",
    "enoutecendo": "enoutecer",
    "enoutecera": "enoutecer",
    "enouteceram": "enoutecer",
    "enouteceras": "enoutecer",
    "enoutecerdes": "enoutecer",
    "enoutecerei": "enoutecer",
    "enoutecereis": "enoutecer",
    "enoutecerem": "enoutecer",
    "enouteceremos": "enoutecer",
    "enouteceres": "enoutecer",
    "enouteceria": "enoutecer",
    "enouteceriam": "enoutecer",
    "enoutecerias": "enoutecer",
    "enoutecermo": "enoutecer",
    "enoutecermos": "enoutecer",
    "enoutecerá": "enoutecer",
    "enoutecerás": "enoutecer",
    "enoutecerão": "enoutecer",
    "enouteceríamos": "enoutecer",
    "enouteceríeis": "enoutecer",
    "enouteces": "enoutecer",
    "enoutecesse": "enoutecer",
    "enoutecessem": "enoutecer",
    "enoutecesses": "enoutecer",
    "enouteceste": "enoutecer",
    "enoutecestes": "enoutecer",
    "enouteceu": "enoutecer",
    "enouteci": "enoutecer",
    "enoutecia": "enoutecer",
    "enouteciam": "enoutecer",
    "enoutecias": "enoutecer",
    "enoutecida": "enoutecer",
    "enoutecidas": "enoutecer",
    "enoutecido": "enoutecer",
    "enoutecidos": "enoutecer",
    "enoutecêramo": "enoutecer",
    "enoutecêramos": "enoutecer",
    "enoutecêreis": "enoutecer",
    "enoutecêsseis": "enoutecer",
    "enoutecêssemos": "enoutecer",
    "enoutecíamo": "enoutecer",
    "enoutecíamos": "enoutecer",
    "enoutecíeis": "enoutecer",
    "enoutei": "enoutar",
    "enouteis": "enoutar",
    "enoutem": "enoutar",
    "enoutemo": "enoutar",
    "enoutemos": "enoutar",
    "enoutes": "enoutar",
    "enouteça": "enoutecer",
    "enouteçais": "enoutecer",
    "enouteçam": "enoutecer",
    "enouteçamo": "enoutecer",
    "enouteçamos": "enoutecer",
    "enouteças": "enoutecer",
    "enouteço": "enoutecer",
    "enouto": "enoutar",
    "enoutou": "enoutar",
    "enoutá": "enoutar",
    "enoutámo": "enoutar",
    "enoutámos": "enoutar",
    "enoutáramo": "enoutar",
    "enoutáramos": "enoutar",
    "enoutárei": "enoutar",
    "enoutáreis": "enoutar",
    "enoutásseis": "enoutar",
    "enoutássemos": "enoutar",
    "enoutávamo": "enoutar",
    "enoutávamos": "enoutar",
    "enoutávei": "enoutar",
    "enoutáveis": "enoutar",
    "enovela": "enovelar",
    "enovelada": "enovelar",
    "enoveladas": "enovelar",
    "enoveladeiras": "enoveladeira",
    "enovelado": "enovelar",
    "enovelados": "enovelar",
    "enovelai": "enovelar",
    "enovelais": "enovelar",
    "enovelam": "enovelar",
    "enovelamentos": "enovelamento",
    "enovelamo": "enovelar",
    "enovelamos": "enovelar",
    "enovelando": "enovelar",
    "enovelara": "enovelar",
    "enovelaram": "enovelar",
    "enovelaras": "enovelar",
    "enovelarde": "enovelar",
    "enovelardes": "enovelar",
    "enovelare": "enovelar",
    "enovelarei": "enovelar",
    "enovelareis": "enovelar",
    "enovelarem": "enovelar",
    "enovelaremos": "enovelar",
    "enovelares": "enovelar",
    "enovelaria": "enovelar",
    "enovelariam": "enovelar",
    "enovelarias": "enovelar",
    "enovelarmo": "enovelar",
    "enovelarmos": "enovelar",
    "enovelará": "enovelar",
    "enovelarás": "enovelar",
    "enovelarão": "enovelar",
    "enovelaríamos": "enovelar",
    "enovelaríeis": "enovelar",
    "enovelas": "enovelar",
    "enovelasse": "enovelar",
    "enovelassem": "enovelar",
    "enovelasses": "enovelar",
    "enovelaste": "enovelar",
    "enovelastes": "enovelar",
    "enovelava": "enovelar",
    "enovelavam": "enovelar",
    "enovelavas": "enovelar",
    "enovele": "enovelar",
    "enovelei": "enovelar",
    "enoveleis": "enovelar",
    "enovelem": "enovelar",
    "enovelemo": "enovelar",
    "enovelemos": "enovelar",
    "enoveles": "enovelar",
    "enovelo": "enovelar",
    "enovelou": "enovelar",
    "enovelá": "enovelar",
    "enovelámo": "enovelar",
    "enovelámos": "enovelar",
    "enoveláramo": "enovelar",
    "enoveláramos": "enovelar",
    "enovelárei": "enovelar",
    "enoveláreis": "enovelar",
    "enovelásseis": "enovelar",
    "enovelássemos": "enovelar",
    "enovelávamo": "enovelar",
    "enovelávamos": "enovelar",
    "enovelávei": "enovelar",
    "enoveláveis": "enovelar",
    "enquadra": "enquadrar",
    "enquadrada": "enquadrar",
    "enquadradas": "enquadrar",
    "enquadrado": "enquadrar",
    "enquadrados": "enquadrar",
    "enquadradíssima": "enquadrado",
    "enquadradíssimas": "enquadrado",
    "enquadradíssimo": "enquadrado",
    "enquadradíssimos": "enquadrado",
    "enquadrai": "enquadrar",
    "enquadrais": "enquadrar",
    "enquadram": "enquadrar",
    "enquadramentos": "enquadramento",
    "enquadramo": "enquadrar",
    "enquadramos": "enquadrar",
    "enquadrando": "enquadrar",
    "enquadrara": "enquadrar",
    "enquadraram": "enquadrar",
    "enquadraras": "enquadrar",
    "enquadrarde": "enquadrar",
    "enquadrardes": "enquadrar",
    "enquadrare": "enquadrar",
    "enquadrarei": "enquadrar",
    "enquadrareis": "enquadrar",
    "enquadrarem": "enquadrar",
    "enquadraremos": "enquadrar",
    "enquadrares": "enquadrar",
    "enquadraria": "enquadrar",
    "enquadrariam": "enquadrar",
    "enquadrarias": "enquadrar",
    "enquadrarmo": "enquadrar",
    "enquadrarmos": "enquadrar",
    "enquadrará": "enquadrar",
    "enquadrarás": "enquadrar",
    "enquadrarão": "enquadrar",
    "enquadraríamos": "enquadrar",
    "enquadraríeis": "enquadrar",
    "enquadras": "enquadrar",
    "enquadrasse": "enquadrar",
    "enquadrassem": "enquadrar",
    "enquadrasses": "enquadrar",
    "enquadraste": "enquadrar",
    "enquadrastes": "enquadrar",
    "enquadrava": "enquadrar",
    "enquadravam": "enquadrar",
    "enquadravas": "enquadrar",
    "enquadre": "enquadrar",
    "enquadrei": "enquadrar",
    "enquadreis": "enquadrar",
    "enquadrem": "enquadrar",
    "enquadremo": "enquadrar",
    "enquadremos": "enquadrar",
    "enquadres": "enquadrar",
    "enquadro": "enquadrar",
    "enquadrou": "enquadrar",
    "enquadrá": "enquadrar",
    "enquadrámo": "enquadrar",
    "enquadrámos": "enquadrar",
    "enquadráramo": "enquadrar",
    "enquadráramos": "enquadrar",
    "enquadrárei": "enquadrar",
    "enquadráreis": "enquadrar",
    "enquadrásseis": "enquadrar",
    "enquadrássemos": "enquadrar",
    "enquadrávamo": "enquadrar",
    "enquadrávamos": "enquadrar",
    "enquadrávei": "enquadrar",
    "enquadráveis": "enquadrável",
    "enqueija": "enqueijar",
    "enqueijada": "enqueijar",
    "enqueijadas": "enqueijar",
    "enqueijado": "enqueijar",
    "enqueijados": "enqueijar",
    "enqueijai": "enqueijar",
    "enqueijais": "enqueijar",
    "enqueijam": "enqueijar",
    "enqueijamo": "enqueijar",
    "enqueijamos": "enqueijar",
    "enqueijando": "enqueijar",
    "enqueijara": "enqueijar",
    "enqueijaram": "enqueijar",
    "enqueijaras": "enqueijar",
    "enqueijardes": "enqueijar",
    "enqueijarei": "enqueijar",
    "enqueijareis": "enqueijar",
    "enqueijarem": "enqueijar",
    "enqueijaremos": "enqueijar",
    "enqueijares": "enqueijar",
    "enqueijaria": "enqueijar",
    "enqueijariam": "enqueijar",
    "enqueijarias": "enqueijar",
    "enqueijarmo": "enqueijar",
    "enqueijarmos": "enqueijar",
    "enqueijará": "enqueijar",
    "enqueijarás": "enqueijar",
    "enqueijarão": "enqueijar",
    "enqueijaríamos": "enqueijar",
    "enqueijaríeis": "enqueijar",
    "enqueijas": "enqueijar",
    "enqueijasse": "enqueijar",
    "enqueijassem": "enqueijar",
    "enqueijasses": "enqueijar",
    "enqueijaste": "enqueijar",
    "enqueijastes": "enqueijar",
    "enqueijava": "enqueijar",
    "enqueijavam": "enqueijar",
    "enqueijavas": "enqueijar",
    "enqueije": "enqueijar",
    "enqueijei": "enqueijar",
    "enqueijeis": "enqueijar",
    "enqueijem": "enqueijar",
    "enqueijemo": "enqueijar",
    "enqueijemos": "enqueijar",
    "enqueijes": "enqueijar",
    "enqueijo": "enqueijar",
    "enqueijou": "enqueijar",
    "enqueijámo": "enqueijar",
    "enqueijámos": "enqueijar",
    "enqueijáramo": "enqueijar",
    "enqueijáramos": "enqueijar",
    "enqueijáreis": "enqueijar",
    "enqueijásseis": "enqueijar",
    "enqueijássemos": "enqueijar",
    "enqueijávamo": "enqueijar",
    "enqueijávamos": "enqueijar",
    "enqueijáveis": "enqueijar",
    "enquere": "enquerir",
    "enquerem": "enquerir",
    "enqueres": "enquerir",
    "enqueri": "enquerir",
    "enqueria": "enquerir",
    "enqueriam": "enquerir",
    "enquerias": "enquerir",
    "enquerida": "enquerir",
    "enqueridas": "enquerir",
    "enquerideiras": "enquerideira",
    "enquerido": "enquerir",
    "enqueridos": "enquerir",
    "enquerimo": "enquerir",
    "enquerimos": "enquerir",
    "enquerindo": "enquerir",
    "enquerira": "enquerir",
    "enqueriram": "enquerir",
    "enqueriras": "enquerir",
    "enquerirde": "enquerir",
    "enquerirdes": "enquerir",
    "enquerire": "enquerir",
    "enquerirei": "enquerir",
    "enquerireis": "enquerir",
    "enquerirem": "enquerir",
    "enqueriremos": "enquerir",
    "enquerires": "enquerir",
    "enqueriria": "enquerir",
    "enqueririam": "enquerir",
    "enqueririas": "enquerir",
    "enquerirmo": "enquerir",
    "enquerirmos": "enquerir",
    "enquerirá": "enquerir",
    "enquerirás": "enquerir",
    "enquerirão": "enquerir",
    "enqueriríamos": "enquerir",
    "enqueriríeis": "enquerir",
    "enqueris": "enquerir",
    "enquerisse": "enquerir",
    "enquerissem": "enquerir",
    "enquerisses": "enquerir",
    "enqueriste": "enquerir",
    "enqueristes": "enquerir",
    "enqueriu": "enquerir",
    "enqueríamo": "enquerir",
    "enqueríamos": "enquerir",
    "enqueríei": "enquerir",
    "enqueríeis": "enquerir",
    "enqueríramo": "enquerir",
    "enqueríramos": "enquerir",
    "enquerírei": "enquerir",
    "enqueríreis": "enquerir",
    "enquerísseis": "enquerir",
    "enqueríssemos": "enquerir",
    "enques": "enque",
    "enquilha": "enquilhar",
    "enquilhada": "enquilhar",
    "enquilhadas": "enquilhar",
    "enquilhado": "enquilhar",
    "enquilhados": "enquilhar",
    "enquilhai": "enquilhar",
    "enquilhais": "enquilhar",
    "enquilham": "enquilhar",
    "enquilhamo": "enquilhar",
    "enquilhamos": "enquilhar",
    "enquilhando": "enquilhar",
    "enquilhara": "enquilhar",
    "enquilharam": "enquilhar",
    "enquilharas": "enquilhar",
    "enquilharde": "enquilhar",
    "enquilhardes": "enquilhar",
    "enquilhare": "enquilhar",
    "enquilharei": "enquilhar",
    "enquilhareis": "enquilhar",
    "enquilharem": "enquilhar",
    "enquilharemos": "enquilhar",
    "enquilhares": "enquilhar",
    "enquilharia": "enquilhar",
    "enquilhariam": "enquilhar",
    "enquilharias": "enquilhar",
    "enquilharmo": "enquilhar",
    "enquilharmos": "enquilhar",
    "enquilhará": "enquilhar",
    "enquilharás": "enquilhar",
    "enquilharão": "enquilhar",
    "enquilharíamos": "enquilhar",
    "enquilharíeis": "enquilhar",
    "enquilhas": "enquilhar",
    "enquilhasse": "enquilhar",
    "enquilhassem": "enquilhar",
    "enquilhasses": "enquilhar",
    "enquilhaste": "enquilhar",
    "enquilhastes": "enquilhar",
    "enquilhava": "enquilhar",
    "enquilhavam": "enquilhar",
    "enquilhavas": "enquilhar",
    "enquilhe": "enquilhar",
    "enquilhei": "enquilhar",
    "enquilheis": "enquilhar",
    "enquilhem": "enquilhar",
    "enquilhemo": "enquilhar",
    "enquilhemos": "enquilhar",
    "enquilhes": "enquilhar",
    "enquilho": "enquilhar",
    "enquilhou": "enquilhar",
    "enquilhá": "enquilhar",
    "enquilhámo": "enquilhar",
    "enquilhámos": "enquilhar",
    "enquilháramo": "enquilhar",
    "enquilháramos": "enquilhar",
    "enquilhárei": "enquilhar",
    "enquilháreis": "enquilhar",
    "enquilhásseis": "enquilhar",
    "enquilhássemos": "enquilhar",
    "enquilhávamo": "enquilhar",
    "enquilhávamos": "enquilhar",
    "enquilhávei": "enquilhar",
    "enquilháveis": "enquilhar",
    "enquimoses": "enquimose",
    "enquimótica": "enquimótico",
    "enquimóticas": "enquimótico",
    "enquimóticos": "enquimótico",
    "enquira": "enquerir",
    "enquirais": "enquerir",
    "enquiram": "enquerir",
    "enquiramo": "enquerir",
    "enquiramos": "enquerir",
    "enquiras": "enquerir",
    "enquiro": "enquerir",
    "enquirídios": "enquirídio",
    "enquista": "enquistar",
    "enquistada": "enquistar",
    "enquistadas": "enquistar",
    "enquistado": "enquistar",
    "enquistados": "enquistar",
    "enquistai": "enquistar",
    "enquistais": "enquistar",
    "enquistam": "enquistar",
    "enquistamentos": "enquistamento",
    "enquistamo": "enquistar",
    "enquistamos": "enquistar",
    "enquistando": "enquistar",
    "enquistara": "enquistar",
    "enquistaram": "enquistar",
    "enquistaras": "enquistar",
    "enquistardes": "enquistar",
    "enquistarei": "enquistar",
    "enquistareis": "enquistar",
    "enquistarem": "enquistar",
    "enquistaremos": "enquistar",
    "enquistares": "enquistar",
    "enquistaria": "enquistar",
    "enquistariam": "enquistar",
    "enquistarias": "enquistar",
    "enquistarmo": "enquistar",
    "enquistarmos": "enquistar",
    "enquistará": "enquistar",
    "enquistarás": "enquistar",
    "enquistarão": "enquistar",
    "enquistaríamos": "enquistar",
    "enquistaríeis": "enquistar",
    "enquistas": "enquistar",
    "enquistasse": "enquistar",
    "enquistassem": "enquistar",
    "enquistasses": "enquistar",
    "enquistaste": "enquistar",
    "enquistastes": "enquistar",
    "enquistava": "enquistar",
    "enquistavam": "enquistar",
    "enquistavas": "enquistar",
    "enquiste": "enquistar",
    "enquistei": "enquistar",
    "enquisteis": "enquistar",
    "enquistem": "enquistar",
    "enquistemo": "enquistar",
    "enquistemos": "enquistar",
    "enquistes": "enquistar",
    "enquisto": "enquistar",
    "enquistou": "enquistar",
    "enquistámo": "enquistar",
    "enquistámos": "enquistar",
    "enquistáramo": "enquistar",
    "enquistáramos": "enquistar",
    "enquistáreis": "enquistar",
    "enquistásseis": "enquistar",
    "enquistássemos": "enquistar",
    "enquistávamo": "enquistar",
    "enquistávamos": "enquistar",
    "enquistáveis": "enquistar",
    "enraba": "enrabar",
    "enrabada": "enrabar",
    "enrabadas": "enrabar",
    "enrabado": "enrabar",
    "enrabados": "enrabar",
    "enrabai": "enrabar",
    "enrabais": "enrabar",
    "enrabam": "enrabar",
    "enrabamentos": "enrabamento",
    "enrabamo": "enrabar",
    "enrabamos": "enrabar",
    "enrabando": "enrabar",
    "enrabara": "enrabar",
    "enrabaram": "enrabar",
    "enrabaras": "enrabar",
    "enrabarde": "enrabar",
    "enrabardes": "enrabar",
    "enrabare": "enrabar",
    "enrabarei": "enrabar",
    "enrabareis": "enrabar",
    "enrabarem": "enrabar",
    "enrabaremos": "enrabar",
    "enrabares": "enrabar",
    "enrabaria": "enrabar",
    "enrabariam": "enrabar",
    "enrabarias": "enrabar",
    "enrabarmo": "enrabar",
    "enrabarmos": "enrabar",
    "enrabará": "enrabar",
    "enrabarás": "enrabar",
    "enrabarão": "enrabar",
    "enrabaríamos": "enrabar",
    "enrabaríeis": "enrabar",
    "enrabas": "enrabar",
    "enrabasse": "enrabar",
    "enrabassem": "enrabar",
    "enrabasses": "enrabar",
    "enrabaste": "enrabar",
    "enrabastes": "enrabar",
    "enrabava": "enrabar",
    "enrabavam": "enrabar",
    "enrabavas": "enrabar",
    "enrabe": "enrabar",
    "enrabei": "enrabar",
    "enrabeira": "enrabeirar",
    "enrabeirada": "enrabeirar",
    "enrabeiradas": "enrabeirar",
    "enrabeirado": "enrabeirar",
    "enrabeirados": "enrabeirar",
    "enrabeirai": "enrabeirar",
    "enrabeirais": "enrabeirar",
    "enrabeiram": "enrabeirar",
    "enrabeiramo": "enrabeirar",
    "enrabeiramos": "enrabeirar",
    "enrabeirando": "enrabeirar",
    "enrabeirara": "enrabeirar",
    "enrabeiraram": "enrabeirar",
    "enrabeiraras": "enrabeirar",
    "enrabeirarde": "enrabeirar",
    "enrabeirardes": "enrabeirar",
    "enrabeirare": "enrabeirar",
    "enrabeirarei": "enrabeirar",
    "enrabeirareis": "enrabeirar",
    "enrabeirarem": "enrabeirar",
    "enrabeiraremos": "enrabeirar",
    "enrabeirares": "enrabeirar",
    "enrabeiraria": "enrabeirar",
    "enrabeirariam": "enrabeirar",
    "enrabeirarias": "enrabeirar",
    "enrabeirarmo": "enrabeirar",
    "enrabeirarmos": "enrabeirar",
    "enrabeirará": "enrabeirar",
    "enrabeirarás": "enrabeirar",
    "enrabeirarão": "enrabeirar",
    "enrabeiraríamos": "enrabeirar",
    "enrabeiraríeis": "enrabeirar",
    "enrabeiras": "enrabeirar",
    "enrabeirasse": "enrabeirar",
    "enrabeirassem": "enrabeirar",
    "enrabeirasses": "enrabeirar",
    "enrabeiraste": "enrabeirar",
    "enrabeirastes": "enrabeirar",
    "enrabeirava": "enrabeirar",
    "enrabeiravam": "enrabeirar",
    "enrabeiravas": "enrabeirar",
    "enrabeire": "enrabeirar",
    "enrabeirei": "enrabeirar",
    "enrabeireis": "enrabeirar",
    "enrabeirem": "enrabeirar",
    "enrabeiremo": "enrabeirar",
    "enrabeiremos": "enrabeirar",
    "enrabeires": "enrabeirar",
    "enrabeiro": "enrabeirar",
    "enrabeirou": "enrabeirar",
    "enrabeirá": "enrabeirar",
    "enrabeirámo": "enrabeirar",
    "enrabeirámos": "enrabeirar",
    "enrabeiráramo": "enrabeirar",
    "enrabeiráramos": "enrabeirar",
    "enrabeirárei": "enrabeirar",
    "enrabeiráreis": "enrabeirar",
    "enrabeirásseis": "enrabeirar",
    "enrabeirássemos": "enrabeirar",
    "enrabeirávamo": "enrabeirar",
    "enrabeirávamos": "enrabeirar",
    "enrabeirávei": "enrabeirar",
    "enrabeiráveis": "enrabeirar",
    "enrabeis": "enrabar",
    "enrabem": "enrabar",
    "enrabemo": "enrabar",
    "enrabemos": "enrabar",
    "enrabes": "enrabar",
    "enrabicha": "enrabichar",
    "enrabichada": "enrabichar",
    "enrabichadas": "enrabichar",
    "enrabichado": "enrabichar",
    "enrabichados": "enrabichar",
    "enrabichai": "enrabichar",
    "enrabichais": "enrabichar",
    "enrabicham": "enrabichar",
    "enrabichamo": "enrabichar",
    "enrabichamos": "enrabichar",
    "enrabichando": "enrabichar",
    "enrabichara": "enrabichar",
    "enrabicharam": "enrabichar",
    "enrabicharas": "enrabichar",
    "enrabicharde": "enrabichar",
    "enrabichardes": "enrabichar",
    "enrabichare": "enrabichar",
    "enrabicharei": "enrabichar",
    "enrabichareis": "enrabichar",
    "enrabicharem": "enrabichar",
    "enrabicharemos": "enrabichar",
    "enrabichares": "enrabichar",
    "enrabicharia": "enrabichar",
    "enrabichariam": "enrabichar",
    "enrabicharias": "enrabichar",
    "enrabicharmo": "enrabichar",
    "enrabicharmos": "enrabichar",
    "enrabichará": "enrabichar",
    "enrabicharás": "enrabichar",
    "enrabicharão": "enrabichar",
    "enrabicharíamos": "enrabichar",
    "enrabicharíeis": "enrabichar",
    "enrabichas": "enrabichar",
    "enrabichasse": "enrabichar",
    "enrabichassem": "enrabichar",
    "enrabichasses": "enrabichar",
    "enrabichaste": "enrabichar",
    "enrabichastes": "enrabichar",
    "enrabichava": "enrabichar",
    "enrabichavam": "enrabichar",
    "enrabichavas": "enrabichar",
    "enrabiche": "enrabichar",
    "enrabichei": "enrabichar",
    "enrabicheis": "enrabichar",
    "enrabichem": "enrabichar",
    "enrabichemo": "enrabichar",
    "enrabichemos": "enrabichar",
    "enrabiches": "enrabichar",
    "enrabicho": "enrabichar",
    "enrabichou": "enrabichar",
    "enrabichá": "enrabichar",
    "enrabichámo": "enrabichar",
    "enrabichámos": "enrabichar",
    "enrabicháramo": "enrabichar",
    "enrabicháramos": "enrabichar",
    "enrabichárei": "enrabichar",
    "enrabicháreis": "enrabichar",
    "enrabichásseis": "enrabichar",
    "enrabichássemos": "enrabichar",
    "enrabichávamo": "enrabichar",
    "enrabichávamos": "enrabichar",
    "enrabichávei": "enrabichar",
    "enrabicháveis": "enrabichar",
    "enrabo": "enrabar",
    "enrabou": "enrabar",
    "enrabá": "enrabar",
    "enrabámo": "enrabar",
    "enrabámos": "enrabar",
    "enrabáramo": "enrabar",
    "enrabáramos": "enrabar",
    "enrabárei": "enrabar",
    "enrabáreis": "enrabar",
    "enrabásseis": "enrabar",
    "enrabássemos": "enrabar",
    "enrabávamo": "enrabar",
    "enrabávamos": "enrabar",
    "enrabávei": "enrabar",
    "enrabáveis": "enrabar",
    "enraia": "enraiar",
    "enraiada": "enraiar",
    "enraiadas": "enraiar",
    "enraiado": "enraiar",
    "enraiados": "enraiar",
    "enraiai": "enraiar",
    "enraiais": "enraiar",
    "enraiam": "enraiar",
    "enraiamo": "enraiar",
    "enraiamos": "enraiar",
    "enraiando": "enraiar",
    "enraiara": "enraiar",
    "enraiaram": "enraiar",
    "enraiaras": "enraiar",
    "enraiarde": "enraiar",
    "enraiardes": "enraiar",
    "enraiare": "enraiar",
    "enraiarei": "enraiar",
    "enraiareis": "enraiar",
    "enraiarem": "enraiar",
    "enraiaremos": "enraiar",
    "enraiares": "enraiar",
    "enraiaria": "enraiar",
    "enraiariam": "enraiar",
    "enraiarias": "enraiar",
    "enraiarmo": "enraiar",
    "enraiarmos": "enraiar",
    "enraiará": "enraiar",
    "enraiarás": "enraiar",
    "enraiarão": "enraiar",
    "enraiaríamos": "enraiar",
    "enraiaríeis": "enraiar",
    "enraias": "enraiar",
    "enraiasse": "enraiar",
    "enraiassem": "enraiar",
    "enraiasses": "enraiar",
    "enraiaste": "enraiar",
    "enraiastes": "enraiar",
    "enraiava": "enraiar",
    "enraiavam": "enraiar",
    "enraiavas": "enraiar",
    "enraie": "enraiar",
    "enraiei": "enraiar",
    "enraieis": "enraiar",
    "enraiem": "enraiar",
    "enraiemo": "enraiar",
    "enraiemos": "enraiar",
    "enraies": "enraiar",
    "enraio": "enraiar",
    "enraiou": "enraiar",
    "enraiva": "enraivar",
    "enraivada": "enraivar",
    "enraivadas": "enraivar",
    "enraivado": "enraivar",
    "enraivados": "enraivar",
    "enraivai": "enraivar",
    "enraivais": "enraivar",
    "enraivam": "enraivar",
    "enraivamo": "enraivar",
    "enraivamos": "enraivar",
    "enraivando": "enraivar",
    "enraivara": "enraivar",
    "enraivaram": "enraivar",
    "enraivaras": "enraivar",
    "enraivarde": "enraivar",
    "enraivardes": "enraivar",
    "enraivare": "enraivar",
    "enraivarei": "enraivar",
    "enraivareis": "enraivar",
    "enraivarem": "enraivar",
    "enraivaremos": "enraivar",
    "enraivares": "enraivar",
    "enraivaria": "enraivar",
    "enraivariam": "enraivar",
    "enraivarias": "enraivar",
    "enraivarmo": "enraivar",
    "enraivarmos": "enraivar",
    "enraivará": "enraivar",
    "enraivarás": "enraivar",
    "enraivarão": "enraivar",
    "enraivaríamos": "enraivar",
    "enraivaríeis": "enraivar",
    "enraivas": "enraivar",
    "enraivasse": "enraivar",
    "enraivassem": "enraivar",
    "enraivasses": "enraivar",
    "enraivaste": "enraivar",
    "enraivastes": "enraivar",
    "enraivava": "enraivar",
    "enraivavam": "enraivar",
    "enraivavas": "enraivar",
    "enraive": "enraivar",
    "enraivece": "enraivecer",
    "enraivecei": "enraivecer",
    "enraiveceis": "enraivecer",
    "enraivecem": "enraivecer",
    "enraivecemo": "enraivecer",
    "enraivecemos": "enraivecer",
    "enraivecendo": "enraivecer",
    "enraivecera": "enraivecer",
    "enraiveceram": "enraivecer",
    "enraiveceras": "enraivecer",
    "enraivecerde": "enraivecer",
    "enraivecerdes": "enraivecer",
    "enraivecere": "enraivecer",
    "enraivecerei": "enraivecer",
    "enraivecereis": "enraivecer",
    "enraivecerem": "enraivecer",
    "enraiveceremos": "enraivecer",
    "enraiveceres": "enraivecer",
    "enraiveceria": "enraivecer",
    "enraiveceriam": "enraivecer",
    "enraivecerias": "enraivecer",
    "enraivecermo": "enraivecer",
    "enraivecermos": "enraivecer",
    "enraivecerá": "enraivecer",
    "enraivecerás": "enraivecer",
    "enraivecerão": "enraivecer",
    "enraiveceríamos": "enraivecer",
    "enraiveceríeis": "enraivecer",
    "enraiveces": "enraivecer",
    "enraivecesse": "enraivecer",
    "enraivecessem": "enraivecer",
    "enraivecesses": "enraivecer",
    "enraiveceste": "enraivecer",
    "enraivecestes": "enraivecer",
    "enraiveceu": "enraivecer",
    "enraiveci": "enraivecer",
    "enraivecia": "enraivecer",
    "enraiveciam": "enraivecer",
    "enraivecias": "enraivecer",
    "enraivecida": "enraivecido",
    "enraivecidas": "enraivecido",
    "enraivecido": "enraivecer",
    "enraivecidos": "enraivecido",
    "enraivecimentos": "enraivecimento",
    "enraivecê": "enraivecer",
    "enraivecêramo": "enraivecer",
    "enraivecêramos": "enraivecer",
    "enraivecêrei": "enraivecer",
    "enraivecêreis": "enraivecer",
    "enraivecêsseis": "enraivecer",
    "enraivecêssemos": "enraivecer",
    "enraivecíamo": "enraivecer",
    "enraivecíamos": "enraivecer",
    "enraivecíei": "enraivecer",
    "enraivecíeis": "enraivecer",
    "enraivei": "enraivar",
    "enraiveis": "enraivar",
    "enraivem": "enraivar",
    "enraivemo": "enraivar",
    "enraivemos": "enraivar",
    "enraives": "enraivar",
    "enraiveça": "enraivecer",
    "enraiveçais": "enraivecer",
    "enraiveçam": "enraivecer",
    "enraiveçamo": "enraivecer",
    "enraiveçamos": "enraivecer",
    "enraiveças": "enraivecer",
    "enraiveço": "enraivecer",
    "enraivo": "enraivar",
    "enraivou": "enraivar",
    "enraivá": "enraivar",
    "enraivámo": "enraivar",
    "enraivámos": "enraivar",
    "enraiváramo": "enraivar",
    "enraiváramos": "enraivar",
    "enraivárei": "enraivar",
    "enraiváreis": "enraivar",
    "enraivásseis": "enraivar",
    "enraivássemos": "enraivar",
    "enraivávamo": "enraivar",
    "enraivávamos": "enraivar",
    "enraivávei": "enraivar",
    "enraiváveis": "enraivar",
    "enraizada": "enraizar",
    "enraizadas": "enraizar",
    "enraizado": "enraizar",
    "enraizados": "enraizar",
    "enraizai": "enraizar",
    "enraizais": "enraizar",
    "enraizamentos": "enraizamento",
    "enraizamo": "enraizar",
    "enraizamos": "enraizar",
    "enraizando": "enraizar",
    "enraizara": "enraizar",
    "enraizaram": "enraizar",
    "enraizaras": "enraizar",
    "enraizarde": "enraizar",
    "enraizardes": "enraizar",
    "enraizare": "enraizar",
    "enraizarei": "enraizar",
    "enraizareis": "enraizar",
    "enraizarem": "enraizar",
    "enraizaremos": "enraizar",
    "enraizares": "enraizar",
    "enraizaria": "enraizar",
    "enraizariam": "enraizar",
    "enraizarias": "enraizar",
    "enraizarmo": "enraizar",
    "enraizarmos": "enraizar",
    "enraizará": "enraizar",
    "enraizarás": "enraizar",
    "enraizarão": "enraizar",
    "enraizaríamos": "enraizar",
    "enraizaríeis": "enraizar",
    "enraizasse": "enraizar",
    "enraizassem": "enraizar",
    "enraizasses": "enraizar",
    "enraizaste": "enraizar",
    "enraizastes": "enraizar",
    "enraizava": "enraizar",
    "enraizavam": "enraizar",
    "enraizavas": "enraizar",
    "enraizei": "enraizar",
    "enraizeis": "enraizar",
    "enraizemo": "enraizar",
    "enraizemos": "enraizar",
    "enraizou": "enraizar",
    "enraizá": "enraizar",
    "enraizámo": "enraizar",
    "enraizámos": "enraizar",
    "enraizáramo": "enraizar",
    "enraizáramos": "enraizar",
    "enraizárei": "enraizar",
    "enraizáreis": "enraizar",
    "enraizásseis": "enraizar",
    "enraizássemos": "enraizar",
    "enraizávamo": "enraizar",
    "enraizávamos": "enraizar",
    "enraizávei": "enraizar",
    "enraizáveis": "enraizar",
    "enraiá": "enraiar",
    "enraiámo": "enraiar",
    "enraiámos": "enraiar",
    "enraiáramo": "enraiar",
    "enraiáramos": "enraiar",
    "enraiárei": "enraiar",
    "enraiáreis": "enraiar",
    "enraiásseis": "enraiar",
    "enraiássemos": "enraiar",
    "enraiávamo": "enraiar",
    "enraiávamos": "enraiar",
    "enraiávei": "enraiar",
    "enraiáveis": "enraiar",
    "enrama": "enramar",
    "enramada": "enramar",
    "enramadas": "enramar",
    "enramado": "enramar",
    "enramados": "enramar",
    "enramai": "enramar",
    "enramais": "enramar",
    "enramalha": "enramalhar",
    "enramalhada": "enramalhar",
    "enramalhadas": "enramalhar",
    "enramalhado": "enramalhar",
    "enramalhados": "enramalhar",
    "enramalhai": "enramalhar",
    "enramalhais": "enramalhar",
    "enramalham": "enramalhar",
    "enramalhamo": "enramalhar",
    "enramalhamos": "enramalhar",
    "enramalhando": "enramalhar",
    "enramalhara": "enramalhar",
    "enramalharam": "enramalhar",
    "enramalharas": "enramalhar",
    "enramalharde": "enramalhar",
    "enramalhardes": "enramalhar",
    "enramalhare": "enramalhar",
    "enramalharei": "enramalhar",
    "enramalhareis": "enramalhar",
    "enramalharem": "enramalhar",
    "enramalharemos": "enramalhar",
    "enramalhares": "enramalhar",
    "enramalharia": "enramalhar",
    "enramalhariam": "enramalhar",
    "enramalharias": "enramalhar",
    "enramalharmo": "enramalhar",
    "enramalharmos": "enramalhar",
    "enramalhará": "enramalhar",
    "enramalharás": "enramalhar",
    "enramalharão": "enramalhar",
    "enramalharíamos": "enramalhar",
    "enramalharíeis": "enramalhar",
    "enramalhas": "enramalhar",
    "enramalhasse": "enramalhar",
    "enramalhassem": "enramalhar",
    "enramalhasses": "enramalhar",
    "enramalhaste": "enramalhar",
    "enramalhastes": "enramalhar",
    "enramalhava": "enramalhar",
    "enramalhavam": "enramalhar",
    "enramalhavas": "enramalhar",
    "enramalhe": "enramalhar",
    "enramalhei": "enramalhar",
    "enramalheis": "enramalhar",
    "enramalhem": "enramalhar",
    "enramalhemo": "enramalhar",
    "enramalhemos": "enramalhar",
    "enramalhes": "enramalhar",
    "enramalheta": "enramalhetar",
    "enramalhetada": "enramalhetar",
    "enramalhetadas": "enramalhetar",
    "enramalhetado": "enramalhetar",
    "enramalhetados": "enramalhetar",
    "enramalhetai": "enramalhetar",
    "enramalhetais": "enramalhetar",
    "enramalhetam": "enramalhetar",
    "enramalhetamo": "enramalhetar",
    "enramalhetamos": "enramalhetar",
    "enramalhetando": "enramalhetar",
    "enramalhetara": "enramalhetar",
    "enramalhetaram": "enramalhetar",
    "enramalhetaras": "enramalhetar",
    "enramalhetarde": "enramalhetar",
    "enramalhetardes": "enramalhetar",
    "enramalhetare": "enramalhetar",
    "enramalhetarei": "enramalhetar",
    "enramalhetareis": "enramalhetar",
    "enramalhetarem": "enramalhetar",
    "enramalhetaremos": "enramalhetar",
    "enramalhetares": "enramalhetar",
    "enramalhetaria": "enramalhetar",
    "enramalhetariam": "enramalhetar",
    "enramalhetarias": "enramalhetar",
    "enramalhetarmo": "enramalhetar",
    "enramalhetarmos": "enramalhetar",
    "enramalhetará": "enramalhetar",
    "enramalhetarás": "enramalhetar",
    "enramalhetarão": "enramalhetar",
    "enramalhetaríamos": "enramalhetar",
    "enramalhetaríeis": "enramalhetar",
    "enramalhetas": "enramalhetar",
    "enramalhetasse": "enramalhetar",
    "enramalhetassem": "enramalhetar",
    "enramalhetasses": "enramalhetar",
    "enramalhetaste": "enramalhetar",
    "enramalhetastes": "enramalhetar",
    "enramalhetava": "enramalhetar",
    "enramalhetavam": "enramalhetar",
    "enramalhetavas": "enramalhetar",
    "enramalhete": "enramalhetar",
    "enramalhetei": "enramalhetar",
    "enramalheteis": "enramalhetar",
    "enramalhetem": "enramalhetar",
    "enramalhetemo": "enramalhetar",
    "enramalhetemos": "enramalhetar",
    "enramalhetes": "enramalhetar",
    "enramalheto": "enramalhetar",
    "enramalhetou": "enramalhetar",
    "enramalhetá": "enramalhetar",
    "enramalhetámo": "enramalhetar",
    "enramalhetámos": "enramalhetar",
    "enramalhetáramo": "enramalhetar",
    "enramalhetáramos": "enramalhetar",
    "enramalhetárei": "enramalhetar",
    "enramalhetáreis": "enramalhetar",
    "enramalhetásseis": "enramalhetar",
    "enramalhetássemos": "enramalhetar",
    "enramalhetávamo": "enramalhetar",
    "enramalhetávamos": "enramalhetar",
    "enramalhetávei": "enramalhetar",
    "enramalhetáveis": "enramalhetar",
    "enramalho": "enramalhar",
    "enramalhou": "enramalhar",
    "enramalhá": "enramalhar",
    "enramalhámo": "enramalhar",
    "enramalhámos": "enramalhar",
    "enramalháramo": "enramalhar",
    "enramalháramos": "enramalhar",
    "enramalhárei": "enramalhar",
    "enramalháreis": "enramalhar",
    "enramalhásseis": "enramalhar",
    "enramalhássemos": "enramalhar",
    "enramalhávamo": "enramalhar",
    "enramalhávamos": "enramalhar",
    "enramalhávei": "enramalhar",
    "enramalháveis": "enramalhar",
    "enramam": "enramar",
    "enramamentos": "enramamento",
    "enramamo": "enramar",
    "enramamos": "enramar",
    "enramando": "enramar",
    "enramara": "enramar",
    "enramaram": "enramar",
    "enramaras": "enramar",
    "enramarde": "enramar",
    "enramardes": "enramar",
    "enramare": "enramar",
    "enramarei": "enramar",
    "enramareis": "enramar",
    "enramarem": "enramar",
    "enramaremos": "enramar",
    "enramares": "enramar",
    "enramaria": "enramar",
    "enramariam": "enramar",
    "enramarias": "enramar",
    "enramarmo": "enramar",
    "enramarmos": "enramar",
    "enramará": "enramar",
    "enramarás": "enramar",
    "enramarão": "enramar",
    "enramaríamos": "enramar",
    "enramaríeis": "enramar",
    "enramas": "enramar",
    "enramasse": "enramar",
    "enramassem": "enramar",
    "enramasses": "enramar",
    "enramaste": "enramar",
    "enramastes": "enramar",
    "enramava": "enramar",
    "enramavam": "enramar",
    "enramavas": "enramar",
    "enramações": "enramação",
    "enrame": "enramar",
    "enrameada": "enramear",
    "enrameadas": "enramear",
    "enrameado": "enramear",
    "enrameados": "enramear",
    "enrameai": "enramear",
    "enrameais": "enramear",
    "enrameamo": "enramear",
    "enrameamos": "enramear",
    "enrameando": "enramear",
    "enrameara": "enramear",
    "enramearam": "enramear",
    "enramearas": "enramear",
    "enramearde": "enramear",
    "enrameardes": "enramear",
    "enrameare": "enramear",
    "enramearei": "enramear",
    "enrameareis": "enramear",
    "enramearem": "enramear",
    "enramearemos": "enramear",
    "enrameares": "enramear",
    "enramearia": "enramear",
    "enrameariam": "enramear",
    "enramearias": "enramear",
    "enramearmo": "enramear",
    "enramearmos": "enramear",
    "enrameará": "enramear",
    "enramearás": "enramear",
    "enramearão": "enramear",
    "enramearíamos": "enramear",
    "enramearíeis": "enramear",
    "enrameasse": "enramear",
    "enrameassem": "enramear",
    "enrameasses": "enramear",
    "enrameaste": "enramear",
    "enrameastes": "enramear",
    "enrameava": "enramear",
    "enrameavam": "enramear",
    "enrameavas": "enramear",
    "enrameei": "enramear",
    "enrameeis": "enramear",
    "enrameemo": "enramear",
    "enrameemos": "enramear",
    "enramei": "enramar",
    "enrameia": "enramear",
    "enrameiam": "enramear",
    "enrameias": "enramear",
    "enrameie": "enramear",
    "enrameiem": "enramear",
    "enrameies": "enramear",
    "enrameio": "enramear",
    "enrameis": "enramar",
    "enramem": "enramar",
    "enramemo": "enramar",
    "enramemos": "enramar",
    "enrameou": "enramear",
    "enrames": "enramar",
    "enrameá": "enramear",
    "enrameámo": "enramear",
    "enrameámos": "enramear",
    "enrameáramo": "enramear",
    "enrameáramos": "enramear",
    "enrameárei": "enramear",
    "enrameáreis": "enramear",
    "enrameásseis": "enramear",
    "enrameássemos": "enramear",
    "enrameávamo": "enramear",
    "enrameávamos": "enramear",
    "enrameávei": "enramear",
    "enrameáveis": "enramear",
    "enramilheta": "enramilhetar",
    "enramilhetada": "enramilhetar",
    "enramilhetadas": "enramilhetar",
    "enramilhetado": "enramilhetar",
    "enramilhetados": "enramilhetar",
    "enramilhetai": "enramilhetar",
    "enramilhetais": "enramilhetar",
    "enramilhetam": "enramilhetar",
    "enramilhetamo": "enramilhetar",
    "enramilhetamos": "enramilhetar",
    "enramilhetando": "enramilhetar",
    "enramilhetara": "enramilhetar",
    "enramilhetaram": "enramilhetar",
    "enramilhetaras": "enramilhetar",
    "enramilhetarde": "enramilhetar",
    "enramilhetardes": "enramilhetar",
    "enramilhetare": "enramilhetar",
    "enramilhetarei": "enramilhetar",
    "enramilhetareis": "enramilhetar",
    "enramilhetarem": "enramilhetar",
    "enramilhetaremos": "enramilhetar",
    "enramilhetares": "enramilhetar",
    "enramilhetaria": "enramilhetar",
    "enramilhetariam": "enramilhetar",
    "enramilhetarias": "enramilhetar",
    "enramilhetarmo": "enramilhetar",
    "enramilhetarmos": "enramilhetar",
    "enramilhetará": "enramilhetar",
    "enramilhetarás": "enramilhetar",
    "enramilhetarão": "enramilhetar",
    "enramilhetaríamos": "enramilhetar",
    "enramilhetaríeis": "enramilhetar",
    "enramilhetas": "enramilhetar",
    "enramilhetasse": "enramilhetar",
    "enramilhetassem": "enramilhetar",
    "enramilhetasses": "enramilhetar",
    "enramilhetaste": "enramilhetar",
    "enramilhetastes": "enramilhetar",
    "enramilhetava": "enramilhetar",
    "enramilhetavam": "enramilhetar",
    "enramilhetavas": "enramilhetar",
    "enramilhete": "enramilhetar",
    "enramilhetei": "enramilhetar",
    "enramilheteis": "enramilhetar",
    "enramilhetem": "enramilhetar",
    "enramilhetemo": "enramilhetar",
    "enramilhetemos": "enramilhetar",
    "enramilhetes": "enramilhetar",
    "enramilheto": "enramilhetar",
    "enramilhetou": "enramilhetar",
    "enramilhetá": "enramilhetar",
    "enramilhetámo": "enramilhetar",
    "enramilhetámos": "enramilhetar",
    "enramilhetáramo": "enramilhetar",
    "enramilhetáramos": "enramilhetar",
    "enramilhetárei": "enramilhetar",
    "enramilhetáreis": "enramilhetar",
    "enramilhetásseis": "enramilhetar",
    "enramilhetássemos": "enramilhetar",
    "enramilhetávamo": "enramilhetar",
    "enramilhetávamos": "enramilhetar",
    "enramilhetávei": "enramilhetar",
    "enramilhetáveis": "enramilhetar",
    "enramo": "enramar",
    "enramou": "enramar",
    "enramá": "enramar",
    "enramámo": "enramar",
    "enramámos": "enramar",
    "enramáramo": "enramar",
    "enramáramos": "enramar",
    "enramárei": "enramar",
    "enramáreis": "enramar",
    "enramásseis": "enramar",
    "enramássemos": "enramar",
    "enramávamo": "enramar",
    "enramávamos": "enramar",
    "enramávei": "enramar",
    "enramáveis": "enramar",
    "enrance": "enrançar",
    "enrancei": "enrançar",
    "enranceis": "enrançar",
    "enrancem": "enrançar",
    "enrancemo": "enrançar",
    "enrancemos": "enrançar",
    "enrances": "enrançar",
    "enrancha": "enranchar",
    "enranchada": "enranchar",
    "enranchadas": "enranchar",
    "enranchado": "enranchar",
    "enranchados": "enranchar",
    "enranchai": "enranchar",
    "enranchais": "enranchar",
    "enrancham": "enranchar",
    "enranchamo": "enranchar",
    "enranchamos": "enranchar",
    "enranchando": "enranchar",
    "enranchara": "enranchar",
    "enrancharam": "enranchar",
    "enrancharas": "enranchar",
    "enrancharde": "enranchar",
    "enranchardes": "enranchar",
    "enranchare": "enranchar",
    "enrancharei": "enranchar",
    "enranchareis": "enranchar",
    "enrancharem": "enranchar",
    "enrancharemos": "enranchar",
    "enranchares": "enranchar",
    "enrancharia": "enranchar",
    "enranchariam": "enranchar",
    "enrancharias": "enranchar",
    "enrancharmo": "enranchar",
    "enrancharmos": "enranchar",
    "enranchará": "enranchar",
    "enrancharás": "enranchar",
    "enrancharão": "enranchar",
    "enrancharíamos": "enranchar",
    "enrancharíeis": "enranchar",
    "enranchas": "enranchar",
    "enranchasse": "enranchar",
    "enranchassem": "enranchar",
    "enranchasses": "enranchar",
    "enranchaste": "enranchar",
    "enranchastes": "enranchar",
    "enranchava": "enranchar",
    "enranchavam": "enranchar",
    "enranchavas": "enranchar",
    "enranche": "enranchar",
    "enranchei": "enranchar",
    "enrancheis": "enranchar",
    "enranchem": "enranchar",
    "enranchemo": "enranchar",
    "enranchemos": "enranchar",
    "enranches": "enranchar",
    "enrancho": "enranchar",
    "enranchou": "enranchar",
    "enranchá": "enranchar",
    "enranchámo": "enranchar",
    "enranchámos": "enranchar",
    "enrancháramo": "enranchar",
    "enrancháramos": "enranchar",
    "enranchárei": "enranchar",
    "enrancháreis": "enranchar",
    "enranchásseis": "enranchar",
    "enranchássemos": "enranchar",
    "enranchávamo": "enranchar",
    "enranchávamos": "enranchar",
    "enranchávei": "enranchar",
    "enrancháveis": "enranchar",
    "enrança": "enrançar",
    "enrançada": "enrançar",
    "enrançadas": "enrançar",
    "enrançado": "enrançar",
    "enrançados": "enrançar",
    "enrançai": "enrançar",
    "enrançais": "enrançar",
    "enrançam": "enrançar",
    "enrançamo": "enrançar",
    "enrançamos": "enrançar",
    "enrançando": "enrançar",
    "enrançara": "enrançar",
    "enrançaram": "enrançar",
    "enrançaras": "enrançar",
    "enrançardes": "enrançar",
    "enrançarei": "enrançar",
    "enrançareis": "enrançar",
    "enrançarem": "enrançar",
    "enrançaremos": "enrançar",
    "enrançares": "enrançar",
    "enrançaria": "enrançar",
    "enrançariam": "enrançar",
    "enrançarias": "enrançar",
    "enrançarmo": "enrançar",
    "enrançarmos": "enrançar",
    "enrançará": "enrançar",
    "enrançarás": "enrançar",
    "enrançarão": "enrançar",
    "enrançaríamos": "enrançar",
    "enrançaríeis": "enrançar",
    "enranças": "enrançar",
    "enrançasse": "enrançar",
    "enrançassem": "enrançar",
    "enrançasses": "enrançar",
    "enrançaste": "enrançar",
    "enrançastes": "enrançar",
    "enrançava": "enrançar",
    "enrançavam": "enrançar",
    "enrançavas": "enrançar",
    "enranço": "enrançar",
    "enrançou": "enrançar",
    "enrançámo": "enrançar",
    "enrançámos": "enrançar",
    "enrançáramo": "enrançar",
    "enrançáramos": "enrançar",
    "enrançáreis": "enrançar",
    "enrançásseis": "enrançar",
    "enrançássemos": "enrançar",
    "enrançávamo": "enrançar",
    "enrançávamos": "enrançar",
    "enrançáveis": "enrançar",
    "enrarece": "enrarecer",
    "enrarecei": "enrarecer",
    "enrareceis": "enrarecer",
    "enrarecem": "enrarecer",
    "enrarecemo": "enrarecer",
    "enrarecemos": "enrarecer",
    "enrarecendo": "enrarecer",
    "enrarecera": "enrarecer",
    "enrareceram": "enrarecer",
    "enrareceras": "enrarecer",
    "enrarecerde": "enrarecer",
    "enrarecerdes": "enrarecer",
    "enrarecere": "enrarecer",
    "enrarecerei": "enrarecer",
    "enrarecereis": "enrarecer",
    "enrarecerem": "enrarecer",
    "enrareceremos": "enrarecer",
    "enrareceres": "enrarecer",
    "enrareceria": "enrarecer",
    "enrareceriam": "enrarecer",
    "enrarecerias": "enrarecer",
    "enrarecermo": "enrarecer",
    "enrarecermos": "enrarecer",
    "enrarecerá": "enrarecer",
    "enrarecerás": "enrarecer",
    "enrarecerão": "enrarecer",
    "enrareceríamos": "enrarecer",
    "enrareceríeis": "enrarecer",
    "enrareces": "enrarecer",
    "enrarecesse": "enrarecer",
    "enrarecessem": "enrarecer",
    "enrarecesses": "enrarecer",
    "enrareceste": "enrarecer",
    "enrarecestes": "enrarecer",
    "enrareceu": "enrarecer",
    "enrareci": "enrarecer",
    "enrarecia": "enrarecer",
    "enrareciam": "enrarecer",
    "enrarecias": "enrarecer",
    "enrarecida": "enrarecer",
    "enrarecidas": "enrarecer",
    "enrarecido": "enrarecer",
    "enrarecidos": "enrarecer",
    "enrarecimentos": "enrarecimento",
    "enrarecê": "enrarecer",
    "enrarecêramo": "enrarecer",
    "enrarecêramos": "enrarecer",
    "enrarecêrei": "enrarecer",
    "enrarecêreis": "enrarecer",
    "enrarecêsseis": "enrarecer",
    "enrarecêssemos": "enrarecer",
    "enrarecíamo": "enrarecer",
    "enrarecíamos": "enrarecer",
    "enrarecíei": "enrarecer",
    "enrarecíeis": "enrarecer",
    "enrareça": "enrarecer",
    "enrareçais": "enrarecer",
    "enrareçam": "enrarecer",
    "enrareçamo": "enrarecer",
    "enrareçamos": "enrarecer",
    "enrareças": "enrarecer",
    "enrareço": "enrarecer",
    "enrasca": "enrascar",
    "enrascada": "enrascar",
    "enrascadas": "enrascar",
    "enrascadelas": "enrascadela",
    "enrascado": "enrascar",
    "enrascados": "enrascar",
    "enrascaduras": "enrascadura",
    "enrascadíssima": "enrascado",
    "enrascadíssimas": "enrascado",
    "enrascadíssimo": "enrascado",
    "enrascadíssimos": "enrascado",
    "enrascai": "enrascar",
    "enrascais": "enrascar",
    "enrascam": "enrascar",
    "enrascamo": "enrascar",
    "enrascamos": "enrascar",
    "enrascando": "enrascar",
    "enrascara": "enrascar",
    "enrascaram": "enrascar",
    "enrascaras": "enrascar",
    "enrascarde": "enrascar",
    "enrascardes": "enrascar",
    "enrascare": "enrascar",
    "enrascarei": "enrascar",
    "enrascareis": "enrascar",
    "enrascarem": "enrascar",
    "enrascaremos": "enrascar",
    "enrascares": "enrascar",
    "enrascaria": "enrascar",
    "enrascariam": "enrascar",
    "enrascarias": "enrascar",
    "enrascarmo": "enrascar",
    "enrascarmos": "enrascar",
    "enrascará": "enrascar",
    "enrascarás": "enrascar",
    "enrascarão": "enrascar",
    "enrascaríamos": "enrascar",
    "enrascaríeis": "enrascar",
    "enrascas": "enrascar",
    "enrascasse": "enrascar",
    "enrascassem": "enrascar",
    "enrascasses": "enrascar",
    "enrascaste": "enrascar",
    "enrascastes": "enrascar",
    "enrascava": "enrascar",
    "enrascavam": "enrascar",
    "enrascavas": "enrascar",
    "enrasco": "enrascar",
    "enrascou": "enrascar",
    "enrascá": "enrascar",
    "enrascámo": "enrascar",
    "enrascámos": "enrascar",
    "enrascáramo": "enrascar",
    "enrascáramos": "enrascar",
    "enrascárei": "enrascar",
    "enrascáreis": "enrascar",
    "enrascásseis": "enrascar",
    "enrascássemos": "enrascar",
    "enrascávamo": "enrascar",
    "enrascávamos": "enrascar",
    "enrascávei": "enrascar",
    "enrascáveis": "enrascar",
    "enrasque": "enrascar",
    "enrasquei": "enrascar",
    "enrasqueis": "enrascar",
    "enrasquem": "enrascar",
    "enrasquemo": "enrascar",
    "enrasquemos": "enrascar",
    "enrasques": "enrascar",
    "enrata": "enratar",
    "enratada": "enratar",
    "enratadas": "enratar",
    "enratado": "enratar",
    "enratados": "enratar",
    "enratai": "enratar",
    "enratais": "enratar",
    "enratam": "enratar",
    "enratamo": "enratar",
    "enratamos": "enratar",
    "enratando": "enratar",
    "enratara": "enratar",
    "enrataram": "enratar",
    "enrataras": "enratar",
    "enratardes": "enratar",
    "enratarei": "enratar",
    "enratareis": "enratar",
    "enratarem": "enratar",
    "enrataremos": "enratar",
    "enratares": "enratar",
    "enrataria": "enratar",
    "enratariam": "enratar",
    "enratarias": "enratar",
    "enratarmo": "enratar",
    "enratarmos": "enratar",
    "enratará": "enratar",
    "enratarás": "enratar",
    "enratarão": "enratar",
    "enrataríamos": "enratar",
    "enrataríeis": "enratar",
    "enratas": "enratar",
    "enratasse": "enratar",
    "enratassem": "enratar",
    "enratasses": "enratar",
    "enrataste": "enratar",
    "enratastes": "enratar",
    "enratava": "enratar",
    "enratavam": "enratar",
    "enratavas": "enratar",
    "enrate": "enratar",
    "enratei": "enratar",
    "enrateis": "enratar",
    "enratem": "enratar",
    "enratemo": "enratar",
    "enratemos": "enratar",
    "enrates": "enratar",
    "enrato": "enratar",
    "enratou": "enratar",
    "enratámo": "enratar",
    "enratámos": "enratar",
    "enratáramo": "enratar",
    "enratáramos": "enratar",
    "enratáreis": "enratar",
    "enratásseis": "enratar",
    "enratássemos": "enratar",
    "enratávamo": "enratar",
    "enratávamos": "enratar",
    "enratáveis": "enratar",
    "enraçada": "enraçado",
    "enraçadas": "enraçado",
    "enraçados": "enraçado",
    "enraíza": "enraizar",
    "enraízam": "enraizar",
    "enraízas": "enraizar",
    "enraíze": "enraizar",
    "enraízem": "enraizar",
    "enraízes": "enraizar",
    "enraízo": "enraizar",
    "enreda": "enredar",
    "enredada": "enredar",
    "enredadas": "enredar",
    "enredadeiras": "enredadeira",
    "enredadelas": "enredadela",
    "enredado": "enredar",
    "enredadora": "enredador",
    "enredadoras": "enredador",
    "enredadores": "enredador",
    "enredados": "enredar",
    "enredadíssima": "enredado",
    "enredadíssimas": "enredado",
    "enredadíssimo": "enredado",
    "enredadíssimos": "enredado",
    "enredai": "enredar",
    "enredais": "enredar",
    "enredam": "enredar",
    "enredamentos": "enredamento",
    "enredamo": "enredar",
    "enredamos": "enredar",
    "enredando": "enredar",
    "enredara": "enredar",
    "enredaram": "enredar",
    "enredaras": "enredar",
    "enredarde": "enredar",
    "enredardes": "enredar",
    "enredare": "enredar",
    "enredarei": "enredar",
    "enredareis": "enredar",
    "enredarem": "enredar",
    "enredaremos": "enredar",
    "enredares": "enredar",
    "enredaria": "enredar",
    "enredariam": "enredar",
    "enredarias": "enredar",
    "enredarmo": "enredar",
    "enredarmos": "enredar",
    "enredará": "enredar",
    "enredarás": "enredar",
    "enredarão": "enredar",
    "enredaríamos": "enredar",
    "enredaríeis": "enredar",
    "enredas": "enredar",
    "enredasse": "enredar",
    "enredassem": "enredar",
    "enredasses": "enredar",
    "enredaste": "enredar",
    "enredastes": "enredar",
    "enredava": "enredar",
    "enredavam": "enredar",
    "enredavas": "enredar",
    "enrede": "enredar",
    "enredeada": "enredear",
    "enredeadas": "enredear",
    "enredeado": "enredear",
    "enredeados": "enredear",
    "enredeai": "enredear",
    "enredeais": "enredear",
    "enredeamo": "enredear",
    "enredeamos": "enredear",
    "enredeando": "enredear",
    "enredeara": "enredear",
    "enredearam": "enredear",
    "enredearas": "enredear",
    "enredearde": "enredear",
    "enredeardes": "enredear",
    "enredeare": "enredear",
    "enredearei": "enredear",
    "enredeareis": "enredear",
    "enredearem": "enredear",
    "enredearemos": "enredear",
    "enredeares": "enredear",
    "enredearia": "enredear",
    "enredeariam": "enredear",
    "enredearias": "enredear",
    "enredearmo": "enredear",
    "enredearmos": "enredear",
    "enredeará": "enredear",
    "enredearás": "enredear",
    "enredearão": "enredear",
    "enredearíamos": "enredear",
    "enredearíeis": "enredear",
    "enredeasse": "enredear",
    "enredeassem": "enredear",
    "enredeasses": "enredear",
    "enredeaste": "enredear",
    "enredeastes": "enredear",
    "enredeava": "enredear",
    "enredeavam": "enredear",
    "enredeavas": "enredear",
    "enredeei": "enredear",
    "enredeeis": "enredear",
    "enredeemo": "enredear",
    "enredeemos": "enredear",
    "enredei": "enredar",
    "enredeia": "enredear",
    "enredeiam": "enredear",
    "enredeias": "enredear",
    "enredeie": "enredear",
    "enredeiem": "enredear",
    "enredeies": "enredear",
    "enredeio": "enredear",
    "enredeis": "enredar",
    "enredem": "enredar",
    "enredemo": "enredar",
    "enredemos": "enredar",
    "enredeou": "enredear",
    "enredes": "enredar",
    "enredeá": "enredear",
    "enredeámo": "enredear",
    "enredeámos": "enredear",
    "enredeáramo": "enredear",
    "enredeáramos": "enredear",
    "enredeárei": "enredear",
    "enredeáreis": "enredear",
    "enredeásseis": "enredear",
    "enredeássemos": "enredear",
    "enredeávamo": "enredear",
    "enredeávamos": "enredear",
    "enredeávei": "enredear",
    "enredeáveis": "enredear",
    "enrediças": "enrediça",
    "enredo": "enredar",
    "enredoice": "enredoiçar",
    "enredoicei": "enredoiçar",
    "enredoiceis": "enredoiçar",
    "enredoicem": "enredoiçar",
    "enredoicemo": "enredoiçar",
    "enredoicemos": "enredoiçar",
    "enredoices": "enredoiçar",
    "enredoiça": "enredoiçar",
    "enredoiçada": "enredoiçar",
    "enredoiçadas": "enredoiçar",
    "enredoiçado": "enredoiçar",
    "enredoiçados": "enredoiçar",
    "enredoiçai": "enredoiçar",
    "enredoiçais": "enredoiçar",
    "enredoiçam": "enredoiçar",
    "enredoiçamo": "enredoiçar",
    "enredoiçamos": "enredoiçar",
    "enredoiçando": "enredoiçar",
    "enredoiçara": "enredoiçar",
    "enredoiçaram": "enredoiçar",
    "enredoiçaras": "enredoiçar",
    "enredoiçarde": "enredoiçar",
    "enredoiçardes": "enredoiçar",
    "enredoiçare": "enredoiçar",
    "enredoiçarei": "enredoiçar",
    "enredoiçareis": "enredoiçar",
    "enredoiçarem": "enredoiçar",
    "enredoiçaremos": "enredoiçar",
    "enredoiçares": "enredoiçar",
    "enredoiçaria": "enredoiçar",
    "enredoiçariam": "enredoiçar",
    "enredoiçarias": "enredoiçar",
    "enredoiçarmo": "enredoiçar",
    "enredoiçarmos": "enredoiçar",
    "enredoiçará": "enredoiçar",
    "enredoiçarás": "enredoiçar",
    "enredoiçarão": "enredoiçar",
    "enredoiçaríamos": "enredoiçar",
    "enredoiçaríeis": "enredoiçar",
    "enredoiças": "enredoiçar",
    "enredoiçasse": "enredoiçar",
    "enredoiçassem": "enredoiçar",
    "enredoiçasses": "enredoiçar",
    "enredoiçaste": "enredoiçar",
    "enredoiçastes": "enredoiçar",
    "enredoiçava": "enredoiçar",
    "enredoiçavam": "enredoiçar",
    "enredoiçavas": "enredoiçar",
    "enredoiço": "enredoiçar",
    "enredoiçou": "enredoiçar",
    "enredoiçá": "enredoiçar",
    "enredoiçámo": "enredoiçar",
    "enredoiçámos": "enredoiçar",
    "enredoiçáramo": "enredoiçar",
    "enredoiçáramos": "enredoiçar",
    "enredoiçárei": "enredoiçar",
    "enredoiçáreis": "enredoiçar",
    "enredoiçásseis": "enredoiçar",
    "enredoiçássemos": "enredoiçar",
    "enredoiçávamo": "enredoiçar",
    "enredoiçávamos": "enredoiçar",
    "enredoiçávei": "enredoiçar",
    "enredoiçáveis": "enredoiçar",
    "enredoma": "enredomar",
    "enredomada": "enredomar",
    "enredomadas": "enredomar",
    "enredomado": "enredomar",
    "enredomados": "enredomar",
    "enredomai": "enredomar",
    "enredomais": "enredomar",
    "enredomam": "enredomar",
    "enredomamo": "enredomar",
    "enredomamos": "enredomar",
    "enredomando": "enredomar",
    "enredomara": "enredomar",
    "enredomaram": "enredomar",
    "enredomaras": "enredomar",
    "enredomarde": "enredomar",
    "enredomardes": "enredomar",
    "enredomare": "enredomar",
    "enredomarei": "enredomar",
    "enredomareis": "enredomar",
    "enredomarem": "enredomar",
    "enredomaremos": "enredomar",
    "enredomares": "enredomar",
    "enredomaria": "enredomar",
    "enredomariam": "enredomar",
    "enredomarias": "enredomar",
    "enredomarmo": "enredomar",
    "enredomarmos": "enredomar",
    "enredomará": "enredomar",
    "enredomarás": "enredomar",
    "enredomarão": "enredomar",
    "enredomaríamos": "enredomar",
    "enredomaríeis": "enredomar",
    "enredomas": "enredomar",
    "enredomasse": "enredomar",
    "enredomassem": "enredomar",
    "enredomasses": "enredomar",
    "enredomaste": "enredomar",
    "enredomastes": "enredomar",
    "enredomava": "enredomar",
    "enredomavam": "enredomar",
    "enredomavas": "enredomar",
    "enredome": "enredomar",
    "enredomei": "enredomar",
    "enredomeis": "enredomar",
    "enredomem": "enredomar",
    "enredomemo": "enredomar",
    "enredomemos": "enredomar",
    "enredomes": "enredomar",
    "enredomo": "enredomar",
    "enredomou": "enredomar",
    "enredomá": "enredomar",
    "enredomámo": "enredomar",
    "enredomámos": "enredomar",
    "enredomáramo": "enredomar",
    "enredomáramos": "enredomar",
    "enredomárei": "enredomar",
    "enredomáreis": "enredomar",
    "enredomásseis": "enredomar",
    "enredomássemos": "enredomar",
    "enredomávamo": "enredomar",
    "enredomávamos": "enredomar",
    "enredomávei": "enredomar",
    "enredomáveis": "enredomar",
    "enredos": "enredo",
    "enredosa": "enredoso",
    "enredosas": "enredoso",
    "enredosos": "enredoso",
    "enredou": "enredar",
    "enredouce": "enredouçar",
    "enredoucei": "enredouçar",
    "enredouceis": "enredouçar",
    "enredoucem": "enredouçar",
    "enredoucemo": "enredouçar",
    "enredoucemos": "enredouçar",
    "enredouces": "enredouçar",
    "enredouça": "enredouçar",
    "enredouçada": "enredouçar",
    "enredouçadas": "enredouçar",
    "enredouçado": "enredouçar",
    "enredouçados": "enredouçar",
    "enredouçai": "enredouçar",
    "enredouçais": "enredouçar",
    "enredouçam": "enredouçar",
    "enredouçamo": "enredouçar",
    "enredouçamos": "enredouçar",
    "enredouçando": "enredouçar",
    "enredouçara": "enredouçar",
    "enredouçaram": "enredouçar",
    "enredouçaras": "enredouçar",
    "enredouçarde": "enredouçar",
    "enredouçardes": "enredouçar",
    "enredouçare": "enredouçar",
    "enredouçarei": "enredouçar",
    "enredouçareis": "enredouçar",
    "enredouçarem": "enredouçar",
    "enredouçaremos": "enredouçar",
    "enredouçares": "enredouçar",
    "enredouçaria": "enredouçar",
    "enredouçariam": "enredouçar",
    "enredouçarias": "enredouçar",
    "enredouçarmo": "enredouçar",
    "enredouçarmos": "enredouçar",
    "enredouçará": "enredouçar",
    "enredouçarás": "enredouçar",
    "enredouçarão": "enredouçar",
    "enredouçaríamos": "enredouçar",
    "enredouçaríeis": "enredouçar",
    "enredouças": "enredouçar",
    "enredouçasse": "enredouçar",
    "enredouçassem": "enredouçar",
    "enredouçasses": "enredouçar",
    "enredouçaste": "enredouçar",
    "enredouçastes": "enredouçar",
    "enredouçava": "enredouçar",
    "enredouçavam": "enredouçar",
    "enredouçavas": "enredouçar",
    "enredouço": "enredouçar",
    "enredouçou": "enredouçar",
    "enredouçá": "enredouçar",
    "enredouçámo": "enredouçar",
    "enredouçámos": "enredouçar",
    "enredouçáramo": "enredouçar",
    "enredouçáramos": "enredouçar",
    "enredouçárei": "enredouçar",
    "enredouçáreis": "enredouçar",
    "enredouçásseis": "enredouçar",
    "enredouçássemos": "enredouçar",
    "enredouçávamo": "enredouçar",
    "enredouçávamos": "enredouçar",
    "enredouçávei": "enredouçar",
    "enredouçáveis": "enredouçar",
    "enredá": "enredar",
    "enredámo": "enredar",
    "enredámos": "enredar",
    "enredáramo": "enredar",
    "enredáramos": "enredar",
    "enredárei": "enredar",
    "enredáreis": "enredar",
    "enredásseis": "enredar",
    "enredássemos": "enredar",
    "enredávamo": "enredar",
    "enredávamos": "enredar",
    "enredávei": "enredar",
    "enredáveis": "enredar",
    "enregela": "enregelar",
    "enregelada": "enregelar",
    "enregeladas": "enregelar",
    "enregelado": "enregelar",
    "enregelados": "enregelar",
    "enregeladíssima": "enregelado",
    "enregeladíssimas": "enregelado",
    "enregeladíssimo": "enregelado",
    "enregeladíssimos": "enregelado",
    "enregelai": "enregelar",
    "enregelais": "enregelar",
    "enregelam": "enregelar",
    "enregelamentos": "enregelamento",
    "enregelamo": "enregelar",
    "enregelamos": "enregelar",
    "enregelando": "enregelar",
    "enregelantes": "enregelante",
    "enregelara": "enregelar",
    "enregelaram": "enregelar",
    "enregelaras": "enregelar",
    "enregelarde": "enregelar",
    "enregelardes": "enregelar",
    "enregelare": "enregelar",
    "enregelarei": "enregelar",
    "enregelareis": "enregelar",
    "enregelarem": "enregelar",
    "enregelaremos": "enregelar",
    "enregelares": "enregelar",
    "enregelaria": "enregelar",
    "enregelariam": "enregelar",
    "enregelarias": "enregelar",
    "enregelarmo": "enregelar",
    "enregelarmos": "enregelar",
    "enregelará": "enregelar",
    "enregelarás": "enregelar",
    "enregelarão": "enregelar",
    "enregelaríamos": "enregelar",
    "enregelaríeis": "enregelar",
    "enregelas": "enregelar",
    "enregelasse": "enregelar",
    "enregelassem": "enregelar",
    "enregelasses": "enregelar",
    "enregelaste": "enregelar",
    "enregelastes": "enregelar",
    "enregelava": "enregelar",
    "enregelavam": "enregelar",
    "enregelavas": "enregelar",
    "enregele": "enregelar",
    "enregelei": "enregelar",
    "enregeleis": "enregelar",
    "enregelem": "enregelar",
    "enregelemo": "enregelar",
    "enregelemos": "enregelar",
    "enregeles": "enregelar",
    "enregelo": "enregelar",
    "enregelou": "enregelar",
    "enregelá": "enregelar",
    "enregelámo": "enregelar",
    "enregelámos": "enregelar",
    "enregeláramo": "enregelar",
    "enregeláramos": "enregelar",
    "enregelárei": "enregelar",
    "enregeláreis": "enregelar",
    "enregelásseis": "enregelar",
    "enregelássemos": "enregelar",
    "enregelávamo": "enregelar",
    "enregelávamos": "enregelar",
    "enregelávei": "enregelar",
    "enregeláveis": "enregelar",
    "enreixa": "enreixar",
    "enreixada": "enreixar",
    "enreixadas": "enreixar",
    "enreixado": "enreixar",
    "enreixados": "enreixar",
    "enreixai": "enreixar",
    "enreixais": "enreixar",
    "enreixam": "enreixar",
    "enreixamo": "enreixar",
    "enreixamos": "enreixar",
    "enreixando": "enreixar",
    "enreixara": "enreixar",
    "enreixaram": "enreixar",
    "enreixaras": "enreixar",
    "enreixardes": "enreixar",
    "enreixarei": "enreixar",
    "enreixareis": "enreixar",
    "enreixarem": "enreixar",
    "enreixaremos": "enreixar",
    "enreixares": "enreixar",
    "enreixaria": "enreixar",
    "enreixariam": "enreixar",
    "enreixarias": "enreixar",
    "enreixarmo": "enreixar",
    "enreixarmos": "enreixar",
    "enreixará": "enreixar",
    "enreixarás": "enreixar",
    "enreixarão": "enreixar",
    "enreixaríamos": "enreixar",
    "enreixaríeis": "enreixar",
    "enreixas": "enreixar",
    "enreixasse": "enreixar",
    "enreixassem": "enreixar",
    "enreixasses": "enreixar",
    "enreixaste": "enreixar",
    "enreixastes": "enreixar",
    "enreixava": "enreixar",
    "enreixavam": "enreixar",
    "enreixavas": "enreixar",
    "enreixe": "enreixar",
    "enreixei": "enreixar",
    "enreixeis": "enreixar",
    "enreixem": "enreixar",
    "enreixemo": "enreixar",
    "enreixemos": "enreixar",
    "enreixes": "enreixar",
    "enreixo": "enreixar",
    "enreixou": "enreixar",
    "enreixámo": "enreixar",
    "enreixámos": "enreixar",
    "enreixáramo": "enreixar",
    "enreixáramos": "enreixar",
    "enreixáreis": "enreixar",
    "enreixásseis": "enreixar",
    "enreixássemos": "enreixar",
    "enreixávamo": "enreixar",
    "enreixávamos": "enreixar",
    "enreixáveis": "enreixar",
    "enrelha": "enrelhar",
    "enrelhada": "enrelhar",
    "enrelhadas": "enrelhar",
    "enrelhado": "enrelhar",
    "enrelhados": "enrelhar",
    "enrelhai": "enrelhar",
    "enrelhais": "enrelhar",
    "enrelham": "enrelhar",
    "enrelhamo": "enrelhar",
    "enrelhamos": "enrelhar",
    "enrelhando": "enrelhar",
    "enrelhara": "enrelhar",
    "enrelharam": "enrelhar",
    "enrelharas": "enrelhar",
    "enrelharde": "enrelhar",
    "enrelhardes": "enrelhar",
    "enrelhare": "enrelhar",
    "enrelharei": "enrelhar",
    "enrelhareis": "enrelhar",
    "enrelharem": "enrelhar",
    "enrelharemos": "enrelhar",
    "enrelhares": "enrelhar",
    "enrelharia": "enrelhar",
    "enrelhariam": "enrelhar",
    "enrelharias": "enrelhar",
    "enrelharmo": "enrelhar",
    "enrelharmos": "enrelhar",
    "enrelhará": "enrelhar",
    "enrelharás": "enrelhar",
    "enrelharão": "enrelhar",
    "enrelharíamos": "enrelhar",
    "enrelharíeis": "enrelhar",
    "enrelhas": "enrelhar",
    "enrelhasse": "enrelhar",
    "enrelhassem": "enrelhar",
    "enrelhasses": "enrelhar",
    "enrelhaste": "enrelhar",
    "enrelhastes": "enrelhar",
    "enrelhava": "enrelhar",
    "enrelhavam": "enrelhar",
    "enrelhavas": "enrelhar",
    "enrelhe": "enrelhar",
    "enrelhei": "enrelhar",
    "enrelheis": "enrelhar",
    "enrelhem": "enrelhar",
    "enrelhemo": "enrelhar",
    "enrelhemos": "enrelhar",
    "enrelhes": "enrelhar",
    "enrelho": "enrelhar",
    "enrelhou": "enrelhar",
    "enrelhá": "enrelhar",
    "enrelhámo": "enrelhar",
    "enrelhámos": "enrelhar",
    "enrelháramo": "enrelhar",
    "enrelháramos": "enrelhar",
    "enrelhárei": "enrelhar",
    "enrelháreis": "enrelhar",
    "enrelhásseis": "enrelhar",
    "enrelhássemos": "enrelhar",
    "enrelhávamo": "enrelhar",
    "enrelhávamos": "enrelhar",
    "enrelhávei": "enrelhar",
    "enrelháveis": "enrelhar",
    "enrelva": "enrelvar",
    "enrelvada": "enrelvar",
    "enrelvadas": "enrelvar",
    "enrelvado": "enrelvar",
    "enrelvados": "enrelvar",
    "enrelvai": "enrelvar",
    "enrelvais": "enrelvar",
    "enrelvam": "enrelvar",
    "enrelvamo": "enrelvar",
    "enrelvamos": "enrelvar",
    "enrelvando": "enrelvar",
    "enrelvara": "enrelvar",
    "enrelvaram": "enrelvar",
    "enrelvaras": "enrelvar",
    "enrelvarde": "enrelvar",
    "enrelvardes": "enrelvar",
    "enrelvare": "enrelvar",
    "enrelvarei": "enrelvar",
    "enrelvareis": "enrelvar",
    "enrelvarem": "enrelvar",
    "enrelvaremos": "enrelvar",
    "enrelvares": "enrelvar",
    "enrelvaria": "enrelvar",
    "enrelvariam": "enrelvar",
    "enrelvarias": "enrelvar",
    "enrelvarmo": "enrelvar",
    "enrelvarmos": "enrelvar",
    "enrelvará": "enrelvar",
    "enrelvarás": "enrelvar",
    "enrelvarão": "enrelvar",
    "enrelvaríamos": "enrelvar",
    "enrelvaríeis": "enrelvar",
    "enrelvas": "enrelvar",
    "enrelvasse": "enrelvar",
    "enrelvassem": "enrelvar",
    "enrelvasses": "enrelvar",
    "enrelvaste": "enrelvar",
    "enrelvastes": "enrelvar",
    "enrelvava": "enrelvar",
    "enrelvavam": "enrelvar",
    "enrelvavas": "enrelvar",
    "enrelve": "enrelvar",
    "enrelvei": "enrelvar",
    "enrelveis": "enrelvar",
    "enrelvem": "enrelvar",
    "enrelvemo": "enrelvar",
    "enrelvemos": "enrelvar",
    "enrelves": "enrelvar",
    "enrelvo": "enrelvar",
    "enrelvou": "enrelvar",
    "enrelvá": "enrelvar",
    "enrelvámo": "enrelvar",
    "enrelvámos": "enrelvar",
    "enrelváramo": "enrelvar",
    "enrelváramos": "enrelvar",
    "enrelvárei": "enrelvar",
    "enrelváreis": "enrelvar",
    "enrelvásseis": "enrelvar",
    "enrelvássemos": "enrelvar",
    "enrelvávamo": "enrelvar",
    "enrelvávamos": "enrelvar",
    "enrelvávei": "enrelvar",
    "enrelváveis": "enrelvar",
    "enremissa": "enremissar",
    "enremissada": "enremissar",
    "enremissadas": "enremissar",
    "enremissado": "enremissar",
    "enremissados": "enremissar",
    "enremissai": "enremissar",
    "enremissais": "enremissar",
    "enremissam": "enremissar",
    "enremissamo": "enremissar",
    "enremissamos": "enremissar",
    "enremissando": "enremissar",
    "enremissara": "enremissar",
    "enremissaram": "enremissar",
    "enremissaras": "enremissar",
    "enremissarde": "enremissar",
    "enremissardes": "enremissar",
    "enremissare": "enremissar",
    "enremissarei": "enremissar",
    "enremissareis": "enremissar",
    "enremissarem": "enremissar",
    "enremissaremos": "enremissar",
    "enremissares": "enremissar",
    "enremissaria": "enremissar",
    "enremissariam": "enremissar",
    "enremissarias": "enremissar",
    "enremissarmo": "enremissar",
    "enremissarmos": "enremissar",
    "enremissará": "enremissar",
    "enremissarás": "enremissar",
    "enremissarão": "enremissar",
    "enremissaríamos": "enremissar",
    "enremissaríeis": "enremissar",
    "enremissas": "enremissar",
    "enremissasse": "enremissar",
    "enremissassem": "enremissar",
    "enremissasses": "enremissar",
    "enremissaste": "enremissar",
    "enremissastes": "enremissar",
    "enremissava": "enremissar",
    "enremissavam": "enremissar",
    "enremissavas": "enremissar",
    "enremisse": "enremissar",
    "enremissei": "enremissar",
    "enremisseis": "enremissar",
    "enremissem": "enremissar",
    "enremissemo": "enremissar",
    "enremissemos": "enremissar",
    "enremisses": "enremissar",
    "enremisso": "enremissar",
    "enremissou": "enremissar",
    "enremissá": "enremissar",
    "enremissámo": "enremissar",
    "enremissámos": "enremissar",
    "enremissáramo": "enremissar",
    "enremissáramos": "enremissar",
    "enremissárei": "enremissar",
    "enremissáreis": "enremissar",
    "enremissásseis": "enremissar",
    "enremissássemos": "enremissar",
    "enremissávamo": "enremissar",
    "enremissávamos": "enremissar",
    "enremissávei": "enremissar",
    "enremissáveis": "enremissar",
    "enrepolha": "enrepolhar",
    "enrepolhada": "enrepolhar",
    "enrepolhadas": "enrepolhar",
    "enrepolhado": "enrepolhar",
    "enrepolhados": "enrepolhar",
    "enrepolhai": "enrepolhar",
    "enrepolhais": "enrepolhar",
    "enrepolham": "enrepolhar",
    "enrepolhamo": "enrepolhar",
    "enrepolhamos": "enrepolhar",
    "enrepolhando": "enrepolhar",
    "enrepolhara": "enrepolhar",
    "enrepolharam": "enrepolhar",
    "enrepolharas": "enrepolhar",
    "enrepolharde": "enrepolhar",
    "enrepolhardes": "enrepolhar",
    "enrepolhare": "enrepolhar",
    "enrepolharei": "enrepolhar",
    "enrepolhareis": "enrepolhar",
    "enrepolharem": "enrepolhar",
    "enrepolharemos": "enrepolhar",
    "enrepolhares": "enrepolhar",
    "enrepolharia": "enrepolhar",
    "enrepolhariam": "enrepolhar",
    "enrepolharias": "enrepolhar",
    "enrepolharmo": "enrepolhar",
    "enrepolharmos": "enrepolhar",
    "enrepolhará": "enrepolhar",
    "enrepolharás": "enrepolhar",
    "enrepolharão": "enrepolhar",
    "enrepolharíamos": "enrepolhar",
    "enrepolharíeis": "enrepolhar",
    "enrepolhas": "enrepolhar",
    "enrepolhasse": "enrepolhar",
    "enrepolhassem": "enrepolhar",
    "enrepolhasses": "enrepolhar",
    "enrepolhaste": "enrepolhar",
    "enrepolhastes": "enrepolhar",
    "enrepolhava": "enrepolhar",
    "enrepolhavam": "enrepolhar",
    "enrepolhavas": "enrepolhar",
    "enrepolhe": "enrepolhar",
    "enrepolhei": "enrepolhar",
    "enrepolheis": "enrepolhar",
    "enrepolhem": "enrepolhar",
    "enrepolhemo": "enrepolhar",
    "enrepolhemos": "enrepolhar",
    "enrepolhes": "enrepolhar",
    "enrepolho": "enrepolhar",
    "enrepolhou": "enrepolhar",
    "enrepolhá": "enrepolhar",
    "enrepolhámo": "enrepolhar",
    "enrepolhámos": "enrepolhar",
    "enrepolháramo": "enrepolhar",
    "enrepolháramos": "enrepolhar",
    "enrepolhárei": "enrepolhar",
    "enrepolháreis": "enrepolhar",
    "enrepolhásseis": "enrepolhar",
    "enrepolhássemos": "enrepolhar",
    "enrepolhávamo": "enrepolhar",
    "enrepolhávamos": "enrepolhar",
    "enrepolhávei": "enrepolhar",
    "enrepolháveis": "enrepolhar",
    "enresina": "enresinar",
    "enresinada": "enresinar",
    "enresinadas": "enresinar",
    "enresinado": "enresinar",
    "enresinados": "enresinar",
    "enresinai": "enresinar",
    "enresinais": "enresinar",
    "enresinam": "enresinar",
    "enresinamo": "enresinar",
    "enresinamos": "enresinar",
    "enresinando": "enresinar",
    "enresinara": "enresinar",
    "enresinaram": "enresinar",
    "enresinaras": "enresinar",
    "enresinarde": "enresinar",
    "enresinardes": "enresinar",
    "enresinare": "enresinar",
    "enresinarei": "enresinar",
    "enresinareis": "enresinar",
    "enresinarem": "enresinar",
    "enresinaremos": "enresinar",
    "enresinares": "enresinar",
    "enresinaria": "enresinar",
    "enresinariam": "enresinar",
    "enresinarias": "enresinar",
    "enresinarmo": "enresinar",
    "enresinarmos": "enresinar",
    "enresinará": "enresinar",
    "enresinarás": "enresinar",
    "enresinarão": "enresinar",
    "enresinaríamos": "enresinar",
    "enresinaríeis": "enresinar",
    "enresinas": "enresinar",
    "enresinasse": "enresinar",
    "enresinassem": "enresinar",
    "enresinasses": "enresinar",
    "enresinaste": "enresinar",
    "enresinastes": "enresinar",
    "enresinava": "enresinar",
    "enresinavam": "enresinar",
    "enresinavas": "enresinar",
    "enresine": "enresinar",
    "enresinei": "enresinar",
    "enresineis": "enresinar",
    "enresinem": "enresinar",
    "enresinemo": "enresinar",
    "enresinemos": "enresinar",
    "enresines": "enresinar",
    "enresino": "enresinar",
    "enresinou": "enresinar",
    "enresiná": "enresinar",
    "enresinámo": "enresinar",
    "enresinámos": "enresinar",
    "enresináramo": "enresinar",
    "enresináramos": "enresinar",
    "enresinárei": "enresinar",
    "enresináreis": "enresinar",
    "enresinásseis": "enresinar",
    "enresinássemos": "enresinar",
    "enresinávamo": "enresinar",
    "enresinávamos": "enresinar",
    "enresinávei": "enresinar",
    "enresináveis": "enresinar",
    "enresma": "enresmar",
    "enresmada": "enresmar",
    "enresmadas": "enresmar",
    "enresmado": "enresmar",
    "enresmados": "enresmar",
    "enresmai": "enresmar",
    "enresmais": "enresmar",
    "enresmam": "enresmar",
    "enresmamo": "enresmar",
    "enresmamos": "enresmar",
    "enresmando": "enresmar",
    "enresmara": "enresmar",
    "enresmaram": "enresmar",
    "enresmaras": "enresmar",
    "enresmarde": "enresmar",
    "enresmardes": "enresmar",
    "enresmare": "enresmar",
    "enresmarei": "enresmar",
    "enresmareis": "enresmar",
    "enresmarem": "enresmar",
    "enresmaremos": "enresmar",
    "enresmares": "enresmar",
    "enresmaria": "enresmar",
    "enresmariam": "enresmar",
    "enresmarias": "enresmar",
    "enresmarmo": "enresmar",
    "enresmarmos": "enresmar",
    "enresmará": "enresmar",
    "enresmarás": "enresmar",
    "enresmarão": "enresmar",
    "enresmaríamos": "enresmar",
    "enresmaríeis": "enresmar",
    "enresmas": "enresmar",
    "enresmasse": "enresmar",
    "enresmassem": "enresmar",
    "enresmasses": "enresmar",
    "enresmaste": "enresmar",
    "enresmastes": "enresmar",
    "enresmava": "enresmar",
    "enresmavam": "enresmar",
    "enresmavas": "enresmar",
    "enresme": "enresmar",
    "enresmei": "enresmar",
    "enresmeis": "enresmar",
    "enresmem": "enresmar",
    "enresmemo": "enresmar",
    "enresmemos": "enresmar",
    "enresmes": "enresmar",
    "enresmo": "enresmar",
    "enresmou": "enresmar",
    "enresmá": "enresmar",
    "enresmámo": "enresmar",
    "enresmámos": "enresmar",
    "enresmáramo": "enresmar",
    "enresmáramos": "enresmar",
    "enresmárei": "enresmar",
    "enresmáreis": "enresmar",
    "enresmásseis": "enresmar",
    "enresmássemos": "enresmar",
    "enresmávamo": "enresmar",
    "enresmávamos": "enresmar",
    "enresmávei": "enresmar",
    "enresmáveis": "enresmar",
    "enrestia": "enrestiar",
    "enrestiada": "enrestiar",
    "enrestiadas": "enrestiar",
    "enrestiado": "enrestiar",
    "enrestiados": "enrestiar",
    "enrestiai": "enrestiar",
    "enrestiais": "enrestiar",
    "enrestiam": "enrestiar",
    "enrestiamo": "enrestiar",
    "enrestiamos": "enrestiar",
    "enrestiando": "enrestiar",
    "enrestiara": "enrestiar",
    "enrestiaram": "enrestiar",
    "enrestiaras": "enrestiar",
    "enrestiarde": "enrestiar",
    "enrestiardes": "enrestiar",
    "enrestiare": "enrestiar",
    "enrestiarei": "enrestiar",
    "enrestiareis": "enrestiar",
    "enrestiarem": "enrestiar",
    "enrestiaremos": "enrestiar",
    "enrestiares": "enrestiar",
    "enrestiaria": "enrestiar",
    "enrestiariam": "enrestiar",
    "enrestiarias": "enrestiar",
    "enrestiarmo": "enrestiar",
    "enrestiarmos": "enrestiar",
    "enrestiará": "enrestiar",
    "enrestiarás": "enrestiar",
    "enrestiarão": "enrestiar",
    "enrestiaríamos": "enrestiar",
    "enrestiaríeis": "enrestiar",
    "enrestias": "enrestiar",
    "enrestiasse": "enrestiar",
    "enrestiassem": "enrestiar",
    "enrestiasses": "enrestiar",
    "enrestiaste": "enrestiar",
    "enrestiastes": "enrestiar",
    "enrestiava": "enrestiar",
    "enrestiavam": "enrestiar",
    "enrestiavas": "enrestiar",
    "enrestie": "enrestiar",
    "enrestiei": "enrestiar",
    "enrestieis": "enrestiar",
    "enrestiem": "enrestiar",
    "enrestiemo": "enrestiar",
    "enrestiemos": "enrestiar",
    "enresties": "enrestiar",
    "enrestio": "enrestiar",
    "enrestiou": "enrestiar",
    "enrestiá": "enrestiar",
    "enrestiámo": "enrestiar",
    "enrestiámos": "enrestiar",
    "enrestiáramo": "enrestiar",
    "enrestiáramos": "enrestiar",
    "enrestiárei": "enrestiar",
    "enrestiáreis": "enrestiar",
    "enrestiásseis": "enrestiar",
    "enrestiássemos": "enrestiar",
    "enrestiávamo": "enrestiar",
    "enrestiávamos": "enrestiar",
    "enrestiávei": "enrestiar",
    "enrestiáveis": "enrestiar",
    "enrevesa": "enrevesar",
    "enrevesada": "enrevesar",
    "enrevesadas": "enrevesar",
    "enrevesado": "enrevesar",
    "enrevesados": "enrevesar",
    "enrevesai": "enrevesar",
    "enrevesais": "enrevesar",
    "enrevesam": "enrevesar",
    "enrevesamo": "enrevesar",
    "enrevesamos": "enrevesar",
    "enrevesando": "enrevesar",
    "enrevesara": "enrevesar",
    "enrevesaram": "enrevesar",
    "enrevesaras": "enrevesar",
    "enrevesarde": "enrevesar",
    "enrevesardes": "enrevesar",
    "enrevesare": "enrevesar",
    "enrevesarei": "enrevesar",
    "enrevesareis": "enrevesar",
    "enrevesarem": "enrevesar",
    "enrevesaremos": "enrevesar",
    "enrevesares": "enrevesar",
    "enrevesaria": "enrevesar",
    "enrevesariam": "enrevesar",
    "enrevesarias": "enrevesar",
    "enrevesarmo": "enrevesar",
    "enrevesarmos": "enrevesar",
    "enrevesará": "enrevesar",
    "enrevesarás": "enrevesar",
    "enrevesarão": "enrevesar",
    "enrevesaríamos": "enrevesar",
    "enrevesaríeis": "enrevesar",
    "enrevesas": "enrevesar",
    "enrevesasse": "enrevesar",
    "enrevesassem": "enrevesar",
    "enrevesasses": "enrevesar",
    "enrevesaste": "enrevesar",
    "enrevesastes": "enrevesar",
    "enrevesava": "enrevesar",
    "enrevesavam": "enrevesar",
    "enrevesavas": "enrevesar",
    "enrevese": "enrevesar",
    "enrevesei": "enrevesar",
    "enreveseis": "enrevesar",
    "enrevesem": "enrevesar",
    "enrevesemo": "enrevesar",
    "enrevesemos": "enrevesar",
    "enreveses": "enrevesar",
    "enreveso": "enrevesar",
    "enrevesou": "enrevesar",
    "enrevesá": "enrevesar",
    "enrevesámo": "enrevesar",
    "enrevesámos": "enrevesar",
    "enrevesáramo": "enrevesar",
    "enrevesáramos": "enrevesar",
    "enrevesárei": "enrevesar",
    "enrevesáreis": "enrevesar",
    "enrevesásseis": "enrevesar",
    "enrevesássemos": "enrevesar",
    "enrevesávamo": "enrevesar",
    "enrevesávamos": "enrevesar",
    "enrevesávei": "enrevesar",
    "enrevesáveis": "enrevesar",
    "enria": "enriar",
    "enriada": "enriar",
    "enriadas": "enriar",
    "enriado": "enriar",
    "enriados": "enriar",
    "enriai": "enriar",
    "enriais": "enriar",
    "enriam": "enriar",
    "enriamo": "enriar",
    "enriamos": "enriar",
    "enriando": "enriar",
    "enriara": "enriar",
    "enriaram": "enriar",
    "enriaras": "enriar",
    "enriarde": "enriar",
    "enriardes": "enriar",
    "enriare": "enriar",
    "enriarei": "enriar",
    "enriareis": "enriar",
    "enriarem": "enriar",
    "enriaremos": "enriar",
    "enriares": "enriar",
    "enriaria": "enriar",
    "enriariam": "enriar",
    "enriarias": "enriar",
    "enriarmo": "enriar",
    "enriarmos": "enriar",
    "enriará": "enriar",
    "enriarás": "enriar",
    "enriarão": "enriar",
    "enriaríamos": "enriar",
    "enriaríeis": "enriar",
    "enrias": "enriar",
    "enriasse": "enriar",
    "enriassem": "enriar",
    "enriasses": "enriar",
    "enriaste": "enriar",
    "enriastes": "enriar",
    "enriava": "enriar",
    "enriavam": "enriar",
    "enriavas": "enriar",
    "enrica": "enricar",
    "enricada": "enricar",
    "enricadas": "enricar",
    "enricado": "enricar",
    "enricados": "enricar",
    "enricai": "enricar",
    "enricais": "enricar",
    "enricam": "enricar",
    "enricamo": "enricar",
    "enricamos": "enricar",
    "enricando": "enricar",
    "enricara": "enricar",
    "enricaram": "enricar",
    "enricaras": "enricar",
    "enricarde": "enricar",
    "enricardes": "enricar",
    "enricare": "enricar",
    "enricarei": "enricar",
    "enricareis": "enricar",
    "enricarem": "enricar",
    "enricaremos": "enricar",
    "enricares": "enricar",
    "enricaria": "enricar",
    "enricariam": "enricar",
    "enricarias": "enricar",
    "enricarmo": "enricar",
    "enricarmos": "enricar",
    "enricará": "enricar",
    "enricarás": "enricar",
    "enricarão": "enricar",
    "enricaríamos": "enricar",
    "enricaríeis": "enricar",
    "enricas": "enricar",
    "enricasse": "enricar",
    "enricassem": "enricar",
    "enricasses": "enricar",
    "enricaste": "enricar",
    "enricastes": "enricar",
    "enricava": "enricar",
    "enricavam": "enricar",
    "enricavas": "enricar",
    "enrice": "enriçar",
    "enricei": "enriçar",
    "enriceis": "enriçar",
    "enricem": "enriçar",
    "enricemo": "enriçar",
    "enricemos": "enriçar",
    "enrices": "enriçar",
    "enrico": "enricar",
    "enricou": "enricar",
    "enricá": "enricar",
    "enricámo": "enricar",
    "enricámos": "enricar",
    "enricáramo": "enricar",
    "enricáramos": "enricar",
    "enricárei": "enricar",
    "enricáreis": "enricar",
    "enricásseis": "enricar",
    "enricássemos": "enricar",
    "enricávamo": "enricar",
    "enricávamos": "enricar",
    "enricávei": "enricar",
    "enricáveis": "enricar",
    "enrie": "enriar",
    "enriei": "enriar",
    "enrieis": "enriar",
    "enriem": "enriar",
    "enriemo": "enriar",
    "enriemos": "enriar",
    "enries": "enriar",
    "enrija": "enrijar",
    "enrijada": "enrijar",
    "enrijadas": "enrijar",
    "enrijado": "enrijar",
    "enrijados": "enrijar",
    "enrijai": "enrijar",
    "enrijais": "enrijar",
    "enrijam": "enrijar",
    "enrijamentos": "enrijamento",
    "enrijamo": "enrijar",
    "enrijamos": "enrijar",
    "enrijando": "enrijar",
    "enrijara": "enrijar",
    "enrijaram": "enrijar",
    "enrijaras": "enrijar",
    "enrijarde": "enrijar",
    "enrijardes": "enrijar",
    "enrijare": "enrijar",
    "enrijarei": "enrijar",
    "enrijareis": "enrijar",
    "enrijarem": "enrijar",
    "enrijaremos": "enrijar",
    "enrijares": "enrijar",
    "enrijaria": "enrijar",
    "enrijariam": "enrijar",
    "enrijarias": "enrijar",
    "enrijarmo": "enrijar",
    "enrijarmos": "enrijar",
    "enrijará": "enrijar",
    "enrijarás": "enrijar",
    "enrijarão": "enrijar",
    "enrijaríamos": "enrijar",
    "enrijaríeis": "enrijar",
    "enrijas": "enrijar",
    "enrijasse": "enrijar",
    "enrijassem": "enrijar",
    "enrijasses": "enrijar",
    "enrijaste": "enrijar",
    "enrijastes": "enrijar",
    "enrijava": "enrijar",
    "enrijavam": "enrijar",
    "enrijavas": "enrijar",
    "enrije": "enrijar",
    "enrijece": "enrijecer",
    "enrijecei": "enrijecer",
    "enrijeceis": "enrijecer",
    "enrijecem": "enrijecer",
    "enrijecemo": "enrijecer",
    "enrijecemos": "enrijecer",
    "enrijecendo": "enrijecer",
    "enrijecera": "enrijecer",
    "enrijeceram": "enrijecer",
    "enrijeceras": "enrijecer",
    "enrijecerde": "enrijecer",
    "enrijecerdes": "enrijecer",
    "enrijecere": "enrijecer",
    "enrijecerei": "enrijecer",
    "enrijecereis": "enrijecer",
    "enrijecerem": "enrijecer",
    "enrijeceremos": "enrijecer",
    "enrijeceres": "enrijecer",
    "enrijeceria": "enrijecer",
    "enrijeceriam": "enrijecer",
    "enrijecerias": "enrijecer",
    "enrijecermo": "enrijecer",
    "enrijecermos": "enrijecer",
    "enrijecerá": "enrijecer",
    "enrijecerás": "enrijecer",
    "enrijecerão": "enrijecer",
    "enrijeceríamos": "enrijecer",
    "enrijeceríeis": "enrijecer",
    "enrijeces": "enrijecer",
    "enrijecesse": "enrijecer",
    "enrijecessem": "enrijecer",
    "enrijecesses": "enrijecer",
    "enrijeceste": "enrijecer",
    "enrijecestes": "enrijecer",
    "enrijeceu": "enrijecer",
    "enrijeci": "enrijecer",
    "enrijecia": "enrijecer",
    "enrijeciam": "enrijecer",
    "enrijecias": "enrijecer",
    "enrijecida": "enrijecer",
    "enrijecidas": "enrijecer",
    "enrijecido": "enrijecer",
    "enrijecidos": "enrijecer",
    "enrijecê": "enrijecer",
    "enrijecêramo": "enrijecer",
    "enrijecêramos": "enrijecer",
    "enrijecêrei": "enrijecer",
    "enrijecêreis": "enrijecer",
    "enrijecêsseis": "enrijecer",
    "enrijecêssemos": "enrijecer",
    "enrijecíamo": "enrijecer",
    "enrijecíamos": "enrijecer",
    "enrijecíei": "enrijecer",
    "enrijecíeis": "enrijecer",
    "enrijei": "enrijar",
    "enrijeis": "enrijar",
    "enrijem": "enrijar",
    "enrijemo": "enrijar",
    "enrijemos": "enrijar",
    "enrijes": "enrijar",
    "enrijeça": "enrijecer",
    "enrijeçais": "enrijecer",
    "enrijeçam": "enrijecer",
    "enrijeçamo": "enrijecer",
    "enrijeçamos": "enrijecer",
    "enrijeças": "enrijecer",
    "enrijeço": "enrijecer",
    "enrijo": "enrijar",
    "enrijou": "enrijar",
    "enrijá": "enrijar",
    "enrijámo": "enrijar",
    "enrijámos": "enrijar",
    "enrijáramo": "enrijar",
    "enrijáramos": "enrijar",
    "enrijárei": "enrijar",
    "enrijáreis": "enrijar",
    "enrijásseis": "enrijar",
    "enrijássemos": "enrijar",
    "enrijávamo": "enrijar",
    "enrijávamos": "enrijar",
    "enrijávei": "enrijar",
    "enrijáveis": "enrijar",
    "enrilha": "enrilhar",
    "enrilhada": "enrilhar",
    "enrilhadas": "enrilhar",
    "enrilhado": "enrilhar",
    "enrilhados": "enrilhar",
    "enrilhai": "enrilhar",
    "enrilhais": "enrilhar",
    "enrilham": "enrilhar",
    "enrilhamo": "enrilhar",
    "enrilhamos": "enrilhar",
    "enrilhando": "enrilhar",
    "enrilhara": "enrilhar",
    "enrilharam": "enrilhar",
    "enrilharas": "enrilhar",
    "enrilharde": "enrilhar",
    "enrilhardes": "enrilhar",
    "enrilhare": "enrilhar",
    "enrilharei": "enrilhar",
    "enrilhareis": "enrilhar",
    "enrilharem": "enrilhar",
    "enrilharemos": "enrilhar",
    "enrilhares": "enrilhar",
    "enrilharia": "enrilhar",
    "enrilhariam": "enrilhar",
    "enrilharias": "enrilhar",
    "enrilharmo": "enrilhar",
    "enrilharmos": "enrilhar",
    "enrilhará": "enrilhar",
    "enrilharás": "enrilhar",
    "enrilharão": "enrilhar",
    "enrilharíamos": "enrilhar",
    "enrilharíeis": "enrilhar",
    "enrilhas": "enrilhar",
    "enrilhasse": "enrilhar",
    "enrilhassem": "enrilhar",
    "enrilhasses": "enrilhar",
    "enrilhaste": "enrilhar",
    "enrilhastes": "enrilhar",
    "enrilhava": "enrilhar",
    "enrilhavam": "enrilhar",
    "enrilhavas": "enrilhar",
    "enrilhe": "enrilhar",
    "enrilhei": "enrilhar",
    "enrilheis": "enrilhar",
    "enrilhem": "enrilhar",
    "enrilhemo": "enrilhar",
    "enrilhemos": "enrilhar",
    "enrilhes": "enrilhar",
    "enrilho": "enrilhar",
    "enrilhou": "enrilhar",
    "enrilhá": "enrilhar",
    "enrilhámo": "enrilhar",
    "enrilhámos": "enrilhar",
    "enrilháramo": "enrilhar",
    "enrilháramos": "enrilhar",
    "enrilhárei": "enrilhar",
    "enrilháreis": "enrilhar",
    "enrilhásseis": "enrilhar",
    "enrilhássemos": "enrilhar",
    "enrilhávamo": "enrilhar",
    "enrilhávamos": "enrilhar",
    "enrilhávei": "enrilhar",
    "enrilháveis": "enrilhar",
    "enrio": "enriar",
    "enriou": "enriar",
    "enripamentos": "enripamento",
    "enrique": "enricar",
    "enriquece": "enriquecer",
    "enriquecedora": "enriquecedor",
    "enriquecedoras": "enriquecedor",
    "enriquecedores": "enriquecedor",
    "enriquecei": "enriquecer",
    "enriqueceis": "enriquecer",
    "enriquecem": "enriquecer",
    "enriquecemo": "enriquecer",
    "enriquecemos": "enriquecer",
    "enriquecendo": "enriquecer",
    "enriquecera": "enriquecer",
    "enriqueceram": "enriquecer",
    "enriqueceras": "enriquecer",
    "enriquecerde": "enriquecer",
    "enriquecerdes": "enriquecer",
    "enriquecere": "enriquecer",
    "enriquecerei": "enriquecer",
    "enriquecereis": "enriquecer",
    "enriquecerem": "enriquecer",
    "enriqueceremos": "enriquecer",
    "enriqueceres": "enriquecer",
    "enriqueceria": "enriquecer",
    "enriqueceriam": "enriquecer",
    "enriquecerias": "enriquecer",
    "enriquecermo": "enriquecer",
    "enriquecermos": "enriquecer",
    "enriquecerá": "enriquecer",
    "enriquecerás": "enriquecer",
    "enriquecerão": "enriquecer",
    "enriqueceríamos": "enriquecer",
    "enriqueceríeis": "enriquecer",
    "enriqueces": "enriquecer",
    "enriquecesse": "enriquecer",
    "enriquecessem": "enriquecer",
    "enriquecesses": "enriquecer",
    "enriqueceste": "enriquecer",
    "enriquecestes": "enriquecer",
    "enriqueceu": "enriquecer",
    "enriqueci": "enriquecer",
    "enriquecia": "enriquecer",
    "enriqueciam": "enriquecer",
    "enriquecias": "enriquecer",
    "enriquecida": "enriquecido",
    "enriquecidas": "enriquecido",
    "enriquecido": "enriquecer",
    "enriquecidos": "enriquecido",
    "enriquecimentos": "enriquecimento",
    "enriquecê": "enriquecer",
    "enriquecêramo": "enriquecer",
    "enriquecêramos": "enriquecer",
    "enriquecêrei": "enriquecer",
    "enriquecêreis": "enriquecer",
    "enriquecêsseis": "enriquecer",
    "enriquecêssemos": "enriquecer",
    "enriquecíamo": "enriquecer",
    "enriquecíamos": "enriquecer",
    "enriquecíei": "enriquecer",
    "enriquecíeis": "enriquecer",
    "enriquei": "enricar",
    "enriqueis": "enricar",
    "enriquem": "enricar",
    "enriquemo": "enricar",
    "enriquemos": "enricar",
    "enriques": "enricar",
    "enriqueça": "enriquecer",
    "enriqueçais": "enriquecer",
    "enriqueçam": "enriquecer",
    "enriqueçamo": "enriquecer",
    "enriqueçamos": "enriquecer",
    "enriqueças": "enriquecer",
    "enriqueço": "enriquecer",
    "enrista": "enristar",
    "enristada": "enristar",
    "enristadas": "enristar",
    "enristado": "enristar",
    "enristados": "enristar",
    "enristai": "enristar",
    "enristais": "enristar",
    "enristam": "enristar",
    "enristamo": "enristar",
    "enristamos": "enristar",
    "enristando": "enristar",
    "enristara": "enristar",
    "enristaram": "enristar",
    "enristaras": "enristar",
    "enristardes": "enristar",
    "enristarei": "enristar",
    "enristareis": "enristar",
    "enristarem": "enristar",
    "enristaremos": "enristar",
    "enristares": "enristar",
    "enristaria": "enristar",
    "enristariam": "enristar",
    "enristarias": "enristar",
    "enristarmo": "enristar",
    "enristarmos": "enristar",
    "enristará": "enristar",
    "enristarás": "enristar",
    "enristarão": "enristar",
    "enristaríamos": "enristar",
    "enristaríeis": "enristar",
    "enristas": "enristar",
    "enristasse": "enristar",
    "enristassem": "enristar",
    "enristasses": "enristar",
    "enristaste": "enristar",
    "enristastes": "enristar",
    "enristava": "enristar",
    "enristavam": "enristar",
    "enristavas": "enristar",
    "enriste": "enristar",
    "enristei": "enristar",
    "enristeis": "enristar",
    "enristem": "enristar",
    "enristemo": "enristar",
    "enristemos": "enristar",
    "enristes": "enristar",
    "enristo": "enristar",
    "enristou": "enristar",
    "enristámo": "enristar",
    "enristámos": "enristar",
    "enristáramo": "enristar",
    "enristáramos": "enristar",
    "enristáreis": "enristar",
    "enristásseis": "enristar",
    "enristássemos": "enristar",
    "enristávamo": "enristar",
    "enristávamos": "enristar",
    "enristáveis": "enristar",
    "enrixada": "enrixado",
    "enrixadas": "enrixado",
    "enrixados": "enrixado",
    "enriza": "enrizar",
    "enrizada": "enrizar",
    "enrizadas": "enrizar",
    "enrizado": "enrizar",
    "enrizados": "enrizar",
    "enrizai": "enrizar",
    "enrizais": "enrizar",
    "enrizam": "enrizar",
    "enrizamo": "enrizar",
    "enrizamos": "enrizar",
    "enrizando": "enrizar",
    "enrizara": "enrizar",
    "enrizaram": "enrizar",
    "enrizaras": "enrizar",
    "enrizarde": "enrizar",
    "enrizardes": "enrizar",
    "enrizare": "enrizar",
    "enrizarei": "enrizar",
    "enrizareis": "enrizar",
    "enrizarem": "enrizar",
    "enrizaremos": "enrizar",
    "enrizares": "enrizar",
    "enrizaria": "enrizar",
    "enrizariam": "enrizar",
    "enrizarias": "enrizar",
    "enrizarmo": "enrizar",
    "enrizarmos": "enrizar",
    "enrizará": "enrizar",
    "enrizarás": "enrizar",
    "enrizarão": "enrizar",
    "enrizaríamos": "enrizar",
    "enrizaríeis": "enrizar",
    "enrizas": "enrizar",
    "enrizasse": "enrizar",
    "enrizassem": "enrizar",
    "enrizasses": "enrizar",
    "enrizaste": "enrizar",
    "enrizastes": "enrizar",
    "enrizava": "enrizar",
    "enrizavam": "enrizar",
    "enrizavas": "enrizar",
    "enrize": "enrizar",
    "enrizei": "enrizar",
    "enrizeis": "enrizar",
    "enrizem": "enrizar",
    "enrizemo": "enrizar",
    "enrizemos": "enrizar",
    "enrizes": "enrizar",
    "enrizo": "enrizar",
    "enrizou": "enrizar",
    "enrizá": "enrizar",
    "enrizámo": "enrizar",
    "enrizámos": "enrizar",
    "enrizáramo": "enrizar",
    "enrizáramos": "enrizar",
    "enrizárei": "enrizar",
    "enrizáreis": "enrizar",
    "enrizásseis": "enrizar",
    "enrizássemos": "enrizar",
    "enrizávamo": "enrizar",
    "enrizávamos": "enrizar",
    "enrizávei": "enrizar",
    "enrizáveis": "enrizar",
    "enriá": "enriar",
    "enriámo": "enriar",
    "enriámos": "enriar",
    "enriáramo": "enriar",
    "enriáramos": "enriar",
    "enriárei": "enriar",
    "enriáreis": "enriar",
    "enriásseis": "enriar",
    "enriássemos": "enriar",
    "enriávamo": "enriar",
    "enriávamos": "enriar",
    "enriávei": "enriar",
    "enriáveis": "enriar",
    "enriça": "enriçar",
    "enriçada": "enriçar",
    "enriçadas": "enriçar",
    "enriçado": "enriçar",
    "enriçados": "enriçar",
    "enriçai": "enriçar",
    "enriçais": "enriçar",
    "enriçam": "enriçar",
    "enriçamo": "enriçar",
    "enriçamos": "enriçar",
    "enriçando": "enriçar",
    "enriçara": "enriçar",
    "enriçaram": "enriçar",
    "enriçaras": "enriçar",
    "enriçarde": "enriçar",
    "enriçardes": "enriçar",
    "enriçare": "enriçar",
    "enriçarei": "enriçar",
    "enriçareis": "enriçar",
    "enriçarem": "enriçar",
    "enriçaremos": "enriçar",
    "enriçares": "enriçar",
    "enriçaria": "enriçar",
    "enriçariam": "enriçar",
    "enriçarias": "enriçar",
    "enriçarmo": "enriçar",
    "enriçarmos": "enriçar",
    "enriçará": "enriçar",
    "enriçarás": "enriçar",
    "enriçarão": "enriçar",
    "enriçaríamos": "enriçar",
    "enriçaríeis": "enriçar",
    "enriças": "enriçar",
    "enriçasse": "enriçar",
    "enriçassem": "enriçar",
    "enriçasses": "enriçar",
    "enriçaste": "enriçar",
    "enriçastes": "enriçar",
    "enriçava": "enriçar",
    "enriçavam": "enriçar",
    "enriçavas": "enriçar",
    "enriço": "enriçar",
    "enriçou": "enriçar",
    "enriçá": "enriçar",
    "enriçámo": "enriçar",
    "enriçámos": "enriçar",
    "enriçáramo": "enriçar",
    "enriçáramos": "enriçar",
    "enriçárei": "enriçar",
    "enriçáreis": "enriçar",
    "enriçásseis": "enriçar",
    "enriçássemos": "enriçar",
    "enriçávamo": "enriçar",
    "enriçávamos": "enriçar",
    "enriçávei": "enriçar",
    "enriçáveis": "enriçar",
    "enrobustece": "enrobustecer",
    "enrobustecei": "enrobustecer",
    "enrobusteceis": "enrobustecer",
    "enrobustecem": "enrobustecer",
    "enrobustecemo": "enrobustecer",
    "enrobustecemos": "enrobustecer",
    "enrobustecendo": "enrobustecer",
    "enrobustecera": "enrobustecer",
    "enrobusteceram": "enrobustecer",
    "enrobusteceras": "enrobustecer",
    "enrobustecerdes": "enrobustecer",
    "enrobustecerei": "enrobustecer",
    "enrobustecereis": "enrobustecer",
    "enrobustecerem": "enrobustecer",
    "enrobusteceremos": "enrobustecer",
    "enrobusteceres": "enrobustecer",
    "enrobusteceria": "enrobustecer",
    "enrobusteceriam": "enrobustecer",
    "enrobustecerias": "enrobustecer",
    "enrobustecermo": "enrobustecer",
    "enrobustecermos": "enrobustecer",
    "enrobustecerá": "enrobustecer",
    "enrobustecerás": "enrobustecer",
    "enrobustecerão": "enrobustecer",
    "enrobusteceríamos": "enrobustecer",
    "enrobusteceríeis": "enrobustecer",
    "enrobusteces": "enrobustecer",
    "enrobustecesse": "enrobustecer",
    "enrobustecessem": "enrobustecer",
    "enrobustecesses": "enrobustecer",
    "enrobusteceste": "enrobustecer",
    "enrobustecestes": "enrobustecer",
    "enrobusteceu": "enrobustecer",
    "enrobusteci": "enrobustecer",
    "enrobustecia": "enrobustecer",
    "enrobusteciam": "enrobustecer",
    "enrobustecias": "enrobustecer",
    "enrobustecida": "enrobustecer",
    "enrobustecidas": "enrobustecer",
    "enrobustecido": "enrobustecer",
    "enrobustecidos": "enrobustecer",
    "enrobustecimentos": "enrobustecimento",
    "enrobustecêramo": "enrobustecer",
    "enrobustecêramos": "enrobustecer",
    "enrobustecêreis": "enrobustecer",
    "enrobustecêsseis": "enrobustecer",
    "enrobustecêssemos": "enrobustecer",
    "enrobustecíamo": "enrobustecer",
    "enrobustecíamos": "enrobustecer",
    "enrobustecíeis": "enrobustecer",
    "enrobusteça": "enrobustecer",
    "enrobusteçais": "enrobustecer",
    "enrobusteçam": "enrobustecer",
    "enrobusteçamo": "enrobustecer",
    "enrobusteçamos": "enrobustecer",
    "enrobusteças": "enrobustecer",
    "enrobusteço": "enrobustecer",
    "enroca": "enrocar",
    "enrocada": "enrocar",
    "enrocadas": "enrocar",
    "enrocado": "enrocar",
    "enrocados": "enrocar",
    "enrocai": "enrocar",
    "enrocais": "enrocar",
    "enrocam": "enrocar",
    "enrocamentos": "enrocamento",
    "enrocamo": "enrocar",
    "enrocamos": "enrocar",
    "enrocando": "enrocar",
    "enrocara": "enrocar",
    "enrocaram": "enrocar",
    "enrocaras": "enrocar",
    "enrocarde": "enrocar",
    "enrocardes": "enrocar",
    "enrocare": "enrocar",
    "enrocarei": "enrocar",
    "enrocareis": "enrocar",
    "enrocarem": "enrocar",
    "enrocaremos": "enrocar",
    "enrocares": "enrocar",
    "enrocaria": "enrocar",
    "enrocariam": "enrocar",
    "enrocarias": "enrocar",
    "enrocarmo": "enrocar",
    "enrocarmos": "enrocar",
    "enrocará": "enrocar",
    "enrocarás": "enrocar",
    "enrocarão": "enrocar",
    "enrocaríamos": "enrocar",
    "enrocaríeis": "enrocar",
    "enrocas": "enrocar",
    "enrocasse": "enrocar",
    "enrocassem": "enrocar",
    "enrocasses": "enrocar",
    "enrocaste": "enrocar",
    "enrocastes": "enrocar",
    "enrocava": "enrocar",
    "enrocavam": "enrocar",
    "enrocavas": "enrocar",
    "enroco": "enrocar",
    "enrocou": "enrocar",
    "enrocá": "enrocar",
    "enrocámo": "enrocar",
    "enrocámos": "enrocar",
    "enrocáramo": "enrocar",
    "enrocáramos": "enrocar",
    "enrocárei": "enrocar",
    "enrocáreis": "enrocar",
    "enrocásseis": "enrocar",
    "enrocássemos": "enrocar",
    "enrocávamo": "enrocar",
    "enrocávamos": "enrocar",
    "enrocávei": "enrocar",
    "enrocáveis": "enrocar",
    "enrodela": "enrodelar",
    "enrodelada": "enrodelar",
    "enrodeladas": "enrodelar",
    "enrodelado": "enrodelar",
    "enrodelados": "enrodelar",
    "enrodelai": "enrodelar",
    "enrodelais": "enrodelar",
    "enrodelam": "enrodelar",
    "enrodelamo": "enrodelar",
    "enrodelamos": "enrodelar",
    "enrodelando": "enrodelar",
    "enrodelara": "enrodelar",
    "enrodelaram": "enrodelar",
    "enrodelaras": "enrodelar",
    "enrodelarde": "enrodelar",
    "enrodelardes": "enrodelar",
    "enrodelare": "enrodelar",
    "enrodelarei": "enrodelar",
    "enrodelareis": "enrodelar",
    "enrodelarem": "enrodelar",
    "enrodelaremos": "enrodelar",
    "enrodelares": "enrodelar",
    "enrodelaria": "enrodelar",
    "enrodelariam": "enrodelar",
    "enrodelarias": "enrodelar",
    "enrodelarmo": "enrodelar",
    "enrodelarmos": "enrodelar",
    "enrodelará": "enrodelar",
    "enrodelarás": "enrodelar",
    "enrodelarão": "enrodelar",
    "enrodelaríamos": "enrodelar",
    "enrodelaríeis": "enrodelar",
    "enrodelas": "enrodelar",
    "enrodelasse": "enrodelar",
    "enrodelassem": "enrodelar",
    "enrodelasses": "enrodelar",
    "enrodelaste": "enrodelar",
    "enrodelastes": "enrodelar",
    "enrodelava": "enrodelar",
    "enrodelavam": "enrodelar",
    "enrodelavas": "enrodelar",
    "enrodele": "enrodelar",
    "enrodelei": "enrodelar",
    "enrodeleis": "enrodelar",
    "enrodelem": "enrodelar",
    "enrodelemo": "enrodelar",
    "enrodelemos": "enrodelar",
    "enrodeles": "enrodelar",
    "enrodelo": "enrodelar",
    "enrodelou": "enrodelar",
    "enrodelá": "enrodelar",
    "enrodelámo": "enrodelar",
    "enrodelámos": "enrodelar",
    "enrodeláramo": "enrodelar",
    "enrodeláramos": "enrodelar",
    "enrodelárei": "enrodelar",
    "enrodeláreis": "enrodelar",
    "enrodelásseis": "enrodelar",
    "enrodelássemos": "enrodelar",
    "enrodelávamo": "enrodelar",
    "enrodelávamos": "enrodelar",
    "enrodelávei": "enrodelar",
    "enrodeláveis": "enrodelar",
    "enrodilha": "enrodilhar",
    "enrodilhada": "enrodilhar",
    "enrodilhadas": "enrodilhar",
    "enrodilhado": "enrodilhar",
    "enrodilhadora": "enrodilhador",
    "enrodilhadoras": "enrodilhador",
    "enrodilhadores": "enrodilhador",
    "enrodilhados": "enrodilhar",
    "enrodilhai": "enrodilhar",
    "enrodilhais": "enrodilhar",
    "enrodilham": "enrodilhar",
    "enrodilhamo": "enrodilhar",
    "enrodilhamos": "enrodilhar",
    "enrodilhando": "enrodilhar",
    "enrodilhara": "enrodilhar",
    "enrodilharam": "enrodilhar",
    "enrodilharas": "enrodilhar",
    "enrodilharde": "enrodilhar",
    "enrodilhardes": "enrodilhar",
    "enrodilhare": "enrodilhar",
    "enrodilharei": "enrodilhar",
    "enrodilhareis": "enrodilhar",
    "enrodilharem": "enrodilhar",
    "enrodilharemos": "enrodilhar",
    "enrodilhares": "enrodilhar",
    "enrodilharia": "enrodilhar",
    "enrodilhariam": "enrodilhar",
    "enrodilharias": "enrodilhar",
    "enrodilharmo": "enrodilhar",
    "enrodilharmos": "enrodilhar",
    "enrodilhará": "enrodilhar",
    "enrodilharás": "enrodilhar",
    "enrodilharão": "enrodilhar",
    "enrodilharíamos": "enrodilhar",
    "enrodilharíeis": "enrodilhar",
    "enrodilhas": "enrodilhar",
    "enrodilhasse": "enrodilhar",
    "enrodilhassem": "enrodilhar",
    "enrodilhasses": "enrodilhar",
    "enrodilhaste": "enrodilhar",
    "enrodilhastes": "enrodilhar",
    "enrodilhava": "enrodilhar",
    "enrodilhavam": "enrodilhar",
    "enrodilhavas": "enrodilhar",
    "enrodilhe": "enrodilhar",
    "enrodilhei": "enrodilhar",
    "enrodilheis": "enrodilhar",
    "enrodilhem": "enrodilhar",
    "enrodilhemo": "enrodilhar",
    "enrodilhemos": "enrodilhar",
    "enrodilhes": "enrodilhar",
    "enrodilho": "enrodilhar",
    "enrodilhou": "enrodilhar",
    "enrodilhá": "enrodilhar",
    "enrodilhámo": "enrodilhar",
    "enrodilhámos": "enrodilhar",
    "enrodilháramo": "enrodilhar",
    "enrodilháramos": "enrodilhar",
    "enrodilhárei": "enrodilhar",
    "enrodilháreis": "enrodilhar",
    "enrodilhásseis": "enrodilhar",
    "enrodilhássemos": "enrodilhar",
    "enrodilhávamo": "enrodilhar",
    "enrodilhávamos": "enrodilhar",
    "enrodilhávei": "enrodilhar",
    "enrodilháveis": "enrodilhar",
    "enrodriga": "enrodrigar",
    "enrodrigada": "enrodrigar",
    "enrodrigadas": "enrodrigar",
    "enrodrigado": "enrodrigar",
    "enrodrigados": "enrodrigar",
    "enrodrigai": "enrodrigar",
    "enrodrigais": "enrodrigar",
    "enrodrigam": "enrodrigar",
    "enrodrigamo": "enrodrigar",
    "enrodrigamos": "enrodrigar",
    "enrodrigando": "enrodrigar",
    "enrodrigara": "enrodrigar",
    "enrodrigaram": "enrodrigar",
    "enrodrigaras": "enrodrigar",
    "enrodrigarde": "enrodrigar",
    "enrodrigardes": "enrodrigar",
    "enrodrigare": "enrodrigar",
    "enrodrigarei": "enrodrigar",
    "enrodrigareis": "enrodrigar",
    "enrodrigarem": "enrodrigar",
    "enrodrigaremos": "enrodrigar",
    "enrodrigares": "enrodrigar",
    "enrodrigaria": "enrodrigar",
    "enrodrigariam": "enrodrigar",
    "enrodrigarias": "enrodrigar",
    "enrodrigarmo": "enrodrigar",
    "enrodrigarmos": "enrodrigar",
    "enrodrigará": "enrodrigar",
    "enrodrigarás": "enrodrigar",
    "enrodrigarão": "enrodrigar",
    "enrodrigaríamos": "enrodrigar",
    "enrodrigaríeis": "enrodrigar",
    "enrodrigas": "enrodrigar",
    "enrodrigasse": "enrodrigar",
    "enrodrigassem": "enrodrigar",
    "enrodrigasses": "enrodrigar",
    "enrodrigaste": "enrodrigar",
    "enrodrigastes": "enrodrigar",
    "enrodrigava": "enrodrigar",
    "enrodrigavam": "enrodrigar",
    "enrodrigavas": "enrodrigar",
    "enrodrigo": "enrodrigar",
    "enrodrigou": "enrodrigar",
    "enrodrigue": "enrodrigar",
    "enrodriguei": "enrodrigar",
    "enrodrigueis": "enrodrigar",
    "enrodriguem": "enrodrigar",
    "enrodriguemo": "enrodrigar",
    "enrodriguemos": "enrodrigar",
    "enrodrigues": "enrodrigar",
    "enrodrigá": "enrodrigar",
    "enrodrigámo": "enrodrigar",
    "enrodrigámos": "enrodrigar",
    "enrodrigáramo": "enrodrigar",
    "enrodrigáramos": "enrodrigar",
    "enrodrigárei": "enrodrigar",
    "enrodrigáreis": "enrodrigar",
    "enrodrigásseis": "enrodrigar",
    "enrodrigássemos": "enrodrigar",
    "enrodrigávamo": "enrodrigar",
    "enrodrigávamos": "enrodrigar",
    "enrodrigávei": "enrodrigar",
    "enrodrigáveis": "enrodrigar",
    "enrola": "enrolar",
    "enrolada": "enrolar",
    "enroladas": "enrolar",
    "enroladeiras": "enroladeira",
    "enrolado": "enrolar",
    "enroladoiros": "enroladoiro",
    "enroladora": "enrolador",
    "enroladoras": "enrolador",
    "enroladores": "enrolador",
    "enrolados": "enrolar",
    "enroladouros": "enroladouro",
    "enrolai": "enrolar",
    "enrolais": "enrolar",
    "enrolam": "enrolar",
    "enrolamentos": "enrolamento",
    "enrolamo": "enrolar",
    "enrolamos": "enrolar",
    "enrolando": "enrolar",
    "enrolara": "enrolar",
    "enrolaram": "enrolar",
    "enrolaras": "enrolar",
    "enrolarde": "enrolar",
    "enrolardes": "enrolar",
    "enrolare": "enrolar",
    "enrolarei": "enrolar",
    "enrolareis": "enrolar",
    "enrolarem": "enrolar",
    "enrolaremos": "enrolar",
    "enrolares": "enrolar",
    "enrolaria": "enrolar",
    "enrolariam": "enrolar",
    "enrolarias": "enrolar",
    "enrolarmo": "enrolar",
    "enrolarmos": "enrolar",
    "enrolará": "enrolar",
    "enrolarás": "enrolar",
    "enrolarão": "enrolar",
    "enrolaríamos": "enrolar",
    "enrolaríeis": "enrolar",
    "enrolas": "enrolar",
    "enrolasse": "enrolar",
    "enrolassem": "enrolar",
    "enrolasses": "enrolar",
    "enrolaste": "enrolar",
    "enrolastes": "enrolar",
    "enrolava": "enrolar",
    "enrolavam": "enrolar",
    "enrolavas": "enrolar",
    "enrole": "enrolar",
    "enrolei": "enrolar",
    "enroleis": "enrolar",
    "enrolem": "enrolar",
    "enrolemo": "enrolar",
    "enrolemos": "enrolar",
    "enroles": "enrolar",
    "enrolha": "enrolhar",
    "enrolhada": "enrolhar",
    "enrolhadas": "enrolhar",
    "enrolhado": "enrolhar",
    "enrolhados": "enrolhar",
    "enrolhai": "enrolhar",
    "enrolhais": "enrolhar",
    "enrolham": "enrolhar",
    "enrolhamo": "enrolhar",
    "enrolhamos": "enrolhar",
    "enrolhando": "enrolhar",
    "enrolhara": "enrolhar",
    "enrolharam": "enrolhar",
    "enrolharas": "enrolhar",
    "enrolharde": "enrolhar",
    "enrolhardes": "enrolhar",
    "enrolhare": "enrolhar",
    "enrolharei": "enrolhar",
    "enrolhareis": "enrolhar",
    "enrolharem": "enrolhar",
    "enrolharemos": "enrolhar",
    "enrolhares": "enrolhar",
    "enrolharia": "enrolhar",
    "enrolhariam": "enrolhar",
    "enrolharias": "enrolhar",
    "enrolharmo": "enrolhar",
    "enrolharmos": "enrolhar",
    "enrolhará": "enrolhar",
    "enrolharás": "enrolhar",
    "enrolharão": "enrolhar",
    "enrolharíamos": "enrolhar",
    "enrolharíeis": "enrolhar",
    "enrolhas": "enrolhar",
    "enrolhasse": "enrolhar",
    "enrolhassem": "enrolhar",
    "enrolhasses": "enrolhar",
    "enrolhaste": "enrolhar",
    "enrolhastes": "enrolhar",
    "enrolhava": "enrolhar",
    "enrolhavam": "enrolhar",
    "enrolhavas": "enrolhar",
    "enrolhe": "enrolhar",
    "enrolhei": "enrolhar",
    "enrolheis": "enrolhar",
    "enrolhem": "enrolhar",
    "enrolhemo": "enrolhar",
    "enrolhemos": "enrolhar",
    "enrolhes": "enrolhar",
    "enrolho": "enrolhar",
    "enrolhou": "enrolhar",
    "enrolhá": "enrolhar",
    "enrolhámo": "enrolhar",
    "enrolhámos": "enrolhar",
    "enrolháramo": "enrolhar",
    "enrolháramos": "enrolhar",
    "enrolhárei": "enrolhar",
    "enrolháreis": "enrolhar",
    "enrolhásseis": "enrolhar",
    "enrolhássemos": "enrolhar",
    "enrolhávamo": "enrolhar",
    "enrolhávamos": "enrolhar",
    "enrolhávei": "enrolhar",
    "enrolháveis": "enrolhar",
    "enrolo": "enrolar",
    "enrolou": "enrolar",
    "enrolá": "enrolar",
    "enrolámo": "enrolar",
    "enrolámos": "enrolar",
    "enroláramo": "enrolar",
    "enroláramos": "enrolar",
    "enrolárei": "enrolar",
    "enroláreis": "enrolar",
    "enrolásseis": "enrolar",
    "enrolássemos": "enrolar",
    "enrolávamo": "enrolar",
    "enrolávamos": "enrolar",
    "enrolávei": "enrolar",
    "enroláveis": "enrolável",
    "enroque": "enrocar",
    "enroquei": "enrocar",
    "enroqueis": "enrocar",
    "enroquem": "enrocar",
    "enroquemo": "enrocar",
    "enroquemos": "enrocar",
    "enroques": "enrocar",
    "enrosca": "enroscar",
    "enroscada": "enroscar",
    "enroscadas": "enroscar",
    "enroscadelas": "enroscadela",
    "enroscado": "enroscar",
    "enroscados": "enroscar",
    "enroscaduras": "enroscadura",
    "enroscai": "enroscar",
    "enroscais": "enroscar",
    "enroscam": "enroscar",
    "enroscamentos": "enroscamento",
    "enroscamo": "enroscar",
    "enroscamos": "enroscar",
    "enroscando": "enroscar",
    "enroscara": "enroscar",
    "enroscaram": "enroscar",
    "enroscaras": "enroscar",
    "enroscarde": "enroscar",
    "enroscardes": "enroscar",
    "enroscare": "enroscar",
    "enroscarei": "enroscar",
    "enroscareis": "enroscar",
    "enroscarem": "enroscar",
    "enroscaremos": "enroscar",
    "enroscares": "enroscar",
    "enroscaria": "enroscar",
    "enroscariam": "enroscar",
    "enroscarias": "enroscar",
    "enroscarmo": "enroscar",
    "enroscarmos": "enroscar",
    "enroscará": "enroscar",
    "enroscarás": "enroscar",
    "enroscarão": "enroscar",
    "enroscaríamos": "enroscar",
    "enroscaríeis": "enroscar",
    "enroscas": "enroscar",
    "enroscasse": "enroscar",
    "enroscassem": "enroscar",
    "enroscasses": "enroscar",
    "enroscaste": "enroscar",
    "enroscastes": "enroscar",
    "enroscava": "enroscar",
    "enroscavam": "enroscar",
    "enroscavas": "enroscar",
    "enrosco": "enroscar",
    "enroscou": "enroscar",
    "enroscá": "enroscar",
    "enroscámo": "enroscar",
    "enroscámos": "enroscar",
    "enroscáramo": "enroscar",
    "enroscáramos": "enroscar",
    "enroscárei": "enroscar",
    "enroscáreis": "enroscar",
    "enroscásseis": "enroscar",
    "enroscássemos": "enroscar",
    "enroscávamo": "enroscar",
    "enroscávamos": "enroscar",
    "enroscávei": "enroscar",
    "enroscáveis": "enroscável",
    "enrosque": "enroscar",
    "enrosquei": "enroscar",
    "enrosqueis": "enroscar",
    "enrosquem": "enroscar",
    "enrosquemo": "enroscar",
    "enrosquemos": "enroscar",
    "enrosques": "enroscar",
    "enroupa": "enroupar",
    "enroupada": "enroupar",
    "enroupadas": "enroupar",
    "enroupado": "enroupar",
    "enroupados": "enroupar",
    "enroupai": "enroupar",
    "enroupais": "enroupar",
    "enroupam": "enroupar",
    "enroupamentos": "enroupamento",
    "enroupamo": "enroupar",
    "enroupamos": "enroupar",
    "enroupando": "enroupar",
    "enroupara": "enroupar",
    "enrouparam": "enroupar",
    "enrouparas": "enroupar",
    "enrouparde": "enroupar",
    "enroupardes": "enroupar",
    "enroupare": "enroupar",
    "enrouparei": "enroupar",
    "enroupareis": "enroupar",
    "enrouparem": "enroupar",
    "enrouparemos": "enroupar",
    "enroupares": "enroupar",
    "enrouparia": "enroupar",
    "enroupariam": "enroupar",
    "enrouparias": "enroupar",
    "enrouparmo": "enroupar",
    "enrouparmos": "enroupar",
    "enroupará": "enroupar",
    "enrouparás": "enroupar",
    "enrouparão": "enroupar",
    "enrouparíamos": "enroupar",
    "enrouparíeis": "enroupar",
    "enroupas": "enroupar",
    "enroupasse": "enroupar",
    "enroupassem": "enroupar",
    "enroupasses": "enroupar",
    "enroupaste": "enroupar",
    "enroupastes": "enroupar",
    "enroupava": "enroupar",
    "enroupavam": "enroupar",
    "enroupavas": "enroupar",
    "enroupe": "enroupar",
    "enroupei": "enroupar",
    "enroupeis": "enroupar",
    "enroupem": "enroupar",
    "enroupemo": "enroupar",
    "enroupemos": "enroupar",
    "enroupes": "enroupar",
    "enroupo": "enroupar",
    "enroupou": "enroupar",
    "enroupá": "enroupar",
    "enroupámo": "enroupar",
    "enroupámos": "enroupar",
    "enroupáramo": "enroupar",
    "enroupáramos": "enroupar",
    "enroupárei": "enroupar",
    "enroupáreis": "enroupar",
    "enroupásseis": "enroupar",
    "enroupássemos": "enroupar",
    "enroupávamo": "enroupar",
    "enroupávamos": "enroupar",
    "enroupávei": "enroupar",
    "enroupáveis": "enroupar",
    "enrouquece": "enrouquecer",
    "enrouquecei": "enrouquecer",
    "enrouqueceis": "enrouquecer",
    "enrouquecem": "enrouquecer",
    "enrouquecemo": "enrouquecer",
    "enrouquecemos": "enrouquecer",
    "enrouquecendo": "enrouquecer",
    "enrouquecera": "enrouquecer",
    "enrouqueceram": "enrouquecer",
    "enrouqueceras": "enrouquecer",
    "enrouquecerde": "enrouquecer",
    "enrouquecerdes": "enrouquecer",
    "enrouquecere": "enrouquecer",
    "enrouquecerei": "enrouquecer",
    "enrouquecereis": "enrouquecer",
    "enrouquecerem": "enrouquecer",
    "enrouqueceremos": "enrouquecer",
    "enrouqueceres": "enrouquecer",
    "enrouqueceria": "enrouquecer",
    "enrouqueceriam": "enrouquecer",
    "enrouquecerias": "enrouquecer",
    "enrouquecermo": "enrouquecer",
    "enrouquecermos": "enrouquecer",
    "enrouquecerá": "enrouquecer",
    "enrouquecerás": "enrouquecer",
    "enrouquecerão": "enrouquecer",
    "enrouqueceríamos": "enrouquecer",
    "enrouqueceríeis": "enrouquecer",
    "enrouqueces": "enrouquecer",
    "enrouquecesse": "enrouquecer",
    "enrouquecessem": "enrouquecer",
    "enrouquecesses": "enrouquecer",
    "enrouqueceste": "enrouquecer",
    "enrouquecestes": "enrouquecer",
    "enrouqueceu": "enrouquecer",
    "enrouqueci": "enrouquecer",
    "enrouquecia": "enrouquecer",
    "enrouqueciam": "enrouquecer",
    "enrouquecias": "enrouquecer",
    "enrouquecida": "enrouquecido",
    "enrouquecidas": "enrouquecido",
    "enrouquecido": "enrouquecer",
    "enrouquecidos": "enrouquecido",
    "enrouquecimentos": "enrouquecimento",
    "enrouquecê": "enrouquecer",
    "enrouquecêramo": "enrouquecer",
    "enrouquecêramos": "enrouquecer",
    "enrouquecêrei": "enrouquecer",
    "enrouquecêreis": "enrouquecer",
    "enrouquecêsseis": "enrouquecer",
    "enrouquecêssemos": "enrouquecer",
    "enrouquecíamo": "enrouquecer",
    "enrouquecíamos": "enrouquecer",
    "enrouquecíei": "enrouquecer",
    "enrouquecíeis": "enrouquecer",
    "enrouqueça": "enrouquecer",
    "enrouqueçais": "enrouquecer",
    "enrouqueçam": "enrouquecer",
    "enrouqueçamo": "enrouquecer",
    "enrouqueçamos": "enrouquecer",
    "enrouqueças": "enrouquecer",
    "enrouqueço": "enrouquecer",
    "enroxa": "enroxar",
    "enroxada": "enroxar",
    "enroxadas": "enroxar",
    "enroxado": "enroxar",
    "enroxados": "enroxar",
    "enroxai": "enroxar",
    "enroxais": "enroxar",
    "enroxam": "enroxar",
    "enroxamo": "enroxar",
    "enroxamos": "enroxar",
    "enroxando": "enroxar",
    "enroxara": "enroxar",
    "enroxaram": "enroxar",
    "enroxaras": "enroxar",
    "enroxarde": "enroxar",
    "enroxardes": "enroxar",
    "enroxare": "enroxar",
    "enroxarei": "enroxar",
    "enroxareis": "enroxar",
    "enroxarem": "enroxar",
    "enroxaremos": "enroxar",
    "enroxares": "enroxar",
    "enroxaria": "enroxar",
    "enroxariam": "enroxar",
    "enroxarias": "enroxar",
    "enroxarmo": "enroxar",
    "enroxarmos": "enroxar",
    "enroxará": "enroxar",
    "enroxarás": "enroxar",
    "enroxarão": "enroxar",
    "enroxaríamos": "enroxar",
    "enroxaríeis": "enroxar",
    "enroxas": "enroxar",
    "enroxasse": "enroxar",
    "enroxassem": "enroxar",
    "enroxasses": "enroxar",
    "enroxaste": "enroxar",
    "enroxastes": "enroxar",
    "enroxava": "enroxar",
    "enroxavam": "enroxar",
    "enroxavas": "enroxar",
    "enroxe": "enroxar",
    "enroxei": "enroxar",
    "enroxeis": "enroxar",
    "enroxem": "enroxar",
    "enroxemo": "enroxar",
    "enroxemos": "enroxar",
    "enroxes": "enroxar",
    "enroxo": "enroxar",
    "enroxou": "enroxar",
    "enroxá": "enroxar",
    "enroxámo": "enroxar",
    "enroxámos": "enroxar",
    "enroxáramo": "enroxar",
    "enroxáramos": "enroxar",
    "enroxárei": "enroxar",
    "enroxáreis": "enroxar",
    "enroxásseis": "enroxar",
    "enroxássemos": "enroxar",
    "enroxávamo": "enroxar",
    "enroxávamos": "enroxar",
    "enroxávei": "enroxar",
    "enroxáveis": "enroxar",
    "enrubesce": "enrubescer",
    "enrubescei": "enrubescer",
    "enrubesceis": "enrubescer",
    "enrubescem": "enrubescer",
    "enrubescemo": "enrubescer",
    "enrubescemos": "enrubescer",
    "enrubescendo": "enrubescer",
    "enrubescera": "enrubescer",
    "enrubesceram": "enrubescer",
    "enrubesceras": "enrubescer",
    "enrubescerde": "enrubescer",
    "enrubescerdes": "enrubescer",
    "enrubescere": "enrubescer",
    "enrubescerei": "enrubescer",
    "enrubescereis": "enrubescer",
    "enrubescerem": "enrubescer",
    "enrubesceremos": "enrubescer",
    "enrubesceres": "enrubescer",
    "enrubesceria": "enrubescer",
    "enrubesceriam": "enrubescer",
    "enrubescerias": "enrubescer",
    "enrubescermo": "enrubescer",
    "enrubescermos": "enrubescer",
    "enrubescerá": "enrubescer",
    "enrubescerás": "enrubescer",
    "enrubescerão": "enrubescer",
    "enrubesceríamos": "enrubescer",
    "enrubesceríeis": "enrubescer",
    "enrubesces": "enrubescer",
    "enrubescesse": "enrubescer",
    "enrubescessem": "enrubescer",
    "enrubescesses": "enrubescer",
    "enrubesceste": "enrubescer",
    "enrubescestes": "enrubescer",
    "enrubesceu": "enrubescer",
    "enrubesci": "enrubescer",
    "enrubescia": "enrubescer",
    "enrubesciam": "enrubescer",
    "enrubescias": "enrubescer",
    "enrubescida": "enrubescido",
    "enrubescidas": "enrubescido",
    "enrubescido": "enrubescer",
    "enrubescidos": "enrubescido",
    "enrubescimentos": "enrubescimento",
    "enrubescê": "enrubescer",
    "enrubescêramo": "enrubescer",
    "enrubescêramos": "enrubescer",
    "enrubescêrei": "enrubescer",
    "enrubescêreis": "enrubescer",
    "enrubescêsseis": "enrubescer",
    "enrubescêssemos": "enrubescer",
    "enrubescíamo": "enrubescer",
    "enrubescíamos": "enrubescer",
    "enrubescíei": "enrubescer",
    "enrubescíeis": "enrubescer",
    "enrubesça": "enrubescer",
    "enrubesçais": "enrubescer",
    "enrubesçam": "enrubescer",
    "enrubesçamo": "enrubescer",
    "enrubesçamos": "enrubescer",
    "enrubesças": "enrubescer",
    "enrubesço": "enrubescer",
    "enruce": "enruçar",
    "enrucei": "enruçar",
    "enruceis": "enruçar",
    "enrucem": "enruçar",
    "enrucemo": "enruçar",
    "enrucemos": "enruçar",
    "enruces": "enruçar",
    "enrudece": "enrudecer",
    "enrudecei": "enrudecer",
    "enrudeceis": "enrudecer",
    "enrudecem": "enrudecer",
    "enrudecemo": "enrudecer",
    "enrudecemos": "enrudecer",
    "enrudecendo": "enrudecer",
    "enrudecera": "enrudecer",
    "enrudeceram": "enrudecer",
    "enrudeceras": "enrudecer",
    "enrudecerdes": "enrudecer",
    "enrudecerei": "enrudecer",
    "enrudecereis": "enrudecer",
    "enrudecerem": "enrudecer",
    "enrudeceremos": "enrudecer",
    "enrudeceres": "enrudecer",
    "enrudeceria": "enrudecer",
    "enrudeceriam": "enrudecer",
    "enrudecerias": "enrudecer",
    "enrudecermo": "enrudecer",
    "enrudecermos": "enrudecer",
    "enrudecerá": "enrudecer",
    "enrudecerás": "enrudecer",
    "enrudecerão": "enrudecer",
    "enrudeceríamos": "enrudecer",
    "enrudeceríeis": "enrudecer",
    "enrudeces": "enrudecer",
    "enrudecesse": "enrudecer",
    "enrudecessem": "enrudecer",
    "enrudecesses": "enrudecer",
    "enrudeceste": "enrudecer",
    "enrudecestes": "enrudecer",
    "enrudeceu": "enrudecer",
    "enrudeci": "enrudecer",
    "enrudecia": "enrudecer",
    "enrudeciam": "enrudecer",
    "enrudecias": "enrudecer",
    "enrudecida": "enrudecido",
    "enrudecidas": "enrudecido",
    "enrudecido": "enrudecer",
    "enrudecidos": "enrudecido",
    "enrudecêramo": "enrudecer",
    "enrudecêramos": "enrudecer",
    "enrudecêreis": "enrudecer",
    "enrudecêsseis": "enrudecer",
    "enrudecêssemos": "enrudecer",
    "enrudecíamo": "enrudecer",
    "enrudecíamos": "enrudecer",
    "enrudecíeis": "enrudecer",
    "enrudeça": "enrudecer",
    "enrudeçais": "enrudecer",
    "enrudeçam": "enrudecer",
    "enrudeçamo": "enrudecer",
    "enrudeçamos": "enrudecer",
    "enrudeças": "enrudecer",
    "enrudeço": "enrudecer",
    "enrufa": "enrufar",
    "enrufada": "enrufar",
    "enrufadas": "enrufar",
    "enrufado": "enrufar",
    "enrufados": "enrufar",
    "enrufai": "enrufar",
    "enrufais": "enrufar",
    "enrufam": "enrufar",
    "enrufamo": "enrufar",
    "enrufamos": "enrufar",
    "enrufando": "enrufar",
    "enrufara": "enrufar",
    "enrufaram": "enrufar",
    "enrufaras": "enrufar",
    "enrufarde": "enrufar",
    "enrufardes": "enrufar",
    "enrufare": "enrufar",
    "enrufarei": "enrufar",
    "enrufareis": "enrufar",
    "enrufarem": "enrufar",
    "enrufaremos": "enrufar",
    "enrufares": "enrufar",
    "enrufaria": "enrufar",
    "enrufariam": "enrufar",
    "enrufarias": "enrufar",
    "enrufarmo": "enrufar",
    "enrufarmos": "enrufar",
    "enrufará": "enrufar",
    "enrufarás": "enrufar",
    "enrufarão": "enrufar",
    "enrufaríamos": "enrufar",
    "enrufaríeis": "enrufar",
    "enrufas": "enrufar",
    "enrufasse": "enrufar",
    "enrufassem": "enrufar",
    "enrufasses": "enrufar",
    "enrufaste": "enrufar",
    "enrufastes": "enrufar",
    "enrufava": "enrufar",
    "enrufavam": "enrufar",
    "enrufavas": "enrufar",
    "enrufe": "enrufar",
    "enrufei": "enrufar",
    "enrufeis": "enrufar",
    "enrufem": "enrufar",
    "enrufemo": "enrufar",
    "enrufemos": "enrufar",
    "enrufes": "enrufar",
    "enrufo": "enrufar",
    "enrufou": "enrufar",
    "enrufá": "enrufar",
    "enrufámo": "enrufar",
    "enrufámos": "enrufar",
    "enrufáramo": "enrufar",
    "enrufáramos": "enrufar",
    "enrufárei": "enrufar",
    "enrufáreis": "enrufar",
    "enrufásseis": "enrufar",
    "enrufássemos": "enrufar",
    "enrufávamo": "enrufar",
    "enrufávamos": "enrufar",
    "enrufávei": "enrufar",
    "enrufáveis": "enrufar",
    "enruga": "enrugar",
    "enrugada": "enrugar",
    "enrugadas": "enrugar",
    "enrugado": "enrugar",
    "enrugados": "enrugar",
    "enrugadíssima": "enrugado",
    "enrugadíssimas": "enrugado",
    "enrugadíssimo": "enrugado",
    "enrugadíssimos": "enrugado",
    "enrugai": "enrugar",
    "enrugais": "enrugar",
    "enrugam": "enrugar",
    "enrugamentos": "enrugamento",
    "enrugamo": "enrugar",
    "enrugamos": "enrugar",
    "enrugando": "enrugar",
    "enrugara": "enrugar",
    "enrugaram": "enrugar",
    "enrugaras": "enrugar",
    "enrugarde": "enrugar",
    "enrugardes": "enrugar",
    "enrugare": "enrugar",
    "enrugarei": "enrugar",
    "enrugareis": "enrugar",
    "enrugarem": "enrugar",
    "enrugaremos": "enrugar",
    "enrugares": "enrugar",
    "enrugaria": "enrugar",
    "enrugariam": "enrugar",
    "enrugarias": "enrugar",
    "enrugarmo": "enrugar",
    "enrugarmos": "enrugar",
    "enrugará": "enrugar",
    "enrugarás": "enrugar",
    "enrugarão": "enrugar",
    "enrugaríamos": "enrugar",
    "enrugaríeis": "enrugar",
    "enrugas": "enrugar",
    "enrugasse": "enrugar",
    "enrugassem": "enrugar",
    "enrugasses": "enrugar",
    "enrugaste": "enrugar",
    "enrugastes": "enrugar",
    "enrugava": "enrugar",
    "enrugavam": "enrugar",
    "enrugavas": "enrugar",
    "enrugações": "enrugação",
    "enrugo": "enrugar",
    "enrugou": "enrugar",
    "enrugue": "enrugar",
    "enruguei": "enrugar",
    "enrugueis": "enrugar",
    "enruguem": "enrugar",
    "enruguemo": "enrugar",
    "enruguemos": "enrugar",
    "enrugues": "enrugar",
    "enrugá": "enrugar",
    "enrugámo": "enrugar",
    "enrugámos": "enrugar",
    "enrugáramo": "enrugar",
    "enrugáramos": "enrugar",
    "enrugárei": "enrugar",
    "enrugáreis": "enrugar",
    "enrugásseis": "enrugar",
    "enrugássemos": "enrugar",
    "enrugávamo": "enrugar",
    "enrugávamos": "enrugar",
    "enrugávei": "enrugar",
    "enrugáveis": "enrugar",
    "enrumina": "enruminar",
    "enruminada": "enruminar",
    "enruminadas": "enruminar",
    "enruminado": "enruminar",
    "enruminados": "enruminar",
    "enruminai": "enruminar",
    "enruminais": "enruminar",
    "enruminam": "enruminar",
    "enruminamo": "enruminar",
    "enruminamos": "enruminar",
    "enruminando": "enruminar",
    "enruminara": "enruminar",
    "enruminaram": "enruminar",
    "enruminaras": "enruminar",
    "enruminarde": "enruminar",
    "enruminardes": "enruminar",
    "enruminare": "enruminar",
    "enruminarei": "enruminar",
    "enruminareis": "enruminar",
    "enruminarem": "enruminar",
    "enruminaremos": "enruminar",
    "enruminares": "enruminar",
    "enruminaria": "enruminar",
    "enruminariam": "enruminar",
    "enruminarias": "enruminar",
    "enruminarmo": "enruminar",
    "enruminarmos": "enruminar",
    "enruminará": "enruminar",
    "enruminarás": "enruminar",
    "enruminarão": "enruminar",
    "enruminaríamos": "enruminar",
    "enruminaríeis": "enruminar",
    "enruminas": "enruminar",
    "enruminasse": "enruminar",
    "enruminassem": "enruminar",
    "enruminasses": "enruminar",
    "enruminaste": "enruminar",
    "enruminastes": "enruminar",
    "enruminava": "enruminar",
    "enruminavam": "enruminar",
    "enruminavas": "enruminar",
    "enrumine": "enruminar",
    "enruminei": "enruminar",
    "enrumineis": "enruminar",
    "enruminem": "enruminar",
    "enruminemo": "enruminar",
    "enruminemos": "enruminar",
    "enrumines": "enruminar",
    "enrumino": "enruminar",
    "enruminou": "enruminar",
    "enruminá": "enruminar",
    "enruminámo": "enruminar",
    "enruminámos": "enruminar",
    "enrumináramo": "enruminar",
    "enrumináramos": "enruminar",
    "enruminárei": "enruminar",
    "enrumináreis": "enruminar",
    "enruminásseis": "enruminar",
    "enruminássemos": "enruminar",
    "enruminávamo": "enruminar",
    "enruminávamos": "enruminar",
    "enruminávei": "enruminar",
    "enrumináveis": "enruminar",
    "enruça": "enruçar",
    "enruçada": "enruçar",
    "enruçadas": "enruçar",
    "enruçado": "enruçar",
    "enruçados": "enruçar",
    "enruçai": "enruçar",
    "enruçais": "enruçar",
    "enruçam": "enruçar",
    "enruçamo": "enruçar",
    "enruçamos": "enruçar",
    "enruçando": "enruçar",
    "enruçara": "enruçar",
    "enruçaram": "enruçar",
    "enruçaras": "enruçar",
    "enruçarde": "enruçar",
    "enruçardes": "enruçar",
    "enruçare": "enruçar",
    "enruçarei": "enruçar",
    "enruçareis": "enruçar",
    "enruçarem": "enruçar",
    "enruçaremos": "enruçar",
    "enruçares": "enruçar",
    "enruçaria": "enruçar",
    "enruçariam": "enruçar",
    "enruçarias": "enruçar",
    "enruçarmo": "enruçar",
    "enruçarmos": "enruçar",
    "enruçará": "enruçar",
    "enruçarás": "enruçar",
    "enruçarão": "enruçar",
    "enruçaríamos": "enruçar",
    "enruçaríeis": "enruçar",
    "enruças": "enruçar",
    "enruçasse": "enruçar",
    "enruçassem": "enruçar",
    "enruçasses": "enruçar",
    "enruçaste": "enruçar",
    "enruçastes": "enruçar",
    "enruçava": "enruçar",
    "enruçavam": "enruçar",
    "enruçavas": "enruçar",
    "enruço": "enruçar",
    "enruçou": "enruçar",
    "enruçá": "enruçar",
    "enruçámo": "enruçar",
    "enruçámos": "enruçar",
    "enruçáramo": "enruçar",
    "enruçáramos": "enruçar",
    "enruçárei": "enruçar",
    "enruçáreis": "enruçar",
    "enruçásseis": "enruçar",
    "enruçássemos": "enruçar",
    "enruçávamo": "enruçar",
    "enruçávamos": "enruçar",
    "enruçávei": "enruçar",
    "enruçáveis": "enruçar",
    "ensaboa": "ensaboar",
    "ensaboada": "ensaboar",
    "ensaboadas": "ensaboar",
    "ensaboadelas": "ensaboadela",
    "ensaboado": "ensaboar",
    "ensaboados": "ensaboar",
    "ensaboaduras": "ensaboadura",
    "ensaboai": "ensaboar",
    "ensaboais": "ensaboar",
    "ensaboam": "ensaboar",
    "ensaboamentos": "ensaboamento",
    "ensaboamo": "ensaboar",
    "ensaboamos": "ensaboar",
    "ensaboando": "ensaboar",
    "ensaboara": "ensaboar",
    "ensaboaram": "ensaboar",
    "ensaboaras": "ensaboar",
    "ensaboarde": "ensaboar",
    "ensaboardes": "ensaboar",
    "ensaboare": "ensaboar",
    "ensaboarei": "ensaboar",
    "ensaboareis": "ensaboar",
    "ensaboarem": "ensaboar",
    "ensaboaremos": "ensaboar",
    "ensaboares": "ensaboar",
    "ensaboaria": "ensaboar",
    "ensaboariam": "ensaboar",
    "ensaboarias": "ensaboar",
    "ensaboarmo": "ensaboar",
    "ensaboarmos": "ensaboar",
    "ensaboará": "ensaboar",
    "ensaboarás": "ensaboar",
    "ensaboarão": "ensaboar",
    "ensaboaríamos": "ensaboar",
    "ensaboaríeis": "ensaboar",
    "ensaboas": "ensaboar",
    "ensaboasse": "ensaboar",
    "ensaboassem": "ensaboar",
    "ensaboasses": "ensaboar",
    "ensaboaste": "ensaboar",
    "ensaboastes": "ensaboar",
    "ensaboava": "ensaboar",
    "ensaboavam": "ensaboar",
    "ensaboavas": "ensaboar",
    "ensaboe": "ensaboar",
    "ensaboei": "ensaboar",
    "ensaboeis": "ensaboar",
    "ensaboem": "ensaboar",
    "ensaboemo": "ensaboar",
    "ensaboemos": "ensaboar",
    "ensaboes": "ensaboar",
    "ensaboo": "ensaboar",
    "ensaboou": "ensaboar",
    "ensaboá": "ensaboar",
    "ensaboámo": "ensaboar",
    "ensaboámos": "ensaboar",
    "ensaboáramo": "ensaboar",
    "ensaboáramos": "ensaboar",
    "ensaboárei": "ensaboar",
    "ensaboáreis": "ensaboar",
    "ensaboásseis": "ensaboar",
    "ensaboássemos": "ensaboar",
    "ensaboávamo": "ensaboar",
    "ensaboávamos": "ensaboar",
    "ensaboávei": "ensaboar",
    "ensaboáveis": "ensaboar",
    "ensaburra": "ensaburrar",
    "ensaburrada": "ensaburrar",
    "ensaburradas": "ensaburrar",
    "ensaburrado": "ensaburrar",
    "ensaburrados": "ensaburrar",
    "ensaburrai": "ensaburrar",
    "ensaburrais": "ensaburrar",
    "ensaburram": "ensaburrar",
    "ensaburramo": "ensaburrar",
    "ensaburramos": "ensaburrar",
    "ensaburrando": "ensaburrar",
    "ensaburrara": "ensaburrar",
    "ensaburraram": "ensaburrar",
    "ensaburraras": "ensaburrar",
    "ensaburrarde": "ensaburrar",
    "ensaburrardes": "ensaburrar",
    "ensaburrare": "ensaburrar",
    "ensaburrarei": "ensaburrar",
    "ensaburrareis": "ensaburrar",
    "ensaburrarem": "ensaburrar",
    "ensaburraremos": "ensaburrar",
    "ensaburrares": "ensaburrar",
    "ensaburraria": "ensaburrar",
    "ensaburrariam": "ensaburrar",
    "ensaburrarias": "ensaburrar",
    "ensaburrarmo": "ensaburrar",
    "ensaburrarmos": "ensaburrar",
    "ensaburrará": "ensaburrar",
    "ensaburrarás": "ensaburrar",
    "ensaburrarão": "ensaburrar",
    "ensaburraríamos": "ensaburrar",
    "ensaburraríeis": "ensaburrar",
    "ensaburras": "ensaburrar",
    "ensaburrasse": "ensaburrar",
    "ensaburrassem": "ensaburrar",
    "ensaburrasses": "ensaburrar",
    "ensaburraste": "ensaburrar",
    "ensaburrastes": "ensaburrar",
    "ensaburrava": "ensaburrar",
    "ensaburravam": "ensaburrar",
    "ensaburravas": "ensaburrar",
    "ensaburre": "ensaburrar",
    "ensaburrei": "ensaburrar",
    "ensaburreis": "ensaburrar",
    "ensaburrem": "ensaburrar",
    "ensaburremo": "ensaburrar",
    "ensaburremos": "ensaburrar",
    "ensaburres": "ensaburrar",
    "ensaburro": "ensaburrar",
    "ensaburrou": "ensaburrar",
    "ensaburrá": "ensaburrar",
    "ensaburrámo": "ensaburrar",
    "ensaburrámos": "ensaburrar",
    "ensaburráramo": "ensaburrar",
    "ensaburráramos": "ensaburrar",
    "ensaburrárei": "ensaburrar",
    "ensaburráreis": "ensaburrar",
    "ensaburrásseis": "ensaburrar",
    "ensaburrássemos": "ensaburrar",
    "ensaburrávamo": "ensaburrar",
    "ensaburrávamos": "ensaburrar",
    "ensaburrávei": "ensaburrar",
    "ensaburráveis": "ensaburrar",
    "ensaca": "ensacar",
    "ensacada": "ensacar",
    "ensacadas": "ensacar",
    "ensacado": "ensacar",
    "ensacados": "ensacar",
    "ensacai": "ensacar",
    "ensacais": "ensacar",
    "ensacam": "ensacar",
    "ensacamentos": "ensacamento",
    "ensacamo": "ensacar",
    "ensacamos": "ensacar",
    "ensacando": "ensacar",
    "ensacara": "ensacar",
    "ensacaram": "ensacar",
    "ensacaras": "ensacar",
    "ensacarde": "ensacar",
    "ensacardes": "ensacar",
    "ensacare": "ensacar",
    "ensacarei": "ensacar",
    "ensacareis": "ensacar",
    "ensacarem": "ensacar",
    "ensacaremos": "ensacar",
    "ensacares": "ensacar",
    "ensacaria": "ensacar",
    "ensacariam": "ensacar",
    "ensacarias": "ensacar",
    "ensacarmo": "ensacar",
    "ensacarmos": "ensacar",
    "ensacará": "ensacar",
    "ensacarás": "ensacar",
    "ensacarão": "ensacar",
    "ensacaríamos": "ensacar",
    "ensacaríeis": "ensacar",
    "ensacas": "ensacar",
    "ensacasse": "ensacar",
    "ensacassem": "ensacar",
    "ensacasses": "ensacar",
    "ensacaste": "ensacar",
    "ensacastes": "ensacar",
    "ensacava": "ensacar",
    "ensacavam": "ensacar",
    "ensacavas": "ensacar",
    "ensaco": "ensacar",
    "ensacou": "ensacar",
    "ensacá": "ensacar",
    "ensacámo": "ensacar",
    "ensacámos": "ensacar",
    "ensacáramo": "ensacar",
    "ensacáramos": "ensacar",
    "ensacárei": "ensacar",
    "ensacáreis": "ensacar",
    "ensacásseis": "ensacar",
    "ensacássemos": "ensacar",
    "ensacávamo": "ensacar",
    "ensacávamos": "ensacar",
    "ensacávei": "ensacar",
    "ensacáveis": "ensacar",
    "ensaia": "ensaiar",
    "ensaiada": "ensaiar",
    "ensaiadas": "ensaiar",
    "ensaiado": "ensaiar",
    "ensaiadora": "ensaiador",
    "ensaiadoras": "ensaiador",
    "ensaiadores": "ensaiador",
    "ensaiados": "ensaiar",
    "ensaiai": "ensaiar",
    "ensaiais": "ensaiar",
    "ensaiam": "ensaiar",
    "ensaiamentos": "ensaiamento",
    "ensaiamo": "ensaiar",
    "ensaiamos": "ensaiar",
    "ensaiando": "ensaiar",
    "ensaiara": "ensaiar",
    "ensaiaram": "ensaiar",
    "ensaiaras": "ensaiar",
    "ensaiarde": "ensaiar",
    "ensaiardes": "ensaiar",
    "ensaiare": "ensaiar",
    "ensaiarei": "ensaiar",
    "ensaiareis": "ensaiar",
    "ensaiarem": "ensaiar",
    "ensaiaremos": "ensaiar",
    "ensaiares": "ensaiar",
    "ensaiaria": "ensaiar",
    "ensaiariam": "ensaiar",
    "ensaiarias": "ensaiar",
    "ensaiarmo": "ensaiar",
    "ensaiarmos": "ensaiar",
    "ensaiará": "ensaiar",
    "ensaiarás": "ensaiar",
    "ensaiarão": "ensaiar",
    "ensaiaríamos": "ensaiar",
    "ensaiaríeis": "ensaiar",
    "ensaias": "ensaiar",
    "ensaiasse": "ensaiar",
    "ensaiassem": "ensaiar",
    "ensaiasses": "ensaiar",
    "ensaiaste": "ensaiar",
    "ensaiastes": "ensaiar",
    "ensaiava": "ensaiar",
    "ensaiavam": "ensaiar",
    "ensaiavas": "ensaiar",
    "ensaibra": "ensaibrar",
    "ensaibrada": "ensaibrar",
    "ensaibradas": "ensaibrar",
    "ensaibrado": "ensaibrar",
    "ensaibrados": "ensaibrar",
    "ensaibrai": "ensaibrar",
    "ensaibrais": "ensaibrar",
    "ensaibram": "ensaibrar",
    "ensaibramentos": "ensaibramento",
    "ensaibramo": "ensaibrar",
    "ensaibramos": "ensaibrar",
    "ensaibrando": "ensaibrar",
    "ensaibrara": "ensaibrar",
    "ensaibraram": "ensaibrar",
    "ensaibraras": "ensaibrar",
    "ensaibrarde": "ensaibrar",
    "ensaibrardes": "ensaibrar",
    "ensaibrare": "ensaibrar",
    "ensaibrarei": "ensaibrar",
    "ensaibrareis": "ensaibrar",
    "ensaibrarem": "ensaibrar",
    "ensaibraremos": "ensaibrar",
    "ensaibrares": "ensaibrar",
    "ensaibraria": "ensaibrar",
    "ensaibrariam": "ensaibrar",
    "ensaibrarias": "ensaibrar",
    "ensaibrarmo": "ensaibrar",
    "ensaibrarmos": "ensaibrar",
    "ensaibrará": "ensaibrar",
    "ensaibrarás": "ensaibrar",
    "ensaibrarão": "ensaibrar",
    "ensaibraríamos": "ensaibrar",
    "ensaibraríeis": "ensaibrar",
    "ensaibras": "ensaibrar",
    "ensaibrasse": "ensaibrar",
    "ensaibrassem": "ensaibrar",
    "ensaibrasses": "ensaibrar",
    "ensaibraste": "ensaibrar",
    "ensaibrastes": "ensaibrar",
    "ensaibrava": "ensaibrar",
    "ensaibravam": "ensaibrar",
    "ensaibravas": "ensaibrar",
    "ensaibre": "ensaibrar",
    "ensaibrei": "ensaibrar",
    "ensaibreis": "ensaibrar",
    "ensaibrem": "ensaibrar",
    "ensaibremo": "ensaibrar",
    "ensaibremos": "ensaibrar",
    "ensaibres": "ensaibrar",
    "ensaibro": "ensaibrar",
    "ensaibrou": "ensaibrar",
    "ensaibrá": "ensaibrar",
    "ensaibrámo": "ensaibrar",
    "ensaibrámos": "ensaibrar",
    "ensaibráramo": "ensaibrar",
    "ensaibráramos": "ensaibrar",
    "ensaibrárei": "ensaibrar",
    "ensaibráreis": "ensaibrar",
    "ensaibrásseis": "ensaibrar",
    "ensaibrássemos": "ensaibrar",
    "ensaibrávamo": "ensaibrar",
    "ensaibrávamos": "ensaibrar",
    "ensaibrávei": "ensaibrar",
    "ensaibráveis": "ensaibrar",
    "ensaie": "ensaiar",
    "ensaiei": "ensaiar",
    "ensaieis": "ensaiar",
    "ensaiem": "ensaiar",
    "ensaiemo": "ensaiar",
    "ensaiemos": "ensaiar",
    "ensaies": "ensaiar",
    "ensaio": "ensaiar",
    "ensaios": "ensaio",
    "ensaiou": "ensaiar",
    "ensaiá": "ensaiar",
    "ensaiámo": "ensaiar",
    "ensaiámos": "ensaiar",
    "ensaiáramo": "ensaiar",
    "ensaiáramos": "ensaiar",
    "ensaiárei": "ensaiar",
    "ensaiáreis": "ensaiar",
    "ensaiásseis": "ensaiar",
    "ensaiássemos": "ensaiar",
    "ensaiávamo": "ensaiar",
    "ensaiávamos": "ensaiar",
    "ensaiávei": "ensaiar",
    "ensaiáveis": "ensaiável",
    "ensaladas": "ensalada",
    "ensalma": "ensalmar",
    "ensalmada": "ensalmar",
    "ensalmadas": "ensalmar",
    "ensalmado": "ensalmar",
    "ensalmadora": "ensalmador",
    "ensalmadoras": "ensalmador",
    "ensalmadores": "ensalmador",
    "ensalmados": "ensalmar",
    "ensalmai": "ensalmar",
    "ensalmais": "ensalmar",
    "ensalmam": "ensalmar",
    "ensalmamo": "ensalmar",
    "ensalmamos": "ensalmar",
    "ensalmando": "ensalmar",
    "ensalmara": "ensalmar",
    "ensalmaram": "ensalmar",
    "ensalmaras": "ensalmar",
    "ensalmardes": "ensalmar",
    "ensalmarei": "ensalmar",
    "ensalmareis": "ensalmar",
    "ensalmarem": "ensalmar",
    "ensalmaremos": "ensalmar",
    "ensalmares": "ensalmar",
    "ensalmaria": "ensalmar",
    "ensalmariam": "ensalmar",
    "ensalmarias": "ensalmar",
    "ensalmarmo": "ensalmar",
    "ensalmarmos": "ensalmar",
    "ensalmará": "ensalmar",
    "ensalmarás": "ensalmar",
    "ensalmarão": "ensalmar",
    "ensalmaríamos": "ensalmar",
    "ensalmaríeis": "ensalmar",
    "ensalmas": "ensalmar",
    "ensalmasse": "ensalmar",
    "ensalmassem": "ensalmar",
    "ensalmasses": "ensalmar",
    "ensalmaste": "ensalmar",
    "ensalmastes": "ensalmar",
    "ensalmava": "ensalmar",
    "ensalmavam": "ensalmar",
    "ensalmavas": "ensalmar",
    "ensalme": "ensalmar",
    "ensalmei": "ensalmar",
    "ensalmeira": "ensalmeiro",
    "ensalmeiras": "ensalmeiro",
    "ensalmeiros": "ensalmeiro",
    "ensalmeis": "ensalmar",
    "ensalmem": "ensalmar",
    "ensalmemo": "ensalmar",
    "ensalmemos": "ensalmar",
    "ensalmes": "ensalmar",
    "ensalmo": "ensalmar",
    "ensalmoira": "ensalmoirar",
    "ensalmoirada": "ensalmoirar",
    "ensalmoiradas": "ensalmoirar",
    "ensalmoirado": "ensalmoirar",
    "ensalmoirados": "ensalmoirar",
    "ensalmoirai": "ensalmoirar",
    "ensalmoirais": "ensalmoirar",
    "ensalmoiram": "ensalmoirar",
    "ensalmoiramo": "ensalmoirar",
    "ensalmoiramos": "ensalmoirar",
    "ensalmoirando": "ensalmoirar",
    "ensalmoirara": "ensalmoirar",
    "ensalmoiraram": "ensalmoirar",
    "ensalmoiraras": "ensalmoirar",
    "ensalmoirarde": "ensalmoirar",
    "ensalmoirardes": "ensalmoirar",
    "ensalmoirare": "ensalmoirar",
    "ensalmoirarei": "ensalmoirar",
    "ensalmoirareis": "ensalmoirar",
    "ensalmoirarem": "ensalmoirar",
    "ensalmoiraremos": "ensalmoirar",
    "ensalmoirares": "ensalmoirar",
    "ensalmoiraria": "ensalmoirar",
    "ensalmoirariam": "ensalmoirar",
    "ensalmoirarias": "ensalmoirar",
    "ensalmoirarmo": "ensalmoirar",
    "ensalmoirarmos": "ensalmoirar",
    "ensalmoirará": "ensalmoirar",
    "ensalmoirarás": "ensalmoirar",
    "ensalmoirarão": "ensalmoirar",
    "ensalmoiraríamos": "ensalmoirar",
    "ensalmoiraríeis": "ensalmoirar",
    "ensalmoiras": "ensalmoirar",
    "ensalmoirasse": "ensalmoirar",
    "ensalmoirassem": "ensalmoirar",
    "ensalmoirasses": "ensalmoirar",
    "ensalmoiraste": "ensalmoirar",
    "ensalmoirastes": "ensalmoirar",
    "ensalmoirava": "ensalmoirar",
    "ensalmoiravam": "ensalmoirar",
    "ensalmoiravas": "ensalmoirar",
    "ensalmoire": "ensalmoirar",
    "ensalmoirei": "ensalmoirar",
    "ensalmoireis": "ensalmoirar",
    "ensalmoirem": "ensalmoirar",
    "ensalmoiremo": "ensalmoirar",
    "ensalmoiremos": "ensalmoirar",
    "ensalmoires": "ensalmoirar",
    "ensalmoiro": "ensalmoirar",
    "ensalmoirou": "ensalmoirar",
    "ensalmoirá": "ensalmoirar",
    "ensalmoirámo": "ensalmoirar",
    "ensalmoirámos": "ensalmoirar",
    "ensalmoiráramo": "ensalmoirar",
    "ensalmoiráramos": "ensalmoirar",
    "ensalmoirárei": "ensalmoirar",
    "ensalmoiráreis": "ensalmoirar",
    "ensalmoirásseis": "ensalmoirar",
    "ensalmoirássemos": "ensalmoirar",
    "ensalmoirávamo": "ensalmoirar",
    "ensalmoirávamos": "ensalmoirar",
    "ensalmoirávei": "ensalmoirar",
    "ensalmoiráveis": "ensalmoirar",
    "ensalmos": "ensalmo",
    "ensalmou": "ensalmar",
    "ensalmoura": "ensalmourar",
    "ensalmourada": "ensalmourar",
    "ensalmouradas": "ensalmourar",
    "ensalmourado": "ensalmourar",
    "ensalmourados": "ensalmourar",
    "ensalmourai": "ensalmourar",
    "ensalmourais": "ensalmourar",
    "ensalmouram": "ensalmourar",
    "ensalmouramo": "ensalmourar",
    "ensalmouramos": "ensalmourar",
    "ensalmourando": "ensalmourar",
    "ensalmourara": "ensalmourar",
    "ensalmouraram": "ensalmourar",
    "ensalmouraras": "ensalmourar",
    "ensalmourarde": "ensalmourar",
    "ensalmourardes": "ensalmourar",
    "ensalmourare": "ensalmourar",
    "ensalmourarei": "ensalmourar",
    "ensalmourareis": "ensalmourar",
    "ensalmourarem": "ensalmourar",
    "ensalmouraremos": "ensalmourar",
    "ensalmourares": "ensalmourar",
    "ensalmouraria": "ensalmourar",
    "ensalmourariam": "ensalmourar",
    "ensalmourarias": "ensalmourar",
    "ensalmourarmo": "ensalmourar",
    "ensalmourarmos": "ensalmourar",
    "ensalmourará": "ensalmourar",
    "ensalmourarás": "ensalmourar",
    "ensalmourarão": "ensalmourar",
    "ensalmouraríamos": "ensalmourar",
    "ensalmouraríeis": "ensalmourar",
    "ensalmouras": "ensalmourar",
    "ensalmourasse": "ensalmourar",
    "ensalmourassem": "ensalmourar",
    "ensalmourasses": "ensalmourar",
    "ensalmouraste": "ensalmourar",
    "ensalmourastes": "ensalmourar",
    "ensalmourava": "ensalmourar",
    "ensalmouravam": "ensalmourar",
    "ensalmouravas": "ensalmourar",
    "ensalmoure": "ensalmourar",
    "ensalmourei": "ensalmourar",
    "ensalmoureis": "ensalmourar",
    "ensalmourem": "ensalmourar",
    "ensalmouremo": "ensalmourar",
    "ensalmouremos": "ensalmourar",
    "ensalmoures": "ensalmourar",
    "ensalmouro": "ensalmourar",
    "ensalmourou": "ensalmourar",
    "ensalmourá": "ensalmourar",
    "ensalmourámo": "ensalmourar",
    "ensalmourámos": "ensalmourar",
    "ensalmouráramo": "ensalmourar",
    "ensalmouráramos": "ensalmourar",
    "ensalmourárei": "ensalmourar",
    "ensalmouráreis": "ensalmourar",
    "ensalmourásseis": "ensalmourar",
    "ensalmourássemos": "ensalmourar",
    "ensalmourávamo": "ensalmourar",
    "ensalmourávamos": "ensalmourar",
    "ensalmourávei": "ensalmourar",
    "ensalmouráveis": "ensalmourar",
    "ensalmámo": "ensalmar",
    "ensalmámos": "ensalmar",
    "ensalmáramo": "ensalmar",
    "ensalmáramos": "ensalmar",
    "ensalmáreis": "ensalmar",
    "ensalmásseis": "ensalmar",
    "ensalmássemos": "ensalmar",
    "ensalmávamo": "ensalmar",
    "ensalmávamos": "ensalmar",
    "ensalmáveis": "ensalmar",
    "ensalsadas": "ensalsada",
    "ensamarra": "ensamarrar",
    "ensamarrada": "ensamarrar",
    "ensamarradas": "ensamarrar",
    "ensamarrado": "ensamarrar",
    "ensamarrados": "ensamarrar",
    "ensamarrai": "ensamarrar",
    "ensamarrais": "ensamarrar",
    "ensamarram": "ensamarrar",
    "ensamarramo": "ensamarrar",
    "ensamarramos": "ensamarrar",
    "ensamarrando": "ensamarrar",
    "ensamarrara": "ensamarrar",
    "ensamarraram": "ensamarrar",
    "ensamarraras": "ensamarrar",
    "ensamarrarde": "ensamarrar",
    "ensamarrardes": "ensamarrar",
    "ensamarrare": "ensamarrar",
    "ensamarrarei": "ensamarrar",
    "ensamarrareis": "ensamarrar",
    "ensamarrarem": "ensamarrar",
    "ensamarraremos": "ensamarrar",
    "ensamarrares": "ensamarrar",
    "ensamarraria": "ensamarrar",
    "ensamarrariam": "ensamarrar",
    "ensamarrarias": "ensamarrar",
    "ensamarrarmo": "ensamarrar",
    "ensamarrarmos": "ensamarrar",
    "ensamarrará": "ensamarrar",
    "ensamarrarás": "ensamarrar",
    "ensamarrarão": "ensamarrar",
    "ensamarraríamos": "ensamarrar",
    "ensamarraríeis": "ensamarrar",
    "ensamarras": "ensamarrar",
    "ensamarrasse": "ensamarrar",
    "ensamarrassem": "ensamarrar",
    "ensamarrasses": "ensamarrar",
    "ensamarraste": "ensamarrar",
    "ensamarrastes": "ensamarrar",
    "ensamarrava": "ensamarrar",
    "ensamarravam": "ensamarrar",
    "ensamarravas": "ensamarrar",
    "ensamarre": "ensamarrar",
    "ensamarrei": "ensamarrar",
    "ensamarreis": "ensamarrar",
    "ensamarrem": "ensamarrar",
    "ensamarremo": "ensamarrar",
    "ensamarremos": "ensamarrar",
    "ensamarres": "ensamarrar",
    "ensamarro": "ensamarrar",
    "ensamarrou": "ensamarrar",
    "ensamarrá": "ensamarrar",
    "ensamarrámo": "ensamarrar",
    "ensamarrámos": "ensamarrar",
    "ensamarráramo": "ensamarrar",
    "ensamarráramos": "ensamarrar",
    "ensamarrárei": "ensamarrar",
    "ensamarráreis": "ensamarrar",
    "ensamarrásseis": "ensamarrar",
    "ensamarrássemos": "ensamarrar",
    "ensamarrávamo": "ensamarrar",
    "ensamarrávamos": "ensamarrar",
    "ensamarrávei": "ensamarrar",
    "ensamarráveis": "ensamarrar",
    "ensambenita": "ensambenitar",
    "ensambenitada": "ensambenitar",
    "ensambenitadas": "ensambenitar",
    "ensambenitado": "ensambenitar",
    "ensambenitados": "ensambenitar",
    "ensambenitai": "ensambenitar",
    "ensambenitais": "ensambenitar",
    "ensambenitam": "ensambenitar",
    "ensambenitamo": "ensambenitar",
    "ensambenitamos": "ensambenitar",
    "ensambenitando": "ensambenitar",
    "ensambenitara": "ensambenitar",
    "ensambenitaram": "ensambenitar",
    "ensambenitaras": "ensambenitar",
    "ensambenitarde": "ensambenitar",
    "ensambenitardes": "ensambenitar",
    "ensambenitare": "ensambenitar",
    "ensambenitarei": "ensambenitar",
    "ensambenitareis": "ensambenitar",
    "ensambenitarem": "ensambenitar",
    "ensambenitaremos": "ensambenitar",
    "ensambenitares": "ensambenitar",
    "ensambenitaria": "ensambenitar",
    "ensambenitariam": "ensambenitar",
    "ensambenitarias": "ensambenitar",
    "ensambenitarmo": "ensambenitar",
    "ensambenitarmos": "ensambenitar",
    "ensambenitará": "ensambenitar",
    "ensambenitarás": "ensambenitar",
    "ensambenitarão": "ensambenitar",
    "ensambenitaríamos": "ensambenitar",
    "ensambenitaríeis": "ensambenitar",
    "ensambenitas": "ensambenitar",
    "ensambenitasse": "ensambenitar",
    "ensambenitassem": "ensambenitar",
    "ensambenitasses": "ensambenitar",
    "ensambenitaste": "ensambenitar",
    "ensambenitastes": "ensambenitar",
    "ensambenitava": "ensambenitar",
    "ensambenitavam": "ensambenitar",
    "ensambenitavas": "ensambenitar",
    "ensambenite": "ensambenitar",
    "ensambenitei": "ensambenitar",
    "ensambeniteis": "ensambenitar",
    "ensambenitem": "ensambenitar",
    "ensambenitemo": "ensambenitar",
    "ensambenitemos": "ensambenitar",
    "ensambenites": "ensambenitar",
    "ensambenito": "ensambenitar",
    "ensambenitou": "ensambenitar",
    "ensambenitá": "ensambenitar",
    "ensambenitámo": "ensambenitar",
    "ensambenitámos": "ensambenitar",
    "ensambenitáramo": "ensambenitar",
    "ensambenitáramos": "ensambenitar",
    "ensambenitárei": "ensambenitar",
    "ensambenitáreis": "ensambenitar",
    "ensambenitásseis": "ensambenitar",
    "ensambenitássemos": "ensambenitar",
    "ensambenitávamo": "ensambenitar",
    "ensambenitávamos": "ensambenitar",
    "ensambenitávei": "ensambenitar",
    "ensambenitáveis": "ensambenitar",
    "ensambla": "ensamblar",
    "ensamblada": "ensamblar",
    "ensambladas": "ensamblar",
    "ensamblado": "ensamblar",
    "ensambladora": "ensamblador",
    "ensambladoras": "ensamblador",
    "ensambladores": "ensamblador",
    "ensamblados": "ensamblar",
    "ensambladuras": "ensambladura",
    "ensamblai": "ensamblar",
    "ensamblais": "ensamblar",
    "ensamblam": "ensamblar",
    "ensamblamentos": "ensamblamento",
    "ensamblamo": "ensamblar",
    "ensamblamos": "ensamblar",
    "ensamblando": "ensamblar",
    "ensamblara": "ensamblar",
    "ensamblaram": "ensamblar",
    "ensamblaras": "ensamblar",
    "ensamblarde": "ensamblar",
    "ensamblardes": "ensamblar",
    "ensamblare": "ensamblar",
    "ensamblarei": "ensamblar",
    "ensamblareis": "ensamblar",
    "ensamblarem": "ensamblar",
    "ensamblaremos": "ensamblar",
    "ensamblares": "ensamblar",
    "ensamblaria": "ensamblar",
    "ensamblariam": "ensamblar",
    "ensamblarias": "ensamblar",
    "ensamblarmo": "ensamblar",
    "ensamblarmos": "ensamblar",
    "ensamblará": "ensamblar",
    "ensamblarás": "ensamblar",
    "ensamblarão": "ensamblar",
    "ensamblaríamos": "ensamblar",
    "ensamblaríeis": "ensamblar",
    "ensamblas": "ensamblar",
    "ensamblasse": "ensamblar",
    "ensamblassem": "ensamblar",
    "ensamblasses": "ensamblar",
    "ensamblaste": "ensamblar",
    "ensamblastes": "ensamblar",
    "ensamblava": "ensamblar",
    "ensamblavam": "ensamblar",
    "ensamblavas": "ensamblar",
    "ensamble": "ensamblar",
    "ensamblei": "ensamblar",
    "ensambleis": "ensamblar",
    "ensamblem": "ensamblar",
    "ensamblemo": "ensamblar",
    "ensamblemos": "ensamblar",
    "ensambles": "ensamblar",
    "ensamblo": "ensamblar",
    "ensamblou": "ensamblar",
    "ensamblá": "ensamblar",
    "ensamblámo": "ensamblar",
    "ensamblámos": "ensamblar",
    "ensambláramo": "ensamblar",
    "ensambláramos": "ensamblar",
    "ensamblárei": "ensamblar",
    "ensambláreis": "ensamblar",
    "ensamblásseis": "ensamblar",
    "ensamblássemos": "ensamblar",
    "ensamblávamo": "ensamblar",
    "ensamblávamos": "ensamblar",
    "ensamblávei": "ensamblar",
    "ensambláveis": "ensamblar",
    "ensancha": "ensanchar",
    "ensanchada": "ensanchar",
    "ensanchadas": "ensanchar",
    "ensanchado": "ensanchar",
    "ensanchados": "ensanchar",
    "ensanchai": "ensanchar",
    "ensanchais": "ensanchar",
    "ensancham": "ensanchar",
    "ensanchamo": "ensanchar",
    "ensanchamos": "ensanchar",
    "ensanchando": "ensanchar",
    "ensanchara": "ensanchar",
    "ensancharam": "ensanchar",
    "ensancharas": "ensanchar",
    "ensancharde": "ensanchar",
    "ensanchardes": "ensanchar",
    "ensanchare": "ensanchar",
    "ensancharei": "ensanchar",
    "ensanchareis": "ensanchar",
    "ensancharem": "ensanchar",
    "ensancharemos": "ensanchar",
    "ensanchares": "ensanchar",
    "ensancharia": "ensanchar",
    "ensanchariam": "ensanchar",
    "ensancharias": "ensanchar",
    "ensancharmo": "ensanchar",
    "ensancharmos": "ensanchar",
    "ensanchará": "ensanchar",
    "ensancharás": "ensanchar",
    "ensancharão": "ensanchar",
    "ensancharíamos": "ensanchar",
    "ensancharíeis": "ensanchar",
    "ensanchas": "ensanchar",
    "ensanchasse": "ensanchar",
    "ensanchassem": "ensanchar",
    "ensanchasses": "ensanchar",
    "ensanchaste": "ensanchar",
    "ensanchastes": "ensanchar",
    "ensanchava": "ensanchar",
    "ensanchavam": "ensanchar",
    "ensanchavas": "ensanchar",
    "ensanche": "ensanchar",
    "ensanchei": "ensanchar",
    "ensancheis": "ensanchar",
    "ensanchem": "ensanchar",
    "ensanchemo": "ensanchar",
    "ensanchemos": "ensanchar",
    "ensanches": "ensanchar",
    "ensancho": "ensanchar",
    "ensanchou": "ensanchar",
    "ensanchá": "ensanchar",
    "ensanchámo": "ensanchar",
    "ensanchámos": "ensanchar",
    "ensancháramo": "ensanchar",
    "ensancháramos": "ensanchar",
    "ensanchárei": "ensanchar",
    "ensancháreis": "ensanchar",
    "ensanchásseis": "ensanchar",
    "ensanchássemos": "ensanchar",
    "ensanchávamo": "ensanchar",
    "ensanchávamos": "ensanchar",
    "ensanchávei": "ensanchar",
    "ensancháveis": "ensanchar",
    "ensandala": "ensandalar",
    "ensandalada": "ensandalar",
    "ensandaladas": "ensandalar",
    "ensandalado": "ensandalar",
    "ensandalados": "ensandalar",
    "ensandalai": "ensandalar",
    "ensandalais": "ensandalar",
    "ensandalam": "ensandalar",
    "ensandalamo": "ensandalar",
    "ensandalamos": "ensandalar",
    "ensandalando": "ensandalar",
    "ensandalara": "ensandalar",
    "ensandalaram": "ensandalar",
    "ensandalaras": "ensandalar",
    "ensandalarde": "ensandalar",
    "ensandalardes": "ensandalar",
    "ensandalare": "ensandalar",
    "ensandalarei": "ensandalar",
    "ensandalareis": "ensandalar",
    "ensandalarem": "ensandalar",
    "ensandalaremos": "ensandalar",
    "ensandalares": "ensandalar",
    "ensandalaria": "ensandalar",
    "ensandalariam": "ensandalar",
    "ensandalarias": "ensandalar",
    "ensandalarmo": "ensandalar",
    "ensandalarmos": "ensandalar",
    "ensandalará": "ensandalar",
    "ensandalarás": "ensandalar",
    "ensandalarão": "ensandalar",
    "ensandalaríamos": "ensandalar",
    "ensandalaríeis": "ensandalar",
    "ensandalas": "ensandalar",
    "ensandalasse": "ensandalar",
    "ensandalassem": "ensandalar",
    "ensandalasses": "ensandalar",
    "ensandalaste": "ensandalar",
    "ensandalastes": "ensandalar",
    "ensandalava": "ensandalar",
    "ensandalavam": "ensandalar",
    "ensandalavas": "ensandalar",
    "ensandale": "ensandalar",
    "ensandalei": "ensandalar",
    "ensandaleis": "ensandalar",
    "ensandalem": "ensandalar",
    "ensandalemo": "ensandalar",
    "ensandalemos": "ensandalar",
    "ensandales": "ensandalar",
    "ensandalo": "ensandalar",
    "ensandalou": "ensandalar",
    "ensandalá": "ensandalar",
    "ensandalámo": "ensandalar",
    "ensandalámos": "ensandalar",
    "ensandaláramo": "ensandalar",
    "ensandaláramos": "ensandalar",
    "ensandalárei": "ensandalar",
    "ensandaláreis": "ensandalar",
    "ensandalásseis": "ensandalar",
    "ensandalássemos": "ensandalar",
    "ensandalávamo": "ensandalar",
    "ensandalávamos": "ensandalar",
    "ensandalávei": "ensandalar",
    "ensandaláveis": "ensandalar",
    "ensandece": "ensandecer",
    "ensandecei": "ensandecer",
    "ensandeceis": "ensandecer",
    "ensandecem": "ensandecer",
    "ensandecemo": "ensandecer",
    "ensandecemos": "ensandecer",
    "ensandecendo": "ensandecer",
    "ensandecera": "ensandecer",
    "ensandeceram": "ensandecer",
    "ensandeceras": "ensandecer",
    "ensandecerdes": "ensandecer",
    "ensandecerei": "ensandecer",
    "ensandecereis": "ensandecer",
    "ensandecerem": "ensandecer",
    "ensandeceremos": "ensandecer",
    "ensandeceres": "ensandecer",
    "ensandeceria": "ensandecer",
    "ensandeceriam": "ensandecer",
    "ensandecerias": "ensandecer",
    "ensandecermo": "ensandecer",
    "ensandecermos": "ensandecer",
    "ensandecerá": "ensandecer",
    "ensandecerás": "ensandecer",
    "ensandecerão": "ensandecer",
    "ensandeceríamos": "ensandecer",
    "ensandeceríeis": "ensandecer",
    "ensandeces": "ensandecer",
    "ensandecesse": "ensandecer",
    "ensandecessem": "ensandecer",
    "ensandecesses": "ensandecer",
    "ensandeceste": "ensandecer",
    "ensandecestes": "ensandecer",
    "ensandeceu": "ensandecer",
    "ensandeci": "ensandecer",
    "ensandecia": "ensandecer",
    "ensandeciam": "ensandecer",
    "ensandecias": "ensandecer",
    "ensandecida": "ensandecido",
    "ensandecidas": "ensandecido",
    "ensandecido": "ensandecer",
    "ensandecidos": "ensandecido",
    "ensandecêramo": "ensandecer",
    "ensandecêramos": "ensandecer",
    "ensandecêreis": "ensandecer",
    "ensandecêsseis": "ensandecer",
    "ensandecêssemos": "ensandecer",
    "ensandecíamo": "ensandecer",
    "ensandecíamos": "ensandecer",
    "ensandecíeis": "ensandecer",
    "ensandeça": "ensandecer",
    "ensandeçais": "ensandecer",
    "ensandeçam": "ensandecer",
    "ensandeçamo": "ensandecer",
    "ensandeçamos": "ensandecer",
    "ensandeças": "ensandecer",
    "ensandeço": "ensandecer",
    "ensanduicha": "ensanduichar",
    "ensanduichada": "ensanduichar",
    "ensanduichadas": "ensanduichar",
    "ensanduichado": "ensanduichar",
    "ensanduichados": "ensanduichar",
    "ensanduichai": "ensanduichar",
    "ensanduichais": "ensanduichar",
    "ensanduicham": "ensanduichar",
    "ensanduichamo": "ensanduichar",
    "ensanduichamos": "ensanduichar",
    "ensanduichando": "ensanduichar",
    "ensanduichara": "ensanduichar",
    "ensanduicharam": "ensanduichar",
    "ensanduicharas": "ensanduichar",
    "ensanduicharde": "ensanduichar",
    "ensanduichardes": "ensanduichar",
    "ensanduichare": "ensanduichar",
    "ensanduicharei": "ensanduichar",
    "ensanduichareis": "ensanduichar",
    "ensanduicharem": "ensanduichar",
    "ensanduicharemos": "ensanduichar",
    "ensanduichares": "ensanduichar",
    "ensanduicharia": "ensanduichar",
    "ensanduichariam": "ensanduichar",
    "ensanduicharias": "ensanduichar",
    "ensanduicharmo": "ensanduichar",
    "ensanduicharmos": "ensanduichar",
    "ensanduichará": "ensanduichar",
    "ensanduicharás": "ensanduichar",
    "ensanduicharão": "ensanduichar",
    "ensanduicharíamos": "ensanduichar",
    "ensanduicharíeis": "ensanduichar",
    "ensanduichas": "ensanduichar",
    "ensanduichasse": "ensanduichar",
    "ensanduichassem": "ensanduichar",
    "ensanduichasses": "ensanduichar",
    "ensanduichaste": "ensanduichar",
    "ensanduichastes": "ensanduichar",
    "ensanduichava": "ensanduichar",
    "ensanduichavam": "ensanduichar",
    "ensanduichavas": "ensanduichar",
    "ensanduiche": "ensanduichar",
    "ensanduichei": "ensanduichar",
    "ensanduicheis": "ensanduichar",
    "ensanduichem": "ensanduichar",
    "ensanduichemo": "ensanduichar",
    "ensanduichemos": "ensanduichar",
    "ensanduiches": "ensanduichar",
    "ensanduicho": "ensanduichar",
    "ensanduichou": "ensanduichar",
    "ensanduichá": "ensanduichar",
    "ensanduichámo": "ensanduichar",
    "ensanduichámos": "ensanduichar",
    "ensanduicháramo": "ensanduichar",
    "ensanduicháramos": "ensanduichar",
    "ensanduichárei": "ensanduichar",
    "ensanduicháreis": "ensanduichar",
    "ensanduichásseis": "ensanduichar",
    "ensanduichássemos": "ensanduichar",
    "ensanduichávamo": "ensanduichar",
    "ensanduichávamos": "ensanduichar",
    "ensanduichávei": "ensanduichar",
    "ensanduicháveis": "ensanduichar",
    "ensanefa": "ensanefar",
    "ensanefada": "ensanefar",
    "ensanefadas": "ensanefar",
    "ensanefado": "ensanefar",
    "ensanefados": "ensanefar",
    "ensanefai": "ensanefar",
    "ensanefais": "ensanefar",
    "ensanefam": "ensanefar",
    "ensanefamo": "ensanefar",
    "ensanefamos": "ensanefar",
    "ensanefando": "ensanefar",
    "ensanefara": "ensanefar",
    "ensanefaram": "ensanefar",
    "ensanefaras": "ensanefar",
    "ensanefarde": "ensanefar",
    "ensanefardes": "ensanefar",
    "ensanefare": "ensanefar",
    "ensanefarei": "ensanefar",
    "ensanefareis": "ensanefar",
    "ensanefarem": "ensanefar",
    "ensanefaremos": "ensanefar",
    "ensanefares": "ensanefar",
    "ensanefaria": "ensanefar",
    "ensanefariam": "ensanefar",
    "ensanefarias": "ensanefar",
    "ensanefarmo": "ensanefar",
    "ensanefarmos": "ensanefar",
    "ensanefará": "ensanefar",
    "ensanefarás": "ensanefar",
    "ensanefarão": "ensanefar",
    "ensanefaríamos": "ensanefar",
    "ensanefaríeis": "ensanefar",
    "ensanefas": "ensanefar",
    "ensanefasse": "ensanefar",
    "ensanefassem": "ensanefar",
    "ensanefasses": "ensanefar",
    "ensanefaste": "ensanefar",
    "ensanefastes": "ensanefar",
    "ensanefava": "ensanefar",
    "ensanefavam": "ensanefar",
    "ensanefavas": "ensanefar",
    "ensanefe": "ensanefar",
    "ensanefei": "ensanefar",
    "ensanefeis": "ensanefar",
    "ensanefem": "ensanefar",
    "ensanefemo": "ensanefar",
    "ensanefemos": "ensanefar",
    "ensanefes": "ensanefar",
    "ensanefo": "ensanefar",
    "ensanefou": "ensanefar",
    "ensanefá": "ensanefar",
    "ensanefámo": "ensanefar",
    "ensanefámos": "ensanefar",
    "ensanefáramo": "ensanefar",
    "ensanefáramos": "ensanefar",
    "ensanefárei": "ensanefar",
    "ensanefáreis": "ensanefar",
    "ensanefásseis": "ensanefar",
    "ensanefássemos": "ensanefar",
    "ensanefávamo": "ensanefar",
    "ensanefávamos": "ensanefar",
    "ensanefávei": "ensanefar",
    "ensanefáveis": "ensanefar",
    "ensanguenta": "ensanguentar",
    "ensanguentada": "ensanguentar",
    "ensanguentadas": "ensanguentar",
    "ensanguentado": "ensanguentar",
    "ensanguentados": "ensanguentar",
    "ensanguentai": "ensanguentar",
    "ensanguentais": "ensanguentar",
    "ensanguentam": "ensanguentar",
    "ensanguentamo": "ensanguentar",
    "ensanguentamos": "ensanguentar",
    "ensanguentando": "ensanguentar",
    "ensanguentara": "ensanguentar",
    "ensanguentaram": "ensanguentar",
    "ensanguentaras": "ensanguentar",
    "ensanguentarde": "ensanguentar",
    "ensanguentardes": "ensanguentar",
    "ensanguentare": "ensanguentar",
    "ensanguentarei": "ensanguentar",
    "ensanguentareis": "ensanguentar",
    "ensanguentarem": "ensanguentar",
    "ensanguentaremos": "ensanguentar",
    "ensanguentares": "ensanguentar",
    "ensanguentaria": "ensanguentar",
    "ensanguentariam": "ensanguentar",
    "ensanguentarias": "ensanguentar",
    "ensanguentarmo": "ensanguentar",
    "ensanguentarmos": "ensanguentar",
    "ensanguentará": "ensanguentar",
    "ensanguentarás": "ensanguentar",
    "ensanguentarão": "ensanguentar",
    "ensanguentaríamos": "ensanguentar",
    "ensanguentaríeis": "ensanguentar",
    "ensanguentas": "ensanguentar",
    "ensanguentasse": "ensanguentar",
    "ensanguentassem": "ensanguentar",
    "ensanguentasses": "ensanguentar",
    "ensanguentaste": "ensanguentar",
    "ensanguentastes": "ensanguentar",
    "ensanguentava": "ensanguentar",
    "ensanguentavam": "ensanguentar",
    "ensanguentavas": "ensanguentar",
    "ensanguente": "ensanguentar",
    "ensanguentei": "ensanguentar",
    "ensanguenteis": "ensanguentar",
    "ensanguentem": "ensanguentar",
    "ensanguentemo": "ensanguentar",
    "ensanguentemos": "ensanguentar",
    "ensanguentes": "ensanguentar",
    "ensanguento": "ensanguentar",
    "ensanguentou": "ensanguentar",
    "ensanguentá": "ensanguentar",
    "ensanguentámo": "ensanguentar",
    "ensanguentámos": "ensanguentar",
    "ensanguentáramo": "ensanguentar",
    "ensanguentáramos": "ensanguentar",
    "ensanguentárei": "ensanguentar",
    "ensanguentáreis": "ensanguentar",
    "ensanguentásseis": "ensanguentar",
    "ensanguentássemos": "ensanguentar",
    "ensanguentávamo": "ensanguentar",
    "ensanguentávamos": "ensanguentar",
    "ensanguentávei": "ensanguentar",
    "ensanguentáveis": "ensanguentar",
    "ensanguinha": "ensanguinhar",
    "ensanguinhada": "ensanguinhar",
    "ensanguinhadas": "ensanguinhar",
    "ensanguinhado": "ensanguinhar",
    "ensanguinhados": "ensanguinhar",
    "ensanguinhai": "ensanguinhar",
    "ensanguinhais": "ensanguinhar",
    "ensanguinham": "ensanguinhar",
    "ensanguinhamo": "ensanguinhar",
    "ensanguinhamos": "ensanguinhar",
    "ensanguinhando": "ensanguinhar",
    "ensanguinhara": "ensanguinhar",
    "ensanguinharam": "ensanguinhar",
    "ensanguinharas": "ensanguinhar",
    "ensanguinharde": "ensanguinhar",
    "ensanguinhardes": "ensanguinhar",
    "ensanguinhare": "ensanguinhar",
    "ensanguinharei": "ensanguinhar",
    "ensanguinhareis": "ensanguinhar",
    "ensanguinharem": "ensanguinhar",
    "ensanguinharemos": "ensanguinhar",
    "ensanguinhares": "ensanguinhar",
    "ensanguinharia": "ensanguinhar",
    "ensanguinhariam": "ensanguinhar",
    "ensanguinharias": "ensanguinhar",
    "ensanguinharmo": "ensanguinhar",
    "ensanguinharmos": "ensanguinhar",
    "ensanguinhará": "ensanguinhar",
    "ensanguinharás": "ensanguinhar",
    "ensanguinharão": "ensanguinhar",
    "ensanguinharíamos": "ensanguinhar",
    "ensanguinharíeis": "ensanguinhar",
    "ensanguinhas": "ensanguinhar",
    "ensanguinhasse": "ensanguinhar",
    "ensanguinhassem": "ensanguinhar",
    "ensanguinhasses": "ensanguinhar",
    "ensanguinhaste": "ensanguinhar",
    "ensanguinhastes": "ensanguinhar",
    "ensanguinhava": "ensanguinhar",
    "ensanguinhavam": "ensanguinhar",
    "ensanguinhavas": "ensanguinhar",
    "ensanguinhe": "ensanguinhar",
    "ensanguinhei": "ensanguinhar",
    "ensanguinheis": "ensanguinhar",
    "ensanguinhem": "ensanguinhar",
    "ensanguinhemo": "ensanguinhar",
    "ensanguinhemos": "ensanguinhar",
    "ensanguinhes": "ensanguinhar",
    "ensanguinho": "ensanguinhar",
    "ensanguinhou": "ensanguinhar",
    "ensanguinhá": "ensanguinhar",
    "ensanguinhámo": "ensanguinhar",
    "ensanguinhámos": "ensanguinhar",
    "ensanguinháramo": "ensanguinhar",
    "ensanguinháramos": "ensanguinhar",
    "ensanguinhárei": "ensanguinhar",
    "ensanguinháreis": "ensanguinhar",
    "ensanguinhásseis": "ensanguinhar",
    "ensanguinhássemos": "ensanguinhar",
    "ensanguinhávamo": "ensanguinhar",
    "ensanguinhávamos": "ensanguinhar",
    "ensanguinhávei": "ensanguinhar",
    "ensanguinháveis": "ensanguinhar",
    "ensaque": "ensacar",
    "ensaquei": "ensacar",
    "ensaqueis": "ensacar",
    "ensaquem": "ensacar",
    "ensaquemo": "ensacar",
    "ensaquemos": "ensacar",
    "ensaques": "ensaque",
    "ensardinha": "ensardinhar",
    "ensardinhada": "ensardinhar",
    "ensardinhadas": "ensardinhar",
    "ensardinhado": "ensardinhar",
    "ensardinhados": "ensardinhar",
    "ensardinhai": "ensardinhar",
    "ensardinhais": "ensardinhar",
    "ensardinham": "ensardinhar",
    "ensardinhamo": "ensardinhar",
    "ensardinhamos": "ensardinhar",
    "ensardinhando": "ensardinhar",
    "ensardinhara": "ensardinhar",
    "ensardinharam": "ensardinhar",
    "ensardinharas": "ensardinhar",
    "ensardinharde": "ensardinhar",
    "ensardinhardes": "ensardinhar",
    "ensardinhare": "ensardinhar",
    "ensardinharei": "ensardinhar",
    "ensardinhareis": "ensardinhar",
    "ensardinharem": "ensardinhar",
    "ensardinharemos": "ensardinhar",
    "ensardinhares": "ensardinhar",
    "ensardinharia": "ensardinhar",
    "ensardinhariam": "ensardinhar",
    "ensardinharias": "ensardinhar",
    "ensardinharmo": "ensardinhar",
    "ensardinharmos": "ensardinhar",
    "ensardinhará": "ensardinhar",
    "ensardinharás": "ensardinhar",
    "ensardinharão": "ensardinhar",
    "ensardinharíamos": "ensardinhar",
    "ensardinharíeis": "ensardinhar",
    "ensardinhas": "ensardinhar",
    "ensardinhasse": "ensardinhar",
    "ensardinhassem": "ensardinhar",
    "ensardinhasses": "ensardinhar",
    "ensardinhaste": "ensardinhar",
    "ensardinhastes": "ensardinhar",
    "ensardinhava": "ensardinhar",
    "ensardinhavam": "ensardinhar",
    "ensardinhavas": "ensardinhar",
    "ensardinhe": "ensardinhar",
    "ensardinhei": "ensardinhar",
    "ensardinheis": "ensardinhar",
    "ensardinhem": "ensardinhar",
    "ensardinhemo": "ensardinhar",
    "ensardinhemos": "ensardinhar",
    "ensardinhes": "ensardinhar",
    "ensardinho": "ensardinhar",
    "ensardinhou": "ensardinhar",
    "ensardinhá": "ensardinhar",
    "ensardinhámo": "ensardinhar",
    "ensardinhámos": "ensardinhar",
    "ensardinháramo": "ensardinhar",
    "ensardinháramos": "ensardinhar",
    "ensardinhárei": "ensardinhar",
    "ensardinháreis": "ensardinhar",
    "ensardinhásseis": "ensardinhar",
    "ensardinhássemos": "ensardinhar",
    "ensardinhávamo": "ensardinhar",
    "ensardinhávamos": "ensardinhar",
    "ensardinhávei": "ensardinhar",
    "ensardinháveis": "ensardinhar",
    "ensarilha": "ensarilhar",
    "ensarilhada": "ensarilhar",
    "ensarilhadas": "ensarilhar",
    "ensarilhado": "ensarilhar",
    "ensarilhados": "ensarilhar",
    "ensarilhai": "ensarilhar",
    "ensarilhais": "ensarilhar",
    "ensarilham": "ensarilhar",
    "ensarilhamo": "ensarilhar",
    "ensarilhamos": "ensarilhar",
    "ensarilhando": "ensarilhar",
    "ensarilhara": "ensarilhar",
    "ensarilharam": "ensarilhar",
    "ensarilharas": "ensarilhar",
    "ensarilharde": "ensarilhar",
    "ensarilhardes": "ensarilhar",
    "ensarilhare": "ensarilhar",
    "ensarilharei": "ensarilhar",
    "ensarilhareis": "ensarilhar",
    "ensarilharem": "ensarilhar",
    "ensarilharemos": "ensarilhar",
    "ensarilhares": "ensarilhar",
    "ensarilharia": "ensarilhar",
    "ensarilhariam": "ensarilhar",
    "ensarilharias": "ensarilhar",
    "ensarilharmo": "ensarilhar",
    "ensarilharmos": "ensarilhar",
    "ensarilhará": "ensarilhar",
    "ensarilharás": "ensarilhar",
    "ensarilharão": "ensarilhar",
    "ensarilharíamos": "ensarilhar",
    "ensarilharíeis": "ensarilhar",
    "ensarilhas": "ensarilhar",
    "ensarilhasse": "ensarilhar",
    "ensarilhassem": "ensarilhar",
    "ensarilhasses": "ensarilhar",
    "ensarilhaste": "ensarilhar",
    "ensarilhastes": "ensarilhar",
    "ensarilhava": "ensarilhar",
    "ensarilhavam": "ensarilhar",
    "ensarilhavas": "ensarilhar",
    "ensarilhe": "ensarilhar",
    "ensarilhei": "ensarilhar",
    "ensarilheis": "ensarilhar",
    "ensarilhem": "ensarilhar",
    "ensarilhemo": "ensarilhar",
    "ensarilhemos": "ensarilhar",
    "ensarilhes": "ensarilhar",
    "ensarilho": "ensarilhar",
    "ensarilhou": "ensarilhar",
    "ensarilhá": "ensarilhar",
    "ensarilhámo": "ensarilhar",
    "ensarilhámos": "ensarilhar",
    "ensarilháramo": "ensarilhar",
    "ensarilháramos": "ensarilhar",
    "ensarilhárei": "ensarilhar",
    "ensarilháreis": "ensarilhar",
    "ensarilhásseis": "ensarilhar",
    "ensarilhássemos": "ensarilhar",
    "ensarilhávamo": "ensarilhar",
    "ensarilhávamos": "ensarilhar",
    "ensarilhávei": "ensarilhar",
    "ensarilháveis": "ensarilhar",
    "ensarnece": "ensarnecer",
    "ensarnecei": "ensarnecer",
    "ensarneceis": "ensarnecer",
    "ensarnecem": "ensarnecer",
    "ensarnecemo": "ensarnecer",
    "ensarnecemos": "ensarnecer",
    "ensarnecendo": "ensarnecer",
    "ensarnecera": "ensarnecer",
    "ensarneceram": "ensarnecer",
    "ensarneceras": "ensarnecer",
    "ensarnecerdes": "ensarnecer",
    "ensarnecerei": "ensarnecer",
    "ensarnecereis": "ensarnecer",
    "ensarnecerem": "ensarnecer",
    "ensarneceremos": "ensarnecer",
    "ensarneceres": "ensarnecer",
    "ensarneceria": "ensarnecer",
    "ensarneceriam": "ensarnecer",
    "ensarnecerias": "ensarnecer",
    "ensarnecermo": "ensarnecer",
    "ensarnecermos": "ensarnecer",
    "ensarnecerá": "ensarnecer",
    "ensarnecerás": "ensarnecer",
    "ensarnecerão": "ensarnecer",
    "ensarneceríamos": "ensarnecer",
    "ensarneceríeis": "ensarnecer",
    "ensarneces": "ensarnecer",
    "ensarnecesse": "ensarnecer",
    "ensarnecessem": "ensarnecer",
    "ensarnecesses": "ensarnecer",
    "ensarneceste": "ensarnecer",
    "ensarnecestes": "ensarnecer",
    "ensarneceu": "ensarnecer",
    "ensarneci": "ensarnecer",
    "ensarnecia": "ensarnecer",
    "ensarneciam": "ensarnecer",
    "ensarnecias": "ensarnecer",
    "ensarnecida": "ensarnecer",
    "ensarnecidas": "ensarnecer",
    "ensarnecido": "ensarnecer",
    "ensarnecidos": "ensarnecer",
    "ensarnecêramo": "ensarnecer",
    "ensarnecêramos": "ensarnecer",
    "ensarnecêreis": "ensarnecer",
    "ensarnecêsseis": "ensarnecer",
    "ensarnecêssemos": "ensarnecer",
    "ensarnecíamo": "ensarnecer",
    "ensarnecíamos": "ensarnecer",
    "ensarnecíeis": "ensarnecer",
    "ensarneça": "ensarnecer",
    "ensarneçais": "ensarnecer",
    "ensarneçam": "ensarnecer",
    "ensarneçamo": "ensarnecer",
    "ensarneçamos": "ensarnecer",
    "ensarneças": "ensarnecer",
    "ensarneço": "ensarnecer",
    "ensarrafa": "ensarrafar",
    "ensarrafada": "ensarrafar",
    "ensarrafadas": "ensarrafar",
    "ensarrafado": "ensarrafar",
    "ensarrafados": "ensarrafar",
    "ensarrafai": "ensarrafar",
    "ensarrafais": "ensarrafar",
    "ensarrafam": "ensarrafar",
    "ensarrafamo": "ensarrafar",
    "ensarrafamos": "ensarrafar",
    "ensarrafando": "ensarrafar",
    "ensarrafara": "ensarrafar",
    "ensarrafaram": "ensarrafar",
    "ensarrafaras": "ensarrafar",
    "ensarrafarde": "ensarrafar",
    "ensarrafardes": "ensarrafar",
    "ensarrafare": "ensarrafar",
    "ensarrafarei": "ensarrafar",
    "ensarrafareis": "ensarrafar",
    "ensarrafarem": "ensarrafar",
    "ensarrafaremos": "ensarrafar",
    "ensarrafares": "ensarrafar",
    "ensarrafaria": "ensarrafar",
    "ensarrafariam": "ensarrafar",
    "ensarrafarias": "ensarrafar",
    "ensarrafarmo": "ensarrafar",
    "ensarrafarmos": "ensarrafar",
    "ensarrafará": "ensarrafar",
    "ensarrafarás": "ensarrafar",
    "ensarrafarão": "ensarrafar",
    "ensarrafaríamos": "ensarrafar",
    "ensarrafaríeis": "ensarrafar",
    "ensarrafas": "ensarrafar",
    "ensarrafasse": "ensarrafar",
    "ensarrafassem": "ensarrafar",
    "ensarrafasses": "ensarrafar",
    "ensarrafaste": "ensarrafar",
    "ensarrafastes": "ensarrafar",
    "ensarrafava": "ensarrafar",
    "ensarrafavam": "ensarrafar",
    "ensarrafavas": "ensarrafar",
    "ensarrafe": "ensarrafar",
    "ensarrafei": "ensarrafar",
    "ensarrafeis": "ensarrafar",
    "ensarrafem": "ensarrafar",
    "ensarrafemo": "ensarrafar",
    "ensarrafemos": "ensarrafar",
    "ensarrafes": "ensarrafar",
    "ensarrafo": "ensarrafar",
    "ensarrafou": "ensarrafar",
    "ensarrafá": "ensarrafar",
    "ensarrafámo": "ensarrafar",
    "ensarrafámos": "ensarrafar",
    "ensarrafáramo": "ensarrafar",
    "ensarrafáramos": "ensarrafar",
    "ensarrafárei": "ensarrafar",
    "ensarrafáreis": "ensarrafar",
    "ensarrafásseis": "ensarrafar",
    "ensarrafássemos": "ensarrafar",
    "ensarrafávamo": "ensarrafar",
    "ensarrafávamos": "ensarrafar",
    "ensarrafávei": "ensarrafar",
    "ensarrafáveis": "ensarrafar",
    "ensarta": "ensartar",
    "ensartada": "ensartar",
    "ensartadas": "ensartar",
    "ensartado": "ensartar",
    "ensartados": "ensartar",
    "ensartai": "ensartar",
    "ensartais": "ensartar",
    "ensartam": "ensartar",
    "ensartamo": "ensartar",
    "ensartamos": "ensartar",
    "ensartando": "ensartar",
    "ensartara": "ensartar",
    "ensartaram": "ensartar",
    "ensartaras": "ensartar",
    "ensartarde": "ensartar",
    "ensartardes": "ensartar",
    "ensartare": "ensartar",
    "ensartarei": "ensartar",
    "ensartareis": "ensartar",
    "ensartarem": "ensartar",
    "ensartaremos": "ensartar",
    "ensartares": "ensartar",
    "ensartaria": "ensartar",
    "ensartariam": "ensartar",
    "ensartarias": "ensartar",
    "ensartarmo": "ensartar",
    "ensartarmos": "ensartar",
    "ensartará": "ensartar",
    "ensartarás": "ensartar",
    "ensartarão": "ensartar",
    "ensartaríamos": "ensartar",
    "ensartaríeis": "ensartar",
    "ensartas": "ensartar",
    "ensartasse": "ensartar",
    "ensartassem": "ensartar",
    "ensartasses": "ensartar",
    "ensartaste": "ensartar",
    "ensartastes": "ensartar",
    "ensartava": "ensartar",
    "ensartavam": "ensartar",
    "ensartavas": "ensartar",
    "ensarte": "ensartar",
    "ensartei": "ensartar",
    "ensarteis": "ensartar",
    "ensartem": "ensartar",
    "ensartemo": "ensartar",
    "ensartemos": "ensartar",
    "ensartes": "ensartar",
    "ensarto": "ensartar",
    "ensartou": "ensartar",
    "ensartá": "ensartar",
    "ensartámo": "ensartar",
    "ensartámos": "ensartar",
    "ensartáramo": "ensartar",
    "ensartáramos": "ensartar",
    "ensartárei": "ensartar",
    "ensartáreis": "ensartar",
    "ensartásseis": "ensartar",
    "ensartássemos": "ensartar",
    "ensartávamo": "ensartar",
    "ensartávamos": "ensartar",
    "ensartávei": "ensartar",
    "ensartáveis": "ensartar",
    "ensaudada": "ensaudar",
    "ensaudadas": "ensaudar",
    "ensaudado": "ensaudar",
    "ensaudados": "ensaudar",
    "ensaudai": "ensaudar",
    "ensaudais": "ensaudar",
    "ensaudamo": "ensaudar",
    "ensaudamos": "ensaudar",
    "ensaudando": "ensaudar",
    "ensaudara": "ensaudar",
    "ensaudaram": "ensaudar",
    "ensaudaras": "ensaudar",
    "ensaudarde": "ensaudar",
    "ensaudardes": "ensaudar",
    "ensaudare": "ensaudar",
    "ensaudarei": "ensaudar",
    "ensaudareis": "ensaudar",
    "ensaudarem": "ensaudar",
    "ensaudaremos": "ensaudar",
    "ensaudares": "ensaudar",
    "ensaudaria": "ensaudar",
    "ensaudariam": "ensaudar",
    "ensaudarias": "ensaudar",
    "ensaudarmo": "ensaudar",
    "ensaudarmos": "ensaudar",
    "ensaudará": "ensaudar",
    "ensaudarás": "ensaudar",
    "ensaudarão": "ensaudar",
    "ensaudaríamos": "ensaudar",
    "ensaudaríeis": "ensaudar",
    "ensaudasse": "ensaudar",
    "ensaudassem": "ensaudar",
    "ensaudasses": "ensaudar",
    "ensaudaste": "ensaudar",
    "ensaudastes": "ensaudar",
    "ensaudava": "ensaudar",
    "ensaudavam": "ensaudar",
    "ensaudavas": "ensaudar",
    "ensaudece": "ensaudecer",
    "ensaudecei": "ensaudecer",
    "ensaudeceis": "ensaudecer",
    "ensaudecem": "ensaudecer",
    "ensaudecemo": "ensaudecer",
    "ensaudecemos": "ensaudecer",
    "ensaudecendo": "ensaudecer",
    "ensaudecera": "ensaudecer",
    "ensaudeceram": "ensaudecer",
    "ensaudeceras": "ensaudecer",
    "ensaudecerde": "ensaudecer",
    "ensaudecerdes": "ensaudecer",
    "ensaudecere": "ensaudecer",
    "ensaudecerei": "ensaudecer",
    "ensaudecereis": "ensaudecer",
    "ensaudecerem": "ensaudecer",
    "ensaudeceremos": "ensaudecer",
    "ensaudeceres": "ensaudecer",
    "ensaudeceria": "ensaudecer",
    "ensaudeceriam": "ensaudecer",
    "ensaudecerias": "ensaudecer",
    "ensaudecermo": "ensaudecer",
    "ensaudecermos": "ensaudecer",
    "ensaudecerá": "ensaudecer",
    "ensaudecerás": "ensaudecer",
    "ensaudecerão": "ensaudecer",
    "ensaudeceríamos": "ensaudecer",
    "ensaudeceríeis": "ensaudecer",
    "ensaudeces": "ensaudecer",
    "ensaudecesse": "ensaudecer",
    "ensaudecessem": "ensaudecer",
    "ensaudecesses": "ensaudecer",
    "ensaudeceste": "ensaudecer",
    "ensaudecestes": "ensaudecer",
    "ensaudeceu": "ensaudecer",
    "ensaudeci": "ensaudecer",
    "ensaudecia": "ensaudecer",
    "ensaudeciam": "ensaudecer",
    "ensaudecias": "ensaudecer",
    "ensaudecida": "ensaudecer",
    "ensaudecidas": "ensaudecer",
    "ensaudecido": "ensaudecer",
    "ensaudecidos": "ensaudecer",
    "ensaudecê": "ensaudecer",
    "ensaudecêramo": "ensaudecer",
    "ensaudecêramos": "ensaudecer",
    "ensaudecêrei": "ensaudecer",
    "ensaudecêreis": "ensaudecer",
    "ensaudecêsseis": "ensaudecer",
    "ensaudecêssemos": "ensaudecer",
    "ensaudecíamo": "ensaudecer",
    "ensaudecíamos": "ensaudecer",
    "ensaudecíei": "ensaudecer",
    "ensaudecíeis": "ensaudecer",
    "ensaudei": "ensaudar",
    "ensaudeis": "ensaudar",
    "ensaudemo": "ensaudar",
    "ensaudemos": "ensaudar",
    "ensaudeça": "ensaudecer",
    "ensaudeçais": "ensaudecer",
    "ensaudeçam": "ensaudecer",
    "ensaudeçamo": "ensaudecer",
    "ensaudeçamos": "ensaudecer",
    "ensaudeças": "ensaudecer",
    "ensaudeço": "ensaudecer",
    "ensaudou": "ensaudar",
    "ensaudá": "ensaudar",
    "ensaudámo": "ensaudar",
    "ensaudámos": "ensaudar",
    "ensaudáramo": "ensaudar",
    "ensaudáramos": "ensaudar",
    "ensaudárei": "ensaudar",
    "ensaudáreis": "ensaudar",
    "ensaudásseis": "ensaudar",
    "ensaudássemos": "ensaudar",
    "ensaudávamo": "ensaudar",
    "ensaudávamos": "ensaudar",
    "ensaudávei": "ensaudar",
    "ensaudáveis": "ensaudar",
    "ensaísmos": "ensaísmo",
    "ensaístas": "ensaísta",
    "ensaísticas": "ensaística",
    "ensaúda": "ensaudar",
    "ensaúdam": "ensaudar",
    "ensaúdas": "ensaudar",
    "ensaúde": "ensaudar",
    "ensaúdem": "ensaudar",
    "ensaúdes": "ensaudar",
    "ensaúdo": "ensaudar",
    "enseadas": "enseada",
    "enseba": "ensebar",
    "ensebada": "ensebar",
    "ensebadas": "ensebar",
    "ensebadelas": "ensebadela",
    "ensebado": "ensebar",
    "ensebados": "ensebar",
    "ensebadíssima": "ensebado",
    "ensebadíssimas": "ensebado",
    "ensebadíssimo": "ensebado",
    "ensebadíssimos": "ensebado",
    "ensebai": "ensebar",
    "ensebais": "ensebar",
    "ensebam": "ensebar",
    "ensebamentos": "ensebamento",
    "ensebamo": "ensebar",
    "ensebamos": "ensebar",
    "ensebando": "ensebar",
    "ensebara": "ensebar",
    "ensebaram": "ensebar",
    "ensebaras": "ensebar",
    "ensebarde": "ensebar",
    "ensebardes": "ensebar",
    "ensebare": "ensebar",
    "ensebarei": "ensebar",
    "ensebareis": "ensebar",
    "ensebarem": "ensebar",
    "ensebaremos": "ensebar",
    "ensebares": "ensebar",
    "ensebaria": "ensebar",
    "ensebariam": "ensebar",
    "ensebarias": "ensebar",
    "ensebarmo": "ensebar",
    "ensebarmos": "ensebar",
    "ensebará": "ensebar",
    "ensebarás": "ensebar",
    "ensebarão": "ensebar",
    "ensebaríamos": "ensebar",
    "ensebaríeis": "ensebar",
    "ensebas": "ensebar",
    "ensebasse": "ensebar",
    "ensebassem": "ensebar",
    "ensebasses": "ensebar",
    "ensebaste": "ensebar",
    "ensebastes": "ensebar",
    "ensebava": "ensebar",
    "ensebavam": "ensebar",
    "ensebavas": "ensebar",
    "ensebe": "ensebar",
    "ensebei": "ensebar",
    "ensebeis": "ensebar",
    "ensebem": "ensebar",
    "ensebemo": "ensebar",
    "ensebemos": "ensebar",
    "ensebes": "ensebar",
    "ensebo": "ensebar",
    "ensebou": "ensebar",
    "ensebá": "ensebar",
    "ensebámo": "ensebar",
    "ensebámos": "ensebar",
    "ensebáramo": "ensebar",
    "ensebáramos": "ensebar",
    "ensebárei": "ensebar",
    "ensebáreis": "ensebar",
    "ensebásseis": "ensebar",
    "ensebássemos": "ensebar",
    "ensebávamo": "ensebar",
    "ensebávamos": "ensebar",
    "ensebávei": "ensebar",
    "ensebáveis": "ensebar",
    "enseca": "ensecar",
    "ensecada": "ensecar",
    "ensecadas": "ensecar",
    "ensecadeiras": "ensecadeira",
    "ensecado": "ensecar",
    "ensecados": "ensecar",
    "ensecai": "ensecar",
    "ensecais": "ensecar",
    "ensecam": "ensecar",
    "ensecamo": "ensecar",
    "ensecamos": "ensecar",
    "ensecando": "ensecar",
    "ensecara": "ensecar",
    "ensecaram": "ensecar",
    "ensecaras": "ensecar",
    "ensecarde": "ensecar",
    "ensecardes": "ensecar",
    "ensecare": "ensecar",
    "ensecarei": "ensecar",
    "ensecareis": "ensecar",
    "ensecarem": "ensecar",
    "ensecaremos": "ensecar",
    "ensecares": "ensecar",
    "ensecaria": "ensecar",
    "ensecariam": "ensecar",
    "ensecarias": "ensecar",
    "ensecarmo": "ensecar",
    "ensecarmos": "ensecar",
    "ensecará": "ensecar",
    "ensecarás": "ensecar",
    "ensecarão": "ensecar",
    "ensecaríamos": "ensecar",
    "ensecaríeis": "ensecar",
    "ensecas": "ensecar",
    "ensecasse": "ensecar",
    "ensecassem": "ensecar",
    "ensecasses": "ensecar",
    "ensecaste": "ensecar",
    "ensecastes": "ensecar",
    "ensecava": "ensecar",
    "ensecavam": "ensecar",
    "ensecavas": "ensecar",
    "enseco": "ensecar",
    "ensecou": "ensecar",
    "ensecá": "ensecar",
    "ensecámo": "ensecar",
    "ensecámos": "ensecar",
    "ensecáramo": "ensecar",
    "ensecáramos": "ensecar",
    "ensecárei": "ensecar",
    "ensecáreis": "ensecar",
    "ensecásseis": "ensecar",
    "ensecássemos": "ensecar",
    "ensecávamo": "ensecar",
    "ensecávamos": "ensecar",
    "ensecávei": "ensecar",
    "ensecáveis": "ensecar",
    "enseda": "ensedar",
    "ensedada": "ensedar",
    "ensedadas": "ensedar",
    "ensedado": "ensedar",
    "ensedados": "ensedar",
    "ensedaduras": "ensedadura",
    "ensedai": "ensedar",
    "ensedais": "ensedar",
    "ensedam": "ensedar",
    "ensedamo": "ensedar",
    "ensedamos": "ensedar",
    "ensedando": "ensedar",
    "ensedara": "ensedar",
    "ensedaram": "ensedar",
    "ensedaras": "ensedar",
    "ensedarde": "ensedar",
    "ensedardes": "ensedar",
    "ensedare": "ensedar",
    "ensedarei": "ensedar",
    "ensedareis": "ensedar",
    "ensedarem": "ensedar",
    "ensedaremos": "ensedar",
    "ensedares": "ensedar",
    "ensedaria": "ensedar",
    "ensedariam": "ensedar",
    "ensedarias": "ensedar",
    "ensedarmo": "ensedar",
    "ensedarmos": "ensedar",
    "ensedará": "ensedar",
    "ensedarás": "ensedar",
    "ensedarão": "ensedar",
    "ensedaríamos": "ensedar",
    "ensedaríeis": "ensedar",
    "ensedas": "ensedar",
    "ensedasse": "ensedar",
    "ensedassem": "ensedar",
    "ensedasses": "ensedar",
    "ensedaste": "ensedar",
    "ensedastes": "ensedar",
    "ensedava": "ensedar",
    "ensedavam": "ensedar",
    "ensedavas": "ensedar",
    "ensede": "ensedar",
    "ensedei": "ensedar",
    "ensedeis": "ensedar",
    "ensedem": "ensedar",
    "ensedemo": "ensedar",
    "ensedemos": "ensedar",
    "ensedes": "ensedar",
    "ensedo": "ensedar",
    "ensedou": "ensedar",
    "ensedá": "ensedar",
    "ensedámo": "ensedar",
    "ensedámos": "ensedar",
    "ensedáramo": "ensedar",
    "ensedáramos": "ensedar",
    "ensedárei": "ensedar",
    "ensedáreis": "ensedar",
    "ensedásseis": "ensedar",
    "ensedássemos": "ensedar",
    "ensedávamo": "ensedar",
    "ensedávamos": "ensedar",
    "ensedávei": "ensedar",
    "ensedáveis": "ensedar",
    "enseios": "enseio",
    "enseira": "enseirar",
    "enseirada": "enseirar",
    "enseiradas": "enseirar",
    "enseirado": "enseirar",
    "enseiradora": "enseirador",
    "enseiradoras": "enseirador",
    "enseiradores": "enseirador",
    "enseirados": "enseirar",
    "enseirai": "enseirar",
    "enseirais": "enseirar",
    "enseiram": "enseirar",
    "enseiramentos": "enseiramento",
    "enseiramo": "enseirar",
    "enseiramos": "enseirar",
    "enseirando": "enseirar",
    "enseirara": "enseirar",
    "enseiraram": "enseirar",
    "enseiraras": "enseirar",
    "enseirarde": "enseirar",
    "enseirardes": "enseirar",
    "enseirare": "enseirar",
    "enseirarei": "enseirar",
    "enseirareis": "enseirar",
    "enseirarem": "enseirar",
    "enseiraremos": "enseirar",
    "enseirares": "enseirar",
    "enseiraria": "enseirar",
    "enseirariam": "enseirar",
    "enseirarias": "enseirar",
    "enseirarmo": "enseirar",
    "enseirarmos": "enseirar",
    "enseirará": "enseirar",
    "enseirarás": "enseirar",
    "enseirarão": "enseirar",
    "enseiraríamos": "enseirar",
    "enseiraríeis": "enseirar",
    "enseiras": "enseirar",
    "enseirasse": "enseirar",
    "enseirassem": "enseirar",
    "enseirasses": "enseirar",
    "enseiraste": "enseirar",
    "enseirastes": "enseirar",
    "enseirava": "enseirar",
    "enseiravam": "enseirar",
    "enseiravas": "enseirar",
    "enseire": "enseirar",
    "enseirei": "enseirar",
    "enseireis": "enseirar",
    "enseirem": "enseirar",
    "enseiremo": "enseirar",
    "enseiremos": "enseirar",
    "enseires": "enseirar",
    "enseiro": "enseirar",
    "enseirou": "enseirar",
    "enseirá": "enseirar",
    "enseirámo": "enseirar",
    "enseirámos": "enseirar",
    "enseiráramo": "enseirar",
    "enseiráramos": "enseirar",
    "enseirárei": "enseirar",
    "enseiráreis": "enseirar",
    "enseirásseis": "enseirar",
    "enseirássemos": "enseirar",
    "enseirávamo": "enseirar",
    "enseirávamos": "enseirar",
    "enseirávei": "enseirar",
    "enseiráveis": "enseirar",
    "enseiva": "enseivar",
    "enseivada": "enseivar",
    "enseivadas": "enseivar",
    "enseivado": "enseivar",
    "enseivados": "enseivar",
    "enseivai": "enseivar",
    "enseivais": "enseivar",
    "enseivam": "enseivar",
    "enseivamo": "enseivar",
    "enseivamos": "enseivar",
    "enseivando": "enseivar",
    "enseivara": "enseivar",
    "enseivaram": "enseivar",
    "enseivaras": "enseivar",
    "enseivarde": "enseivar",
    "enseivardes": "enseivar",
    "enseivare": "enseivar",
    "enseivarei": "enseivar",
    "enseivareis": "enseivar",
    "enseivarem": "enseivar",
    "enseivaremos": "enseivar",
    "enseivares": "enseivar",
    "enseivaria": "enseivar",
    "enseivariam": "enseivar",
    "enseivarias": "enseivar",
    "enseivarmo": "enseivar",
    "enseivarmos": "enseivar",
    "enseivará": "enseivar",
    "enseivarás": "enseivar",
    "enseivarão": "enseivar",
    "enseivaríamos": "enseivar",
    "enseivaríeis": "enseivar",
    "enseivas": "enseivar",
    "enseivasse": "enseivar",
    "enseivassem": "enseivar",
    "enseivasses": "enseivar",
    "enseivaste": "enseivar",
    "enseivastes": "enseivar",
    "enseivava": "enseivar",
    "enseivavam": "enseivar",
    "enseivavas": "enseivar",
    "enseive": "enseivar",
    "enseivei": "enseivar",
    "enseiveis": "enseivar",
    "enseivem": "enseivar",
    "enseivemo": "enseivar",
    "enseivemos": "enseivar",
    "enseives": "enseivar",
    "enseivo": "enseivar",
    "enseivou": "enseivar",
    "enseivá": "enseivar",
    "enseivámo": "enseivar",
    "enseivámos": "enseivar",
    "enseiváramo": "enseivar",
    "enseiváramos": "enseivar",
    "enseivárei": "enseivar",
    "enseiváreis": "enseivar",
    "enseivásseis": "enseivar",
    "enseivássemos": "enseivar",
    "enseivávamo": "enseivar",
    "enseivávamos": "enseivar",
    "enseivávei": "enseivar",
    "enseiváveis": "enseivar",
    "enseja": "ensejar",
    "ensejada": "ensejar",
    "ensejadas": "ensejar",
    "ensejado": "ensejar",
    "ensejados": "ensejar",
    "ensejai": "ensejar",
    "ensejais": "ensejar",
    "ensejam": "ensejar",
    "ensejamo": "ensejar",
    "ensejamos": "ensejar",
    "ensejando": "ensejar",
    "ensejara": "ensejar",
    "ensejaram": "ensejar",
    "ensejaras": "ensejar",
    "ensejarde": "ensejar",
    "ensejardes": "ensejar",
    "ensejare": "ensejar",
    "ensejarei": "ensejar",
    "ensejareis": "ensejar",
    "ensejarem": "ensejar",
    "ensejaremos": "ensejar",
    "ensejares": "ensejar",
    "ensejaria": "ensejar",
    "ensejariam": "ensejar",
    "ensejarias": "ensejar",
    "ensejarmo": "ensejar",
    "ensejarmos": "ensejar",
    "ensejará": "ensejar",
    "ensejarás": "ensejar",
    "ensejarão": "ensejar",
    "ensejaríamos": "ensejar",
    "ensejaríeis": "ensejar",
    "ensejas": "ensejar",
    "ensejasse": "ensejar",
    "ensejassem": "ensejar",
    "ensejasses": "ensejar",
    "ensejaste": "ensejar",
    "ensejastes": "ensejar",
    "ensejava": "ensejar",
    "ensejavam": "ensejar",
    "ensejavas": "ensejar",
    "enseje": "ensejar",
    "ensejei": "ensejar",
    "ensejeis": "ensejar",
    "ensejem": "ensejar",
    "ensejemo": "ensejar",
    "ensejemos": "ensejar",
    "ensejes": "ensejar",
    "ensejo": "ensejar",
    "ensejos": "ensejo",
    "ensejou": "ensejar",
    "ensejá": "ensejar",
    "ensejámo": "ensejar",
    "ensejámos": "ensejar",
    "ensejáramo": "ensejar",
    "ensejáramos": "ensejar",
    "ensejárei": "ensejar",
    "ensejáreis": "ensejar",
    "ensejásseis": "ensejar",
    "ensejássemos": "ensejar",
    "ensejávamo": "ensejar",
    "ensejávamos": "ensejar",
    "ensejávei": "ensejar",
    "ensejáveis": "ensejar",
    "ensenhoreada": "ensenhorear",
    "ensenhoreadas": "ensenhorear",
    "ensenhoreado": "ensenhorear",
    "ensenhoreados": "ensenhorear",
    "ensenhoreai": "ensenhorear",
    "ensenhoreais": "ensenhorear",
    "ensenhoreamo": "ensenhorear",
    "ensenhoreamos": "ensenhorear",
    "ensenhoreando": "ensenhorear",
    "ensenhoreara": "ensenhorear",
    "ensenhorearam": "ensenhorear",
    "ensenhorearas": "ensenhorear",
    "ensenhorearde": "ensenhorear",
    "ensenhoreardes": "ensenhorear",
    "ensenhoreare": "ensenhorear",
    "ensenhorearei": "ensenhorear",
    "ensenhoreareis": "ensenhorear",
    "ensenhorearem": "ensenhorear",
    "ensenhorearemos": "ensenhorear",
    "ensenhoreares": "ensenhorear",
    "ensenhorearia": "ensenhorear",
    "ensenhoreariam": "ensenhorear",
    "ensenhorearias": "ensenhorear",
    "ensenhorearmo": "ensenhorear",
    "ensenhorearmos": "ensenhorear",
    "ensenhoreará": "ensenhorear",
    "ensenhorearás": "ensenhorear",
    "ensenhorearão": "ensenhorear",
    "ensenhorearíamos": "ensenhorear",
    "ensenhorearíeis": "ensenhorear",
    "ensenhoreasse": "ensenhorear",
    "ensenhoreassem": "ensenhorear",
    "ensenhoreasses": "ensenhorear",
    "ensenhoreaste": "ensenhorear",
    "ensenhoreastes": "ensenhorear",
    "ensenhoreava": "ensenhorear",
    "ensenhoreavam": "ensenhorear",
    "ensenhoreavas": "ensenhorear",
    "ensenhoreei": "ensenhorear",
    "ensenhoreeis": "ensenhorear",
    "ensenhoreemo": "ensenhorear",
    "ensenhoreemos": "ensenhorear",
    "ensenhoreia": "ensenhorear",
    "ensenhoreiam": "ensenhorear",
    "ensenhoreias": "ensenhorear",
    "ensenhoreie": "ensenhorear",
    "ensenhoreiem": "ensenhorear",
    "ensenhoreies": "ensenhorear",
    "ensenhoreio": "ensenhorear",
    "ensenhoreou": "ensenhorear",
    "ensenhoreá": "ensenhorear",
    "ensenhoreámo": "ensenhorear",
    "ensenhoreámos": "ensenhorear",
    "ensenhoreáramo": "ensenhorear",
    "ensenhoreáramos": "ensenhorear",
    "ensenhoreárei": "ensenhorear",
    "ensenhoreáreis": "ensenhorear",
    "ensenhoreásseis": "ensenhorear",
    "ensenhoreássemos": "ensenhorear",
    "ensenhoreávamo": "ensenhorear",
    "ensenhoreávamos": "ensenhorear",
    "ensenhoreávei": "ensenhorear",
    "ensenhoreáveis": "ensenhorear",
    "enseque": "ensecar",
    "ensequei": "ensecar",
    "ensequeis": "ensecar",
    "ensequem": "ensecar",
    "ensequemo": "ensecar",
    "ensequemos": "ensecar",
    "enseques": "ensecar",
    "ensesga": "ensesgar",
    "ensesgada": "ensesgar",
    "ensesgadas": "ensesgar",
    "ensesgado": "ensesgar",
    "ensesgados": "ensesgar",
    "ensesgai": "ensesgar",
    "ensesgais": "ensesgar",
    "ensesgam": "ensesgar",
    "ensesgamo": "ensesgar",
    "ensesgamos": "ensesgar",
    "ensesgando": "ensesgar",
    "ensesgara": "ensesgar",
    "ensesgaram": "ensesgar",
    "ensesgaras": "ensesgar",
    "ensesgarde": "ensesgar",
    "ensesgardes": "ensesgar",
    "ensesgare": "ensesgar",
    "ensesgarei": "ensesgar",
    "ensesgareis": "ensesgar",
    "ensesgarem": "ensesgar",
    "ensesgaremos": "ensesgar",
    "ensesgares": "ensesgar",
    "ensesgaria": "ensesgar",
    "ensesgariam": "ensesgar",
    "ensesgarias": "ensesgar",
    "ensesgarmo": "ensesgar",
    "ensesgarmos": "ensesgar",
    "ensesgará": "ensesgar",
    "ensesgarás": "ensesgar",
    "ensesgarão": "ensesgar",
    "ensesgaríamos": "ensesgar",
    "ensesgaríeis": "ensesgar",
    "ensesgas": "ensesgar",
    "ensesgasse": "ensesgar",
    "ensesgassem": "ensesgar",
    "ensesgasses": "ensesgar",
    "ensesgaste": "ensesgar",
    "ensesgastes": "ensesgar",
    "ensesgava": "ensesgar",
    "ensesgavam": "ensesgar",
    "ensesgavas": "ensesgar",
    "ensesgo": "ensesgar",
    "ensesgou": "ensesgar",
    "ensesgue": "ensesgar",
    "ensesguei": "ensesgar",
    "ensesgueis": "ensesgar",
    "ensesguem": "ensesgar",
    "ensesguemo": "ensesgar",
    "ensesguemos": "ensesgar",
    "ensesgues": "ensesgar",
    "ensesgá": "ensesgar",
    "ensesgámo": "ensesgar",
    "ensesgámos": "ensesgar",
    "ensesgáramo": "ensesgar",
    "ensesgáramos": "ensesgar",
    "ensesgárei": "ensesgar",
    "ensesgáreis": "ensesgar",
    "ensesgásseis": "ensesgar",
    "ensesgássemos": "ensesgar",
    "ensesgávamo": "ensesgar",
    "ensesgávamos": "ensesgar",
    "ensesgávei": "ensesgar",
    "ensesgáveis": "ensesgar",
    "ensila": "ensilar",
    "ensilada": "ensilar",
    "ensiladas": "ensilar",
    "ensilado": "ensilar",
    "ensilados": "ensilar",
    "ensilagens": "ensilagem",
    "ensilai": "ensilar",
    "ensilais": "ensilar",
    "ensilam": "ensilar",
    "ensilamo": "ensilar",
    "ensilamos": "ensilar",
    "ensilando": "ensilar",
    "ensilara": "ensilar",
    "ensilaram": "ensilar",
    "ensilaras": "ensilar",
    "ensilarde": "ensilar",
    "ensilardes": "ensilar",
    "ensilare": "ensilar",
    "ensilarei": "ensilar",
    "ensilareis": "ensilar",
    "ensilarem": "ensilar",
    "ensilaremos": "ensilar",
    "ensilares": "ensilar",
    "ensilaria": "ensilar",
    "ensilariam": "ensilar",
    "ensilarias": "ensilar",
    "ensilarmo": "ensilar",
    "ensilarmos": "ensilar",
    "ensilará": "ensilar",
    "ensilarás": "ensilar",
    "ensilarão": "ensilar",
    "ensilaríamos": "ensilar",
    "ensilaríeis": "ensilar",
    "ensilas": "ensilar",
    "ensilasse": "ensilar",
    "ensilassem": "ensilar",
    "ensilasses": "ensilar",
    "ensilaste": "ensilar",
    "ensilastes": "ensilar",
    "ensilava": "ensilar",
    "ensilavam": "ensilar",
    "ensilavas": "ensilar",
    "ensile": "ensilar",
    "ensilei": "ensilar",
    "ensileis": "ensilar",
    "ensilem": "ensilar",
    "ensilemo": "ensilar",
    "ensilemos": "ensilar",
    "ensiles": "ensilar",
    "ensilo": "ensilar",
    "ensilou": "ensilar",
    "ensilva": "ensilvar",
    "ensilvada": "ensilvar",
    "ensilvadas": "ensilvar",
    "ensilvado": "ensilvar",
    "ensilvados": "ensilvar",
    "ensilvai": "ensilvar",
    "ensilvais": "ensilvar",
    "ensilvam": "ensilvar",
    "ensilvamo": "ensilvar",
    "ensilvamos": "ensilvar",
    "ensilvando": "ensilvar",
    "ensilvara": "ensilvar",
    "ensilvaram": "ensilvar",
    "ensilvaras": "ensilvar",
    "ensilvarde": "ensilvar",
    "ensilvardes": "ensilvar",
    "ensilvare": "ensilvar",
    "ensilvarei": "ensilvar",
    "ensilvareis": "ensilvar",
    "ensilvarem": "ensilvar",
    "ensilvaremos": "ensilvar",
    "ensilvares": "ensilvar",
    "ensilvaria": "ensilvar",
    "ensilvariam": "ensilvar",
    "ensilvarias": "ensilvar",
    "ensilvarmo": "ensilvar",
    "ensilvarmos": "ensilvar",
    "ensilvará": "ensilvar",
    "ensilvarás": "ensilvar",
    "ensilvarão": "ensilvar",
    "ensilvaríamos": "ensilvar",
    "ensilvaríeis": "ensilvar",
    "ensilvas": "ensilvar",
    "ensilvasse": "ensilvar",
    "ensilvassem": "ensilvar",
    "ensilvasses": "ensilvar",
    "ensilvaste": "ensilvar",
    "ensilvastes": "ensilvar",
    "ensilvava": "ensilvar",
    "ensilvavam": "ensilvar",
    "ensilvavas": "ensilvar",
    "ensilve": "ensilvar",
    "ensilvei": "ensilvar",
    "ensilveira": "ensilveirar",
    "ensilveirada": "ensilveirar",
    "ensilveiradas": "ensilveirar",
    "ensilveirado": "ensilveirar",
    "ensilveirados": "ensilveirar",
    "ensilveirai": "ensilveirar",
    "ensilveirais": "ensilveirar",
    "ensilveiram": "ensilveirar",
    "ensilveiramo": "ensilveirar",
    "ensilveiramos": "ensilveirar",
    "ensilveirando": "ensilveirar",
    "ensilveirara": "ensilveirar",
    "ensilveiraram": "ensilveirar",
    "ensilveiraras": "ensilveirar",
    "ensilveirarde": "ensilveirar",
    "ensilveirardes": "ensilveirar",
    "ensilveirare": "ensilveirar",
    "ensilveirarei": "ensilveirar",
    "ensilveirareis": "ensilveirar",
    "ensilveirarem": "ensilveirar",
    "ensilveiraremos": "ensilveirar",
    "ensilveirares": "ensilveirar",
    "ensilveiraria": "ensilveirar",
    "ensilveirariam": "ensilveirar",
    "ensilveirarias": "ensilveirar",
    "ensilveirarmo": "ensilveirar",
    "ensilveirarmos": "ensilveirar",
    "ensilveirará": "ensilveirar",
    "ensilveirarás": "ensilveirar",
    "ensilveirarão": "ensilveirar",
    "ensilveiraríamos": "ensilveirar",
    "ensilveiraríeis": "ensilveirar",
    "ensilveiras": "ensilveirar",
    "ensilveirasse": "ensilveirar",
    "ensilveirassem": "ensilveirar",
    "ensilveirasses": "ensilveirar",
    "ensilveiraste": "ensilveirar",
    "ensilveirastes": "ensilveirar",
    "ensilveirava": "ensilveirar",
    "ensilveiravam": "ensilveirar",
    "ensilveiravas": "ensilveirar",
    "ensilveire": "ensilveirar",
    "ensilveirei": "ensilveirar",
    "ensilveireis": "ensilveirar",
    "ensilveirem": "ensilveirar",
    "ensilveiremo": "ensilveirar",
    "ensilveiremos": "ensilveirar",
    "ensilveires": "ensilveirar",
    "ensilveiro": "ensilveirar",
    "ensilveirou": "ensilveirar",
    "ensilveirá": "ensilveirar",
    "ensilveirámo": "ensilveirar",
    "ensilveirámos": "ensilveirar",
    "ensilveiráramo": "ensilveirar",
    "ensilveiráramos": "ensilveirar",
    "ensilveirárei": "ensilveirar",
    "ensilveiráreis": "ensilveirar",
    "ensilveirásseis": "ensilveirar",
    "ensilveirássemos": "ensilveirar",
    "ensilveirávamo": "ensilveirar",
    "ensilveirávamos": "ensilveirar",
    "ensilveirávei": "ensilveirar",
    "ensilveiráveis": "ensilveirar",
    "ensilveis": "ensilvar",
    "ensilvem": "ensilvar",
    "ensilvemo": "ensilvar",
    "ensilvemos": "ensilvar",
    "ensilves": "ensilvar",
    "ensilvo": "ensilvar",
    "ensilvou": "ensilvar",
    "ensilvá": "ensilvar",
    "ensilvámo": "ensilvar",
    "ensilvámos": "ensilvar",
    "ensilváramo": "ensilvar",
    "ensilváramos": "ensilvar",
    "ensilvárei": "ensilvar",
    "ensilváreis": "ensilvar",
    "ensilvásseis": "ensilvar",
    "ensilvássemos": "ensilvar",
    "ensilvávamo": "ensilvar",
    "ensilvávamos": "ensilvar",
    "ensilvávei": "ensilvar",
    "ensilváveis": "ensilvar",
    "ensilá": "ensilar",
    "ensilámo": "ensilar",
    "ensilámos": "ensilar",
    "ensiláramo": "ensilar",
    "ensiláramos": "ensilar",
    "ensilárei": "ensilar",
    "ensiláreis": "ensilar",
    "ensilásseis": "ensilar",
    "ensilássemos": "ensilar",
    "ensilávamo": "ensilar",
    "ensilávamos": "ensilar",
    "ensilávei": "ensilar",
    "ensiláveis": "ensilar",
    "ensimesma": "ensimesmar",
    "ensimesmada": "ensimesmar",
    "ensimesmadas": "ensimesmar",
    "ensimesmado": "ensimesmar",
    "ensimesmados": "ensimesmar",
    "ensimesmai": "ensimesmar",
    "ensimesmais": "ensimesmar",
    "ensimesmam": "ensimesmar",
    "ensimesmamentos": "ensimesmamento",
    "ensimesmamo": "ensimesmar",
    "ensimesmamos": "ensimesmar",
    "ensimesmando": "ensimesmar",
    "ensimesmara": "ensimesmar",
    "ensimesmaram": "ensimesmar",
    "ensimesmaras": "ensimesmar",
    "ensimesmarde": "ensimesmar",
    "ensimesmardes": "ensimesmar",
    "ensimesmare": "ensimesmar",
    "ensimesmarei": "ensimesmar",
    "ensimesmareis": "ensimesmar",
    "ensimesmarem": "ensimesmar",
    "ensimesmaremos": "ensimesmar",
    "ensimesmares": "ensimesmar",
    "ensimesmaria": "ensimesmar",
    "ensimesmariam": "ensimesmar",
    "ensimesmarias": "ensimesmar",
    "ensimesmarmo": "ensimesmar",
    "ensimesmarmos": "ensimesmar",
    "ensimesmará": "ensimesmar",
    "ensimesmarás": "ensimesmar",
    "ensimesmarão": "ensimesmar",
    "ensimesmaríamos": "ensimesmar",
    "ensimesmaríeis": "ensimesmar",
    "ensimesmas": "ensimesmar",
    "ensimesmasse": "ensimesmar",
    "ensimesmassem": "ensimesmar",
    "ensimesmasses": "ensimesmar",
    "ensimesmaste": "ensimesmar",
    "ensimesmastes": "ensimesmar",
    "ensimesmava": "ensimesmar",
    "ensimesmavam": "ensimesmar",
    "ensimesmavas": "ensimesmar",
    "ensimesme": "ensimesmar",
    "ensimesmei": "ensimesmar",
    "ensimesmeis": "ensimesmar",
    "ensimesmem": "ensimesmar",
    "ensimesmemo": "ensimesmar",
    "ensimesmemos": "ensimesmar",
    "ensimesmes": "ensimesmar",
    "ensimesmo": "ensimesmar",
    "ensimesmou": "ensimesmar",
    "ensimesmá": "ensimesmar",
    "ensimesmámo": "ensimesmar",
    "ensimesmámos": "ensimesmar",
    "ensimesmáramo": "ensimesmar",
    "ensimesmáramos": "ensimesmar",
    "ensimesmárei": "ensimesmar",
    "ensimesmáreis": "ensimesmar",
    "ensimesmásseis": "ensimesmar",
    "ensimesmássemos": "ensimesmar",
    "ensimesmávamo": "ensimesmar",
    "ensimesmávamos": "ensimesmar",
    "ensimesmávei": "ensimesmar",
    "ensimesmáveis": "ensimesmar",
    "ensina": "ensinar",
    "ensinada": "ensinar",
    "ensinadas": "ensinar",
    "ensinadelas": "ensinadela",
    "ensinadiça": "ensinadiço",
    "ensinadiças": "ensinadiço",
    "ensinadiços": "ensinadiço",
    "ensinado": "ensinar",
    "ensinadora": "ensinador",
    "ensinadoras": "ensinador",
    "ensinadores": "ensinador",
    "ensinados": "ensinar",
    "ensinadíssima": "ensinado",
    "ensinadíssimas": "ensinado",
    "ensinadíssimo": "ensinado",
    "ensinadíssimos": "ensinado",
    "ensinai": "ensinar",
    "ensinais": "ensinar",
    "ensinam": "ensinar",
    "ensinamentos": "ensinamento",
    "ensinamo": "ensinar",
    "ensinamos": "ensinar",
    "ensinanda": "ensinando",
    "ensinandas": "ensinando",
    "ensinando": "ensinar",
    "ensinandos": "ensinando",
    "ensinantes": "ensinante",
    "ensinanças": "ensinança",
    "ensinara": "ensinar",
    "ensinaram": "ensinar",
    "ensinaras": "ensinar",
    "ensinarde": "ensinar",
    "ensinardes": "ensinar",
    "ensinare": "ensinar",
    "ensinarei": "ensinar",
    "ensinareis": "ensinar",
    "ensinarem": "ensinar",
    "ensinaremos": "ensinar",
    "ensinares": "ensinar",
    "ensinaria": "ensinar",
    "ensinariam": "ensinar",
    "ensinarias": "ensinar",
    "ensinarmo": "ensinar",
    "ensinarmos": "ensinar",
    "ensinará": "ensinar",
    "ensinarás": "ensinar",
    "ensinarão": "ensinar",
    "ensinaríamos": "ensinar",
    "ensinaríeis": "ensinar",
    "ensinas": "ensinar",
    "ensinasse": "ensinar",
    "ensinassem": "ensinar",
    "ensinasses": "ensinar",
    "ensinaste": "ensinar",
    "ensinastes": "ensinar",
    "ensinava": "ensinar",
    "ensinavam": "ensinar",
    "ensinavas": "ensinar",
    "ensine": "ensinar",
    "ensinei": "ensinar",
    "ensineis": "ensinar",
    "ensinem": "ensinar",
    "ensinemo": "ensinar",
    "ensinemos": "ensinar",
    "ensines": "ensinar",
    "ensino": "ensinar",
    "ensinos": "ensino",
    "ensinou": "ensinar",
    "ensiná": "ensinar",
    "ensinámo": "ensinar",
    "ensinámos": "ensinar",
    "ensináramo": "ensinar",
    "ensináramos": "ensinar",
    "ensinárei": "ensinar",
    "ensináreis": "ensinar",
    "ensinásseis": "ensinar",
    "ensinássemos": "ensinar",
    "ensinávamo": "ensinar",
    "ensinávamos": "ensinar",
    "ensinávei": "ensinar",
    "ensináveis": "ensinável",
    "ensirrostra": "ensirrostro",
    "ensirrostras": "ensirrostro",
    "ensirrostros": "ensirrostro",
    "ensoa": "ensoar",
    "ensoada": "ensoar",
    "ensoadas": "ensoar",
    "ensoado": "ensoar",
    "ensoados": "ensoar",
    "ensoai": "ensoar",
    "ensoais": "ensoar",
    "ensoalheira": "ensoalheirar",
    "ensoalheirada": "ensoalheirar",
    "ensoalheiradas": "ensoalheirar",
    "ensoalheirado": "ensoalheirar",
    "ensoalheirados": "ensoalheirar",
    "ensoalheirai": "ensoalheirar",
    "ensoalheirais": "ensoalheirar",
    "ensoalheiram": "ensoalheirar",
    "ensoalheiramo": "ensoalheirar",
    "ensoalheiramos": "ensoalheirar",
    "ensoalheirando": "ensoalheirar",
    "ensoalheirara": "ensoalheirar",
    "ensoalheiraram": "ensoalheirar",
    "ensoalheiraras": "ensoalheirar",
    "ensoalheirarde": "ensoalheirar",
    "ensoalheirardes": "ensoalheirar",
    "ensoalheirare": "ensoalheirar",
    "ensoalheirarei": "ensoalheirar",
    "ensoalheirareis": "ensoalheirar",
    "ensoalheirarem": "ensoalheirar",
    "ensoalheiraremos": "ensoalheirar",
    "ensoalheirares": "ensoalheirar",
    "ensoalheiraria": "ensoalheirar",
    "ensoalheirariam": "ensoalheirar",
    "ensoalheirarias": "ensoalheirar",
    "ensoalheirarmo": "ensoalheirar",
    "ensoalheirarmos": "ensoalheirar",
    "ensoalheirará": "ensoalheirar",
    "ensoalheirarás": "ensoalheirar",
    "ensoalheirarão": "ensoalheirar",
    "ensoalheiraríamos": "ensoalheirar",
    "ensoalheiraríeis": "ensoalheirar",
    "ensoalheiras": "ensoalheirar",
    "ensoalheirasse": "ensoalheirar",
    "ensoalheirassem": "ensoalheirar",
    "ensoalheirasses": "ensoalheirar",
    "ensoalheiraste": "ensoalheirar",
    "ensoalheirastes": "ensoalheirar",
    "ensoalheirava": "ensoalheirar",
    "ensoalheiravam": "ensoalheirar",
    "ensoalheiravas": "ensoalheirar",
    "ensoalheire": "ensoalheirar",
    "ensoalheirei": "ensoalheirar",
    "ensoalheireis": "ensoalheirar",
    "ensoalheirem": "ensoalheirar",
    "ensoalheiremo": "ensoalheirar",
    "ensoalheiremos": "ensoalheirar",
    "ensoalheires": "ensoalheirar",
    "ensoalheiro": "ensoalheirar",
    "ensoalheirou": "ensoalheirar",
    "ensoalheirá": "ensoalheirar",
    "ensoalheirámo": "ensoalheirar",
    "ensoalheirámos": "ensoalheirar",
    "ensoalheiráramo": "ensoalheirar",
    "ensoalheiráramos": "ensoalheirar",
    "ensoalheirárei": "ensoalheirar",
    "ensoalheiráreis": "ensoalheirar",
    "ensoalheirásseis": "ensoalheirar",
    "ensoalheirássemos": "ensoalheirar",
    "ensoalheirávamo": "ensoalheirar",
    "ensoalheirávamos": "ensoalheirar",
    "ensoalheirávei": "ensoalheirar",
    "ensoalheiráveis": "ensoalheirar",
    "ensoam": "ensoar",
    "ensoamentos": "ensoamento",
    "ensoamo": "ensoar",
    "ensoamos": "ensoar",
    "ensoando": "ensoar",
    "ensoara": "ensoar",
    "ensoaram": "ensoar",
    "ensoaras": "ensoar",
    "ensoardes": "ensoar",
    "ensoarei": "ensoar",
    "ensoareis": "ensoar",
    "ensoarem": "ensoar",
    "ensoaremos": "ensoar",
    "ensoares": "ensoar",
    "ensoaria": "ensoar",
    "ensoariam": "ensoar",
    "ensoarias": "ensoar",
    "ensoarmo": "ensoar",
    "ensoarmos": "ensoar",
    "ensoará": "ensoar",
    "ensoarás": "ensoar",
    "ensoarão": "ensoar",
    "ensoaríamos": "ensoar",
    "ensoaríeis": "ensoar",
    "ensoas": "ensoar",
    "ensoasse": "ensoar",
    "ensoassem": "ensoar",
    "ensoasses": "ensoar",
    "ensoaste": "ensoar",
    "ensoastes": "ensoar",
    "ensoava": "ensoar",
    "ensoavam": "ensoar",
    "ensoavas": "ensoar",
    "ensoberba": "ensoberbar",
    "ensoberbada": "ensoberbar",
    "ensoberbadas": "ensoberbar",
    "ensoberbado": "ensoberbar",
    "ensoberbados": "ensoberbar",
    "ensoberbai": "ensoberbar",
    "ensoberbais": "ensoberbar",
    "ensoberbam": "ensoberbar",
    "ensoberbamo": "ensoberbar",
    "ensoberbamos": "ensoberbar",
    "ensoberbando": "ensoberbar",
    "ensoberbara": "ensoberbar",
    "ensoberbaram": "ensoberbar",
    "ensoberbaras": "ensoberbar",
    "ensoberbarde": "ensoberbar",
    "ensoberbardes": "ensoberbar",
    "ensoberbare": "ensoberbar",
    "ensoberbarei": "ensoberbar",
    "ensoberbareis": "ensoberbar",
    "ensoberbarem": "ensoberbar",
    "ensoberbaremos": "ensoberbar",
    "ensoberbares": "ensoberbar",
    "ensoberbaria": "ensoberbar",
    "ensoberbariam": "ensoberbar",
    "ensoberbarias": "ensoberbar",
    "ensoberbarmo": "ensoberbar",
    "ensoberbarmos": "ensoberbar",
    "ensoberbará": "ensoberbar",
    "ensoberbarás": "ensoberbar",
    "ensoberbarão": "ensoberbar",
    "ensoberbaríamos": "ensoberbar",
    "ensoberbaríeis": "ensoberbar",
    "ensoberbas": "ensoberbar",
    "ensoberbasse": "ensoberbar",
    "ensoberbassem": "ensoberbar",
    "ensoberbasses": "ensoberbar",
    "ensoberbaste": "ensoberbar",
    "ensoberbastes": "ensoberbar",
    "ensoberbava": "ensoberbar",
    "ensoberbavam": "ensoberbar",
    "ensoberbavas": "ensoberbar",
    "ensoberbe": "ensoberbar",
    "ensoberbece": "ensoberbecer",
    "ensoberbecei": "ensoberbecer",
    "ensoberbeceis": "ensoberbecer",
    "ensoberbecem": "ensoberbecer",
    "ensoberbecemo": "ensoberbecer",
    "ensoberbecemos": "ensoberbecer",
    "ensoberbecendo": "ensoberbecer",
    "ensoberbecera": "ensoberbecer",
    "ensoberbeceram": "ensoberbecer",
    "ensoberbeceras": "ensoberbecer",
    "ensoberbecerde": "ensoberbecer",
    "ensoberbecerdes": "ensoberbecer",
    "ensoberbecere": "ensoberbecer",
    "ensoberbecerei": "ensoberbecer",
    "ensoberbecereis": "ensoberbecer",
    "ensoberbecerem": "ensoberbecer",
    "ensoberbeceremos": "ensoberbecer",
    "ensoberbeceres": "ensoberbecer",
    "ensoberbeceria": "ensoberbecer",
    "ensoberbeceriam": "ensoberbecer",
    "ensoberbecerias": "ensoberbecer",
    "ensoberbecermo": "ensoberbecer",
    "ensoberbecermos": "ensoberbecer",
    "ensoberbecerá": "ensoberbecer",
    "ensoberbecerás": "ensoberbecer",
    "ensoberbecerão": "ensoberbecer",
    "ensoberbeceríamos": "ensoberbecer",
    "ensoberbeceríeis": "ensoberbecer",
    "ensoberbeces": "ensoberbecer",
    "ensoberbecesse": "ensoberbecer",
    "ensoberbecessem": "ensoberbecer",
    "ensoberbecesses": "ensoberbecer",
    "ensoberbeceste": "ensoberbecer",
    "ensoberbecestes": "ensoberbecer",
    "ensoberbeceu": "ensoberbecer",
    "ensoberbeci": "ensoberbecer",
    "ensoberbecia": "ensoberbecer",
    "ensoberbeciam": "ensoberbecer",
    "ensoberbecias": "ensoberbecer",
    "ensoberbecida": "ensoberbecido",
    "ensoberbecidas": "ensoberbecido",
    "ensoberbecido": "ensoberbecer",
    "ensoberbecidos": "ensoberbecido",
    "ensoberbecimentos": "ensoberbecimento",
    "ensoberbecê": "ensoberbecer",
    "ensoberbecêramo": "ensoberbecer",
    "ensoberbecêramos": "ensoberbecer",
    "ensoberbecêrei": "ensoberbecer",
    "ensoberbecêreis": "ensoberbecer",
    "ensoberbecêsseis": "ensoberbecer",
    "ensoberbecêssemos": "ensoberbecer",
    "ensoberbecíamo": "ensoberbecer",
    "ensoberbecíamos": "ensoberbecer",
    "ensoberbecíei": "ensoberbecer",
    "ensoberbecíeis": "ensoberbecer",
    "ensoberbei": "ensoberbar",
    "ensoberbeis": "ensoberbar",
    "ensoberbem": "ensoberbar",
    "ensoberbemo": "ensoberbar",
    "ensoberbemos": "ensoberbar",
    "ensoberbes": "ensoberbar",
    "ensoberbeça": "ensoberbecer",
    "ensoberbeçais": "ensoberbecer",
    "ensoberbeçam": "ensoberbecer",
    "ensoberbeçamo": "ensoberbecer",
    "ensoberbeçamos": "ensoberbecer",
    "ensoberbeças": "ensoberbecer",
    "ensoberbeço": "ensoberbecer",
    "ensoberbo": "ensoberbar",
    "ensoberbou": "ensoberbar",
    "ensoberbá": "ensoberbar",
    "ensoberbámo": "ensoberbar",
    "ensoberbámos": "ensoberbar",
    "ensoberbáramo": "ensoberbar",
    "ensoberbáramos": "ensoberbar",
    "ensoberbárei": "ensoberbar",
    "ensoberbáreis": "ensoberbar",
    "ensoberbásseis": "ensoberbar",
    "ensoberbássemos": "ensoberbar",
    "ensoberbávamo": "ensoberbar",
    "ensoberbávamos": "ensoberbar",
    "ensoberbávei": "ensoberbar",
    "ensoberbáveis": "ensoberbar",
    "ensobrada": "ensobradar",
    "ensobradada": "ensobradar",
    "ensobradadas": "ensobradar",
    "ensobradado": "ensobradar",
    "ensobradados": "ensobradar",
    "ensobradai": "ensobradar",
    "ensobradais": "ensobradar",
    "ensobradam": "ensobradar",
    "ensobradamo": "ensobradar",
    "ensobradamos": "ensobradar",
    "ensobradando": "ensobradar",
    "ensobradara": "ensobradar",
    "ensobradaram": "ensobradar",
    "ensobradaras": "ensobradar",
    "ensobradarde": "ensobradar",
    "ensobradardes": "ensobradar",
    "ensobradare": "ensobradar",
    "ensobradarei": "ensobradar",
    "ensobradareis": "ensobradar",
    "ensobradarem": "ensobradar",
    "ensobradaremos": "ensobradar",
    "ensobradares": "ensobradar",
    "ensobradaria": "ensobradar",
    "ensobradariam": "ensobradar",
    "ensobradarias": "ensobradar",
    "ensobradarmo": "ensobradar",
    "ensobradarmos": "ensobradar",
    "ensobradará": "ensobradar",
    "ensobradarás": "ensobradar",
    "ensobradarão": "ensobradar",
    "ensobradaríamos": "ensobradar",
    "ensobradaríeis": "ensobradar",
    "ensobradas": "ensobradar",
    "ensobradasse": "ensobradar",
    "ensobradassem": "ensobradar",
    "ensobradasses": "ensobradar",
    "ensobradaste": "ensobradar",
    "ensobradastes": "ensobradar",
    "ensobradava": "ensobradar",
    "ensobradavam": "ensobradar",
    "ensobradavas": "ensobradar",
    "ensobrade": "ensobradar",
    "ensobradei": "ensobradar",
    "ensobradeis": "ensobradar",
    "ensobradem": "ensobradar",
    "ensobrademo": "ensobradar",
    "ensobrademos": "ensobradar",
    "ensobrades": "ensobradar",
    "ensobrado": "ensobradar",
    "ensobradou": "ensobradar",
    "ensobradá": "ensobradar",
    "ensobradámo": "ensobradar",
    "ensobradámos": "ensobradar",
    "ensobradáramo": "ensobradar",
    "ensobradáramos": "ensobradar",
    "ensobradárei": "ensobradar",
    "ensobradáreis": "ensobradar",
    "ensobradásseis": "ensobradar",
    "ensobradássemos": "ensobradar",
    "ensobradávamo": "ensobradar",
    "ensobradávamos": "ensobradar",
    "ensobradávei": "ensobradar",
    "ensobradáveis": "ensobradar",
    "ensoe": "ensoar",
    "ensoei": "ensoar",
    "ensoeis": "ensoar",
    "ensoem": "ensoar",
    "ensoemo": "ensoar",
    "ensoemos": "ensoar",
    "ensoes": "ensoar",
    "ensofrega": "ensofregar",
    "ensofregada": "ensofregar",
    "ensofregadas": "ensofregar",
    "ensofregado": "ensofregar",
    "ensofregados": "ensofregar",
    "ensofregai": "ensofregar",
    "ensofregais": "ensofregar",
    "ensofregam": "ensofregar",
    "ensofregamo": "ensofregar",
    "ensofregamos": "ensofregar",
    "ensofregando": "ensofregar",
    "ensofregara": "ensofregar",
    "ensofregaram": "ensofregar",
    "ensofregaras": "ensofregar",
    "ensofregarde": "ensofregar",
    "ensofregardes": "ensofregar",
    "ensofregare": "ensofregar",
    "ensofregarei": "ensofregar",
    "ensofregareis": "ensofregar",
    "ensofregarem": "ensofregar",
    "ensofregaremos": "ensofregar",
    "ensofregares": "ensofregar",
    "ensofregaria": "ensofregar",
    "ensofregariam": "ensofregar",
    "ensofregarias": "ensofregar",
    "ensofregarmo": "ensofregar",
    "ensofregarmos": "ensofregar",
    "ensofregará": "ensofregar",
    "ensofregarás": "ensofregar",
    "ensofregarão": "ensofregar",
    "ensofregaríamos": "ensofregar",
    "ensofregaríeis": "ensofregar",
    "ensofregas": "ensofregar",
    "ensofregasse": "ensofregar",
    "ensofregassem": "ensofregar",
    "ensofregasses": "ensofregar",
    "ensofregaste": "ensofregar",
    "ensofregastes": "ensofregar",
    "ensofregava": "ensofregar",
    "ensofregavam": "ensofregar",
    "ensofregavas": "ensofregar",
    "ensofrego": "ensofregar",
    "ensofregou": "ensofregar",
    "ensofregue": "ensofregar",
    "ensofreguei": "ensofregar",
    "ensofregueis": "ensofregar",
    "ensofreguem": "ensofregar",
    "ensofreguemo": "ensofregar",
    "ensofreguemos": "ensofregar",
    "ensofregues": "ensofregar",
    "ensofregá": "ensofregar",
    "ensofregámo": "ensofregar",
    "ensofregámos": "ensofregar",
    "ensofregáramo": "ensofregar",
    "ensofregáramos": "ensofregar",
    "ensofregárei": "ensofregar",
    "ensofregáreis": "ensofregar",
    "ensofregásseis": "ensofregar",
    "ensofregássemos": "ensofregar",
    "ensofregávamo": "ensofregar",
    "ensofregávamos": "ensofregar",
    "ensofregávei": "ensofregar",
    "ensofregáveis": "ensofregar",
    "ensoga": "ensogar",
    "ensogada": "ensogar",
    "ensogadas": "ensogar",
    "ensogado": "ensogar",
    "ensogadoiros": "ensogadoiro",
    "ensogados": "ensogar",
    "ensogadouros": "ensogadouro",
    "ensogaduras": "ensogadura",
    "ensogai": "ensogar",
    "ensogais": "ensogar",
    "ensogam": "ensogar",
    "ensogamo": "ensogar",
    "ensogamos": "ensogar",
    "ensogando": "ensogar",
    "ensogara": "ensogar",
    "ensogaram": "ensogar",
    "ensogaras": "ensogar",
    "ensogarde": "ensogar",
    "ensogardes": "ensogar",
    "ensogare": "ensogar",
    "ensogarei": "ensogar",
    "ensogareis": "ensogar",
    "ensogarem": "ensogar",
    "ensogaremos": "ensogar",
    "ensogares": "ensogar",
    "ensogaria": "ensogar",
    "ensogariam": "ensogar",
    "ensogarias": "ensogar",
    "ensogarmo": "ensogar",
    "ensogarmos": "ensogar",
    "ensogará": "ensogar",
    "ensogarás": "ensogar",
    "ensogarão": "ensogar",
    "ensogaríamos": "ensogar",
    "ensogaríeis": "ensogar",
    "ensogas": "ensogar",
    "ensogasse": "ensogar",
    "ensogassem": "ensogar",
    "ensogasses": "ensogar",
    "ensogaste": "ensogar",
    "ensogastes": "ensogar",
    "ensogava": "ensogar",
    "ensogavam": "ensogar",
    "ensogavas": "ensogar",
    "ensogo": "ensogar",
    "ensogou": "ensogar",
    "ensogue": "ensogar",
    "ensoguei": "ensogar",
    "ensogueis": "ensogar",
    "ensoguem": "ensogar",
    "ensoguemo": "ensogar",
    "ensoguemos": "ensogar",
    "ensogues": "ensogar",
    "ensogá": "ensogar",
    "ensogámo": "ensogar",
    "ensogámos": "ensogar",
    "ensogáramo": "ensogar",
    "ensogáramos": "ensogar",
    "ensogárei": "ensogar",
    "ensogáreis": "ensogar",
    "ensogásseis": "ensogar",
    "ensogássemos": "ensogar",
    "ensogávamo": "ensogar",
    "ensogávamos": "ensogar",
    "ensogávei": "ensogar",
    "ensogáveis": "ensogar",
    "ensoissa": "ensoissar",
    "ensoissada": "ensoissar",
    "ensoissadas": "ensoissar",
    "ensoissado": "ensoissar",
    "ensoissados": "ensoissar",
    "ensoissai": "ensoissar",
    "ensoissais": "ensoissar",
    "ensoissam": "ensoissar",
    "ensoissamo": "ensoissar",
    "ensoissamos": "ensoissar",
    "ensoissando": "ensoissar",
    "ensoissara": "ensoissar",
    "ensoissaram": "ensoissar",
    "ensoissaras": "ensoissar",
    "ensoissarde": "ensoissar",
    "ensoissardes": "ensoissar",
    "ensoissare": "ensoissar",
    "ensoissarei": "ensoissar",
    "ensoissareis": "ensoissar",
    "ensoissarem": "ensoissar",
    "ensoissaremos": "ensoissar",
    "ensoissares": "ensoissar",
    "ensoissaria": "ensoissar",
    "ensoissariam": "ensoissar",
    "ensoissarias": "ensoissar",
    "ensoissarmo": "ensoissar",
    "ensoissarmos": "ensoissar",
    "ensoissará": "ensoissar",
    "ensoissarás": "ensoissar",
    "ensoissarão": "ensoissar",
    "ensoissaríamos": "ensoissar",
    "ensoissaríeis": "ensoissar",
    "ensoissas": "ensoissar",
    "ensoissasse": "ensoissar",
    "ensoissassem": "ensoissar",
    "ensoissasses": "ensoissar",
    "ensoissaste": "ensoissar",
    "ensoissastes": "ensoissar",
    "ensoissava": "ensoissar",
    "ensoissavam": "ensoissar",
    "ensoissavas": "ensoissar",
    "ensoisse": "ensoissar",
    "ensoissei": "ensoissar",
    "ensoisseis": "ensoissar",
    "ensoissem": "ensoissar",
    "ensoissemo": "ensoissar",
    "ensoissemos": "ensoissar",
    "ensoisses": "ensoissar",
    "ensoisso": "ensoissar",
    "ensoissou": "ensoissar",
    "ensoissá": "ensoissar",
    "ensoissámo": "ensoissar",
    "ensoissámos": "ensoissar",
    "ensoissáramo": "ensoissar",
    "ensoissáramos": "ensoissar",
    "ensoissárei": "ensoissar",
    "ensoissáreis": "ensoissar",
    "ensoissásseis": "ensoissar",
    "ensoissássemos": "ensoissar",
    "ensoissávamo": "ensoissar",
    "ensoissávamos": "ensoissar",
    "ensoissávei": "ensoissar",
    "ensoissáveis": "ensoissar",
    "ensolarada": "ensolarado",
    "ensolaradas": "ensolarado",
    "ensolarados": "ensolarado",
    "ensoleira": "ensoleirar",
    "ensoleirada": "ensoleirar",
    "ensoleiradas": "ensoleirar",
    "ensoleirado": "ensoleirar",
    "ensoleirados": "ensoleirar",
    "ensoleirai": "ensoleirar",
    "ensoleirais": "ensoleirar",
    "ensoleiram": "ensoleirar",
    "ensoleiramentos": "ensoleiramento",
    "ensoleiramo": "ensoleirar",
    "ensoleiramos": "ensoleirar",
    "ensoleirando": "ensoleirar",
    "ensoleirara": "ensoleirar",
    "ensoleiraram": "ensoleirar",
    "ensoleiraras": "ensoleirar",
    "ensoleirarde": "ensoleirar",
    "ensoleirardes": "ensoleirar",
    "ensoleirare": "ensoleirar",
    "ensoleirarei": "ensoleirar",
    "ensoleirareis": "ensoleirar",
    "ensoleirarem": "ensoleirar",
    "ensoleiraremos": "ensoleirar",
    "ensoleirares": "ensoleirar",
    "ensoleiraria": "ensoleirar",
    "ensoleirariam": "ensoleirar",
    "ensoleirarias": "ensoleirar",
    "ensoleirarmo": "ensoleirar",
    "ensoleirarmos": "ensoleirar",
    "ensoleirará": "ensoleirar",
    "ensoleirarás": "ensoleirar",
    "ensoleirarão": "ensoleirar",
    "ensoleiraríamos": "ensoleirar",
    "ensoleiraríeis": "ensoleirar",
    "ensoleiras": "ensoleirar",
    "ensoleirasse": "ensoleirar",
    "ensoleirassem": "ensoleirar",
    "ensoleirasses": "ensoleirar",
    "ensoleiraste": "ensoleirar",
    "ensoleirastes": "ensoleirar",
    "ensoleirava": "ensoleirar",
    "ensoleiravam": "ensoleirar",
    "ensoleiravas": "ensoleirar",
    "ensoleire": "ensoleirar",
    "ensoleirei": "ensoleirar",
    "ensoleireis": "ensoleirar",
    "ensoleirem": "ensoleirar",
    "ensoleiremo": "ensoleirar",
    "ensoleiremos": "ensoleirar",
    "ensoleires": "ensoleirar",
    "ensoleiro": "ensoleirar",
    "ensoleirou": "ensoleirar",
    "ensoleirá": "ensoleirar",
    "ensoleirámo": "ensoleirar",
    "ensoleirámos": "ensoleirar",
    "ensoleiráramo": "ensoleirar",
    "ensoleiráramos": "ensoleirar",
    "ensoleirárei": "ensoleirar",
    "ensoleiráreis": "ensoleirar",
    "ensoleirásseis": "ensoleirar",
    "ensoleirássemos": "ensoleirar",
    "ensoleirávamo": "ensoleirar",
    "ensoleirávamos": "ensoleirar",
    "ensoleirávei": "ensoleirar",
    "ensoleiráveis": "ensoleirar",
    "ensolva": "ensolvar",
    "ensolvada": "ensolvar",
    "ensolvadas": "ensolvar",
    "ensolvado": "ensolvar",
    "ensolvados": "ensolvar",
    "ensolvai": "ensolvar",
    "ensolvais": "ensolvar",
    "ensolvam": "ensolvar",
    "ensolvamentos": "ensolvamento",
    "ensolvamo": "ensolvar",
    "ensolvamos": "ensolvar",
    "ensolvando": "ensolvar",
    "ensolvara": "ensolvar",
    "ensolvaram": "ensolvar",
    "ensolvaras": "ensolvar",
    "ensolvarde": "ensolvar",
    "ensolvardes": "ensolvar",
    "ensolvare": "ensolvar",
    "ensolvarei": "ensolvar",
    "ensolvareis": "ensolvar",
    "ensolvarem": "ensolvar",
    "ensolvaremos": "ensolvar",
    "ensolvares": "ensolvar",
    "ensolvaria": "ensolvar",
    "ensolvariam": "ensolvar",
    "ensolvarias": "ensolvar",
    "ensolvarmo": "ensolvar",
    "ensolvarmos": "ensolvar",
    "ensolvará": "ensolvar",
    "ensolvarás": "ensolvar",
    "ensolvarão": "ensolvar",
    "ensolvaríamos": "ensolvar",
    "ensolvaríeis": "ensolvar",
    "ensolvas": "ensolvar",
    "ensolvasse": "ensolvar",
    "ensolvassem": "ensolvar",
    "ensolvasses": "ensolvar",
    "ensolvaste": "ensolvar",
    "ensolvastes": "ensolvar",
    "ensolvava": "ensolvar",
    "ensolvavam": "ensolvar",
    "ensolvavas": "ensolvar",
    "ensolve": "ensolvar",
    "ensolvei": "ensolvar",
    "ensolveis": "ensolvar",
    "ensolvem": "ensolvar",
    "ensolvemo": "ensolvar",
    "ensolvemos": "ensolvar",
    "ensolves": "ensolvar",
    "ensolvo": "ensolvar",
    "ensolvou": "ensolvar",
    "ensolvá": "ensolvar",
    "ensolvámo": "ensolvar",
    "ensolvámos": "ensolvar",
    "ensolváramo": "ensolvar",
    "ensolváramos": "ensolvar",
    "ensolvárei": "ensolvar",
    "ensolváreis": "ensolvar",
    "ensolvásseis": "ensolvar",
    "ensolvássemos": "ensolvar",
    "ensolvávamo": "ensolvar",
    "ensolvávamos": "ensolvar",
    "ensolvávei": "ensolvar",
    "ensolváveis": "ensolvar",
    "ensombra": "ensombrar",
    "ensombrada": "ensombrar",
    "ensombradas": "ensombrar",
    "ensombrado": "ensombrar",
    "ensombrados": "ensombrar",
    "ensombrai": "ensombrar",
    "ensombrais": "ensombrar",
    "ensombram": "ensombrar",
    "ensombramentos": "ensombramento",
    "ensombramo": "ensombrar",
    "ensombramos": "ensombrar",
    "ensombrando": "ensombrar",
    "ensombrara": "ensombrar",
    "ensombraram": "ensombrar",
    "ensombraras": "ensombrar",
    "ensombrarde": "ensombrar",
    "ensombrardes": "ensombrar",
    "ensombrare": "ensombrar",
    "ensombrarei": "ensombrar",
    "ensombrareis": "ensombrar",
    "ensombrarem": "ensombrar",
    "ensombraremos": "ensombrar",
    "ensombrares": "ensombrar",
    "ensombraria": "ensombrar",
    "ensombrariam": "ensombrar",
    "ensombrarias": "ensombrar",
    "ensombrarmo": "ensombrar",
    "ensombrarmos": "ensombrar",
    "ensombrará": "ensombrar",
    "ensombrarás": "ensombrar",
    "ensombrarão": "ensombrar",
    "ensombraríamos": "ensombrar",
    "ensombraríeis": "ensombrar",
    "ensombras": "ensombrar",
    "ensombrasse": "ensombrar",
    "ensombrassem": "ensombrar",
    "ensombrasses": "ensombrar",
    "ensombraste": "ensombrar",
    "ensombrastes": "ensombrar",
    "ensombrava": "ensombrar",
    "ensombravam": "ensombrar",
    "ensombravas": "ensombrar",
    "ensombre": "ensombrar",
    "ensombrei": "ensombrar",
    "ensombreis": "ensombrar",
    "ensombrem": "ensombrar",
    "ensombremo": "ensombrar",
    "ensombremos": "ensombrar",
    "ensombres": "ensombrar",
    "ensombro": "ensombrar",
    "ensombros": "ensombro",
    "ensombrou": "ensombrar",
    "ensombrá": "ensombrar",
    "ensombrámo": "ensombrar",
    "ensombrámos": "ensombrar",
    "ensombráramo": "ensombrar",
    "ensombráramos": "ensombrar",
    "ensombrárei": "ensombrar",
    "ensombráreis": "ensombrar",
    "ensombrásseis": "ensombrar",
    "ensombrássemos": "ensombrar",
    "ensombrávamo": "ensombrar",
    "ensombrávamos": "ensombrar",
    "ensombrávei": "ensombrar",
    "ensombráveis": "ensombrar",
    "ensonada": "ensonado",
    "ensonadas": "ensonado",
    "ensonados": "ensonado",
    "ensonorentada": "ensonorentado",
    "ensonorentadas": "ensonorentado",
    "ensonorentados": "ensonorentado",
    "ensoo": "ensoar",
    "ensoou": "ensoar",
    "ensopa": "ensopar",
    "ensopada": "ensopar",
    "ensopadas": "ensopar",
    "ensopadinhos": "ensopadinho",
    "ensopado": "ensopar",
    "ensopados": "ensopar",
    "ensopadíssima": "ensopado",
    "ensopadíssimas": "ensopado",
    "ensopadíssimo": "ensopado",
    "ensopadíssimos": "ensopado",
    "ensopai": "ensopar",
    "ensopais": "ensopar",
    "ensopam": "ensopar",
    "ensopamo": "ensopar",
    "ensopamos": "ensopar",
    "ensopando": "ensopar",
    "ensopara": "ensopar",
    "ensoparam": "ensopar",
    "ensoparas": "ensopar",
    "ensoparde": "ensopar",
    "ensopardes": "ensopar",
    "ensopare": "ensopar",
    "ensoparei": "ensopar",
    "ensopareis": "ensopar",
    "ensoparem": "ensopar",
    "ensoparemos": "ensopar",
    "ensopares": "ensopar",
    "ensoparia": "ensopar",
    "ensopariam": "ensopar",
    "ensoparias": "ensopar",
    "ensoparmo": "ensopar",
    "ensoparmos": "ensopar",
    "ensopará": "ensopar",
    "ensoparás": "ensopar",
    "ensoparão": "ensopar",
    "ensoparíamos": "ensopar",
    "ensoparíeis": "ensopar",
    "ensopas": "ensopar",
    "ensopasse": "ensopar",
    "ensopassem": "ensopar",
    "ensopasses": "ensopar",
    "ensopaste": "ensopar",
    "ensopastes": "ensopar",
    "ensopava": "ensopar",
    "ensopavam": "ensopar",
    "ensopavas": "ensopar",
    "ensope": "ensopar",
    "ensopeada": "ensopear",
    "ensopeadas": "ensopear",
    "ensopeado": "ensopear",
    "ensopeados": "ensopear",
    "ensopeai": "ensopear",
    "ensopeais": "ensopear",
    "ensopeamo": "ensopear",
    "ensopeamos": "ensopear",
    "ensopeando": "ensopear",
    "ensopeara": "ensopear",
    "ensopearam": "ensopear",
    "ensopearas": "ensopear",
    "ensopearde": "ensopear",
    "ensopeardes": "ensopear",
    "ensopeare": "ensopear",
    "ensopearei": "ensopear",
    "ensopeareis": "ensopear",
    "ensopearem": "ensopear",
    "ensopearemos": "ensopear",
    "ensopeares": "ensopear",
    "ensopearia": "ensopear",
    "ensopeariam": "ensopear",
    "ensopearias": "ensopear",
    "ensopearmo": "ensopear",
    "ensopearmos": "ensopear",
    "ensopeará": "ensopear",
    "ensopearás": "ensopear",
    "ensopearão": "ensopear",
    "ensopearíamos": "ensopear",
    "ensopearíeis": "ensopear",
    "ensopeasse": "ensopear",
    "ensopeassem": "ensopear",
    "ensopeasses": "ensopear",
    "ensopeaste": "ensopear",
    "ensopeastes": "ensopear",
    "ensopeava": "ensopear",
    "ensopeavam": "ensopear",
    "ensopeavas": "ensopear",
    "ensopeei": "ensopear",
    "ensopeeis": "ensopear",
    "ensopeemo": "ensopear",
    "ensopeemos": "ensopear",
    "ensopei": "ensopar",
    "ensopeia": "ensopear",
    "ensopeiam": "ensopear",
    "ensopeias": "ensopear",
    "ensopeie": "ensopear",
    "ensopeiem": "ensopear",
    "ensopeies": "ensopear",
    "ensopeio": "ensopear",
    "ensopeis": "ensopar",
    "ensopem": "ensopar",
    "ensopemo": "ensopar",
    "ensopemos": "ensopar",
    "ensopeou": "ensopear",
    "ensopes": "ensopar",
    "ensopeá": "ensopear",
    "ensopeámo": "ensopear",
    "ensopeámos": "ensopear",
    "ensopeáramo": "ensopear",
    "ensopeáramos": "ensopear",
    "ensopeárei": "ensopear",
    "ensopeáreis": "ensopear",
    "ensopeásseis": "ensopear",
    "ensopeássemos": "ensopear",
    "ensopeávamo": "ensopear",
    "ensopeávamos": "ensopear",
    "ensopeávei": "ensopear",
    "ensopeáveis": "ensopear",
    "ensopo": "ensopar",
    "ensopou": "ensopar",
    "ensopá": "ensopar",
    "ensopámo": "ensopar",
    "ensopámos": "ensopar",
    "ensopáramo": "ensopar",
    "ensopáramos": "ensopar",
    "ensopárei": "ensopar",
    "ensopáreis": "ensopar",
    "ensopásseis": "ensopar",
    "ensopássemos": "ensopar",
    "ensopávamo": "ensopar",
    "ensopávamos": "ensopar",
    "ensopávei": "ensopar",
    "ensopáveis": "ensopar",
    "ensoreada": "ensorear",
    "ensoreadas": "ensorear",
    "ensoreado": "ensorear",
    "ensoreados": "ensorear",
    "ensoreai": "ensorear",
    "ensoreais": "ensorear",
    "ensoreamentos": "ensoreamento",
    "ensoreamo": "ensorear",
    "ensoreamos": "ensorear",
    "ensoreando": "ensorear",
    "ensoreara": "ensorear",
    "ensorearam": "ensorear",
    "ensorearas": "ensorear",
    "ensorearde": "ensorear",
    "ensoreardes": "ensorear",
    "ensoreare": "ensorear",
    "ensorearei": "ensorear",
    "ensoreareis": "ensorear",
    "ensorearem": "ensorear",
    "ensorearemos": "ensorear",
    "ensoreares": "ensorear",
    "ensorearia": "ensorear",
    "ensoreariam": "ensorear",
    "ensorearias": "ensorear",
    "ensorearmo": "ensorear",
    "ensorearmos": "ensorear",
    "ensoreará": "ensorear",
    "ensorearás": "ensorear",
    "ensorearão": "ensorear",
    "ensorearíamos": "ensorear",
    "ensorearíeis": "ensorear",
    "ensoreasse": "ensorear",
    "ensoreassem": "ensorear",
    "ensoreasses": "ensorear",
    "ensoreaste": "ensorear",
    "ensoreastes": "ensorear",
    "ensoreava": "ensorear",
    "ensoreavam": "ensorear",
    "ensoreavas": "ensorear",
    "ensoreei": "ensorear",
    "ensoreeis": "ensorear",
    "ensoreemo": "ensorear",
    "ensoreemos": "ensorear",
    "ensoreia": "ensorear",
    "ensoreiam": "ensorear",
    "ensoreias": "ensorear",
    "ensoreie": "ensorear",
    "ensoreiem": "ensorear",
    "ensoreies": "ensorear",
    "ensoreio": "ensorear",
    "ensoreou": "ensorear",
    "ensoreá": "ensorear",
    "ensoreámo": "ensorear",
    "ensoreámos": "ensorear",
    "ensoreáramo": "ensorear",
    "ensoreáramos": "ensorear",
    "ensoreárei": "ensorear",
    "ensoreáreis": "ensorear",
    "ensoreásseis": "ensorear",
    "ensoreássemos": "ensorear",
    "ensoreávamo": "ensorear",
    "ensoreávamos": "ensorear",
    "ensoreávei": "ensorear",
    "ensoreáveis": "ensorear",
    "ensossa": "ensosso",
    "ensossas": "ensosso",
    "ensossos": "ensosso",
    "ensovaca": "ensovacar",
    "ensovacada": "ensovacar",
    "ensovacadas": "ensovacar",
    "ensovacado": "ensovacar",
    "ensovacados": "ensovacar",
    "ensovacai": "ensovacar",
    "ensovacais": "ensovacar",
    "ensovacam": "ensovacar",
    "ensovacamo": "ensovacar",
    "ensovacamos": "ensovacar",
    "ensovacando": "ensovacar",
    "ensovacara": "ensovacar",
    "ensovacaram": "ensovacar",
    "ensovacaras": "ensovacar",
    "ensovacarde": "ensovacar",
    "ensovacardes": "ensovacar",
    "ensovacare": "ensovacar",
    "ensovacarei": "ensovacar",
    "ensovacareis": "ensovacar",
    "ensovacarem": "ensovacar",
    "ensovacaremos": "ensovacar",
    "ensovacares": "ensovacar",
    "ensovacaria": "ensovacar",
    "ensovacariam": "ensovacar",
    "ensovacarias": "ensovacar",
    "ensovacarmo": "ensovacar",
    "ensovacarmos": "ensovacar",
    "ensovacará": "ensovacar",
    "ensovacarás": "ensovacar",
    "ensovacarão": "ensovacar",
    "ensovacaríamos": "ensovacar",
    "ensovacaríeis": "ensovacar",
    "ensovacas": "ensovacar",
    "ensovacasse": "ensovacar",
    "ensovacassem": "ensovacar",
    "ensovacasses": "ensovacar",
    "ensovacaste": "ensovacar",
    "ensovacastes": "ensovacar",
    "ensovacava": "ensovacar",
    "ensovacavam": "ensovacar",
    "ensovacavas": "ensovacar",
    "ensovaco": "ensovacar",
    "ensovacou": "ensovacar",
    "ensovacá": "ensovacar",
    "ensovacámo": "ensovacar",
    "ensovacámos": "ensovacar",
    "ensovacáramo": "ensovacar",
    "ensovacáramos": "ensovacar",
    "ensovacárei": "ensovacar",
    "ensovacáreis": "ensovacar",
    "ensovacásseis": "ensovacar",
    "ensovacássemos": "ensovacar",
    "ensovacávamo": "ensovacar",
    "ensovacávamos": "ensovacar",
    "ensovacávei": "ensovacar",
    "ensovacáveis": "ensovacar",
    "ensovaque": "ensovacar",
    "ensovaquei": "ensovacar",
    "ensovaqueis": "ensovacar",
    "ensovaquem": "ensovacar",
    "ensovaquemo": "ensovacar",
    "ensovaquemos": "ensovacar",
    "ensovaques": "ensovacar",
    "ensoámo": "ensoar",
    "ensoámos": "ensoar",
    "ensoáramo": "ensoar",
    "ensoáramos": "ensoar",
    "ensoáreis": "ensoar",
    "ensoásseis": "ensoar",
    "ensoássemos": "ensoar",
    "ensoávamo": "ensoar",
    "ensoávamos": "ensoar",
    "ensoáveis": "ensoar",
    "enstatites": "enstatite",
    "enstatítica": "enstatítico",
    "enstatíticas": "enstatítico",
    "enstatíticos": "enstatítico",
    "ensumagra": "ensumagrar",
    "ensumagrada": "ensumagrar",
    "ensumagradas": "ensumagrar",
    "ensumagrado": "ensumagrar",
    "ensumagrados": "ensumagrar",
    "ensumagrai": "ensumagrar",
    "ensumagrais": "ensumagrar",
    "ensumagram": "ensumagrar",
    "ensumagramo": "ensumagrar",
    "ensumagramos": "ensumagrar",
    "ensumagrando": "ensumagrar",
    "ensumagrara": "ensumagrar",
    "ensumagraram": "ensumagrar",
    "ensumagraras": "ensumagrar",
    "ensumagrarde": "ensumagrar",
    "ensumagrardes": "ensumagrar",
    "ensumagrare": "ensumagrar",
    "ensumagrarei": "ensumagrar",
    "ensumagrareis": "ensumagrar",
    "ensumagrarem": "ensumagrar",
    "ensumagraremos": "ensumagrar",
    "ensumagrares": "ensumagrar",
    "ensumagraria": "ensumagrar",
    "ensumagrariam": "ensumagrar",
    "ensumagrarias": "ensumagrar",
    "ensumagrarmo": "ensumagrar",
    "ensumagrarmos": "ensumagrar",
    "ensumagrará": "ensumagrar",
    "ensumagrarás": "ensumagrar",
    "ensumagrarão": "ensumagrar",
    "ensumagraríamos": "ensumagrar",
    "ensumagraríeis": "ensumagrar",
    "ensumagras": "ensumagrar",
    "ensumagrasse": "ensumagrar",
    "ensumagrassem": "ensumagrar",
    "ensumagrasses": "ensumagrar",
    "ensumagraste": "ensumagrar",
    "ensumagrastes": "ensumagrar",
    "ensumagrava": "ensumagrar",
    "ensumagravam": "ensumagrar",
    "ensumagravas": "ensumagrar",
    "ensumagre": "ensumagrar",
    "ensumagrei": "ensumagrar",
    "ensumagreis": "ensumagrar",
    "ensumagrem": "ensumagrar",
    "ensumagremo": "ensumagrar",
    "ensumagremos": "ensumagrar",
    "ensumagres": "ensumagrar",
    "ensumagro": "ensumagrar",
    "ensumagrou": "ensumagrar",
    "ensumagrá": "ensumagrar",
    "ensumagrámo": "ensumagrar",
    "ensumagrámos": "ensumagrar",
    "ensumagráramo": "ensumagrar",
    "ensumagráramos": "ensumagrar",
    "ensumagrárei": "ensumagrar",
    "ensumagráreis": "ensumagrar",
    "ensumagrásseis": "ensumagrar",
    "ensumagrássemos": "ensumagrar",
    "ensumagrávamo": "ensumagrar",
    "ensumagrávamos": "ensumagrar",
    "ensumagrávei": "ensumagrar",
    "ensumagráveis": "ensumagrar",
    "ensurdece": "ensurdecer",
    "ensurdecedora": "ensurdecedor",
    "ensurdecedoras": "ensurdecedor",
    "ensurdecedores": "ensurdecedor",
    "ensurdecei": "ensurdecer",
    "ensurdeceis": "ensurdecer",
    "ensurdecem": "ensurdecer",
    "ensurdecemo": "ensurdecer",
    "ensurdecemos": "ensurdecer",
    "ensurdecendo": "ensurdecer",
    "ensurdecentes": "ensurdecente",
    "ensurdecera": "ensurdecer",
    "ensurdeceram": "ensurdecer",
    "ensurdeceras": "ensurdecer",
    "ensurdecerde": "ensurdecer",
    "ensurdecerdes": "ensurdecer",
    "ensurdecere": "ensurdecer",
    "ensurdecerei": "ensurdecer",
    "ensurdecereis": "ensurdecer",
    "ensurdecerem": "ensurdecer",
    "ensurdeceremos": "ensurdecer",
    "ensurdeceres": "ensurdecer",
    "ensurdeceria": "ensurdecer",
    "ensurdeceriam": "ensurdecer",
    "ensurdecerias": "ensurdecer",
    "ensurdecermo": "ensurdecer",
    "ensurdecermos": "ensurdecer",
    "ensurdecerá": "ensurdecer",
    "ensurdecerás": "ensurdecer",
    "ensurdecerão": "ensurdecer",
    "ensurdeceríamos": "ensurdecer",
    "ensurdeceríeis": "ensurdecer",
    "ensurdeces": "ensurdecer",
    "ensurdecesse": "ensurdecer",
    "ensurdecessem": "ensurdecer",
    "ensurdecesses": "ensurdecer",
    "ensurdeceste": "ensurdecer",
    "ensurdecestes": "ensurdecer",
    "ensurdeceu": "ensurdecer",
    "ensurdeci": "ensurdecer",
    "ensurdecia": "ensurdecer",
    "ensurdeciam": "ensurdecer",
    "ensurdecias": "ensurdecer",
    "ensurdecida": "ensurdecido",
    "ensurdecidas": "ensurdecido",
    "ensurdecido": "ensurdecer",
    "ensurdecidos": "ensurdecido",
    "ensurdecimentos": "ensurdecimento",
    "ensurdecê": "ensurdecer",
    "ensurdecências": "ensurdecência",
    "ensurdecêramo": "ensurdecer",
    "ensurdecêramos": "ensurdecer",
    "ensurdecêrei": "ensurdecer",
    "ensurdecêreis": "ensurdecer",
    "ensurdecêsseis": "ensurdecer",
    "ensurdecêssemos": "ensurdecer",
    "ensurdecíamo": "ensurdecer",
    "ensurdecíamos": "ensurdecer",
    "ensurdecíei": "ensurdecer",
    "ensurdecíeis": "ensurdecer",
    "ensurdeça": "ensurdecer",
    "ensurdeçais": "ensurdecer",
    "ensurdeçam": "ensurdecer",
    "ensurdeçamo": "ensurdecer",
    "ensurdeçamos": "ensurdecer",
    "ensurdeças": "ensurdecer",
    "ensurdeço": "ensurdecer",
    "ensífera": "ensífero",
    "ensíferas": "ensífero",
    "ensíferos": "ensífero",
    "entablamentos": "entablamento",
    "entaboca": "entabocar",
    "entabocada": "entabocar",
    "entabocadas": "entabocar",
    "entabocado": "entabocar",
    "entabocados": "entabocar",
    "entabocai": "entabocar",
    "entabocais": "entabocar",
    "entabocam": "entabocar",
    "entabocamo": "entabocar",
    "entabocamos": "entabocar",
    "entabocando": "entabocar",
    "entabocara": "entabocar",
    "entabocaram": "entabocar",
    "entabocaras": "entabocar",
    "entabocarde": "entabocar",
    "entabocardes": "entabocar",
    "entabocare": "entabocar",
    "entabocarei": "entabocar",
    "entabocareis": "entabocar",
    "entabocarem": "entabocar",
    "entabocaremos": "entabocar",
    "entabocares": "entabocar",
    "entabocaria": "entabocar",
    "entabocariam": "entabocar",
    "entabocarias": "entabocar",
    "entabocarmo": "entabocar",
    "entabocarmos": "entabocar",
    "entabocará": "entabocar",
    "entabocarás": "entabocar",
    "entabocarão": "entabocar",
    "entabocaríamos": "entabocar",
    "entabocaríeis": "entabocar",
    "entabocas": "entabocar",
    "entabocasse": "entabocar",
    "entabocassem": "entabocar",
    "entabocasses": "entabocar",
    "entabocaste": "entabocar",
    "entabocastes": "entabocar",
    "entabocava": "entabocar",
    "entabocavam": "entabocar",
    "entabocavas": "entabocar",
    "entaboco": "entabocar",
    "entabocou": "entabocar",
    "entabocá": "entabocar",
    "entabocámo": "entabocar",
    "entabocámos": "entabocar",
    "entabocáramo": "entabocar",
    "entabocáramos": "entabocar",
    "entabocárei": "entabocar",
    "entabocáreis": "entabocar",
    "entabocásseis": "entabocar",
    "entabocássemos": "entabocar",
    "entabocávamo": "entabocar",
    "entabocávamos": "entabocar",
    "entabocávei": "entabocar",
    "entabocáveis": "entabocar",
    "entaboque": "entabocar",
    "entaboquei": "entabocar",
    "entaboqueis": "entabocar",
    "entaboquem": "entabocar",
    "entaboquemo": "entabocar",
    "entaboquemos": "entabocar",
    "entaboques": "entabocar",
    "entabua": "entabuar",
    "entabuada": "entabuar",
    "entabuadas": "entabuar",
    "entabuado": "entabuar",
    "entabuados": "entabuar",
    "entabuai": "entabuar",
    "entabuais": "entabuar",
    "entabuam": "entabuar",
    "entabuamentos": "entabuamento",
    "entabuamo": "entabuar",
    "entabuamos": "entabuar",
    "entabuando": "entabuar",
    "entabuara": "entabuar",
    "entabuaram": "entabuar",
    "entabuaras": "entabuar",
    "entabuarde": "entabuar",
    "entabuardes": "entabuar",
    "entabuare": "entabuar",
    "entabuarei": "entabuar",
    "entabuareis": "entabuar",
    "entabuarem": "entabuar",
    "entabuaremos": "entabuar",
    "entabuares": "entabuar",
    "entabuaria": "entabuar",
    "entabuariam": "entabuar",
    "entabuarias": "entabuar",
    "entabuarmo": "entabuar",
    "entabuarmos": "entabuar",
    "entabuará": "entabuar",
    "entabuarás": "entabuar",
    "entabuarão": "entabuar",
    "entabuaríamos": "entabuar",
    "entabuaríeis": "entabuar",
    "entabuas": "entabuar",
    "entabuasse": "entabuar",
    "entabuassem": "entabuar",
    "entabuasses": "entabuar",
    "entabuaste": "entabuar",
    "entabuastes": "entabuar",
    "entabuava": "entabuar",
    "entabuavam": "entabuar",
    "entabuavas": "entabuar",
    "entabue": "entabuar",
    "entabuei": "entabuar",
    "entabueis": "entabuar",
    "entabuem": "entabuar",
    "entabuemo": "entabuar",
    "entabuemos": "entabuar",
    "entabues": "entabuar",
    "entabula": "entabular",
    "entabulada": "entabular",
    "entabuladas": "entabular",
    "entabulado": "entabular",
    "entabulados": "entabular",
    "entabulai": "entabular",
    "entabulais": "entabular",
    "entabulam": "entabular",
    "entabulamentos": "entabulamento",
    "entabulamo": "entabular",
    "entabulamos": "entabular",
    "entabulando": "entabular",
    "entabulara": "entabular",
    "entabularam": "entabular",
    "entabularas": "entabular",
    "entabularde": "entabular",
    "entabulardes": "entabular",
    "entabulare": "entabular",
    "entabularei": "entabular",
    "entabulareis": "entabular",
    "entabularem": "entabular",
    "entabularemos": "entabular",
    "entabulares": "entabular",
    "entabularia": "entabular",
    "entabulariam": "entabular",
    "entabularias": "entabular",
    "entabularmo": "entabular",
    "entabularmos": "entabular",
    "entabulará": "entabular",
    "entabularás": "entabular",
    "entabularão": "entabular",
    "entabularíamos": "entabular",
    "entabularíeis": "entabular",
    "entabulas": "entabular",
    "entabulasse": "entabular",
    "entabulassem": "entabular",
    "entabulasses": "entabular",
    "entabulaste": "entabular",
    "entabulastes": "entabular",
    "entabulava": "entabular",
    "entabulavam": "entabular",
    "entabulavas": "entabular",
    "entabule": "entabular",
    "entabulei": "entabular",
    "entabuleis": "entabular",
    "entabulem": "entabular",
    "entabulemo": "entabular",
    "entabulemos": "entabular",
    "entabules": "entabular",
    "entabulo": "entabular",
    "entabulou": "entabular",
    "entabulá": "entabular",
    "entabulámo": "entabular",
    "entabulámos": "entabular",
    "entabuláramo": "entabular",
    "entabuláramos": "entabular",
    "entabulárei": "entabular",
    "entabuláreis": "entabular",
    "entabulásseis": "entabular",
    "entabulássemos": "entabular",
    "entabulávamo": "entabular",
    "entabulávamos": "entabular",
    "entabulávei": "entabular",
    "entabuláveis": "entabular",
    "entabuo": "entabuar",
    "entabuou": "entabuar",
    "entabuá": "entabuar",
    "entabuámo": "entabuar",
    "entabuámos": "entabuar",
    "entabuáramo": "entabuar",
    "entabuáramos": "entabuar",
    "entabuárei": "entabuar",
    "entabuáreis": "entabuar",
    "entabuásseis": "entabuar",
    "entabuássemos": "entabuar",
    "entabuávamo": "entabuar",
    "entabuávamos": "entabuar",
    "entabuávei": "entabuar",
    "entabuáveis": "entabuar",
    "entacha": "entachar",
    "entachada": "entachar",
    "entachadas": "entachar",
    "entachado": "entachar",
    "entachados": "entachar",
    "entachai": "entachar",
    "entachais": "entachar",
    "entacham": "entachar",
    "entachamo": "entachar",
    "entachamos": "entachar",
    "entachando": "entachar",
    "entachara": "entachar",
    "entacharam": "entachar",
    "entacharas": "entachar",
    "entacharde": "entachar",
    "entachardes": "entachar",
    "entachare": "entachar",
    "entacharei": "entachar",
    "entachareis": "entachar",
    "entacharem": "entachar",
    "entacharemos": "entachar",
    "entachares": "entachar",
    "entacharia": "entachar",
    "entachariam": "entachar",
    "entacharias": "entachar",
    "entacharmo": "entachar",
    "entacharmos": "entachar",
    "entachará": "entachar",
    "entacharás": "entachar",
    "entacharão": "entachar",
    "entacharíamos": "entachar",
    "entacharíeis": "entachar",
    "entachas": "entachar",
    "entachasse": "entachar",
    "entachassem": "entachar",
    "entachasses": "entachar",
    "entachaste": "entachar",
    "entachastes": "entachar",
    "entachava": "entachar",
    "entachavam": "entachar",
    "entachavas": "entachar",
    "entache": "entachar",
    "entachei": "entachar",
    "entacheis": "entachar",
    "entachem": "entachar",
    "entachemo": "entachar",
    "entachemos": "entachar",
    "entaches": "entachar",
    "entacho": "entachar",
    "entachou": "entachar",
    "entachá": "entachar",
    "entachámo": "entachar",
    "entachámos": "entachar",
    "entacháramo": "entachar",
    "entacháramos": "entachar",
    "entachárei": "entachar",
    "entacháreis": "entachar",
    "entachásseis": "entachar",
    "entachássemos": "entachar",
    "entachávamo": "entachar",
    "entachávamos": "entachar",
    "entachávei": "entachar",
    "entacháveis": "entachar",
    "entaipa": "entaipar",
    "entaipada": "entaipar",
    "entaipadas": "entaipar",
    "entaipado": "entaipar",
    "entaipados": "entaipar",
    "entaipagens": "entaipagem",
    "entaipai": "entaipar",
    "entaipais": "entaipar",
    "entaipam": "entaipar",
    "entaipamentos": "entaipamento",
    "entaipamo": "entaipar",
    "entaipamos": "entaipar",
    "entaipando": "entaipar",
    "entaipara": "entaipar",
    "entaiparam": "entaipar",
    "entaiparas": "entaipar",
    "entaiparde": "entaipar",
    "entaipardes": "entaipar",
    "entaipare": "entaipar",
    "entaiparei": "entaipar",
    "entaipareis": "entaipar",
    "entaiparem": "entaipar",
    "entaiparemos": "entaipar",
    "entaipares": "entaipar",
    "entaiparia": "entaipar",
    "entaipariam": "entaipar",
    "entaiparias": "entaipar",
    "entaiparmo": "entaipar",
    "entaiparmos": "entaipar",
    "entaipará": "entaipar",
    "entaiparás": "entaipar",
    "entaiparão": "entaipar",
    "entaiparíamos": "entaipar",
    "entaiparíeis": "entaipar",
    "entaipas": "entaipar",
    "entaipasse": "entaipar",
    "entaipassem": "entaipar",
    "entaipasses": "entaipar",
    "entaipaste": "entaipar",
    "entaipastes": "entaipar",
    "entaipava": "entaipar",
    "entaipavam": "entaipar",
    "entaipavas": "entaipar",
    "entaipe": "entaipar",
    "entaipei": "entaipar",
    "entaipeis": "entaipar",
    "entaipem": "entaipar",
    "entaipemo": "entaipar",
    "entaipemos": "entaipar",
    "entaipes": "entaipar",
    "entaipo": "entaipar",
    "entaipou": "entaipar",
    "entaipá": "entaipar",
    "entaipámo": "entaipar",
    "entaipámos": "entaipar",
    "entaipáramo": "entaipar",
    "entaipáramos": "entaipar",
    "entaipárei": "entaipar",
    "entaipáreis": "entaipar",
    "entaipásseis": "entaipar",
    "entaipássemos": "entaipar",
    "entaipávamo": "entaipar",
    "entaipávamos": "entaipar",
    "entaipávei": "entaipar",
    "entaipáveis": "entaipar",
    "entala": "entalir",
    "entalada": "entalar",
    "entaladas": "entalar",
    "entaladelas": "entaladela",
    "entalado": "entalar",
    "entaladora": "entalador",
    "entaladoras": "entalador",
    "entaladores": "entalador",
    "entalados": "entalar",
    "entalai": "entalar",
    "entalais": "entalir",
    "entalam": "entalir",
    "entalamo": "entalir",
    "entalamos": "entalir",
    "entalando": "entalar",
    "entalara": "entalar",
    "entalaram": "entalar",
    "entalaras": "entalar",
    "entalarde": "entalar",
    "entalardes": "entalar",
    "entalare": "entalar",
    "entalarei": "entalar",
    "entalareis": "entalar",
    "entalarem": "entalar",
    "entalaremos": "entalar",
    "entalares": "entalar",
    "entalaria": "entalar",
    "entalariam": "entalar",
    "entalarias": "entalar",
    "entalarmo": "entalar",
    "entalarmos": "entalar",
    "entalará": "entalar",
    "entalarás": "entalar",
    "entalarão": "entalar",
    "entalaríamos": "entalar",
    "entalaríeis": "entalar",
    "entalas": "entalir",
    "entalasse": "entalar",
    "entalassem": "entalar",
    "entalasses": "entalar",
    "entalaste": "entalar",
    "entalastes": "entalar",
    "entalava": "entalar",
    "entalavam": "entalar",
    "entalavas": "entalar",
    "entalações": "entalação",
    "entale": "entalir",
    "entalece": "entalecer",
    "entalecei": "entalecer",
    "entaleceis": "entalecer",
    "entalecem": "entalecer",
    "entalecemo": "entalecer",
    "entalecemos": "entalecer",
    "entalecendo": "entalecer",
    "entalecera": "entalecer",
    "entaleceram": "entalecer",
    "entaleceras": "entalecer",
    "entalecerde": "entalecer",
    "entalecerdes": "entalecer",
    "entalecere": "entalecer",
    "entalecerei": "entalecer",
    "entalecereis": "entalecer",
    "entalecerem": "entalecer",
    "entaleceremos": "entalecer",
    "entaleceres": "entalecer",
    "entaleceria": "entalecer",
    "entaleceriam": "entalecer",
    "entalecerias": "entalecer",
    "entalecermo": "entalecer",
    "entalecermos": "entalecer",
    "entalecerá": "entalecer",
    "entalecerás": "entalecer",
    "entalecerão": "entalecer",
    "entaleceríamos": "entalecer",
    "entaleceríeis": "entalecer",
    "entaleces": "entalecer",
    "entalecesse": "entalecer",
    "entalecessem": "entalecer",
    "entalecesses": "entalecer",
    "entaleceste": "entalecer",
    "entalecestes": "entalecer",
    "entaleceu": "entalecer",
    "entaleci": "entalecer",
    "entalecia": "entalecer",
    "entaleciam": "entalecer",
    "entalecias": "entalecer",
    "entalecida": "entalecer",
    "entalecidas": "entalecer",
    "entalecido": "entalecer",
    "entalecidos": "entalecer",
    "entalecê": "entalecer",
    "entalecêramo": "entalecer",
    "entalecêramos": "entalecer",
    "entalecêrei": "entalecer",
    "entalecêreis": "entalecer",
    "entalecêsseis": "entalecer",
    "entalecêssemos": "entalecer",
    "entalecíamo": "entalecer",
    "entalecíamos": "entalecer",
    "entalecíei": "entalecer",
    "entalecíeis": "entalecer",
    "entalei": "entalar",
    "entaleiga": "entaleigar",
    "entaleigada": "entaleigar",
    "entaleigadas": "entaleigar",
    "entaleigado": "entaleigar",
    "entaleigados": "entaleigar",
    "entaleigai": "entaleigar",
    "entaleigais": "entaleigar",
    "entaleigam": "entaleigar",
    "entaleigamo": "entaleigar",
    "entaleigamos": "entaleigar",
    "entaleigando": "entaleigar",
    "entaleigara": "entaleigar",
    "entaleigaram": "entaleigar",
    "entaleigaras": "entaleigar",
    "entaleigarde": "entaleigar",
    "entaleigardes": "entaleigar",
    "entaleigare": "entaleigar",
    "entaleigarei": "entaleigar",
    "entaleigareis": "entaleigar",
    "entaleigarem": "entaleigar",
    "entaleigaremos": "entaleigar",
    "entaleigares": "entaleigar",
    "entaleigaria": "entaleigar",
    "entaleigariam": "entaleigar",
    "entaleigarias": "entaleigar",
    "entaleigarmo": "entaleigar",
    "entaleigarmos": "entaleigar",
    "entaleigará": "entaleigar",
    "entaleigarás": "entaleigar",
    "entaleigarão": "entaleigar",
    "entaleigaríamos": "entaleigar",
    "entaleigaríeis": "entaleigar",
    "entaleigas": "entaleigar",
    "entaleigasse": "entaleigar",
    "entaleigassem": "entaleigar",
    "entaleigasses": "entaleigar",
    "entaleigaste": "entaleigar",
    "entaleigastes": "entaleigar",
    "entaleigava": "entaleigar",
    "entaleigavam": "entaleigar",
    "entaleigavas": "entaleigar",
    "entaleigo": "entaleigar",
    "entaleigou": "entaleigar",
    "entaleigue": "entaleigar",
    "entaleiguei": "entaleigar",
    "entaleigueis": "entaleigar",
    "entaleiguem": "entaleigar",
    "entaleiguemo": "entaleigar",
    "entaleiguemos": "entaleigar",
    "entaleigues": "entaleigar",
    "entaleigá": "entaleigar",
    "entaleigámo": "entaleigar",
    "entaleigámos": "entaleigar",
    "entaleigáramo": "entaleigar",
    "entaleigáramos": "entaleigar",
    "entaleigárei": "entaleigar",
    "entaleigáreis": "entaleigar",
    "entaleigásseis": "entaleigar",
    "entaleigássemos": "entaleigar",
    "entaleigávamo": "entaleigar",
    "entaleigávamos": "entaleigar",
    "entaleigávei": "entaleigar",
    "entaleigáveis": "entaleigar",
    "entaleis": "entalar",
    "entalem": "entalir",
    "entalemo": "entalar",
    "entalemos": "entalar",
    "entales": "entalir",
    "entaleça": "entalecer",
    "entaleçais": "entalecer",
    "entaleçam": "entalecer",
    "entaleçamo": "entalecer",
    "entaleçamos": "entalecer",
    "entaleças": "entalecer",
    "entaleço": "entalecer",
    "entalha": "entalhar",
    "entalhada": "entalhar",
    "entalhadas": "entalhar",
    "entalhado": "entalhar",
    "entalhadora": "entalhador",
    "entalhadoras": "entalhador",
    "entalhadores": "entalhador",
    "entalhados": "entalhar",
    "entalhaduras": "entalhadura",
    "entalhai": "entalhar",
    "entalhais": "entalhar",
    "entalham": "entalhar",
    "entalhamentos": "entalhamento",
    "entalhamo": "entalhar",
    "entalhamos": "entalhar",
    "entalhando": "entalhar",
    "entalhara": "entalhar",
    "entalharam": "entalhar",
    "entalharas": "entalhar",
    "entalharde": "entalhar",
    "entalhardes": "entalhar",
    "entalhare": "entalhar",
    "entalharei": "entalhar",
    "entalhareis": "entalhar",
    "entalharem": "entalhar",
    "entalharemos": "entalhar",
    "entalhares": "entalhar",
    "entalharia": "entalhar",
    "entalhariam": "entalhar",
    "entalharias": "entalhar",
    "entalharmo": "entalhar",
    "entalharmos": "entalhar",
    "entalhará": "entalhar",
    "entalharás": "entalhar",
    "entalharão": "entalhar",
    "entalharíamos": "entalhar",
    "entalharíeis": "entalhar",
    "entalhas": "entalhar",
    "entalhasse": "entalhar",
    "entalhassem": "entalhar",
    "entalhasses": "entalhar",
    "entalhaste": "entalhar",
    "entalhastes": "entalhar",
    "entalhava": "entalhar",
    "entalhavam": "entalhar",
    "entalhavas": "entalhar",
    "entalhe": "entalhar",
    "entalhei": "entalhar",
    "entalheis": "entalhar",
    "entalhem": "entalhar",
    "entalhemo": "entalhar",
    "entalhemos": "entalhar",
    "entalhes": "entalhe",
    "entalho": "entalhar",
    "entalhos": "entalho",
    "entalhou": "entalhar",
    "entalhá": "entalhar",
    "entalhámo": "entalhar",
    "entalhámos": "entalhar",
    "entalháramo": "entalhar",
    "entalháramos": "entalhar",
    "entalhárei": "entalhar",
    "entalháreis": "entalhar",
    "entalhásseis": "entalhar",
    "entalhássemos": "entalhar",
    "entalhávamo": "entalhar",
    "entalhávamos": "entalhar",
    "entalhávei": "entalhar",
    "entalháveis": "entalhar",
    "entali": "entalir",
    "entalia": "entalir",
    "entaliam": "entalir",
    "entalias": "entalir",
    "entalida": "entalir",
    "entalidas": "entalir",
    "entalido": "entalir",
    "entalidos": "entalir",
    "entalimo": "entalir",
    "entalimos": "entalir",
    "entalindo": "entalir",
    "entalira": "entalir",
    "entaliram": "entalir",
    "entaliras": "entalir",
    "entalirde": "entalir",
    "entalirdes": "entalir",
    "entalire": "entalir",
    "entalirei": "entalir",
    "entalireis": "entalir",
    "entalirem": "entalir",
    "entaliremos": "entalir",
    "entalires": "entalir",
    "entaliria": "entalir",
    "entaliriam": "entalir",
    "entalirias": "entalir",
    "entalirmo": "entalir",
    "entalirmos": "entalir",
    "entalirá": "entalir",
    "entalirás": "entalir",
    "entalirão": "entalir",
    "entaliríamos": "entalir",
    "entaliríeis": "entalir",
    "entalis": "entalir",
    "entalisca": "entaliscar",
    "entaliscada": "entaliscar",
    "entaliscadas": "entaliscar",
    "entaliscado": "entaliscar",
    "entaliscados": "entaliscar",
    "entaliscai": "entaliscar",
    "entaliscais": "entaliscar",
    "entaliscam": "entaliscar",
    "entaliscamo": "entaliscar",
    "entaliscamos": "entaliscar",
    "entaliscando": "entaliscar",
    "entaliscara": "entaliscar",
    "entaliscaram": "entaliscar",
    "entaliscaras": "entaliscar",
    "entaliscarde": "entaliscar",
    "entaliscardes": "entaliscar",
    "entaliscare": "entaliscar",
    "entaliscarei": "entaliscar",
    "entaliscareis": "entaliscar",
    "entaliscarem": "entaliscar",
    "entaliscaremos": "entaliscar",
    "entaliscares": "entaliscar",
    "entaliscaria": "entaliscar",
    "entaliscariam": "entaliscar",
    "entaliscarias": "entaliscar",
    "entaliscarmo": "entaliscar",
    "entaliscarmos": "entaliscar",
    "entaliscará": "entaliscar",
    "entaliscarás": "entaliscar",
    "entaliscarão": "entaliscar",
    "entaliscaríamos": "entaliscar",
    "entaliscaríeis": "entaliscar",
    "entaliscas": "entaliscar",
    "entaliscasse": "entaliscar",
    "entaliscassem": "entaliscar",
    "entaliscasses": "entaliscar",
    "entaliscaste": "entaliscar",
    "entaliscastes": "entaliscar",
    "entaliscava": "entaliscar",
    "entaliscavam": "entaliscar",
    "entaliscavas": "entaliscar",
    "entalisco": "entaliscar",
    "entaliscou": "entaliscar",
    "entaliscá": "entaliscar",
    "entaliscámo": "entaliscar",
    "entaliscámos": "entaliscar",
    "entaliscáramo": "entaliscar",
    "entaliscáramos": "entaliscar",
    "entaliscárei": "entaliscar",
    "entaliscáreis": "entaliscar",
    "entaliscásseis": "entaliscar",
    "entaliscássemos": "entaliscar",
    "entaliscávamo": "entaliscar",
    "entaliscávamos": "entaliscar",
    "entaliscávei": "entaliscar",
    "entaliscáveis": "entaliscar",
    "entalisque": "entaliscar",
    "entalisquei": "entaliscar",
    "entalisqueis": "entaliscar",
    "entalisquem": "entaliscar",
    "entalisquemo": "entaliscar",
    "entalisquemos": "entaliscar",
    "entalisques": "entaliscar",
    "entalisse": "entalir",
    "entalissem": "entalir",
    "entalisses": "entalir",
    "entaliste": "entalir",
    "entalistes": "entalir",
    "entaliu": "entalir",
    "entalo": "entalir",
    "entaloa": "entaloar",
    "entaloada": "entaloar",
    "entaloadas": "entaloar",
    "entaloado": "entaloar",
    "entaloados": "entaloar",
    "entaloai": "entaloar",
    "entaloais": "entaloar",
    "entaloam": "entaloar",
    "entaloamo": "entaloar",
    "entaloamos": "entaloar",
    "entaloando": "entaloar",
    "entaloara": "entaloar",
    "entaloaram": "entaloar",
    "entaloaras": "entaloar",
    "entaloarde": "entaloar",
    "entaloardes": "entaloar",
    "entaloare": "entaloar",
    "entaloarei": "entaloar",
    "entaloareis": "entaloar",
    "entaloarem": "entaloar",
    "entaloaremos": "entaloar",
    "entaloares": "entaloar",
    "entaloaria": "entaloar",
    "entaloariam": "entaloar",
    "entaloarias": "entaloar",
    "entaloarmo": "entaloar",
    "entaloarmos": "entaloar",
    "entaloará": "entaloar",
    "entaloarás": "entaloar",
    "entaloarão": "entaloar",
    "entaloaríamos": "entaloar",
    "entaloaríeis": "entaloar",
    "entaloas": "entaloar",
    "entaloasse": "entaloar",
    "entaloassem": "entaloar",
    "entaloasses": "entaloar",
    "entaloaste": "entaloar",
    "entaloastes": "entaloar",
    "entaloava": "entaloar",
    "entaloavam": "entaloar",
    "entaloavas": "entaloar",
    "entaloe": "entaloar",
    "entaloei": "entaloar",
    "entaloeis": "entaloar",
    "entaloem": "entaloar",
    "entaloemo": "entaloar",
    "entaloemos": "entaloar",
    "entaloes": "entaloar",
    "entaloo": "entaloar",
    "entaloou": "entaloar",
    "entalou": "entalar",
    "entaloá": "entaloar",
    "entaloámo": "entaloar",
    "entaloámos": "entaloar",
    "entaloáramo": "entaloar",
    "entaloáramos": "entaloar",
    "entaloárei": "entaloar",
    "entaloáreis": "entaloar",
    "entaloásseis": "entaloar",
    "entaloássemos": "entaloar",
    "entaloávamo": "entaloar",
    "entaloávamos": "entaloar",
    "entaloávei": "entaloar",
    "entaloáveis": "entaloar",
    "entalpias": "entalpia",
    "entaluada": "entaluado",
    "entaluadas": "entaluado",
    "entaluados": "entaluado",
    "entalá": "entalar",
    "entalámo": "entalar",
    "entalámos": "entalar",
    "entaláramo": "entalar",
    "entaláramos": "entalar",
    "entalárei": "entalar",
    "entaláreis": "entalar",
    "entalásseis": "entalar",
    "entalássemos": "entalar",
    "entalávamo": "entalar",
    "entalávamos": "entalar",
    "entalávei": "entalar",
    "entaláveis": "entalar",
    "entalíamo": "entalir",
    "entalíamos": "entalir",
    "entalíei": "entalir",
    "entalíeis": "entalir",
    "entalíramo": "entalir",
    "entalíramos": "entalir",
    "entalírei": "entalir",
    "entalíreis": "entalir",
    "entalísseis": "entalir",
    "entalíssemos": "entalir",
    "entalões": "entalão",
    "entanca": "entancar",
    "entancada": "entancar",
    "entancadas": "entancar",
    "entancado": "entancar",
    "entancados": "entancar",
    "entancai": "entancar",
    "entancais": "entancar",
    "entancam": "entancar",
    "entancamo": "entancar",
    "entancamos": "entancar",
    "entancando": "entancar",
    "entancara": "entancar",
    "entancaram": "entancar",
    "entancaras": "entancar",
    "entancarde": "entancar",
    "entancardes": "entancar",
    "entancare": "entancar",
    "entancarei": "entancar",
    "entancareis": "entancar",
    "entancarem": "entancar",
    "entancaremos": "entancar",
    "entancares": "entancar",
    "entancaria": "entancar",
    "entancariam": "entancar",
    "entancarias": "entancar",
    "entancarmo": "entancar",
    "entancarmos": "entancar",
    "entancará": "entancar",
    "entancarás": "entancar",
    "entancarão": "entancar",
    "entancaríamos": "entancar",
    "entancaríeis": "entancar",
    "entancas": "entancar",
    "entancasse": "entancar",
    "entancassem": "entancar",
    "entancasses": "entancar",
    "entancaste": "entancar",
    "entancastes": "entancar",
    "entancava": "entancar",
    "entancavam": "entancar",
    "entancavas": "entancar",
    "entanco": "entancar",
    "entancou": "entancar",
    "entancá": "entancar",
    "entancámo": "entancar",
    "entancámos": "entancar",
    "entancáramo": "entancar",
    "entancáramos": "entancar",
    "entancárei": "entancar",
    "entancáreis": "entancar",
    "entancásseis": "entancar",
    "entancássemos": "entancar",
    "entancávamo": "entancar",
    "entancávamos": "entancar",
    "entancávei": "entancar",
    "entancáveis": "entancar",
    "entanga": "entanguir",
    "entangais": "entanguir",
    "entangam": "entanguir",
    "entangamo": "entanguir",
    "entangamos": "entanguir",
    "entangas": "entanguir",
    "entango": "entanguir",
    "entangue": "entanguir",
    "entanguece": "entanguecer",
    "entanguecei": "entanguecer",
    "entangueceis": "entanguecer",
    "entanguecem": "entanguecer",
    "entanguecemo": "entanguecer",
    "entanguecemos": "entanguecer",
    "entanguecendo": "entanguecer",
    "entanguecera": "entanguecer",
    "entangueceram": "entanguecer",
    "entangueceras": "entanguecer",
    "entanguecerdes": "entanguecer",
    "entanguecerei": "entanguecer",
    "entanguecereis": "entanguecer",
    "entanguecerem": "entanguecer",
    "entangueceremos": "entanguecer",
    "entangueceres": "entanguecer",
    "entangueceria": "entanguecer",
    "entangueceriam": "entanguecer",
    "entanguecerias": "entanguecer",
    "entanguecermo": "entanguecer",
    "entanguecermos": "entanguecer",
    "entanguecerá": "entanguecer",
    "entanguecerás": "entanguecer",
    "entanguecerão": "entanguecer",
    "entangueceríamos": "entanguecer",
    "entangueceríeis": "entanguecer",
    "entangueces": "entanguecer",
    "entanguecesse": "entanguecer",
    "entanguecessem": "entanguecer",
    "entanguecesses": "entanguecer",
    "entangueceste": "entanguecer",
    "entanguecestes": "entanguecer",
    "entangueceu": "entanguecer",
    "entangueci": "entanguecer",
    "entanguecia": "entanguecer",
    "entangueciam": "entanguecer",
    "entanguecias": "entanguecer",
    "entanguecida": "entanguecer",
    "entanguecidas": "entanguecer",
    "entanguecido": "entanguecer",
    "entanguecidos": "entanguecer",
    "entanguecêramo": "entanguecer",
    "entanguecêramos": "entanguecer",
    "entanguecêreis": "entanguecer",
    "entanguecêsseis": "entanguecer",
    "entanguecêssemos": "entanguecer",
    "entanguecíamo": "entanguecer",
    "entanguecíamos": "entanguecer",
    "entanguecíeis": "entanguecer",
    "entanguem": "entanguir",
    "entangues": "entanguir",
    "entangueça": "entanguecer",
    "entangueçais": "entanguecer",
    "entangueçam": "entanguecer",
    "entangueçamo": "entanguecer",
    "entangueçamos": "entanguecer",
    "entangueças": "entanguecer",
    "entangueço": "entanguecer",
    "entangui": "entanguir",
    "entanguia": "entanguir",
    "entanguiam": "entanguir",
    "entanguias": "entanguir",
    "entanguida": "entanguir",
    "entanguidas": "entanguir",
    "entanguido": "entanguir",
    "entanguidos": "entanguir",
    "entanguimo": "entanguir",
    "entanguimos": "entanguir",
    "entanguindo": "entanguir",
    "entanguira": "entanguir",
    "entanguiram": "entanguir",
    "entanguiras": "entanguir",
    "entanguirde": "entanguir",
    "entanguirdes": "entanguir",
    "entanguire": "entanguir",
    "entanguirei": "entanguir",
    "entanguireis": "entanguir",
    "entanguirem": "entanguir",
    "entanguiremos": "entanguir",
    "entanguires": "entanguir",
    "entanguiria": "entanguir",
    "entanguiriam": "entanguir",
    "entanguirias": "entanguir",
    "entanguirmo": "entanguir",
    "entanguirmos": "entanguir",
    "entanguirá": "entanguir",
    "entanguirás": "entanguir",
    "entanguirão": "entanguir",
    "entanguiríamos": "entanguir",
    "entanguiríeis": "entanguir",
    "entanguis": "entanguir",
    "entanguisse": "entanguir",
    "entanguissem": "entanguir",
    "entanguisses": "entanguir",
    "entanguiste": "entanguir",
    "entanguistes": "entanguir",
    "entanguiu": "entanguir",
    "entanguíamo": "entanguir",
    "entanguíamos": "entanguir",
    "entanguíei": "entanguir",
    "entanguíeis": "entanguir",
    "entanguíramo": "entanguir",
    "entanguíramos": "entanguir",
    "entanguírei": "entanguir",
    "entanguíreis": "entanguir",
    "entanguísseis": "entanguir",
    "entanguíssemos": "entanguir",
    "entanque": "entancar",
    "entanquei": "entancar",
    "entanqueis": "entancar",
    "entanquem": "entancar",
    "entanquemo": "entancar",
    "entanquemos": "entancar",
    "entanques": "entancar",
    "entapeta": "entapetar",
    "entapetada": "entapetar",
    "entapetadas": "entapetar",
    "entapetado": "entapetar",
    "entapetados": "entapetar",
    "entapetai": "entapetar",
    "entapetais": "entapetar",
    "entapetam": "entapetar",
    "entapetamo": "entapetar",
    "entapetamos": "entapetar",
    "entapetando": "entapetar",
    "entapetara": "entapetar",
    "entapetaram": "entapetar",
    "entapetaras": "entapetar",
    "entapetarde": "entapetar",
    "entapetardes": "entapetar",
    "entapetare": "entapetar",
    "entapetarei": "entapetar",
    "entapetareis": "entapetar",
    "entapetarem": "entapetar",
    "entapetaremos": "entapetar",
    "entapetares": "entapetar",
    "entapetaria": "entapetar",
    "entapetariam": "entapetar",
    "entapetarias": "entapetar",
    "entapetarmo": "entapetar",
    "entapetarmos": "entapetar",
    "entapetará": "entapetar",
    "entapetarás": "entapetar",
    "entapetarão": "entapetar",
    "entapetaríamos": "entapetar",
    "entapetaríeis": "entapetar",
    "entapetas": "entapetar",
    "entapetasse": "entapetar",
    "entapetassem": "entapetar",
    "entapetasses": "entapetar",
    "entapetaste": "entapetar",
    "entapetastes": "entapetar",
    "entapetava": "entapetar",
    "entapetavam": "entapetar",
    "entapetavas": "entapetar",
    "entapete": "entapetar",
    "entapetei": "entapetar",
    "entapeteis": "entapetar",
    "entapetem": "entapetar",
    "entapetemo": "entapetar",
    "entapetemos": "entapetar",
    "entapetes": "entapetar",
    "entapeto": "entapetar",
    "entapetou": "entapetar",
    "entapetá": "entapetar",
    "entapetámo": "entapetar",
    "entapetámos": "entapetar",
    "entapetáramo": "entapetar",
    "entapetáramos": "entapetar",
    "entapetárei": "entapetar",
    "entapetáreis": "entapetar",
    "entapetásseis": "entapetar",
    "entapetássemos": "entapetar",
    "entapetávamo": "entapetar",
    "entapetávamos": "entapetar",
    "entapetávei": "entapetar",
    "entapetáveis": "entapetar",
    "entapiza": "entapizar",
    "entapizada": "entapizar",
    "entapizadas": "entapizar",
    "entapizado": "entapizar",
    "entapizados": "entapizar",
    "entapizai": "entapizar",
    "entapizais": "entapizar",
    "entapizam": "entapizar",
    "entapizamo": "entapizar",
    "entapizamos": "entapizar",
    "entapizando": "entapizar",
    "entapizara": "entapizar",
    "entapizaram": "entapizar",
    "entapizaras": "entapizar",
    "entapizarde": "entapizar",
    "entapizardes": "entapizar",
    "entapizare": "entapizar",
    "entapizarei": "entapizar",
    "entapizareis": "entapizar",
    "entapizarem": "entapizar",
    "entapizaremos": "entapizar",
    "entapizares": "entapizar",
    "entapizaria": "entapizar",
    "entapizariam": "entapizar",
    "entapizarias": "entapizar",
    "entapizarmo": "entapizar",
    "entapizarmos": "entapizar",
    "entapizará": "entapizar",
    "entapizarás": "entapizar",
    "entapizarão": "entapizar",
    "entapizaríamos": "entapizar",
    "entapizaríeis": "entapizar",
    "entapizas": "entapizar",
    "entapizasse": "entapizar",
    "entapizassem": "entapizar",
    "entapizasses": "entapizar",
    "entapizaste": "entapizar",
    "entapizastes": "entapizar",
    "entapizava": "entapizar",
    "entapizavam": "entapizar",
    "entapizavas": "entapizar",
    "entapize": "entapizar",
    "entapizei": "entapizar",
    "entapizeis": "entapizar",
    "entapizem": "entapizar",
    "entapizemo": "entapizar",
    "entapizemos": "entapizar",
    "entapizes": "entapizar",
    "entapizo": "entapizar",
    "entapizou": "entapizar",
    "entapizá": "entapizar",
    "entapizámo": "entapizar",
    "entapizámos": "entapizar",
    "entapizáramo": "entapizar",
    "entapizáramos": "entapizar",
    "entapizárei": "entapizar",
    "entapizáreis": "entapizar",
    "entapizásseis": "entapizar",
    "entapizássemos": "entapizar",
    "entapizávamo": "entapizar",
    "entapizávamos": "entapizar",
    "entapizávei": "entapizar",
    "entapizáveis": "entapizar",
    "entaramela": "entaramelar",
    "entaramelada": "entaramelar",
    "entarameladas": "entaramelar",
    "entaramelado": "entaramelar",
    "entaramelados": "entaramelar",
    "entaramelai": "entaramelar",
    "entaramelais": "entaramelar",
    "entaramelam": "entaramelar",
    "entaramelamo": "entaramelar",
    "entaramelamos": "entaramelar",
    "entaramelando": "entaramelar",
    "entaramelara": "entaramelar",
    "entaramelaram": "entaramelar",
    "entaramelaras": "entaramelar",
    "entaramelarde": "entaramelar",
    "entaramelardes": "entaramelar",
    "entaramelare": "entaramelar",
    "entaramelarei": "entaramelar",
    "entaramelareis": "entaramelar",
    "entaramelarem": "entaramelar",
    "entaramelaremos": "entaramelar",
    "entaramelares": "entaramelar",
    "entaramelaria": "entaramelar",
    "entaramelariam": "entaramelar",
    "entaramelarias": "entaramelar",
    "entaramelarmo": "entaramelar",
    "entaramelarmos": "entaramelar",
    "entaramelará": "entaramelar",
    "entaramelarás": "entaramelar",
    "entaramelarão": "entaramelar",
    "entaramelaríamos": "entaramelar",
    "entaramelaríeis": "entaramelar",
    "entaramelas": "entaramelar",
    "entaramelasse": "entaramelar",
    "entaramelassem": "entaramelar",
    "entaramelasses": "entaramelar",
    "entaramelaste": "entaramelar",
    "entaramelastes": "entaramelar",
    "entaramelava": "entaramelar",
    "entaramelavam": "entaramelar",
    "entaramelavas": "entaramelar",
    "entaramele": "entaramelar",
    "entaramelei": "entaramelar",
    "entarameleis": "entaramelar",
    "entaramelem": "entaramelar",
    "entaramelemo": "entaramelar",
    "entaramelemos": "entaramelar",
    "entarameles": "entaramelar",
    "entaramelo": "entaramelar",
    "entaramelou": "entaramelar",
    "entaramelá": "entaramelar",
    "entaramelámo": "entaramelar",
    "entaramelámos": "entaramelar",
    "entarameláramo": "entaramelar",
    "entarameláramos": "entaramelar",
    "entaramelárei": "entaramelar",
    "entarameláreis": "entaramelar",
    "entaramelásseis": "entaramelar",
    "entaramelássemos": "entaramelar",
    "entaramelávamo": "entaramelar",
    "entaramelávamos": "entaramelar",
    "entaramelávei": "entaramelar",
    "entarameláveis": "entaramelar",
    "entardece": "entardecer",
    "entardecei": "entardecer",
    "entardeceis": "entardecer",
    "entardecem": "entardecer",
    "entardecemo": "entardecer",
    "entardecemos": "entardecer",
    "entardecendo": "entardecer",
    "entardecera": "entardecer",
    "entardeceram": "entardecer",
    "entardeceras": "entardecer",
    "entardecerdes": "entardecer",
    "entardecerei": "entardecer",
    "entardecereis": "entardecer",
    "entardecerem": "entardecer",
    "entardeceremos": "entardecer",
    "entardeceres": "entardecer",
    "entardeceria": "entardecer",
    "entardeceriam": "entardecer",
    "entardecerias": "entardecer",
    "entardecermo": "entardecer",
    "entardecermos": "entardecer",
    "entardecerá": "entardecer",
    "entardecerás": "entardecer",
    "entardecerão": "entardecer",
    "entardeceríamos": "entardecer",
    "entardeceríeis": "entardecer",
    "entardeces": "entardecer",
    "entardecesse": "entardecer",
    "entardecessem": "entardecer",
    "entardecesses": "entardecer",
    "entardeceste": "entardecer",
    "entardecestes": "entardecer",
    "entardeceu": "entardecer",
    "entardeci": "entardecer",
    "entardecia": "entardecer",
    "entardeciam": "entardecer",
    "entardecias": "entardecer",
    "entardecida": "entardecer",
    "entardecidas": "entardecer",
    "entardecido": "entardecer",
    "entardecidos": "entardecer",
    "entardecêramo": "entardecer",
    "entardecêramos": "entardecer",
    "entardecêreis": "entardecer",
    "entardecêsseis": "entardecer",
    "entardecêssemos": "entardecer",
    "entardecíamo": "entardecer",
    "entardecíamos": "entardecer",
    "entardecíeis": "entardecer",
    "entardeça": "entardecer",
    "entardeçais": "entardecer",
    "entardeçam": "entardecer",
    "entardeçamo": "entardecer",
    "entardeçamos": "entardecer",
    "entardeças": "entardecer",
    "entardeço": "entardecer",
    "entarraxa": "entarraxar",
    "entarraxada": "entarraxar",
    "entarraxadas": "entarraxar",
    "entarraxado": "entarraxar",
    "entarraxados": "entarraxar",
    "entarraxai": "entarraxar",
    "entarraxais": "entarraxar",
    "entarraxam": "entarraxar",
    "entarraxamo": "entarraxar",
    "entarraxamos": "entarraxar",
    "entarraxando": "entarraxar",
    "entarraxara": "entarraxar",
    "entarraxaram": "entarraxar",
    "entarraxaras": "entarraxar",
    "entarraxarde": "entarraxar",
    "entarraxardes": "entarraxar",
    "entarraxare": "entarraxar",
    "entarraxarei": "entarraxar",
    "entarraxareis": "entarraxar",
    "entarraxarem": "entarraxar",
    "entarraxaremos": "entarraxar",
    "entarraxares": "entarraxar",
    "entarraxaria": "entarraxar",
    "entarraxariam": "entarraxar",
    "entarraxarias": "entarraxar",
    "entarraxarmo": "entarraxar",
    "entarraxarmos": "entarraxar",
    "entarraxará": "entarraxar",
    "entarraxarás": "entarraxar",
    "entarraxarão": "entarraxar",
    "entarraxaríamos": "entarraxar",
    "entarraxaríeis": "entarraxar",
    "entarraxas": "entarraxar",
    "entarraxasse": "entarraxar",
    "entarraxassem": "entarraxar",
    "entarraxasses": "entarraxar",
    "entarraxaste": "entarraxar",
    "entarraxastes": "entarraxar",
    "entarraxava": "entarraxar",
    "entarraxavam": "entarraxar",
    "entarraxavas": "entarraxar",
    "entarraxe": "entarraxar",
    "entarraxei": "entarraxar",
    "entarraxeis": "entarraxar",
    "entarraxem": "entarraxar",
    "entarraxemo": "entarraxar",
    "entarraxemos": "entarraxar",
    "entarraxes": "entarraxar",
    "entarraxo": "entarraxar",
    "entarraxou": "entarraxar",
    "entarraxá": "entarraxar",
    "entarraxámo": "entarraxar",
    "entarraxámos": "entarraxar",
    "entarraxáramo": "entarraxar",
    "entarraxáramos": "entarraxar",
    "entarraxárei": "entarraxar",
    "entarraxáreis": "entarraxar",
    "entarraxásseis": "entarraxar",
    "entarraxássemos": "entarraxar",
    "entarraxávamo": "entarraxar",
    "entarraxávamos": "entarraxar",
    "entarraxávei": "entarraxar",
    "entarraxáveis": "entarraxar",
    "enteada": "entear",
    "enteadas": "entear",
    "enteado": "entear",
    "enteados": "entear",
    "enteai": "entear",
    "enteais": "entear",
    "enteamentos": "enteamento",
    "enteamo": "entear",
    "enteamos": "entear",
    "enteando": "entear",
    "enteara": "entear",
    "entearam": "entear",
    "entearas": "entear",
    "entearde": "entear",
    "enteardes": "entear",
    "enteare": "entear",
    "entearei": "entear",
    "enteareis": "entear",
    "entearem": "entear",
    "entearemos": "entear",
    "enteares": "entear",
    "entearia": "entear",
    "enteariam": "entear",
    "entearias": "entear",
    "entearmo": "entear",
    "entearmos": "entear",
    "enteará": "entear",
    "entearás": "entear",
    "entearão": "entear",
    "entearíamos": "entear",
    "entearíeis": "entear",
    "enteasse": "entear",
    "enteassem": "entear",
    "enteasses": "entear",
    "enteaste": "entear",
    "enteastes": "entear",
    "enteava": "entear",
    "enteavam": "entear",
    "enteavas": "entear",
    "entedia": "entediar",
    "entediada": "entediar",
    "entediadas": "entediar",
    "entediado": "entediar",
    "entediados": "entediar",
    "entediai": "entediar",
    "entediais": "entediar",
    "entediam": "entediar",
    "entediamo": "entediar",
    "entediamos": "entediar",
    "entediando": "entediar",
    "entediantes": "entediante",
    "entediara": "entediar",
    "entediaram": "entediar",
    "entediaras": "entediar",
    "entediarde": "entediar",
    "entediardes": "entediar",
    "entediare": "entediar",
    "entediarei": "entediar",
    "entediareis": "entediar",
    "entediarem": "entediar",
    "entediaremos": "entediar",
    "entediares": "entediar",
    "entediaria": "entediar",
    "entediariam": "entediar",
    "entediarias": "entediar",
    "entediarmo": "entediar",
    "entediarmos": "entediar",
    "entediará": "entediar",
    "entediarás": "entediar",
    "entediarão": "entediar",
    "entediaríamos": "entediar",
    "entediaríeis": "entediar",
    "entedias": "entediar",
    "entediasse": "entediar",
    "entediassem": "entediar",
    "entediasses": "entediar",
    "entediaste": "entediar",
    "entediastes": "entediar",
    "entediava": "entediar",
    "entediavam": "entediar",
    "entediavas": "entediar",
    "entedie": "entediar",
    "entediei": "entediar",
    "entedieis": "entediar",
    "entediem": "entediar",
    "entediemo": "entediar",
    "entediemos": "entediar",
    "entedies": "entediar",
    "entedio": "entediar",
    "entediou": "entediar",
    "entediá": "entediar",
    "entediámo": "entediar",
    "entediámos": "entediar",
    "entediáramo": "entediar",
    "entediáramos": "entediar",
    "entediárei": "entediar",
    "entediáreis": "entediar",
    "entediásseis": "entediar",
    "entediássemos": "entediar",
    "entediávamo": "entediar",
    "entediávamos": "entediar",
    "entediávei": "entediar",
    "entediáveis": "entediar",
    "enteei": "entear",
    "enteeis": "entear",
    "enteemo": "entear",
    "enteemos": "entear",
    "enteia": "entear",
    "enteiam": "entear",
    "enteias": "entear",
    "enteie": "entear",
    "enteiem": "entear",
    "enteies": "entear",
    "enteio": "entear",
    "enteja": "entejar",
    "entejada": "entejar",
    "entejadas": "entejar",
    "entejado": "entejar",
    "entejados": "entejar",
    "entejai": "entejar",
    "entejais": "entejar",
    "entejam": "entejar",
    "entejamo": "entejar",
    "entejamos": "entejar",
    "entejando": "entejar",
    "entejara": "entejar",
    "entejaram": "entejar",
    "entejaras": "entejar",
    "entejarde": "entejar",
    "entejardes": "entejar",
    "entejare": "entejar",
    "entejarei": "entejar",
    "entejareis": "entejar",
    "entejarem": "entejar",
    "entejaremos": "entejar",
    "entejares": "entejar",
    "entejaria": "entejar",
    "entejariam": "entejar",
    "entejarias": "entejar",
    "entejarmo": "entejar",
    "entejarmos": "entejar",
    "entejará": "entejar",
    "entejarás": "entejar",
    "entejarão": "entejar",
    "entejaríamos": "entejar",
    "entejaríeis": "entejar",
    "entejas": "entejar",
    "entejasse": "entejar",
    "entejassem": "entejar",
    "entejasses": "entejar",
    "entejaste": "entejar",
    "entejastes": "entejar",
    "entejava": "entejar",
    "entejavam": "entejar",
    "entejavas": "entejar",
    "enteje": "entejar",
    "entejei": "entejar",
    "entejeis": "entejar",
    "entejem": "entejar",
    "entejemo": "entejar",
    "entejemos": "entejar",
    "entejes": "entejar",
    "entejo": "entejar",
    "entejos": "entejo",
    "entejou": "entejar",
    "entejá": "entejar",
    "entejámo": "entejar",
    "entejámos": "entejar",
    "entejáramo": "entejar",
    "entejáramos": "entejar",
    "entejárei": "entejar",
    "entejáreis": "entejar",
    "entejásseis": "entejar",
    "entejássemos": "entejar",
    "entejávamo": "entejar",
    "entejávamos": "entejar",
    "entejávei": "entejar",
    "entejáveis": "entejar",
    "entelequias": "entelequia",
    "entelha": "entelhar",
    "entelhada": "entelhar",
    "entelhadas": "entelhar",
    "entelhado": "entelhar",
    "entelhados": "entelhar",
    "entelhai": "entelhar",
    "entelhais": "entelhar",
    "entelham": "entelhar",
    "entelhamo": "entelhar",
    "entelhamos": "entelhar",
    "entelhando": "entelhar",
    "entelhara": "entelhar",
    "entelharam": "entelhar",
    "entelharas": "entelhar",
    "entelharde": "entelhar",
    "entelhardes": "entelhar",
    "entelhare": "entelhar",
    "entelharei": "entelhar",
    "entelhareis": "entelhar",
    "entelharem": "entelhar",
    "entelharemos": "entelhar",
    "entelhares": "entelhar",
    "entelharia": "entelhar",
    "entelhariam": "entelhar",
    "entelharias": "entelhar",
    "entelharmo": "entelhar",
    "entelharmos": "entelhar",
    "entelhará": "entelhar",
    "entelharás": "entelhar",
    "entelharão": "entelhar",
    "entelharíamos": "entelhar",
    "entelharíeis": "entelhar",
    "entelhas": "entelhar",
    "entelhasse": "entelhar",
    "entelhassem": "entelhar",
    "entelhasses": "entelhar",
    "entelhaste": "entelhar",
    "entelhastes": "entelhar",
    "entelhava": "entelhar",
    "entelhavam": "entelhar",
    "entelhavas": "entelhar",
    "entelhe": "entelhar",
    "entelhei": "entelhar",
    "entelheis": "entelhar",
    "entelhem": "entelhar",
    "entelhemo": "entelhar",
    "entelhemos": "entelhar",
    "entelhes": "entelhar",
    "entelho": "entelhar",
    "entelhou": "entelhar",
    "entelhá": "entelhar",
    "entelhámo": "entelhar",
    "entelhámos": "entelhar",
    "entelháramo": "entelhar",
    "entelháramos": "entelhar",
    "entelhárei": "entelhar",
    "entelháreis": "entelhar",
    "entelhásseis": "entelhar",
    "entelhássemos": "entelhar",
    "entelhávamo": "entelhar",
    "entelhávamos": "entelhar",
    "entelhávei": "entelhar",
    "entelháveis": "entelhar",
    "entenda": "entender",
    "entendais": "entender",
    "entendam": "entender",
    "entendamo": "entender",
    "entendamos": "entender",
    "entendas": "entender",
    "entende": "entender",
    "entendedora": "entendedor",
    "entendedoras": "entendedor",
    "entendedores": "entendedor",
    "entendei": "entender",
    "entendeis": "entender",
    "entendem": "entender",
    "entendemo": "entender",
    "entendemos": "entender",
    "entendendo": "entender",
    "entendera": "entender",
    "entenderam": "entender",
    "entenderas": "entender",
    "entenderde": "entender",
    "entenderdes": "entender",
    "entendere": "entender",
    "entenderei": "entender",
    "entendereis": "entender",
    "entenderem": "entender",
    "entenderemos": "entender",
    "entenderes": "entender",
    "entenderia": "entender",
    "entenderiam": "entender",
    "entenderias": "entender",
    "entendermo": "entender",
    "entendermos": "entender",
    "entenderá": "entender",
    "entenderás": "entender",
    "entenderão": "entender",
    "entenderíamos": "entender",
    "entenderíeis": "entender",
    "entendes": "entender",
    "entendesse": "entender",
    "entendessem": "entender",
    "entendesses": "entender",
    "entendeste": "entender",
    "entendestes": "entender",
    "entendeu": "entender",
    "entendi": "entender",
    "entendia": "entender",
    "entendiam": "entender",
    "entendias": "entender",
    "entendida": "entendido",
    "entendidas": "entendido",
    "entendido": "entender",
    "entendidos": "entendido",
    "entendidíssima": "entendido",
    "entendidíssimas": "entendido",
    "entendidíssimo": "entendido",
    "entendidíssimos": "entendido",
    "entendimentos": "entendimento",
    "entendo": "entender",
    "entendê": "entender",
    "entendêramo": "entender",
    "entendêramos": "entender",
    "entendêrei": "entender",
    "entendêreis": "entender",
    "entendêsseis": "entender",
    "entendêssemos": "entender",
    "entendíamo": "entender",
    "entendíamos": "entender",
    "entendíei": "entender",
    "entendíeis": "entender",
    "entendíveis": "entendível",
    "entenebrece": "entenebrecer",
    "entenebrecei": "entenebrecer",
    "entenebreceis": "entenebrecer",
    "entenebrecem": "entenebrecer",
    "entenebrecemo": "entenebrecer",
    "entenebrecemos": "entenebrecer",
    "entenebrecendo": "entenebrecer",
    "entenebrecera": "entenebrecer",
    "entenebreceram": "entenebrecer",
    "entenebreceras": "entenebrecer",
    "entenebrecerdes": "entenebrecer",
    "entenebrecerei": "entenebrecer",
    "entenebrecereis": "entenebrecer",
    "entenebrecerem": "entenebrecer",
    "entenebreceremos": "entenebrecer",
    "entenebreceres": "entenebrecer",
    "entenebreceria": "entenebrecer",
    "entenebreceriam": "entenebrecer",
    "entenebrecerias": "entenebrecer",
    "entenebrecermo": "entenebrecer",
    "entenebrecermos": "entenebrecer",
    "entenebrecerá": "entenebrecer",
    "entenebrecerás": "entenebrecer",
    "entenebrecerão": "entenebrecer",
    "entenebreceríamos": "entenebrecer",
    "entenebreceríeis": "entenebrecer",
    "entenebreces": "entenebrecer",
    "entenebrecesse": "entenebrecer",
    "entenebrecessem": "entenebrecer",
    "entenebrecesses": "entenebrecer",
    "entenebreceste": "entenebrecer",
    "entenebrecestes": "entenebrecer",
    "entenebreceu": "entenebrecer",
    "entenebreci": "entenebrecer",
    "entenebrecia": "entenebrecer",
    "entenebreciam": "entenebrecer",
    "entenebrecias": "entenebrecer",
    "entenebrecida": "entenebrecido",
    "entenebrecidas": "entenebrecido",
    "entenebrecido": "entenebrecer",
    "entenebrecidos": "entenebrecido",
    "entenebrecimentos": "entenebrecimento",
    "entenebrecêramo": "entenebrecer",
    "entenebrecêramos": "entenebrecer",
    "entenebrecêreis": "entenebrecer",
    "entenebrecêsseis": "entenebrecer",
    "entenebrecêssemos": "entenebrecer",
    "entenebrecíamo": "entenebrecer",
    "entenebrecíamos": "entenebrecer",
    "entenebrecíeis": "entenebrecer",
    "entenebreça": "entenebrecer",
    "entenebreçais": "entenebrecer",
    "entenebreçam": "entenebrecer",
    "entenebreçamo": "entenebrecer",
    "entenebreçamos": "entenebrecer",
    "entenebreças": "entenebrecer",
    "entenebreço": "entenebrecer",
    "entenrece": "entenrecer",
    "entenrecei": "entenrecer",
    "entenreceis": "entenrecer",
    "entenrecem": "entenrecer",
    "entenrecemo": "entenrecer",
    "entenrecemos": "entenrecer",
    "entenrecendo": "entenrecer",
    "entenrecera": "entenrecer",
    "entenreceram": "entenrecer",
    "entenreceras": "entenrecer",
    "entenrecerde": "entenrecer",
    "entenrecerdes": "entenrecer",
    "entenrecere": "entenrecer",
    "entenrecerei": "entenrecer",
    "entenrecereis": "entenrecer",
    "entenrecerem": "entenrecer",
    "entenreceremos": "entenrecer",
    "entenreceres": "entenrecer",
    "entenreceria": "entenrecer",
    "entenreceriam": "entenrecer",
    "entenrecerias": "entenrecer",
    "entenrecermo": "entenrecer",
    "entenrecermos": "entenrecer",
    "entenrecerá": "entenrecer",
    "entenrecerás": "entenrecer",
    "entenrecerão": "entenrecer",
    "entenreceríamos": "entenrecer",
    "entenreceríeis": "entenrecer",
    "entenreces": "entenrecer",
    "entenrecesse": "entenrecer",
    "entenrecessem": "entenrecer",
    "entenrecesses": "entenrecer",
    "entenreceste": "entenrecer",
    "entenrecestes": "entenrecer",
    "entenreceu": "entenrecer",
    "entenreci": "entenrecer",
    "entenrecia": "entenrecer",
    "entenreciam": "entenrecer",
    "entenrecias": "entenrecer",
    "entenrecida": "entenrecer",
    "entenrecidas": "entenrecer",
    "entenrecido": "entenrecer",
    "entenrecidos": "entenrecer",
    "entenrecê": "entenrecer",
    "entenrecêramo": "entenrecer",
    "entenrecêramos": "entenrecer",
    "entenrecêrei": "entenrecer",
    "entenrecêreis": "entenrecer",
    "entenrecêsseis": "entenrecer",
    "entenrecêssemos": "entenrecer",
    "entenrecíamo": "entenrecer",
    "entenrecíamos": "entenrecer",
    "entenrecíei": "entenrecer",
    "entenrecíeis": "entenrecer",
    "entenreça": "entenrecer",
    "entenreçais": "entenrecer",
    "entenreçam": "entenrecer",
    "entenreçamo": "entenrecer",
    "entenreçamos": "entenrecer",
    "entenreças": "entenrecer",
    "entenreço": "entenrecer",
    "enteou": "entear",
    "entepidece": "entepidecer",
    "entepidecei": "entepidecer",
    "entepideceis": "entepidecer",
    "entepidecem": "entepidecer",
    "entepidecemo": "entepidecer",
    "entepidecemos": "entepidecer",
    "entepidecendo": "entepidecer",
    "entepidecera": "entepidecer",
    "entepideceram": "entepidecer",
    "entepideceras": "entepidecer",
    "entepidecerdes": "entepidecer",
    "entepidecerei": "entepidecer",
    "entepidecereis": "entepidecer",
    "entepidecerem": "entepidecer",
    "entepideceremos": "entepidecer",
    "entepideceres": "entepidecer",
    "entepideceria": "entepidecer",
    "entepideceriam": "entepidecer",
    "entepidecerias": "entepidecer",
    "entepidecermo": "entepidecer",
    "entepidecermos": "entepidecer",
    "entepidecerá": "entepidecer",
    "entepidecerás": "entepidecer",
    "entepidecerão": "entepidecer",
    "entepideceríamos": "entepidecer",
    "entepideceríeis": "entepidecer",
    "entepideces": "entepidecer",
    "entepidecesse": "entepidecer",
    "entepidecessem": "entepidecer",
    "entepidecesses": "entepidecer",
    "entepideceste": "entepidecer",
    "entepidecestes": "entepidecer",
    "entepideceu": "entepidecer",
    "entepideci": "entepidecer",
    "entepidecia": "entepidecer",
    "entepideciam": "entepidecer",
    "entepidecias": "entepidecer",
    "entepidecida": "entepidecer",
    "entepidecidas": "entepidecer",
    "entepidecido": "entepidecer",
    "entepidecidos": "entepidecer",
    "entepidecêramo": "entepidecer",
    "entepidecêramos": "entepidecer",
    "entepidecêreis": "entepidecer",
    "entepidecêsseis": "entepidecer",
    "entepidecêssemos": "entepidecer",
    "entepidecíamo": "entepidecer",
    "entepidecíamos": "entepidecer",
    "entepidecíeis": "entepidecer",
    "entepideça": "entepidecer",
    "entepideçais": "entepidecer",
    "entepideçam": "entepidecer",
    "entepideçamo": "entepidecer",
    "entepideçamos": "entepidecer",
    "entepideças": "entepidecer",
    "entepideço": "entepidecer",
    "enteradenografias": "enteradenografia",
    "enteradenográfica": "enteradenográfico",
    "enteradenográficas": "enteradenográfico",
    "enteradenográficos": "enteradenográfico",
    "enteralgias": "enteralgia",
    "enterectomias": "enterectomia",
    "enterectómica": "enterectómico",
    "enterectómicas": "enterectómico",
    "enterectómicos": "enterectómico",
    "enteremias": "enteremia",
    "enteremorragias": "enteremorragia",
    "enteremorrágica": "enteremorrágico",
    "enteremorrágicas": "enteremorrágico",
    "enteremorrágicos": "enteremorrágico",
    "enterites": "enterite",
    "enternece": "enternecer",
    "enternecedora": "enternecedor",
    "enternecedoras": "enternecedor",
    "enternecedores": "enternecedor",
    "enternecei": "enternecer",
    "enterneceis": "enternecer",
    "enternecem": "enternecer",
    "enternecemo": "enternecer",
    "enternecemos": "enternecer",
    "enternecendo": "enternecer",
    "enternecera": "enternecer",
    "enterneceram": "enternecer",
    "enterneceras": "enternecer",
    "enternecerdes": "enternecer",
    "enternecerei": "enternecer",
    "enternecereis": "enternecer",
    "enternecerem": "enternecer",
    "enterneceremos": "enternecer",
    "enterneceres": "enternecer",
    "enterneceria": "enternecer",
    "enterneceriam": "enternecer",
    "enternecerias": "enternecer",
    "enternecermo": "enternecer",
    "enternecermos": "enternecer",
    "enternecerá": "enternecer",
    "enternecerás": "enternecer",
    "enternecerão": "enternecer",
    "enterneceríamos": "enternecer",
    "enterneceríeis": "enternecer",
    "enterneces": "enternecer",
    "enternecesse": "enternecer",
    "enternecessem": "enternecer",
    "enternecesses": "enternecer",
    "enterneceste": "enternecer",
    "enternecestes": "enternecer",
    "enterneceu": "enternecer",
    "enterneci": "enternecer",
    "enternecia": "enternecer",
    "enterneciam": "enternecer",
    "enternecias": "enternecer",
    "enternecida": "enternecido",
    "enternecidas": "enternecido",
    "enternecido": "enternecer",
    "enternecidos": "enternecido",
    "enternecidíssima": "enternecido",
    "enternecidíssimas": "enternecido",
    "enternecidíssimo": "enternecido",
    "enternecidíssimos": "enternecido",
    "enternecimentos": "enternecimento",
    "enternecêramo": "enternecer",
    "enternecêramos": "enternecer",
    "enternecêreis": "enternecer",
    "enternecêsseis": "enternecer",
    "enternecêssemos": "enternecer",
    "enternecíamo": "enternecer",
    "enternecíamos": "enternecer",
    "enternecíeis": "enternecer",
    "enterneça": "enternecer",
    "enterneçais": "enternecer",
    "enterneçam": "enternecer",
    "enterneçamo": "enternecer",
    "enterneçamos": "enternecer",
    "enterneças": "enternecer",
    "enterneço": "enternecer",
    "enteroceles": "enterocele",
    "enteroclítica": "enteroclítico",
    "enteroclíticas": "enteroclítico",
    "enteroclíticos": "enteroclítico",
    "enterocolites": "enterocolite",
    "enterodermas": "enteroderma",
    "enterodermes": "enteroderme",
    "enterodinias": "enterodinia",
    "enterodérmica": "enterodérmico",
    "enterodérmicas": "enterodérmico",
    "enterodérmicos": "enterodérmico",
    "enterogastrites": "enterogastrite",
    "enterogástrica": "enterogástrico",
    "enterogástricas": "enterogástrico",
    "enterogástricos": "enterogástrico",
    "enteropneustos": "enteropneusto",
    "enteroquínases": "enteroquínase",
    "enterorragias": "enterorragia",
    "enterorrágica": "enterorrágico",
    "enterorrágicas": "enterorrágico",
    "enterorrágicos": "enterorrágico",
    "enteroscopias": "enteroscopia",
    "enteroscópica": "enteroscópico",
    "enteroscópicas": "enteroscópico",
    "enteroscópicos": "enteroscópico",
    "enteroses": "enterose",
    "enterostomias": "enterostomia",
    "enterostómica": "enterostómico",
    "enterostómicas": "enterostómico",
    "enterostómicos": "enterostómico",
    "enterotomias": "enterotomia",
    "enterotómica": "enterotómico",
    "enterotómicas": "enterotómico",
    "enterotómicos": "enterotómico",
    "enterovacinas": "enterovacina",
    "enterozoária": "enterozoário",
    "enterozoárias": "enterozoário",
    "enterozoários": "enterozoário",
    "enterozóica": "enterozóico",
    "enterozóicas": "enterozóico",
    "enterozóicos": "enterozóico",
    "enterra": "enterrar",
    "enterrada": "enterrar",
    "enterradas": "enterrar",
    "enterrado": "enterrar",
    "enterradora": "enterrador",
    "enterradoras": "enterrador",
    "enterradores": "enterrador",
    "enterrados": "enterrar",
    "enterradouros": "enterradouro",
    "enterradíssima": "enterrado",
    "enterradíssimas": "enterrado",
    "enterradíssimo": "enterrado",
    "enterradíssimos": "enterrado",
    "enterrai": "enterrar",
    "enterrais": "enterrar",
    "enterram": "enterrar",
    "enterramentos": "enterramento",
    "enterramo": "enterrar",
    "enterramos": "enterrar",
    "enterrando": "enterrar",
    "enterrara": "enterrar",
    "enterraram": "enterrar",
    "enterraras": "enterrar",
    "enterrarde": "enterrar",
    "enterrardes": "enterrar",
    "enterrare": "enterrar",
    "enterrarei": "enterrar",
    "enterrareis": "enterrar",
    "enterrarem": "enterrar",
    "enterraremos": "enterrar",
    "enterrares": "enterrar",
    "enterraria": "enterrar",
    "enterrariam": "enterrar",
    "enterrarias": "enterrar",
    "enterrarmo": "enterrar",
    "enterrarmos": "enterrar",
    "enterrará": "enterrar",
    "enterrarás": "enterrar",
    "enterrarão": "enterrar",
    "enterraríamos": "enterrar",
    "enterraríeis": "enterrar",
    "enterras": "enterrar",
    "enterrasse": "enterrar",
    "enterrassem": "enterrar",
    "enterrasses": "enterrar",
    "enterraste": "enterrar",
    "enterrastes": "enterrar",
    "enterrava": "enterrar",
    "enterravam": "enterrar",
    "enterravas": "enterrar",
    "enterrações": "enterração",
    "enterre": "enterrar",
    "enterrei": "enterrar",
    "enterreira": "enterreirar",
    "enterreirada": "enterreirar",
    "enterreiradas": "enterreirar",
    "enterreirado": "enterreirar",
    "enterreirados": "enterreirar",
    "enterreirai": "enterreirar",
    "enterreirais": "enterreirar",
    "enterreiram": "enterreirar",
    "enterreiramo": "enterreirar",
    "enterreiramos": "enterreirar",
    "enterreirando": "enterreirar",
    "enterreirara": "enterreirar",
    "enterreiraram": "enterreirar",
    "enterreiraras": "enterreirar",
    "enterreirarde": "enterreirar",
    "enterreirardes": "enterreirar",
    "enterreirare": "enterreirar",
    "enterreirarei": "enterreirar",
    "enterreirareis": "enterreirar",
    "enterreirarem": "enterreirar",
    "enterreiraremos": "enterreirar",
    "enterreirares": "enterreirar",
    "enterreiraria": "enterreirar",
    "enterreirariam": "enterreirar",
    "enterreirarias": "enterreirar",
    "enterreirarmo": "enterreirar",
    "enterreirarmos": "enterreirar",
    "enterreirará": "enterreirar",
    "enterreirarás": "enterreirar",
    "enterreirarão": "enterreirar",
    "enterreiraríamos": "enterreirar",
    "enterreiraríeis": "enterreirar",
    "enterreiras": "enterreirar",
    "enterreirasse": "enterreirar",
    "enterreirassem": "enterreirar",
    "enterreirasses": "enterreirar",
    "enterreiraste": "enterreirar",
    "enterreirastes": "enterreirar",
    "enterreirava": "enterreirar",
    "enterreiravam": "enterreirar",
    "enterreiravas": "enterreirar",
    "enterreire": "enterreirar",
    "enterreirei": "enterreirar",
    "enterreireis": "enterreirar",
    "enterreirem": "enterreirar",
    "enterreiremo": "enterreirar",
    "enterreiremos": "enterreirar",
    "enterreires": "enterreirar",
    "enterreiro": "enterreirar",
    "enterreirou": "enterreirar",
    "enterreirá": "enterreirar",
    "enterreirámo": "enterreirar",
    "enterreirámos": "enterreirar",
    "enterreiráramo": "enterreirar",
    "enterreiráramos": "enterreirar",
    "enterreirárei": "enterreirar",
    "enterreiráreis": "enterreirar",
    "enterreirásseis": "enterreirar",
    "enterreirássemos": "enterreirar",
    "enterreirávamo": "enterreirar",
    "enterreirávamos": "enterreirar",
    "enterreirávei": "enterreirar",
    "enterreiráveis": "enterreirar",
    "enterreis": "enterrar",
    "enterrem": "enterrar",
    "enterremo": "enterrar",
    "enterremos": "enterrar",
    "enterres": "enterrar",
    "enterro": "enterrar",
    "enterroa": "enterroar",
    "enterroada": "enterroar",
    "enterroadas": "enterroar",
    "enterroado": "enterroar",
    "enterroados": "enterroar",
    "enterroai": "enterroar",
    "enterroais": "enterroar",
    "enterroam": "enterroar",
    "enterroamo": "enterroar",
    "enterroamos": "enterroar",
    "enterroando": "enterroar",
    "enterroara": "enterroar",
    "enterroaram": "enterroar",
    "enterroaras": "enterroar",
    "enterroarde": "enterroar",
    "enterroardes": "enterroar",
    "enterroare": "enterroar",
    "enterroarei": "enterroar",
    "enterroareis": "enterroar",
    "enterroarem": "enterroar",
    "enterroaremos": "enterroar",
    "enterroares": "enterroar",
    "enterroaria": "enterroar",
    "enterroariam": "enterroar",
    "enterroarias": "enterroar",
    "enterroarmo": "enterroar",
    "enterroarmos": "enterroar",
    "enterroará": "enterroar",
    "enterroarás": "enterroar",
    "enterroarão": "enterroar",
    "enterroaríamos": "enterroar",
    "enterroaríeis": "enterroar",
    "enterroas": "enterroar",
    "enterroasse": "enterroar",
    "enterroassem": "enterroar",
    "enterroasses": "enterroar",
    "enterroaste": "enterroar",
    "enterroastes": "enterroar",
    "enterroava": "enterroar",
    "enterroavam": "enterroar",
    "enterroavas": "enterroar",
    "enterroe": "enterroar",
    "enterroei": "enterroar",
    "enterroeis": "enterroar",
    "enterroem": "enterroar",
    "enterroemo": "enterroar",
    "enterroemos": "enterroar",
    "enterroes": "enterroar",
    "enterroo": "enterroar",
    "enterroou": "enterroar",
    "enterros": "enterro",
    "enterrou": "enterrar",
    "enterroá": "enterroar",
    "enterroámo": "enterroar",
    "enterroámos": "enterroar",
    "enterroáramo": "enterroar",
    "enterroáramos": "enterroar",
    "enterroárei": "enterroar",
    "enterroáreis": "enterroar",
    "enterroásseis": "enterroar",
    "enterroássemos": "enterroar",
    "enterroávamo": "enterroar",
    "enterroávamos": "enterroar",
    "enterroávei": "enterroar",
    "enterroáveis": "enterroar",
    "enterrá": "enterrar",
    "enterrámo": "enterrar",
    "enterrámos": "enterrar",
    "enterráramo": "enterrar",
    "enterráramos": "enterrar",
    "enterrárei": "enterrar",
    "enterráreis": "enterrar",
    "enterrásseis": "enterrar",
    "enterrássemos": "enterrar",
    "enterrávamo": "enterrar",
    "enterrávamos": "enterrar",
    "enterrávei": "enterrar",
    "enterráveis": "enterrar",
    "enterálgica": "enterálgico",
    "enterálgicas": "enterálgico",
    "enterálgicos": "enterálgico",
    "enterémica": "enterémico",
    "enterémicas": "enterémico",
    "enterémicos": "enterémico",
    "enterítica": "enterítico",
    "enteríticas": "enterítico",
    "enteríticos": "enterítico",
    "enteróclises": "enteróclise",
    "enterótica": "enterótico",
    "enteróticas": "enterótico",
    "enteróticos": "enterótico",
    "enterótomos": "enterótomo",
    "entes": "ente",
    "entesa": "entesar",
    "entesada": "entesar",
    "entesadas": "entesar",
    "entesado": "entesar",
    "entesados": "entesar",
    "entesaduras": "entesadura",
    "entesai": "entesar",
    "entesais": "entesar",
    "entesam": "entesar",
    "entesamentos": "entesamento",
    "entesamo": "entesar",
    "entesamos": "entesar",
    "entesando": "entesar",
    "entesara": "entesar",
    "entesaram": "entesar",
    "entesaras": "entesar",
    "entesarde": "entesar",
    "entesardes": "entesar",
    "entesare": "entesar",
    "entesarei": "entesar",
    "entesareis": "entesar",
    "entesarem": "entesar",
    "entesaremos": "entesar",
    "entesares": "entesar",
    "entesaria": "entesar",
    "entesariam": "entesar",
    "entesarias": "entesar",
    "entesarmo": "entesar",
    "entesarmos": "entesar",
    "entesará": "entesar",
    "entesarás": "entesar",
    "entesarão": "entesar",
    "entesaríamos": "entesar",
    "entesaríeis": "entesar",
    "entesas": "entesar",
    "entesasse": "entesar",
    "entesassem": "entesar",
    "entesasses": "entesar",
    "entesaste": "entesar",
    "entesastes": "entesar",
    "entesava": "entesar",
    "entesavam": "entesar",
    "entesavas": "entesar",
    "entese": "entesar",
    "entesei": "entesar",
    "enteseis": "entesar",
    "entesem": "entesar",
    "entesemo": "entesar",
    "entesemos": "entesar",
    "enteses": "entesar",
    "enteso": "entesar",
    "entesoira": "entesoirar",
    "entesoirada": "entesoirar",
    "entesoiradas": "entesoirar",
    "entesoirado": "entesoirar",
    "entesoirados": "entesoirar",
    "entesoirai": "entesoirar",
    "entesoirais": "entesoirar",
    "entesoiram": "entesoirar",
    "entesoiramentos": "entesoiramento",
    "entesoiramo": "entesoirar",
    "entesoiramos": "entesoirar",
    "entesoirando": "entesoirar",
    "entesoirara": "entesoirar",
    "entesoiraram": "entesoirar",
    "entesoiraras": "entesoirar",
    "entesoirarde": "entesoirar",
    "entesoirardes": "entesoirar",
    "entesoirare": "entesoirar",
    "entesoirarei": "entesoirar",
    "entesoirareis": "entesoirar",
    "entesoirarem": "entesoirar",
    "entesoiraremos": "entesoirar",
    "entesoirares": "entesoirar",
    "entesoiraria": "entesoirar",
    "entesoirariam": "entesoirar",
    "entesoirarias": "entesoirar",
    "entesoirarmo": "entesoirar",
    "entesoirarmos": "entesoirar",
    "entesoirará": "entesoirar",
    "entesoirarás": "entesoirar",
    "entesoirarão": "entesoirar",
    "entesoiraríamos": "entesoirar",
    "entesoiraríeis": "entesoirar",
    "entesoiras": "entesoirar",
    "entesoirasse": "entesoirar",
    "entesoirassem": "entesoirar",
    "entesoirasses": "entesoirar",
    "entesoiraste": "entesoirar",
    "entesoirastes": "entesoirar",
    "entesoirava": "entesoirar",
    "entesoiravam": "entesoirar",
    "entesoiravas": "entesoirar",
    "entesoire": "entesoirar",
    "entesoirei": "entesoirar",
    "entesoireis": "entesoirar",
    "entesoirem": "entesoirar",
    "entesoiremo": "entesoirar",
    "entesoiremos": "entesoirar",
    "entesoires": "entesoirar",
    "entesoiro": "entesoirar",
    "entesoirou": "entesoirar",
    "entesoirá": "entesoirar",
    "entesoirámo": "entesoirar",
    "entesoirámos": "entesoirar",
    "entesoiráramo": "entesoirar",
    "entesoiráramos": "entesoirar",
    "entesoirárei": "entesoirar",
    "entesoiráreis": "entesoirar",
    "entesoirásseis": "entesoirar",
    "entesoirássemos": "entesoirar",
    "entesoirávamo": "entesoirar",
    "entesoirávamos": "entesoirar",
    "entesoirávei": "entesoirar",
    "entesoiráveis": "entesoirar",
    "entesou": "entesar",
    "entesoura": "entesourar",
    "entesourada": "entesourar",
    "entesouradas": "entesourar",
    "entesourado": "entesourar",
    "entesourados": "entesourar",
    "entesourai": "entesourar",
    "entesourais": "entesourar",
    "entesouram": "entesourar",
    "entesouramentos": "entesouramento",
    "entesouramo": "entesourar",
    "entesouramos": "entesourar",
    "entesourando": "entesourar",
    "entesourara": "entesourar",
    "entesouraram": "entesourar",
    "entesouraras": "entesourar",
    "entesourarde": "entesourar",
    "entesourardes": "entesourar",
    "entesourare": "entesourar",
    "entesourarei": "entesourar",
    "entesourareis": "entesourar",
    "entesourarem": "entesourar",
    "entesouraremos": "entesourar",
    "entesourares": "entesourar",
    "entesouraria": "entesourar",
    "entesourariam": "entesourar",
    "entesourarias": "entesourar",
    "entesourarmo": "entesourar",
    "entesourarmos": "entesourar",
    "entesourará": "entesourar",
    "entesourarás": "entesourar",
    "entesourarão": "entesourar",
    "entesouraríamos": "entesourar",
    "entesouraríeis": "entesourar",
    "entesouras": "entesourar",
    "entesourasse": "entesourar",
    "entesourassem": "entesourar",
    "entesourasses": "entesourar",
    "entesouraste": "entesourar",
    "entesourastes": "entesourar",
    "entesourava": "entesourar",
    "entesouravam": "entesourar",
    "entesouravas": "entesourar",
    "entesoure": "entesourar",
    "entesourei": "entesourar",
    "entesoureis": "entesourar",
    "entesourem": "entesourar",
    "entesouremo": "entesourar",
    "entesouremos": "entesourar",
    "entesoures": "entesourar",
    "entesouro": "entesourar",
    "entesourou": "entesourar",
    "entesourá": "entesourar",
    "entesourámo": "entesourar",
    "entesourámos": "entesourar",
    "entesouráramo": "entesourar",
    "entesouráramos": "entesourar",
    "entesourárei": "entesourar",
    "entesouráreis": "entesourar",
    "entesourásseis": "entesourar",
    "entesourássemos": "entesourar",
    "entesourávamo": "entesourar",
    "entesourávamos": "entesourar",
    "entesourávei": "entesourar",
    "entesouráveis": "entesourar",
    "entesta": "entestar",
    "entestada": "entestar",
    "entestadas": "entestar",
    "entestado": "entestar",
    "entestados": "entestar",
    "entestai": "entestar",
    "entestais": "entestar",
    "entestam": "entestar",
    "entestamo": "entestar",
    "entestamos": "entestar",
    "entestando": "entestar",
    "entestara": "entestar",
    "entestaram": "entestar",
    "entestaras": "entestar",
    "entestarde": "entestar",
    "entestardes": "entestar",
    "entestare": "entestar",
    "entestarei": "entestar",
    "entestareis": "entestar",
    "entestarem": "entestar",
    "entestaremos": "entestar",
    "entestares": "entestar",
    "entestaria": "entestar",
    "entestariam": "entestar",
    "entestarias": "entestar",
    "entestarmo": "entestar",
    "entestarmos": "entestar",
    "entestará": "entestar",
    "entestarás": "entestar",
    "entestarão": "entestar",
    "entestaríamos": "entestar",
    "entestaríeis": "entestar",
    "entestas": "entestar",
    "entestasse": "entestar",
    "entestassem": "entestar",
    "entestasses": "entestar",
    "entestaste": "entestar",
    "entestastes": "entestar",
    "entestava": "entestar",
    "entestavam": "entestar",
    "entestavas": "entestar",
    "enteste": "entestar",
    "entestei": "entestar",
    "entesteis": "entestar",
    "entestem": "entestar",
    "entestemo": "entestar",
    "entestemos": "entestar",
    "entestes": "entestar",
    "entesto": "entestar",
    "entestou": "entestar",
    "entestá": "entestar",
    "entestámo": "entestar",
    "entestámos": "entestar",
    "entestáramo": "entestar",
    "entestáramos": "entestar",
    "entestárei": "entestar",
    "entestáreis": "entestar",
    "entestásseis": "entestar",
    "entestássemos": "entestar",
    "entestávamo": "entestar",
    "entestávamos": "entestar",
    "entestávei": "entestar",
    "entestáveis": "entestar",
    "entesá": "entesar",
    "entesámo": "entesar",
    "entesámos": "entesar",
    "entesáramo": "entesar",
    "entesáramos": "entesar",
    "entesárei": "entesar",
    "entesáreis": "entesar",
    "entesásseis": "entesar",
    "entesássemos": "entesar",
    "entesávamo": "entesar",
    "entesávamos": "entesar",
    "entesávei": "entesar",
    "entesáveis": "entesar",
    "enteá": "entear",
    "enteámo": "entear",
    "enteámos": "entear",
    "enteáramo": "entear",
    "enteáramos": "entear",
    "enteárei": "entear",
    "enteáreis": "entear",
    "enteásseis": "entear",
    "enteássemos": "entear",
    "enteávamo": "entear",
    "enteávamos": "entear",
    "enteávei": "entear",
    "enteáveis": "entear",
    "entibece": "entibecer",
    "entibecei": "entibecer",
    "entibeceis": "entibecer",
    "entibecem": "entibecer",
    "entibecemo": "entibecer",
    "entibecemos": "entibecer",
    "entibecendo": "entibecer",
    "entibecera": "entibecer",
    "entibeceram": "entibecer",
    "entibeceras": "entibecer",
    "entibecerdes": "entibecer",
    "entibecerei": "entibecer",
    "entibecereis": "entibecer",
    "entibecerem": "entibecer",
    "entibeceremos": "entibecer",
    "entibeceres": "entibecer",
    "entibeceria": "entibecer",
    "entibeceriam": "entibecer",
    "entibecerias": "entibecer",
    "entibecermo": "entibecer",
    "entibecermos": "entibecer",
    "entibecerá": "entibecer",
    "entibecerás": "entibecer",
    "entibecerão": "entibecer",
    "entibeceríamos": "entibecer",
    "entibeceríeis": "entibecer",
    "entibeces": "entibecer",
    "entibecesse": "entibecer",
    "entibecessem": "entibecer",
    "entibecesses": "entibecer",
    "entibeceste": "entibecer",
    "entibecestes": "entibecer",
    "entibeceu": "entibecer",
    "entibeci": "entibecer",
    "entibecia": "entibecer",
    "entibeciam": "entibecer",
    "entibecias": "entibecer",
    "entibecida": "entibecido",
    "entibecidas": "entibecido",
    "entibecido": "entibecer",
    "entibecidos": "entibecido",
    "entibecêramo": "entibecer",
    "entibecêramos": "entibecer",
    "entibecêreis": "entibecer",
    "entibecêsseis": "entibecer",
    "entibecêssemos": "entibecer",
    "entibecíamo": "entibecer",
    "entibecíamos": "entibecer",
    "entibecíeis": "entibecer",
    "entibeça": "entibecer",
    "entibeçais": "entibecer",
    "entibeçam": "entibecer",
    "entibeçamo": "entibecer",
    "entibeçamos": "entibecer",
    "entibeças": "entibecer",
    "entibeço": "entibecer",
    "entibia": "entibiar",
    "entibiada": "entibiar",
    "entibiadas": "entibiar",
    "entibiado": "entibiar",
    "entibiados": "entibiar",
    "entibiai": "entibiar",
    "entibiais": "entibiar",
    "entibiam": "entibiar",
    "entibiamentos": "entibiamento",
    "entibiamo": "entibiar",
    "entibiamos": "entibiar",
    "entibiando": "entibiar",
    "entibiara": "entibiar",
    "entibiaram": "entibiar",
    "entibiaras": "entibiar",
    "entibiarde": "entibiar",
    "entibiardes": "entibiar",
    "entibiare": "entibiar",
    "entibiarei": "entibiar",
    "entibiareis": "entibiar",
    "entibiarem": "entibiar",
    "entibiaremos": "entibiar",
    "entibiares": "entibiar",
    "entibiaria": "entibiar",
    "entibiariam": "entibiar",
    "entibiarias": "entibiar",
    "entibiarmo": "entibiar",
    "entibiarmos": "entibiar",
    "entibiará": "entibiar",
    "entibiarás": "entibiar",
    "entibiarão": "entibiar",
    "entibiaríamos": "entibiar",
    "entibiaríeis": "entibiar",
    "entibias": "entibiar",
    "entibiasse": "entibiar",
    "entibiassem": "entibiar",
    "entibiasses": "entibiar",
    "entibiaste": "entibiar",
    "entibiastes": "entibiar",
    "entibiava": "entibiar",
    "entibiavam": "entibiar",
    "entibiavas": "entibiar",
    "entibie": "entibiar",
    "entibiei": "entibiar",
    "entibieis": "entibiar",
    "entibiem": "entibiar",
    "entibiemo": "entibiar",
    "entibiemos": "entibiar",
    "entibies": "entibiar",
    "entibio": "entibiar",
    "entibiou": "entibiar",
    "entibiá": "entibiar",
    "entibiámo": "entibiar",
    "entibiámos": "entibiar",
    "entibiáramo": "entibiar",
    "entibiáramos": "entibiar",
    "entibiárei": "entibiar",
    "entibiáreis": "entibiar",
    "entibiásseis": "entibiar",
    "entibiássemos": "entibiar",
    "entibiávamo": "entibiar",
    "entibiávamos": "entibiar",
    "entibiávei": "entibiar",
    "entibiáveis": "entibiar",
    "entidades": "entidade",
    "entijola": "entijolar",
    "entijolada": "entijolar",
    "entijoladas": "entijolar",
    "entijolado": "entijolar",
    "entijolados": "entijolar",
    "entijolai": "entijolar",
    "entijolais": "entijolar",
    "entijolam": "entijolar",
    "entijolamentos": "entijolamento",
    "entijolamo": "entijolar",
    "entijolamos": "entijolar",
    "entijolando": "entijolar",
    "entijolara": "entijolar",
    "entijolaram": "entijolar",
    "entijolaras": "entijolar",
    "entijolarde": "entijolar",
    "entijolardes": "entijolar",
    "entijolare": "entijolar",
    "entijolarei": "entijolar",
    "entijolareis": "entijolar",
    "entijolarem": "entijolar",
    "entijolaremos": "entijolar",
    "entijolares": "entijolar",
    "entijolaria": "entijolar",
    "entijolariam": "entijolar",
    "entijolarias": "entijolar",
    "entijolarmo": "entijolar",
    "entijolarmos": "entijolar",
    "entijolará": "entijolar",
    "entijolarás": "entijolar",
    "entijolarão": "entijolar",
    "entijolaríamos": "entijolar",
    "entijolaríeis": "entijolar",
    "entijolas": "entijolar",
    "entijolasse": "entijolar",
    "entijolassem": "entijolar",
    "entijolasses": "entijolar",
    "entijolaste": "entijolar",
    "entijolastes": "entijolar",
    "entijolava": "entijolar",
    "entijolavam": "entijolar",
    "entijolavas": "entijolar",
    "entijole": "entijolar",
    "entijolei": "entijolar",
    "entijoleis": "entijolar",
    "entijolem": "entijolar",
    "entijolemo": "entijolar",
    "entijolemos": "entijolar",
    "entijoles": "entijolar",
    "entijolo": "entijolar",
    "entijolou": "entijolar",
    "entijolá": "entijolar",
    "entijolámo": "entijolar",
    "entijolámos": "entijolar",
    "entijoláramo": "entijolar",
    "entijoláramos": "entijolar",
    "entijolárei": "entijolar",
    "entijoláreis": "entijolar",
    "entijolásseis": "entijolar",
    "entijolássemos": "entijolar",
    "entijolávamo": "entijolar",
    "entijolávamos": "entijolar",
    "entijolávei": "entijolar",
    "entijoláveis": "entijolar",
    "entimemas": "entimema",
    "entintamentos": "entintamento",
    "entisica": "entisicar",
    "entisicada": "entisicar",
    "entisicadas": "entisicar",
    "entisicado": "entisicar",
    "entisicados": "entisicar",
    "entisicais": "entisicar",
    "entisicam": "entisicar",
    "entisicamo": "entisicar",
    "entisicamos": "entisicar",
    "entisicando": "entisicar",
    "entisicara": "entisicar",
    "entisicaram": "entisicar",
    "entisicaras": "entisicar",
    "entisicardes": "entisicar",
    "entisicarei": "entisicar",
    "entisicareis": "entisicar",
    "entisicarem": "entisicar",
    "entisicaremos": "entisicar",
    "entisicares": "entisicar",
    "entisicaria": "entisicar",
    "entisicariam": "entisicar",
    "entisicarias": "entisicar",
    "entisicarmo": "entisicar",
    "entisicarmos": "entisicar",
    "entisicará": "entisicar",
    "entisicarás": "entisicar",
    "entisicarão": "entisicar",
    "entisicaríamos": "entisicar",
    "entisicaríeis": "entisicar",
    "entisicas": "entisicar",
    "entisicasse": "entisicar",
    "entisicassem": "entisicar",
    "entisicasses": "entisicar",
    "entisicaste": "entisicar",
    "entisicastes": "entisicar",
    "entisicava": "entisicar",
    "entisicavam": "entisicar",
    "entisicavas": "entisicar",
    "entisico": "entisicar",
    "entisicou": "entisicar",
    "entisicámo": "entisicar",
    "entisicámos": "entisicar",
    "entisicáramo": "entisicar",
    "entisicáramos": "entisicar",
    "entisicáreis": "entisicar",
    "entisicásseis": "entisicar",
    "entisicássemos": "entisicar",
    "entisicávamo": "entisicar",
    "entisicávamos": "entisicar",
    "entisicáveis": "entisicar",
    "entisique": "entisicar",
    "entisiquei": "entisicar",
    "entisiqueis": "entisicar",
    "entisiquem": "entisicar",
    "entisiquemos": "entisicar",
    "entisiques": "entisicar",
    "entiva": "entivar",
    "entivada": "entivar",
    "entivadas": "entivar",
    "entivado": "entivar",
    "entivadora": "entivador",
    "entivadoras": "entivador",
    "entivadores": "entivador",
    "entivados": "entivar",
    "entivai": "entivar",
    "entivais": "entivar",
    "entivam": "entivar",
    "entivamo": "entivar",
    "entivamos": "entivar",
    "entivando": "entivar",
    "entivara": "entivar",
    "entivaram": "entivar",
    "entivaras": "entivar",
    "entivarde": "entivar",
    "entivardes": "entivar",
    "entivare": "entivar",
    "entivarei": "entivar",
    "entivareis": "entivar",
    "entivarem": "entivar",
    "entivaremos": "entivar",
    "entivares": "entivar",
    "entivaria": "entivar",
    "entivariam": "entivar",
    "entivarias": "entivar",
    "entivarmo": "entivar",
    "entivarmos": "entivar",
    "entivará": "entivar",
    "entivarás": "entivar",
    "entivarão": "entivar",
    "entivaríamos": "entivar",
    "entivaríeis": "entivar",
    "entivas": "entivar",
    "entivasse": "entivar",
    "entivassem": "entivar",
    "entivasses": "entivar",
    "entivaste": "entivar",
    "entivastes": "entivar",
    "entivava": "entivar",
    "entivavam": "entivar",
    "entivavas": "entivar",
    "entivações": "entivação",
    "entive": "entivar",
    "entivei": "entivar",
    "entiveis": "entivar",
    "entivem": "entivar",
    "entivemo": "entivar",
    "entivemos": "entivar",
    "entives": "entivar",
    "entivo": "entivar",
    "entivou": "entivar",
    "entivá": "entivar",
    "entivámo": "entivar",
    "entivámos": "entivar",
    "entiváramo": "entivar",
    "entiváramos": "entivar",
    "entivárei": "entivar",
    "entiváreis": "entivar",
    "entivásseis": "entivar",
    "entivássemos": "entivar",
    "entivávamo": "entivar",
    "entivávamos": "entivar",
    "entivávei": "entivar",
    "entiváveis": "entivar",
    "entoa": "entoar",
    "entoada": "entoar",
    "entoadas": "entoar",
    "entoado": "entoar",
    "entoadora": "entoador",
    "entoadoras": "entoador",
    "entoadores": "entoador",
    "entoados": "entoar",
    "entoai": "entoar",
    "entoais": "entoar",
    "entoalhada": "entoalhado",
    "entoalhadas": "entoalhado",
    "entoalhados": "entoalhado",
    "entoam": "entoar",
    "entoamentos": "entoamento",
    "entoamo": "entoar",
    "entoamos": "entoar",
    "entoando": "entoar",
    "entoara": "entoar",
    "entoaram": "entoar",
    "entoaras": "entoar",
    "entoarde": "entoar",
    "entoardes": "entoar",
    "entoare": "entoar",
    "entoarei": "entoar",
    "entoareis": "entoar",
    "entoarem": "entoar",
    "entoaremos": "entoar",
    "entoares": "entoar",
    "entoaria": "entoar",
    "entoariam": "entoar",
    "entoarias": "entoar",
    "entoarmo": "entoar",
    "entoarmos": "entoar",
    "entoará": "entoar",
    "entoarás": "entoar",
    "entoarão": "entoar",
    "entoaríamos": "entoar",
    "entoaríeis": "entoar",
    "entoas": "entoar",
    "entoasse": "entoar",
    "entoassem": "entoar",
    "entoasses": "entoar",
    "entoaste": "entoar",
    "entoastes": "entoar",
    "entoava": "entoar",
    "entoavam": "entoar",
    "entoavas": "entoar",
    "entoações": "entoação",
    "entoblastos": "entoblasto",
    "entoblástica": "entoblástico",
    "entoblásticas": "entoblástico",
    "entoblásticos": "entoblástico",
    "entoca": "entocar",
    "entocada": "entocar",
    "entocadas": "entocar",
    "entocado": "entocar",
    "entocados": "entocar",
    "entocai": "entocar",
    "entocais": "entocar",
    "entocam": "entocar",
    "entocamentos": "entocamento",
    "entocamo": "entocar",
    "entocamos": "entocar",
    "entocando": "entocar",
    "entocara": "entocar",
    "entocaram": "entocar",
    "entocaras": "entocar",
    "entocarde": "entocar",
    "entocardes": "entocar",
    "entocare": "entocar",
    "entocarei": "entocar",
    "entocareis": "entocar",
    "entocarem": "entocar",
    "entocaremos": "entocar",
    "entocares": "entocar",
    "entocaria": "entocar",
    "entocariam": "entocar",
    "entocarias": "entocar",
    "entocarmo": "entocar",
    "entocarmos": "entocar",
    "entocará": "entocar",
    "entocarás": "entocar",
    "entocarão": "entocar",
    "entocaríamos": "entocar",
    "entocaríeis": "entocar",
    "entocas": "entocar",
    "entocasse": "entocar",
    "entocassem": "entocar",
    "entocasses": "entocar",
    "entocaste": "entocar",
    "entocastes": "entocar",
    "entocava": "entocar",
    "entocavam": "entocar",
    "entocavas": "entocar",
    "entocnémea": "entocnémeo",
    "entocnémeas": "entocnémeo",
    "entocnémeos": "entocnémeo",
    "entoco": "entocar",
    "entocou": "entocar",
    "entocá": "entocar",
    "entocámo": "entocar",
    "entocámos": "entocar",
    "entocáramo": "entocar",
    "entocáramos": "entocar",
    "entocárei": "entocar",
    "entocáreis": "entocar",
    "entocásseis": "entocar",
    "entocássemos": "entocar",
    "entocávamo": "entocar",
    "entocávamos": "entocar",
    "entocávei": "entocar",
    "entocáveis": "entocar",
    "entodermas": "entoderma",
    "entodermes": "entoderme",
    "entodérmica": "entodérmico",
    "entodérmicas": "entodérmico",
    "entodérmicos": "entodérmico",
    "entoe": "entoar",
    "entoei": "entoar",
    "entoeis": "entoar",
    "entoem": "entoar",
    "entoemo": "entoar",
    "entoemos": "entoar",
    "entoes": "entoar",
    "entoftalmias": "entoftalmia",
    "entoftálmica": "entoftálmico",
    "entoftálmicas": "entoftálmico",
    "entoftálmicos": "entoftálmico",
    "entoga": "entogar",
    "entogada": "entogar",
    "entogadas": "entogar",
    "entogado": "entogar",
    "entogados": "entogar",
    "entogai": "entogar",
    "entogais": "entogar",
    "entogam": "entogar",
    "entogamo": "entogar",
    "entogamos": "entogar",
    "entogando": "entogar",
    "entogara": "entogar",
    "entogaram": "entogar",
    "entogaras": "entogar",
    "entogarde": "entogar",
    "entogardes": "entogar",
    "entogare": "entogar",
    "entogarei": "entogar",
    "entogareis": "entogar",
    "entogarem": "entogar",
    "entogaremos": "entogar",
    "entogares": "entogar",
    "entogaria": "entogar",
    "entogariam": "entogar",
    "entogarias": "entogar",
    "entogarmo": "entogar",
    "entogarmos": "entogar",
    "entogará": "entogar",
    "entogarás": "entogar",
    "entogarão": "entogar",
    "entogaríamos": "entogar",
    "entogaríeis": "entogar",
    "entogas": "entogar",
    "entogasse": "entogar",
    "entogassem": "entogar",
    "entogasses": "entogar",
    "entogaste": "entogar",
    "entogastes": "entogar",
    "entogava": "entogar",
    "entogavam": "entogar",
    "entogavas": "entogar",
    "entogo": "entogar",
    "entogou": "entogar",
    "entogue": "entogar",
    "entoguei": "entogar",
    "entogueis": "entogar",
    "entoguem": "entogar",
    "entoguemo": "entogar",
    "entoguemos": "entogar",
    "entogues": "entogar",
    "entogá": "entogar",
    "entogámo": "entogar",
    "entogámos": "entogar",
    "entogáramo": "entogar",
    "entogáramos": "entogar",
    "entogárei": "entogar",
    "entogáreis": "entogar",
    "entogásseis": "entogar",
    "entogássemos": "entogar",
    "entogávamo": "entogar",
    "entogávamos": "entogar",
    "entogávei": "entogar",
    "entogáveis": "entogar",
    "entoice": "entoiçar",
    "entoicei": "entoiçar",
    "entoiceira": "entoiceirar",
    "entoiceirada": "entoiceirar",
    "entoiceiradas": "entoiceirar",
    "entoiceirado": "entoiceirar",
    "entoiceirados": "entoiceirar",
    "entoiceirai": "entoiceirar",
    "entoiceirais": "entoiceirar",
    "entoiceiram": "entoiceirar",
    "entoiceiramo": "entoiceirar",
    "entoiceiramos": "entoiceirar",
    "entoiceirando": "entoiceirar",
    "entoiceirara": "entoiceirar",
    "entoiceiraram": "entoiceirar",
    "entoiceiraras": "entoiceirar",
    "entoiceirarde": "entoiceirar",
    "entoiceirardes": "entoiceirar",
    "entoiceirare": "entoiceirar",
    "entoiceirarei": "entoiceirar",
    "entoiceirareis": "entoiceirar",
    "entoiceirarem": "entoiceirar",
    "entoiceiraremos": "entoiceirar",
    "entoiceirares": "entoiceirar",
    "entoiceiraria": "entoiceirar",
    "entoiceirariam": "entoiceirar",
    "entoiceirarias": "entoiceirar",
    "entoiceirarmo": "entoiceirar",
    "entoiceirarmos": "entoiceirar",
    "entoiceirará": "entoiceirar",
    "entoiceirarás": "entoiceirar",
    "entoiceirarão": "entoiceirar",
    "entoiceiraríamos": "entoiceirar",
    "entoiceiraríeis": "entoiceirar",
    "entoiceiras": "entoiceirar",
    "entoiceirasse": "entoiceirar",
    "entoiceirassem": "entoiceirar",
    "entoiceirasses": "entoiceirar",
    "entoiceiraste": "entoiceirar",
    "entoiceirastes": "entoiceirar",
    "entoiceirava": "entoiceirar",
    "entoiceiravam": "entoiceirar",
    "entoiceiravas": "entoiceirar",
    "entoiceire": "entoiceirar",
    "entoiceirei": "entoiceirar",
    "entoiceireis": "entoiceirar",
    "entoiceirem": "entoiceirar",
    "entoiceiremo": "entoiceirar",
    "entoiceiremos": "entoiceirar",
    "entoiceires": "entoiceirar",
    "entoiceiro": "entoiceirar",
    "entoiceirou": "entoiceirar",
    "entoiceirá": "entoiceirar",
    "entoiceirámo": "entoiceirar",
    "entoiceirámos": "entoiceirar",
    "entoiceiráramo": "entoiceirar",
    "entoiceiráramos": "entoiceirar",
    "entoiceirárei": "entoiceirar",
    "entoiceiráreis": "entoiceirar",
    "entoiceirásseis": "entoiceirar",
    "entoiceirássemos": "entoiceirar",
    "entoiceirávamo": "entoiceirar",
    "entoiceirávamos": "entoiceirar",
    "entoiceirávei": "entoiceirar",
    "entoiceiráveis": "entoiceirar",
    "entoiceis": "entoiçar",
    "entoicem": "entoiçar",
    "entoicemo": "entoiçar",
    "entoicemos": "entoiçar",
    "entoices": "entoiçar",
    "entoira": "entoirir",
    "entoirada": "entoirar",
    "entoiradas": "entoirar",
    "entoiradiça": "entoiradiço",
    "entoiradiças": "entoiradiço",
    "entoiradiços": "entoiradiço",
    "entoirado": "entoirar",
    "entoirados": "entoirar",
    "entoirai": "entoirar",
    "entoirais": "entoirir",
    "entoiram": "entoirir",
    "entoiramo": "entoirir",
    "entoiramos": "entoirir",
    "entoirando": "entoirar",
    "entoirara": "entoirar",
    "entoiraram": "entoirar",
    "entoiraras": "entoirar",
    "entoirardes": "entoirar",
    "entoirarei": "entoirar",
    "entoirareis": "entoirar",
    "entoirarem": "entoirar",
    "entoiraremos": "entoirar",
    "entoirares": "entoirar",
    "entoiraria": "entoirar",
    "entoirariam": "entoirar",
    "entoirarias": "entoirar",
    "entoirarmo": "entoirar",
    "entoirarmos": "entoirar",
    "entoirará": "entoirar",
    "entoirarás": "entoirar",
    "entoirarão": "entoirar",
    "entoiraríamos": "entoirar",
    "entoiraríeis": "entoirar",
    "entoiras": "entoirir",
    "entoirasse": "entoirar",
    "entoirassem": "entoirar",
    "entoirasses": "entoirar",
    "entoiraste": "entoirar",
    "entoirastes": "entoirar",
    "entoirava": "entoirar",
    "entoiravam": "entoirar",
    "entoiravas": "entoirar",
    "entoire": "entoirir",
    "entoirei": "entoirar",
    "entoireis": "entoirar",
    "entoirem": "entoirir",
    "entoiremo": "entoirar",
    "entoiremos": "entoirar",
    "entoires": "entoirir",
    "entoiri": "entoirir",
    "entoiria": "entoirir",
    "entoiriam": "entoirir",
    "entoirias": "entoirir",
    "entoirida": "entoirir",
    "entoiridas": "entoirir",
    "entoirido": "entoirir",
    "entoiridos": "entoirir",
    "entoirimo": "entoirir",
    "entoirimos": "entoirir",
    "entoirindo": "entoirir",
    "entoirira": "entoirir",
    "entoiriram": "entoirir",
    "entoiriras": "entoirir",
    "entoirirdes": "entoirir",
    "entoirirei": "entoirir",
    "entoirireis": "entoirir",
    "entoirirem": "entoirir",
    "entoiriremos": "entoirir",
    "entoirires": "entoirir",
    "entoiriria": "entoirir",
    "entoiririam": "entoirir",
    "entoiririas": "entoirir",
    "entoirirmo": "entoirir",
    "entoirirmos": "entoirir",
    "entoirirá": "entoirir",
    "entoirirás": "entoirir",
    "entoirirão": "entoirir",
    "entoiriríamos": "entoirir",
    "entoiriríeis": "entoirir",
    "entoiris": "entoirir",
    "entoirisse": "entoirir",
    "entoirissem": "entoirir",
    "entoirisses": "entoirir",
    "entoiriste": "entoirir",
    "entoiristes": "entoirir",
    "entoiriu": "entoirir",
    "entoiriçada": "entoiriçado",
    "entoiriçadas": "entoiriçado",
    "entoiriçados": "entoiriçado",
    "entoiro": "entoirir",
    "entoirou": "entoirar",
    "entoirámo": "entoirar",
    "entoirámos": "entoirar",
    "entoiráramo": "entoirar",
    "entoiráramos": "entoirar",
    "entoiráreis": "entoirar",
    "entoirásseis": "entoirar",
    "entoirássemos": "entoirar",
    "entoirávamo": "entoirar",
    "entoirávamos": "entoirar",
    "entoiráveis": "entoirar",
    "entoiríamo": "entoirir",
    "entoiríamos": "entoirir",
    "entoiríeis": "entoirir",
    "entoiríramo": "entoirir",
    "entoiríramos": "entoirir",
    "entoiríreis": "entoirir",
    "entoirísseis": "entoirir",
    "entoiríssemos": "entoirir",
    "entoiça": "entoiçar",
    "entoiçada": "entoiçar",
    "entoiçadas": "entoiçar",
    "entoiçado": "entoiçar",
    "entoiçados": "entoiçar",
    "entoiçai": "entoiçar",
    "entoiçais": "entoiçar",
    "entoiçam": "entoiçar",
    "entoiçamo": "entoiçar",
    "entoiçamos": "entoiçar",
    "entoiçando": "entoiçar",
    "entoiçara": "entoiçar",
    "entoiçaram": "entoiçar",
    "entoiçaras": "entoiçar",
    "entoiçardes": "entoiçar",
    "entoiçarei": "entoiçar",
    "entoiçareis": "entoiçar",
    "entoiçarem": "entoiçar",
    "entoiçaremos": "entoiçar",
    "entoiçares": "entoiçar",
    "entoiçaria": "entoiçar",
    "entoiçariam": "entoiçar",
    "entoiçarias": "entoiçar",
    "entoiçarmo": "entoiçar",
    "entoiçarmos": "entoiçar",
    "entoiçará": "entoiçar",
    "entoiçarás": "entoiçar",
    "entoiçarão": "entoiçar",
    "entoiçaríamos": "entoiçar",
    "entoiçaríeis": "entoiçar",
    "entoiças": "entoiçar",
    "entoiçasse": "entoiçar",
    "entoiçassem": "entoiçar",
    "entoiçasses": "entoiçar",
    "entoiçaste": "entoiçar",
    "entoiçastes": "entoiçar",
    "entoiçava": "entoiçar",
    "entoiçavam": "entoiçar",
    "entoiçavas": "entoiçar",
    "entoiço": "entoiçar",
    "entoiçou": "entoiçar",
    "entoiçámo": "entoiçar",
    "entoiçámos": "entoiçar",
    "entoiçáramo": "entoiçar",
    "entoiçáramos": "entoiçar",
    "entoiçáreis": "entoiçar",
    "entoiçásseis": "entoiçar",
    "entoiçássemos": "entoiçar",
    "entoiçávamo": "entoiçar",
    "entoiçávamos": "entoiçar",
    "entoiçáveis": "entoiçar",
    "entoja": "entojar",
    "entojada": "entojar",
    "entojadas": "entojar",
    "entojado": "entojar",
    "entojados": "entojar",
    "entojai": "entojar",
    "entojais": "entojar",
    "entojam": "entojar",
    "entojamo": "entojar",
    "entojamos": "entojar",
    "entojando": "entojar",
    "entojara": "entojar",
    "entojaram": "entojar",
    "entojaras": "entojar",
    "entojarde": "entojar",
    "entojardes": "entojar",
    "entojare": "entojar",
    "entojarei": "entojar",
    "entojareis": "entojar",
    "entojarem": "entojar",
    "entojaremos": "entojar",
    "entojares": "entojar",
    "entojaria": "entojar",
    "entojariam": "entojar",
    "entojarias": "entojar",
    "entojarmo": "entojar",
    "entojarmos": "entojar",
    "entojará": "entojar",
    "entojarás": "entojar",
    "entojarão": "entojar",
    "entojaríamos": "entojar",
    "entojaríeis": "entojar",
    "entojas": "entojar",
    "entojasse": "entojar",
    "entojassem": "entojar",
    "entojasses": "entojar",
    "entojaste": "entojar",
    "entojastes": "entojar",
    "entojava": "entojar",
    "entojavam": "entojar",
    "entojavas": "entojar",
    "entoje": "entojar",
    "entojei": "entojar",
    "entojeis": "entojar",
    "entojem": "entojar",
    "entojemo": "entojar",
    "entojemos": "entojar",
    "entojes": "entojar",
    "entojo": "entojar",
    "entojos": "entojo",
    "entojou": "entojar",
    "entojá": "entojar",
    "entojámo": "entojar",
    "entojámos": "entojar",
    "entojáramo": "entojar",
    "entojáramos": "entojar",
    "entojárei": "entojar",
    "entojáreis": "entojar",
    "entojásseis": "entojar",
    "entojássemos": "entojar",
    "entojávamo": "entojar",
    "entojávamos": "entojar",
    "entojávei": "entojar",
    "entojáveis": "entojar",
    "entomologias": "entomologia",
    "entomologistas": "entomologista",
    "entomológica": "entomológico",
    "entomológicas": "entomológico",
    "entomológicos": "entomológico",
    "entomostrácea": "entomostráceo",
    "entomostráceas": "entomostráceo",
    "entomostráceos": "entomostráceo",
    "entomozoária": "entomozoário",
    "entomozoárias": "entomozoário",
    "entomozoários": "entomozoário",
    "entomófaga": "entomófago",
    "entomófagas": "entomófago",
    "entomófagos": "entomófago",
    "entomófila": "entomófilo",
    "entomófilas": "entomófilo",
    "entomófilos": "entomófilo",
    "entomógama": "entomógamo",
    "entomógamas": "entomógamo",
    "entomógamos": "entomógamo",
    "entomóloga": "entomólogo",
    "entomólogas": "entomólogo",
    "entomólogos": "entomólogo",
    "entona": "entonar",
    "entonada": "entonar",
    "entonadas": "entonar",
    "entonado": "entonar",
    "entonados": "entonar",
    "entonai": "entonar",
    "entonais": "entonar",
    "entonam": "entonar",
    "entonamo": "entonar",
    "entonamos": "entonar",
    "entonando": "entonar",
    "entonara": "entonar",
    "entonaram": "entonar",
    "entonaras": "entonar",
    "entonarde": "entonar",
    "entonardes": "entonar",
    "entonare": "entonar",
    "entonarei": "entonar",
    "entonareis": "entonar",
    "entonarem": "entonar",
    "entonaremos": "entonar",
    "entonares": "entonar",
    "entonaria": "entonar",
    "entonariam": "entonar",
    "entonarias": "entonar",
    "entonarmo": "entonar",
    "entonarmos": "entonar",
    "entonará": "entonar",
    "entonarás": "entonar",
    "entonarão": "entonar",
    "entonaríamos": "entonar",
    "entonaríeis": "entonar",
    "entonas": "entonar",
    "entonasse": "entonar",
    "entonassem": "entonar",
    "entonasses": "entonar",
    "entonaste": "entonar",
    "entonastes": "entonar",
    "entonava": "entonar",
    "entonavam": "entonar",
    "entonavas": "entonar",
    "entonações": "entonação",
    "entone": "entonar",
    "entonei": "entonar",
    "entoneis": "entonar",
    "entonem": "entonar",
    "entonemo": "entonar",
    "entonemos": "entonar",
    "entones": "entonar",
    "entono": "entonar",
    "entonos": "entono",
    "entonou": "entonar",
    "entonta": "entontar",
    "entontada": "entontar",
    "entontadas": "entontar",
    "entontado": "entontar",
    "entontados": "entontar",
    "entontai": "entontar",
    "entontais": "entontar",
    "entontam": "entontar",
    "entontamo": "entontar",
    "entontamos": "entontar",
    "entontando": "entontar",
    "entontara": "entontar",
    "entontaram": "entontar",
    "entontaras": "entontar",
    "entontarde": "entontar",
    "entontardes": "entontar",
    "entontare": "entontar",
    "entontarei": "entontar",
    "entontareis": "entontar",
    "entontarem": "entontar",
    "entontaremos": "entontar",
    "entontares": "entontar",
    "entontaria": "entontar",
    "entontariam": "entontar",
    "entontarias": "entontar",
    "entontarmo": "entontar",
    "entontarmos": "entontar",
    "entontará": "entontar",
    "entontarás": "entontar",
    "entontarão": "entontar",
    "entontaríamos": "entontar",
    "entontaríeis": "entontar",
    "entontas": "entontar",
    "entontasse": "entontar",
    "entontassem": "entontar",
    "entontasses": "entontar",
    "entontaste": "entontar",
    "entontastes": "entontar",
    "entontava": "entontar",
    "entontavam": "entontar",
    "entontavas": "entontar",
    "entonte": "entontar",
    "entontece": "entontecer",
    "entontecei": "entontecer",
    "entonteceis": "entontecer",
    "entontecem": "entontecer",
    "entontecemo": "entontecer",
    "entontecemos": "entontecer",
    "entontecendo": "entontecer",
    "entontecera": "entontecer",
    "entonteceram": "entontecer",
    "entonteceras": "entontecer",
    "entontecerde": "entontecer",
    "entontecerdes": "entontecer",
    "entontecere": "entontecer",
    "entontecerei": "entontecer",
    "entontecereis": "entontecer",
    "entontecerem": "entontecer",
    "entonteceremos": "entontecer",
    "entonteceres": "entontecer",
    "entonteceria": "entontecer",
    "entonteceriam": "entontecer",
    "entontecerias": "entontecer",
    "entontecermo": "entontecer",
    "entontecermos": "entontecer",
    "entontecerá": "entontecer",
    "entontecerás": "entontecer",
    "entontecerão": "entontecer",
    "entonteceríamos": "entontecer",
    "entonteceríeis": "entontecer",
    "entonteces": "entontecer",
    "entontecesse": "entontecer",
    "entontecessem": "entontecer",
    "entontecesses": "entontecer",
    "entonteceste": "entontecer",
    "entontecestes": "entontecer",
    "entonteceu": "entontecer",
    "entonteci": "entontecer",
    "entontecia": "entontecer",
    "entonteciam": "entontecer",
    "entontecias": "entontecer",
    "entontecida": "entontecido",
    "entontecidas": "entontecido",
    "entontecido": "entontecer",
    "entontecidos": "entontecido",
    "entontecimentos": "entontecimento",
    "entontecê": "entontecer",
    "entontecêramo": "entontecer",
    "entontecêramos": "entontecer",
    "entontecêrei": "entontecer",
    "entontecêreis": "entontecer",
    "entontecêsseis": "entontecer",
    "entontecêssemos": "entontecer",
    "entontecíamo": "entontecer",
    "entontecíamos": "entontecer",
    "entontecíei": "entontecer",
    "entontecíeis": "entontecer",
    "entontei": "entontar",
    "entonteis": "entontar",
    "entontem": "entontar",
    "entontemo": "entontar",
    "entontemos": "entontar",
    "entontes": "entontar",
    "entonteça": "entontecer",
    "entonteçais": "entontecer",
    "entonteçam": "entontecer",
    "entonteçamo": "entontecer",
    "entonteçamos": "entontecer",
    "entonteças": "entontecer",
    "entonteço": "entontecer",
    "entonto": "entontar",
    "entontou": "entontar",
    "entontá": "entontar",
    "entontámo": "entontar",
    "entontámos": "entontar",
    "entontáramo": "entontar",
    "entontáramos": "entontar",
    "entontárei": "entontar",
    "entontáreis": "entontar",
    "entontásseis": "entontar",
    "entontássemos": "entontar",
    "entontávamo": "entontar",
    "entontávamos": "entontar",
    "entontávei": "entontar",
    "entontáveis": "entontar",
    "entoná": "entonar",
    "entonámo": "entonar",
    "entonámos": "entonar",
    "entonáramo": "entonar",
    "entonáramos": "entonar",
    "entonárei": "entonar",
    "entonáreis": "entonar",
    "entonásseis": "entonar",
    "entonássemos": "entonar",
    "entonávamo": "entonar",
    "entonávamos": "entonar",
    "entonávei": "entonar",
    "entonáveis": "entonável",
    "entoo": "entoar",
    "entoou": "entoar",
    "entope": "entupir",
    "entopem": "entupir",
    "entopes": "entupir",
    "entoque": "entocar",
    "entoquei": "entocar",
    "entoqueis": "entocar",
    "entoquem": "entocar",
    "entoquemo": "entocar",
    "entoquemos": "entocar",
    "entoques": "entocar",
    "entorna": "entornar",
    "entornada": "entornar",
    "entornadas": "entornar",
    "entornado": "entornar",
    "entornados": "entornar",
    "entornai": "entornar",
    "entornais": "entornar",
    "entornam": "entornar",
    "entornamo": "entornar",
    "entornamos": "entornar",
    "entornando": "entornar",
    "entornara": "entornar",
    "entornaram": "entornar",
    "entornaras": "entornar",
    "entornarde": "entornar",
    "entornardes": "entornar",
    "entornare": "entornar",
    "entornarei": "entornar",
    "entornareis": "entornar",
    "entornarem": "entornar",
    "entornaremos": "entornar",
    "entornares": "entornar",
    "entornaria": "entornar",
    "entornariam": "entornar",
    "entornarias": "entornar",
    "entornarmo": "entornar",
    "entornarmos": "entornar",
    "entornará": "entornar",
    "entornarás": "entornar",
    "entornarão": "entornar",
    "entornaríamos": "entornar",
    "entornaríeis": "entornar",
    "entornas": "entornar",
    "entornasse": "entornar",
    "entornassem": "entornar",
    "entornasses": "entornar",
    "entornaste": "entornar",
    "entornastes": "entornar",
    "entornava": "entornar",
    "entornavam": "entornar",
    "entornavas": "entornar",
    "entorne": "entornar",
    "entornei": "entornar",
    "entorneiros": "entorneiro",
    "entorneis": "entornar",
    "entornem": "entornar",
    "entornemo": "entornar",
    "entornemos": "entornar",
    "entornes": "entornar",
    "entorno": "entornar",
    "entornou": "entornar",
    "entorná": "entornar",
    "entornámo": "entornar",
    "entornámos": "entornar",
    "entornáramo": "entornar",
    "entornáramos": "entornar",
    "entornárei": "entornar",
    "entornáreis": "entornar",
    "entornásseis": "entornar",
    "entornássemos": "entornar",
    "entornávamo": "entornar",
    "entornávamos": "entornar",
    "entornávei": "entornar",
    "entornáveis": "entornar",
    "entorpece": "entorpecer",
    "entorpecei": "entorpecer",
    "entorpeceis": "entorpecer",
    "entorpecem": "entorpecer",
    "entorpecemo": "entorpecer",
    "entorpecemos": "entorpecer",
    "entorpecendo": "entorpecer",
    "entorpecentes": "entorpecente",
    "entorpecera": "entorpecer",
    "entorpeceram": "entorpecer",
    "entorpeceras": "entorpecer",
    "entorpecerde": "entorpecer",
    "entorpecerdes": "entorpecer",
    "entorpecere": "entorpecer",
    "entorpecerei": "entorpecer",
    "entorpecereis": "entorpecer",
    "entorpecerem": "entorpecer",
    "entorpeceremos": "entorpecer",
    "entorpeceres": "entorpecer",
    "entorpeceria": "entorpecer",
    "entorpeceriam": "entorpecer",
    "entorpecerias": "entorpecer",
    "entorpecermo": "entorpecer",
    "entorpecermos": "entorpecer",
    "entorpecerá": "entorpecer",
    "entorpecerás": "entorpecer",
    "entorpecerão": "entorpecer",
    "entorpeceríamos": "entorpecer",
    "entorpeceríeis": "entorpecer",
    "entorpeces": "entorpecer",
    "entorpecesse": "entorpecer",
    "entorpecessem": "entorpecer",
    "entorpecesses": "entorpecer",
    "entorpeceste": "entorpecer",
    "entorpecestes": "entorpecer",
    "entorpeceu": "entorpecer",
    "entorpeci": "entorpecer",
    "entorpecia": "entorpecer",
    "entorpeciam": "entorpecer",
    "entorpecias": "entorpecer",
    "entorpecida": "entorpecido",
    "entorpecidas": "entorpecido",
    "entorpecido": "entorpecer",
    "entorpecidos": "entorpecido",
    "entorpecimentos": "entorpecimento",
    "entorpecê": "entorpecer",
    "entorpecêramo": "entorpecer",
    "entorpecêramos": "entorpecer",
    "entorpecêrei": "entorpecer",
    "entorpecêreis": "entorpecer",
    "entorpecêsseis": "entorpecer",
    "entorpecêssemos": "entorpecer",
    "entorpecíamo": "entorpecer",
    "entorpecíamos": "entorpecer",
    "entorpecíei": "entorpecer",
    "entorpecíeis": "entorpecer",
    "entorpeça": "entorpecer",
    "entorpeçais": "entorpecer",
    "entorpeçam": "entorpecer",
    "entorpeçamo": "entorpecer",
    "entorpeçamos": "entorpecer",
    "entorpeças": "entorpecer",
    "entorpeço": "entorpecer",
    "entorroa": "entorroar",
    "entorroada": "entorroar",
    "entorroadas": "entorroar",
    "entorroado": "entorroar",
    "entorroados": "entorroar",
    "entorroai": "entorroar",
    "entorroais": "entorroar",
    "entorroam": "entorroar",
    "entorroamo": "entorroar",
    "entorroamos": "entorroar",
    "entorroando": "entorroar",
    "entorroara": "entorroar",
    "entorroaram": "entorroar",
    "entorroaras": "entorroar",
    "entorroarde": "entorroar",
    "entorroardes": "entorroar",
    "entorroare": "entorroar",
    "entorroarei": "entorroar",
    "entorroareis": "entorroar",
    "entorroarem": "entorroar",
    "entorroaremos": "entorroar",
    "entorroares": "entorroar",
    "entorroaria": "entorroar",
    "entorroariam": "entorroar",
    "entorroarias": "entorroar",
    "entorroarmo": "entorroar",
    "entorroarmos": "entorroar",
    "entorroará": "entorroar",
    "entorroarás": "entorroar",
    "entorroarão": "entorroar",
    "entorroaríamos": "entorroar",
    "entorroaríeis": "entorroar",
    "entorroas": "entorroar",
    "entorroasse": "entorroar",
    "entorroassem": "entorroar",
    "entorroasses": "entorroar",
    "entorroaste": "entorroar",
    "entorroastes": "entorroar",
    "entorroava": "entorroar",
    "entorroavam": "entorroar",
    "entorroavas": "entorroar",
    "entorroe": "entorroar",
    "entorroei": "entorroar",
    "entorroeis": "entorroar",
    "entorroem": "entorroar",
    "entorroemo": "entorroar",
    "entorroemos": "entorroar",
    "entorroes": "entorroar",
    "entorroo": "entorroar",
    "entorroou": "entorroar",
    "entorroá": "entorroar",
    "entorroámo": "entorroar",
    "entorroámos": "entorroar",
    "entorroáramo": "entorroar",
    "entorroáramos": "entorroar",
    "entorroárei": "entorroar",
    "entorroáreis": "entorroar",
    "entorroásseis": "entorroar",
    "entorroássemos": "entorroar",
    "entorroávamo": "entorroar",
    "entorroávamos": "entorroar",
    "entorroávei": "entorroar",
    "entorroáveis": "entorroar",
    "entorses": "entorse",
    "entorta": "entortar",
    "entortada": "entortar",
    "entortadas": "entortar",
    "entortado": "entortar",
    "entortados": "entortar",
    "entortaduras": "entortadura",
    "entortai": "entortar",
    "entortais": "entortar",
    "entortam": "entortar",
    "entortamo": "entortar",
    "entortamos": "entortar",
    "entortando": "entortar",
    "entortara": "entortar",
    "entortaram": "entortar",
    "entortaras": "entortar",
    "entortarde": "entortar",
    "entortardes": "entortar",
    "entortare": "entortar",
    "entortarei": "entortar",
    "entortareis": "entortar",
    "entortarem": "entortar",
    "entortaremos": "entortar",
    "entortares": "entortar",
    "entortaria": "entortar",
    "entortariam": "entortar",
    "entortarias": "entortar",
    "entortarmo": "entortar",
    "entortarmos": "entortar",
    "entortará": "entortar",
    "entortarás": "entortar",
    "entortarão": "entortar",
    "entortaríamos": "entortar",
    "entortaríeis": "entortar",
    "entortas": "entortar",
    "entortasse": "entortar",
    "entortassem": "entortar",
    "entortasses": "entortar",
    "entortaste": "entortar",
    "entortastes": "entortar",
    "entortava": "entortar",
    "entortavam": "entortar",
    "entortavas": "entortar",
    "entorte": "entortar",
    "entortei": "entortar",
    "entorteis": "entortar",
    "entortem": "entortar",
    "entortemo": "entortar",
    "entortemos": "entortar",
    "entortes": "entortar",
    "entorto": "entortar",
    "entortou": "entortar",
    "entortá": "entortar",
    "entortámo": "entortar",
    "entortámos": "entortar",
    "entortáramo": "entortar",
    "entortáramos": "entortar",
    "entortárei": "entortar",
    "entortáreis": "entortar",
    "entortásseis": "entortar",
    "entortássemos": "entortar",
    "entortávamo": "entortar",
    "entortávamos": "entortar",
    "entortávei": "entortar",
    "entortáveis": "entortável",
    "entouca": "entoucar",
    "entoucada": "entoucar",
    "entoucadas": "entoucar",
    "entoucado": "entoucar",
    "entoucados": "entoucar",
    "entoucai": "entoucar",
    "entoucais": "entoucar",
    "entoucam": "entoucar",
    "entoucamo": "entoucar",
    "entoucamos": "entoucar",
    "entoucando": "entoucar",
    "entoucara": "entoucar",
    "entoucaram": "entoucar",
    "entoucaras": "entoucar",
    "entoucarde": "entoucar",
    "entoucardes": "entoucar",
    "entoucare": "entoucar",
    "entoucarei": "entoucar",
    "entoucareis": "entoucar",
    "entoucarem": "entoucar",
    "entoucaremos": "entoucar",
    "entoucares": "entoucar",
    "entoucaria": "entoucar",
    "entoucariam": "entoucar",
    "entoucarias": "entoucar",
    "entoucarmo": "entoucar",
    "entoucarmos": "entoucar",
    "entoucará": "entoucar",
    "entoucarás": "entoucar",
    "entoucarão": "entoucar",
    "entoucaríamos": "entoucar",
    "entoucaríeis": "entoucar",
    "entoucas": "entoucar",
    "entoucasse": "entoucar",
    "entoucassem": "entoucar",
    "entoucasses": "entoucar",
    "entoucaste": "entoucar",
    "entoucastes": "entoucar",
    "entoucava": "entoucar",
    "entoucavam": "entoucar",
    "entoucavas": "entoucar",
    "entouce": "entouçar",
    "entoucei": "entouçar",
    "entouceira": "entouceirar",
    "entouceirada": "entouceirar",
    "entouceiradas": "entouceirar",
    "entouceirado": "entouceirar",
    "entouceirados": "entouceirar",
    "entouceirai": "entouceirar",
    "entouceirais": "entouceirar",
    "entouceiram": "entouceirar",
    "entouceiramo": "entouceirar",
    "entouceiramos": "entouceirar",
    "entouceirando": "entouceirar",
    "entouceirara": "entouceirar",
    "entouceiraram": "entouceirar",
    "entouceiraras": "entouceirar",
    "entouceirardes": "entouceirar",
    "entouceirarei": "entouceirar",
    "entouceirareis": "entouceirar",
    "entouceirarem": "entouceirar",
    "entouceiraremos": "entouceirar",
    "entouceirares": "entouceirar",
    "entouceiraria": "entouceirar",
    "entouceirariam": "entouceirar",
    "entouceirarias": "entouceirar",
    "entouceirarmo": "entouceirar",
    "entouceirarmos": "entouceirar",
    "entouceirará": "entouceirar",
    "entouceirarás": "entouceirar",
    "entouceirarão": "entouceirar",
    "entouceiraríamos": "entouceirar",
    "entouceiraríeis": "entouceirar",
    "entouceiras": "entouceirar",
    "entouceirasse": "entouceirar",
    "entouceirassem": "entouceirar",
    "entouceirasses": "entouceirar",
    "entouceiraste": "entouceirar",
    "entouceirastes": "entouceirar",
    "entouceirava": "entouceirar",
    "entouceiravam": "entouceirar",
    "entouceiravas": "entouceirar",
    "entouceire": "entouceirar",
    "entouceirei": "entouceirar",
    "entouceireis": "entouceirar",
    "entouceirem": "entouceirar",
    "entouceiremo": "entouceirar",
    "entouceiremos": "entouceirar",
    "entouceires": "entouceirar",
    "entouceiro": "entouceirar",
    "entouceirou": "entouceirar",
    "entouceirámo": "entouceirar",
    "entouceirámos": "entouceirar",
    "entouceiráramo": "entouceirar",
    "entouceiráramos": "entouceirar",
    "entouceiráreis": "entouceirar",
    "entouceirásseis": "entouceirar",
    "entouceirássemos": "entouceirar",
    "entouceirávamo": "entouceirar",
    "entouceirávamos": "entouceirar",
    "entouceiráveis": "entouceirar",
    "entouceis": "entouçar",
    "entoucem": "entouçar",
    "entoucemo": "entouçar",
    "entoucemos": "entouçar",
    "entouces": "entouçar",
    "entouco": "entoucar",
    "entoucou": "entoucar",
    "entoucá": "entoucar",
    "entoucámo": "entoucar",
    "entoucámos": "entoucar",
    "entoucáramo": "entoucar",
    "entoucáramos": "entoucar",
    "entoucárei": "entoucar",
    "entoucáreis": "entoucar",
    "entoucásseis": "entoucar",
    "entoucássemos": "entoucar",
    "entoucávamo": "entoucar",
    "entoucávamos": "entoucar",
    "entoucávei": "entoucar",
    "entoucáveis": "entoucar",
    "entouque": "entoucar",
    "entouquei": "entoucar",
    "entouqueis": "entoucar",
    "entouquem": "entoucar",
    "entouquemo": "entoucar",
    "entouquemos": "entoucar",
    "entouques": "entoucar",
    "entoura": "entourir",
    "entourada": "entourar",
    "entouradas": "entourar",
    "entouradiça": "entouradiço",
    "entouradiças": "entouradiço",
    "entouradiços": "entouradiço",
    "entourado": "entourar",
    "entourados": "entourar",
    "entourages": "entourage",
    "entourai": "entourar",
    "entourais": "entourir",
    "entouram": "entourir",
    "entouramo": "entourir",
    "entouramos": "entourir",
    "entourando": "entourar",
    "entourara": "entourar",
    "entouraram": "entourar",
    "entouraras": "entourar",
    "entourarde": "entourar",
    "entourardes": "entourar",
    "entourare": "entourar",
    "entourarei": "entourar",
    "entourareis": "entourar",
    "entourarem": "entourar",
    "entouraremos": "entourar",
    "entourares": "entourar",
    "entouraria": "entourar",
    "entourariam": "entourar",
    "entourarias": "entourar",
    "entourarmo": "entourar",
    "entourarmos": "entourar",
    "entourará": "entourar",
    "entourarás": "entourar",
    "entourarão": "entourar",
    "entouraríamos": "entourar",
    "entouraríeis": "entourar",
    "entouras": "entourir",
    "entourasse": "entourar",
    "entourassem": "entourar",
    "entourasses": "entourar",
    "entouraste": "entourar",
    "entourastes": "entourar",
    "entourava": "entourar",
    "entouravam": "entourar",
    "entouravas": "entourar",
    "entoure": "entourir",
    "entourei": "entourar",
    "entoureis": "entourar",
    "entourem": "entourir",
    "entouremo": "entourar",
    "entouremos": "entourar",
    "entoures": "entourir",
    "entouri": "entourir",
    "entouria": "entourir",
    "entouriam": "entourir",
    "entourias": "entourir",
    "entourida": "entourir",
    "entouridas": "entourir",
    "entourido": "entourir",
    "entouridos": "entourir",
    "entourimo": "entourir",
    "entourimos": "entourir",
    "entourindo": "entourir",
    "entourira": "entourir",
    "entouriram": "entourir",
    "entouriras": "entourir",
    "entourirde": "entourir",
    "entourirdes": "entourir",
    "entourire": "entourir",
    "entourirei": "entourir",
    "entourireis": "entourir",
    "entourirem": "entourir",
    "entouriremos": "entourir",
    "entourires": "entourir",
    "entouriria": "entourir",
    "entouririam": "entourir",
    "entouririas": "entourir",
    "entourirmo": "entourir",
    "entourirmos": "entourir",
    "entourirá": "entourir",
    "entourirás": "entourir",
    "entourirão": "entourir",
    "entouriríamos": "entourir",
    "entouriríeis": "entourir",
    "entouris": "entourir",
    "entourisse": "entourir",
    "entourissem": "entourir",
    "entourisses": "entourir",
    "entouriste": "entourir",
    "entouristes": "entourir",
    "entouriu": "entourir",
    "entouro": "entourir",
    "entourou": "entourar",
    "entourá": "entourar",
    "entourámo": "entourar",
    "entourámos": "entourar",
    "entouráramo": "entourar",
    "entouráramos": "entourar",
    "entourárei": "entourar",
    "entouráreis": "entourar",
    "entourásseis": "entourar",
    "entourássemos": "entourar",
    "entourávamo": "entourar",
    "entourávamos": "entourar",
    "entourávei": "entourar",
    "entouráveis": "entourar",
    "entouríamo": "entourir",
    "entouríamos": "entourir",
    "entouríei": "entourir",
    "entouríeis": "entourir",
    "entouríramo": "entourir",
    "entouríramos": "entourir",
    "entourírei": "entourir",
    "entouríreis": "entourir",
    "entourísseis": "entourir",
    "entouríssemos": "entourir",
    "entouça": "entouçar",
    "entouçada": "entouçar",
    "entouçadas": "entouçar",
    "entouçado": "entouçar",
    "entouçados": "entouçar",
    "entouçai": "entouçar",
    "entouçais": "entouçar",
    "entouçam": "entouçar",
    "entouçamo": "entouçar",
    "entouçamos": "entouçar",
    "entouçando": "entouçar",
    "entouçara": "entouçar",
    "entouçaram": "entouçar",
    "entouçaras": "entouçar",
    "entouçardes": "entouçar",
    "entouçarei": "entouçar",
    "entouçareis": "entouçar",
    "entouçarem": "entouçar",
    "entouçaremos": "entouçar",
    "entouçares": "entouçar",
    "entouçaria": "entouçar",
    "entouçariam": "entouçar",
    "entouçarias": "entouçar",
    "entouçarmo": "entouçar",
    "entouçarmos": "entouçar",
    "entouçará": "entouçar",
    "entouçarás": "entouçar",
    "entouçarão": "entouçar",
    "entouçaríamos": "entouçar",
    "entouçaríeis": "entouçar",
    "entouças": "entouçar",
    "entouçasse": "entouçar",
    "entouçassem": "entouçar",
    "entouçasses": "entouçar",
    "entouçaste": "entouçar",
    "entouçastes": "entouçar",
    "entouçava": "entouçar",
    "entouçavam": "entouçar",
    "entouçavas": "entouçar",
    "entouço": "entouçar",
    "entouçou": "entouçar",
    "entouçámo": "entouçar",
    "entouçámos": "entouçar",
    "entouçáramo": "entouçar",
    "entouçáramos": "entouçar",
    "entouçáreis": "entouçar",
    "entouçásseis": "entouçar",
    "entouçássemos": "entouçar",
    "entouçávamo": "entouçar",
    "entouçávamos": "entouçar",
    "entouçáveis": "entouçar",
    "entozoária": "entozoário",
    "entozoárias": "entozoário",
    "entozoários": "entozoário",
    "entoá": "entoar",
    "entoámo": "entoar",
    "entoámos": "entoar",
    "entoáramo": "entoar",
    "entoáramos": "entoar",
    "entoárei": "entoar",
    "entoáreis": "entoar",
    "entoásseis": "entoar",
    "entoássemos": "entoar",
    "entoávamo": "entoar",
    "entoávamos": "entoar",
    "entoávei": "entoar",
    "entoáveis": "entoável",
    "entra": "entrar",
    "entrada": "entrar",
    "entradas": "entrar",
    "entrado": "entrar",
    "entrados": "entrar",
    "entradota": "entradote",
    "entradotas": "entradote",
    "entradotes": "entradote",
    "entrai": "entrar",
    "entrais": "entrar",
    "entraja": "entrajar",
    "entrajada": "entrajar",
    "entrajadas": "entrajar",
    "entrajado": "entrajar",
    "entrajados": "entrajar",
    "entrajai": "entrajar",
    "entrajais": "entrajar",
    "entrajam": "entrajar",
    "entrajamo": "entrajar",
    "entrajamos": "entrajar",
    "entrajando": "entrajar",
    "entrajara": "entrajar",
    "entrajaram": "entrajar",
    "entrajaras": "entrajar",
    "entrajarde": "entrajar",
    "entrajardes": "entrajar",
    "entrajare": "entrajar",
    "entrajarei": "entrajar",
    "entrajareis": "entrajar",
    "entrajarem": "entrajar",
    "entrajaremos": "entrajar",
    "entrajares": "entrajar",
    "entrajaria": "entrajar",
    "entrajariam": "entrajar",
    "entrajarias": "entrajar",
    "entrajarmo": "entrajar",
    "entrajarmos": "entrajar",
    "entrajará": "entrajar",
    "entrajarás": "entrajar",
    "entrajarão": "entrajar",
    "entrajaríamos": "entrajar",
    "entrajaríeis": "entrajar",
    "entrajas": "entrajar",
    "entrajasse": "entrajar",
    "entrajassem": "entrajar",
    "entrajasses": "entrajar",
    "entrajaste": "entrajar",
    "entrajastes": "entrajar",
    "entrajava": "entrajar",
    "entrajavam": "entrajar",
    "entrajavas": "entrajar",
    "entraje": "entrajar",
    "entrajei": "entrajar",
    "entrajeis": "entrajar",
    "entrajem": "entrajar",
    "entrajemo": "entrajar",
    "entrajemos": "entrajar",
    "entrajes": "entraje",
    "entrajo": "entrajar",
    "entrajou": "entrajar",
    "entrajá": "entrajar",
    "entrajámo": "entrajar",
    "entrajámos": "entrajar",
    "entrajáramo": "entrajar",
    "entrajáramos": "entrajar",
    "entrajárei": "entrajar",
    "entrajáreis": "entrajar",
    "entrajásseis": "entrajar",
    "entrajássemos": "entrajar",
    "entrajávamo": "entrajar",
    "entrajávamos": "entrajar",
    "entrajávei": "entrajar",
    "entrajáveis": "entrajar",
    "entralha": "entralhar",
    "entralhada": "entralhar",
    "entralhadas": "entralhar",
    "entralhado": "entralhar",
    "entralhados": "entralhar",
    "entralhai": "entralhar",
    "entralhais": "entralhar",
    "entralham": "entralhar",
    "entralhamo": "entralhar",
    "entralhamos": "entralhar",
    "entralhando": "entralhar",
    "entralhara": "entralhar",
    "entralharam": "entralhar",
    "entralharas": "entralhar",
    "entralharde": "entralhar",
    "entralhardes": "entralhar",
    "entralhare": "entralhar",
    "entralharei": "entralhar",
    "entralhareis": "entralhar",
    "entralharem": "entralhar",
    "entralharemos": "entralhar",
    "entralhares": "entralhar",
    "entralharia": "entralhar",
    "entralhariam": "entralhar",
    "entralharias": "entralhar",
    "entralharmo": "entralhar",
    "entralharmos": "entralhar",
    "entralhará": "entralhar",
    "entralharás": "entralhar",
    "entralharão": "entralhar",
    "entralharíamos": "entralhar",
    "entralharíeis": "entralhar",
    "entralhas": "entralhar",
    "entralhasse": "entralhar",
    "entralhassem": "entralhar",
    "entralhasses": "entralhar",
    "entralhaste": "entralhar",
    "entralhastes": "entralhar",
    "entralhava": "entralhar",
    "entralhavam": "entralhar",
    "entralhavas": "entralhar",
    "entralhações": "entralhação",
    "entralhe": "entralhar",
    "entralhei": "entralhar",
    "entralheis": "entralhar",
    "entralhem": "entralhar",
    "entralhemo": "entralhar",
    "entralhemos": "entralhar",
    "entralhes": "entralhar",
    "entralho": "entralhar",
    "entralhoadas": "entralhoada",
    "entralhos": "entralho",
    "entralhou": "entralhar",
    "entralhá": "entralhar",
    "entralhámo": "entralhar",
    "entralhámos": "entralhar",
    "entralháramo": "entralhar",
    "entralháramos": "entralhar",
    "entralhárei": "entralhar",
    "entralháreis": "entralhar",
    "entralhásseis": "entralhar",
    "entralhássemos": "entralhar",
    "entralhávamo": "entralhar",
    "entralhávamos": "entralhar",
    "entralhávei": "entralhar",
    "entralháveis": "entralhar",
    "entram": "entrar",
    "entramo": "entrar",
    "entramos": "entrar",
    "entrance": "entrançar",
    "entrancei": "entrançar",
    "entranceis": "entrançar",
    "entrancem": "entrançar",
    "entrancemo": "entrançar",
    "entrancemos": "entrançar",
    "entrances": "entrançar",
    "entrando": "entrar",
    "entranha": "entranhar",
    "entranhada": "entranhar",
    "entranhadas": "entranhar",
    "entranhado": "entranhar",
    "entranhados": "entranhar",
    "entranhai": "entranhar",
    "entranhais": "entranhar",
    "entranham": "entranhar",
    "entranhamo": "entranhar",
    "entranhamos": "entranhar",
    "entranhando": "entranhar",
    "entranhara": "entranhar",
    "entranharam": "entranhar",
    "entranharas": "entranhar",
    "entranharde": "entranhar",
    "entranhardes": "entranhar",
    "entranhare": "entranhar",
    "entranharei": "entranhar",
    "entranhareis": "entranhar",
    "entranharem": "entranhar",
    "entranharemos": "entranhar",
    "entranhares": "entranhar",
    "entranharia": "entranhar",
    "entranhariam": "entranhar",
    "entranharias": "entranhar",
    "entranharmo": "entranhar",
    "entranharmos": "entranhar",
    "entranhará": "entranhar",
    "entranharás": "entranhar",
    "entranharão": "entranhar",
    "entranharíamos": "entranhar",
    "entranharíeis": "entranhar",
    "entranhas": "entranhar",
    "entranhasse": "entranhar",
    "entranhassem": "entranhar",
    "entranhasses": "entranhar",
    "entranhaste": "entranhar",
    "entranhastes": "entranhar",
    "entranhava": "entranhar",
    "entranhavam": "entranhar",
    "entranhavas": "entranhar",
    "entranhe": "entranhar",
    "entranhei": "entranhar",
    "entranheis": "entranhar",
    "entranhem": "entranhar",
    "entranhemo": "entranhar",
    "entranhemos": "entranhar",
    "entranhes": "entranhar",
    "entranho": "entranhar",
    "entranhou": "entranhar",
    "entranhá": "entranhar",
    "entranhámo": "entranhar",
    "entranhámos": "entranhar",
    "entranháramo": "entranhar",
    "entranháramos": "entranhar",
    "entranhárei": "entranhar",
    "entranháreis": "entranhar",
    "entranhásseis": "entranhar",
    "entranhássemos": "entranhar",
    "entranhávamo": "entranhar",
    "entranhávamos": "entranhar",
    "entranhávei": "entranhar",
    "entranháveis": "entranhável",
    "entrança": "entrançar",
    "entrançada": "entrançar",
    "entrançadas": "entrançar",
    "entrançado": "entrançar",
    "entrançadora": "entrançador",
    "entrançadoras": "entrançador",
    "entrançadores": "entrançador",
    "entrançados": "entrançar",
    "entrançaduras": "entrançadura",
    "entrançai": "entrançar",
    "entrançais": "entrançar",
    "entrançam": "entrançar",
    "entrançamentos": "entrançamento",
    "entrançamo": "entrançar",
    "entrançamos": "entrançar",
    "entrançando": "entrançar",
    "entrançara": "entrançar",
    "entrançaram": "entrançar",
    "entrançaras": "entrançar",
    "entrançarde": "entrançar",
    "entrançardes": "entrançar",
    "entrançare": "entrançar",
    "entrançarei": "entrançar",
    "entrançareis": "entrançar",
    "entrançarem": "entrançar",
    "entrançaremos": "entrançar",
    "entrançares": "entrançar",
    "entrançaria": "entrançar",
    "entrançariam": "entrançar",
    "entrançarias": "entrançar",
    "entrançarmo": "entrançar",
    "entrançarmos": "entrançar",
    "entrançará": "entrançar",
    "entrançarás": "entrançar",
    "entrançarão": "entrançar",
    "entrançaríamos": "entrançar",
    "entrançaríeis": "entrançar",
    "entranças": "entrançar",
    "entrançasse": "entrançar",
    "entrançassem": "entrançar",
    "entrançasses": "entrançar",
    "entrançaste": "entrançar",
    "entrançastes": "entrançar",
    "entrançava": "entrançar",
    "entrançavam": "entrançar",
    "entrançavas": "entrançar",
    "entranço": "entrançar",
    "entrançou": "entrançar",
    "entrançá": "entrançar",
    "entrançámo": "entrançar",
    "entrançámos": "entrançar",
    "entrançáramo": "entrançar",
    "entrançáramos": "entrançar",
    "entrançárei": "entrançar",
    "entrançáreis": "entrançar",
    "entrançásseis": "entrançar",
    "entrançássemos": "entrançar",
    "entrançávamo": "entrançar",
    "entrançávamos": "entrançar",
    "entrançávei": "entrançar",
    "entrançáveis": "entrançar",
    "entrapa": "entrapar",
    "entrapada": "entrapar",
    "entrapadas": "entrapar",
    "entrapado": "entrapar",
    "entrapados": "entrapar",
    "entrapai": "entrapar",
    "entrapais": "entrapar",
    "entrapam": "entrapar",
    "entrapamo": "entrapar",
    "entrapamos": "entrapar",
    "entrapando": "entrapar",
    "entrapara": "entrapar",
    "entraparam": "entrapar",
    "entraparas": "entrapar",
    "entraparde": "entrapar",
    "entrapardes": "entrapar",
    "entrapare": "entrapar",
    "entraparei": "entrapar",
    "entrapareis": "entrapar",
    "entraparem": "entrapar",
    "entraparemos": "entrapar",
    "entrapares": "entrapar",
    "entraparia": "entrapar",
    "entrapariam": "entrapar",
    "entraparias": "entrapar",
    "entraparmo": "entrapar",
    "entraparmos": "entrapar",
    "entrapará": "entrapar",
    "entraparás": "entrapar",
    "entraparão": "entrapar",
    "entraparíamos": "entrapar",
    "entraparíeis": "entrapar",
    "entrapas": "entrapar",
    "entrapasse": "entrapar",
    "entrapassem": "entrapar",
    "entrapasses": "entrapar",
    "entrapaste": "entrapar",
    "entrapastes": "entrapar",
    "entrapava": "entrapar",
    "entrapavam": "entrapar",
    "entrapavas": "entrapar",
    "entrape": "entrapar",
    "entrapei": "entrapar",
    "entrapeis": "entrapar",
    "entrapem": "entrapar",
    "entrapemo": "entrapar",
    "entrapemos": "entrapar",
    "entrapes": "entrapar",
    "entrapo": "entrapar",
    "entrapou": "entrapar",
    "entrapá": "entrapar",
    "entrapámo": "entrapar",
    "entrapámos": "entrapar",
    "entrapáramo": "entrapar",
    "entrapáramos": "entrapar",
    "entrapárei": "entrapar",
    "entrapáreis": "entrapar",
    "entrapásseis": "entrapar",
    "entrapássemos": "entrapar",
    "entrapávamo": "entrapar",
    "entrapávamos": "entrapar",
    "entrapávei": "entrapar",
    "entrapáveis": "entrapar",
    "entrara": "entrar",
    "entraram": "entrar",
    "entraras": "entrar",
    "entrardes": "entrar",
    "entrarei": "entrar",
    "entrareis": "entrar",
    "entrarem": "entrar",
    "entraremos": "entrar",
    "entrares": "entrar",
    "entraria": "entrar",
    "entrariam": "entrar",
    "entrarias": "entrar",
    "entrarmo": "entrar",
    "entrarmos": "entrar",
    "entrará": "entrar",
    "entrarás": "entrar",
    "entrarão": "entrar",
    "entraríamos": "entrar",
    "entraríeis": "entrar",
    "entras": "entrar",
    "entrasgada": "entrasgado",
    "entrasgadas": "entrasgado",
    "entrasgados": "entrasgado",
    "entrasse": "entrar",
    "entrassem": "entrar",
    "entrasses": "entrar",
    "entraste": "entrar",
    "entrastes": "entrar",
    "entrava": "entravar",
    "entravada": "entravar",
    "entravadas": "entravar",
    "entravado": "entravar",
    "entravadora": "entravador",
    "entravadoras": "entravador",
    "entravadores": "entravador",
    "entravados": "entravar",
    "entravai": "entravar",
    "entravais": "entravar",
    "entravam": "entravar",
    "entravamentos": "entravamento",
    "entravamo": "entravar",
    "entravamos": "entravar",
    "entravando": "entravar",
    "entravara": "entravar",
    "entravaram": "entravar",
    "entravaras": "entravar",
    "entravarde": "entravar",
    "entravardes": "entravar",
    "entravare": "entravar",
    "entravarei": "entravar",
    "entravareis": "entravar",
    "entravarem": "entravar",
    "entravaremos": "entravar",
    "entravares": "entravar",
    "entravaria": "entravar",
    "entravariam": "entravar",
    "entravarias": "entravar",
    "entravarmo": "entravar",
    "entravarmos": "entravar",
    "entravará": "entravar",
    "entravarás": "entravar",
    "entravarão": "entravar",
    "entravaríamos": "entravar",
    "entravaríeis": "entravar",
    "entravas": "entravar",
    "entravasse": "entravar",
    "entravassem": "entravar",
    "entravasses": "entravar",
    "entravaste": "entravar",
    "entravastes": "entravar",
    "entravava": "entravar",
    "entravavam": "entravar",
    "entravavas": "entravar",
    "entrave": "entravar",
    "entravei": "entravar",
    "entraveis": "entravar",
    "entravem": "entravar",
    "entravemo": "entravar",
    "entravemos": "entravar",
    "entraves": "entrave",
    "entravo": "entravar",
    "entravou": "entravar",
    "entravá": "entravar",
    "entravámo": "entravar",
    "entravámos": "entravar",
    "entraváramo": "entravar",
    "entraváramos": "entravar",
    "entravárei": "entravar",
    "entraváreis": "entravar",
    "entravásseis": "entravar",
    "entravássemos": "entravar",
    "entravávamo": "entravar",
    "entravávamos": "entravar",
    "entravávei": "entravar",
    "entraváveis": "entravar",
    "entre": "entrar",
    "entreaberta": "entreaberto",
    "entreabertas": "entreaberto",
    "entreabertos": "entreaberto",
    "entreabra": "entreabrir",
    "entreabrais": "entreabrir",
    "entreabram": "entreabrir",
    "entreabramo": "entreabrir",
    "entreabramos": "entreabrir",
    "entreabras": "entreabrir",
    "entreabre": "entreabrir",
    "entreabrem": "entreabrir",
    "entreabres": "entreabrir",
    "entreabri": "entreabrir",
    "entreabria": "entreabrir",
    "entreabriam": "entreabrir",
    "entreabrias": "entreabrir",
    "entreabrida": "entreabrir",
    "entreabridas": "entreabrir",
    "entreabrido": "entreabrir",
    "entreabridos": "entreabrir",
    "entreabrimo": "entreabrir",
    "entreabrimos": "entreabrir",
    "entreabrindo": "entreabrir",
    "entreabrira": "entreabrir",
    "entreabriram": "entreabrir",
    "entreabriras": "entreabrir",
    "entreabrirde": "entreabrir",
    "entreabrirdes": "entreabrir",
    "entreabrire": "entreabrir",
    "entreabrirei": "entreabrir",
    "entreabrireis": "entreabrir",
    "entreabrirem": "entreabrir",
    "entreabriremos": "entreabrir",
    "entreabrires": "entreabrir",
    "entreabriria": "entreabrir",
    "entreabririam": "entreabrir",
    "entreabririas": "entreabrir",
    "entreabrirmo": "entreabrir",
    "entreabrirmos": "entreabrir",
    "entreabrirá": "entreabrir",
    "entreabrirás": "entreabrir",
    "entreabrirão": "entreabrir",
    "entreabriríamos": "entreabrir",
    "entreabriríeis": "entreabrir",
    "entreabris": "entreabrir",
    "entreabrisse": "entreabrir",
    "entreabrissem": "entreabrir",
    "entreabrisses": "entreabrir",
    "entreabriste": "entreabrir",
    "entreabristes": "entreabrir",
    "entreabriu": "entreabrir",
    "entreabro": "entreabrir",
    "entreabríamo": "entreabrir",
    "entreabríamos": "entreabrir",
    "entreabríei": "entreabrir",
    "entreabríeis": "entreabrir",
    "entreabríramo": "entreabrir",
    "entreabríramos": "entreabrir",
    "entreabrírei": "entreabrir",
    "entreabríreis": "entreabrir",
    "entreabrísseis": "entreabrir",
    "entreabríssemos": "entreabrir",
    "entreactos": "entreacto",
    "entreajuda": "entreajudar",
    "entreajudada": "entreajudar",
    "entreajudadas": "entreajudar",
    "entreajudado": "entreajudar",
    "entreajudados": "entreajudar",
    "entreajudai": "entreajudar",
    "entreajudais": "entreajudar",
    "entreajudam": "entreajudar",
    "entreajudamo": "entreajudar",
    "entreajudamos": "entreajudar",
    "entreajudando": "entreajudar",
    "entreajudara": "entreajudar",
    "entreajudaram": "entreajudar",
    "entreajudaras": "entreajudar",
    "entreajudarde": "entreajudar",
    "entreajudardes": "entreajudar",
    "entreajudare": "entreajudar",
    "entreajudarei": "entreajudar",
    "entreajudareis": "entreajudar",
    "entreajudarem": "entreajudar",
    "entreajudaremos": "entreajudar",
    "entreajudares": "entreajudar",
    "entreajudaria": "entreajudar",
    "entreajudariam": "entreajudar",
    "entreajudarias": "entreajudar",
    "entreajudarmo": "entreajudar",
    "entreajudarmos": "entreajudar",
    "entreajudará": "entreajudar",
    "entreajudarás": "entreajudar",
    "entreajudarão": "entreajudar",
    "entreajudaríamos": "entreajudar",
    "entreajudaríeis": "entreajudar",
    "entreajudas": "entreajudar",
    "entreajudasse": "entreajudar",
    "entreajudassem": "entreajudar",
    "entreajudasses": "entreajudar",
    "entreajudaste": "entreajudar",
    "entreajudastes": "entreajudar",
    "entreajudava": "entreajudar",
    "entreajudavam": "entreajudar",
    "entreajudavas": "entreajudar",
    "entreajude": "entreajudar",
    "entreajudei": "entreajudar",
    "entreajudeis": "entreajudar",
    "entreajudem": "entreajudar",
    "entreajudemo": "entreajudar",
    "entreajudemos": "entreajudar",
    "entreajudes": "entreajudar",
    "entreajudo": "entreajudar",
    "entreajudou": "entreajudar",
    "entreajudá": "entreajudar",
    "entreajudámo": "entreajudar",
    "entreajudámos": "entreajudar",
    "entreajudáramo": "entreajudar",
    "entreajudáramos": "entreajudar",
    "entreajudárei": "entreajudar",
    "entreajudáreis": "entreajudar",
    "entreajudásseis": "entreajudar",
    "entreajudássemos": "entreajudar",
    "entreajudávamo": "entreajudar",
    "entreajudávamos": "entreajudar",
    "entreajudávei": "entreajudar",
    "entreajudáveis": "entreajudar",
    "entrebanhos": "entrebanho",
    "entrebata": "entrebater",
    "entrebatais": "entrebater",
    "entrebatam": "entrebater",
    "entrebatamo": "entrebater",
    "entrebatamos": "entrebater",
    "entrebatas": "entrebater",
    "entrebate": "entrebater",
    "entrebatei": "entrebater",
    "entrebateis": "entrebater",
    "entrebatem": "entrebater",
    "entrebatemo": "entrebater",
    "entrebatemos": "entrebater",
    "entrebatendo": "entrebater",
    "entrebatera": "entrebater",
    "entrebateram": "entrebater",
    "entrebateras": "entrebater",
    "entrebaterdes": "entrebater",
    "entrebaterei": "entrebater",
    "entrebatereis": "entrebater",
    "entrebaterem": "entrebater",
    "entrebateremos": "entrebater",
    "entrebateres": "entrebater",
    "entrebateria": "entrebater",
    "entrebateriam": "entrebater",
    "entrebaterias": "entrebater",
    "entrebatermo": "entrebater",
    "entrebatermos": "entrebater",
    "entrebaterá": "entrebater",
    "entrebaterás": "entrebater",
    "entrebaterão": "entrebater",
    "entrebateríamos": "entrebater",
    "entrebateríeis": "entrebater",
    "entrebates": "entrebater",
    "entrebatesse": "entrebater",
    "entrebatessem": "entrebater",
    "entrebatesses": "entrebater",
    "entrebateste": "entrebater",
    "entrebatestes": "entrebater",
    "entrebateu": "entrebater",
    "entrebati": "entrebater",
    "entrebatia": "entrebater",
    "entrebatiam": "entrebater",
    "entrebatias": "entrebater",
    "entrebatida": "entrebater",
    "entrebatidas": "entrebater",
    "entrebatido": "entrebater",
    "entrebatidos": "entrebater",
    "entrebato": "entrebater",
    "entrebatêramo": "entrebater",
    "entrebatêramos": "entrebater",
    "entrebatêreis": "entrebater",
    "entrebatêsseis": "entrebater",
    "entrebatêssemos": "entrebater",
    "entrebatíamo": "entrebater",
    "entrebatíamos": "entrebater",
    "entrebatíeis": "entrebater",
    "entrebeija": "entrebeijar",
    "entrebeijada": "entrebeijar",
    "entrebeijadas": "entrebeijar",
    "entrebeijado": "entrebeijar",
    "entrebeijados": "entrebeijar",
    "entrebeijai": "entrebeijar",
    "entrebeijais": "entrebeijar",
    "entrebeijam": "entrebeijar",
    "entrebeijamo": "entrebeijar",
    "entrebeijamos": "entrebeijar",
    "entrebeijando": "entrebeijar",
    "entrebeijara": "entrebeijar",
    "entrebeijaram": "entrebeijar",
    "entrebeijaras": "entrebeijar",
    "entrebeijarde": "entrebeijar",
    "entrebeijardes": "entrebeijar",
    "entrebeijare": "entrebeijar",
    "entrebeijarei": "entrebeijar",
    "entrebeijareis": "entrebeijar",
    "entrebeijarem": "entrebeijar",
    "entrebeijaremos": "entrebeijar",
    "entrebeijares": "entrebeijar",
    "entrebeijaria": "entrebeijar",
    "entrebeijariam": "entrebeijar",
    "entrebeijarias": "entrebeijar",
    "entrebeijarmo": "entrebeijar",
    "entrebeijarmos": "entrebeijar",
    "entrebeijará": "entrebeijar",
    "entrebeijarás": "entrebeijar",
    "entrebeijarão": "entrebeijar",
    "entrebeijaríamos": "entrebeijar",
    "entrebeijaríeis": "entrebeijar",
    "entrebeijas": "entrebeijar",
    "entrebeijasse": "entrebeijar",
    "entrebeijassem": "entrebeijar",
    "entrebeijasses": "entrebeijar",
    "entrebeijaste": "entrebeijar",
    "entrebeijastes": "entrebeijar",
    "entrebeijava": "entrebeijar",
    "entrebeijavam": "entrebeijar",
    "entrebeijavas": "entrebeijar",
    "entrebeije": "entrebeijar",
    "entrebeijei": "entrebeijar",
    "entrebeijeis": "entrebeijar",
    "entrebeijem": "entrebeijar",
    "entrebeijemo": "entrebeijar",
    "entrebeijemos": "entrebeijar",
    "entrebeijes": "entrebeijar",
    "entrebeijo": "entrebeijar",
    "entrebeijou": "entrebeijar",
    "entrebeijá": "entrebeijar",
    "entrebeijámo": "entrebeijar",
    "entrebeijámos": "entrebeijar",
    "entrebeijáramo": "entrebeijar",
    "entrebeijáramos": "entrebeijar",
    "entrebeijárei": "entrebeijar",
    "entrebeijáreis": "entrebeijar",
    "entrebeijásseis": "entrebeijar",
    "entrebeijássemos": "entrebeijar",
    "entrebeijávamo": "entrebeijar",
    "entrebeijávamos": "entrebeijar",
    "entrebeijávei": "entrebeijar",
    "entrebeijáveis": "entrebeijar",
    "entrebranca": "entrebranco",
    "entrebrancas": "entrebranco",
    "entrebrancos": "entrebranco",
    "entrecacas": "entrecaca",
    "entrecambada": "entrecambado",
    "entrecambadas": "entrecambado",
    "entrecambados": "entrecambado",
    "entrecanas": "entrecana",
    "entrecargas": "entrecarga",
    "entrecascas": "entrecasca",
    "entrecascos": "entrecasco",
    "entrecenas": "entrecena",
    "entrecerra": "entrecerrar",
    "entrecerrada": "entrecerrar",
    "entrecerradas": "entrecerrar",
    "entrecerrado": "entrecerrar",
    "entrecerrados": "entrecerrar",
    "entrecerrai": "entrecerrar",
    "entrecerrais": "entrecerrar",
    "entrecerram": "entrecerrar",
    "entrecerramo": "entrecerrar",
    "entrecerramos": "entrecerrar",
    "entrecerrando": "entrecerrar",
    "entrecerrara": "entrecerrar",
    "entrecerraram": "entrecerrar",
    "entrecerraras": "entrecerrar",
    "entrecerrarde": "entrecerrar",
    "entrecerrardes": "entrecerrar",
    "entrecerrare": "entrecerrar",
    "entrecerrarei": "entrecerrar",
    "entrecerrareis": "entrecerrar",
    "entrecerrarem": "entrecerrar",
    "entrecerraremos": "entrecerrar",
    "entrecerrares": "entrecerrar",
    "entrecerraria": "entrecerrar",
    "entrecerrariam": "entrecerrar",
    "entrecerrarias": "entrecerrar",
    "entrecerrarmo": "entrecerrar",
    "entrecerrarmos": "entrecerrar",
    "entrecerrará": "entrecerrar",
    "entrecerrarás": "entrecerrar",
    "entrecerrarão": "entrecerrar",
    "entrecerraríamos": "entrecerrar",
    "entrecerraríeis": "entrecerrar",
    "entrecerras": "entrecerrar",
    "entrecerrasse": "entrecerrar",
    "entrecerrassem": "entrecerrar",
    "entrecerrasses": "entrecerrar",
    "entrecerraste": "entrecerrar",
    "entrecerrastes": "entrecerrar",
    "entrecerrava": "entrecerrar",
    "entrecerravam": "entrecerrar",
    "entrecerravas": "entrecerrar",
    "entrecerre": "entrecerrar",
    "entrecerrei": "entrecerrar",
    "entrecerreis": "entrecerrar",
    "entrecerrem": "entrecerrar",
    "entrecerremo": "entrecerrar",
    "entrecerremos": "entrecerrar",
    "entrecerres": "entrecerrar",
    "entrecerro": "entrecerrar",
    "entrecerrou": "entrecerrar",
    "entrecerrá": "entrecerrar",
    "entrecerrámo": "entrecerrar",
    "entrecerrámos": "entrecerrar",
    "entrecerráramo": "entrecerrar",
    "entrecerráramos": "entrecerrar",
    "entrecerrárei": "entrecerrar",
    "entrecerráreis": "entrecerrar",
    "entrecerrásseis": "entrecerrar",
    "entrecerrássemos": "entrecerrar",
    "entrecerrávamo": "entrecerrar",
    "entrecerrávamos": "entrecerrar",
    "entrecerrávei": "entrecerrar",
    "entrecerráveis": "entrecerrar",
    "entrecha": "entrechar",
    "entrechada": "entrechar",
    "entrechadas": "entrechar",
    "entrechado": "entrechar",
    "entrechados": "entrechar",
    "entrechai": "entrechar",
    "entrechais": "entrechar",
    "entrecham": "entrechar",
    "entrechamo": "entrechar",
    "entrechamos": "entrechar",
    "entrechando": "entrechar",
    "entrechara": "entrechar",
    "entrecharam": "entrechar",
    "entrecharas": "entrechar",
    "entrecharde": "entrechar",
    "entrechardes": "entrechar",
    "entrechare": "entrechar",
    "entrecharei": "entrechar",
    "entrechareis": "entrechar",
    "entrecharem": "entrechar",
    "entrecharemos": "entrechar",
    "entrechares": "entrechar",
    "entrecharia": "entrechar",
    "entrechariam": "entrechar",
    "entrecharias": "entrechar",
    "entrecharmo": "entrechar",
    "entrecharmos": "entrechar",
    "entrechará": "entrechar",
    "entrecharás": "entrechar",
    "entrecharão": "entrechar",
    "entrecharíamos": "entrechar",
    "entrecharíeis": "entrechar",
    "entrechas": "entrechar",
    "entrechasse": "entrechar",
    "entrechassem": "entrechar",
    "entrechasses": "entrechar",
    "entrechaste": "entrechar",
    "entrechastes": "entrechar",
    "entrechava": "entrechar",
    "entrechavam": "entrechar",
    "entrechavas": "entrechar",
    "entreche": "entrechar",
    "entrechei": "entrechar",
    "entrecheis": "entrechar",
    "entrechem": "entrechar",
    "entrechemo": "entrechar",
    "entrechemos": "entrechar",
    "entreches": "entrechar",
    "entrecho": "entrechar",
    "entrechoca": "entrechocar",
    "entrechocada": "entrechocar",
    "entrechocadas": "entrechocar",
    "entrechocado": "entrechocar",
    "entrechocados": "entrechocar",
    "entrechocai": "entrechocar",
    "entrechocais": "entrechocar",
    "entrechocam": "entrechocar",
    "entrechocamo": "entrechocar",
    "entrechocamos": "entrechocar",
    "entrechocando": "entrechocar",
    "entrechocara": "entrechocar",
    "entrechocaram": "entrechocar",
    "entrechocaras": "entrechocar",
    "entrechocarde": "entrechocar",
    "entrechocardes": "entrechocar",
    "entrechocare": "entrechocar",
    "entrechocarei": "entrechocar",
    "entrechocareis": "entrechocar",
    "entrechocarem": "entrechocar",
    "entrechocaremos": "entrechocar",
    "entrechocares": "entrechocar",
    "entrechocaria": "entrechocar",
    "entrechocariam": "entrechocar",
    "entrechocarias": "entrechocar",
    "entrechocarmo": "entrechocar",
    "entrechocarmos": "entrechocar",
    "entrechocará": "entrechocar",
    "entrechocarás": "entrechocar",
    "entrechocarão": "entrechocar",
    "entrechocaríamos": "entrechocar",
    "entrechocaríeis": "entrechocar",
    "entrechocas": "entrechocar",
    "entrechocasse": "entrechocar",
    "entrechocassem": "entrechocar",
    "entrechocasses": "entrechocar",
    "entrechocaste": "entrechocar",
    "entrechocastes": "entrechocar",
    "entrechocava": "entrechocar",
    "entrechocavam": "entrechocar",
    "entrechocavas": "entrechocar",
    "entrechoco": "entrechocar",
    "entrechocou": "entrechocar",
    "entrechocá": "entrechocar",
    "entrechocámo": "entrechocar",
    "entrechocámos": "entrechocar",
    "entrechocáramo": "entrechocar",
    "entrechocáramos": "entrechocar",
    "entrechocárei": "entrechocar",
    "entrechocáreis": "entrechocar",
    "entrechocásseis": "entrechocar",
    "entrechocássemos": "entrechocar",
    "entrechocávamo": "entrechocar",
    "entrechocávamos": "entrechocar",
    "entrechocávei": "entrechocar",
    "entrechocáveis": "entrechocar",
    "entrechoque": "entrechocar",
    "entrechoquei": "entrechocar",
    "entrechoqueis": "entrechocar",
    "entrechoquem": "entrechocar",
    "entrechoquemo": "entrechocar",
    "entrechoquemos": "entrechocar",
    "entrechoques": "entrechoque",
    "entrechos": "entrecho",
    "entrechou": "entrechar",
    "entrechá": "entrechar",
    "entrechámo": "entrechar",
    "entrechámos": "entrechar",
    "entrecháramo": "entrechar",
    "entrecháramos": "entrechar",
    "entrechárei": "entrechar",
    "entrecháreis": "entrechar",
    "entrechásseis": "entrechar",
    "entrechássemos": "entrechar",
    "entrechávamo": "entrechar",
    "entrechávamos": "entrechar",
    "entrechávei": "entrechar",
    "entrecháveis": "entrechar",
    "entrecolha": "entrecolher",
    "entrecolhais": "entrecolher",
    "entrecolham": "entrecolher",
    "entrecolhamo": "entrecolher",
    "entrecolhamos": "entrecolher",
    "entrecolhas": "entrecolher",
    "entrecolhe": "entrecolher",
    "entrecolhei": "entrecolher",
    "entrecolheis": "entrecolher",
    "entrecolhem": "entrecolher",
    "entrecolhemo": "entrecolher",
    "entrecolhemos": "entrecolher",
    "entrecolhendo": "entrecolher",
    "entrecolhera": "entrecolher",
    "entrecolheram": "entrecolher",
    "entrecolheras": "entrecolher",
    "entrecolherde": "entrecolher",
    "entrecolherdes": "entrecolher",
    "entrecolhere": "entrecolher",
    "entrecolherei": "entrecolher",
    "entrecolhereis": "entrecolher",
    "entrecolherem": "entrecolher",
    "entrecolheremos": "entrecolher",
    "entrecolheres": "entrecolher",
    "entrecolheria": "entrecolher",
    "entrecolheriam": "entrecolher",
    "entrecolherias": "entrecolher",
    "entrecolhermo": "entrecolher",
    "entrecolhermos": "entrecolher",
    "entrecolherá": "entrecolher",
    "entrecolherás": "entrecolher",
    "entrecolherão": "entrecolher",
    "entrecolheríamos": "entrecolher",
    "entrecolheríeis": "entrecolher",
    "entrecolhes": "entrecolher",
    "entrecolhesse": "entrecolher",
    "entrecolhessem": "entrecolher",
    "entrecolhesses": "entrecolher",
    "entrecolheste": "entrecolher",
    "entrecolhestes": "entrecolher",
    "entrecolheu": "entrecolher",
    "entrecolhi": "entrecolher",
    "entrecolhia": "entrecolher",
    "entrecolhiam": "entrecolher",
    "entrecolhias": "entrecolher",
    "entrecolhida": "entrecolher",
    "entrecolhidas": "entrecolher",
    "entrecolhido": "entrecolher",
    "entrecolhidos": "entrecolher",
    "entrecolho": "entrecolher",
    "entrecolhê": "entrecolher",
    "entrecolhêramo": "entrecolher",
    "entrecolhêramos": "entrecolher",
    "entrecolhêrei": "entrecolher",
    "entrecolhêreis": "entrecolher",
    "entrecolhêsseis": "entrecolher",
    "entrecolhêssemos": "entrecolher",
    "entrecolhíamo": "entrecolher",
    "entrecolhíamos": "entrecolher",
    "entrecolhíei": "entrecolher",
    "entrecolhíeis": "entrecolher",
    "entreconhece": "entreconhecer",
    "entreconhecei": "entreconhecer",
    "entreconheceis": "entreconhecer",
    "entreconhecem": "entreconhecer",
    "entreconhecemo": "entreconhecer",
    "entreconhecemos": "entreconhecer",
    "entreconhecendo": "entreconhecer",
    "entreconhecera": "entreconhecer",
    "entreconheceram": "entreconhecer",
    "entreconheceras": "entreconhecer",
    "entreconhecerde": "entreconhecer",
    "entreconhecerdes": "entreconhecer",
    "entreconhecere": "entreconhecer",
    "entreconhecerei": "entreconhecer",
    "entreconhecereis": "entreconhecer",
    "entreconhecerem": "entreconhecer",
    "entreconheceremos": "entreconhecer",
    "entreconheceres": "entreconhecer",
    "entreconheceria": "entreconhecer",
    "entreconheceriam": "entreconhecer",
    "entreconhecerias": "entreconhecer",
    "entreconhecermo": "entreconhecer",
    "entreconhecermos": "entreconhecer",
    "entreconhecerá": "entreconhecer",
    "entreconhecerás": "entreconhecer",
    "entreconhecerão": "entreconhecer",
    "entreconheceríamos": "entreconhecer",
    "entreconheceríeis": "entreconhecer",
    "entreconheces": "entreconhecer",
    "entreconhecesse": "entreconhecer",
    "entreconhecessem": "entreconhecer",
    "entreconhecesses": "entreconhecer",
    "entreconheceste": "entreconhecer",
    "entreconhecestes": "entreconhecer",
    "entreconheceu": "entreconhecer",
    "entreconheci": "entreconhecer",
    "entreconhecia": "entreconhecer",
    "entreconheciam": "entreconhecer",
    "entreconhecias": "entreconhecer",
    "entreconhecida": "entreconhecer",
    "entreconhecidas": "entreconhecer",
    "entreconhecido": "entreconhecer",
    "entreconhecidos": "entreconhecer",
    "entreconhecê": "entreconhecer",
    "entreconhecêramo": "entreconhecer",
    "entreconhecêramos": "entreconhecer",
    "entreconhecêrei": "entreconhecer",
    "entreconhecêreis": "entreconhecer",
    "entreconhecêsseis": "entreconhecer",
    "entreconhecêssemos": "entreconhecer",
    "entreconhecíamo": "entreconhecer",
    "entreconhecíamos": "entreconhecer",
    "entreconhecíei": "entreconhecer",
    "entreconhecíeis": "entreconhecer",
    "entreconheça": "entreconhecer",
    "entreconheçais": "entreconhecer",
    "entreconheçam": "entreconhecer",
    "entreconheçamo": "entreconhecer",
    "entreconheçamos": "entreconhecer",
    "entreconheças": "entreconhecer",
    "entreconheço": "entreconhecer",
    "entrecoros": "entrecoro",
    "entrecorra": "entrecorrer",
    "entrecorrais": "entrecorrer",
    "entrecorram": "entrecorrer",
    "entrecorramo": "entrecorrer",
    "entrecorramos": "entrecorrer",
    "entrecorras": "entrecorrer",
    "entrecorre": "entrecorrer",
    "entrecorrei": "entrecorrer",
    "entrecorreis": "entrecorrer",
    "entrecorrem": "entrecorrer",
    "entrecorremo": "entrecorrer",
    "entrecorremos": "entrecorrer",
    "entrecorrendo": "entrecorrer",
    "entrecorrera": "entrecorrer",
    "entrecorreram": "entrecorrer",
    "entrecorreras": "entrecorrer",
    "entrecorrerdes": "entrecorrer",
    "entrecorrerei": "entrecorrer",
    "entrecorrereis": "entrecorrer",
    "entrecorrerem": "entrecorrer",
    "entrecorreremos": "entrecorrer",
    "entrecorreres": "entrecorrer",
    "entrecorreria": "entrecorrer",
    "entrecorreriam": "entrecorrer",
    "entrecorrerias": "entrecorrer",
    "entrecorrermo": "entrecorrer",
    "entrecorrermos": "entrecorrer",
    "entrecorrerá": "entrecorrer",
    "entrecorrerás": "entrecorrer",
    "entrecorrerão": "entrecorrer",
    "entrecorreríamos": "entrecorrer",
    "entrecorreríeis": "entrecorrer",
    "entrecorres": "entrecorrer",
    "entrecorresse": "entrecorrer",
    "entrecorressem": "entrecorrer",
    "entrecorresses": "entrecorrer",
    "entrecorreste": "entrecorrer",
    "entrecorrestes": "entrecorrer",
    "entrecorreu": "entrecorrer",
    "entrecorri": "entrecorrer",
    "entrecorria": "entrecorrer",
    "entrecorriam": "entrecorrer",
    "entrecorrias": "entrecorrer",
    "entrecorrida": "entrecorrer",
    "entrecorridas": "entrecorrer",
    "entrecorrido": "entrecorrer",
    "entrecorridos": "entrecorrer",
    "entrecorro": "entrecorrer",
    "entrecorrêramo": "entrecorrer",
    "entrecorrêramos": "entrecorrer",
    "entrecorrêreis": "entrecorrer",
    "entrecorrêsseis": "entrecorrer",
    "entrecorrêssemos": "entrecorrer",
    "entrecorríamo": "entrecorrer",
    "entrecorríamos": "entrecorrer",
    "entrecorríeis": "entrecorrer",
    "entrecorta": "entrecortar",
    "entrecortada": "entrecortar",
    "entrecortadas": "entrecortar",
    "entrecortado": "entrecortar",
    "entrecortados": "entrecortar",
    "entrecortai": "entrecortar",
    "entrecortais": "entrecortar",
    "entrecortam": "entrecortar",
    "entrecortamo": "entrecortar",
    "entrecortamos": "entrecortar",
    "entrecortando": "entrecortar",
    "entrecortara": "entrecortar",
    "entrecortaram": "entrecortar",
    "entrecortaras": "entrecortar",
    "entrecortarde": "entrecortar",
    "entrecortardes": "entrecortar",
    "entrecortare": "entrecortar",
    "entrecortarei": "entrecortar",
    "entrecortareis": "entrecortar",
    "entrecortarem": "entrecortar",
    "entrecortaremos": "entrecortar",
    "entrecortares": "entrecortar",
    "entrecortaria": "entrecortar",
    "entrecortariam": "entrecortar",
    "entrecortarias": "entrecortar",
    "entrecortarmo": "entrecortar",
    "entrecortarmos": "entrecortar",
    "entrecortará": "entrecortar",
    "entrecortarás": "entrecortar",
    "entrecortarão": "entrecortar",
    "entrecortaríamos": "entrecortar",
    "entrecortaríeis": "entrecortar",
    "entrecortas": "entrecortar",
    "entrecortasse": "entrecortar",
    "entrecortassem": "entrecortar",
    "entrecortasses": "entrecortar",
    "entrecortaste": "entrecortar",
    "entrecortastes": "entrecortar",
    "entrecortava": "entrecortar",
    "entrecortavam": "entrecortar",
    "entrecortavas": "entrecortar",
    "entrecorte": "entrecortar",
    "entrecortei": "entrecortar",
    "entrecorteis": "entrecortar",
    "entrecortem": "entrecortar",
    "entrecortemo": "entrecortar",
    "entrecortemos": "entrecortar",
    "entrecortes": "entrecorte",
    "entrecorto": "entrecortar",
    "entrecortou": "entrecortar",
    "entrecortá": "entrecortar",
    "entrecortámo": "entrecortar",
    "entrecortámos": "entrecortar",
    "entrecortáramo": "entrecortar",
    "entrecortáramos": "entrecortar",
    "entrecortárei": "entrecortar",
    "entrecortáreis": "entrecortar",
    "entrecortásseis": "entrecortar",
    "entrecortássemos": "entrecortar",
    "entrecortávamo": "entrecortar",
    "entrecortávamos": "entrecortar",
    "entrecortávei": "entrecortar",
    "entrecortáveis": "entrecortar",
    "entrecostados": "entrecostado",
    "entrecostos": "entrecosto",
    "entrecruza": "entrecruzar",
    "entrecruzada": "entrecruzar",
    "entrecruzadas": "entrecruzar",
    "entrecruzado": "entrecruzar",
    "entrecruzados": "entrecruzar",
    "entrecruzai": "entrecruzar",
    "entrecruzais": "entrecruzar",
    "entrecruzam": "entrecruzar",
    "entrecruzamentos": "entrecruzamento",
    "entrecruzamo": "entrecruzar",
    "entrecruzamos": "entrecruzar",
    "entrecruzando": "entrecruzar",
    "entrecruzara": "entrecruzar",
    "entrecruzaram": "entrecruzar",
    "entrecruzaras": "entrecruzar",
    "entrecruzarde": "entrecruzar",
    "entrecruzardes": "entrecruzar",
    "entrecruzare": "entrecruzar",
    "entrecruzarei": "entrecruzar",
    "entrecruzareis": "entrecruzar",
    "entrecruzarem": "entrecruzar",
    "entrecruzaremos": "entrecruzar",
    "entrecruzares": "entrecruzar",
    "entrecruzaria": "entrecruzar",
    "entrecruzariam": "entrecruzar",
    "entrecruzarias": "entrecruzar",
    "entrecruzarmo": "entrecruzar",
    "entrecruzarmos": "entrecruzar",
    "entrecruzará": "entrecruzar",
    "entrecruzarás": "entrecruzar",
    "entrecruzarão": "entrecruzar",
    "entrecruzaríamos": "entrecruzar",
    "entrecruzaríeis": "entrecruzar",
    "entrecruzas": "entrecruzar",
    "entrecruzasse": "entrecruzar",
    "entrecruzassem": "entrecruzar",
    "entrecruzasses": "entrecruzar",
    "entrecruzaste": "entrecruzar",
    "entrecruzastes": "entrecruzar",
    "entrecruzava": "entrecruzar",
    "entrecruzavam": "entrecruzar",
    "entrecruzavas": "entrecruzar",
    "entrecruze": "entrecruzar",
    "entrecruzei": "entrecruzar",
    "entrecruzeis": "entrecruzar",
    "entrecruzem": "entrecruzar",
    "entrecruzemo": "entrecruzar",
    "entrecruzemos": "entrecruzar",
    "entrecruzes": "entrecruzar",
    "entrecruzo": "entrecruzar",
    "entrecruzou": "entrecruzar",
    "entrecruzá": "entrecruzar",
    "entrecruzámo": "entrecruzar",
    "entrecruzámos": "entrecruzar",
    "entrecruzáramo": "entrecruzar",
    "entrecruzáramos": "entrecruzar",
    "entrecruzárei": "entrecruzar",
    "entrecruzáreis": "entrecruzar",
    "entrecruzásseis": "entrecruzar",
    "entrecruzássemos": "entrecruzar",
    "entrecruzávamo": "entrecruzar",
    "entrecruzávamos": "entrecruzar",
    "entrecruzávei": "entrecruzar",
    "entrecruzáveis": "entrecruzar",
    "entrededos": "entrededo",
    "entredentes": "entredente",
    "entredevora": "entredevorar",
    "entredevorada": "entredevorar",
    "entredevoradas": "entredevorar",
    "entredevorado": "entredevorar",
    "entredevorados": "entredevorar",
    "entredevorai": "entredevorar",
    "entredevorais": "entredevorar",
    "entredevoram": "entredevorar",
    "entredevoramo": "entredevorar",
    "entredevoramos": "entredevorar",
    "entredevorando": "entredevorar",
    "entredevorara": "entredevorar",
    "entredevoraram": "entredevorar",
    "entredevoraras": "entredevorar",
    "entredevorarde": "entredevorar",
    "entredevorardes": "entredevorar",
    "entredevorare": "entredevorar",
    "entredevorarei": "entredevorar",
    "entredevorareis": "entredevorar",
    "entredevorarem": "entredevorar",
    "entredevoraremos": "entredevorar",
    "entredevorares": "entredevorar",
    "entredevoraria": "entredevorar",
    "entredevorariam": "entredevorar",
    "entredevorarias": "entredevorar",
    "entredevorarmo": "entredevorar",
    "entredevorarmos": "entredevorar",
    "entredevorará": "entredevorar",
    "entredevorarás": "entredevorar",
    "entredevorarão": "entredevorar",
    "entredevoraríamos": "entredevorar",
    "entredevoraríeis": "entredevorar",
    "entredevoras": "entredevorar",
    "entredevorasse": "entredevorar",
    "entredevorassem": "entredevorar",
    "entredevorasses": "entredevorar",
    "entredevoraste": "entredevorar",
    "entredevorastes": "entredevorar",
    "entredevorava": "entredevorar",
    "entredevoravam": "entredevorar",
    "entredevoravas": "entredevorar",
    "entredevore": "entredevorar",
    "entredevorei": "entredevorar",
    "entredevoreis": "entredevorar",
    "entredevorem": "entredevorar",
    "entredevoremo": "entredevorar",
    "entredevoremos": "entredevorar",
    "entredevores": "entredevorar",
    "entredevoro": "entredevorar",
    "entredevorou": "entredevorar",
    "entredevorá": "entredevorar",
    "entredevorámo": "entredevorar",
    "entredevorámos": "entredevorar",
    "entredevoráramo": "entredevorar",
    "entredevoráramos": "entredevorar",
    "entredevorárei": "entredevorar",
    "entredevoráreis": "entredevorar",
    "entredevorásseis": "entredevorar",
    "entredevorássemos": "entredevorar",
    "entredevorávamo": "entredevorar",
    "entredevorávamos": "entredevorar",
    "entredevorávei": "entredevorar",
    "entredevoráveis": "entredevorar",
    "entrediga": "entredizer",
    "entredigais": "entredizer",
    "entredigam": "entredizer",
    "entredigamo": "entredizer",
    "entredigamos": "entredizer",
    "entredigas": "entredizer",
    "entredigo": "entredizer",
    "entredilacera": "entredilacerar",
    "entredilacerada": "entredilacerar",
    "entredilaceradas": "entredilacerar",
    "entredilacerado": "entredilacerar",
    "entredilacerados": "entredilacerar",
    "entredilacerai": "entredilacerar",
    "entredilacerais": "entredilacerar",
    "entredilaceram": "entredilacerar",
    "entredilaceramo": "entredilacerar",
    "entredilaceramos": "entredilacerar",
    "entredilacerando": "entredilacerar",
    "entredilacerara": "entredilacerar",
    "entredilaceraram": "entredilacerar",
    "entredilaceraras": "entredilacerar",
    "entredilacerarde": "entredilacerar",
    "entredilacerardes": "entredilacerar",
    "entredilacerare": "entredilacerar",
    "entredilacerarei": "entredilacerar",
    "entredilacerareis": "entredilacerar",
    "entredilacerarem": "entredilacerar",
    "entredilaceraremos": "entredilacerar",
    "entredilacerares": "entredilacerar",
    "entredilaceraria": "entredilacerar",
    "entredilacerariam": "entredilacerar",
    "entredilacerarias": "entredilacerar",
    "entredilacerarmo": "entredilacerar",
    "entredilacerarmos": "entredilacerar",
    "entredilacerará": "entredilacerar",
    "entredilacerarás": "entredilacerar",
    "entredilacerarão": "entredilacerar",
    "entredilaceraríamos": "entredilacerar",
    "entredilaceraríeis": "entredilacerar",
    "entredilaceras": "entredilacerar",
    "entredilacerasse": "entredilacerar",
    "entredilacerassem": "entredilacerar",
    "entredilacerasses": "entredilacerar",
    "entredilaceraste": "entredilacerar",
    "entredilacerastes": "entredilacerar",
    "entredilacerava": "entredilacerar",
    "entredilaceravam": "entredilacerar",
    "entredilaceravas": "entredilacerar",
    "entredilacere": "entredilacerar",
    "entredilacerei": "entredilacerar",
    "entredilacereis": "entredilacerar",
    "entredilacerem": "entredilacerar",
    "entredilaceremo": "entredilacerar",
    "entredilaceremos": "entredilacerar",
    "entredilaceres": "entredilacerar",
    "entredilacero": "entredilacerar",
    "entredilacerou": "entredilacerar",
    "entredilacerá": "entredilacerar",
    "entredilacerámo": "entredilacerar",
    "entredilacerámos": "entredilacerar",
    "entredilaceráramo": "entredilacerar",
    "entredilaceráramos": "entredilacerar",
    "entredilacerárei": "entredilacerar",
    "entredilaceráreis": "entredilacerar",
    "entredilacerásseis": "entredilacerar",
    "entredilacerássemos": "entredilacerar",
    "entredilacerávamo": "entredilacerar",
    "entredilacerávamos": "entredilacerar",
    "entredilacerávei": "entredilacerar",
    "entredilaceráveis": "entredilacerar",
    "entredirei": "entredizer",
    "entredireis": "entredizer",
    "entrediremos": "entredizer",
    "entrediria": "entredizer",
    "entrediriam": "entredizer",
    "entredirias": "entredizer",
    "entredirá": "entredizer",
    "entredirás": "entredizer",
    "entredirão": "entredizer",
    "entrediríamos": "entredizer",
    "entrediríeis": "entredizer",
    "entredisputa": "entredisputar",
    "entredisputada": "entredisputar",
    "entredisputadas": "entredisputar",
    "entredisputado": "entredisputar",
    "entredisputados": "entredisputar",
    "entredisputai": "entredisputar",
    "entredisputais": "entredisputar",
    "entredisputam": "entredisputar",
    "entredisputamo": "entredisputar",
    "entredisputamos": "entredisputar",
    "entredisputando": "entredisputar",
    "entredisputara": "entredisputar",
    "entredisputaram": "entredisputar",
    "entredisputaras": "entredisputar",
    "entredisputarde": "entredisputar",
    "entredisputardes": "entredisputar",
    "entredisputare": "entredisputar",
    "entredisputarei": "entredisputar",
    "entredisputareis": "entredisputar",
    "entredisputarem": "entredisputar",
    "entredisputaremos": "entredisputar",
    "entredisputares": "entredisputar",
    "entredisputaria": "entredisputar",
    "entredisputariam": "entredisputar",
    "entredisputarias": "entredisputar",
    "entredisputarmo": "entredisputar",
    "entredisputarmos": "entredisputar",
    "entredisputará": "entredisputar",
    "entredisputarás": "entredisputar",
    "entredisputarão": "entredisputar",
    "entredisputaríamos": "entredisputar",
    "entredisputaríeis": "entredisputar",
    "entredisputas": "entredisputar",
    "entredisputasse": "entredisputar",
    "entredisputassem": "entredisputar",
    "entredisputasses": "entredisputar",
    "entredisputaste": "entredisputar",
    "entredisputastes": "entredisputar",
    "entredisputava": "entredisputar",
    "entredisputavam": "entredisputar",
    "entredisputavas": "entredisputar",
    "entredispute": "entredisputar",
    "entredisputei": "entredisputar",
    "entredisputeis": "entredisputar",
    "entredisputem": "entredisputar",
    "entredisputemo": "entredisputar",
    "entredisputemos": "entredisputar",
    "entredisputes": "entredisputar",
    "entredisputo": "entredisputar",
    "entredisputou": "entredisputar",
    "entredisputá": "entredisputar",
    "entredisputámo": "entredisputar",
    "entredisputámos": "entredisputar",
    "entredisputáramo": "entredisputar",
    "entredisputáramos": "entredisputar",
    "entredisputárei": "entredisputar",
    "entredisputáreis": "entredisputar",
    "entredisputásseis": "entredisputar",
    "entredisputássemos": "entredisputar",
    "entredisputávamo": "entredisputar",
    "entredisputávamos": "entredisputar",
    "entredisputávei": "entredisputar",
    "entredisputáveis": "entredisputar",
    "entredisse": "entredizer",
    "entredissemo": "entredizer",
    "entredissemos": "entredizer",
    "entredisser": "entredizer",
    "entredissera": "entredizer",
    "entredisseram": "entredizer",
    "entredisseras": "entredizer",
    "entredisserdes": "entredizer",
    "entredisserem": "entredizer",
    "entredisseres": "entredizer",
    "entredissermos": "entredizer",
    "entredissesse": "entredizer",
    "entredissessem": "entredizer",
    "entredissesses": "entredizer",
    "entredisseste": "entredizer",
    "entredissestes": "entredizer",
    "entredisséramo": "entredizer",
    "entredisséramos": "entredizer",
    "entredissérei": "entredizer",
    "entredisséreis": "entredizer",
    "entredissésseis": "entredizer",
    "entredisséssemos": "entredizer",
    "entredita": "entredizer",
    "entreditas": "entredizer",
    "entredito": "entredizer",
    "entreditos": "entredizer",
    "entrediz": "entredizer",
    "entredize": "entredizer",
    "entredizei": "entredizer",
    "entredizeis": "entredizer",
    "entredizem": "entredizer",
    "entredizemo": "entredizer",
    "entredizemos": "entredizer",
    "entredizendo": "entredizer",
    "entredizerde": "entredizer",
    "entredizerdes": "entredizer",
    "entredizere": "entredizer",
    "entredizerem": "entredizer",
    "entredizeres": "entredizer",
    "entredizermo": "entredizer",
    "entredizermos": "entredizer",
    "entredizes": "entredizer",
    "entredizia": "entredizer",
    "entrediziam": "entredizer",
    "entredizias": "entredizer",
    "entredizê": "entredizer",
    "entredizíamo": "entredizer",
    "entredizíamos": "entredizer",
    "entredizíei": "entredizer",
    "entredizíeis": "entredizer",
    "entredormida": "entredormido",
    "entredormidas": "entredormido",
    "entredormidos": "entredormido",
    "entredúvidas": "entredúvida",
    "entreferros": "entreferro",
    "entrefesteja": "entrefestejar",
    "entrefestejada": "entrefestejar",
    "entrefestejadas": "entrefestejar",
    "entrefestejado": "entrefestejar",
    "entrefestejados": "entrefestejar",
    "entrefestejai": "entrefestejar",
    "entrefestejais": "entrefestejar",
    "entrefestejam": "entrefestejar",
    "entrefestejamo": "entrefestejar",
    "entrefestejamos": "entrefestejar",
    "entrefestejando": "entrefestejar",
    "entrefestejara": "entrefestejar",
    "entrefestejaram": "entrefestejar",
    "entrefestejaras": "entrefestejar",
    "entrefestejarde": "entrefestejar",
    "entrefestejardes": "entrefestejar",
    "entrefestejare": "entrefestejar",
    "entrefestejarei": "entrefestejar",
    "entrefestejareis": "entrefestejar",
    "entrefestejarem": "entrefestejar",
    "entrefestejaremos": "entrefestejar",
    "entrefestejares": "entrefestejar",
    "entrefestejaria": "entrefestejar",
    "entrefestejariam": "entrefestejar",
    "entrefestejarias": "entrefestejar",
    "entrefestejarmo": "entrefestejar",
    "entrefestejarmos": "entrefestejar",
    "entrefestejará": "entrefestejar",
    "entrefestejarás": "entrefestejar",
    "entrefestejarão": "entrefestejar",
    "entrefestejaríamos": "entrefestejar",
    "entrefestejaríeis": "entrefestejar",
    "entrefestejas": "entrefestejar",
    "entrefestejasse": "entrefestejar",
    "entrefestejassem": "entrefestejar",
    "entrefestejasses": "entrefestejar",
    "entrefestejaste": "entrefestejar",
    "entrefestejastes": "entrefestejar",
    "entrefestejava": "entrefestejar",
    "entrefestejavam": "entrefestejar",
    "entrefestejavas": "entrefestejar",
    "entrefesteje": "entrefestejar",
    "entrefestejei": "entrefestejar",
    "entrefestejeis": "entrefestejar",
    "entrefestejem": "entrefestejar",
    "entrefestejemo": "entrefestejar",
    "entrefestejemos": "entrefestejar",
    "entrefestejes": "entrefestejar",
    "entrefestejo": "entrefestejar",
    "entrefestejou": "entrefestejar",
    "entrefestejá": "entrefestejar",
    "entrefestejámo": "entrefestejar",
    "entrefestejámos": "entrefestejar",
    "entrefestejáramo": "entrefestejar",
    "entrefestejáramos": "entrefestejar",
    "entrefestejárei": "entrefestejar",
    "entrefestejáreis": "entrefestejar",
    "entrefestejásseis": "entrefestejar",
    "entrefestejássemos": "entrefestejar",
    "entrefestejávamo": "entrefestejar",
    "entrefestejávamos": "entrefestejar",
    "entrefestejávei": "entrefestejar",
    "entrefestejáveis": "entrefestejar",
    "entrefigura": "entrefigurar",
    "entrefigurada": "entrefigurar",
    "entrefiguradas": "entrefigurar",
    "entrefigurado": "entrefigurar",
    "entrefigurados": "entrefigurar",
    "entrefigurai": "entrefigurar",
    "entrefigurais": "entrefigurar",
    "entrefiguram": "entrefigurar",
    "entrefiguramo": "entrefigurar",
    "entrefiguramos": "entrefigurar",
    "entrefigurando": "entrefigurar",
    "entrefigurara": "entrefigurar",
    "entrefiguraram": "entrefigurar",
    "entrefiguraras": "entrefigurar",
    "entrefigurarde": "entrefigurar",
    "entrefigurardes": "entrefigurar",
    "entrefigurare": "entrefigurar",
    "entrefigurarei": "entrefigurar",
    "entrefigurareis": "entrefigurar",
    "entrefigurarem": "entrefigurar",
    "entrefiguraremos": "entrefigurar",
    "entrefigurares": "entrefigurar",
    "entrefiguraria": "entrefigurar",
    "entrefigurariam": "entrefigurar",
    "entrefigurarias": "entrefigurar",
    "entrefigurarmo": "entrefigurar",
    "entrefigurarmos": "entrefigurar",
    "entrefigurará": "entrefigurar",
    "entrefigurarás": "entrefigurar",
    "entrefigurarão": "entrefigurar",
    "entrefiguraríamos": "entrefigurar",
    "entrefiguraríeis": "entrefigurar",
    "entrefiguras": "entrefigurar",
    "entrefigurasse": "entrefigurar",
    "entrefigurassem": "entrefigurar",
    "entrefigurasses": "entrefigurar",
    "entrefiguraste": "entrefigurar",
    "entrefigurastes": "entrefigurar",
    "entrefigurava": "entrefigurar",
    "entrefiguravam": "entrefigurar",
    "entrefiguravas": "entrefigurar",
    "entrefigure": "entrefigurar",
    "entrefigurei": "entrefigurar",
    "entrefigureis": "entrefigurar",
    "entrefigurem": "entrefigurar",
    "entrefiguremo": "entrefigurar",
    "entrefiguremos": "entrefigurar",
    "entrefigures": "entrefigurar",
    "entrefiguro": "entrefigurar",
    "entrefigurou": "entrefigurar",
    "entrefigurá": "entrefigurar",
    "entrefigurámo": "entrefigurar",
    "entrefigurámos": "entrefigurar",
    "entrefiguráramo": "entrefigurar",
    "entrefiguráramos": "entrefigurar",
    "entrefigurárei": "entrefigurar",
    "entrefiguráreis": "entrefigurar",
    "entrefigurásseis": "entrefigurar",
    "entrefigurássemos": "entrefigurar",
    "entrefigurávamo": "entrefigurar",
    "entrefigurávamos": "entrefigurar",
    "entrefigurávei": "entrefigurar",
    "entrefiguráveis": "entrefigurar",
    "entrefolha": "entrefolhar",
    "entrefolhada": "entrefolhar",
    "entrefolhadas": "entrefolhar",
    "entrefolhado": "entrefolhar",
    "entrefolhados": "entrefolhar",
    "entrefolhai": "entrefolhar",
    "entrefolhais": "entrefolhar",
    "entrefolham": "entrefolhar",
    "entrefolhamo": "entrefolhar",
    "entrefolhamos": "entrefolhar",
    "entrefolhando": "entrefolhar",
    "entrefolhara": "entrefolhar",
    "entrefolharam": "entrefolhar",
    "entrefolharas": "entrefolhar",
    "entrefolharde": "entrefolhar",
    "entrefolhardes": "entrefolhar",
    "entrefolhare": "entrefolhar",
    "entrefolharei": "entrefolhar",
    "entrefolhareis": "entrefolhar",
    "entrefolharem": "entrefolhar",
    "entrefolharemos": "entrefolhar",
    "entrefolhares": "entrefolhar",
    "entrefolharia": "entrefolhar",
    "entrefolhariam": "entrefolhar",
    "entrefolharias": "entrefolhar",
    "entrefolharmo": "entrefolhar",
    "entrefolharmos": "entrefolhar",
    "entrefolhará": "entrefolhar",
    "entrefolharás": "entrefolhar",
    "entrefolharão": "entrefolhar",
    "entrefolharíamos": "entrefolhar",
    "entrefolharíeis": "entrefolhar",
    "entrefolhas": "entrefolhar",
    "entrefolhasse": "entrefolhar",
    "entrefolhassem": "entrefolhar",
    "entrefolhasses": "entrefolhar",
    "entrefolhaste": "entrefolhar",
    "entrefolhastes": "entrefolhar",
    "entrefolhava": "entrefolhar",
    "entrefolhavam": "entrefolhar",
    "entrefolhavas": "entrefolhar",
    "entrefolhe": "entrefolhar",
    "entrefolhei": "entrefolhar",
    "entrefolheis": "entrefolhar",
    "entrefolhem": "entrefolhar",
    "entrefolhemo": "entrefolhar",
    "entrefolhemos": "entrefolhar",
    "entrefolhes": "entrefolhar",
    "entrefolho": "entrefolhar",
    "entrefolhos": "entrefolho",
    "entrefolhou": "entrefolhar",
    "entrefolhá": "entrefolhar",
    "entrefolhámo": "entrefolhar",
    "entrefolhámos": "entrefolhar",
    "entrefolháramo": "entrefolhar",
    "entrefolháramos": "entrefolhar",
    "entrefolhárei": "entrefolhar",
    "entrefolháreis": "entrefolhar",
    "entrefolhásseis": "entrefolhar",
    "entrefolhássemos": "entrefolhar",
    "entrefolhávamo": "entrefolhar",
    "entrefolhávamos": "entrefolhar",
    "entrefolhávei": "entrefolhar",
    "entrefolháveis": "entrefolhar",
    "entreforros": "entreforro",
    "entrega": "entregar",
    "entregada": "entregar",
    "entregadas": "entregar",
    "entregado": "entregar",
    "entregadoira": "entregadoiro",
    "entregadoiras": "entregadoiro",
    "entregadoiros": "entregadoiro",
    "entregadora": "entregador",
    "entregadoras": "entregador",
    "entregadores": "entregador",
    "entregados": "entregar",
    "entregadoura": "entregadouro",
    "entregadouras": "entregadouro",
    "entregadouros": "entregadouro",
    "entregai": "entregar",
    "entregais": "entregar",
    "entregam": "entregar",
    "entregamo": "entregar",
    "entregamos": "entregar",
    "entregando": "entregar",
    "entregara": "entregar",
    "entregaram": "entregar",
    "entregaras": "entregar",
    "entregarde": "entregar",
    "entregardes": "entregar",
    "entregare": "entregar",
    "entregarei": "entregar",
    "entregareis": "entregar",
    "entregarem": "entregar",
    "entregaremos": "entregar",
    "entregares": "entregar",
    "entregaria": "entregar",
    "entregariam": "entregar",
    "entregarias": "entregar",
    "entregarmo": "entregar",
    "entregarmos": "entregar",
    "entregará": "entregar",
    "entregarás": "entregar",
    "entregarão": "entregar",
    "entregaríamos": "entregar",
    "entregaríeis": "entregar",
    "entregas": "entregar",
    "entregasse": "entregar",
    "entregassem": "entregar",
    "entregasses": "entregar",
    "entregaste": "entregar",
    "entregastes": "entregar",
    "entregava": "entregar",
    "entregavam": "entregar",
    "entregavas": "entregar",
    "entrego": "entregar",
    "entregou": "entregar",
    "entregue": "entregar",
    "entreguei": "entregar",
    "entregueis": "entregar",
    "entreguem": "entregar",
    "entreguemo": "entregar",
    "entreguemos": "entregar",
    "entregues": "entregue",
    "entregá": "entregar",
    "entregámo": "entregar",
    "entregámos": "entregar",
    "entregáramo": "entregar",
    "entregáramos": "entregar",
    "entregárei": "entregar",
    "entregáreis": "entregar",
    "entregásseis": "entregar",
    "entregássemos": "entregar",
    "entregávamo": "entregar",
    "entregávamos": "entregar",
    "entregávei": "entregar",
    "entregáveis": "entregável",
    "entrei": "entrar",
    "entreis": "entrar",
    "entrejuntas": "entrejunta",
    "entrelace": "entrelaçar",
    "entrelacei": "entrelaçar",
    "entrelaceis": "entrelaçar",
    "entrelacem": "entrelaçar",
    "entrelacemo": "entrelaçar",
    "entrelacemos": "entrelaçar",
    "entrelaces": "entrelaçar",
    "entrelaça": "entrelaçar",
    "entrelaçada": "entrelaçar",
    "entrelaçadas": "entrelaçar",
    "entrelaçado": "entrelaçar",
    "entrelaçados": "entrelaçar",
    "entrelaçai": "entrelaçar",
    "entrelaçais": "entrelaçar",
    "entrelaçam": "entrelaçar",
    "entrelaçamentos": "entrelaçamento",
    "entrelaçamo": "entrelaçar",
    "entrelaçamos": "entrelaçar",
    "entrelaçando": "entrelaçar",
    "entrelaçara": "entrelaçar",
    "entrelaçaram": "entrelaçar",
    "entrelaçaras": "entrelaçar",
    "entrelaçarde": "entrelaçar",
    "entrelaçardes": "entrelaçar",
    "entrelaçare": "entrelaçar",
    "entrelaçarei": "entrelaçar",
    "entrelaçareis": "entrelaçar",
    "entrelaçarem": "entrelaçar",
    "entrelaçaremos": "entrelaçar",
    "entrelaçares": "entrelaçar",
    "entrelaçaria": "entrelaçar",
    "entrelaçariam": "entrelaçar",
    "entrelaçarias": "entrelaçar",
    "entrelaçarmo": "entrelaçar",
    "entrelaçarmos": "entrelaçar",
    "entrelaçará": "entrelaçar",
    "entrelaçarás": "entrelaçar",
    "entrelaçarão": "entrelaçar",
    "entrelaçaríamos": "entrelaçar",
    "entrelaçaríeis": "entrelaçar",
    "entrelaças": "entrelaçar",
    "entrelaçasse": "entrelaçar",
    "entrelaçassem": "entrelaçar",
    "entrelaçasses": "entrelaçar",
    "entrelaçaste": "entrelaçar",
    "entrelaçastes": "entrelaçar",
    "entrelaçava": "entrelaçar",
    "entrelaçavam": "entrelaçar",
    "entrelaçavas": "entrelaçar",
    "entrelaço": "entrelaçar",
    "entrelaçou": "entrelaçar",
    "entrelaçá": "entrelaçar",
    "entrelaçámo": "entrelaçar",
    "entrelaçámos": "entrelaçar",
    "entrelaçáramo": "entrelaçar",
    "entrelaçáramos": "entrelaçar",
    "entrelaçárei": "entrelaçar",
    "entrelaçáreis": "entrelaçar",
    "entrelaçásseis": "entrelaçar",
    "entrelaçássemos": "entrelaçar",
    "entrelaçávamo": "entrelaçar",
    "entrelaçávamos": "entrelaçar",
    "entrelaçávei": "entrelaçar",
    "entrelaçáveis": "entrelaçar",
    "entrelembra": "entrelembrar",
    "entrelembrada": "entrelembrar",
    "entrelembradas": "entrelembrar",
    "entrelembrado": "entrelembrar",
    "entrelembrados": "entrelembrar",
    "entrelembrai": "entrelembrar",
    "entrelembrais": "entrelembrar",
    "entrelembram": "entrelembrar",
    "entrelembramo": "entrelembrar",
    "entrelembramos": "entrelembrar",
    "entrelembrando": "entrelembrar",
    "entrelembrara": "entrelembrar",
    "entrelembraram": "entrelembrar",
    "entrelembraras": "entrelembrar",
    "entrelembrarde": "entrelembrar",
    "entrelembrardes": "entrelembrar",
    "entrelembrare": "entrelembrar",
    "entrelembrarei": "entrelembrar",
    "entrelembrareis": "entrelembrar",
    "entrelembrarem": "entrelembrar",
    "entrelembraremos": "entrelembrar",
    "entrelembrares": "entrelembrar",
    "entrelembraria": "entrelembrar",
    "entrelembrariam": "entrelembrar",
    "entrelembrarias": "entrelembrar",
    "entrelembrarmo": "entrelembrar",
    "entrelembrarmos": "entrelembrar",
    "entrelembrará": "entrelembrar",
    "entrelembrarás": "entrelembrar",
    "entrelembrarão": "entrelembrar",
    "entrelembraríamos": "entrelembrar",
    "entrelembraríeis": "entrelembrar",
    "entrelembras": "entrelembrar",
    "entrelembrasse": "entrelembrar",
    "entrelembrassem": "entrelembrar",
    "entrelembrasses": "entrelembrar",
    "entrelembraste": "entrelembrar",
    "entrelembrastes": "entrelembrar",
    "entrelembrava": "entrelembrar",
    "entrelembravam": "entrelembrar",
    "entrelembravas": "entrelembrar",
    "entrelembre": "entrelembrar",
    "entrelembrei": "entrelembrar",
    "entrelembreis": "entrelembrar",
    "entrelembrem": "entrelembrar",
    "entrelembremo": "entrelembrar",
    "entrelembremos": "entrelembrar",
    "entrelembres": "entrelembrar",
    "entrelembro": "entrelembrar",
    "entrelembrou": "entrelembrar",
    "entrelembrá": "entrelembrar",
    "entrelembrámo": "entrelembrar",
    "entrelembrámos": "entrelembrar",
    "entrelembráramo": "entrelembrar",
    "entrelembráramos": "entrelembrar",
    "entrelembrárei": "entrelembrar",
    "entrelembráreis": "entrelembrar",
    "entrelembrásseis": "entrelembrar",
    "entrelembrássemos": "entrelembrar",
    "entrelembrávamo": "entrelembrar",
    "entrelembrávamos": "entrelembrar",
    "entrelembrávei": "entrelembrar",
    "entrelembráveis": "entrelembrar",
    "entreliga": "entreligar",
    "entreligada": "entreligar",
    "entreligadas": "entreligar",
    "entreligado": "entreligar",
    "entreligados": "entreligar",
    "entreligai": "entreligar",
    "entreligais": "entreligar",
    "entreligam": "entreligar",
    "entreligamo": "entreligar",
    "entreligamos": "entreligar",
    "entreligando": "entreligar",
    "entreligara": "entreligar",
    "entreligaram": "entreligar",
    "entreligaras": "entreligar",
    "entreligarde": "entreligar",
    "entreligardes": "entreligar",
    "entreligare": "entreligar",
    "entreligarei": "entreligar",
    "entreligareis": "entreligar",
    "entreligarem": "entreligar",
    "entreligaremos": "entreligar",
    "entreligares": "entreligar",
    "entreligaria": "entreligar",
    "entreligariam": "entreligar",
    "entreligarias": "entreligar",
    "entreligarmo": "entreligar",
    "entreligarmos": "entreligar",
    "entreligará": "entreligar",
    "entreligarás": "entreligar",
    "entreligarão": "entreligar",
    "entreligaríamos": "entreligar",
    "entreligaríeis": "entreligar",
    "entreligas": "entreligar",
    "entreligasse": "entreligar",
    "entreligassem": "entreligar",
    "entreligasses": "entreligar",
    "entreligaste": "entreligar",
    "entreligastes": "entreligar",
    "entreligava": "entreligar",
    "entreligavam": "entreligar",
    "entreligavas": "entreligar",
    "entreligo": "entreligar",
    "entreligou": "entreligar",
    "entreligue": "entreligar",
    "entreliguei": "entreligar",
    "entreligueis": "entreligar",
    "entreliguem": "entreligar",
    "entreliguemo": "entreligar",
    "entreliguemos": "entreligar",
    "entreligues": "entreligar",
    "entreligá": "entreligar",
    "entreligámo": "entreligar",
    "entreligámos": "entreligar",
    "entreligáramo": "entreligar",
    "entreligáramos": "entreligar",
    "entreligárei": "entreligar",
    "entreligáreis": "entreligar",
    "entreligásseis": "entreligar",
    "entreligássemos": "entreligar",
    "entreligávamo": "entreligar",
    "entreligávamos": "entreligar",
    "entreligávei": "entreligar",
    "entreligáveis": "entreligar",
    "entrelinha": "entrelinhar",
    "entrelinhada": "entrelinhar",
    "entrelinhadas": "entrelinhar",
    "entrelinhado": "entrelinhar",
    "entrelinhados": "entrelinhar",
    "entrelinhai": "entrelinhar",
    "entrelinhais": "entrelinhar",
    "entrelinham": "entrelinhar",
    "entrelinhamentos": "entrelinhamento",
    "entrelinhamo": "entrelinhar",
    "entrelinhamos": "entrelinhar",
    "entrelinhando": "entrelinhar",
    "entrelinhara": "entrelinhar",
    "entrelinharam": "entrelinhar",
    "entrelinharas": "entrelinhar",
    "entrelinharde": "entrelinhar",
    "entrelinhardes": "entrelinhar",
    "entrelinhare": "entrelinhar",
    "entrelinharei": "entrelinhar",
    "entrelinhareis": "entrelinhar",
    "entrelinharem": "entrelinhar",
    "entrelinharemos": "entrelinhar",
    "entrelinhares": "entrelinhar",
    "entrelinharia": "entrelinhar",
    "entrelinhariam": "entrelinhar",
    "entrelinharias": "entrelinhar",
    "entrelinharmo": "entrelinhar",
    "entrelinharmos": "entrelinhar",
    "entrelinhará": "entrelinhar",
    "entrelinharás": "entrelinhar",
    "entrelinharão": "entrelinhar",
    "entrelinharíamos": "entrelinhar",
    "entrelinharíeis": "entrelinhar",
    "entrelinhas": "entrelinhar",
    "entrelinhasse": "entrelinhar",
    "entrelinhassem": "entrelinhar",
    "entrelinhasses": "entrelinhar",
    "entrelinhaste": "entrelinhar",
    "entrelinhastes": "entrelinhar",
    "entrelinhava": "entrelinhar",
    "entrelinhavam": "entrelinhar",
    "entrelinhavas": "entrelinhar",
    "entrelinhe": "entrelinhar",
    "entrelinhei": "entrelinhar",
    "entrelinheis": "entrelinhar",
    "entrelinhem": "entrelinhar",
    "entrelinhemo": "entrelinhar",
    "entrelinhemos": "entrelinhar",
    "entrelinhes": "entrelinhar",
    "entrelinho": "entrelinhar",
    "entrelinhou": "entrelinhar",
    "entrelinhá": "entrelinhar",
    "entrelinhámo": "entrelinhar",
    "entrelinhámos": "entrelinhar",
    "entrelinháramo": "entrelinhar",
    "entrelinháramos": "entrelinhar",
    "entrelinhárei": "entrelinhar",
    "entrelinháreis": "entrelinhar",
    "entrelinhásseis": "entrelinhar",
    "entrelinhássemos": "entrelinhar",
    "entrelinhávamo": "entrelinhar",
    "entrelinhávamos": "entrelinhar",
    "entrelinhávei": "entrelinhar",
    "entrelinháveis": "entrelinhar",
    "entreluz": "entreluzir",
    "entreluza": "entreluzir",
    "entreluzais": "entreluzir",
    "entreluzam": "entreluzir",
    "entreluzamo": "entreluzir",
    "entreluzamos": "entreluzir",
    "entreluzas": "entreluzir",
    "entreluze": "entreluzir",
    "entreluzem": "entreluzir",
    "entreluzes": "entreluzir",
    "entreluzi": "entreluzir",
    "entreluzia": "entreluzir",
    "entreluziam": "entreluzir",
    "entreluzias": "entreluzir",
    "entreluzida": "entreluzir",
    "entreluzidas": "entreluzir",
    "entreluzido": "entreluzir",
    "entreluzidos": "entreluzir",
    "entreluzimo": "entreluzir",
    "entreluzimos": "entreluzir",
    "entreluzindo": "entreluzir",
    "entreluzira": "entreluzir",
    "entreluziram": "entreluzir",
    "entreluziras": "entreluzir",
    "entreluzirdes": "entreluzir",
    "entreluzirei": "entreluzir",
    "entreluzireis": "entreluzir",
    "entreluzirem": "entreluzir",
    "entreluziremos": "entreluzir",
    "entreluzires": "entreluzir",
    "entreluziria": "entreluzir",
    "entreluziriam": "entreluzir",
    "entreluzirias": "entreluzir",
    "entreluzirmo": "entreluzir",
    "entreluzirmos": "entreluzir",
    "entreluzirá": "entreluzir",
    "entreluzirás": "entreluzir",
    "entreluzirão": "entreluzir",
    "entreluziríamos": "entreluzir",
    "entreluziríeis": "entreluzir",
    "entreluzis": "entreluzir",
    "entreluzisse": "entreluzir",
    "entreluzissem": "entreluzir",
    "entreluzisses": "entreluzir",
    "entreluziste": "entreluzir",
    "entreluzistes": "entreluzir",
    "entreluziu": "entreluzir",
    "entreluzo": "entreluzir",
    "entreluzíamo": "entreluzir",
    "entreluzíamos": "entreluzir",
    "entreluzíeis": "entreluzir",
    "entreluzíramo": "entreluzir",
    "entreluzíramos": "entreluzir",
    "entreluzíreis": "entreluzir",
    "entreluzísseis": "entreluzir",
    "entreluzíssemos": "entreluzir",
    "entrem": "entrar",
    "entremadura": "entremaduro",
    "entremaduras": "entremaduro",
    "entremaduros": "entremaduro",
    "entremanhãs": "entremanhã",
    "entremeada": "entremear",
    "entremeadas": "entremear",
    "entremeado": "entremear",
    "entremeados": "entremear",
    "entremeai": "entremear",
    "entremeais": "entremear",
    "entremeamo": "entremear",
    "entremeamos": "entremear",
    "entremeando": "entremear",
    "entremeara": "entremear",
    "entremearam": "entremear",
    "entremearas": "entremear",
    "entremearde": "entremear",
    "entremeardes": "entremear",
    "entremeare": "entremear",
    "entremearei": "entremear",
    "entremeareis": "entremear",
    "entremearem": "entremear",
    "entremearemos": "entremear",
    "entremeares": "entremear",
    "entremearia": "entremear",
    "entremeariam": "entremear",
    "entremearias": "entremear",
    "entremearmo": "entremear",
    "entremearmos": "entremear",
    "entremeará": "entremear",
    "entremearás": "entremear",
    "entremearão": "entremear",
    "entremearíamos": "entremear",
    "entremearíeis": "entremear",
    "entremeasse": "entremear",
    "entremeassem": "entremear",
    "entremeasses": "entremear",
    "entremeaste": "entremear",
    "entremeastes": "entremear",
    "entremeava": "entremear",
    "entremeavam": "entremear",
    "entremeavas": "entremear",
    "entremechas": "entremecha",
    "entremeei": "entremear",
    "entremeeis": "entremear",
    "entremeemo": "entremear",
    "entremeemos": "entremear",
    "entremeia": "entremear",
    "entremeiam": "entremear",
    "entremeias": "entremear",
    "entremeie": "entremear",
    "entremeiem": "entremear",
    "entremeies": "entremear",
    "entremeio": "entremear",
    "entremeios": "entremeio",
    "entremeou": "entremear",
    "entremeses": "entremês",
    "entremessas": "entremessa",
    "entremeta": "entremeter",
    "entremetais": "entremeter",
    "entremetam": "entremeter",
    "entremetamo": "entremeter",
    "entremetamos": "entremeter",
    "entremetas": "entremeter",
    "entremete": "entremeter",
    "entremetei": "entremeter",
    "entremeteis": "entremeter",
    "entremetem": "entremeter",
    "entremetemo": "entremeter",
    "entremetemos": "entremeter",
    "entremetendo": "entremeter",
    "entremetera": "entremeter",
    "entremeteram": "entremeter",
    "entremeteras": "entremeter",
    "entremeterde": "entremeter",
    "entremeterdes": "entremeter",
    "entremetere": "entremeter",
    "entremeterei": "entremeter",
    "entremetereis": "entremeter",
    "entremeterem": "entremeter",
    "entremeteremos": "entremeter",
    "entremeteres": "entremeter",
    "entremeteria": "entremeter",
    "entremeteriam": "entremeter",
    "entremeterias": "entremeter",
    "entremetermo": "entremeter",
    "entremetermos": "entremeter",
    "entremeterá": "entremeter",
    "entremeterás": "entremeter",
    "entremeterão": "entremeter",
    "entremeteríamos": "entremeter",
    "entremeteríeis": "entremeter",
    "entremetes": "entremeter",
    "entremetesse": "entremeter",
    "entremetessem": "entremeter",
    "entremetesses": "entremeter",
    "entremeteste": "entremeter",
    "entremetestes": "entremeter",
    "entremeteu": "entremeter",
    "entremeti": "entremeter",
    "entremetia": "entremeter",
    "entremetiam": "entremeter",
    "entremetias": "entremeter",
    "entremetida": "entremetido",
    "entremetidas": "entremetido",
    "entremetido": "entremeter",
    "entremetidos": "entremetido",
    "entremetimentos": "entremetimento",
    "entremeto": "entremeter",
    "entremetê": "entremeter",
    "entremetêramo": "entremeter",
    "entremetêramos": "entremeter",
    "entremetêrei": "entremeter",
    "entremetêreis": "entremeter",
    "entremetêsseis": "entremeter",
    "entremetêssemos": "entremeter",
    "entremetíamo": "entremeter",
    "entremetíamos": "entremeter",
    "entremetíei": "entremeter",
    "entremetíeis": "entremeter",
    "entremezada": "entremezado",
    "entremezadas": "entremezado",
    "entremezados": "entremezado",
    "entremezes": "entremez",
    "entremezistas": "entremezista",
    "entremeá": "entremear",
    "entremeámo": "entremear",
    "entremeámos": "entremear",
    "entremeáramo": "entremear",
    "entremeáramos": "entremear",
    "entremeárei": "entremear",
    "entremeáreis": "entremear",
    "entremeásseis": "entremear",
    "entremeássemos": "entremear",
    "entremeávamo": "entremear",
    "entremeávamos": "entremear",
    "entremeávei": "entremear",
    "entremeáveis": "entremeável",
    "entremistura": "entremisturar",
    "entremisturada": "entremisturar",
    "entremisturadas": "entremisturar",
    "entremisturado": "entremisturar",
    "entremisturados": "entremisturar",
    "entremisturai": "entremisturar",
    "entremisturais": "entremisturar",
    "entremisturam": "entremisturar",
    "entremisturamo": "entremisturar",
    "entremisturamos": "entremisturar",
    "entremisturando": "entremisturar",
    "entremisturara": "entremisturar",
    "entremisturaram": "entremisturar",
    "entremisturaras": "entremisturar",
    "entremisturarde": "entremisturar",
    "entremisturardes": "entremisturar",
    "entremisturare": "entremisturar",
    "entremisturarei": "entremisturar",
    "entremisturareis": "entremisturar",
    "entremisturarem": "entremisturar",
    "entremisturaremos": "entremisturar",
    "entremisturares": "entremisturar",
    "entremisturaria": "entremisturar",
    "entremisturariam": "entremisturar",
    "entremisturarias": "entremisturar",
    "entremisturarmo": "entremisturar",
    "entremisturarmos": "entremisturar",
    "entremisturará": "entremisturar",
    "entremisturarás": "entremisturar",
    "entremisturarão": "entremisturar",
    "entremisturaríamos": "entremisturar",
    "entremisturaríeis": "entremisturar",
    "entremisturas": "entremisturar",
    "entremisturasse": "entremisturar",
    "entremisturassem": "entremisturar",
    "entremisturasses": "entremisturar",
    "entremisturaste": "entremisturar",
    "entremisturastes": "entremisturar",
    "entremisturava": "entremisturar",
    "entremisturavam": "entremisturar",
    "entremisturavas": "entremisturar",
    "entremisture": "entremisturar",
    "entremisturei": "entremisturar",
    "entremistureis": "entremisturar",
    "entremisturem": "entremisturar",
    "entremisturemo": "entremisturar",
    "entremisturemos": "entremisturar",
    "entremistures": "entremisturar",
    "entremisturo": "entremisturar",
    "entremisturou": "entremisturar",
    "entremisturá": "entremisturar",
    "entremisturámo": "entremisturar",
    "entremisturámos": "entremisturar",
    "entremisturáramo": "entremisturar",
    "entremisturáramos": "entremisturar",
    "entremisturárei": "entremisturar",
    "entremisturáreis": "entremisturar",
    "entremisturásseis": "entremisturar",
    "entremisturássemos": "entremisturar",
    "entremisturávamo": "entremisturar",
    "entremisturávamos": "entremisturar",
    "entremisturávei": "entremisturar",
    "entremisturáveis": "entremisturar",
    "entremo": "entrar",
    "entremodilhões": "entremodilhão",
    "entremontana": "entremontano",
    "entremontanas": "entremontano",
    "entremontanos": "entremontano",
    "entremos": "entrar",
    "entremostra": "entremostrar",
    "entremostrada": "entremostrar",
    "entremostradas": "entremostrar",
    "entremostrado": "entremostrar",
    "entremostrados": "entremostrar",
    "entremostrai": "entremostrar",
    "entremostrais": "entremostrar",
    "entremostram": "entremostrar",
    "entremostramo": "entremostrar",
    "entremostramos": "entremostrar",
    "entremostrando": "entremostrar",
    "entremostrara": "entremostrar",
    "entremostraram": "entremostrar",
    "entremostraras": "entremostrar",
    "entremostrarde": "entremostrar",
    "entremostrardes": "entremostrar",
    "entremostrare": "entremostrar",
    "entremostrarei": "entremostrar",
    "entremostrareis": "entremostrar",
    "entremostrarem": "entremostrar",
    "entremostraremos": "entremostrar",
    "entremostrares": "entremostrar",
    "entremostraria": "entremostrar",
    "entremostrariam": "entremostrar",
    "entremostrarias": "entremostrar",
    "entremostrarmo": "entremostrar",
    "entremostrarmos": "entremostrar",
    "entremostrará": "entremostrar",
    "entremostrarás": "entremostrar",
    "entremostrarão": "entremostrar",
    "entremostraríamos": "entremostrar",
    "entremostraríeis": "entremostrar",
    "entremostras": "entremostrar",
    "entremostrasse": "entremostrar",
    "entremostrassem": "entremostrar",
    "entremostrasses": "entremostrar",
    "entremostraste": "entremostrar",
    "entremostrastes": "entremostrar",
    "entremostrava": "entremostrar",
    "entremostravam": "entremostrar",
    "entremostravas": "entremostrar",
    "entremostre": "entremostrar",
    "entremostrei": "entremostrar",
    "entremostreis": "entremostrar",
    "entremostrem": "entremostrar",
    "entremostremo": "entremostrar",
    "entremostremos": "entremostrar",
    "entremostres": "entremostrar",
    "entremostro": "entremostrar",
    "entremostrou": "entremostrar",
    "entremostrá": "entremostrar",
    "entremostrámo": "entremostrar",
    "entremostrámos": "entremostrar",
    "entremostráramo": "entremostrar",
    "entremostráramos": "entremostrar",
    "entremostrárei": "entremostrar",
    "entremostráreis": "entremostrar",
    "entremostrásseis": "entremostrar",
    "entremostrássemos": "entremostrar",
    "entremostrávamo": "entremostrar",
    "entremostrávamos": "entremostrar",
    "entremostrávei": "entremostrar",
    "entremostráveis": "entremostrar",
    "entrenubla": "entrenublar",
    "entrenublada": "entrenublar",
    "entrenubladas": "entrenublar",
    "entrenublado": "entrenublar",
    "entrenublados": "entrenublar",
    "entrenublai": "entrenublar",
    "entrenublais": "entrenublar",
    "entrenublam": "entrenublar",
    "entrenublamo": "entrenublar",
    "entrenublamos": "entrenublar",
    "entrenublando": "entrenublar",
    "entrenublara": "entrenublar",
    "entrenublaram": "entrenublar",
    "entrenublaras": "entrenublar",
    "entrenublardes": "entrenublar",
    "entrenublarei": "entrenublar",
    "entrenublareis": "entrenublar",
    "entrenublarem": "entrenublar",
    "entrenublaremos": "entrenublar",
    "entrenublares": "entrenublar",
    "entrenublaria": "entrenublar",
    "entrenublariam": "entrenublar",
    "entrenublarias": "entrenublar",
    "entrenublarmo": "entrenublar",
    "entrenublarmos": "entrenublar",
    "entrenublará": "entrenublar",
    "entrenublarás": "entrenublar",
    "entrenublarão": "entrenublar",
    "entrenublaríamos": "entrenublar",
    "entrenublaríeis": "entrenublar",
    "entrenublas": "entrenublar",
    "entrenublasse": "entrenublar",
    "entrenublassem": "entrenublar",
    "entrenublasses": "entrenublar",
    "entrenublaste": "entrenublar",
    "entrenublastes": "entrenublar",
    "entrenublava": "entrenublar",
    "entrenublavam": "entrenublar",
    "entrenublavas": "entrenublar",
    "entrenuble": "entrenublar",
    "entrenublei": "entrenublar",
    "entrenubleis": "entrenublar",
    "entrenublem": "entrenublar",
    "entrenublemo": "entrenublar",
    "entrenublemos": "entrenublar",
    "entrenubles": "entrenublar",
    "entrenublo": "entrenublar",
    "entrenublou": "entrenublar",
    "entrenublámo": "entrenublar",
    "entrenublámos": "entrenublar",
    "entrenubláramo": "entrenublar",
    "entrenubláramos": "entrenublar",
    "entrenubláreis": "entrenublar",
    "entrenublásseis": "entrenublar",
    "entrenublássemos": "entrenublar",
    "entrenublávamo": "entrenublar",
    "entrenublávamos": "entrenublar",
    "entrenubláveis": "entrenublar",
    "entrenós": "entrenó",
    "entreoiça": "entreouvir",
    "entreoiçais": "entreouvir",
    "entreoiçam": "entreouvir",
    "entreoiçamo": "entreouvir",
    "entreoiçamos": "entreouvir",
    "entreoiças": "entreouvir",
    "entreoiço": "entreouvir",
    "entreolha": "entreolhar",
    "entreolhada": "entreolhar",
    "entreolhadas": "entreolhar",
    "entreolhado": "entreolhar",
    "entreolhados": "entreolhar",
    "entreolhai": "entreolhar",
    "entreolhais": "entreolhar",
    "entreolham": "entreolhar",
    "entreolhamo": "entreolhar",
    "entreolhamos": "entreolhar",
    "entreolhando": "entreolhar",
    "entreolhara": "entreolhar",
    "entreolharam": "entreolhar",
    "entreolharas": "entreolhar",
    "entreolharde": "entreolhar",
    "entreolhardes": "entreolhar",
    "entreolhare": "entreolhar",
    "entreolharei": "entreolhar",
    "entreolhareis": "entreolhar",
    "entreolharem": "entreolhar",
    "entreolharemos": "entreolhar",
    "entreolhares": "entreolhar",
    "entreolharia": "entreolhar",
    "entreolhariam": "entreolhar",
    "entreolharias": "entreolhar",
    "entreolharmo": "entreolhar",
    "entreolharmos": "entreolhar",
    "entreolhará": "entreolhar",
    "entreolharás": "entreolhar",
    "entreolharão": "entreolhar",
    "entreolharíamos": "entreolhar",
    "entreolharíeis": "entreolhar",
    "entreolhas": "entreolhar",
    "entreolhasse": "entreolhar",
    "entreolhassem": "entreolhar",
    "entreolhasses": "entreolhar",
    "entreolhaste": "entreolhar",
    "entreolhastes": "entreolhar",
    "entreolhava": "entreolhar",
    "entreolhavam": "entreolhar",
    "entreolhavas": "entreolhar",
    "entreolhe": "entreolhar",
    "entreolhei": "entreolhar",
    "entreolheis": "entreolhar",
    "entreolhem": "entreolhar",
    "entreolhemo": "entreolhar",
    "entreolhemos": "entreolhar",
    "entreolhes": "entreolhar",
    "entreolho": "entreolhar",
    "entreolhou": "entreolhar",
    "entreolhá": "entreolhar",
    "entreolhámo": "entreolhar",
    "entreolhámos": "entreolhar",
    "entreolháramo": "entreolhar",
    "entreolháramos": "entreolhar",
    "entreolhárei": "entreolhar",
    "entreolháreis": "entreolhar",
    "entreolhásseis": "entreolhar",
    "entreolhássemos": "entreolhar",
    "entreolhávamo": "entreolhar",
    "entreolhávamos": "entreolhar",
    "entreolhávei": "entreolhar",
    "entreolháveis": "entreolhar",
    "entreouve": "entreouvir",
    "entreouvem": "entreouvir",
    "entreouves": "entreouvir",
    "entreouvi": "entreouvir",
    "entreouvia": "entreouvir",
    "entreouviam": "entreouvir",
    "entreouvias": "entreouvir",
    "entreouvida": "entreouvir",
    "entreouvidas": "entreouvir",
    "entreouvido": "entreouvir",
    "entreouvidos": "entreouvir",
    "entreouvimo": "entreouvir",
    "entreouvimos": "entreouvir",
    "entreouvindo": "entreouvir",
    "entreouvira": "entreouvir",
    "entreouviram": "entreouvir",
    "entreouviras": "entreouvir",
    "entreouvirde": "entreouvir",
    "entreouvirdes": "entreouvir",
    "entreouvire": "entreouvir",
    "entreouvirei": "entreouvir",
    "entreouvireis": "entreouvir",
    "entreouvirem": "entreouvir",
    "entreouviremos": "entreouvir",
    "entreouvires": "entreouvir",
    "entreouviria": "entreouvir",
    "entreouviriam": "entreouvir",
    "entreouvirias": "entreouvir",
    "entreouvirmo": "entreouvir",
    "entreouvirmos": "entreouvir",
    "entreouvirá": "entreouvir",
    "entreouvirás": "entreouvir",
    "entreouvirão": "entreouvir",
    "entreouviríamos": "entreouvir",
    "entreouviríeis": "entreouvir",
    "entreouvis": "entreouvir",
    "entreouvisse": "entreouvir",
    "entreouvissem": "entreouvir",
    "entreouvisses": "entreouvir",
    "entreouviste": "entreouvir",
    "entreouvistes": "entreouvir",
    "entreouviu": "entreouvir",
    "entreouvíamo": "entreouvir",
    "entreouvíamos": "entreouvir",
    "entreouvíei": "entreouvir",
    "entreouvíeis": "entreouvir",
    "entreouvíramo": "entreouvir",
    "entreouvíramos": "entreouvir",
    "entreouvírei": "entreouvir",
    "entreouvíreis": "entreouvir",
    "entreouvísseis": "entreouvir",
    "entreouvíssemos": "entreouvir",
    "entreouça": "entreouvir",
    "entreouçais": "entreouvir",
    "entreouçam": "entreouvir",
    "entreouçamo": "entreouvir",
    "entreouçamos": "entreouvir",
    "entreouças": "entreouvir",
    "entreouço": "entreouvir",
    "entrepanos": "entrepano",
    "entrepassa": "entrepassar",
    "entrepassada": "entrepassar",
    "entrepassadas": "entrepassar",
    "entrepassado": "entrepassar",
    "entrepassados": "entrepassar",
    "entrepassai": "entrepassar",
    "entrepassais": "entrepassar",
    "entrepassam": "entrepassar",
    "entrepassamo": "entrepassar",
    "entrepassamos": "entrepassar",
    "entrepassando": "entrepassar",
    "entrepassara": "entrepassar",
    "entrepassaram": "entrepassar",
    "entrepassaras": "entrepassar",
    "entrepassarde": "entrepassar",
    "entrepassardes": "entrepassar",
    "entrepassare": "entrepassar",
    "entrepassarei": "entrepassar",
    "entrepassareis": "entrepassar",
    "entrepassarem": "entrepassar",
    "entrepassaremos": "entrepassar",
    "entrepassares": "entrepassar",
    "entrepassaria": "entrepassar",
    "entrepassariam": "entrepassar",
    "entrepassarias": "entrepassar",
    "entrepassarmo": "entrepassar",
    "entrepassarmos": "entrepassar",
    "entrepassará": "entrepassar",
    "entrepassarás": "entrepassar",
    "entrepassarão": "entrepassar",
    "entrepassaríamos": "entrepassar",
    "entrepassaríeis": "entrepassar",
    "entrepassas": "entrepassar",
    "entrepassasse": "entrepassar",
    "entrepassassem": "entrepassar",
    "entrepassasses": "entrepassar",
    "entrepassaste": "entrepassar",
    "entrepassastes": "entrepassar",
    "entrepassava": "entrepassar",
    "entrepassavam": "entrepassar",
    "entrepassavas": "entrepassar",
    "entrepasse": "entrepassar",
    "entrepassei": "entrepassar",
    "entrepasseis": "entrepassar",
    "entrepassem": "entrepassar",
    "entrepassemo": "entrepassar",
    "entrepassemos": "entrepassar",
    "entrepasses": "entrepassar",
    "entrepasso": "entrepassar",
    "entrepassos": "entrepasso",
    "entrepassou": "entrepassar",
    "entrepassá": "entrepassar",
    "entrepassámo": "entrepassar",
    "entrepassámos": "entrepassar",
    "entrepassáramo": "entrepassar",
    "entrepassáramos": "entrepassar",
    "entrepassárei": "entrepassar",
    "entrepassáreis": "entrepassar",
    "entrepassásseis": "entrepassar",
    "entrepassássemos": "entrepassar",
    "entrepassávamo": "entrepassar",
    "entrepassávamos": "entrepassar",
    "entrepassávei": "entrepassar",
    "entrepassáveis": "entrepassar",
    "entrepausas": "entrepausa",
    "entrepernas": "entreperna",
    "entreplica": "entreplicar",
    "entreplicada": "entreplicar",
    "entreplicadas": "entreplicar",
    "entreplicado": "entreplicar",
    "entreplicados": "entreplicar",
    "entreplicais": "entreplicar",
    "entreplicam": "entreplicar",
    "entreplicamo": "entreplicar",
    "entreplicamos": "entreplicar",
    "entreplicando": "entreplicar",
    "entreplicara": "entreplicar",
    "entreplicaram": "entreplicar",
    "entreplicaras": "entreplicar",
    "entreplicardes": "entreplicar",
    "entreplicarei": "entreplicar",
    "entreplicareis": "entreplicar",
    "entreplicarem": "entreplicar",
    "entreplicaremos": "entreplicar",
    "entreplicares": "entreplicar",
    "entreplicaria": "entreplicar",
    "entreplicariam": "entreplicar",
    "entreplicarias": "entreplicar",
    "entreplicarmo": "entreplicar",
    "entreplicarmos": "entreplicar",
    "entreplicará": "entreplicar",
    "entreplicarás": "entreplicar",
    "entreplicarão": "entreplicar",
    "entreplicaríamos": "entreplicar",
    "entreplicaríeis": "entreplicar",
    "entreplicas": "entreplicar",
    "entreplicasse": "entreplicar",
    "entreplicassem": "entreplicar",
    "entreplicasses": "entreplicar",
    "entreplicaste": "entreplicar",
    "entreplicastes": "entreplicar",
    "entreplicava": "entreplicar",
    "entreplicavam": "entreplicar",
    "entreplicavas": "entreplicar",
    "entreplico": "entreplicar",
    "entreplicou": "entreplicar",
    "entreplicámo": "entreplicar",
    "entreplicámos": "entreplicar",
    "entreplicáramo": "entreplicar",
    "entreplicáramos": "entreplicar",
    "entreplicáreis": "entreplicar",
    "entreplicásseis": "entreplicar",
    "entreplicássemos": "entreplicar",
    "entreplicávamo": "entreplicar",
    "entreplicávamos": "entreplicar",
    "entreplicáveis": "entreplicar",
    "entreplique": "entreplicar",
    "entrepliquei": "entreplicar",
    "entrepliqueis": "entreplicar",
    "entrepliquem": "entreplicar",
    "entrepliquemos": "entreplicar",
    "entrepliques": "entreplicar",
    "entrepomo": "entrepor",
    "entrepomos": "entrepor",
    "entreponde": "entrepor",
    "entrepondes": "entrepor",
    "entrepondo": "entrepor",
    "entreponha": "entrepor",
    "entreponhais": "entrepor",
    "entreponham": "entrepor",
    "entreponhamo": "entrepor",
    "entreponhamos": "entrepor",
    "entreponhas": "entrepor",
    "entreponho": "entrepor",
    "entrepontes": "entreponte",
    "entreporde": "entrepor",
    "entrepordes": "entrepor",
    "entrepore": "entrepor",
    "entreporei": "entrepor",
    "entreporeis": "entrepor",
    "entreporem": "entrepor",
    "entreporemos": "entrepor",
    "entrepores": "entrepor",
    "entreporia": "entrepor",
    "entreporiam": "entrepor",
    "entreporias": "entrepor",
    "entrepormo": "entrepor",
    "entrepormos": "entrepor",
    "entreporá": "entrepor",
    "entreporás": "entrepor",
    "entreporão": "entrepor",
    "entreporíamos": "entrepor",
    "entreporíeis": "entrepor",
    "entreposta": "entrepor",
    "entrepostas": "entrepor",
    "entreposto": "entrepor",
    "entrepostos": "entreposto",
    "entreprenda": "entreprender",
    "entreprendais": "entreprender",
    "entreprendam": "entreprender",
    "entreprendamo": "entreprender",
    "entreprendamos": "entreprender",
    "entreprendas": "entreprender",
    "entreprende": "entreprender",
    "entreprendei": "entreprender",
    "entreprendeis": "entreprender",
    "entreprendem": "entreprender",
    "entreprendemo": "entreprender",
    "entreprendemos": "entreprender",
    "entreprendendo": "entreprender",
    "entreprendera": "entreprender",
    "entreprenderam": "entreprender",
    "entreprenderas": "entreprender",
    "entreprenderde": "entreprender",
    "entreprenderdes": "entreprender",
    "entreprendere": "entreprender",
    "entreprenderei": "entreprender",
    "entreprendereis": "entreprender",
    "entreprenderem": "entreprender",
    "entreprenderemos": "entreprender",
    "entreprenderes": "entreprender",
    "entreprenderia": "entreprender",
    "entreprenderiam": "entreprender",
    "entreprenderias": "entreprender",
    "entreprendermo": "entreprender",
    "entreprendermos": "entreprender",
    "entreprenderá": "entreprender",
    "entreprenderás": "entreprender",
    "entreprenderão": "entreprender",
    "entreprenderíamos": "entreprender",
    "entreprenderíeis": "entreprender",
    "entreprendes": "entreprender",
    "entreprendesse": "entreprender",
    "entreprendessem": "entreprender",
    "entreprendesses": "entreprender",
    "entreprendeste": "entreprender",
    "entreprendestes": "entreprender",
    "entreprendeu": "entreprender",
    "entreprendi": "entreprender",
    "entreprendia": "entreprender",
    "entreprendiam": "entreprender",
    "entreprendias": "entreprender",
    "entreprendida": "entreprender",
    "entreprendidas": "entreprender",
    "entreprendido": "entreprender",
    "entreprendidos": "entreprender",
    "entreprendo": "entreprender",
    "entreprendê": "entreprender",
    "entreprendêramo": "entreprender",
    "entreprendêramos": "entreprender",
    "entreprendêrei": "entreprender",
    "entreprendêreis": "entreprender",
    "entreprendêsseis": "entreprender",
    "entreprendêssemos": "entreprender",
    "entreprendíamo": "entreprender",
    "entreprendíamos": "entreprender",
    "entreprendíei": "entreprender",
    "entreprendíeis": "entreprender",
    "entrepresas": "entrepresa",
    "entrepunha": "entrepor",
    "entrepunham": "entrepor",
    "entrepunhas": "entrepor",
    "entrepus": "entrepor",
    "entrepusemo": "entrepor",
    "entrepusemos": "entrepor",
    "entrepuser": "entrepor",
    "entrepusera": "entrepor",
    "entrepuseram": "entrepor",
    "entrepuseras": "entrepor",
    "entrepuserdes": "entrepor",
    "entrepuserem": "entrepor",
    "entrepuseres": "entrepor",
    "entrepusermos": "entrepor",
    "entrepusesse": "entrepor",
    "entrepusessem": "entrepor",
    "entrepusesses": "entrepor",
    "entrepuseste": "entrepor",
    "entrepusestes": "entrepor",
    "entrepuséramo": "entrepor",
    "entrepuséramos": "entrepor",
    "entrepusérei": "entrepor",
    "entrepuséreis": "entrepor",
    "entrepusésseis": "entrepor",
    "entrepuséssemos": "entrepor",
    "entrepósitos": "entrepósito",
    "entrepô": "entrepor",
    "entrepôs": "entrepor",
    "entrepõe": "entrepor",
    "entrepõem": "entrepor",
    "entrepões": "entrepor",
    "entrepúnhamo": "entrepor",
    "entrepúnhamos": "entrepor",
    "entrepúnhei": "entrepor",
    "entrepúnheis": "entrepor",
    "entrequeira": "entrequerer",
    "entrequeirais": "entrequerer",
    "entrequeiram": "entrequerer",
    "entrequeiramo": "entrequerer",
    "entrequeiramos": "entrequerer",
    "entrequeiras": "entrequerer",
    "entrequer": "entrequerer",
    "entrequere": "entrequerer",
    "entrequerei": "entrequerer",
    "entrequereis": "entrequerer",
    "entrequerem": "entrequerer",
    "entrequeremo": "entrequerer",
    "entrequeremos": "entrequerer",
    "entrequerendo": "entrequerer",
    "entrequererde": "entrequerer",
    "entrequererdes": "entrequerer",
    "entrequerere": "entrequerer",
    "entrequererei": "entrequerer",
    "entrequerereis": "entrequerer",
    "entrequererem": "entrequerer",
    "entrequereremos": "entrequerer",
    "entrequereres": "entrequerer",
    "entrequereria": "entrequerer",
    "entrequereriam": "entrequerer",
    "entrequererias": "entrequerer",
    "entrequerermo": "entrequerer",
    "entrequerermos": "entrequerer",
    "entrequererá": "entrequerer",
    "entrequererás": "entrequerer",
    "entrequererão": "entrequerer",
    "entrequereríamos": "entrequerer",
    "entrequereríeis": "entrequerer",
    "entrequeres": "entrequerer",
    "entrequeria": "entrequerer",
    "entrequeriam": "entrequerer",
    "entrequerias": "entrequerer",
    "entrequerida": "entrequerer",
    "entrequeridas": "entrequerer",
    "entrequerido": "entrequerer",
    "entrequeridos": "entrequerer",
    "entrequero": "entrequerer",
    "entrequerê": "entrequerer",
    "entrequeríamo": "entrequerer",
    "entrequeríamos": "entrequerer",
    "entrequeríei": "entrequerer",
    "entrequeríeis": "entrequerer",
    "entrequis": "entrequerer",
    "entrequisemo": "entrequerer",
    "entrequisemos": "entrequerer",
    "entrequiser": "entrequerer",
    "entrequisera": "entrequerer",
    "entrequiseram": "entrequerer",
    "entrequiseras": "entrequerer",
    "entrequiserdes": "entrequerer",
    "entrequiserem": "entrequerer",
    "entrequiseres": "entrequerer",
    "entrequisermos": "entrequerer",
    "entrequisesse": "entrequerer",
    "entrequisessem": "entrequerer",
    "entrequisesses": "entrequerer",
    "entrequiseste": "entrequerer",
    "entrequisestes": "entrequerer",
    "entrequiséramo": "entrequerer",
    "entrequiséramos": "entrequerer",
    "entrequisérei": "entrequerer",
    "entrequiséreis": "entrequerer",
    "entrequisésseis": "entrequerer",
    "entrequiséssemos": "entrequerer",
    "entrerrega": "entrerregar",
    "entrerregada": "entrerregar",
    "entrerregadas": "entrerregar",
    "entrerregado": "entrerregar",
    "entrerregados": "entrerregar",
    "entrerregai": "entrerregar",
    "entrerregais": "entrerregar",
    "entrerregam": "entrerregar",
    "entrerregamo": "entrerregar",
    "entrerregamos": "entrerregar",
    "entrerregando": "entrerregar",
    "entrerregara": "entrerregar",
    "entrerregaram": "entrerregar",
    "entrerregaras": "entrerregar",
    "entrerregarde": "entrerregar",
    "entrerregardes": "entrerregar",
    "entrerregare": "entrerregar",
    "entrerregarei": "entrerregar",
    "entrerregareis": "entrerregar",
    "entrerregarem": "entrerregar",
    "entrerregaremos": "entrerregar",
    "entrerregares": "entrerregar",
    "entrerregaria": "entrerregar",
    "entrerregariam": "entrerregar",
    "entrerregarias": "entrerregar",
    "entrerregarmo": "entrerregar",
    "entrerregarmos": "entrerregar",
    "entrerregará": "entrerregar",
    "entrerregarás": "entrerregar",
    "entrerregarão": "entrerregar",
    "entrerregaríamos": "entrerregar",
    "entrerregaríeis": "entrerregar",
    "entrerregas": "entrerregar",
    "entrerregasse": "entrerregar",
    "entrerregassem": "entrerregar",
    "entrerregasses": "entrerregar",
    "entrerregaste": "entrerregar",
    "entrerregastes": "entrerregar",
    "entrerregava": "entrerregar",
    "entrerregavam": "entrerregar",
    "entrerregavas": "entrerregar",
    "entrerrego": "entrerregar",
    "entrerregou": "entrerregar",
    "entrerregue": "entrerregar",
    "entrerreguei": "entrerregar",
    "entrerregueis": "entrerregar",
    "entrerreguem": "entrerregar",
    "entrerreguemo": "entrerregar",
    "entrerreguemos": "entrerregar",
    "entrerregues": "entrerregar",
    "entrerregá": "entrerregar",
    "entrerregámo": "entrerregar",
    "entrerregámos": "entrerregar",
    "entrerregáramo": "entrerregar",
    "entrerregáramos": "entrerregar",
    "entrerregárei": "entrerregar",
    "entrerregáreis": "entrerregar",
    "entrerregásseis": "entrerregar",
    "entrerregássemos": "entrerregar",
    "entrerregávamo": "entrerregar",
    "entrerregávamos": "entrerregar",
    "entrerregávei": "entrerregar",
    "entrerregáveis": "entrerregar",
    "entres": "entrar",
    "entrescolha": "entrescolher",
    "entrescolhais": "entrescolher",
    "entrescolham": "entrescolher",
    "entrescolhamo": "entrescolher",
    "entrescolhamos": "entrescolher",
    "entrescolhas": "entrescolher",
    "entrescolhe": "entrescolher",
    "entrescolhei": "entrescolher",
    "entrescolheis": "entrescolher",
    "entrescolhem": "entrescolher",
    "entrescolhemo": "entrescolher",
    "entrescolhemos": "entrescolher",
    "entrescolhendo": "entrescolher",
    "entrescolhera": "entrescolher",
    "entrescolheram": "entrescolher",
    "entrescolheras": "entrescolher",
    "entrescolherde": "entrescolher",
    "entrescolherdes": "entrescolher",
    "entrescolhere": "entrescolher",
    "entrescolherei": "entrescolher",
    "entrescolhereis": "entrescolher",
    "entrescolherem": "entrescolher",
    "entrescolheremos": "entrescolher",
    "entrescolheres": "entrescolher",
    "entrescolheria": "entrescolher",
    "entrescolheriam": "entrescolher",
    "entrescolherias": "entrescolher",
    "entrescolhermo": "entrescolher",
    "entrescolhermos": "entrescolher",
    "entrescolherá": "entrescolher",
    "entrescolherás": "entrescolher",
    "entrescolherão": "entrescolher",
    "entrescolheríamos": "entrescolher",
    "entrescolheríeis": "entrescolher",
    "entrescolhes": "entrescolher",
    "entrescolhesse": "entrescolher",
    "entrescolhessem": "entrescolher",
    "entrescolhesses": "entrescolher",
    "entrescolheste": "entrescolher",
    "entrescolhestes": "entrescolher",
    "entrescolheu": "entrescolher",
    "entrescolhi": "entrescolher",
    "entrescolhia": "entrescolher",
    "entrescolhiam": "entrescolher",
    "entrescolhias": "entrescolher",
    "entrescolhida": "entrescolher",
    "entrescolhidas": "entrescolher",
    "entrescolhido": "entrescolher",
    "entrescolhidos": "entrescolher",
    "entrescolho": "entrescolher",
    "entrescolhê": "entrescolher",
    "entrescolhêramo": "entrescolher",
    "entrescolhêramos": "entrescolher",
    "entrescolhêrei": "entrescolher",
    "entrescolhêreis": "entrescolher",
    "entrescolhêsseis": "entrescolher",
    "entrescolhêssemos": "entrescolher",
    "entrescolhíamo": "entrescolher",
    "entrescolhíamos": "entrescolher",
    "entrescolhíei": "entrescolher",
    "entrescolhíeis": "entrescolher",
    "entrescuta": "entrescutar",
    "entrescutada": "entrescutar",
    "entrescutadas": "entrescutar",
    "entrescutado": "entrescutar",
    "entrescutados": "entrescutar",
    "entrescutai": "entrescutar",
    "entrescutais": "entrescutar",
    "entrescutam": "entrescutar",
    "entrescutamo": "entrescutar",
    "entrescutamos": "entrescutar",
    "entrescutando": "entrescutar",
    "entrescutara": "entrescutar",
    "entrescutaram": "entrescutar",
    "entrescutaras": "entrescutar",
    "entrescutarde": "entrescutar",
    "entrescutardes": "entrescutar",
    "entrescutare": "entrescutar",
    "entrescutarei": "entrescutar",
    "entrescutareis": "entrescutar",
    "entrescutarem": "entrescutar",
    "entrescutaremos": "entrescutar",
    "entrescutares": "entrescutar",
    "entrescutaria": "entrescutar",
    "entrescutariam": "entrescutar",
    "entrescutarias": "entrescutar",
    "entrescutarmo": "entrescutar",
    "entrescutarmos": "entrescutar",
    "entrescutará": "entrescutar",
    "entrescutarás": "entrescutar",
    "entrescutarão": "entrescutar",
    "entrescutaríamos": "entrescutar",
    "entrescutaríeis": "entrescutar",
    "entrescutas": "entrescutar",
    "entrescutasse": "entrescutar",
    "entrescutassem": "entrescutar",
    "entrescutasses": "entrescutar",
    "entrescutaste": "entrescutar",
    "entrescutastes": "entrescutar",
    "entrescutava": "entrescutar",
    "entrescutavam": "entrescutar",
    "entrescutavas": "entrescutar",
    "entrescute": "entrescutar",
    "entrescutei": "entrescutar",
    "entrescuteis": "entrescutar",
    "entrescutem": "entrescutar",
    "entrescutemo": "entrescutar",
    "entrescutemos": "entrescutar",
    "entrescutes": "entrescutar",
    "entrescuto": "entrescutar",
    "entrescutou": "entrescutar",
    "entrescutá": "entrescutar",
    "entrescutámo": "entrescutar",
    "entrescutámos": "entrescutar",
    "entrescutáramo": "entrescutar",
    "entrescutáramos": "entrescutar",
    "entrescutárei": "entrescutar",
    "entrescutáreis": "entrescutar",
    "entrescutásseis": "entrescutar",
    "entrescutássemos": "entrescutar",
    "entrescutávamo": "entrescutar",
    "entrescutávamos": "entrescutar",
    "entrescutávei": "entrescutar",
    "entrescutáveis": "entrescutar",
    "entresilha": "entresilhar",
    "entresilhada": "entresilhar",
    "entresilhadas": "entresilhar",
    "entresilhado": "entresilhar",
    "entresilhados": "entresilhar",
    "entresilhai": "entresilhar",
    "entresilhais": "entresilhar",
    "entresilham": "entresilhar",
    "entresilhamo": "entresilhar",
    "entresilhamos": "entresilhar",
    "entresilhando": "entresilhar",
    "entresilhara": "entresilhar",
    "entresilharam": "entresilhar",
    "entresilharas": "entresilhar",
    "entresilharde": "entresilhar",
    "entresilhardes": "entresilhar",
    "entresilhare": "entresilhar",
    "entresilharei": "entresilhar",
    "entresilhareis": "entresilhar",
    "entresilharem": "entresilhar",
    "entresilharemos": "entresilhar",
    "entresilhares": "entresilhar",
    "entresilharia": "entresilhar",
    "entresilhariam": "entresilhar",
    "entresilharias": "entresilhar",
    "entresilharmo": "entresilhar",
    "entresilharmos": "entresilhar",
    "entresilhará": "entresilhar",
    "entresilharás": "entresilhar",
    "entresilharão": "entresilhar",
    "entresilharíamos": "entresilhar",
    "entresilharíeis": "entresilhar",
    "entresilhas": "entresilhar",
    "entresilhasse": "entresilhar",
    "entresilhassem": "entresilhar",
    "entresilhasses": "entresilhar",
    "entresilhaste": "entresilhar",
    "entresilhastes": "entresilhar",
    "entresilhava": "entresilhar",
    "entresilhavam": "entresilhar",
    "entresilhavas": "entresilhar",
    "entresilhe": "entresilhar",
    "entresilhei": "entresilhar",
    "entresilheis": "entresilhar",
    "entresilhem": "entresilhar",
    "entresilhemo": "entresilhar",
    "entresilhemos": "entresilhar",
    "entresilhes": "entresilhar",
    "entresilho": "entresilhar",
    "entresilhou": "entresilhar",
    "entresilhá": "entresilhar",
    "entresilhámo": "entresilhar",
    "entresilhámos": "entresilhar",
    "entresilháramo": "entresilhar",
    "entresilháramos": "entresilhar",
    "entresilhárei": "entresilhar",
    "entresilháreis": "entresilhar",
    "entresilhásseis": "entresilhar",
    "entresilhássemos": "entresilhar",
    "entresilhávamo": "entresilhar",
    "entresilhávamos": "entresilhar",
    "entresilhávei": "entresilhar",
    "entresilháveis": "entresilhar",
    "entressacha": "entressachar",
    "entressachada": "entressachar",
    "entressachadas": "entressachar",
    "entressachado": "entressachar",
    "entressachados": "entressachar",
    "entressachai": "entressachar",
    "entressachais": "entressachar",
    "entressacham": "entressachar",
    "entressachamo": "entressachar",
    "entressachamos": "entressachar",
    "entressachando": "entressachar",
    "entressachara": "entressachar",
    "entressacharam": "entressachar",
    "entressacharas": "entressachar",
    "entressacharde": "entressachar",
    "entressachardes": "entressachar",
    "entressachare": "entressachar",
    "entressacharei": "entressachar",
    "entressachareis": "entressachar",
    "entressacharem": "entressachar",
    "entressacharemos": "entressachar",
    "entressachares": "entressachar",
    "entressacharia": "entressachar",
    "entressachariam": "entressachar",
    "entressacharias": "entressachar",
    "entressacharmo": "entressachar",
    "entressacharmos": "entressachar",
    "entressachará": "entressachar",
    "entressacharás": "entressachar",
    "entressacharão": "entressachar",
    "entressacharíamos": "entressachar",
    "entressacharíeis": "entressachar",
    "entressachas": "entressachar",
    "entressachasse": "entressachar",
    "entressachassem": "entressachar",
    "entressachasses": "entressachar",
    "entressachaste": "entressachar",
    "entressachastes": "entressachar",
    "entressachava": "entressachar",
    "entressachavam": "entressachar",
    "entressachavas": "entressachar",
    "entressache": "entressachar",
    "entressachei": "entressachar",
    "entressacheis": "entressachar",
    "entressachem": "entressachar",
    "entressachemo": "entressachar",
    "entressachemos": "entressachar",
    "entressaches": "entressachar",
    "entressacho": "entressachar",
    "entressachou": "entressachar",
    "entressachá": "entressachar",
    "entressachámo": "entressachar",
    "entressachámos": "entressachar",
    "entressacháramo": "entressachar",
    "entressacháramos": "entressachar",
    "entressachárei": "entressachar",
    "entressacháreis": "entressachar",
    "entressachásseis": "entressachar",
    "entressachássemos": "entressachar",
    "entressachávamo": "entressachar",
    "entressachávamos": "entressachar",
    "entressachávei": "entressachar",
    "entressacháveis": "entressachar",
    "entresseios": "entresseio",
    "entressemeada": "entressemear",
    "entressemeadas": "entressemear",
    "entressemeado": "entressemear",
    "entressemeados": "entressemear",
    "entressemeai": "entressemear",
    "entressemeais": "entressemear",
    "entressemeamo": "entressemear",
    "entressemeamos": "entressemear",
    "entressemeando": "entressemear",
    "entressemeara": "entressemear",
    "entressemearam": "entressemear",
    "entressemearas": "entressemear",
    "entressemearde": "entressemear",
    "entressemeardes": "entressemear",
    "entressemeare": "entressemear",
    "entressemearei": "entressemear",
    "entressemeareis": "entressemear",
    "entressemearem": "entressemear",
    "entressemearemos": "entressemear",
    "entressemeares": "entressemear",
    "entressemearia": "entressemear",
    "entressemeariam": "entressemear",
    "entressemearias": "entressemear",
    "entressemearmo": "entressemear",
    "entressemearmos": "entressemear",
    "entressemeará": "entressemear",
    "entressemearás": "entressemear",
    "entressemearão": "entressemear",
    "entressemearíamos": "entressemear",
    "entressemearíeis": "entressemear",
    "entressemeasse": "entressemear",
    "entressemeassem": "entressemear",
    "entressemeasses": "entressemear",
    "entressemeaste": "entressemear",
    "entressemeastes": "entressemear",
    "entressemeava": "entressemear",
    "entressemeavam": "entressemear",
    "entressemeavas": "entressemear",
    "entressemeei": "entressemear",
    "entressemeeis": "entressemear",
    "entressemeemo": "entressemear",
    "entressemeemos": "entressemear",
    "entressemeia": "entressemear",
    "entressemeiam": "entressemear",
    "entressemeias": "entressemear",
    "entressemeie": "entressemear",
    "entressemeiem": "entressemear",
    "entressemeies": "entressemear",
    "entressemeio": "entressemear",
    "entressemeou": "entressemear",
    "entressemeá": "entressemear",
    "entressemeámo": "entressemear",
    "entressemeámos": "entressemear",
    "entressemeáramo": "entressemear",
    "entressemeáramos": "entressemear",
    "entressemeárei": "entressemear",
    "entressemeáreis": "entressemear",
    "entressemeásseis": "entressemear",
    "entressemeássemos": "entressemear",
    "entressemeávamo": "entressemear",
    "entressemeávamos": "entressemear",
    "entressemeávei": "entressemear",
    "entressemeáveis": "entressemear",
    "entressolas": "entressola",
    "entressolha": "entressolhar",
    "entressolhada": "entressolhar",
    "entressolhadas": "entressolhar",
    "entressolhado": "entressolhar",
    "entressolhados": "entressolhar",
    "entressolhai": "entressolhar",
    "entressolhais": "entressolhar",
    "entressolham": "entressolhar",
    "entressolhamo": "entressolhar",
    "entressolhamos": "entressolhar",
    "entressolhando": "entressolhar",
    "entressolhara": "entressolhar",
    "entressolharam": "entressolhar",
    "entressolharas": "entressolhar",
    "entressolharde": "entressolhar",
    "entressolhardes": "entressolhar",
    "entressolhare": "entressolhar",
    "entressolharei": "entressolhar",
    "entressolhareis": "entressolhar",
    "entressolharem": "entressolhar",
    "entressolharemos": "entressolhar",
    "entressolhares": "entressolhar",
    "entressolharia": "entressolhar",
    "entressolhariam": "entressolhar",
    "entressolharias": "entressolhar",
    "entressolharmo": "entressolhar",
    "entressolharmos": "entressolhar",
    "entressolhará": "entressolhar",
    "entressolharás": "entressolhar",
    "entressolharão": "entressolhar",
    "entressolharíamos": "entressolhar",
    "entressolharíeis": "entressolhar",
    "entressolhas": "entressolhar",
    "entressolhasse": "entressolhar",
    "entressolhassem": "entressolhar",
    "entressolhasses": "entressolhar",
    "entressolhaste": "entressolhar",
    "entressolhastes": "entressolhar",
    "entressolhava": "entressolhar",
    "entressolhavam": "entressolhar",
    "entressolhavas": "entressolhar",
    "entressolhe": "entressolhar",
    "entressolhei": "entressolhar",
    "entressolheis": "entressolhar",
    "entressolhem": "entressolhar",
    "entressolhemo": "entressolhar",
    "entressolhemos": "entressolhar",
    "entressolhes": "entressolhar",
    "entressolho": "entressolhar",
    "entressolhos": "entressolho",
    "entressolhou": "entressolhar",
    "entressolhá": "entressolhar",
    "entressolhámo": "entressolhar",
    "entressolhámos": "entressolhar",
    "entressolháramo": "entressolhar",
    "entressolháramos": "entressolhar",
    "entressolhárei": "entressolhar",
    "entressolháreis": "entressolhar",
    "entressolhásseis": "entressolhar",
    "entressolhássemos": "entressolhar",
    "entressolhávamo": "entressolhar",
    "entressolhávamos": "entressolhar",
    "entressolhávei": "entressolhar",
    "entressolháveis": "entressolhar",
    "entressonha": "entressonhar",
    "entressonhada": "entressonhar",
    "entressonhadas": "entressonhar",
    "entressonhado": "entressonhar",
    "entressonhados": "entressonhar",
    "entressonhai": "entressonhar",
    "entressonhais": "entressonhar",
    "entressonham": "entressonhar",
    "entressonhamo": "entressonhar",
    "entressonhamos": "entressonhar",
    "entressonhando": "entressonhar",
    "entressonhara": "entressonhar",
    "entressonharam": "entressonhar",
    "entressonharas": "entressonhar",
    "entressonharde": "entressonhar",
    "entressonhardes": "entressonhar",
    "entressonhare": "entressonhar",
    "entressonharei": "entressonhar",
    "entressonhareis": "entressonhar",
    "entressonharem": "entressonhar",
    "entressonharemos": "entressonhar",
    "entressonhares": "entressonhar",
    "entressonharia": "entressonhar",
    "entressonhariam": "entressonhar",
    "entressonharias": "entressonhar",
    "entressonharmo": "entressonhar",
    "entressonharmos": "entressonhar",
    "entressonhará": "entressonhar",
    "entressonharás": "entressonhar",
    "entressonharão": "entressonhar",
    "entressonharíamos": "entressonhar",
    "entressonharíeis": "entressonhar",
    "entressonhas": "entressonhar",
    "entressonhasse": "entressonhar",
    "entressonhassem": "entressonhar",
    "entressonhasses": "entressonhar",
    "entressonhaste": "entressonhar",
    "entressonhastes": "entressonhar",
    "entressonhava": "entressonhar",
    "entressonhavam": "entressonhar",
    "entressonhavas": "entressonhar",
    "entressonhe": "entressonhar",
    "entressonhei": "entressonhar",
    "entressonheis": "entressonhar",
    "entressonhem": "entressonhar",
    "entressonhemo": "entressonhar",
    "entressonhemos": "entressonhar",
    "entressonhes": "entressonhar",
    "entressonho": "entressonhar",
    "entressonhos": "entressonho",
    "entressonhou": "entressonhar",
    "entressonhá": "entressonhar",
    "entressonhámo": "entressonhar",
    "entressonhámos": "entressonhar",
    "entressonháramo": "entressonhar",
    "entressonháramos": "entressonhar",
    "entressonhárei": "entressonhar",
    "entressonháreis": "entressonhar",
    "entressonhásseis": "entressonhar",
    "entressonhássemos": "entressonhar",
    "entressonhávamo": "entressonhar",
    "entressonhávamos": "entressonhar",
    "entressonhávei": "entressonhar",
    "entressonháveis": "entressonhar",
    "entressorrisos": "entressorriso",
    "entressoura": "entressourir",
    "entressourais": "entressourir",
    "entressouram": "entressourir",
    "entressouramo": "entressourir",
    "entressouramos": "entressourir",
    "entressouras": "entressourir",
    "entressoure": "entressourir",
    "entressourem": "entressourir",
    "entressoures": "entressourir",
    "entressouri": "entressourir",
    "entressouria": "entressourir",
    "entressouriam": "entressourir",
    "entressourias": "entressourir",
    "entressourida": "entressourir",
    "entressouridas": "entressourir",
    "entressourido": "entressourir",
    "entressouridos": "entressourir",
    "entressourimo": "entressourir",
    "entressourimos": "entressourir",
    "entressourindo": "entressourir",
    "entressourira": "entressourir",
    "entressouriram": "entressourir",
    "entressouriras": "entressourir",
    "entressourirde": "entressourir",
    "entressourirdes": "entressourir",
    "entressourire": "entressourir",
    "entressourirei": "entressourir",
    "entressourireis": "entressourir",
    "entressourirem": "entressourir",
    "entressouriremos": "entressourir",
    "entressourires": "entressourir",
    "entressouriria": "entressourir",
    "entressouririam": "entressourir",
    "entressouririas": "entressourir",
    "entressourirmo": "entressourir",
    "entressourirmos": "entressourir",
    "entressourirá": "entressourir",
    "entressourirás": "entressourir",
    "entressourirão": "entressourir",
    "entressouriríamos": "entressourir",
    "entressouriríeis": "entressourir",
    "entressouris": "entressourir",
    "entressourisse": "entressourir",
    "entressourissem": "entressourir",
    "entressourisses": "entressourir",
    "entressouriste": "entressourir",
    "entressouristes": "entressourir",
    "entressouriu": "entressourir",
    "entressouro": "entressourir",
    "entressouríamo": "entressourir",
    "entressouríamos": "entressourir",
    "entressouríei": "entressourir",
    "entressouríeis": "entressourir",
    "entressouríramo": "entressourir",
    "entressouríramos": "entressourir",
    "entressourírei": "entressourir",
    "entressouríreis": "entressourir",
    "entressourísseis": "entressourir",
    "entressouríssemos": "entressourir",
    "entretalha": "entretalhar",
    "entretalhada": "entretalhar",
    "entretalhadas": "entretalhar",
    "entretalhado": "entretalhar",
    "entretalhadora": "entretalhador",
    "entretalhadoras": "entretalhador",
    "entretalhadores": "entretalhador",
    "entretalhados": "entretalhar",
    "entretalhaduras": "entretalhadura",
    "entretalhai": "entretalhar",
    "entretalhais": "entretalhar",
    "entretalham": "entretalhar",
    "entretalhamo": "entretalhar",
    "entretalhamos": "entretalhar",
    "entretalhando": "entretalhar",
    "entretalhara": "entretalhar",
    "entretalharam": "entretalhar",
    "entretalharas": "entretalhar",
    "entretalharde": "entretalhar",
    "entretalhardes": "entretalhar",
    "entretalhare": "entretalhar",
    "entretalharei": "entretalhar",
    "entretalhareis": "entretalhar",
    "entretalharem": "entretalhar",
    "entretalharemos": "entretalhar",
    "entretalhares": "entretalhar",
    "entretalharia": "entretalhar",
    "entretalhariam": "entretalhar",
    "entretalharias": "entretalhar",
    "entretalharmo": "entretalhar",
    "entretalharmos": "entretalhar",
    "entretalhará": "entretalhar",
    "entretalharás": "entretalhar",
    "entretalharão": "entretalhar",
    "entretalharíamos": "entretalhar",
    "entretalharíeis": "entretalhar",
    "entretalhas": "entretalhar",
    "entretalhasse": "entretalhar",
    "entretalhassem": "entretalhar",
    "entretalhasses": "entretalhar",
    "entretalhaste": "entretalhar",
    "entretalhastes": "entretalhar",
    "entretalhava": "entretalhar",
    "entretalhavam": "entretalhar",
    "entretalhavas": "entretalhar",
    "entretalhe": "entretalhar",
    "entretalhei": "entretalhar",
    "entretalheis": "entretalhar",
    "entretalhem": "entretalhar",
    "entretalhemo": "entretalhar",
    "entretalhemos": "entretalhar",
    "entretalhes": "entretalhar",
    "entretalho": "entretalhar",
    "entretalhos": "entretalho",
    "entretalhou": "entretalhar",
    "entretalhá": "entretalhar",
    "entretalhámo": "entretalhar",
    "entretalhámos": "entretalhar",
    "entretalháramo": "entretalhar",
    "entretalháramos": "entretalhar",
    "entretalhárei": "entretalhar",
    "entretalháreis": "entretalhar",
    "entretalhásseis": "entretalhar",
    "entretalhássemos": "entretalhar",
    "entretalhávamo": "entretalhar",
    "entretalhávamos": "entretalhar",
    "entretalhávei": "entretalhar",
    "entretalháveis": "entretalhar",
    "entretantos": "entretanto",
    "entretece": "entretecer",
    "entretecedora": "entretecedor",
    "entretecedoras": "entretecedor",
    "entretecedores": "entretecedor",
    "entreteceduras": "entretecedura",
    "entretecei": "entretecer",
    "entreteceis": "entretecer",
    "entretecem": "entretecer",
    "entretecemo": "entretecer",
    "entretecemos": "entretecer",
    "entretecendo": "entretecer",
    "entretecera": "entretecer",
    "entreteceram": "entretecer",
    "entreteceras": "entretecer",
    "entretecerde": "entretecer",
    "entretecerdes": "entretecer",
    "entretecere": "entretecer",
    "entretecerei": "entretecer",
    "entretecereis": "entretecer",
    "entretecerem": "entretecer",
    "entreteceremos": "entretecer",
    "entreteceres": "entretecer",
    "entreteceria": "entretecer",
    "entreteceriam": "entretecer",
    "entretecerias": "entretecer",
    "entretecermo": "entretecer",
    "entretecermos": "entretecer",
    "entretecerá": "entretecer",
    "entretecerás": "entretecer",
    "entretecerão": "entretecer",
    "entreteceríamos": "entretecer",
    "entreteceríeis": "entretecer",
    "entreteces": "entretecer",
    "entretecesse": "entretecer",
    "entretecessem": "entretecer",
    "entretecesses": "entretecer",
    "entreteceste": "entretecer",
    "entretecestes": "entretecer",
    "entreteceu": "entretecer",
    "entreteci": "entretecer",
    "entretecia": "entretecer",
    "entreteciam": "entretecer",
    "entretecias": "entretecer",
    "entretecida": "entretecido",
    "entretecidas": "entretecido",
    "entretecido": "entretecer",
    "entretecidos": "entretecido",
    "entretecimentos": "entretecimento",
    "entretecê": "entretecer",
    "entretecêramo": "entretecer",
    "entretecêramos": "entretecer",
    "entretecêrei": "entretecer",
    "entretecêreis": "entretecer",
    "entretecêsseis": "entretecer",
    "entretecêssemos": "entretecer",
    "entretecíamo": "entretecer",
    "entretecíamos": "entretecer",
    "entretecíei": "entretecer",
    "entretecíeis": "entretecer",
    "entretela": "entretelar",
    "entretelada": "entretelar",
    "entreteladas": "entretelar",
    "entretelado": "entretelar",
    "entretelados": "entretelar",
    "entretelai": "entretelar",
    "entretelais": "entretelar",
    "entretelam": "entretelar",
    "entretelamo": "entretelar",
    "entretelamos": "entretelar",
    "entretelando": "entretelar",
    "entretelara": "entretelar",
    "entretelaram": "entretelar",
    "entretelaras": "entretelar",
    "entretelarde": "entretelar",
    "entretelardes": "entretelar",
    "entretelare": "entretelar",
    "entretelarei": "entretelar",
    "entretelareis": "entretelar",
    "entretelarem": "entretelar",
    "entretelaremos": "entretelar",
    "entretelares": "entretelar",
    "entretelaria": "entretelar",
    "entretelariam": "entretelar",
    "entretelarias": "entretelar",
    "entretelarmo": "entretelar",
    "entretelarmos": "entretelar",
    "entretelará": "entretelar",
    "entretelarás": "entretelar",
    "entretelarão": "entretelar",
    "entretelaríamos": "entretelar",
    "entretelaríeis": "entretelar",
    "entretelas": "entretelar",
    "entretelasse": "entretelar",
    "entretelassem": "entretelar",
    "entretelasses": "entretelar",
    "entretelaste": "entretelar",
    "entretelastes": "entretelar",
    "entretelava": "entretelar",
    "entretelavam": "entretelar",
    "entretelavas": "entretelar",
    "entretele": "entretelar",
    "entretelei": "entretelar",
    "entreteleis": "entretelar",
    "entretelem": "entretelar",
    "entretelemo": "entretelar",
    "entretelemos": "entretelar",
    "entreteles": "entretelar",
    "entretelo": "entretelar",
    "entretelou": "entretelar",
    "entretelá": "entretelar",
    "entretelámo": "entretelar",
    "entretelámos": "entretelar",
    "entreteláramo": "entretelar",
    "entreteláramos": "entretelar",
    "entretelárei": "entretelar",
    "entreteláreis": "entretelar",
    "entretelásseis": "entretelar",
    "entretelássemos": "entretelar",
    "entretelávamo": "entretelar",
    "entretelávamos": "entretelar",
    "entretelávei": "entretelar",
    "entreteláveis": "entretelar",
    "entretemo": "entreter",
    "entretemos": "entreter",
    "entretempos": "entretempo",
    "entretende": "entreter",
    "entretendes": "entreter",
    "entretendo": "entreter",
    "entretenha": "entreter",
    "entretenhais": "entreter",
    "entretenham": "entreter",
    "entretenhamo": "entreter",
    "entretenhamos": "entreter",
    "entretenhas": "entreter",
    "entretenho": "entreter",
    "entretenimentos": "entretenimento",
    "entretens": "entretem",
    "entreterde": "entreter",
    "entreterdes": "entreter",
    "entretere": "entreter",
    "entreterei": "entreter",
    "entretereis": "entreter",
    "entreterem": "entreter",
    "entreteremos": "entreter",
    "entreteres": "entreter",
    "entreteria": "entreter",
    "entreteriam": "entreter",
    "entreterias": "entreter",
    "entretermo": "entreter",
    "entretermos": "entreter",
    "entreterá": "entreter",
    "entreterás": "entreter",
    "entreterão": "entreter",
    "entreteríamos": "entreter",
    "entreteríeis": "entreter",
    "entretestas": "entretesta",
    "entreteve": "entreter",
    "entreteça": "entretecer",
    "entreteçais": "entretecer",
    "entreteçam": "entretecer",
    "entreteçamo": "entretecer",
    "entreteçamos": "entretecer",
    "entreteças": "entretecer",
    "entreteço": "entretecer",
    "entretida": "entretido",
    "entretidas": "entretido",
    "entretido": "entreter",
    "entretidos": "entretido",
    "entretimentos": "entretimento",
    "entretinha": "entreter",
    "entretinham": "entreter",
    "entretinhas": "entreter",
    "entretinhos": "entretinho",
    "entretive": "entreter",
    "entretivemo": "entreter",
    "entretivemos": "entreter",
    "entretiver": "entreter",
    "entretivera": "entreter",
    "entretiveram": "entreter",
    "entretiveras": "entreter",
    "entretiverdes": "entreter",
    "entretiverem": "entreter",
    "entretiveres": "entreter",
    "entretivermos": "entreter",
    "entretivesse": "entreter",
    "entretivessem": "entreter",
    "entretivesses": "entreter",
    "entretiveste": "entreter",
    "entretivestes": "entreter",
    "entretivéramo": "entreter",
    "entretivéramos": "entreter",
    "entretivérei": "entreter",
    "entretivéreis": "entreter",
    "entretivésseis": "entreter",
    "entretivéssemos": "entreter",
    "entretons": "entretom",
    "entreturba": "entreturbar",
    "entreturbada": "entreturbar",
    "entreturbadas": "entreturbar",
    "entreturbado": "entreturbar",
    "entreturbados": "entreturbar",
    "entreturbai": "entreturbar",
    "entreturbais": "entreturbar",
    "entreturbam": "entreturbar",
    "entreturbamo": "entreturbar",
    "entreturbamos": "entreturbar",
    "entreturbando": "entreturbar",
    "entreturbara": "entreturbar",
    "entreturbaram": "entreturbar",
    "entreturbaras": "entreturbar",
    "entreturbarde": "entreturbar",
    "entreturbardes": "entreturbar",
    "entreturbare": "entreturbar",
    "entreturbarei": "entreturbar",
    "entreturbareis": "entreturbar",
    "entreturbarem": "entreturbar",
    "entreturbaremos": "entreturbar",
    "entreturbares": "entreturbar",
    "entreturbaria": "entreturbar",
    "entreturbariam": "entreturbar",
    "entreturbarias": "entreturbar",
    "entreturbarmo": "entreturbar",
    "entreturbarmos": "entreturbar",
    "entreturbará": "entreturbar",
    "entreturbarás": "entreturbar",
    "entreturbarão": "entreturbar",
    "entreturbaríamos": "entreturbar",
    "entreturbaríeis": "entreturbar",
    "entreturbas": "entreturbar",
    "entreturbasse": "entreturbar",
    "entreturbassem": "entreturbar",
    "entreturbasses": "entreturbar",
    "entreturbaste": "entreturbar",
    "entreturbastes": "entreturbar",
    "entreturbava": "entreturbar",
    "entreturbavam": "entreturbar",
    "entreturbavas": "entreturbar",
    "entreturbe": "entreturbar",
    "entreturbei": "entreturbar",
    "entreturbeis": "entreturbar",
    "entreturbem": "entreturbar",
    "entreturbemo": "entreturbar",
    "entreturbemos": "entreturbar",
    "entreturbes": "entreturbar",
    "entreturbo": "entreturbar",
    "entreturbou": "entreturbar",
    "entreturbá": "entreturbar",
    "entreturbámo": "entreturbar",
    "entreturbámos": "entreturbar",
    "entreturbáramo": "entreturbar",
    "entreturbáramos": "entreturbar",
    "entreturbárei": "entreturbar",
    "entreturbáreis": "entreturbar",
    "entreturbásseis": "entreturbar",
    "entreturbássemos": "entreturbar",
    "entreturbávamo": "entreturbar",
    "entreturbávamos": "entreturbar",
    "entreturbávei": "entreturbar",
    "entreturbáveis": "entreturbar",
    "entretém": "entreter",
    "entreténs": "entreter",
    "entretê": "entreter",
    "entretêm": "entreter",
    "entretínhamo": "entreter",
    "entretínhamos": "entreter",
    "entretínhei": "entreter",
    "entretínheis": "entreter",
    "entreuna": "entreunir",
    "entreunais": "entreunir",
    "entreunam": "entreunir",
    "entreunamo": "entreunir",
    "entreunamos": "entreunir",
    "entreunas": "entreunir",
    "entreune": "entreunir",
    "entreunem": "entreunir",
    "entreunes": "entreunir",
    "entreuni": "entreunir",
    "entreunia": "entreunir",
    "entreuniam": "entreunir",
    "entreunias": "entreunir",
    "entreunida": "entreunir",
    "entreunidas": "entreunir",
    "entreunido": "entreunir",
    "entreunidos": "entreunir",
    "entreunimo": "entreunir",
    "entreunimos": "entreunir",
    "entreunindo": "entreunir",
    "entreunira": "entreunir",
    "entreuniram": "entreunir",
    "entreuniras": "entreunir",
    "entreunirde": "entreunir",
    "entreunirdes": "entreunir",
    "entreunire": "entreunir",
    "entreunirei": "entreunir",
    "entreunireis": "entreunir",
    "entreunirem": "entreunir",
    "entreuniremos": "entreunir",
    "entreunires": "entreunir",
    "entreuniria": "entreunir",
    "entreuniriam": "entreunir",
    "entreunirias": "entreunir",
    "entreunirmo": "entreunir",
    "entreunirmos": "entreunir",
    "entreunirá": "entreunir",
    "entreunirás": "entreunir",
    "entreunirão": "entreunir",
    "entreuniríamos": "entreunir",
    "entreuniríeis": "entreunir",
    "entreunis": "entreunir",
    "entreunisse": "entreunir",
    "entreunissem": "entreunir",
    "entreunisses": "entreunir",
    "entreuniste": "entreunir",
    "entreunistes": "entreunir",
    "entreuniu": "entreunir",
    "entreuno": "entreunir",
    "entreuníamo": "entreunir",
    "entreuníamos": "entreunir",
    "entreuníei": "entreunir",
    "entreuníeis": "entreunir",
    "entreuníramo": "entreunir",
    "entreuníramos": "entreunir",
    "entreunírei": "entreunir",
    "entreuníreis": "entreunir",
    "entreunísseis": "entreunir",
    "entreuníssemos": "entreunir",
    "entreva": "entrevar",
    "entrevada": "entrevar",
    "entrevadas": "entrevar",
    "entrevado": "entrevar",
    "entrevados": "entrevar",
    "entrevai": "entrevar",
    "entrevais": "entrevar",
    "entrevam": "entrevar",
    "entrevamentos": "entrevamento",
    "entrevamo": "entrevar",
    "entrevamos": "entrevar",
    "entrevando": "entrevar",
    "entrevara": "entrevar",
    "entrevaram": "entrevar",
    "entrevaras": "entrevar",
    "entrevarde": "entrevar",
    "entrevardes": "entrevar",
    "entrevare": "entrevar",
    "entrevarei": "entrevar",
    "entrevareis": "entrevar",
    "entrevarem": "entrevar",
    "entrevaremos": "entrevar",
    "entrevares": "entrevar",
    "entrevaria": "entrevar",
    "entrevariam": "entrevar",
    "entrevarias": "entrevar",
    "entrevarmo": "entrevar",
    "entrevarmos": "entrevar",
    "entrevará": "entrevar",
    "entrevarás": "entrevar",
    "entrevarão": "entrevar",
    "entrevaríamos": "entrevar",
    "entrevaríeis": "entrevar",
    "entrevas": "entrevar",
    "entrevasse": "entrevar",
    "entrevassem": "entrevar",
    "entrevasses": "entrevar",
    "entrevaste": "entrevar",
    "entrevastes": "entrevar",
    "entrevava": "entrevar",
    "entrevavam": "entrevar",
    "entrevavas": "entrevar",
    "entrevações": "entrevação",
    "entreve": "entrevar",
    "entreveada": "entreveado",
    "entreveadas": "entreveado",
    "entreveados": "entreveado",
    "entrevece": "entrevecer",
    "entrevecei": "entrevecer",
    "entreveceis": "entrevecer",
    "entrevecem": "entrevecer",
    "entrevecemo": "entrevecer",
    "entrevecemos": "entrevecer",
    "entrevecendo": "entrevecer",
    "entrevecera": "entrevecer",
    "entreveceram": "entrevecer",
    "entreveceras": "entrevecer",
    "entrevecerde": "entrevecer",
    "entrevecerdes": "entrevecer",
    "entrevecere": "entrevecer",
    "entrevecerei": "entrevecer",
    "entrevecereis": "entrevecer",
    "entrevecerem": "entrevecer",
    "entreveceremos": "entrevecer",
    "entreveceres": "entrevecer",
    "entreveceria": "entrevecer",
    "entreveceriam": "entrevecer",
    "entrevecerias": "entrevecer",
    "entrevecermo": "entrevecer",
    "entrevecermos": "entrevecer",
    "entrevecerá": "entrevecer",
    "entrevecerás": "entrevecer",
    "entrevecerão": "entrevecer",
    "entreveceríamos": "entrevecer",
    "entreveceríeis": "entrevecer",
    "entreveces": "entrevecer",
    "entrevecesse": "entrevecer",
    "entrevecessem": "entrevecer",
    "entrevecesses": "entrevecer",
    "entreveceste": "entrevecer",
    "entrevecestes": "entrevecer",
    "entreveceu": "entrevecer",
    "entreveci": "entrevecer",
    "entrevecia": "entrevecer",
    "entreveciam": "entrevecer",
    "entrevecias": "entrevecer",
    "entrevecida": "entrevecido",
    "entrevecidas": "entrevecido",
    "entrevecido": "entrevecer",
    "entrevecidos": "entrevecido",
    "entrevecimentos": "entrevecimento",
    "entrevecê": "entrevecer",
    "entrevecêramo": "entrevecer",
    "entrevecêramos": "entrevecer",
    "entrevecêrei": "entrevecer",
    "entrevecêreis": "entrevecer",
    "entrevecêsseis": "entrevecer",
    "entrevecêssemos": "entrevecer",
    "entrevecíamo": "entrevecer",
    "entrevecíamos": "entrevecer",
    "entrevecíei": "entrevecer",
    "entrevecíeis": "entrevecer",
    "entrevede": "entrever",
    "entrevedes": "entrever",
    "entrevei": "entrevar",
    "entreveis": "entrevar",
    "entreveja": "entrever",
    "entrevejais": "entrever",
    "entrevejam": "entrever",
    "entrevejamo": "entrever",
    "entrevejamos": "entrever",
    "entrevejas": "entrever",
    "entrevejo": "entrever",
    "entrevem": "entrevar",
    "entrevemo": "entrever",
    "entrevemos": "entrever",
    "entrevendo": "entrever",
    "entrevera": "entreverar",
    "entreverada": "entreverar",
    "entreveradas": "entreverar",
    "entreverado": "entreverar",
    "entreverados": "entreverar",
    "entreverai": "entreverar",
    "entreverais": "entreverar",
    "entreveram": "entreverar",
    "entreveramo": "entreverar",
    "entreveramos": "entreverar",
    "entreverando": "entreverar",
    "entreverara": "entreverar",
    "entreveraram": "entreverar",
    "entreveraras": "entreverar",
    "entreverarde": "entreverar",
    "entreverardes": "entreverar",
    "entreverare": "entreverar",
    "entreverarei": "entreverar",
    "entreverareis": "entreverar",
    "entreverarem": "entreverar",
    "entreveraremos": "entreverar",
    "entreverares": "entreverar",
    "entreveraria": "entreverar",
    "entreverariam": "entreverar",
    "entreverarias": "entreverar",
    "entreverarmo": "entreverar",
    "entreverarmos": "entreverar",
    "entreverará": "entreverar",
    "entreverarás": "entreverar",
    "entreverarão": "entreverar",
    "entreveraríamos": "entreverar",
    "entreveraríeis": "entreverar",
    "entreveras": "entreverar",
    "entreverasse": "entreverar",
    "entreverassem": "entreverar",
    "entreverasses": "entreverar",
    "entreveraste": "entreverar",
    "entreverastes": "entreverar",
    "entreverava": "entreverar",
    "entreveravam": "entreverar",
    "entreveravas": "entreverar",
    "entreverde": "entrever",
    "entreverdes": "entreverde",
    "entrevere": "entreverar",
    "entreverei": "entreverar",
    "entrevereis": "entreverar",
    "entreverem": "entreverar",
    "entreveremo": "entreverar",
    "entreveremos": "entreverar",
    "entreveres": "entreverar",
    "entreveria": "entrever",
    "entreveriam": "entrever",
    "entreverias": "entrever",
    "entrevermo": "entrever",
    "entrevermos": "entrever",
    "entrevero": "entreverar",
    "entreverou": "entreverar",
    "entreverá": "entreverar",
    "entreverámo": "entreverar",
    "entreverámos": "entreverar",
    "entreveráramo": "entreverar",
    "entreveráramos": "entreverar",
    "entreverárei": "entreverar",
    "entreveráreis": "entreverar",
    "entreverás": "entrever",
    "entreverásseis": "entreverar",
    "entreverássemos": "entreverar",
    "entreverávamo": "entreverar",
    "entreverávamos": "entreverar",
    "entreverávei": "entreverar",
    "entreveráveis": "entreverar",
    "entreverão": "entrever",
    "entreveríamos": "entrever",
    "entreveríeis": "entrever",
    "entreves": "entrevar",
    "entreveça": "entrevecer",
    "entreveçais": "entrevecer",
    "entreveçam": "entrevecer",
    "entreveçamo": "entrevecer",
    "entreveçamos": "entrevecer",
    "entreveças": "entrevecer",
    "entreveço": "entrevecer",
    "entrevi": "entrever",
    "entrevia": "entrever",
    "entreviam": "entrever",
    "entrevias": "entrevia",
    "entrevimo": "entrever",
    "entrevimos": "entrever",
    "entrevindas": "entrevinda",
    "entrevir": "entrever",
    "entrevira": "entrever",
    "entreviram": "entrever",
    "entreviras": "entrever",
    "entrevirdes": "entrever",
    "entrevirem": "entrever",
    "entrevires": "entrever",
    "entrevirmos": "entrever",
    "entrevisse": "entrever",
    "entrevissem": "entrever",
    "entrevisses": "entrever",
    "entrevista": "entrevisto",
    "entrevistada": "entrevistar",
    "entrevistadas": "entrevistar",
    "entrevistado": "entrevistar",
    "entrevistadora": "entrevistador",
    "entrevistadoras": "entrevistador",
    "entrevistadores": "entrevistador",
    "entrevistados": "entrevistar",
    "entrevistai": "entrevistar",
    "entrevistais": "entrevistar",
    "entrevistam": "entrevistar",
    "entrevistamo": "entrevistar",
    "entrevistamos": "entrevistar",
    "entrevistando": "entrevistar",
    "entrevistara": "entrevistar",
    "entrevistaram": "entrevistar",
    "entrevistaras": "entrevistar",
    "entrevistarde": "entrevistar",
    "entrevistardes": "entrevistar",
    "entrevistare": "entrevistar",
    "entrevistarei": "entrevistar",
    "entrevistareis": "entrevistar",
    "entrevistarem": "entrevistar",
    "entrevistaremos": "entrevistar",
    "entrevistares": "entrevistar",
    "entrevistaria": "entrevistar",
    "entrevistariam": "entrevistar",
    "entrevistarias": "entrevistar",
    "entrevistarmo": "entrevistar",
    "entrevistarmos": "entrevistar",
    "entrevistará": "entrevistar",
    "entrevistarás": "entrevistar",
    "entrevistarão": "entrevistar",
    "entrevistaríamos": "entrevistar",
    "entrevistaríeis": "entrevistar",
    "entrevistas": "entrevisto",
    "entrevistasse": "entrevistar",
    "entrevistassem": "entrevistar",
    "entrevistasses": "entrevistar",
    "entrevistaste": "entrevistar",
    "entrevistastes": "entrevistar",
    "entrevistava": "entrevistar",
    "entrevistavam": "entrevistar",
    "entrevistavas": "entrevistar",
    "entreviste": "entrevistar",
    "entrevistei": "entrevistar",
    "entrevisteis": "entrevistar",
    "entrevistem": "entrevistar",
    "entrevistemo": "entrevistar",
    "entrevistemos": "entrevistar",
    "entrevistes": "entrevistar",
    "entrevisto": "entrevistar",
    "entrevistos": "entrevisto",
    "entrevistou": "entrevistar",
    "entrevistá": "entrevistar",
    "entrevistámo": "entrevistar",
    "entrevistámos": "entrevistar",
    "entrevistáramo": "entrevistar",
    "entrevistáramos": "entrevistar",
    "entrevistárei": "entrevistar",
    "entrevistáreis": "entrevistar",
    "entrevistásseis": "entrevistar",
    "entrevistássemos": "entrevistar",
    "entrevistávamo": "entrevistar",
    "entrevistávamos": "entrevistar",
    "entrevistávei": "entrevistar",
    "entrevistáveis": "entrevistar",
    "entrevisões": "entrevisão",
    "entreviu": "entrever",
    "entrevo": "entrevar",
    "entrevou": "entrevar",
    "entrevá": "entrevar",
    "entrevámo": "entrevar",
    "entrevámos": "entrevar",
    "entreváramo": "entrevar",
    "entreváramos": "entrevar",
    "entrevárei": "entrevar",
    "entreváreis": "entrevar",
    "entrevásseis": "entrevar",
    "entrevássemos": "entrevar",
    "entrevávamo": "entrevar",
    "entrevávamos": "entrevar",
    "entrevávei": "entrevar",
    "entreváveis": "entrevar",
    "entrevê": "entrever",
    "entrevêem": "entrever",
    "entrevês": "entrever",
    "entrevíamo": "entrever",
    "entrevíamos": "entrever",
    "entrevíei": "entrever",
    "entrevíeis": "entrever",
    "entrevíramo": "entrever",
    "entrevíramos": "entrever",
    "entrevírei": "entrever",
    "entrevíreis": "entrever",
    "entrevísseis": "entrever",
    "entrevíssemos": "entrever",
    "entrilha": "entrilhar",
    "entrilhada": "entrilhar",
    "entrilhadas": "entrilhar",
    "entrilhado": "entrilhar",
    "entrilhados": "entrilhar",
    "entrilhai": "entrilhar",
    "entrilhais": "entrilhar",
    "entrilham": "entrilhar",
    "entrilhamo": "entrilhar",
    "entrilhamos": "entrilhar",
    "entrilhando": "entrilhar",
    "entrilhara": "entrilhar",
    "entrilharam": "entrilhar",
    "entrilharas": "entrilhar",
    "entrilharde": "entrilhar",
    "entrilhardes": "entrilhar",
    "entrilhare": "entrilhar",
    "entrilharei": "entrilhar",
    "entrilhareis": "entrilhar",
    "entrilharem": "entrilhar",
    "entrilharemos": "entrilhar",
    "entrilhares": "entrilhar",
    "entrilharia": "entrilhar",
    "entrilhariam": "entrilhar",
    "entrilharias": "entrilhar",
    "entrilharmo": "entrilhar",
    "entrilharmos": "entrilhar",
    "entrilhará": "entrilhar",
    "entrilharás": "entrilhar",
    "entrilharão": "entrilhar",
    "entrilharíamos": "entrilhar",
    "entrilharíeis": "entrilhar",
    "entrilhas": "entrilhar",
    "entrilhasse": "entrilhar",
    "entrilhassem": "entrilhar",
    "entrilhasses": "entrilhar",
    "entrilhaste": "entrilhar",
    "entrilhastes": "entrilhar",
    "entrilhava": "entrilhar",
    "entrilhavam": "entrilhar",
    "entrilhavas": "entrilhar",
    "entrilhe": "entrilhar",
    "entrilhei": "entrilhar",
    "entrilheis": "entrilhar",
    "entrilhem": "entrilhar",
    "entrilhemo": "entrilhar",
    "entrilhemos": "entrilhar",
    "entrilhes": "entrilhar",
    "entrilho": "entrilhar",
    "entrilhou": "entrilhar",
    "entrilhá": "entrilhar",
    "entrilhámo": "entrilhar",
    "entrilhámos": "entrilhar",
    "entrilháramo": "entrilhar",
    "entrilháramos": "entrilhar",
    "entrilhárei": "entrilhar",
    "entrilháreis": "entrilhar",
    "entrilhásseis": "entrilhar",
    "entrilhássemos": "entrilhar",
    "entrilhávamo": "entrilhar",
    "entrilhávamos": "entrilhar",
    "entrilhávei": "entrilhar",
    "entrilháveis": "entrilhar",
    "entrincheira": "entrincheirar",
    "entrincheirada": "entrincheirar",
    "entrincheiradas": "entrincheirar",
    "entrincheirado": "entrincheirar",
    "entrincheirados": "entrincheirar",
    "entrincheirai": "entrincheirar",
    "entrincheirais": "entrincheirar",
    "entrincheiram": "entrincheirar",
    "entrincheiramentos": "entrincheiramento",
    "entrincheiramo": "entrincheirar",
    "entrincheiramos": "entrincheirar",
    "entrincheirando": "entrincheirar",
    "entrincheirara": "entrincheirar",
    "entrincheiraram": "entrincheirar",
    "entrincheiraras": "entrincheirar",
    "entrincheirarde": "entrincheirar",
    "entrincheirardes": "entrincheirar",
    "entrincheirare": "entrincheirar",
    "entrincheirarei": "entrincheirar",
    "entrincheirareis": "entrincheirar",
    "entrincheirarem": "entrincheirar",
    "entrincheiraremos": "entrincheirar",
    "entrincheirares": "entrincheirar",
    "entrincheiraria": "entrincheirar",
    "entrincheirariam": "entrincheirar",
    "entrincheirarias": "entrincheirar",
    "entrincheirarmo": "entrincheirar",
    "entrincheirarmos": "entrincheirar",
    "entrincheirará": "entrincheirar",
    "entrincheirarás": "entrincheirar",
    "entrincheirarão": "entrincheirar",
    "entrincheiraríamos": "entrincheirar",
    "entrincheiraríeis": "entrincheirar",
    "entrincheiras": "entrincheirar",
    "entrincheirasse": "entrincheirar",
    "entrincheirassem": "entrincheirar",
    "entrincheirasses": "entrincheirar",
    "entrincheiraste": "entrincheirar",
    "entrincheirastes": "entrincheirar",
    "entrincheirava": "entrincheirar",
    "entrincheiravam": "entrincheirar",
    "entrincheiravas": "entrincheirar",
    "entrincheire": "entrincheirar",
    "entrincheirei": "entrincheirar",
    "entrincheireis": "entrincheirar",
    "entrincheirem": "entrincheirar",
    "entrincheiremo": "entrincheirar",
    "entrincheiremos": "entrincheirar",
    "entrincheires": "entrincheirar",
    "entrincheiro": "entrincheirar",
    "entrincheirou": "entrincheirar",
    "entrincheirá": "entrincheirar",
    "entrincheirámo": "entrincheirar",
    "entrincheirámos": "entrincheirar",
    "entrincheiráramo": "entrincheirar",
    "entrincheiráramos": "entrincheirar",
    "entrincheirárei": "entrincheirar",
    "entrincheiráreis": "entrincheirar",
    "entrincheirásseis": "entrincheirar",
    "entrincheirássemos": "entrincheirar",
    "entrincheirávamo": "entrincheirar",
    "entrincheirávamos": "entrincheirar",
    "entrincheirávei": "entrincheirar",
    "entrincheiráveis": "entrincheirar",
    "entripada": "entripado",
    "entripadas": "entripado",
    "entripados": "entripado",
    "entristece": "entristecer",
    "entristecei": "entristecer",
    "entristeceis": "entristecer",
    "entristecem": "entristecer",
    "entristecemo": "entristecer",
    "entristecemos": "entristecer",
    "entristecendo": "entristecer",
    "entristecera": "entristecer",
    "entristeceram": "entristecer",
    "entristeceras": "entristecer",
    "entristecerde": "entristecer",
    "entristecerdes": "entristecer",
    "entristecere": "entristecer",
    "entristecerei": "entristecer",
    "entristecereis": "entristecer",
    "entristecerem": "entristecer",
    "entristeceremos": "entristecer",
    "entristeceres": "entristecer",
    "entristeceria": "entristecer",
    "entristeceriam": "entristecer",
    "entristecerias": "entristecer",
    "entristecermo": "entristecer",
    "entristecermos": "entristecer",
    "entristecerá": "entristecer",
    "entristecerás": "entristecer",
    "entristecerão": "entristecer",
    "entristeceríamos": "entristecer",
    "entristeceríeis": "entristecer",
    "entristeces": "entristecer",
    "entristecesse": "entristecer",
    "entristecessem": "entristecer",
    "entristecesses": "entristecer",
    "entristeceste": "entristecer",
    "entristecestes": "entristecer",
    "entristeceu": "entristecer",
    "entristeci": "entristecer",
    "entristecia": "entristecer",
    "entristeciam": "entristecer",
    "entristecias": "entristecer",
    "entristecida": "entristecido",
    "entristecidas": "entristecido",
    "entristecido": "entristecer",
    "entristecidos": "entristecido",
    "entristecimentos": "entristecimento",
    "entristecê": "entristecer",
    "entristecêramo": "entristecer",
    "entristecêramos": "entristecer",
    "entristecêrei": "entristecer",
    "entristecêreis": "entristecer",
    "entristecêsseis": "entristecer",
    "entristecêssemos": "entristecer",
    "entristecíamo": "entristecer",
    "entristecíamos": "entristecer",
    "entristecíei": "entristecer",
    "entristecíeis": "entristecer",
    "entristeça": "entristecer",
    "entristeçais": "entristecer",
    "entristeçam": "entristecer",
    "entristeçamo": "entristecer",
    "entristeçamos": "entristecer",
    "entristeças": "entristecer",
    "entristeço": "entristecer",
    "entritas": "entrita",
    "entriteiras": "entriteira",
    "entriza": "entrizar",
    "entrizada": "entrizar",
    "entrizadas": "entrizar",
    "entrizado": "entrizar",
    "entrizados": "entrizar",
    "entrizai": "entrizar",
    "entrizais": "entrizar",
    "entrizam": "entrizar",
    "entrizamo": "entrizar",
    "entrizamos": "entrizar",
    "entrizando": "entrizar",
    "entrizara": "entrizar",
    "entrizaram": "entrizar",
    "entrizaras": "entrizar",
    "entrizarde": "entrizar",
    "entrizardes": "entrizar",
    "entrizare": "entrizar",
    "entrizarei": "entrizar",
    "entrizareis": "entrizar",
    "entrizarem": "entrizar",
    "entrizaremos": "entrizar",
    "entrizares": "entrizar",
    "entrizaria": "entrizar",
    "entrizariam": "entrizar",
    "entrizarias": "entrizar",
    "entrizarmo": "entrizar",
    "entrizarmos": "entrizar",
    "entrizará": "entrizar",
    "entrizarás": "entrizar",
    "entrizarão": "entrizar",
    "entrizaríamos": "entrizar",
    "entrizaríeis": "entrizar",
    "entrizas": "entrizar",
    "entrizasse": "entrizar",
    "entrizassem": "entrizar",
    "entrizasses": "entrizar",
    "entrizaste": "entrizar",
    "entrizastes": "entrizar",
    "entrizava": "entrizar",
    "entrizavam": "entrizar",
    "entrizavas": "entrizar",
    "entrize": "entrizar",
    "entrizei": "entrizar",
    "entrizeis": "entrizar",
    "entrizem": "entrizar",
    "entrizemo": "entrizar",
    "entrizemos": "entrizar",
    "entrizes": "entrizar",
    "entrizo": "entrizar",
    "entrizou": "entrizar",
    "entrizá": "entrizar",
    "entrizámo": "entrizar",
    "entrizámos": "entrizar",
    "entrizáramo": "entrizar",
    "entrizáramos": "entrizar",
    "entrizárei": "entrizar",
    "entrizáreis": "entrizar",
    "entrizásseis": "entrizar",
    "entrizássemos": "entrizar",
    "entrizávamo": "entrizar",
    "entrizávamos": "entrizar",
    "entrizávei": "entrizar",
    "entrizáveis": "entrizar",
    "entro": "entrar",
    "entroichos": "entroicho",
    "entroixa": "entroixar",
    "entroixada": "entroixar",
    "entroixadas": "entroixar",
    "entroixado": "entroixar",
    "entroixados": "entroixar",
    "entroixai": "entroixar",
    "entroixais": "entroixar",
    "entroixam": "entroixar",
    "entroixamo": "entroixar",
    "entroixamos": "entroixar",
    "entroixando": "entroixar",
    "entroixara": "entroixar",
    "entroixaram": "entroixar",
    "entroixaras": "entroixar",
    "entroixarde": "entroixar",
    "entroixardes": "entroixar",
    "entroixare": "entroixar",
    "entroixarei": "entroixar",
    "entroixareis": "entroixar",
    "entroixarem": "entroixar",
    "entroixaremos": "entroixar",
    "entroixares": "entroixar",
    "entroixaria": "entroixar",
    "entroixariam": "entroixar",
    "entroixarias": "entroixar",
    "entroixarmo": "entroixar",
    "entroixarmos": "entroixar",
    "entroixará": "entroixar",
    "entroixarás": "entroixar",
    "entroixarão": "entroixar",
    "entroixaríamos": "entroixar",
    "entroixaríeis": "entroixar",
    "entroixas": "entroixar",
    "entroixasse": "entroixar",
    "entroixassem": "entroixar",
    "entroixasses": "entroixar",
    "entroixaste": "entroixar",
    "entroixastes": "entroixar",
    "entroixava": "entroixar",
    "entroixavam": "entroixar",
    "entroixavas": "entroixar",
    "entroixe": "entroixar",
    "entroixei": "entroixar",
    "entroixeis": "entroixar",
    "entroixem": "entroixar",
    "entroixemo": "entroixar",
    "entroixemos": "entroixar",
    "entroixes": "entroixar",
    "entroixo": "entroixar",
    "entroixos": "entroixo",
    "entroixou": "entroixar",
    "entroixá": "entroixar",
    "entroixámo": "entroixar",
    "entroixámos": "entroixar",
    "entroixáramo": "entroixar",
    "entroixáramos": "entroixar",
    "entroixárei": "entroixar",
    "entroixáreis": "entroixar",
    "entroixásseis": "entroixar",
    "entroixássemos": "entroixar",
    "entroixávamo": "entroixar",
    "entroixávamos": "entroixar",
    "entroixávei": "entroixar",
    "entroixáveis": "entroixar",
    "entromba": "entrombar",
    "entrombada": "entrombar",
    "entrombadas": "entrombar",
    "entrombado": "entrombar",
    "entrombados": "entrombar",
    "entrombai": "entrombar",
    "entrombais": "entrombar",
    "entrombam": "entrombar",
    "entrombamo": "entrombar",
    "entrombamos": "entrombar",
    "entrombando": "entrombar",
    "entrombara": "entrombar",
    "entrombaram": "entrombar",
    "entrombaras": "entrombar",
    "entrombarde": "entrombar",
    "entrombardes": "entrombar",
    "entrombare": "entrombar",
    "entrombarei": "entrombar",
    "entrombareis": "entrombar",
    "entrombarem": "entrombar",
    "entrombaremos": "entrombar",
    "entrombares": "entrombar",
    "entrombaria": "entrombar",
    "entrombariam": "entrombar",
    "entrombarias": "entrombar",
    "entrombarmo": "entrombar",
    "entrombarmos": "entrombar",
    "entrombará": "entrombar",
    "entrombarás": "entrombar",
    "entrombarão": "entrombar",
    "entrombaríamos": "entrombar",
    "entrombaríeis": "entrombar",
    "entrombas": "entrombar",
    "entrombasse": "entrombar",
    "entrombassem": "entrombar",
    "entrombasses": "entrombar",
    "entrombaste": "entrombar",
    "entrombastes": "entrombar",
    "entrombava": "entrombar",
    "entrombavam": "entrombar",
    "entrombavas": "entrombar",
    "entrombe": "entrombar",
    "entrombei": "entrombar",
    "entrombeis": "entrombar",
    "entrombem": "entrombar",
    "entrombemo": "entrombar",
    "entrombemos": "entrombar",
    "entrombes": "entrombar",
    "entrombo": "entrombar",
    "entrombou": "entrombar",
    "entrombá": "entrombar",
    "entrombámo": "entrombar",
    "entrombámos": "entrombar",
    "entrombáramo": "entrombar",
    "entrombáramos": "entrombar",
    "entrombárei": "entrombar",
    "entrombáreis": "entrombar",
    "entrombásseis": "entrombar",
    "entrombássemos": "entrombar",
    "entrombávamo": "entrombar",
    "entrombávamos": "entrombar",
    "entrombávei": "entrombar",
    "entrombáveis": "entrombar",
    "entronada": "entronado",
    "entronadas": "entronado",
    "entronados": "entronado",
    "entronca": "entroncar",
    "entroncada": "entroncar",
    "entroncadas": "entroncar",
    "entroncado": "entroncar",
    "entroncados": "entroncar",
    "entroncai": "entroncar",
    "entroncais": "entroncar",
    "entroncam": "entroncar",
    "entroncamentos": "entroncamento",
    "entroncamo": "entroncar",
    "entroncamos": "entroncar",
    "entroncando": "entroncar",
    "entroncara": "entroncar",
    "entroncaram": "entroncar",
    "entroncaras": "entroncar",
    "entroncarde": "entroncar",
    "entroncardes": "entroncar",
    "entroncare": "entroncar",
    "entroncarei": "entroncar",
    "entroncareis": "entroncar",
    "entroncarem": "entroncar",
    "entroncaremos": "entroncar",
    "entroncares": "entroncar",
    "entroncaria": "entroncar",
    "entroncariam": "entroncar",
    "entroncarias": "entroncar",
    "entroncarmo": "entroncar",
    "entroncarmos": "entroncar",
    "entroncará": "entroncar",
    "entroncarás": "entroncar",
    "entroncarão": "entroncar",
    "entroncaríamos": "entroncar",
    "entroncaríeis": "entroncar",
    "entroncas": "entroncar",
    "entroncasse": "entroncar",
    "entroncassem": "entroncar",
    "entroncasses": "entroncar",
    "entroncaste": "entroncar",
    "entroncastes": "entroncar",
    "entroncava": "entroncar",
    "entroncavam": "entroncar",
    "entroncavas": "entroncar",
    "entroncha": "entronchar",
    "entronchada": "entronchar",
    "entronchadas": "entronchar",
    "entronchado": "entronchar",
    "entronchados": "entronchar",
    "entronchai": "entronchar",
    "entronchais": "entronchar",
    "entroncham": "entronchar",
    "entronchamo": "entronchar",
    "entronchamos": "entronchar",
    "entronchando": "entronchar",
    "entronchara": "entronchar",
    "entroncharam": "entronchar",
    "entroncharas": "entronchar",
    "entronchardes": "entronchar",
    "entroncharei": "entronchar",
    "entronchareis": "entronchar",
    "entroncharem": "entronchar",
    "entroncharemos": "entronchar",
    "entronchares": "entronchar",
    "entroncharia": "entronchar",
    "entronchariam": "entronchar",
    "entroncharias": "entronchar",
    "entroncharmo": "entronchar",
    "entroncharmos": "entronchar",
    "entronchará": "entronchar",
    "entroncharás": "entronchar",
    "entroncharão": "entronchar",
    "entroncharíamos": "entronchar",
    "entroncharíeis": "entronchar",
    "entronchas": "entronchar",
    "entronchasse": "entronchar",
    "entronchassem": "entronchar",
    "entronchasses": "entronchar",
    "entronchaste": "entronchar",
    "entronchastes": "entronchar",
    "entronchava": "entronchar",
    "entronchavam": "entronchar",
    "entronchavas": "entronchar",
    "entronche": "entronchar",
    "entronchei": "entronchar",
    "entroncheis": "entronchar",
    "entronchem": "entronchar",
    "entronchemo": "entronchar",
    "entronchemos": "entronchar",
    "entronches": "entronchar",
    "entroncho": "entronchar",
    "entronchou": "entronchar",
    "entronchámo": "entronchar",
    "entronchámos": "entronchar",
    "entroncháramo": "entronchar",
    "entroncháramos": "entronchar",
    "entroncháreis": "entronchar",
    "entronchásseis": "entronchar",
    "entronchássemos": "entronchar",
    "entronchávamo": "entronchar",
    "entronchávamos": "entronchar",
    "entroncháveis": "entronchar",
    "entronco": "entroncar",
    "entroncou": "entroncar",
    "entroncá": "entroncar",
    "entroncámo": "entroncar",
    "entroncámos": "entroncar",
    "entroncáramo": "entroncar",
    "entroncáramos": "entroncar",
    "entroncárei": "entroncar",
    "entroncáreis": "entroncar",
    "entroncásseis": "entroncar",
    "entroncássemos": "entroncar",
    "entroncávamo": "entroncar",
    "entroncávamos": "entroncar",
    "entroncávei": "entroncar",
    "entroncáveis": "entroncar",
    "entroniza": "entronizar",
    "entronizada": "entronizar",
    "entronizadas": "entronizar",
    "entronizado": "entronizar",
    "entronizados": "entronizar",
    "entronizai": "entronizar",
    "entronizais": "entronizar",
    "entronizam": "entronizar",
    "entronizamentos": "entronizamento",
    "entronizamo": "entronizar",
    "entronizamos": "entronizar",
    "entronizando": "entronizar",
    "entronizara": "entronizar",
    "entronizaram": "entronizar",
    "entronizaras": "entronizar",
    "entronizarde": "entronizar",
    "entronizardes": "entronizar",
    "entronizare": "entronizar",
    "entronizarei": "entronizar",
    "entronizareis": "entronizar",
    "entronizarem": "entronizar",
    "entronizaremos": "entronizar",
    "entronizares": "entronizar",
    "entronizaria": "entronizar",
    "entronizariam": "entronizar",
    "entronizarias": "entronizar",
    "entronizarmo": "entronizar",
    "entronizarmos": "entronizar",
    "entronizará": "entronizar",
    "entronizarás": "entronizar",
    "entronizarão": "entronizar",
    "entronizaríamos": "entronizar",
    "entronizaríeis": "entronizar",
    "entronizas": "entronizar",
    "entronizasse": "entronizar",
    "entronizassem": "entronizar",
    "entronizasses": "entronizar",
    "entronizaste": "entronizar",
    "entronizastes": "entronizar",
    "entronizava": "entronizar",
    "entronizavam": "entronizar",
    "entronizavas": "entronizar",
    "entronizações": "entronização",
    "entronize": "entronizar",
    "entronizei": "entronizar",
    "entronizeis": "entronizar",
    "entronizem": "entronizar",
    "entronizemo": "entronizar",
    "entronizemos": "entronizar",
    "entronizes": "entronizar",
    "entronizo": "entronizar",
    "entronizou": "entronizar",
    "entronizá": "entronizar",
    "entronizámo": "entronizar",
    "entronizámos": "entronizar",
    "entronizáramo": "entronizar",
    "entronizáramos": "entronizar",
    "entronizárei": "entronizar",
    "entronizáreis": "entronizar",
    "entronizásseis": "entronizar",
    "entronizássemos": "entronizar",
    "entronizávamo": "entronizar",
    "entronizávamos": "entronizar",
    "entronizávei": "entronizar",
    "entronizáveis": "entronizar",
    "entronque": "entroncar",
    "entronquece": "entronquecer",
    "entronquecei": "entronquecer",
    "entronqueceis": "entronquecer",
    "entronquecem": "entronquecer",
    "entronquecemo": "entronquecer",
    "entronquecemos": "entronquecer",
    "entronquecendo": "entronquecer",
    "entronquecera": "entronquecer",
    "entronqueceram": "entronquecer",
    "entronqueceras": "entronquecer",
    "entronquecerdes": "entronquecer",
    "entronquecerei": "entronquecer",
    "entronquecereis": "entronquecer",
    "entronquecerem": "entronquecer",
    "entronqueceremos": "entronquecer",
    "entronqueceres": "entronquecer",
    "entronqueceria": "entronquecer",
    "entronqueceriam": "entronquecer",
    "entronquecerias": "entronquecer",
    "entronquecermo": "entronquecer",
    "entronquecermos": "entronquecer",
    "entronquecerá": "entronquecer",
    "entronquecerás": "entronquecer",
    "entronquecerão": "entronquecer",
    "entronqueceríamos": "entronquecer",
    "entronqueceríeis": "entronquecer",
    "entronqueces": "entronquecer",
    "entronquecesse": "entronquecer",
    "entronquecessem": "entronquecer",
    "entronquecesses": "entronquecer",
    "entronqueceste": "entronquecer",
    "entronquecestes": "entronquecer",
    "entronqueceu": "entronquecer",
    "entronqueci": "entronquecer",
    "entronquecia": "entronquecer",
    "entronqueciam": "entronquecer",
    "entronquecias": "entronquecer",
    "entronquecida": "entronquecer",
    "entronquecidas": "entronquecer",
    "entronquecido": "entronquecer",
    "entronquecidos": "entronquecer",
    "entronquecêramo": "entronquecer",
    "entronquecêramos": "entronquecer",
    "entronquecêreis": "entronquecer",
    "entronquecêsseis": "entronquecer",
    "entronquecêssemos": "entronquecer",
    "entronquecíamo": "entronquecer",
    "entronquecíamos": "entronquecer",
    "entronquecíeis": "entronquecer",
    "entronquei": "entroncar",
    "entronqueis": "entroncar",
    "entronquem": "entroncar",
    "entronquemo": "entroncar",
    "entronquemos": "entroncar",
    "entronques": "entroncar",
    "entronqueça": "entronquecer",
    "entronqueçais": "entronquecer",
    "entronqueçam": "entronquecer",
    "entronqueçamo": "entronquecer",
    "entronqueçamos": "entronquecer",
    "entronqueças": "entronquecer",
    "entronqueço": "entronquecer",
    "entropece": "entropeçar",
    "entropecei": "entropeçar",
    "entropeceis": "entropeçar",
    "entropecem": "entropeçar",
    "entropecemo": "entropeçar",
    "entropecemos": "entropeçar",
    "entropeces": "entropeçar",
    "entropeça": "entropeçar",
    "entropeçada": "entropeçar",
    "entropeçadas": "entropeçar",
    "entropeçado": "entropeçar",
    "entropeçados": "entropeçar",
    "entropeçai": "entropeçar",
    "entropeçais": "entropeçar",
    "entropeçam": "entropeçar",
    "entropeçamo": "entropeçar",
    "entropeçamos": "entropeçar",
    "entropeçando": "entropeçar",
    "entropeçara": "entropeçar",
    "entropeçaram": "entropeçar",
    "entropeçaras": "entropeçar",
    "entropeçardes": "entropeçar",
    "entropeçarei": "entropeçar",
    "entropeçareis": "entropeçar",
    "entropeçarem": "entropeçar",
    "entropeçaremos": "entropeçar",
    "entropeçares": "entropeçar",
    "entropeçaria": "entropeçar",
    "entropeçariam": "entropeçar",
    "entropeçarias": "entropeçar",
    "entropeçarmo": "entropeçar",
    "entropeçarmos": "entropeçar",
    "entropeçará": "entropeçar",
    "entropeçarás": "entropeçar",
    "entropeçarão": "entropeçar",
    "entropeçaríamos": "entropeçar",
    "entropeçaríeis": "entropeçar",
    "entropeças": "entropeçar",
    "entropeçasse": "entropeçar",
    "entropeçassem": "entropeçar",
    "entropeçasses": "entropeçar",
    "entropeçaste": "entropeçar",
    "entropeçastes": "entropeçar",
    "entropeçava": "entropeçar",
    "entropeçavam": "entropeçar",
    "entropeçavas": "entropeçar",
    "entropeço": "entropeçar",
    "entropeços": "entropeço",
    "entropeçou": "entropeçar",
    "entropeçámo": "entropeçar",
    "entropeçámos": "entropeçar",
    "entropeçáramo": "entropeçar",
    "entropeçáramos": "entropeçar",
    "entropeçáreis": "entropeçar",
    "entropeçásseis": "entropeçar",
    "entropeçássemos": "entropeçar",
    "entropeçávamo": "entropeçar",
    "entropeçávamos": "entropeçar",
    "entropeçáveis": "entropeçar",
    "entropias": "entropia",
    "entrosa": "entrosar",
    "entrosada": "entrosar",
    "entrosadas": "entrosar",
    "entrosado": "entrosar",
    "entrosados": "entrosar",
    "entrosagens": "entrosagem",
    "entrosai": "entrosar",
    "entrosais": "entrosar",
    "entrosam": "entrosar",
    "entrosamentos": "entrosamento",
    "entrosamo": "entrosar",
    "entrosamos": "entrosar",
    "entrosando": "entrosar",
    "entrosara": "entrosar",
    "entrosaram": "entrosar",
    "entrosaras": "entrosar",
    "entrosarde": "entrosar",
    "entrosardes": "entrosar",
    "entrosare": "entrosar",
    "entrosarei": "entrosar",
    "entrosareis": "entrosar",
    "entrosarem": "entrosar",
    "entrosaremos": "entrosar",
    "entrosares": "entrosar",
    "entrosaria": "entrosar",
    "entrosariam": "entrosar",
    "entrosarias": "entrosar",
    "entrosarmo": "entrosar",
    "entrosarmos": "entrosar",
    "entrosará": "entrosar",
    "entrosarás": "entrosar",
    "entrosarão": "entrosar",
    "entrosaríamos": "entrosar",
    "entrosaríeis": "entrosar",
    "entrosas": "entrosar",
    "entrosasse": "entrosar",
    "entrosassem": "entrosar",
    "entrosasses": "entrosar",
    "entrosaste": "entrosar",
    "entrosastes": "entrosar",
    "entrosava": "entrosar",
    "entrosavam": "entrosar",
    "entrosavas": "entrosar",
    "entrose": "entrosar",
    "entrosei": "entrosar",
    "entroseis": "entrosar",
    "entrosem": "entrosar",
    "entrosemo": "entrosar",
    "entrosemos": "entrosar",
    "entroses": "entrosar",
    "entroso": "entrosar",
    "entrosou": "entrosar",
    "entrosá": "entrosar",
    "entrosámo": "entrosar",
    "entrosámos": "entrosar",
    "entrosáramo": "entrosar",
    "entrosáramos": "entrosar",
    "entrosárei": "entrosar",
    "entrosáreis": "entrosar",
    "entrosásseis": "entrosar",
    "entrosássemos": "entrosar",
    "entrosávamo": "entrosar",
    "entrosávamos": "entrosar",
    "entrosávei": "entrosar",
    "entrosáveis": "entrosar",
    "entrou": "entrar",
    "entrouxa": "entrouxar",
    "entrouxada": "entrouxar",
    "entrouxadas": "entrouxar",
    "entrouxado": "entrouxar",
    "entrouxados": "entrouxar",
    "entrouxai": "entrouxar",
    "entrouxais": "entrouxar",
    "entrouxam": "entrouxar",
    "entrouxamo": "entrouxar",
    "entrouxamos": "entrouxar",
    "entrouxando": "entrouxar",
    "entrouxara": "entrouxar",
    "entrouxaram": "entrouxar",
    "entrouxaras": "entrouxar",
    "entrouxarde": "entrouxar",
    "entrouxardes": "entrouxar",
    "entrouxare": "entrouxar",
    "entrouxarei": "entrouxar",
    "entrouxareis": "entrouxar",
    "entrouxarem": "entrouxar",
    "entrouxaremos": "entrouxar",
    "entrouxares": "entrouxar",
    "entrouxaria": "entrouxar",
    "entrouxariam": "entrouxar",
    "entrouxarias": "entrouxar",
    "entrouxarmo": "entrouxar",
    "entrouxarmos": "entrouxar",
    "entrouxará": "entrouxar",
    "entrouxarás": "entrouxar",
    "entrouxarão": "entrouxar",
    "entrouxaríamos": "entrouxar",
    "entrouxaríeis": "entrouxar",
    "entrouxas": "entrouxar",
    "entrouxasse": "entrouxar",
    "entrouxassem": "entrouxar",
    "entrouxasses": "entrouxar",
    "entrouxaste": "entrouxar",
    "entrouxastes": "entrouxar",
    "entrouxava": "entrouxar",
    "entrouxavam": "entrouxar",
    "entrouxavas": "entrouxar",
    "entrouxe": "entrouxar",
    "entrouxei": "entrouxar",
    "entrouxeis": "entrouxar",
    "entrouxem": "entrouxar",
    "entrouxemo": "entrouxar",
    "entrouxemos": "entrouxar",
    "entrouxes": "entrouxar",
    "entrouxo": "entrouxar",
    "entrouxos": "entrouxo",
    "entrouxou": "entrouxar",
    "entrouxá": "entrouxar",
    "entrouxámo": "entrouxar",
    "entrouxámos": "entrouxar",
    "entrouxáramo": "entrouxar",
    "entrouxáramos": "entrouxar",
    "entrouxárei": "entrouxar",
    "entrouxáreis": "entrouxar",
    "entrouxásseis": "entrouxar",
    "entrouxássemos": "entrouxar",
    "entrouxávamo": "entrouxar",
    "entrouxávamos": "entrouxar",
    "entrouxávei": "entrouxar",
    "entrouxáveis": "entrouxar",
    "entrovisca": "entroviscar",
    "entroviscada": "entroviscar",
    "entroviscadas": "entroviscar",
    "entroviscado": "entroviscar",
    "entroviscados": "entroviscar",
    "entroviscai": "entroviscar",
    "entroviscais": "entroviscar",
    "entroviscam": "entroviscar",
    "entroviscamo": "entroviscar",
    "entroviscamos": "entroviscar",
    "entroviscando": "entroviscar",
    "entroviscara": "entroviscar",
    "entroviscaram": "entroviscar",
    "entroviscaras": "entroviscar",
    "entroviscarde": "entroviscar",
    "entroviscardes": "entroviscar",
    "entroviscare": "entroviscar",
    "entroviscarei": "entroviscar",
    "entroviscareis": "entroviscar",
    "entroviscarem": "entroviscar",
    "entroviscaremos": "entroviscar",
    "entroviscares": "entroviscar",
    "entroviscaria": "entroviscar",
    "entroviscariam": "entroviscar",
    "entroviscarias": "entroviscar",
    "entroviscarmo": "entroviscar",
    "entroviscarmos": "entroviscar",
    "entroviscará": "entroviscar",
    "entroviscarás": "entroviscar",
    "entroviscarão": "entroviscar",
    "entroviscaríamos": "entroviscar",
    "entroviscaríeis": "entroviscar",
    "entroviscas": "entroviscar",
    "entroviscasse": "entroviscar",
    "entroviscassem": "entroviscar",
    "entroviscasses": "entroviscar",
    "entroviscaste": "entroviscar",
    "entroviscastes": "entroviscar",
    "entroviscava": "entroviscar",
    "entroviscavam": "entroviscar",
    "entroviscavas": "entroviscar",
    "entrovisco": "entroviscar",
    "entroviscou": "entroviscar",
    "entroviscá": "entroviscar",
    "entroviscámo": "entroviscar",
    "entroviscámos": "entroviscar",
    "entroviscáramo": "entroviscar",
    "entroviscáramos": "entroviscar",
    "entroviscárei": "entroviscar",
    "entroviscáreis": "entroviscar",
    "entroviscásseis": "entroviscar",
    "entroviscássemos": "entroviscar",
    "entroviscávamo": "entroviscar",
    "entroviscávamos": "entroviscar",
    "entroviscávei": "entroviscar",
    "entroviscáveis": "entroviscar",
    "entrovisque": "entroviscar",
    "entrovisquei": "entroviscar",
    "entrovisqueis": "entroviscar",
    "entrovisquem": "entroviscar",
    "entrovisquemo": "entroviscar",
    "entrovisquemos": "entroviscar",
    "entrovisques": "entroviscar",
    "entruda": "entrudar",
    "entrudada": "entrudar",
    "entrudadas": "entrudar",
    "entrudado": "entrudar",
    "entrudados": "entrudar",
    "entrudai": "entrudar",
    "entrudais": "entrudar",
    "entrudam": "entrudar",
    "entrudamo": "entrudar",
    "entrudamos": "entrudar",
    "entrudando": "entrudar",
    "entrudara": "entrudar",
    "entrudaram": "entrudar",
    "entrudaras": "entrudar",
    "entrudarde": "entrudar",
    "entrudardes": "entrudar",
    "entrudare": "entrudar",
    "entrudarei": "entrudar",
    "entrudareis": "entrudar",
    "entrudarem": "entrudar",
    "entrudaremos": "entrudar",
    "entrudares": "entrudar",
    "entrudaria": "entrudar",
    "entrudariam": "entrudar",
    "entrudarias": "entrudar",
    "entrudarmo": "entrudar",
    "entrudarmos": "entrudar",
    "entrudará": "entrudar",
    "entrudarás": "entrudar",
    "entrudarão": "entrudar",
    "entrudaríamos": "entrudar",
    "entrudaríeis": "entrudar",
    "entrudas": "entrudar",
    "entrudasse": "entrudar",
    "entrudassem": "entrudar",
    "entrudasses": "entrudar",
    "entrudaste": "entrudar",
    "entrudastes": "entrudar",
    "entrudava": "entrudar",
    "entrudavam": "entrudar",
    "entrudavas": "entrudar",
    "entrude": "entrudar",
    "entrudei": "entrudar",
    "entrudeira": "entrudeiro",
    "entrudeiras": "entrudeiro",
    "entrudeiros": "entrudeiro",
    "entrudeis": "entrudar",
    "entrudem": "entrudar",
    "entrudemo": "entrudar",
    "entrudemos": "entrudar",
    "entrudes": "entrudar",
    "entrudesca": "entrudesco",
    "entrudescas": "entrudesco",
    "entrudescos": "entrudesco",
    "entrudo": "entrudar",
    "entrudos": "entrudo",
    "entrudou": "entrudar",
    "entrudá": "entrudar",
    "entrudámo": "entrudar",
    "entrudámos": "entrudar",
    "entrudáramo": "entrudar",
    "entrudáramos": "entrudar",
    "entrudárei": "entrudar",
    "entrudáreis": "entrudar",
    "entrudásseis": "entrudar",
    "entrudássemos": "entrudar",
    "entrudávamo": "entrudar",
    "entrudávamos": "entrudar",
    "entrudávei": "entrudar",
    "entrudáveis": "entrudar",
    "entrámo": "entrar",
    "entrámos": "entrar",
    "entráramo": "entrar",
    "entráramos": "entrar",
    "entráreis": "entrar",
    "entrásseis": "entrar",
    "entrássemos": "entrar",
    "entrávamo": "entrar",
    "entrávamos": "entrar",
    "entráveis": "entrar",
    "entrópica": "entrópico",
    "entrópicas": "entrópico",
    "entrópicos": "entrópico",
    "entuba": "entubar",
    "entubada": "entubar",
    "entubadas": "entubar",
    "entubado": "entubar",
    "entubados": "entubar",
    "entubai": "entubar",
    "entubais": "entubar",
    "entubam": "entubar",
    "entubamo": "entubar",
    "entubamos": "entubar",
    "entubando": "entubar",
    "entubara": "entubar",
    "entubaram": "entubar",
    "entubaras": "entubar",
    "entubarde": "entubar",
    "entubardes": "entubar",
    "entubare": "entubar",
    "entubarei": "entubar",
    "entubareis": "entubar",
    "entubarem": "entubar",
    "entubaremos": "entubar",
    "entubares": "entubar",
    "entubaria": "entubar",
    "entubariam": "entubar",
    "entubarias": "entubar",
    "entubarmo": "entubar",
    "entubarmos": "entubar",
    "entubará": "entubar",
    "entubarás": "entubar",
    "entubarão": "entubar",
    "entubaríamos": "entubar",
    "entubaríeis": "entubar",
    "entubas": "entubar",
    "entubasse": "entubar",
    "entubassem": "entubar",
    "entubasses": "entubar",
    "entubaste": "entubar",
    "entubastes": "entubar",
    "entubava": "entubar",
    "entubavam": "entubar",
    "entubavas": "entubar",
    "entube": "entubar",
    "entubei": "entubar",
    "entubeis": "entubar",
    "entubem": "entubar",
    "entubemo": "entubar",
    "entubemos": "entubar",
    "entubes": "entubar",
    "entubo": "entubar",
    "entubou": "entubar",
    "entubá": "entubar",
    "entubámo": "entubar",
    "entubámos": "entubar",
    "entubáramo": "entubar",
    "entubáramos": "entubar",
    "entubárei": "entubar",
    "entubáreis": "entubar",
    "entubásseis": "entubar",
    "entubássemos": "entubar",
    "entubávamo": "entubar",
    "entubávamos": "entubar",
    "entubávei": "entubar",
    "entubáveis": "entubar",
    "entucha": "entuchar",
    "entuchada": "entuchar",
    "entuchadas": "entuchar",
    "entuchado": "entuchar",
    "entuchados": "entuchar",
    "entuchai": "entuchar",
    "entuchais": "entuchar",
    "entucham": "entuchar",
    "entuchamo": "entuchar",
    "entuchamos": "entuchar",
    "entuchando": "entuchar",
    "entuchara": "entuchar",
    "entucharam": "entuchar",
    "entucharas": "entuchar",
    "entucharde": "entuchar",
    "entuchardes": "entuchar",
    "entuchare": "entuchar",
    "entucharei": "entuchar",
    "entuchareis": "entuchar",
    "entucharem": "entuchar",
    "entucharemos": "entuchar",
    "entuchares": "entuchar",
    "entucharia": "entuchar",
    "entuchariam": "entuchar",
    "entucharias": "entuchar",
    "entucharmo": "entuchar",
    "entucharmos": "entuchar",
    "entuchará": "entuchar",
    "entucharás": "entuchar",
    "entucharão": "entuchar",
    "entucharíamos": "entuchar",
    "entucharíeis": "entuchar",
    "entuchas": "entuchar",
    "entuchasse": "entuchar",
    "entuchassem": "entuchar",
    "entuchasses": "entuchar",
    "entuchaste": "entuchar",
    "entuchastes": "entuchar",
    "entuchava": "entuchar",
    "entuchavam": "entuchar",
    "entuchavas": "entuchar",
    "entuche": "entuchar",
    "entuchei": "entuchar",
    "entucheis": "entuchar",
    "entuchem": "entuchar",
    "entuchemo": "entuchar",
    "entuchemos": "entuchar",
    "entuches": "entuchar",
    "entucho": "entuchar",
    "entuchou": "entuchar",
    "entuchá": "entuchar",
    "entuchámo": "entuchar",
    "entuchámos": "entuchar",
    "entucháramo": "entuchar",
    "entucháramos": "entuchar",
    "entuchárei": "entuchar",
    "entucháreis": "entuchar",
    "entuchásseis": "entuchar",
    "entuchássemos": "entuchar",
    "entuchávamo": "entuchar",
    "entuchávamos": "entuchar",
    "entuchávei": "entuchar",
    "entucháveis": "entuchar",
    "entufa": "entufar",
    "entufada": "entufar",
    "entufadas": "entufar",
    "entufado": "entufar",
    "entufados": "entufar",
    "entufai": "entufar",
    "entufais": "entufar",
    "entufam": "entufar",
    "entufamo": "entufar",
    "entufamos": "entufar",
    "entufando": "entufar",
    "entufara": "entufar",
    "entufaram": "entufar",
    "entufaras": "entufar",
    "entufarde": "entufar",
    "entufardes": "entufar",
    "entufare": "entufar",
    "entufarei": "entufar",
    "entufareis": "entufar",
    "entufarem": "entufar",
    "entufaremos": "entufar",
    "entufares": "entufar",
    "entufaria": "entufar",
    "entufariam": "entufar",
    "entufarias": "entufar",
    "entufarmo": "entufar",
    "entufarmos": "entufar",
    "entufará": "entufar",
    "entufarás": "entufar",
    "entufarão": "entufar",
    "entufaríamos": "entufar",
    "entufaríeis": "entufar",
    "entufas": "entufar",
    "entufasse": "entufar",
    "entufassem": "entufar",
    "entufasses": "entufar",
    "entufaste": "entufar",
    "entufastes": "entufar",
    "entufava": "entufar",
    "entufavam": "entufar",
    "entufavas": "entufar",
    "entufe": "entufar",
    "entufei": "entufar",
    "entufeis": "entufar",
    "entufem": "entufar",
    "entufemo": "entufar",
    "entufemos": "entufar",
    "entufes": "entufar",
    "entufo": "entufar",
    "entufou": "entufar",
    "entufá": "entufar",
    "entufámo": "entufar",
    "entufámos": "entufar",
    "entufáramo": "entufar",
    "entufáramos": "entufar",
    "entufárei": "entufar",
    "entufáreis": "entufar",
    "entufásseis": "entufar",
    "entufássemos": "entufar",
    "entufávamo": "entufar",
    "entufávamos": "entufar",
    "entufávei": "entufar",
    "entufáveis": "entufar",
    "entulha": "entulhar",
    "entulhada": "entulhar",
    "entulhadas": "entulhar",
    "entulhado": "entulhar",
    "entulhados": "entulhar",
    "entulhai": "entulhar",
    "entulhais": "entulhar",
    "entulham": "entulhar",
    "entulhamo": "entulhar",
    "entulhamos": "entulhar",
    "entulhando": "entulhar",
    "entulhara": "entulhar",
    "entulharam": "entulhar",
    "entulharas": "entulhar",
    "entulharde": "entulhar",
    "entulhardes": "entulhar",
    "entulhare": "entulhar",
    "entulharei": "entulhar",
    "entulhareis": "entulhar",
    "entulharem": "entulhar",
    "entulharemos": "entulhar",
    "entulhares": "entulhar",
    "entulharia": "entulhar",
    "entulhariam": "entulhar",
    "entulharias": "entulhar",
    "entulharmo": "entulhar",
    "entulharmos": "entulhar",
    "entulhará": "entulhar",
    "entulharás": "entulhar",
    "entulharão": "entulhar",
    "entulharíamos": "entulhar",
    "entulharíeis": "entulhar",
    "entulhas": "entulhar",
    "entulhasse": "entulhar",
    "entulhassem": "entulhar",
    "entulhasses": "entulhar",
    "entulhaste": "entulhar",
    "entulhastes": "entulhar",
    "entulhava": "entulhar",
    "entulhavam": "entulhar",
    "entulhavas": "entulhar",
    "entulhe": "entulhar",
    "entulhei": "entulhar",
    "entulheis": "entulhar",
    "entulhem": "entulhar",
    "entulhemo": "entulhar",
    "entulhemos": "entulhar",
    "entulhes": "entulhar",
    "entulho": "entulhar",
    "entulhos": "entulho",
    "entulhou": "entulhar",
    "entulhá": "entulhar",
    "entulhámo": "entulhar",
    "entulhámos": "entulhar",
    "entulháramo": "entulhar",
    "entulháramos": "entulhar",
    "entulhárei": "entulhar",
    "entulháreis": "entulhar",
    "entulhásseis": "entulhar",
    "entulhássemos": "entulhar",
    "entulhávamo": "entulhar",
    "entulhávamos": "entulhar",
    "entulhávei": "entulhar",
    "entulháveis": "entulhar",
    "entumece": "entumecer",
    "entumecei": "entumecer",
    "entumeceis": "entumecer",
    "entumecem": "entumecer",
    "entumecemo": "entumecer",
    "entumecemos": "entumecer",
    "entumecendo": "entumecer",
    "entumecentes": "entumecente",
    "entumecera": "entumecer",
    "entumeceram": "entumecer",
    "entumeceras": "entumecer",
    "entumecerde": "entumecer",
    "entumecerdes": "entumecer",
    "entumecere": "entumecer",
    "entumecerei": "entumecer",
    "entumecereis": "entumecer",
    "entumecerem": "entumecer",
    "entumeceremos": "entumecer",
    "entumeceres": "entumecer",
    "entumeceria": "entumecer",
    "entumeceriam": "entumecer",
    "entumecerias": "entumecer",
    "entumecermo": "entumecer",
    "entumecermos": "entumecer",
    "entumecerá": "entumecer",
    "entumecerás": "entumecer",
    "entumecerão": "entumecer",
    "entumeceríamos": "entumecer",
    "entumeceríeis": "entumecer",
    "entumeces": "entumecer",
    "entumecesse": "entumecer",
    "entumecessem": "entumecer",
    "entumecesses": "entumecer",
    "entumeceste": "entumecer",
    "entumecestes": "entumecer",
    "entumeceu": "entumecer",
    "entumeci": "entumecer",
    "entumecia": "entumecer",
    "entumeciam": "entumecer",
    "entumecias": "entumecer",
    "entumecida": "entumecido",
    "entumecidas": "entumecido",
    "entumecido": "entumecer",
    "entumecidos": "entumecido",
    "entumecimentos": "entumecimento",
    "entumecê": "entumecer",
    "entumecências": "entumecência",
    "entumecêramo": "entumecer",
    "entumecêramos": "entumecer",
    "entumecêrei": "entumecer",
    "entumecêreis": "entumecer",
    "entumecêsseis": "entumecer",
    "entumecêssemos": "entumecer",
    "entumecíamo": "entumecer",
    "entumecíamos": "entumecer",
    "entumecíei": "entumecer",
    "entumecíeis": "entumecer",
    "entumeça": "entumecer",
    "entumeçais": "entumecer",
    "entumeçam": "entumecer",
    "entumeçamo": "entumecer",
    "entumeçamos": "entumecer",
    "entumeças": "entumecer",
    "entumeço": "entumecer",
    "entunicada": "entunicado",
    "entunicadas": "entunicado",
    "entunicados": "entunicado",
    "entupa": "entupir",
    "entupais": "entupir",
    "entupam": "entupir",
    "entupamo": "entupir",
    "entupamos": "entupir",
    "entupas": "entupir",
    "entupe": "entupir",
    "entupem": "entupir",
    "entupes": "entupir",
    "entupi": "entupir",
    "entupia": "entupir",
    "entupiam": "entupir",
    "entupias": "entupir",
    "entupida": "entupir",
    "entupidas": "entupir",
    "entupido": "entupir",
    "entupidos": "entupir",
    "entupidíssima": "entupido",
    "entupidíssimas": "entupido",
    "entupidíssimo": "entupido",
    "entupidíssimos": "entupido",
    "entupimentos": "entupimento",
    "entupimo": "entupir",
    "entupimos": "entupir",
    "entupindo": "entupir",
    "entupira": "entupir",
    "entupiram": "entupir",
    "entupiras": "entupir",
    "entupirde": "entupir",
    "entupirdes": "entupir",
    "entupire": "entupir",
    "entupirei": "entupir",
    "entupireis": "entupir",
    "entupirem": "entupir",
    "entupiremos": "entupir",
    "entupires": "entupir",
    "entupiria": "entupir",
    "entupiriam": "entupir",
    "entupirias": "entupir",
    "entupirmo": "entupir",
    "entupirmos": "entupir",
    "entupirá": "entupir",
    "entupirás": "entupir",
    "entupirão": "entupir",
    "entupiríamos": "entupir",
    "entupiríeis": "entupir",
    "entupis": "entupir",
    "entupisse": "entupir",
    "entupissem": "entupir",
    "entupisses": "entupir",
    "entupiste": "entupir",
    "entupistes": "entupir",
    "entupiu": "entupir",
    "entupo": "entupir",
    "entupíamo": "entupir",
    "entupíamos": "entupir",
    "entupíei": "entupir",
    "entupíeis": "entupir",
    "entupíramo": "entupir",
    "entupíramos": "entupir",
    "entupírei": "entupir",
    "entupíreis": "entupir",
    "entupísseis": "entupir",
    "entupíssemos": "entupir",
    "enturva": "enturvar",
    "enturvada": "enturvar",
    "enturvadas": "enturvar",
    "enturvado": "enturvar",
    "enturvados": "enturvar",
    "enturvai": "enturvar",
    "enturvais": "enturvar",
    "enturvam": "enturvar",
    "enturvamo": "enturvar",
    "enturvamos": "enturvar",
    "enturvando": "enturvar",
    "enturvara": "enturvar",
    "enturvaram": "enturvar",
    "enturvaras": "enturvar",
    "enturvarde": "enturvar",
    "enturvardes": "enturvar",
    "enturvare": "enturvar",
    "enturvarei": "enturvar",
    "enturvareis": "enturvar",
    "enturvarem": "enturvar",
    "enturvaremos": "enturvar",
    "enturvares": "enturvar",
    "enturvaria": "enturvar",
    "enturvariam": "enturvar",
    "enturvarias": "enturvar",
    "enturvarmo": "enturvar",
    "enturvarmos": "enturvar",
    "enturvará": "enturvar",
    "enturvarás": "enturvar",
    "enturvarão": "enturvar",
    "enturvaríamos": "enturvar",
    "enturvaríeis": "enturvar",
    "enturvas": "enturvar",
    "enturvasse": "enturvar",
    "enturvassem": "enturvar",
    "enturvasses": "enturvar",
    "enturvaste": "enturvar",
    "enturvastes": "enturvar",
    "enturvava": "enturvar",
    "enturvavam": "enturvar",
    "enturvavas": "enturvar",
    "enturvações": "enturvação",
    "enturve": "enturvar",
    "enturvece": "enturvecer",
    "enturvecei": "enturvecer",
    "enturveceis": "enturvecer",
    "enturvecem": "enturvecer",
    "enturvecemo": "enturvecer",
    "enturvecemos": "enturvecer",
    "enturvecendo": "enturvecer",
    "enturvecera": "enturvecer",
    "enturveceram": "enturvecer",
    "enturveceras": "enturvecer",
    "enturvecerde": "enturvecer",
    "enturvecerdes": "enturvecer",
    "enturvecere": "enturvecer",
    "enturvecerei": "enturvecer",
    "enturvecereis": "enturvecer",
    "enturvecerem": "enturvecer",
    "enturveceremos": "enturvecer",
    "enturveceres": "enturvecer",
    "enturveceria": "enturvecer",
    "enturveceriam": "enturvecer",
    "enturvecerias": "enturvecer",
    "enturvecermo": "enturvecer",
    "enturvecermos": "enturvecer",
    "enturvecerá": "enturvecer",
    "enturvecerás": "enturvecer",
    "enturvecerão": "enturvecer",
    "enturveceríamos": "enturvecer",
    "enturveceríeis": "enturvecer",
    "enturveces": "enturvecer",
    "enturvecesse": "enturvecer",
    "enturvecessem": "enturvecer",
    "enturvecesses": "enturvecer",
    "enturveceste": "enturvecer",
    "enturvecestes": "enturvecer",
    "enturveceu": "enturvecer",
    "enturveci": "enturvecer",
    "enturvecia": "enturvecer",
    "enturveciam": "enturvecer",
    "enturvecias": "enturvecer",
    "enturvecida": "enturvecido",
    "enturvecidas": "enturvecido",
    "enturvecido": "enturvecer",
    "enturvecidos": "enturvecido",
    "enturvecê": "enturvecer",
    "enturvecêramo": "enturvecer",
    "enturvecêramos": "enturvecer",
    "enturvecêrei": "enturvecer",
    "enturvecêreis": "enturvecer",
    "enturvecêsseis": "enturvecer",
    "enturvecêssemos": "enturvecer",
    "enturvecíamo": "enturvecer",
    "enturvecíamos": "enturvecer",
    "enturvecíei": "enturvecer",
    "enturvecíeis": "enturvecer",
    "enturvei": "enturvar",
    "enturveis": "enturvar",
    "enturvem": "enturvar",
    "enturvemo": "enturvar",
    "enturvemos": "enturvar",
    "enturves": "enturvar",
    "enturveça": "enturvecer",
    "enturveçais": "enturvecer",
    "enturveçam": "enturvecer",
    "enturveçamo": "enturvecer",
    "enturveçamos": "enturvecer",
    "enturveças": "enturvecer",
    "enturveço": "enturvecer",
    "enturvisca": "enturviscar",
    "enturviscada": "enturviscar",
    "enturviscadas": "enturviscar",
    "enturviscado": "enturviscar",
    "enturviscados": "enturviscar",
    "enturviscais": "enturviscar",
    "enturviscam": "enturviscar",
    "enturviscamo": "enturviscar",
    "enturviscamos": "enturviscar",
    "enturviscando": "enturviscar",
    "enturviscara": "enturviscar",
    "enturviscaram": "enturviscar",
    "enturviscaras": "enturviscar",
    "enturviscardes": "enturviscar",
    "enturviscarei": "enturviscar",
    "enturviscareis": "enturviscar",
    "enturviscarem": "enturviscar",
    "enturviscaremos": "enturviscar",
    "enturviscares": "enturviscar",
    "enturviscaria": "enturviscar",
    "enturviscariam": "enturviscar",
    "enturviscarias": "enturviscar",
    "enturviscarmo": "enturviscar",
    "enturviscarmos": "enturviscar",
    "enturviscará": "enturviscar",
    "enturviscarás": "enturviscar",
    "enturviscarão": "enturviscar",
    "enturviscaríamos": "enturviscar",
    "enturviscaríeis": "enturviscar",
    "enturviscas": "enturviscar",
    "enturviscasse": "enturviscar",
    "enturviscassem": "enturviscar",
    "enturviscasses": "enturviscar",
    "enturviscaste": "enturviscar",
    "enturviscastes": "enturviscar",
    "enturviscava": "enturviscar",
    "enturviscavam": "enturviscar",
    "enturviscavas": "enturviscar",
    "enturvisco": "enturviscar",
    "enturviscou": "enturviscar",
    "enturviscámo": "enturviscar",
    "enturviscámos": "enturviscar",
    "enturviscáramo": "enturviscar",
    "enturviscáramos": "enturviscar",
    "enturviscáreis": "enturviscar",
    "enturviscásseis": "enturviscar",
    "enturviscássemos": "enturviscar",
    "enturviscávamo": "enturviscar",
    "enturviscávamos": "enturviscar",
    "enturviscáveis": "enturviscar",
    "enturvisque": "enturviscar",
    "enturvisquei": "enturviscar",
    "enturvisqueis": "enturviscar",
    "enturvisquem": "enturviscar",
    "enturvisquemos": "enturviscar",
    "enturvisques": "enturviscar",
    "enturvo": "enturvar",
    "enturvou": "enturvar",
    "enturvá": "enturvar",
    "enturvámo": "enturvar",
    "enturvámos": "enturvar",
    "enturváramo": "enturvar",
    "enturváramos": "enturvar",
    "enturvárei": "enturvar",
    "enturváreis": "enturvar",
    "enturvásseis": "enturvar",
    "enturvássemos": "enturvar",
    "enturvávamo": "enturvar",
    "enturvávamos": "enturvar",
    "enturvávei": "enturvar",
    "enturváveis": "enturvar",
    "entusiasma": "entusiasmar",
    "entusiasmada": "entusiasmar",
    "entusiasmadas": "entusiasmar",
    "entusiasmado": "entusiasmar",
    "entusiasmados": "entusiasmar",
    "entusiasmadíssima": "entusiasmado",
    "entusiasmadíssimas": "entusiasmado",
    "entusiasmadíssimo": "entusiasmado",
    "entusiasmadíssimos": "entusiasmado",
    "entusiasmai": "entusiasmar",
    "entusiasmais": "entusiasmar",
    "entusiasmam": "entusiasmar",
    "entusiasmamo": "entusiasmar",
    "entusiasmamos": "entusiasmar",
    "entusiasmando": "entusiasmar",
    "entusiasmantes": "entusiasmante",
    "entusiasmara": "entusiasmar",
    "entusiasmaram": "entusiasmar",
    "entusiasmaras": "entusiasmar",
    "entusiasmarde": "entusiasmar",
    "entusiasmardes": "entusiasmar",
    "entusiasmare": "entusiasmar",
    "entusiasmarei": "entusiasmar",
    "entusiasmareis": "entusiasmar",
    "entusiasmarem": "entusiasmar",
    "entusiasmaremos": "entusiasmar",
    "entusiasmares": "entusiasmar",
    "entusiasmaria": "entusiasmar",
    "entusiasmariam": "entusiasmar",
    "entusiasmarias": "entusiasmar",
    "entusiasmarmo": "entusiasmar",
    "entusiasmarmos": "entusiasmar",
    "entusiasmará": "entusiasmar",
    "entusiasmarás": "entusiasmar",
    "entusiasmarão": "entusiasmar",
    "entusiasmaríamos": "entusiasmar",
    "entusiasmaríeis": "entusiasmar",
    "entusiasmas": "entusiasmar",
    "entusiasmasse": "entusiasmar",
    "entusiasmassem": "entusiasmar",
    "entusiasmasses": "entusiasmar",
    "entusiasmaste": "entusiasmar",
    "entusiasmastes": "entusiasmar",
    "entusiasmava": "entusiasmar",
    "entusiasmavam": "entusiasmar",
    "entusiasmavas": "entusiasmar",
    "entusiasme": "entusiasmar",
    "entusiasmei": "entusiasmar",
    "entusiasmeis": "entusiasmar",
    "entusiasmem": "entusiasmar",
    "entusiasmemo": "entusiasmar",
    "entusiasmemos": "entusiasmar",
    "entusiasmes": "entusiasmar",
    "entusiasmo": "entusiasmar",
    "entusiasmos": "entusiasmo",
    "entusiasmou": "entusiasmar",
    "entusiasmá": "entusiasmar",
    "entusiasmámo": "entusiasmar",
    "entusiasmámos": "entusiasmar",
    "entusiasmáramo": "entusiasmar",
    "entusiasmáramos": "entusiasmar",
    "entusiasmárei": "entusiasmar",
    "entusiasmáreis": "entusiasmar",
    "entusiasmásseis": "entusiasmar",
    "entusiasmássemos": "entusiasmar",
    "entusiasmávamo": "entusiasmar",
    "entusiasmávamos": "entusiasmar",
    "entusiasmávei": "entusiasmar",
    "entusiasmáveis": "entusiasmável",
    "entusiastas": "entusiasta",
    "entusiástica": "entusiástico",
    "entusiásticas": "entusiástico",
    "entusiásticos": "entusiástico",
    "entálpica": "entálpico",
    "entálpicas": "entálpico",
    "entálpicos": "entálpico",
    "entérica": "entérico",
    "entéricas": "entérico",
    "entéricos": "entérico",
    "entófita": "entófito",
    "entófitas": "entófito",
    "entófitos": "entófito",
    "entómica": "entómico",
    "entómicas": "entómico",
    "entómicos": "entómico",
    "entóptica": "entóptico",
    "entópticas": "entóptico",
    "entópticos": "entóptico",
    "entótica": "entótico",
    "entóticas": "entótico",
    "entóticos": "entótico",
    "enubla": "enublar",
    "enublada": "enublar",
    "enubladas": "enublar",
    "enublado": "enublar",
    "enublados": "enublar",
    "enublai": "enublar",
    "enublais": "enublar",
    "enublam": "enublar",
    "enublamo": "enublar",
    "enublamos": "enublar",
    "enublando": "enublar",
    "enublara": "enublar",
    "enublaram": "enublar",
    "enublaras": "enublar",
    "enublarde": "enublar",
    "enublardes": "enublar",
    "enublare": "enublar",
    "enublarei": "enublar",
    "enublareis": "enublar",
    "enublarem": "enublar",
    "enublaremos": "enublar",
    "enublares": "enublar",
    "enublaria": "enublar",
    "enublariam": "enublar",
    "enublarias": "enublar",
    "enublarmo": "enublar",
    "enublarmos": "enublar",
    "enublará": "enublar",
    "enublarás": "enublar",
    "enublarão": "enublar",
    "enublaríamos": "enublar",
    "enublaríeis": "enublar",
    "enublas": "enublar",
    "enublasse": "enublar",
    "enublassem": "enublar",
    "enublasses": "enublar",
    "enublaste": "enublar",
    "enublastes": "enublar",
    "enublava": "enublar",
    "enublavam": "enublar",
    "enublavas": "enublar",
    "enublações": "enublação",
    "enuble": "enublar",
    "enublei": "enublar",
    "enubleis": "enublar",
    "enublem": "enublar",
    "enublemo": "enublar",
    "enublemos": "enublar",
    "enubles": "enublar",
    "enublo": "enublar",
    "enublou": "enublar",
    "enublá": "enublar",
    "enublámo": "enublar",
    "enublámos": "enublar",
    "enubláramo": "enublar",
    "enubláramos": "enublar",
    "enublárei": "enublar",
    "enubláreis": "enublar",
    "enublásseis": "enublar",
    "enublássemos": "enublar",
    "enublávamo": "enublar",
    "enublávamos": "enublar",
    "enublávei": "enublar",
    "enubláveis": "enublar",
    "enucleada": "enuclear",
    "enucleadas": "enuclear",
    "enucleado": "enuclear",
    "enucleados": "enuclear",
    "enucleai": "enuclear",
    "enucleais": "enuclear",
    "enucleamo": "enuclear",
    "enucleamos": "enuclear",
    "enucleando": "enuclear",
    "enucleara": "enuclear",
    "enuclearam": "enuclear",
    "enuclearas": "enuclear",
    "enuclearde": "enuclear",
    "enucleardes": "enuclear",
    "enucleare": "enuclear",
    "enuclearei": "enuclear",
    "enucleareis": "enuclear",
    "enuclearem": "enuclear",
    "enuclearemos": "enuclear",
    "enucleares": "enuclear",
    "enuclearia": "enuclear",
    "enucleariam": "enuclear",
    "enuclearias": "enuclear",
    "enuclearmo": "enuclear",
    "enuclearmos": "enuclear",
    "enucleará": "enuclear",
    "enuclearás": "enuclear",
    "enuclearão": "enuclear",
    "enuclearíamos": "enuclear",
    "enuclearíeis": "enuclear",
    "enucleasse": "enuclear",
    "enucleassem": "enuclear",
    "enucleasses": "enuclear",
    "enucleaste": "enuclear",
    "enucleastes": "enuclear",
    "enucleava": "enuclear",
    "enucleavam": "enuclear",
    "enucleavas": "enuclear",
    "enucleações": "enucleação",
    "enucleei": "enuclear",
    "enucleeis": "enuclear",
    "enucleemo": "enuclear",
    "enucleemos": "enuclear",
    "enucleia": "enuclear",
    "enucleiam": "enuclear",
    "enucleias": "enuclear",
    "enucleie": "enuclear",
    "enucleiem": "enuclear",
    "enucleies": "enuclear",
    "enucleio": "enuclear",
    "enucleou": "enuclear",
    "enucleá": "enuclear",
    "enucleámo": "enuclear",
    "enucleámos": "enuclear",
    "enucleáramo": "enuclear",
    "enucleáramos": "enuclear",
    "enucleárei": "enuclear",
    "enucleáreis": "enuclear",
    "enucleásseis": "enuclear",
    "enucleássemos": "enuclear",
    "enucleávamo": "enuclear",
    "enucleávamos": "enuclear",
    "enucleávei": "enuclear",
    "enucleáveis": "enuclear",
    "enumera": "enumerar",
    "enumerabilidades": "enumerabilidade",
    "enumerada": "enumerar",
    "enumeradas": "enumerar",
    "enumerado": "enumerar",
    "enumeradora": "enumerador",
    "enumeradoras": "enumerador",
    "enumeradores": "enumerador",
    "enumerados": "enumerar",
    "enumerai": "enumerar",
    "enumerais": "enumerar",
    "enumeram": "enumerar",
    "enumeramo": "enumerar",
    "enumeramos": "enumerar",
    "enumerando": "enumerar",
    "enumerara": "enumerar",
    "enumeraram": "enumerar",
    "enumeraras": "enumerar",
    "enumerarde": "enumerar",
    "enumerardes": "enumerar",
    "enumerare": "enumerar",
    "enumerarei": "enumerar",
    "enumerareis": "enumerar",
    "enumerarem": "enumerar",
    "enumeraremos": "enumerar",
    "enumerares": "enumerar",
    "enumeraria": "enumerar",
    "enumerariam": "enumerar",
    "enumerarias": "enumerar",
    "enumerarmo": "enumerar",
    "enumerarmos": "enumerar",
    "enumerará": "enumerar",
    "enumerarás": "enumerar",
    "enumerarão": "enumerar",
    "enumeraríamos": "enumerar",
    "enumeraríeis": "enumerar",
    "enumeras": "enumerar",
    "enumerasse": "enumerar",
    "enumerassem": "enumerar",
    "enumerasses": "enumerar",
    "enumeraste": "enumerar",
    "enumerastes": "enumerar",
    "enumerativa": "enumerativo",
    "enumerativas": "enumerativo",
    "enumerativos": "enumerativo",
    "enumerava": "enumerar",
    "enumeravam": "enumerar",
    "enumeravas": "enumerar",
    "enumerações": "enumeração",
    "enumere": "enumerar",
    "enumerei": "enumerar",
    "enumereis": "enumerar",
    "enumerem": "enumerar",
    "enumeremo": "enumerar",
    "enumeremos": "enumerar",
    "enumeres": "enumerar",
    "enumero": "enumerar",
    "enumerou": "enumerar",
    "enumerá": "enumerar",
    "enumerámo": "enumerar",
    "enumerámos": "enumerar",
    "enumeráramo": "enumerar",
    "enumeráramos": "enumerar",
    "enumerárei": "enumerar",
    "enumeráreis": "enumerar",
    "enumerásseis": "enumerar",
    "enumerássemos": "enumerar",
    "enumerávamo": "enumerar",
    "enumerávamos": "enumerar",
    "enumerávei": "enumerar",
    "enumeráveis": "enumerável",
    "enuncia": "enunciar",
    "enunciada": "enunciar",
    "enunciadas": "enunciar",
    "enunciado": "enunciar",
    "enunciadora": "enunciador",
    "enunciadoras": "enunciador",
    "enunciadores": "enunciador",
    "enunciados": "enunciar",
    "enunciai": "enunciar",
    "enunciais": "enunciar",
    "enunciam": "enunciar",
    "enunciamo": "enunciar",
    "enunciamos": "enunciar",
    "enunciando": "enunciar",
    "enunciara": "enunciar",
    "enunciaram": "enunciar",
    "enunciaras": "enunciar",
    "enunciarde": "enunciar",
    "enunciardes": "enunciar",
    "enunciare": "enunciar",
    "enunciarei": "enunciar",
    "enunciareis": "enunciar",
    "enunciarem": "enunciar",
    "enunciaremos": "enunciar",
    "enunciares": "enunciar",
    "enunciaria": "enunciar",
    "enunciariam": "enunciar",
    "enunciarias": "enunciar",
    "enunciarmo": "enunciar",
    "enunciarmos": "enunciar",
    "enunciará": "enunciar",
    "enunciarás": "enunciar",
    "enunciarão": "enunciar",
    "enunciaríamos": "enunciar",
    "enunciaríeis": "enunciar",
    "enuncias": "enunciar",
    "enunciasse": "enunciar",
    "enunciassem": "enunciar",
    "enunciasses": "enunciar",
    "enunciaste": "enunciar",
    "enunciastes": "enunciar",
    "enunciativa": "enunciativo",
    "enunciativas": "enunciativo",
    "enunciativos": "enunciativo",
    "enunciava": "enunciar",
    "enunciavam": "enunciar",
    "enunciavas": "enunciar",
    "enunciações": "enunciação",
    "enuncie": "enunciar",
    "enunciei": "enunciar",
    "enuncieis": "enunciar",
    "enunciem": "enunciar",
    "enunciemo": "enunciar",
    "enunciemos": "enunciar",
    "enuncies": "enunciar",
    "enuncio": "enunciar",
    "enunciou": "enunciar",
    "enunciá": "enunciar",
    "enunciámo": "enunciar",
    "enunciámos": "enunciar",
    "enunciáramo": "enunciar",
    "enunciáramos": "enunciar",
    "enunciárei": "enunciar",
    "enunciáreis": "enunciar",
    "enunciásseis": "enunciar",
    "enunciássemos": "enunciar",
    "enunciávamo": "enunciar",
    "enunciávamos": "enunciar",
    "enunciávei": "enunciar",
    "enunciáveis": "enunciável",
    "enureses": "enurese",
    "enuresias": "enuresia",
    "enuvia": "enuviar",
    "enuviada": "enuviar",
    "enuviadas": "enuviar",
    "enuviado": "enuviar",
    "enuviados": "enuviar",
    "enuviai": "enuviar",
    "enuviais": "enuviar",
    "enuviam": "enuviar",
    "enuviamo": "enuviar",
    "enuviamos": "enuviar",
    "enuviando": "enuviar",
    "enuviara": "enuviar",
    "enuviaram": "enuviar",
    "enuviaras": "enuviar",
    "enuviarde": "enuviar",
    "enuviardes": "enuviar",
    "enuviare": "enuviar",
    "enuviarei": "enuviar",
    "enuviareis": "enuviar",
    "enuviarem": "enuviar",
    "enuviaremos": "enuviar",
    "enuviares": "enuviar",
    "enuviaria": "enuviar",
    "enuviariam": "enuviar",
    "enuviarias": "enuviar",
    "enuviarmo": "enuviar",
    "enuviarmos": "enuviar",
    "enuviará": "enuviar",
    "enuviarás": "enuviar",
    "enuviarão": "enuviar",
    "enuviaríamos": "enuviar",
    "enuviaríeis": "enuviar",
    "enuvias": "enuviar",
    "enuviasse": "enuviar",
    "enuviassem": "enuviar",
    "enuviasses": "enuviar",
    "enuviaste": "enuviar",
    "enuviastes": "enuviar",
    "enuviava": "enuviar",
    "enuviavam": "enuviar",
    "enuviavas": "enuviar",
    "enuvie": "enuviar",
    "enuviei": "enuviar",
    "enuvieis": "enuviar",
    "enuviem": "enuviar",
    "enuviemo": "enuviar",
    "enuviemos": "enuviar",
    "enuvies": "enuviar",
    "enuvio": "enuviar",
    "enuviou": "enuviar",
    "enuviá": "enuviar",
    "enuviámo": "enuviar",
    "enuviámos": "enuviar",
    "enuviáramo": "enuviar",
    "enuviáramos": "enuviar",
    "enuviárei": "enuviar",
    "enuviáreis": "enuviar",
    "enuviásseis": "enuviar",
    "enuviássemos": "enuviar",
    "enuviávamo": "enuviar",
    "enuviávamos": "enuviar",
    "enuviávei": "enuviar",
    "enuviáveis": "enuviar",
    "envagina": "envaginar",
    "envaginada": "envaginar",
    "envaginadas": "envaginar",
    "envaginado": "envaginar",
    "envaginados": "envaginar",
    "envaginai": "envaginar",
    "envaginais": "envaginar",
    "envaginam": "envaginar",
    "envaginamo": "envaginar",
    "envaginamos": "envaginar",
    "envaginando": "envaginar",
    "envaginantes": "envaginante",
    "envaginara": "envaginar",
    "envaginaram": "envaginar",
    "envaginaras": "envaginar",
    "envaginarde": "envaginar",
    "envaginardes": "envaginar",
    "envaginare": "envaginar",
    "envaginarei": "envaginar",
    "envaginareis": "envaginar",
    "envaginarem": "envaginar",
    "envaginaremos": "envaginar",
    "envaginares": "envaginar",
    "envaginaria": "envaginar",
    "envaginariam": "envaginar",
    "envaginarias": "envaginar",
    "envaginarmo": "envaginar",
    "envaginarmos": "envaginar",
    "envaginará": "envaginar",
    "envaginarás": "envaginar",
    "envaginarão": "envaginar",
    "envaginaríamos": "envaginar",
    "envaginaríeis": "envaginar",
    "envaginas": "envaginar",
    "envaginasse": "envaginar",
    "envaginassem": "envaginar",
    "envaginasses": "envaginar",
    "envaginaste": "envaginar",
    "envaginastes": "envaginar",
    "envaginava": "envaginar",
    "envaginavam": "envaginar",
    "envaginavas": "envaginar",
    "envagine": "envaginar",
    "envaginei": "envaginar",
    "envagineis": "envaginar",
    "envaginem": "envaginar",
    "envaginemo": "envaginar",
    "envaginemos": "envaginar",
    "envagines": "envaginar",
    "envagino": "envaginar",
    "envaginou": "envaginar",
    "envaginá": "envaginar",
    "envaginámo": "envaginar",
    "envaginámos": "envaginar",
    "envagináramo": "envaginar",
    "envagináramos": "envaginar",
    "envaginárei": "envaginar",
    "envagináreis": "envaginar",
    "envaginásseis": "envaginar",
    "envaginássemos": "envaginar",
    "envaginávamo": "envaginar",
    "envaginávamos": "envaginar",
    "envaginávei": "envaginar",
    "envagináveis": "envaginar",
    "envaida": "envaidar",
    "envaidada": "envaidar",
    "envaidadas": "envaidar",
    "envaidado": "envaidar",
    "envaidados": "envaidar",
    "envaidai": "envaidar",
    "envaidais": "envaidar",
    "envaidam": "envaidar",
    "envaidamo": "envaidar",
    "envaidamos": "envaidar",
    "envaidando": "envaidar",
    "envaidara": "envaidar",
    "envaidaram": "envaidar",
    "envaidaras": "envaidar",
    "envaidarde": "envaidar",
    "envaidardes": "envaidar",
    "envaidare": "envaidar",
    "envaidarei": "envaidar",
    "envaidareis": "envaidar",
    "envaidarem": "envaidar",
    "envaidaremos": "envaidar",
    "envaidares": "envaidar",
    "envaidaria": "envaidar",
    "envaidariam": "envaidar",
    "envaidarias": "envaidar",
    "envaidarmo": "envaidar",
    "envaidarmos": "envaidar",
    "envaidará": "envaidar",
    "envaidarás": "envaidar",
    "envaidarão": "envaidar",
    "envaidaríamos": "envaidar",
    "envaidaríeis": "envaidar",
    "envaidas": "envaidar",
    "envaidasse": "envaidar",
    "envaidassem": "envaidar",
    "envaidasses": "envaidar",
    "envaidaste": "envaidar",
    "envaidastes": "envaidar",
    "envaidava": "envaidar",
    "envaidavam": "envaidar",
    "envaidavas": "envaidar",
    "envaide": "envaidar",
    "envaidece": "envaidecer",
    "envaidecei": "envaidecer",
    "envaideceis": "envaidecer",
    "envaidecem": "envaidecer",
    "envaidecemo": "envaidecer",
    "envaidecemos": "envaidecer",
    "envaidecendo": "envaidecer",
    "envaidecera": "envaidecer",
    "envaideceram": "envaidecer",
    "envaideceras": "envaidecer",
    "envaidecerde": "envaidecer",
    "envaidecerdes": "envaidecer",
    "envaidecere": "envaidecer",
    "envaidecerei": "envaidecer",
    "envaidecereis": "envaidecer",
    "envaidecerem": "envaidecer",
    "envaideceremos": "envaidecer",
    "envaideceres": "envaidecer",
    "envaideceria": "envaidecer",
    "envaideceriam": "envaidecer",
    "envaidecerias": "envaidecer",
    "envaidecermo": "envaidecer",
    "envaidecermos": "envaidecer",
    "envaidecerá": "envaidecer",
    "envaidecerás": "envaidecer",
    "envaidecerão": "envaidecer",
    "envaideceríamos": "envaidecer",
    "envaideceríeis": "envaidecer",
    "envaideces": "envaidecer",
    "envaidecesse": "envaidecer",
    "envaidecessem": "envaidecer",
    "envaidecesses": "envaidecer",
    "envaideceste": "envaidecer",
    "envaidecestes": "envaidecer",
    "envaideceu": "envaidecer",
    "envaideci": "envaidecer",
    "envaidecia": "envaidecer",
    "envaideciam": "envaidecer",
    "envaidecias": "envaidecer",
    "envaidecida": "envaidecido",
    "envaidecidas": "envaidecido",
    "envaidecido": "envaidecer",
    "envaidecidos": "envaidecido",
    "envaidecimentos": "envaidecimento",
    "envaidecê": "envaidecer",
    "envaidecêramo": "envaidecer",
    "envaidecêramos": "envaidecer",
    "envaidecêrei": "envaidecer",
    "envaidecêreis": "envaidecer",
    "envaidecêsseis": "envaidecer",
    "envaidecêssemos": "envaidecer",
    "envaidecíamo": "envaidecer",
    "envaidecíamos": "envaidecer",
    "envaidecíei": "envaidecer",
    "envaidecíeis": "envaidecer",
    "envaidei": "envaidar",
    "envaideis": "envaidar",
    "envaidem": "envaidar",
    "envaidemo": "envaidar",
    "envaidemos": "envaidar",
    "envaides": "envaidar",
    "envaideça": "envaidecer",
    "envaideçais": "envaidecer",
    "envaideçam": "envaidecer",
    "envaideçamo": "envaidecer",
    "envaideçamos": "envaidecer",
    "envaideças": "envaidecer",
    "envaideço": "envaidecer",
    "envaido": "envaidar",
    "envaidou": "envaidar",
    "envaidá": "envaidar",
    "envaidámo": "envaidar",
    "envaidámos": "envaidar",
    "envaidáramo": "envaidar",
    "envaidáramos": "envaidar",
    "envaidárei": "envaidar",
    "envaidáreis": "envaidar",
    "envaidásseis": "envaidar",
    "envaidássemos": "envaidar",
    "envaidávamo": "envaidar",
    "envaidávamos": "envaidar",
    "envaidávei": "envaidar",
    "envaidáveis": "envaidar",
    "envala": "envalar",
    "envalada": "envalar",
    "envaladas": "envalar",
    "envalado": "envalar",
    "envalados": "envalar",
    "envalai": "envalar",
    "envalais": "envalar",
    "envalam": "envalar",
    "envalamo": "envalar",
    "envalamos": "envalar",
    "envalando": "envalar",
    "envalara": "envalar",
    "envalaram": "envalar",
    "envalaras": "envalar",
    "envalarde": "envalar",
    "envalardes": "envalar",
    "envalare": "envalar",
    "envalarei": "envalar",
    "envalareis": "envalar",
    "envalarem": "envalar",
    "envalaremos": "envalar",
    "envalares": "envalar",
    "envalaria": "envalar",
    "envalariam": "envalar",
    "envalarias": "envalar",
    "envalarmo": "envalar",
    "envalarmos": "envalar",
    "envalará": "envalar",
    "envalarás": "envalar",
    "envalarão": "envalar",
    "envalaríamos": "envalar",
    "envalaríeis": "envalar",
    "envalas": "envalar",
    "envalasse": "envalar",
    "envalassem": "envalar",
    "envalasses": "envalar",
    "envalaste": "envalar",
    "envalastes": "envalar",
    "envalava": "envalar",
    "envalavam": "envalar",
    "envalavas": "envalar",
    "envale": "envalar",
    "envalece": "envalecer",
    "envalecei": "envalecer",
    "envaleceis": "envalecer",
    "envalecem": "envalecer",
    "envalecemo": "envalecer",
    "envalecemos": "envalecer",
    "envalecendo": "envalecer",
    "envalecera": "envalecer",
    "envaleceram": "envalecer",
    "envaleceras": "envalecer",
    "envalecerdes": "envalecer",
    "envalecerei": "envalecer",
    "envalecereis": "envalecer",
    "envalecerem": "envalecer",
    "envaleceremos": "envalecer",
    "envaleceres": "envalecer",
    "envaleceria": "envalecer",
    "envaleceriam": "envalecer",
    "envalecerias": "envalecer",
    "envalecermo": "envalecer",
    "envalecermos": "envalecer",
    "envalecerá": "envalecer",
    "envalecerás": "envalecer",
    "envalecerão": "envalecer",
    "envaleceríamos": "envalecer",
    "envaleceríeis": "envalecer",
    "envaleces": "envalecer",
    "envalecesse": "envalecer",
    "envalecessem": "envalecer",
    "envalecesses": "envalecer",
    "envaleceste": "envalecer",
    "envalecestes": "envalecer",
    "envaleceu": "envalecer",
    "envaleci": "envalecer",
    "envalecia": "envalecer",
    "envaleciam": "envalecer",
    "envalecias": "envalecer",
    "envalecida": "envalecer",
    "envalecidas": "envalecer",
    "envalecido": "envalecer",
    "envalecidos": "envalecer",
    "envalecêramo": "envalecer",
    "envalecêramos": "envalecer",
    "envalecêreis": "envalecer",
    "envalecêsseis": "envalecer",
    "envalecêssemos": "envalecer",
    "envalecíamo": "envalecer",
    "envalecíamos": "envalecer",
    "envalecíeis": "envalecer",
    "envalei": "envalar",
    "envaleis": "envalar",
    "envalem": "envalar",
    "envalemo": "envalar",
    "envalemos": "envalar",
    "envales": "envalar",
    "envaleça": "envalecer",
    "envaleçais": "envalecer",
    "envaleçam": "envalecer",
    "envaleçamo": "envalecer",
    "envaleçamos": "envalecer",
    "envaleças": "envalecer",
    "envaleço": "envalecer",
    "envalo": "envalar",
    "envalou": "envalar",
    "envalá": "envalar",
    "envalámo": "envalar",
    "envalámos": "envalar",
    "envaláramo": "envalar",
    "envaláramos": "envalar",
    "envalárei": "envalar",
    "envaláreis": "envalar",
    "envalásseis": "envalar",
    "envalássemos": "envalar",
    "envalávamo": "envalar",
    "envalávamos": "envalar",
    "envalávei": "envalar",
    "envaláveis": "envalar",
    "envara": "envarar",
    "envarada": "envarar",
    "envaradas": "envarar",
    "envarado": "envarar",
    "envarados": "envarar",
    "envarai": "envarar",
    "envarais": "envarar",
    "envaram": "envarar",
    "envaramo": "envarar",
    "envaramos": "envarar",
    "envarando": "envarar",
    "envarara": "envarar",
    "envararam": "envarar",
    "envararas": "envarar",
    "envararde": "envarar",
    "envarardes": "envarar",
    "envarare": "envarar",
    "envararei": "envarar",
    "envarareis": "envarar",
    "envararem": "envarar",
    "envararemos": "envarar",
    "envarares": "envarar",
    "envararia": "envarar",
    "envarariam": "envarar",
    "envararias": "envarar",
    "envararmo": "envarar",
    "envararmos": "envarar",
    "envarará": "envarar",
    "envararás": "envarar",
    "envararão": "envarar",
    "envararíamos": "envarar",
    "envararíeis": "envarar",
    "envaras": "envarar",
    "envarasse": "envarar",
    "envarassem": "envarar",
    "envarasses": "envarar",
    "envaraste": "envarar",
    "envarastes": "envarar",
    "envarava": "envarar",
    "envaravam": "envarar",
    "envaravas": "envarar",
    "envare": "envarar",
    "envarei": "envarar",
    "envareis": "envarar",
    "envarem": "envarar",
    "envaremo": "envarar",
    "envaremos": "envarar",
    "envares": "envarar",
    "envareta": "envaretar",
    "envaretada": "envaretar",
    "envaretadas": "envaretar",
    "envaretado": "envaretar",
    "envaretados": "envaretar",
    "envaretai": "envaretar",
    "envaretais": "envaretar",
    "envaretam": "envaretar",
    "envaretamo": "envaretar",
    "envaretamos": "envaretar",
    "envaretando": "envaretar",
    "envaretara": "envaretar",
    "envaretaram": "envaretar",
    "envaretaras": "envaretar",
    "envaretarde": "envaretar",
    "envaretardes": "envaretar",
    "envaretare": "envaretar",
    "envaretarei": "envaretar",
    "envaretareis": "envaretar",
    "envaretarem": "envaretar",
    "envaretaremos": "envaretar",
    "envaretares": "envaretar",
    "envaretaria": "envaretar",
    "envaretariam": "envaretar",
    "envaretarias": "envaretar",
    "envaretarmo": "envaretar",
    "envaretarmos": "envaretar",
    "envaretará": "envaretar",
    "envaretarás": "envaretar",
    "envaretarão": "envaretar",
    "envaretaríamos": "envaretar",
    "envaretaríeis": "envaretar",
    "envaretas": "envaretar",
    "envaretasse": "envaretar",
    "envaretassem": "envaretar",
    "envaretasses": "envaretar",
    "envaretaste": "envaretar",
    "envaretastes": "envaretar",
    "envaretava": "envaretar",
    "envaretavam": "envaretar",
    "envaretavas": "envaretar",
    "envarete": "envaretar",
    "envaretei": "envaretar",
    "envareteis": "envaretar",
    "envaretem": "envaretar",
    "envaretemo": "envaretar",
    "envaretemos": "envaretar",
    "envaretes": "envaretar",
    "envareto": "envaretar",
    "envaretou": "envaretar",
    "envaretá": "envaretar",
    "envaretámo": "envaretar",
    "envaretámos": "envaretar",
    "envaretáramo": "envaretar",
    "envaretáramos": "envaretar",
    "envaretárei": "envaretar",
    "envaretáreis": "envaretar",
    "envaretásseis": "envaretar",
    "envaretássemos": "envaretar",
    "envaretávamo": "envaretar",
    "envaretávamos": "envaretar",
    "envaretávei": "envaretar",
    "envaretáveis": "envaretar",
    "envaro": "envarar",
    "envarou": "envarar",
    "envará": "envarar",
    "envarámo": "envarar",
    "envarámos": "envarar",
    "envaráramo": "envarar",
    "envaráramos": "envarar",
    "envarárei": "envarar",
    "envaráreis": "envarar",
    "envarásseis": "envarar",
    "envarássemos": "envarar",
    "envarávamo": "envarar",
    "envarávamos": "envarar",
    "envarávei": "envarar",
    "envaráveis": "envarar",
    "envasa": "envasar",
    "envasada": "envasar",
    "envasadas": "envasar",
    "envasado": "envasar",
    "envasados": "envasar",
    "envasaduras": "envasadura",
    "envasai": "envasar",
    "envasais": "envasar",
    "envasam": "envasar",
    "envasamentos": "envasamento",
    "envasamo": "envasar",
    "envasamos": "envasar",
    "envasando": "envasar",
    "envasara": "envasar",
    "envasaram": "envasar",
    "envasaras": "envasar",
    "envasarde": "envasar",
    "envasardes": "envasar",
    "envasare": "envasar",
    "envasarei": "envasar",
    "envasareis": "envasar",
    "envasarem": "envasar",
    "envasaremos": "envasar",
    "envasares": "envasar",
    "envasaria": "envasar",
    "envasariam": "envasar",
    "envasarias": "envasar",
    "envasarmo": "envasar",
    "envasarmos": "envasar",
    "envasará": "envasar",
    "envasarás": "envasar",
    "envasarão": "envasar",
    "envasaríamos": "envasar",
    "envasaríeis": "envasar",
    "envasas": "envasar",
    "envasasse": "envasar",
    "envasassem": "envasar",
    "envasasses": "envasar",
    "envasaste": "envasar",
    "envasastes": "envasar",
    "envasava": "envasar",
    "envasavam": "envasar",
    "envasavas": "envasar",
    "envase": "envasar",
    "envasei": "envasar",
    "envaseis": "envasar",
    "envasem": "envasar",
    "envasemo": "envasar",
    "envasemos": "envasar",
    "envases": "envasar",
    "envasilha": "envasilhar",
    "envasilhada": "envasilhar",
    "envasilhadas": "envasilhar",
    "envasilhado": "envasilhar",
    "envasilhados": "envasilhar",
    "envasilhai": "envasilhar",
    "envasilhais": "envasilhar",
    "envasilham": "envasilhar",
    "envasilhamentos": "envasilhamento",
    "envasilhamo": "envasilhar",
    "envasilhamos": "envasilhar",
    "envasilhando": "envasilhar",
    "envasilhara": "envasilhar",
    "envasilharam": "envasilhar",
    "envasilharas": "envasilhar",
    "envasilharde": "envasilhar",
    "envasilhardes": "envasilhar",
    "envasilhare": "envasilhar",
    "envasilharei": "envasilhar",
    "envasilhareis": "envasilhar",
    "envasilharem": "envasilhar",
    "envasilharemos": "envasilhar",
    "envasilhares": "envasilhar",
    "envasilharia": "envasilhar",
    "envasilhariam": "envasilhar",
    "envasilharias": "envasilhar",
    "envasilharmo": "envasilhar",
    "envasilharmos": "envasilhar",
    "envasilhará": "envasilhar",
    "envasilharás": "envasilhar",
    "envasilharão": "envasilhar",
    "envasilharíamos": "envasilhar",
    "envasilharíeis": "envasilhar",
    "envasilhas": "envasilhar",
    "envasilhasse": "envasilhar",
    "envasilhassem": "envasilhar",
    "envasilhasses": "envasilhar",
    "envasilhaste": "envasilhar",
    "envasilhastes": "envasilhar",
    "envasilhava": "envasilhar",
    "envasilhavam": "envasilhar",
    "envasilhavas": "envasilhar",
    "envasilhe": "envasilhar",
    "envasilhei": "envasilhar",
    "envasilheis": "envasilhar",
    "envasilhem": "envasilhar",
    "envasilhemo": "envasilhar",
    "envasilhemos": "envasilhar",
    "envasilhes": "envasilhar",
    "envasilho": "envasilhar",
    "envasilhou": "envasilhar",
    "envasilhá": "envasilhar",
    "envasilhámo": "envasilhar",
    "envasilhámos": "envasilhar",
    "envasilháramo": "envasilhar",
    "envasilháramos": "envasilhar",
    "envasilhárei": "envasilhar",
    "envasilháreis": "envasilhar",
    "envasilhásseis": "envasilhar",
    "envasilhássemos": "envasilhar",
    "envasilhávamo": "envasilhar",
    "envasilhávamos": "envasilhar",
    "envasilhávei": "envasilhar",
    "envasilháveis": "envasilhar",
    "envaso": "envasar",
    "envasou": "envasar",
    "envasá": "envasar",
    "envasámo": "envasar",
    "envasámos": "envasar",
    "envasáramo": "envasar",
    "envasáramos": "envasar",
    "envasárei": "envasar",
    "envasáreis": "envasar",
    "envasásseis": "envasar",
    "envasássemos": "envasar",
    "envasávamo": "envasar",
    "envasávamos": "envasar",
    "envasávei": "envasar",
    "envasáveis": "envasar",
    "envaza": "envazar",
    "envazada": "envazar",
    "envazadas": "envazar",
    "envazado": "envazar",
    "envazados": "envazar",
    "envazaduras": "envazadura",
    "envazai": "envazar",
    "envazais": "envazar",
    "envazam": "envazar",
    "envazamo": "envazar",
    "envazamos": "envazar",
    "envazando": "envazar",
    "envazara": "envazar",
    "envazaram": "envazar",
    "envazaras": "envazar",
    "envazarde": "envazar",
    "envazardes": "envazar",
    "envazare": "envazar",
    "envazarei": "envazar",
    "envazareis": "envazar",
    "envazarem": "envazar",
    "envazaremos": "envazar",
    "envazares": "envazar",
    "envazaria": "envazar",
    "envazariam": "envazar",
    "envazarias": "envazar",
    "envazarmo": "envazar",
    "envazarmos": "envazar",
    "envazará": "envazar",
    "envazarás": "envazar",
    "envazarão": "envazar",
    "envazaríamos": "envazar",
    "envazaríeis": "envazar",
    "envazas": "envazar",
    "envazasse": "envazar",
    "envazassem": "envazar",
    "envazasses": "envazar",
    "envazaste": "envazar",
    "envazastes": "envazar",
    "envazava": "envazar",
    "envazavam": "envazar",
    "envazavas": "envazar",
    "envaze": "envazar",
    "envazei": "envazar",
    "envazeis": "envazar",
    "envazem": "envazar",
    "envazemo": "envazar",
    "envazemos": "envazar",
    "envazes": "envazar",
    "envaziados": "envaziado",
    "envazo": "envazar",
    "envazou": "envazar",
    "envazá": "envazar",
    "envazámo": "envazar",
    "envazámos": "envazar",
    "envazáramo": "envazar",
    "envazáramos": "envazar",
    "envazárei": "envazar",
    "envazáreis": "envazar",
    "envazásseis": "envazar",
    "envazássemos": "envazar",
    "envazávamo": "envazar",
    "envazávamos": "envazar",
    "envazávei": "envazar",
    "envazáveis": "envazar",
    "envelhaca": "envelhacar",
    "envelhacada": "envelhacar",
    "envelhacadas": "envelhacar",
    "envelhacado": "envelhacar",
    "envelhacados": "envelhacar",
    "envelhacai": "envelhacar",
    "envelhacais": "envelhacar",
    "envelhacam": "envelhacar",
    "envelhacamo": "envelhacar",
    "envelhacamos": "envelhacar",
    "envelhacando": "envelhacar",
    "envelhacara": "envelhacar",
    "envelhacaram": "envelhacar",
    "envelhacaras": "envelhacar",
    "envelhacarde": "envelhacar",
    "envelhacardes": "envelhacar",
    "envelhacare": "envelhacar",
    "envelhacarei": "envelhacar",
    "envelhacareis": "envelhacar",
    "envelhacarem": "envelhacar",
    "envelhacaremos": "envelhacar",
    "envelhacares": "envelhacar",
    "envelhacaria": "envelhacar",
    "envelhacariam": "envelhacar",
    "envelhacarias": "envelhacar",
    "envelhacarmo": "envelhacar",
    "envelhacarmos": "envelhacar",
    "envelhacará": "envelhacar",
    "envelhacarás": "envelhacar",
    "envelhacarão": "envelhacar",
    "envelhacaríamos": "envelhacar",
    "envelhacaríeis": "envelhacar",
    "envelhacas": "envelhacar",
    "envelhacasse": "envelhacar",
    "envelhacassem": "envelhacar",
    "envelhacasses": "envelhacar",
    "envelhacaste": "envelhacar",
    "envelhacastes": "envelhacar",
    "envelhacava": "envelhacar",
    "envelhacavam": "envelhacar",
    "envelhacavas": "envelhacar",
    "envelhaco": "envelhacar",
    "envelhacou": "envelhacar",
    "envelhacá": "envelhacar",
    "envelhacámo": "envelhacar",
    "envelhacámos": "envelhacar",
    "envelhacáramo": "envelhacar",
    "envelhacáramos": "envelhacar",
    "envelhacárei": "envelhacar",
    "envelhacáreis": "envelhacar",
    "envelhacásseis": "envelhacar",
    "envelhacássemos": "envelhacar",
    "envelhacávamo": "envelhacar",
    "envelhacávamos": "envelhacar",
    "envelhacávei": "envelhacar",
    "envelhacáveis": "envelhacar",
    "envelhaque": "envelhacar",
    "envelhaquei": "envelhacar",
    "envelhaqueis": "envelhacar",
    "envelhaquem": "envelhacar",
    "envelhaquemo": "envelhacar",
    "envelhaquemos": "envelhacar",
    "envelhaques": "envelhacar",
    "envelhece": "envelhecer",
    "envelhecei": "envelhecer",
    "envelheceis": "envelhecer",
    "envelhecem": "envelhecer",
    "envelhecemo": "envelhecer",
    "envelhecemos": "envelhecer",
    "envelhecendo": "envelhecer",
    "envelhecera": "envelhecer",
    "envelheceram": "envelhecer",
    "envelheceras": "envelhecer",
    "envelhecerde": "envelhecer",
    "envelhecerdes": "envelhecer",
    "envelhecere": "envelhecer",
    "envelhecerei": "envelhecer",
    "envelhecereis": "envelhecer",
    "envelhecerem": "envelhecer",
    "envelheceremos": "envelhecer",
    "envelheceres": "envelhecer",
    "envelheceria": "envelhecer",
    "envelheceriam": "envelhecer",
    "envelhecerias": "envelhecer",
    "envelhecermo": "envelhecer",
    "envelhecermos": "envelhecer",
    "envelhecerá": "envelhecer",
    "envelhecerás": "envelhecer",
    "envelhecerão": "envelhecer",
    "envelheceríamos": "envelhecer",
    "envelheceríeis": "envelhecer",
    "envelheces": "envelhecer",
    "envelhecesse": "envelhecer",
    "envelhecessem": "envelhecer",
    "envelhecesses": "envelhecer",
    "envelheceste": "envelhecer",
    "envelhecestes": "envelhecer",
    "envelheceu": "envelhecer",
    "envelheci": "envelhecer",
    "envelhecia": "envelhecer",
    "envelheciam": "envelhecer",
    "envelhecias": "envelhecer",
    "envelhecida": "envelhecido",
    "envelhecidas": "envelhecido",
    "envelhecido": "envelhecer",
    "envelhecidos": "envelhecido",
    "envelhecimentos": "envelhecimento",
    "envelhecê": "envelhecer",
    "envelhecêramo": "envelhecer",
    "envelhecêramos": "envelhecer",
    "envelhecêrei": "envelhecer",
    "envelhecêreis": "envelhecer",
    "envelhecêsseis": "envelhecer",
    "envelhecêssemos": "envelhecer",
    "envelhecíamo": "envelhecer",
    "envelhecíamos": "envelhecer",
    "envelhecíei": "envelhecer",
    "envelhecíeis": "envelhecer",
    "envelhenta": "envelhentar",
    "envelhentada": "envelhentar",
    "envelhentadas": "envelhentar",
    "envelhentado": "envelhentar",
    "envelhentados": "envelhentar",
    "envelhentai": "envelhentar",
    "envelhentais": "envelhentar",
    "envelhentam": "envelhentar",
    "envelhentamo": "envelhentar",
    "envelhentamos": "envelhentar",
    "envelhentando": "envelhentar",
    "envelhentara": "envelhentar",
    "envelhentaram": "envelhentar",
    "envelhentaras": "envelhentar",
    "envelhentarde": "envelhentar",
    "envelhentardes": "envelhentar",
    "envelhentare": "envelhentar",
    "envelhentarei": "envelhentar",
    "envelhentareis": "envelhentar",
    "envelhentarem": "envelhentar",
    "envelhentaremos": "envelhentar",
    "envelhentares": "envelhentar",
    "envelhentaria": "envelhentar",
    "envelhentariam": "envelhentar",
    "envelhentarias": "envelhentar",
    "envelhentarmo": "envelhentar",
    "envelhentarmos": "envelhentar",
    "envelhentará": "envelhentar",
    "envelhentarás": "envelhentar",
    "envelhentarão": "envelhentar",
    "envelhentaríamos": "envelhentar",
    "envelhentaríeis": "envelhentar",
    "envelhentas": "envelhentar",
    "envelhentasse": "envelhentar",
    "envelhentassem": "envelhentar",
    "envelhentasses": "envelhentar",
    "envelhentaste": "envelhentar",
    "envelhentastes": "envelhentar",
    "envelhentava": "envelhentar",
    "envelhentavam": "envelhentar",
    "envelhentavas": "envelhentar",
    "envelhente": "envelhentar",
    "envelhentei": "envelhentar",
    "envelhenteis": "envelhentar",
    "envelhentem": "envelhentar",
    "envelhentemo": "envelhentar",
    "envelhentemos": "envelhentar",
    "envelhentes": "envelhentar",
    "envelhento": "envelhentar",
    "envelhentou": "envelhentar",
    "envelhentá": "envelhentar",
    "envelhentámo": "envelhentar",
    "envelhentámos": "envelhentar",
    "envelhentáramo": "envelhentar",
    "envelhentáramos": "envelhentar",
    "envelhentárei": "envelhentar",
    "envelhentáreis": "envelhentar",
    "envelhentásseis": "envelhentar",
    "envelhentássemos": "envelhentar",
    "envelhentávamo": "envelhentar",
    "envelhentávamos": "envelhentar",
    "envelhentávei": "envelhentar",
    "envelhentáveis": "envelhentar",
    "envelheça": "envelhecer",
    "envelheçais": "envelhecer",
    "envelheçam": "envelhecer",
    "envelheçamo": "envelhecer",
    "envelheçamos": "envelhecer",
    "envelheças": "envelhecer",
    "envelheço": "envelhecer",
    "envelopes": "envelope",
    "envencilha": "envencilhar",
    "envencilhada": "envencilhar",
    "envencilhadas": "envencilhar",
    "envencilhado": "envencilhar",
    "envencilhados": "envencilhar",
    "envencilhai": "envencilhar",
    "envencilhais": "envencilhar",
    "envencilham": "envencilhar",
    "envencilhamo": "envencilhar",
    "envencilhamos": "envencilhar",
    "envencilhando": "envencilhar",
    "envencilhara": "envencilhar",
    "envencilharam": "envencilhar",
    "envencilharas": "envencilhar",
    "envencilharde": "envencilhar",
    "envencilhardes": "envencilhar",
    "envencilhare": "envencilhar",
    "envencilharei": "envencilhar",
    "envencilhareis": "envencilhar",
    "envencilharem": "envencilhar",
    "envencilharemos": "envencilhar",
    "envencilhares": "envencilhar",
    "envencilharia": "envencilhar",
    "envencilhariam": "envencilhar",
    "envencilharias": "envencilhar",
    "envencilharmo": "envencilhar",
    "envencilharmos": "envencilhar",
    "envencilhará": "envencilhar",
    "envencilharás": "envencilhar",
    "envencilharão": "envencilhar",
    "envencilharíamos": "envencilhar",
    "envencilharíeis": "envencilhar",
    "envencilhas": "envencilhar",
    "envencilhasse": "envencilhar",
    "envencilhassem": "envencilhar",
    "envencilhasses": "envencilhar",
    "envencilhaste": "envencilhar",
    "envencilhastes": "envencilhar",
    "envencilhava": "envencilhar",
    "envencilhavam": "envencilhar",
    "envencilhavas": "envencilhar",
    "envencilhe": "envencilhar",
    "envencilhei": "envencilhar",
    "envencilheis": "envencilhar",
    "envencilhem": "envencilhar",
    "envencilhemo": "envencilhar",
    "envencilhemos": "envencilhar",
    "envencilhes": "envencilhar",
    "envencilho": "envencilhar",
    "envencilhou": "envencilhar",
    "envencilhá": "envencilhar",
    "envencilhámo": "envencilhar",
    "envencilhámos": "envencilhar",
    "envencilháramo": "envencilhar",
    "envencilháramos": "envencilhar",
    "envencilhárei": "envencilhar",
    "envencilháreis": "envencilhar",
    "envencilhásseis": "envencilhar",
    "envencilhássemos": "envencilhar",
    "envencilhávamo": "envencilhar",
    "envencilhávamos": "envencilhar",
    "envencilhávei": "envencilhar",
    "envencilháveis": "envencilhar",
    "envenena": "envenenar",
    "envenenada": "envenenar",
    "envenenadas": "envenenar",
    "envenenado": "envenenar",
    "envenenadora": "envenenador",
    "envenenadoras": "envenenador",
    "envenenadores": "envenenador",
    "envenenados": "envenenar",
    "envenenai": "envenenar",
    "envenenais": "envenenar",
    "envenenam": "envenenar",
    "envenenamentos": "envenenamento",
    "envenenamo": "envenenar",
    "envenenamos": "envenenar",
    "envenenando": "envenenar",
    "envenenara": "envenenar",
    "envenenaram": "envenenar",
    "envenenaras": "envenenar",
    "envenenarde": "envenenar",
    "envenenardes": "envenenar",
    "envenenare": "envenenar",
    "envenenarei": "envenenar",
    "envenenareis": "envenenar",
    "envenenarem": "envenenar",
    "envenenaremos": "envenenar",
    "envenenares": "envenenar",
    "envenenaria": "envenenar",
    "envenenariam": "envenenar",
    "envenenarias": "envenenar",
    "envenenarmo": "envenenar",
    "envenenarmos": "envenenar",
    "envenenará": "envenenar",
    "envenenarás": "envenenar",
    "envenenarão": "envenenar",
    "envenenaríamos": "envenenar",
    "envenenaríeis": "envenenar",
    "envenenas": "envenenar",
    "envenenasse": "envenenar",
    "envenenassem": "envenenar",
    "envenenasses": "envenenar",
    "envenenaste": "envenenar",
    "envenenastes": "envenenar",
    "envenenava": "envenenar",
    "envenenavam": "envenenar",
    "envenenavas": "envenenar",
    "envenene": "envenenar",
    "envenenei": "envenenar",
    "enveneneis": "envenenar",
    "envenenem": "envenenar",
    "envenenemo": "envenenar",
    "envenenemos": "envenenar",
    "envenenes": "envenenar",
    "enveneno": "envenenar",
    "envenenou": "envenenar",
    "envenená": "envenenar",
    "envenenámo": "envenenar",
    "envenenámos": "envenenar",
    "envenenáramo": "envenenar",
    "envenenáramos": "envenenar",
    "envenenárei": "envenenar",
    "envenenáreis": "envenenar",
    "envenenásseis": "envenenar",
    "envenenássemos": "envenenar",
    "envenenávamo": "envenenar",
    "envenenávamos": "envenenar",
    "envenenávei": "envenenar",
    "envenenáveis": "envenenar",
    "enventana": "enventanar",
    "enventanada": "enventanar",
    "enventanadas": "enventanar",
    "enventanado": "enventanar",
    "enventanados": "enventanar",
    "enventanai": "enventanar",
    "enventanais": "enventanar",
    "enventanam": "enventanar",
    "enventanamo": "enventanar",
    "enventanamos": "enventanar",
    "enventanando": "enventanar",
    "enventanara": "enventanar",
    "enventanaram": "enventanar",
    "enventanaras": "enventanar",
    "enventanarde": "enventanar",
    "enventanardes": "enventanar",
    "enventanare": "enventanar",
    "enventanarei": "enventanar",
    "enventanareis": "enventanar",
    "enventanarem": "enventanar",
    "enventanaremos": "enventanar",
    "enventanares": "enventanar",
    "enventanaria": "enventanar",
    "enventanariam": "enventanar",
    "enventanarias": "enventanar",
    "enventanarmo": "enventanar",
    "enventanarmos": "enventanar",
    "enventanará": "enventanar",
    "enventanarás": "enventanar",
    "enventanarão": "enventanar",
    "enventanaríamos": "enventanar",
    "enventanaríeis": "enventanar",
    "enventanas": "enventanar",
    "enventanasse": "enventanar",
    "enventanassem": "enventanar",
    "enventanasses": "enventanar",
    "enventanaste": "enventanar",
    "enventanastes": "enventanar",
    "enventanava": "enventanar",
    "enventanavam": "enventanar",
    "enventanavas": "enventanar",
    "enventane": "enventanar",
    "enventanei": "enventanar",
    "enventaneis": "enventanar",
    "enventanem": "enventanar",
    "enventanemo": "enventanar",
    "enventanemos": "enventanar",
    "enventanes": "enventanar",
    "enventano": "enventanar",
    "enventanou": "enventanar",
    "enventaná": "enventanar",
    "enventanámo": "enventanar",
    "enventanámos": "enventanar",
    "enventanáramo": "enventanar",
    "enventanáramos": "enventanar",
    "enventanárei": "enventanar",
    "enventanáreis": "enventanar",
    "enventanásseis": "enventanar",
    "enventanássemos": "enventanar",
    "enventanávamo": "enventanar",
    "enventanávamos": "enventanar",
    "enventanávei": "enventanar",
    "enventanáveis": "enventanar",
    "enverdece": "enverdecer",
    "enverdecei": "enverdecer",
    "enverdeceis": "enverdecer",
    "enverdecem": "enverdecer",
    "enverdecemo": "enverdecer",
    "enverdecemos": "enverdecer",
    "enverdecendo": "enverdecer",
    "enverdecera": "enverdecer",
    "enverdeceram": "enverdecer",
    "enverdeceras": "enverdecer",
    "enverdecerde": "enverdecer",
    "enverdecerdes": "enverdecer",
    "enverdecere": "enverdecer",
    "enverdecerei": "enverdecer",
    "enverdecereis": "enverdecer",
    "enverdecerem": "enverdecer",
    "enverdeceremos": "enverdecer",
    "enverdeceres": "enverdecer",
    "enverdeceria": "enverdecer",
    "enverdeceriam": "enverdecer",
    "enverdecerias": "enverdecer",
    "enverdecermo": "enverdecer",
    "enverdecermos": "enverdecer",
    "enverdecerá": "enverdecer",
    "enverdecerás": "enverdecer",
    "enverdecerão": "enverdecer",
    "enverdeceríamos": "enverdecer",
    "enverdeceríeis": "enverdecer",
    "enverdeces": "enverdecer",
    "enverdecesse": "enverdecer",
    "enverdecessem": "enverdecer",
    "enverdecesses": "enverdecer",
    "enverdeceste": "enverdecer",
    "enverdecestes": "enverdecer",
    "enverdeceu": "enverdecer",
    "enverdeci": "enverdecer",
    "enverdecia": "enverdecer",
    "enverdeciam": "enverdecer",
    "enverdecias": "enverdecer",
    "enverdecida": "enverdecer",
    "enverdecidas": "enverdecer",
    "enverdecido": "enverdecer",
    "enverdecidos": "enverdecer",
    "enverdecimentos": "enverdecimento",
    "enverdecê": "enverdecer",
    "enverdecêramo": "enverdecer",
    "enverdecêramos": "enverdecer",
    "enverdecêrei": "enverdecer",
    "enverdecêreis": "enverdecer",
    "enverdecêsseis": "enverdecer",
    "enverdecêssemos": "enverdecer",
    "enverdecíamo": "enverdecer",
    "enverdecíamos": "enverdecer",
    "enverdecíei": "enverdecer",
    "enverdecíeis": "enverdecer",
    "enverdeja": "enverdejar",
    "enverdejada": "enverdejar",
    "enverdejadas": "enverdejar",
    "enverdejado": "enverdejar",
    "enverdejados": "enverdejar",
    "enverdejai": "enverdejar",
    "enverdejais": "enverdejar",
    "enverdejam": "enverdejar",
    "enverdejamo": "enverdejar",
    "enverdejamos": "enverdejar",
    "enverdejando": "enverdejar",
    "enverdejara": "enverdejar",
    "enverdejaram": "enverdejar",
    "enverdejaras": "enverdejar",
    "enverdejarde": "enverdejar",
    "enverdejardes": "enverdejar",
    "enverdejare": "enverdejar",
    "enverdejarei": "enverdejar",
    "enverdejareis": "enverdejar",
    "enverdejarem": "enverdejar",
    "enverdejaremos": "enverdejar",
    "enverdejares": "enverdejar",
    "enverdejaria": "enverdejar",
    "enverdejariam": "enverdejar",
    "enverdejarias": "enverdejar",
    "enverdejarmo": "enverdejar",
    "enverdejarmos": "enverdejar",
    "enverdejará": "enverdejar",
    "enverdejarás": "enverdejar",
    "enverdejarão": "enverdejar",
    "enverdejaríamos": "enverdejar",
    "enverdejaríeis": "enverdejar",
    "enverdejas": "enverdejar",
    "enverdejasse": "enverdejar",
    "enverdejassem": "enverdejar",
    "enverdejasses": "enverdejar",
    "enverdejaste": "enverdejar",
    "enverdejastes": "enverdejar",
    "enverdejava": "enverdejar",
    "enverdejavam": "enverdejar",
    "enverdejavas": "enverdejar",
    "enverdeje": "enverdejar",
    "enverdejei": "enverdejar",
    "enverdejeis": "enverdejar",
    "enverdejem": "enverdejar",
    "enverdejemo": "enverdejar",
    "enverdejemos": "enverdejar",
    "enverdejes": "enverdejar",
    "enverdejo": "enverdejar",
    "enverdejou": "enverdejar",
    "enverdejá": "enverdejar",
    "enverdejámo": "enverdejar",
    "enverdejámos": "enverdejar",
    "enverdejáramo": "enverdejar",
    "enverdejáramos": "enverdejar",
    "enverdejárei": "enverdejar",
    "enverdejáreis": "enverdejar",
    "enverdejásseis": "enverdejar",
    "enverdejássemos": "enverdejar",
    "enverdejávamo": "enverdejar",
    "enverdejávamos": "enverdejar",
    "enverdejávei": "enverdejar",
    "enverdejáveis": "enverdejar",
    "enverdeça": "enverdecer",
    "enverdeçais": "enverdecer",
    "enverdeçam": "enverdecer",
    "enverdeçamo": "enverdecer",
    "enverdeçamos": "enverdecer",
    "enverdeças": "enverdecer",
    "enverdeço": "enverdecer",
    "envereda": "enveredar",
    "enveredada": "enveredar",
    "enveredadas": "enveredar",
    "enveredado": "enveredar",
    "enveredados": "enveredar",
    "enveredai": "enveredar",
    "enveredais": "enveredar",
    "enveredam": "enveredar",
    "enveredamo": "enveredar",
    "enveredamos": "enveredar",
    "enveredando": "enveredar",
    "enveredara": "enveredar",
    "enveredaram": "enveredar",
    "enveredaras": "enveredar",
    "enveredardes": "enveredar",
    "enveredarei": "enveredar",
    "enveredareis": "enveredar",
    "enveredarem": "enveredar",
    "enveredaremos": "enveredar",
    "enveredares": "enveredar",
    "enveredaria": "enveredar",
    "enveredariam": "enveredar",
    "enveredarias": "enveredar",
    "enveredarmo": "enveredar",
    "enveredarmos": "enveredar",
    "enveredará": "enveredar",
    "enveredarás": "enveredar",
    "enveredarão": "enveredar",
    "enveredaríamos": "enveredar",
    "enveredaríeis": "enveredar",
    "enveredas": "enveredar",
    "enveredasse": "enveredar",
    "enveredassem": "enveredar",
    "enveredasses": "enveredar",
    "enveredaste": "enveredar",
    "enveredastes": "enveredar",
    "enveredava": "enveredar",
    "enveredavam": "enveredar",
    "enveredavas": "enveredar",
    "enverede": "enveredar",
    "enveredei": "enveredar",
    "enveredeis": "enveredar",
    "enveredem": "enveredar",
    "enveredemo": "enveredar",
    "enveredemos": "enveredar",
    "enveredes": "enveredar",
    "enveredo": "enveredar",
    "enveredou": "enveredar",
    "enveredámo": "enveredar",
    "enveredámos": "enveredar",
    "enveredáramo": "enveredar",
    "enveredáramos": "enveredar",
    "enveredáreis": "enveredar",
    "enveredásseis": "enveredar",
    "enveredássemos": "enveredar",
    "enveredávamo": "enveredar",
    "enveredávamos": "enveredar",
    "enveredáveis": "enveredar",
    "enverga": "envergar",
    "envergada": "envergar",
    "envergadas": "envergar",
    "envergado": "envergar",
    "envergados": "envergar",
    "envergaduras": "envergadura",
    "envergai": "envergar",
    "envergais": "envergar",
    "envergam": "envergar",
    "envergamentos": "envergamento",
    "envergamo": "envergar",
    "envergamos": "envergar",
    "envergando": "envergar",
    "envergara": "envergar",
    "envergaram": "envergar",
    "envergaras": "envergar",
    "envergarde": "envergar",
    "envergardes": "envergar",
    "envergare": "envergar",
    "envergarei": "envergar",
    "envergareis": "envergar",
    "envergarem": "envergar",
    "envergaremos": "envergar",
    "envergares": "envergar",
    "envergaria": "envergar",
    "envergariam": "envergar",
    "envergarias": "envergar",
    "envergarmo": "envergar",
    "envergarmos": "envergar",
    "envergará": "envergar",
    "envergarás": "envergar",
    "envergarão": "envergar",
    "envergaríamos": "envergar",
    "envergaríeis": "envergar",
    "envergas": "envergar",
    "envergasse": "envergar",
    "envergassem": "envergar",
    "envergasses": "envergar",
    "envergaste": "envergar",
    "envergastes": "envergar",
    "envergava": "envergar",
    "envergavam": "envergar",
    "envergavas": "envergar",
    "envergo": "envergar",
    "envergonha": "envergonhar",
    "envergonhada": "envergonhar",
    "envergonhadas": "envergonhar",
    "envergonhadelas": "envergonhadela",
    "envergonhado": "envergonhar",
    "envergonhados": "envergonhar",
    "envergonhadíssima": "envergonhado",
    "envergonhadíssimas": "envergonhado",
    "envergonhadíssimo": "envergonhado",
    "envergonhadíssimos": "envergonhado",
    "envergonhai": "envergonhar",
    "envergonhais": "envergonhar",
    "envergonham": "envergonhar",
    "envergonhamo": "envergonhar",
    "envergonhamos": "envergonhar",
    "envergonhando": "envergonhar",
    "envergonhara": "envergonhar",
    "envergonharam": "envergonhar",
    "envergonharas": "envergonhar",
    "envergonharde": "envergonhar",
    "envergonhardes": "envergonhar",
    "envergonhare": "envergonhar",
    "envergonharei": "envergonhar",
    "envergonhareis": "envergonhar",
    "envergonharem": "envergonhar",
    "envergonharemos": "envergonhar",
    "envergonhares": "envergonhar",
    "envergonharia": "envergonhar",
    "envergonhariam": "envergonhar",
    "envergonharias": "envergonhar",
    "envergonharmo": "envergonhar",
    "envergonharmos": "envergonhar",
    "envergonhará": "envergonhar",
    "envergonharás": "envergonhar",
    "envergonharão": "envergonhar",
    "envergonharíamos": "envergonhar",
    "envergonharíeis": "envergonhar",
    "envergonhas": "envergonhar",
    "envergonhasse": "envergonhar",
    "envergonhassem": "envergonhar",
    "envergonhasses": "envergonhar",
    "envergonhaste": "envergonhar",
    "envergonhastes": "envergonhar",
    "envergonhava": "envergonhar",
    "envergonhavam": "envergonhar",
    "envergonhavas": "envergonhar",
    "envergonhe": "envergonhar",
    "envergonhei": "envergonhar",
    "envergonheis": "envergonhar",
    "envergonhem": "envergonhar",
    "envergonhemo": "envergonhar",
    "envergonhemos": "envergonhar",
    "envergonhes": "envergonhar",
    "envergonho": "envergonhar",
    "envergonhou": "envergonhar",
    "envergonhá": "envergonhar",
    "envergonhámo": "envergonhar",
    "envergonhámos": "envergonhar",
    "envergonháramo": "envergonhar",
    "envergonháramos": "envergonhar",
    "envergonhárei": "envergonhar",
    "envergonháreis": "envergonhar",
    "envergonhásseis": "envergonhar",
    "envergonhássemos": "envergonhar",
    "envergonhávamo": "envergonhar",
    "envergonhávamos": "envergonhar",
    "envergonhávei": "envergonhar",
    "envergonháveis": "envergonhar",
    "envergou": "envergar",
    "envergue": "envergar",
    "enverguei": "envergar",
    "envergueis": "envergar",
    "enverguem": "envergar",
    "enverguemo": "envergar",
    "enverguemos": "envergar",
    "envergues": "envergue",
    "envergá": "envergar",
    "envergámo": "envergar",
    "envergámos": "envergar",
    "envergáramo": "envergar",
    "envergáramos": "envergar",
    "envergárei": "envergar",
    "envergáreis": "envergar",
    "envergásseis": "envergar",
    "envergássemos": "envergar",
    "envergávamo": "envergar",
    "envergávamos": "envergar",
    "envergávei": "envergar",
    "envergáveis": "envergar",
    "envermelha": "envermelhar",
    "envermelhada": "envermelhar",
    "envermelhadas": "envermelhar",
    "envermelhado": "envermelhar",
    "envermelhados": "envermelhar",
    "envermelhai": "envermelhar",
    "envermelhais": "envermelhar",
    "envermelham": "envermelhar",
    "envermelhamo": "envermelhar",
    "envermelhamos": "envermelhar",
    "envermelhando": "envermelhar",
    "envermelhara": "envermelhar",
    "envermelharam": "envermelhar",
    "envermelharas": "envermelhar",
    "envermelharde": "envermelhar",
    "envermelhardes": "envermelhar",
    "envermelhare": "envermelhar",
    "envermelharei": "envermelhar",
    "envermelhareis": "envermelhar",
    "envermelharem": "envermelhar",
    "envermelharemos": "envermelhar",
    "envermelhares": "envermelhar",
    "envermelharia": "envermelhar",
    "envermelhariam": "envermelhar",
    "envermelharias": "envermelhar",
    "envermelharmo": "envermelhar",
    "envermelharmos": "envermelhar",
    "envermelhará": "envermelhar",
    "envermelharás": "envermelhar",
    "envermelharão": "envermelhar",
    "envermelharíamos": "envermelhar",
    "envermelharíeis": "envermelhar",
    "envermelhas": "envermelhar",
    "envermelhasse": "envermelhar",
    "envermelhassem": "envermelhar",
    "envermelhasses": "envermelhar",
    "envermelhaste": "envermelhar",
    "envermelhastes": "envermelhar",
    "envermelhava": "envermelhar",
    "envermelhavam": "envermelhar",
    "envermelhavas": "envermelhar",
    "envermelhe": "envermelhar",
    "envermelhece": "envermelhecer",
    "envermelhecei": "envermelhecer",
    "envermelheceis": "envermelhecer",
    "envermelhecem": "envermelhecer",
    "envermelhecemo": "envermelhecer",
    "envermelhecemos": "envermelhecer",
    "envermelhecendo": "envermelhecer",
    "envermelhecera": "envermelhecer",
    "envermelheceram": "envermelhecer",
    "envermelheceras": "envermelhecer",
    "envermelhecerde": "envermelhecer",
    "envermelhecerdes": "envermelhecer",
    "envermelhecere": "envermelhecer",
    "envermelhecerei": "envermelhecer",
    "envermelhecereis": "envermelhecer",
    "envermelhecerem": "envermelhecer",
    "envermelheceremos": "envermelhecer",
    "envermelheceres": "envermelhecer",
    "envermelheceria": "envermelhecer",
    "envermelheceriam": "envermelhecer",
    "envermelhecerias": "envermelhecer",
    "envermelhecermo": "envermelhecer",
    "envermelhecermos": "envermelhecer",
    "envermelhecerá": "envermelhecer",
    "envermelhecerás": "envermelhecer",
    "envermelhecerão": "envermelhecer",
    "envermelheceríamos": "envermelhecer",
    "envermelheceríeis": "envermelhecer",
    "envermelheces": "envermelhecer",
    "envermelhecesse": "envermelhecer",
    "envermelhecessem": "envermelhecer",
    "envermelhecesses": "envermelhecer",
    "envermelheceste": "envermelhecer",
    "envermelhecestes": "envermelhecer",
    "envermelheceu": "envermelhecer",
    "envermelheci": "envermelhecer",
    "envermelhecia": "envermelhecer",
    "envermelheciam": "envermelhecer",
    "envermelhecias": "envermelhecer",
    "envermelhecida": "envermelhecer",
    "envermelhecidas": "envermelhecer",
    "envermelhecido": "envermelhecer",
    "envermelhecidos": "envermelhecer",
    "envermelhecê": "envermelhecer",
    "envermelhecêramo": "envermelhecer",
    "envermelhecêramos": "envermelhecer",
    "envermelhecêrei": "envermelhecer",
    "envermelhecêreis": "envermelhecer",
    "envermelhecêsseis": "envermelhecer",
    "envermelhecêssemos": "envermelhecer",
    "envermelhecíamo": "envermelhecer",
    "envermelhecíamos": "envermelhecer",
    "envermelhecíei": "envermelhecer",
    "envermelhecíeis": "envermelhecer",
    "envermelhei": "envermelhar",
    "envermelheis": "envermelhar",
    "envermelhem": "envermelhar",
    "envermelhemo": "envermelhar",
    "envermelhemos": "envermelhar",
    "envermelhes": "envermelhar",
    "envermelheça": "envermelhecer",
    "envermelheçais": "envermelhecer",
    "envermelheçam": "envermelhecer",
    "envermelheçamo": "envermelhecer",
    "envermelheçamos": "envermelhecer",
    "envermelheças": "envermelhecer",
    "envermelheço": "envermelhecer",
    "envermelho": "envermelhar",
    "envermelhou": "envermelhar",
    "envermelhá": "envermelhar",
    "envermelhámo": "envermelhar",
    "envermelhámos": "envermelhar",
    "envermelháramo": "envermelhar",
    "envermelháramos": "envermelhar",
    "envermelhárei": "envermelhar",
    "envermelháreis": "envermelhar",
    "envermelhásseis": "envermelhar",
    "envermelhássemos": "envermelhar",
    "envermelhávamo": "envermelhar",
    "envermelhávamos": "envermelhar",
    "envermelhávei": "envermelhar",
    "envermelháveis": "envermelhar",
    "enverniza": "envernizar",
    "envernizada": "envernizar",
    "envernizadas": "envernizar",
    "envernizadelas": "envernizadela",
    "envernizado": "envernizar",
    "envernizadora": "envernizador",
    "envernizadoras": "envernizador",
    "envernizadores": "envernizador",
    "envernizados": "envernizar",
    "envernizai": "envernizar",
    "envernizais": "envernizar",
    "envernizam": "envernizar",
    "envernizamentos": "envernizamento",
    "envernizamo": "envernizar",
    "envernizamos": "envernizar",
    "envernizando": "envernizar",
    "envernizara": "envernizar",
    "envernizaram": "envernizar",
    "envernizaras": "envernizar",
    "envernizarde": "envernizar",
    "envernizardes": "envernizar",
    "envernizare": "envernizar",
    "envernizarei": "envernizar",
    "envernizareis": "envernizar",
    "envernizarem": "envernizar",
    "envernizaremos": "envernizar",
    "envernizares": "envernizar",
    "envernizaria": "envernizar",
    "envernizariam": "envernizar",
    "envernizarias": "envernizar",
    "envernizarmo": "envernizar",
    "envernizarmos": "envernizar",
    "envernizará": "envernizar",
    "envernizarás": "envernizar",
    "envernizarão": "envernizar",
    "envernizaríamos": "envernizar",
    "envernizaríeis": "envernizar",
    "envernizas": "envernizar",
    "envernizasse": "envernizar",
    "envernizassem": "envernizar",
    "envernizasses": "envernizar",
    "envernizaste": "envernizar",
    "envernizastes": "envernizar",
    "envernizava": "envernizar",
    "envernizavam": "envernizar",
    "envernizavas": "envernizar",
    "envernize": "envernizar",
    "envernizei": "envernizar",
    "envernizeis": "envernizar",
    "envernizem": "envernizar",
    "envernizemo": "envernizar",
    "envernizemos": "envernizar",
    "envernizes": "envernizar",
    "envernizo": "envernizar",
    "envernizou": "envernizar",
    "envernizá": "envernizar",
    "envernizámo": "envernizar",
    "envernizámos": "envernizar",
    "envernizáramo": "envernizar",
    "envernizáramos": "envernizar",
    "envernizárei": "envernizar",
    "envernizáreis": "envernizar",
    "envernizásseis": "envernizar",
    "envernizássemos": "envernizar",
    "envernizávamo": "envernizar",
    "envernizávamos": "envernizar",
    "envernizávei": "envernizar",
    "envernizáveis": "envernizar",
    "enverruga": "enverrugar",
    "enverrugada": "enverrugar",
    "enverrugadas": "enverrugar",
    "enverrugado": "enverrugar",
    "enverrugados": "enverrugar",
    "enverrugai": "enverrugar",
    "enverrugais": "enverrugar",
    "enverrugam": "enverrugar",
    "enverrugamo": "enverrugar",
    "enverrugamos": "enverrugar",
    "enverrugando": "enverrugar",
    "enverrugara": "enverrugar",
    "enverrugaram": "enverrugar",
    "enverrugaras": "enverrugar",
    "enverrugarde": "enverrugar",
    "enverrugardes": "enverrugar",
    "enverrugare": "enverrugar",
    "enverrugarei": "enverrugar",
    "enverrugareis": "enverrugar",
    "enverrugarem": "enverrugar",
    "enverrugaremos": "enverrugar",
    "enverrugares": "enverrugar",
    "enverrugaria": "enverrugar",
    "enverrugariam": "enverrugar",
    "enverrugarias": "enverrugar",
    "enverrugarmo": "enverrugar",
    "enverrugarmos": "enverrugar",
    "enverrugará": "enverrugar",
    "enverrugarás": "enverrugar",
    "enverrugarão": "enverrugar",
    "enverrugaríamos": "enverrugar",
    "enverrugaríeis": "enverrugar",
    "enverrugas": "enverrugar",
    "enverrugasse": "enverrugar",
    "enverrugassem": "enverrugar",
    "enverrugasses": "enverrugar",
    "enverrugaste": "enverrugar",
    "enverrugastes": "enverrugar",
    "enverrugava": "enverrugar",
    "enverrugavam": "enverrugar",
    "enverrugavas": "enverrugar",
    "enverrugo": "enverrugar",
    "enverrugou": "enverrugar",
    "enverrugue": "enverrugar",
    "enverruguei": "enverrugar",
    "enverrugueis": "enverrugar",
    "enverruguem": "enverrugar",
    "enverruguemo": "enverrugar",
    "enverruguemos": "enverrugar",
    "enverrugues": "enverrugar",
    "enverrugá": "enverrugar",
    "enverrugámo": "enverrugar",
    "enverrugámos": "enverrugar",
    "enverrugáramo": "enverrugar",
    "enverrugáramos": "enverrugar",
    "enverrugárei": "enverrugar",
    "enverrugáreis": "enverrugar",
    "enverrugásseis": "enverrugar",
    "enverrugássemos": "enverrugar",
    "enverrugávamo": "enverrugar",
    "enverrugávamos": "enverrugar",
    "enverrugávei": "enverrugar",
    "enverrugáveis": "enverrugar",
    "envesa": "envesar",
    "envesada": "envesar",
    "envesadas": "envesar",
    "envesado": "envesar",
    "envesados": "envesar",
    "envesai": "envesar",
    "envesais": "envesar",
    "envesam": "envesar",
    "envesamentos": "envesamento",
    "envesamo": "envesar",
    "envesamos": "envesar",
    "envesando": "envesar",
    "envesara": "envesar",
    "envesaram": "envesar",
    "envesaras": "envesar",
    "envesarde": "envesar",
    "envesardes": "envesar",
    "envesare": "envesar",
    "envesarei": "envesar",
    "envesareis": "envesar",
    "envesarem": "envesar",
    "envesaremos": "envesar",
    "envesares": "envesar",
    "envesaria": "envesar",
    "envesariam": "envesar",
    "envesarias": "envesar",
    "envesarmo": "envesar",
    "envesarmos": "envesar",
    "envesará": "envesar",
    "envesarás": "envesar",
    "envesarão": "envesar",
    "envesaríamos": "envesar",
    "envesaríeis": "envesar",
    "envesas": "envesar",
    "envesasse": "envesar",
    "envesassem": "envesar",
    "envesasses": "envesar",
    "envesaste": "envesar",
    "envesastes": "envesar",
    "envesava": "envesar",
    "envesavam": "envesar",
    "envesavas": "envesar",
    "envese": "envesar",
    "envesei": "envesar",
    "enveseis": "envesar",
    "envesem": "envesar",
    "envesemo": "envesar",
    "envesemos": "envesar",
    "enveses": "envesar",
    "envesga": "envesgar",
    "envesgada": "envesgar",
    "envesgadas": "envesgar",
    "envesgado": "envesgar",
    "envesgados": "envesgar",
    "envesgai": "envesgar",
    "envesgais": "envesgar",
    "envesgam": "envesgar",
    "envesgamo": "envesgar",
    "envesgamos": "envesgar",
    "envesgando": "envesgar",
    "envesgara": "envesgar",
    "envesgaram": "envesgar",
    "envesgaras": "envesgar",
    "envesgarde": "envesgar",
    "envesgardes": "envesgar",
    "envesgare": "envesgar",
    "envesgarei": "envesgar",
    "envesgareis": "envesgar",
    "envesgarem": "envesgar",
    "envesgaremos": "envesgar",
    "envesgares": "envesgar",
    "envesgaria": "envesgar",
    "envesgariam": "envesgar",
    "envesgarias": "envesgar",
    "envesgarmo": "envesgar",
    "envesgarmos": "envesgar",
    "envesgará": "envesgar",
    "envesgarás": "envesgar",
    "envesgarão": "envesgar",
    "envesgaríamos": "envesgar",
    "envesgaríeis": "envesgar",
    "envesgas": "envesgar",
    "envesgasse": "envesgar",
    "envesgassem": "envesgar",
    "envesgasses": "envesgar",
    "envesgaste": "envesgar",
    "envesgastes": "envesgar",
    "envesgava": "envesgar",
    "envesgavam": "envesgar",
    "envesgavas": "envesgar",
    "envesgo": "envesgar",
    "envesgou": "envesgar",
    "envesgue": "envesgar",
    "envesguei": "envesgar",
    "envesgueis": "envesgar",
    "envesguem": "envesgar",
    "envesguemo": "envesgar",
    "envesguemos": "envesgar",
    "envesgues": "envesgar",
    "envesgá": "envesgar",
    "envesgámo": "envesgar",
    "envesgámos": "envesgar",
    "envesgáramo": "envesgar",
    "envesgáramos": "envesgar",
    "envesgárei": "envesgar",
    "envesgáreis": "envesgar",
    "envesgásseis": "envesgar",
    "envesgássemos": "envesgar",
    "envesgávamo": "envesgar",
    "envesgávamos": "envesgar",
    "envesgávei": "envesgar",
    "envesgáveis": "envesgar",
    "enveso": "envesar",
    "envesou": "envesar",
    "envessa": "envesso",
    "envessada": "envessar",
    "envessadas": "envessar",
    "envessado": "envessar",
    "envessados": "envessar",
    "envessai": "envessar",
    "envessais": "envessar",
    "envessam": "envessar",
    "envessamentos": "envessamento",
    "envessamo": "envessar",
    "envessamos": "envessar",
    "envessando": "envessar",
    "envessara": "envessar",
    "envessaram": "envessar",
    "envessaras": "envessar",
    "envessarde": "envessar",
    "envessardes": "envessar",
    "envessare": "envessar",
    "envessarei": "envessar",
    "envessareis": "envessar",
    "envessarem": "envessar",
    "envessaremos": "envessar",
    "envessares": "envessar",
    "envessaria": "envessar",
    "envessariam": "envessar",
    "envessarias": "envessar",
    "envessarmo": "envessar",
    "envessarmos": "envessar",
    "envessará": "envessar",
    "envessarás": "envessar",
    "envessarão": "envessar",
    "envessaríamos": "envessar",
    "envessaríeis": "envessar",
    "envessas": "envesso",
    "envessasse": "envessar",
    "envessassem": "envessar",
    "envessasses": "envessar",
    "envessaste": "envessar",
    "envessastes": "envessar",
    "envessava": "envessar",
    "envessavam": "envessar",
    "envessavas": "envessar",
    "envesse": "envessar",
    "envessei": "envessar",
    "envesseis": "envessar",
    "envessem": "envessar",
    "envessemo": "envessar",
    "envessemos": "envessar",
    "envesses": "envessar",
    "envesso": "envessar",
    "envessos": "envesso",
    "envessou": "envessar",
    "envessá": "envessar",
    "envessámo": "envessar",
    "envessámos": "envessar",
    "envessáramo": "envessar",
    "envessáramos": "envessar",
    "envessárei": "envessar",
    "envessáreis": "envessar",
    "envessásseis": "envessar",
    "envessássemos": "envessar",
    "envessávamo": "envessar",
    "envessávamos": "envessar",
    "envessávei": "envessar",
    "envessáveis": "envessar",
    "envesá": "envesar",
    "envesámo": "envesar",
    "envesámos": "envesar",
    "envesáramo": "envesar",
    "envesáramos": "envesar",
    "envesárei": "envesar",
    "envesáreis": "envesar",
    "envesásseis": "envesar",
    "envesássemos": "envesar",
    "envesávamo": "envesar",
    "envesávamos": "envesar",
    "envesávei": "envesar",
    "envesáveis": "envesar",
    "envia": "enviar",
    "enviada": "enviar",
    "enviadas": "enviar",
    "enviado": "enviar",
    "enviados": "enviar",
    "enviai": "enviar",
    "enviais": "enviar",
    "enviam": "enviar",
    "enviamentos": "enviamento",
    "enviamo": "enviar",
    "enviamos": "enviar",
    "enviando": "enviar",
    "enviara": "enviar",
    "enviaram": "enviar",
    "enviaras": "enviar",
    "enviarde": "enviar",
    "enviardes": "enviar",
    "enviare": "enviar",
    "enviarei": "enviar",
    "enviareis": "enviar",
    "enviarem": "enviar",
    "enviaremos": "enviar",
    "enviares": "enviar",
    "enviaria": "enviar",
    "enviariam": "enviar",
    "enviarias": "enviar",
    "enviarmo": "enviar",
    "enviarmos": "enviar",
    "enviará": "enviar",
    "enviarás": "enviar",
    "enviarão": "enviar",
    "enviaríamos": "enviar",
    "enviaríeis": "enviar",
    "envias": "enviar",
    "enviasse": "enviar",
    "enviassem": "enviar",
    "enviasses": "enviar",
    "enviaste": "enviar",
    "enviastes": "enviar",
    "enviava": "enviar",
    "enviavam": "enviar",
    "enviavas": "enviar",
    "envice": "enviçar",
    "envicei": "enviçar",
    "enviceis": "enviçar",
    "envicem": "enviçar",
    "envicemo": "enviçar",
    "envicemos": "enviçar",
    "envices": "enviçar",
    "envida": "envidar",
    "envidada": "envidar",
    "envidadas": "envidar",
    "envidado": "envidar",
    "envidados": "envidar",
    "envidai": "envidar",
    "envidais": "envidar",
    "envidam": "envidar",
    "envidamo": "envidar",
    "envidamos": "envidar",
    "envidando": "envidar",
    "envidara": "envidar",
    "envidaram": "envidar",
    "envidaras": "envidar",
    "envidarde": "envidar",
    "envidardes": "envidar",
    "envidare": "envidar",
    "envidarei": "envidar",
    "envidareis": "envidar",
    "envidarem": "envidar",
    "envidaremos": "envidar",
    "envidares": "envidar",
    "envidaria": "envidar",
    "envidariam": "envidar",
    "envidarias": "envidar",
    "envidarmo": "envidar",
    "envidarmos": "envidar",
    "envidará": "envidar",
    "envidarás": "envidar",
    "envidarão": "envidar",
    "envidaríamos": "envidar",
    "envidaríeis": "envidar",
    "envidas": "envidar",
    "envidasse": "envidar",
    "envidassem": "envidar",
    "envidasses": "envidar",
    "envidaste": "envidar",
    "envidastes": "envidar",
    "envidava": "envidar",
    "envidavam": "envidar",
    "envidavas": "envidar",
    "envide": "envidar",
    "envidei": "envidar",
    "envideis": "envidar",
    "envidem": "envidar",
    "envidemo": "envidar",
    "envidemos": "envidar",
    "envides": "envide",
    "envidilha": "envidilhar",
    "envidilhada": "envidilhar",
    "envidilhadas": "envidilhar",
    "envidilhado": "envidilhar",
    "envidilhados": "envidilhar",
    "envidilhai": "envidilhar",
    "envidilhais": "envidilhar",
    "envidilham": "envidilhar",
    "envidilhamo": "envidilhar",
    "envidilhamos": "envidilhar",
    "envidilhando": "envidilhar",
    "envidilhara": "envidilhar",
    "envidilharam": "envidilhar",
    "envidilharas": "envidilhar",
    "envidilharde": "envidilhar",
    "envidilhardes": "envidilhar",
    "envidilhare": "envidilhar",
    "envidilharei": "envidilhar",
    "envidilhareis": "envidilhar",
    "envidilharem": "envidilhar",
    "envidilharemos": "envidilhar",
    "envidilhares": "envidilhar",
    "envidilharia": "envidilhar",
    "envidilhariam": "envidilhar",
    "envidilharias": "envidilhar",
    "envidilharmo": "envidilhar",
    "envidilharmos": "envidilhar",
    "envidilhará": "envidilhar",
    "envidilharás": "envidilhar",
    "envidilharão": "envidilhar",
    "envidilharíamos": "envidilhar",
    "envidilharíeis": "envidilhar",
    "envidilhas": "envidilhar",
    "envidilhasse": "envidilhar",
    "envidilhassem": "envidilhar",
    "envidilhasses": "envidilhar",
    "envidilhaste": "envidilhar",
    "envidilhastes": "envidilhar",
    "envidilhava": "envidilhar",
    "envidilhavam": "envidilhar",
    "envidilhavas": "envidilhar",
    "envidilhe": "envidilhar",
    "envidilhei": "envidilhar",
    "envidilheis": "envidilhar",
    "envidilhem": "envidilhar",
    "envidilhemo": "envidilhar",
    "envidilhemos": "envidilhar",
    "envidilhes": "envidilhar",
    "envidilho": "envidilhar",
    "envidilhou": "envidilhar",
    "envidilhá": "envidilhar",
    "envidilhámo": "envidilhar",
    "envidilhámos": "envidilhar",
    "envidilháramo": "envidilhar",
    "envidilháramos": "envidilhar",
    "envidilhárei": "envidilhar",
    "envidilháreis": "envidilhar",
    "envidilhásseis": "envidilhar",
    "envidilhássemos": "envidilhar",
    "envidilhávamo": "envidilhar",
    "envidilhávamos": "envidilhar",
    "envidilhávei": "envidilhar",
    "envidilháveis": "envidilhar",
    "envido": "envidar",
    "envidou": "envidar",
    "envidrace": "envidraçar",
    "envidracei": "envidraçar",
    "envidraceis": "envidraçar",
    "envidracem": "envidraçar",
    "envidracemo": "envidraçar",
    "envidracemos": "envidraçar",
    "envidraces": "envidraçar",
    "envidraça": "envidraçar",
    "envidraçada": "envidraçar",
    "envidraçadas": "envidraçar",
    "envidraçado": "envidraçar",
    "envidraçados": "envidraçar",
    "envidraçai": "envidraçar",
    "envidraçais": "envidraçar",
    "envidraçam": "envidraçar",
    "envidraçamentos": "envidraçamento",
    "envidraçamo": "envidraçar",
    "envidraçamos": "envidraçar",
    "envidraçando": "envidraçar",
    "envidraçara": "envidraçar",
    "envidraçaram": "envidraçar",
    "envidraçaras": "envidraçar",
    "envidraçarde": "envidraçar",
    "envidraçardes": "envidraçar",
    "envidraçare": "envidraçar",
    "envidraçarei": "envidraçar",
    "envidraçareis": "envidraçar",
    "envidraçarem": "envidraçar",
    "envidraçaremos": "envidraçar",
    "envidraçares": "envidraçar",
    "envidraçaria": "envidraçar",
    "envidraçariam": "envidraçar",
    "envidraçarias": "envidraçar",
    "envidraçarmo": "envidraçar",
    "envidraçarmos": "envidraçar",
    "envidraçará": "envidraçar",
    "envidraçarás": "envidraçar",
    "envidraçarão": "envidraçar",
    "envidraçaríamos": "envidraçar",
    "envidraçaríeis": "envidraçar",
    "envidraças": "envidraçar",
    "envidraçasse": "envidraçar",
    "envidraçassem": "envidraçar",
    "envidraçasses": "envidraçar",
    "envidraçaste": "envidraçar",
    "envidraçastes": "envidraçar",
    "envidraçava": "envidraçar",
    "envidraçavam": "envidraçar",
    "envidraçavas": "envidraçar",
    "envidraço": "envidraçar",
    "envidraçou": "envidraçar",
    "envidraçá": "envidraçar",
    "envidraçámo": "envidraçar",
    "envidraçámos": "envidraçar",
    "envidraçáramo": "envidraçar",
    "envidraçáramos": "envidraçar",
    "envidraçárei": "envidraçar",
    "envidraçáreis": "envidraçar",
    "envidraçásseis": "envidraçar",
    "envidraçássemos": "envidraçar",
    "envidraçávamo": "envidraçar",
    "envidraçávamos": "envidraçar",
    "envidraçávei": "envidraçar",
    "envidraçáveis": "envidraçar",
    "envidá": "envidar",
    "envidámo": "envidar",
    "envidámos": "envidar",
    "envidáramo": "envidar",
    "envidáramos": "envidar",
    "envidárei": "envidar",
    "envidáreis": "envidar",
    "envidásseis": "envidar",
    "envidássemos": "envidar",
    "envidávamo": "envidar",
    "envidávamos": "envidar",
    "envidávei": "envidar",
    "envidáveis": "envidar",
    "envie": "enviar",
    "enviei": "enviar",
    "envieira": "envieirar",
    "envieirada": "envieirar",
    "envieiradas": "envieirar",
    "envieirado": "envieirar",
    "envieirados": "envieirar",
    "envieirai": "envieirar",
    "envieirais": "envieirar",
    "envieiram": "envieirar",
    "envieiramo": "envieirar",
    "envieiramos": "envieirar",
    "envieirando": "envieirar",
    "envieirara": "envieirar",
    "envieiraram": "envieirar",
    "envieiraras": "envieirar",
    "envieirarde": "envieirar",
    "envieirardes": "envieirar",
    "envieirare": "envieirar",
    "envieirarei": "envieirar",
    "envieirareis": "envieirar",
    "envieirarem": "envieirar",
    "envieiraremos": "envieirar",
    "envieirares": "envieirar",
    "envieiraria": "envieirar",
    "envieirariam": "envieirar",
    "envieirarias": "envieirar",
    "envieirarmo": "envieirar",
    "envieirarmos": "envieirar",
    "envieirará": "envieirar",
    "envieirarás": "envieirar",
    "envieirarão": "envieirar",
    "envieiraríamos": "envieirar",
    "envieiraríeis": "envieirar",
    "envieiras": "envieirar",
    "envieirasse": "envieirar",
    "envieirassem": "envieirar",
    "envieirasses": "envieirar",
    "envieiraste": "envieirar",
    "envieirastes": "envieirar",
    "envieirava": "envieirar",
    "envieiravam": "envieirar",
    "envieiravas": "envieirar",
    "envieire": "envieirar",
    "envieirei": "envieirar",
    "envieireis": "envieirar",
    "envieirem": "envieirar",
    "envieiremo": "envieirar",
    "envieiremos": "envieirar",
    "envieires": "envieirar",
    "envieiro": "envieirar",
    "envieirou": "envieirar",
    "envieirá": "envieirar",
    "envieirámo": "envieirar",
    "envieirámos": "envieirar",
    "envieiráramo": "envieirar",
    "envieiráramos": "envieirar",
    "envieirárei": "envieirar",
    "envieiráreis": "envieirar",
    "envieirásseis": "envieirar",
    "envieirássemos": "envieirar",
    "envieirávamo": "envieirar",
    "envieirávamos": "envieirar",
    "envieirávei": "envieirar",
    "envieiráveis": "envieirar",
    "envieis": "enviar",
    "enviem": "enviar",
    "enviemo": "enviar",
    "enviemos": "enviar",
    "envies": "enviar",
    "enviesa": "enviesar",
    "enviesada": "enviesar",
    "enviesadas": "enviesar",
    "enviesado": "enviesar",
    "enviesados": "enviesar",
    "enviesai": "enviesar",
    "enviesais": "enviesar",
    "enviesam": "enviesar",
    "enviesamentos": "enviesamento",
    "enviesamo": "enviesar",
    "enviesamos": "enviesar",
    "enviesando": "enviesar",
    "enviesara": "enviesar",
    "enviesaram": "enviesar",
    "enviesaras": "enviesar",
    "enviesarde": "enviesar",
    "enviesardes": "enviesar",
    "enviesare": "enviesar",
    "enviesarei": "enviesar",
    "enviesareis": "enviesar",
    "enviesarem": "enviesar",
    "enviesaremos": "enviesar",
    "enviesares": "enviesar",
    "enviesaria": "enviesar",
    "enviesariam": "enviesar",
    "enviesarias": "enviesar",
    "enviesarmo": "enviesar",
    "enviesarmos": "enviesar",
    "enviesará": "enviesar",
    "enviesarás": "enviesar",
    "enviesarão": "enviesar",
    "enviesaríamos": "enviesar",
    "enviesaríeis": "enviesar",
    "enviesas": "enviesar",
    "enviesasse": "enviesar",
    "enviesassem": "enviesar",
    "enviesasses": "enviesar",
    "enviesaste": "enviesar",
    "enviesastes": "enviesar",
    "enviesava": "enviesar",
    "enviesavam": "enviesar",
    "enviesavas": "enviesar",
    "enviese": "enviesar",
    "enviesei": "enviesar",
    "envieseis": "enviesar",
    "enviesem": "enviesar",
    "enviesemo": "enviesar",
    "enviesemos": "enviesar",
    "envieses": "enviesar",
    "envieso": "enviesar",
    "enviesou": "enviesar",
    "enviesá": "enviesar",
    "enviesámo": "enviesar",
    "enviesámos": "enviesar",
    "enviesáramo": "enviesar",
    "enviesáramos": "enviesar",
    "enviesárei": "enviesar",
    "enviesáreis": "enviesar",
    "enviesásseis": "enviesar",
    "enviesássemos": "enviesar",
    "enviesávamo": "enviesar",
    "enviesávamos": "enviesar",
    "enviesávei": "enviesar",
    "enviesáveis": "enviesar",
    "enviga": "envigar",
    "envigada": "envigar",
    "envigadas": "envigar",
    "envigado": "envigar",
    "envigados": "envigar",
    "envigai": "envigar",
    "envigais": "envigar",
    "envigam": "envigar",
    "envigamentos": "envigamento",
    "envigamo": "envigar",
    "envigamos": "envigar",
    "envigando": "envigar",
    "envigara": "envigar",
    "envigaram": "envigar",
    "envigaras": "envigar",
    "envigarde": "envigar",
    "envigardes": "envigar",
    "envigare": "envigar",
    "envigarei": "envigar",
    "envigareis": "envigar",
    "envigarem": "envigar",
    "envigaremos": "envigar",
    "envigares": "envigar",
    "envigaria": "envigar",
    "envigariam": "envigar",
    "envigarias": "envigar",
    "envigarmo": "envigar",
    "envigarmos": "envigar",
    "envigará": "envigar",
    "envigarás": "envigar",
    "envigarão": "envigar",
    "envigaríamos": "envigar",
    "envigaríeis": "envigar",
    "envigas": "envigar",
    "envigasse": "envigar",
    "envigassem": "envigar",
    "envigasses": "envigar",
    "envigaste": "envigar",
    "envigastes": "envigar",
    "envigava": "envigar",
    "envigavam": "envigar",
    "envigavas": "envigar",
    "envigo": "envigar",
    "envigora": "envigorar",
    "envigorada": "envigorar",
    "envigoradas": "envigorar",
    "envigorado": "envigorar",
    "envigorados": "envigorar",
    "envigorai": "envigorar",
    "envigorais": "envigorar",
    "envigoram": "envigorar",
    "envigoramo": "envigorar",
    "envigoramos": "envigorar",
    "envigorando": "envigorar",
    "envigorara": "envigorar",
    "envigoraram": "envigorar",
    "envigoraras": "envigorar",
    "envigorarde": "envigorar",
    "envigorardes": "envigorar",
    "envigorare": "envigorar",
    "envigorarei": "envigorar",
    "envigorareis": "envigorar",
    "envigorarem": "envigorar",
    "envigoraremos": "envigorar",
    "envigorares": "envigorar",
    "envigoraria": "envigorar",
    "envigorariam": "envigorar",
    "envigorarias": "envigorar",
    "envigorarmo": "envigorar",
    "envigorarmos": "envigorar",
    "envigorará": "envigorar",
    "envigorarás": "envigorar",
    "envigorarão": "envigorar",
    "envigoraríamos": "envigorar",
    "envigoraríeis": "envigorar",
    "envigoras": "envigorar",
    "envigorasse": "envigorar",
    "envigorassem": "envigorar",
    "envigorasses": "envigorar",
    "envigoraste": "envigorar",
    "envigorastes": "envigorar",
    "envigorava": "envigorar",
    "envigoravam": "envigorar",
    "envigoravas": "envigorar",
    "envigore": "envigorar",
    "envigorei": "envigorar",
    "envigoreis": "envigorar",
    "envigorem": "envigorar",
    "envigoremo": "envigorar",
    "envigoremos": "envigorar",
    "envigores": "envigorar",
    "envigoro": "envigorar",
    "envigorou": "envigorar",
    "envigorá": "envigorar",
    "envigorámo": "envigorar",
    "envigorámos": "envigorar",
    "envigoráramo": "envigorar",
    "envigoráramos": "envigorar",
    "envigorárei": "envigorar",
    "envigoráreis": "envigorar",
    "envigorásseis": "envigorar",
    "envigorássemos": "envigorar",
    "envigorávamo": "envigorar",
    "envigorávamos": "envigorar",
    "envigorávei": "envigorar",
    "envigoráveis": "envigorar",
    "envigota": "envigotar",
    "envigotada": "envigotar",
    "envigotadas": "envigotar",
    "envigotado": "envigotar",
    "envigotados": "envigotar",
    "envigotai": "envigotar",
    "envigotais": "envigotar",
    "envigotam": "envigotar",
    "envigotamo": "envigotar",
    "envigotamos": "envigotar",
    "envigotando": "envigotar",
    "envigotara": "envigotar",
    "envigotaram": "envigotar",
    "envigotaras": "envigotar",
    "envigotarde": "envigotar",
    "envigotardes": "envigotar",
    "envigotare": "envigotar",
    "envigotarei": "envigotar",
    "envigotareis": "envigotar",
    "envigotarem": "envigotar",
    "envigotaremos": "envigotar",
    "envigotares": "envigotar",
    "envigotaria": "envigotar",
    "envigotariam": "envigotar",
    "envigotarias": "envigotar",
    "envigotarmo": "envigotar",
    "envigotarmos": "envigotar",
    "envigotará": "envigotar",
    "envigotarás": "envigotar",
    "envigotarão": "envigotar",
    "envigotaríamos": "envigotar",
    "envigotaríeis": "envigotar",
    "envigotas": "envigotar",
    "envigotasse": "envigotar",
    "envigotassem": "envigotar",
    "envigotasses": "envigotar",
    "envigotaste": "envigotar",
    "envigotastes": "envigotar",
    "envigotava": "envigotar",
    "envigotavam": "envigotar",
    "envigotavas": "envigotar",
    "envigote": "envigotar",
    "envigotei": "envigotar",
    "envigoteis": "envigotar",
    "envigotem": "envigotar",
    "envigotemo": "envigotar",
    "envigotemos": "envigotar",
    "envigotes": "envigotar",
    "envigoto": "envigotar",
    "envigotou": "envigotar",
    "envigotá": "envigotar",
    "envigotámo": "envigotar",
    "envigotámos": "envigotar",
    "envigotáramo": "envigotar",
    "envigotáramos": "envigotar",
    "envigotárei": "envigotar",
    "envigotáreis": "envigotar",
    "envigotásseis": "envigotar",
    "envigotássemos": "envigotar",
    "envigotávamo": "envigotar",
    "envigotávamos": "envigotar",
    "envigotávei": "envigotar",
    "envigotáveis": "envigotar",
    "envigou": "envigar",
    "envigue": "envigar",
    "enviguei": "envigar",
    "envigueis": "envigar",
    "enviguem": "envigar",
    "enviguemo": "envigar",
    "enviguemos": "envigar",
    "envigues": "envigar",
    "envigá": "envigar",
    "envigámo": "envigar",
    "envigámos": "envigar",
    "envigáramo": "envigar",
    "envigáramos": "envigar",
    "envigárei": "envigar",
    "envigáreis": "envigar",
    "envigásseis": "envigar",
    "envigássemos": "envigar",
    "envigávamo": "envigar",
    "envigávamos": "envigar",
    "envigávei": "envigar",
    "envigáveis": "envigar",
    "envilece": "envilecer",
    "envilecei": "envilecer",
    "envileceis": "envilecer",
    "envilecem": "envilecer",
    "envilecemo": "envilecer",
    "envilecemos": "envilecer",
    "envilecendo": "envilecer",
    "envilecera": "envilecer",
    "envileceram": "envilecer",
    "envileceras": "envilecer",
    "envilecerde": "envilecer",
    "envilecerdes": "envilecer",
    "envilecere": "envilecer",
    "envilecerei": "envilecer",
    "envilecereis": "envilecer",
    "envilecerem": "envilecer",
    "envileceremos": "envilecer",
    "envileceres": "envilecer",
    "envileceria": "envilecer",
    "envileceriam": "envilecer",
    "envilecerias": "envilecer",
    "envilecermo": "envilecer",
    "envilecermos": "envilecer",
    "envilecerá": "envilecer",
    "envilecerás": "envilecer",
    "envilecerão": "envilecer",
    "envileceríamos": "envilecer",
    "envileceríeis": "envilecer",
    "envileces": "envilecer",
    "envilecesse": "envilecer",
    "envilecessem": "envilecer",
    "envilecesses": "envilecer",
    "envileceste": "envilecer",
    "envilecestes": "envilecer",
    "envileceu": "envilecer",
    "envileci": "envilecer",
    "envilecia": "envilecer",
    "envileciam": "envilecer",
    "envilecias": "envilecer",
    "envilecida": "envilecido",
    "envilecidas": "envilecido",
    "envilecido": "envilecer",
    "envilecidos": "envilecido",
    "envilecimentos": "envilecimento",
    "envilecê": "envilecer",
    "envilecêramo": "envilecer",
    "envilecêramos": "envilecer",
    "envilecêrei": "envilecer",
    "envilecêreis": "envilecer",
    "envilecêsseis": "envilecer",
    "envilecêssemos": "envilecer",
    "envilecíamo": "envilecer",
    "envilecíamos": "envilecer",
    "envilecíei": "envilecer",
    "envilecíeis": "envilecer",
    "envileça": "envilecer",
    "envileçais": "envilecer",
    "envileçam": "envilecer",
    "envileçamo": "envilecer",
    "envileçamos": "envilecer",
    "envileças": "envilecer",
    "envileço": "envilecer",
    "envinagra": "envinagrar",
    "envinagrada": "envinagrar",
    "envinagradas": "envinagrar",
    "envinagrado": "envinagrar",
    "envinagrados": "envinagrar",
    "envinagrai": "envinagrar",
    "envinagrais": "envinagrar",
    "envinagram": "envinagrar",
    "envinagramo": "envinagrar",
    "envinagramos": "envinagrar",
    "envinagrando": "envinagrar",
    "envinagrara": "envinagrar",
    "envinagraram": "envinagrar",
    "envinagraras": "envinagrar",
    "envinagrarde": "envinagrar",
    "envinagrardes": "envinagrar",
    "envinagrare": "envinagrar",
    "envinagrarei": "envinagrar",
    "envinagrareis": "envinagrar",
    "envinagrarem": "envinagrar",
    "envinagraremos": "envinagrar",
    "envinagrares": "envinagrar",
    "envinagraria": "envinagrar",
    "envinagrariam": "envinagrar",
    "envinagrarias": "envinagrar",
    "envinagrarmo": "envinagrar",
    "envinagrarmos": "envinagrar",
    "envinagrará": "envinagrar",
    "envinagrarás": "envinagrar",
    "envinagrarão": "envinagrar",
    "envinagraríamos": "envinagrar",
    "envinagraríeis": "envinagrar",
    "envinagras": "envinagrar",
    "envinagrasse": "envinagrar",
    "envinagrassem": "envinagrar",
    "envinagrasses": "envinagrar",
    "envinagraste": "envinagrar",
    "envinagrastes": "envinagrar",
    "envinagrava": "envinagrar",
    "envinagravam": "envinagrar",
    "envinagravas": "envinagrar",
    "envinagre": "envinagrar",
    "envinagrei": "envinagrar",
    "envinagreis": "envinagrar",
    "envinagrem": "envinagrar",
    "envinagremo": "envinagrar",
    "envinagremos": "envinagrar",
    "envinagres": "envinagrar",
    "envinagro": "envinagrar",
    "envinagrou": "envinagrar",
    "envinagrá": "envinagrar",
    "envinagrámo": "envinagrar",
    "envinagrámos": "envinagrar",
    "envinagráramo": "envinagrar",
    "envinagráramos": "envinagrar",
    "envinagrárei": "envinagrar",
    "envinagráreis": "envinagrar",
    "envinagrásseis": "envinagrar",
    "envinagrássemos": "envinagrar",
    "envinagrávamo": "envinagrar",
    "envinagrávamos": "envinagrar",
    "envinagrávei": "envinagrar",
    "envinagráveis": "envinagrar",
    "envio": "enviar",
    "envios": "envio",
    "enviou": "enviar",
    "envipera": "enviperar",
    "enviperada": "enviperar",
    "enviperadas": "enviperar",
    "enviperado": "enviperar",
    "enviperados": "enviperar",
    "enviperai": "enviperar",
    "enviperais": "enviperar",
    "enviperam": "enviperar",
    "enviperamo": "enviperar",
    "enviperamos": "enviperar",
    "enviperando": "enviperar",
    "enviperara": "enviperar",
    "enviperaram": "enviperar",
    "enviperaras": "enviperar",
    "enviperarde": "enviperar",
    "enviperardes": "enviperar",
    "enviperare": "enviperar",
    "enviperarei": "enviperar",
    "enviperareis": "enviperar",
    "enviperarem": "enviperar",
    "enviperaremos": "enviperar",
    "enviperares": "enviperar",
    "enviperaria": "enviperar",
    "enviperariam": "enviperar",
    "enviperarias": "enviperar",
    "enviperarmo": "enviperar",
    "enviperarmos": "enviperar",
    "enviperará": "enviperar",
    "enviperarás": "enviperar",
    "enviperarão": "enviperar",
    "enviperaríamos": "enviperar",
    "enviperaríeis": "enviperar",
    "enviperas": "enviperar",
    "enviperasse": "enviperar",
    "enviperassem": "enviperar",
    "enviperasses": "enviperar",
    "enviperaste": "enviperar",
    "enviperastes": "enviperar",
    "enviperava": "enviperar",
    "enviperavam": "enviperar",
    "enviperavas": "enviperar",
    "envipere": "enviperar",
    "enviperei": "enviperar",
    "envipereis": "enviperar",
    "enviperem": "enviperar",
    "enviperemo": "enviperar",
    "enviperemos": "enviperar",
    "enviperes": "enviperar",
    "envipero": "enviperar",
    "enviperou": "enviperar",
    "enviperá": "enviperar",
    "enviperámo": "enviperar",
    "enviperámos": "enviperar",
    "enviperáramo": "enviperar",
    "enviperáramos": "enviperar",
    "enviperárei": "enviperar",
    "enviperáreis": "enviperar",
    "enviperásseis": "enviperar",
    "enviperássemos": "enviperar",
    "enviperávamo": "enviperar",
    "enviperávamos": "enviperar",
    "enviperávei": "enviperar",
    "enviperáveis": "enviperar",
    "envisca": "enviscar",
    "enviscada": "enviscar",
    "enviscadas": "enviscar",
    "enviscado": "enviscar",
    "enviscados": "enviscar",
    "enviscai": "enviscar",
    "enviscais": "enviscar",
    "enviscam": "enviscar",
    "enviscamo": "enviscar",
    "enviscamos": "enviscar",
    "enviscando": "enviscar",
    "enviscara": "enviscar",
    "enviscaram": "enviscar",
    "enviscaras": "enviscar",
    "enviscarde": "enviscar",
    "enviscardes": "enviscar",
    "enviscare": "enviscar",
    "enviscarei": "enviscar",
    "enviscareis": "enviscar",
    "enviscarem": "enviscar",
    "enviscaremos": "enviscar",
    "enviscares": "enviscar",
    "enviscaria": "enviscar",
    "enviscariam": "enviscar",
    "enviscarias": "enviscar",
    "enviscarmo": "enviscar",
    "enviscarmos": "enviscar",
    "enviscará": "enviscar",
    "enviscarás": "enviscar",
    "enviscarão": "enviscar",
    "enviscaríamos": "enviscar",
    "enviscaríeis": "enviscar",
    "enviscas": "enviscar",
    "enviscasse": "enviscar",
    "enviscassem": "enviscar",
    "enviscasses": "enviscar",
    "enviscaste": "enviscar",
    "enviscastes": "enviscar",
    "enviscava": "enviscar",
    "enviscavam": "enviscar",
    "enviscavas": "enviscar",
    "enviscações": "enviscação",
    "envisco": "enviscar",
    "enviscou": "enviscar",
    "enviscá": "enviscar",
    "enviscámo": "enviscar",
    "enviscámos": "enviscar",
    "enviscáramo": "enviscar",
    "enviscáramos": "enviscar",
    "enviscárei": "enviscar",
    "enviscáreis": "enviscar",
    "enviscásseis": "enviscar",
    "enviscássemos": "enviscar",
    "enviscávamo": "enviscar",
    "enviscávamos": "enviscar",
    "enviscávei": "enviscar",
    "enviscáveis": "enviscar",
    "envisga": "envisgar",
    "envisgada": "envisgar",
    "envisgadas": "envisgar",
    "envisgado": "envisgar",
    "envisgados": "envisgar",
    "envisgai": "envisgar",
    "envisgais": "envisgar",
    "envisgam": "envisgar",
    "envisgamo": "envisgar",
    "envisgamos": "envisgar",
    "envisgando": "envisgar",
    "envisgara": "envisgar",
    "envisgaram": "envisgar",
    "envisgaras": "envisgar",
    "envisgarde": "envisgar",
    "envisgardes": "envisgar",
    "envisgare": "envisgar",
    "envisgarei": "envisgar",
    "envisgareis": "envisgar",
    "envisgarem": "envisgar",
    "envisgaremos": "envisgar",
    "envisgares": "envisgar",
    "envisgaria": "envisgar",
    "envisgariam": "envisgar",
    "envisgarias": "envisgar",
    "envisgarmo": "envisgar",
    "envisgarmos": "envisgar",
    "envisgará": "envisgar",
    "envisgarás": "envisgar",
    "envisgarão": "envisgar",
    "envisgaríamos": "envisgar",
    "envisgaríeis": "envisgar",
    "envisgas": "envisgar",
    "envisgasse": "envisgar",
    "envisgassem": "envisgar",
    "envisgasses": "envisgar",
    "envisgaste": "envisgar",
    "envisgastes": "envisgar",
    "envisgava": "envisgar",
    "envisgavam": "envisgar",
    "envisgavas": "envisgar",
    "envisgo": "envisgar",
    "envisgou": "envisgar",
    "envisgue": "envisgar",
    "envisguei": "envisgar",
    "envisgueis": "envisgar",
    "envisguem": "envisgar",
    "envisguemo": "envisgar",
    "envisguemos": "envisgar",
    "envisgues": "envisgar",
    "envisgá": "envisgar",
    "envisgámo": "envisgar",
    "envisgámos": "envisgar",
    "envisgáramo": "envisgar",
    "envisgáramos": "envisgar",
    "envisgárei": "envisgar",
    "envisgáreis": "envisgar",
    "envisgásseis": "envisgar",
    "envisgássemos": "envisgar",
    "envisgávamo": "envisgar",
    "envisgávamos": "envisgar",
    "envisgávei": "envisgar",
    "envisgáveis": "envisgar",
    "envisque": "enviscar",
    "envisquei": "enviscar",
    "envisqueis": "enviscar",
    "envisquem": "enviscar",
    "envisquemo": "enviscar",
    "envisquemos": "enviscar",
    "envisques": "enviscar",
    "enviuva": "enviuvar",
    "enviuvada": "enviuvar",
    "enviuvadas": "enviuvar",
    "enviuvado": "enviuvar",
    "enviuvados": "enviuvar",
    "enviuvai": "enviuvar",
    "enviuvais": "enviuvar",
    "enviuvam": "enviuvar",
    "enviuvamo": "enviuvar",
    "enviuvamos": "enviuvar",
    "enviuvando": "enviuvar",
    "enviuvara": "enviuvar",
    "enviuvaram": "enviuvar",
    "enviuvaras": "enviuvar",
    "enviuvardes": "enviuvar",
    "enviuvarei": "enviuvar",
    "enviuvareis": "enviuvar",
    "enviuvarem": "enviuvar",
    "enviuvaremos": "enviuvar",
    "enviuvares": "enviuvar",
    "enviuvaria": "enviuvar",
    "enviuvariam": "enviuvar",
    "enviuvarias": "enviuvar",
    "enviuvarmo": "enviuvar",
    "enviuvarmos": "enviuvar",
    "enviuvará": "enviuvar",
    "enviuvarás": "enviuvar",
    "enviuvarão": "enviuvar",
    "enviuvaríamos": "enviuvar",
    "enviuvaríeis": "enviuvar",
    "enviuvas": "enviuvar",
    "enviuvasse": "enviuvar",
    "enviuvassem": "enviuvar",
    "enviuvasses": "enviuvar",
    "enviuvaste": "enviuvar",
    "enviuvastes": "enviuvar",
    "enviuvava": "enviuvar",
    "enviuvavam": "enviuvar",
    "enviuvavas": "enviuvar",
    "enviuve": "enviuvar",
    "enviuvei": "enviuvar",
    "enviuveis": "enviuvar",
    "enviuvem": "enviuvar",
    "enviuvemo": "enviuvar",
    "enviuvemos": "enviuvar",
    "enviuves": "enviuvar",
    "enviuvo": "enviuvar",
    "enviuvou": "enviuvar",
    "enviuvámo": "enviuvar",
    "enviuvámos": "enviuvar",
    "enviuváramo": "enviuvar",
    "enviuváramos": "enviuvar",
    "enviuváreis": "enviuvar",
    "enviuvásseis": "enviuvar",
    "enviuvássemos": "enviuvar",
    "enviuvávamo": "enviuvar",
    "enviuvávamos": "enviuvar",
    "enviuváveis": "enviuvar",
    "enviveira": "enviveirar",
    "enviveirada": "enviveirar",
    "enviveiradas": "enviveirar",
    "enviveirado": "enviveirar",
    "enviveirados": "enviveirar",
    "enviveirai": "enviveirar",
    "enviveirais": "enviveirar",
    "enviveiram": "enviveirar",
    "enviveiramo": "enviveirar",
    "enviveiramos": "enviveirar",
    "enviveirando": "enviveirar",
    "enviveirara": "enviveirar",
    "enviveiraram": "enviveirar",
    "enviveiraras": "enviveirar",
    "enviveirarde": "enviveirar",
    "enviveirardes": "enviveirar",
    "enviveirare": "enviveirar",
    "enviveirarei": "enviveirar",
    "enviveirareis": "enviveirar",
    "enviveirarem": "enviveirar",
    "enviveiraremos": "enviveirar",
    "enviveirares": "enviveirar",
    "enviveiraria": "enviveirar",
    "enviveirariam": "enviveirar",
    "enviveirarias": "enviveirar",
    "enviveirarmo": "enviveirar",
    "enviveirarmos": "enviveirar",
    "enviveirará": "enviveirar",
    "enviveirarás": "enviveirar",
    "enviveirarão": "enviveirar",
    "enviveiraríamos": "enviveirar",
    "enviveiraríeis": "enviveirar",
    "enviveiras": "enviveirar",
    "enviveirasse": "enviveirar",
    "enviveirassem": "enviveirar",
    "enviveirasses": "enviveirar",
    "enviveiraste": "enviveirar",
    "enviveirastes": "enviveirar",
    "enviveirava": "enviveirar",
    "enviveiravam": "enviveirar",
    "enviveiravas": "enviveirar",
    "enviveire": "enviveirar",
    "enviveirei": "enviveirar",
    "enviveireis": "enviveirar",
    "enviveirem": "enviveirar",
    "enviveiremo": "enviveirar",
    "enviveiremos": "enviveirar",
    "enviveires": "enviveirar",
    "enviveiro": "enviveirar",
    "enviveirou": "enviveirar",
    "enviveirá": "enviveirar",
    "enviveirámo": "enviveirar",
    "enviveirámos": "enviveirar",
    "enviveiráramo": "enviveirar",
    "enviveiráramos": "enviveirar",
    "enviveirárei": "enviveirar",
    "enviveiráreis": "enviveirar",
    "enviveirásseis": "enviveirar",
    "enviveirássemos": "enviveirar",
    "enviveirávamo": "enviveirar",
    "enviveirávamos": "enviveirar",
    "enviveirávei": "enviveirar",
    "enviveiráveis": "enviveirar",
    "enviá": "enviar",
    "enviámo": "enviar",
    "enviámos": "enviar",
    "enviáramo": "enviar",
    "enviáramos": "enviar",
    "enviárei": "enviar",
    "enviáreis": "enviar",
    "enviásseis": "enviar",
    "enviássemos": "enviar",
    "enviávamo": "enviar",
    "enviávamos": "enviar",
    "enviávei": "enviar",
    "enviáveis": "enviar",
    "enviça": "enviçar",
    "enviçada": "enviçar",
    "enviçadas": "enviçar",
    "enviçado": "enviçar",
    "enviçados": "enviçar",
    "enviçai": "enviçar",
    "enviçais": "enviçar",
    "enviçam": "enviçar",
    "enviçamo": "enviçar",
    "enviçamos": "enviçar",
    "enviçando": "enviçar",
    "enviçara": "enviçar",
    "enviçaram": "enviçar",
    "enviçaras": "enviçar",
    "enviçarde": "enviçar",
    "enviçardes": "enviçar",
    "enviçare": "enviçar",
    "enviçarei": "enviçar",
    "enviçareis": "enviçar",
    "enviçarem": "enviçar",
    "enviçaremos": "enviçar",
    "enviçares": "enviçar",
    "enviçaria": "enviçar",
    "enviçariam": "enviçar",
    "enviçarias": "enviçar",
    "enviçarmo": "enviçar",
    "enviçarmos": "enviçar",
    "enviçará": "enviçar",
    "enviçarás": "enviçar",
    "enviçarão": "enviçar",
    "enviçaríamos": "enviçar",
    "enviçaríeis": "enviçar",
    "enviças": "enviçar",
    "enviçasse": "enviçar",
    "enviçassem": "enviçar",
    "enviçasses": "enviçar",
    "enviçaste": "enviçar",
    "enviçastes": "enviçar",
    "enviçava": "enviçar",
    "enviçavam": "enviçar",
    "enviçavas": "enviçar",
    "enviço": "enviçar",
    "enviçou": "enviçar",
    "enviçá": "enviçar",
    "enviçámo": "enviçar",
    "enviçámos": "enviçar",
    "enviçáramo": "enviçar",
    "enviçáramos": "enviçar",
    "enviçárei": "enviçar",
    "enviçáreis": "enviçar",
    "enviçásseis": "enviçar",
    "enviçássemos": "enviçar",
    "enviçávamo": "enviçar",
    "enviçávamos": "enviçar",
    "enviçávei": "enviçar",
    "enviçáveis": "enviçar",
    "envolta": "envolto",
    "envoltas": "envolto",
    "envoltos": "envolto",
    "envolturas": "envoltura",
    "envoltórias": "envoltória",
    "envoltórios": "envoltório",
    "envolva": "envolver",
    "envolvais": "envolver",
    "envolvam": "envolver",
    "envolvamo": "envolver",
    "envolvamos": "envolver",
    "envolvas": "envolver",
    "envolve": "envolver",
    "envolvei": "envolver",
    "envolveis": "envolver",
    "envolvem": "envolver",
    "envolvemo": "envolver",
    "envolvemos": "envolver",
    "envolvendo": "envolver",
    "envolventes": "envolvente",
    "envolvera": "envolver",
    "envolveram": "envolver",
    "envolveras": "envolver",
    "envolverde": "envolver",
    "envolverdes": "envolver",
    "envolvere": "envolver",
    "envolverei": "envolver",
    "envolvereis": "envolver",
    "envolverem": "envolver",
    "envolveremos": "envolver",
    "envolveres": "envolver",
    "envolveria": "envolver",
    "envolveriam": "envolver",
    "envolverias": "envolver",
    "envolvermo": "envolver",
    "envolvermos": "envolver",
    "envolverá": "envolver",
    "envolverás": "envolver",
    "envolverão": "envolver",
    "envolveríamos": "envolver",
    "envolveríeis": "envolver",
    "envolves": "envolver",
    "envolvesse": "envolver",
    "envolvessem": "envolver",
    "envolvesses": "envolver",
    "envolveste": "envolver",
    "envolvestes": "envolver",
    "envolveu": "envolver",
    "envolvi": "envolver",
    "envolvia": "envolver",
    "envolviam": "envolver",
    "envolvias": "envolver",
    "envolvida": "envolvido",
    "envolvidas": "envolvido",
    "envolvido": "envolver",
    "envolvidos": "envolvido",
    "envolvidíssima": "envolvido",
    "envolvidíssimas": "envolvido",
    "envolvidíssimo": "envolvido",
    "envolvidíssimos": "envolvido",
    "envolvimentos": "envolvimento",
    "envolvo": "envolver",
    "envolvê": "envolver",
    "envolvências": "envolvência",
    "envolvêramo": "envolver",
    "envolvêramos": "envolver",
    "envolvêrei": "envolver",
    "envolvêreis": "envolver",
    "envolvêsseis": "envolver",
    "envolvêssemos": "envolver",
    "envolvíamo": "envolver",
    "envolvíamos": "envolver",
    "envolvíei": "envolver",
    "envolvíeis": "envolver",
    "enxabida": "enxabido",
    "enxabidas": "enxabido",
    "enxabidezes": "enxabidez",
    "enxabidos": "enxabido",
    "enxacas": "enxaca",
    "enxacoca": "enxacoco",
    "enxacocas": "enxacoco",
    "enxacocos": "enxacoco",
    "enxadadas": "enxadada",
    "enxadas": "enxada",
    "enxadreias": "enxadreia",
    "enxadreza": "enxadrezar",
    "enxadrezada": "enxadrezar",
    "enxadrezadas": "enxadrezar",
    "enxadrezado": "enxadrezar",
    "enxadrezados": "enxadrezar",
    "enxadrezai": "enxadrezar",
    "enxadrezais": "enxadrezar",
    "enxadrezam": "enxadrezar",
    "enxadrezamo": "enxadrezar",
    "enxadrezamos": "enxadrezar",
    "enxadrezando": "enxadrezar",
    "enxadrezara": "enxadrezar",
    "enxadrezaram": "enxadrezar",
    "enxadrezaras": "enxadrezar",
    "enxadrezarde": "enxadrezar",
    "enxadrezardes": "enxadrezar",
    "enxadrezare": "enxadrezar",
    "enxadrezarei": "enxadrezar",
    "enxadrezareis": "enxadrezar",
    "enxadrezarem": "enxadrezar",
    "enxadrezaremos": "enxadrezar",
    "enxadrezares": "enxadrezar",
    "enxadrezaria": "enxadrezar",
    "enxadrezariam": "enxadrezar",
    "enxadrezarias": "enxadrezar",
    "enxadrezarmo": "enxadrezar",
    "enxadrezarmos": "enxadrezar",
    "enxadrezará": "enxadrezar",
    "enxadrezarás": "enxadrezar",
    "enxadrezarão": "enxadrezar",
    "enxadrezaríamos": "enxadrezar",
    "enxadrezaríeis": "enxadrezar",
    "enxadrezas": "enxadrezar",
    "enxadrezasse": "enxadrezar",
    "enxadrezassem": "enxadrezar",
    "enxadrezasses": "enxadrezar",
    "enxadrezaste": "enxadrezar",
    "enxadrezastes": "enxadrezar",
    "enxadrezava": "enxadrezar",
    "enxadrezavam": "enxadrezar",
    "enxadrezavas": "enxadrezar",
    "enxadreze": "enxadrezar",
    "enxadrezei": "enxadrezar",
    "enxadrezeis": "enxadrezar",
    "enxadrezem": "enxadrezar",
    "enxadrezemo": "enxadrezar",
    "enxadrezemos": "enxadrezar",
    "enxadrezes": "enxadrezar",
    "enxadrezo": "enxadrezar",
    "enxadrezou": "enxadrezar",
    "enxadrezá": "enxadrezar",
    "enxadrezámo": "enxadrezar",
    "enxadrezámos": "enxadrezar",
    "enxadrezáramo": "enxadrezar",
    "enxadrezáramos": "enxadrezar",
    "enxadrezárei": "enxadrezar",
    "enxadrezáreis": "enxadrezar",
    "enxadrezásseis": "enxadrezar",
    "enxadrezássemos": "enxadrezar",
    "enxadrezávamo": "enxadrezar",
    "enxadrezávamos": "enxadrezar",
    "enxadrezávei": "enxadrezar",
    "enxadrezáveis": "enxadrezar",
    "enxadões": "enxadão",
    "enxagua": "enxaguar",
    "enxaguada": "enxaguar",
    "enxaguadas": "enxaguar",
    "enxaguadelas": "enxaguadela",
    "enxaguado": "enxaguar",
    "enxaguadoiros": "enxaguadoiro",
    "enxaguados": "enxaguar",
    "enxaguadouros": "enxaguadouro",
    "enxaguaduras": "enxaguadura",
    "enxaguai": "enxaguar",
    "enxaguais": "enxaguar",
    "enxaguam": "enxaguar",
    "enxaguamo": "enxaguar",
    "enxaguamos": "enxaguar",
    "enxaguando": "enxaguar",
    "enxaguara": "enxaguar",
    "enxaguaram": "enxaguar",
    "enxaguaras": "enxaguar",
    "enxaguarde": "enxaguar",
    "enxaguardes": "enxaguar",
    "enxaguare": "enxaguar",
    "enxaguarei": "enxaguar",
    "enxaguareis": "enxaguar",
    "enxaguarem": "enxaguar",
    "enxaguaremos": "enxaguar",
    "enxaguares": "enxaguar",
    "enxaguaria": "enxaguar",
    "enxaguariam": "enxaguar",
    "enxaguarias": "enxaguar",
    "enxaguarmo": "enxaguar",
    "enxaguarmos": "enxaguar",
    "enxaguará": "enxaguar",
    "enxaguarás": "enxaguar",
    "enxaguarão": "enxaguar",
    "enxaguaríamos": "enxaguar",
    "enxaguaríeis": "enxaguar",
    "enxaguas": "enxaguar",
    "enxaguasse": "enxaguar",
    "enxaguassem": "enxaguar",
    "enxaguasses": "enxaguar",
    "enxaguaste": "enxaguar",
    "enxaguastes": "enxaguar",
    "enxaguava": "enxaguar",
    "enxaguavam": "enxaguar",
    "enxaguavas": "enxaguar",
    "enxaguei": "enxaguar",
    "enxagueis": "enxaguar",
    "enxaguemo": "enxaguar",
    "enxaguemos": "enxaguar",
    "enxagues": "enxaguar",
    "enxaguo": "enxaguar",
    "enxaguou": "enxaguar",
    "enxaguá": "enxaguar",
    "enxaguámo": "enxaguar",
    "enxaguámos": "enxaguar",
    "enxaguáramo": "enxaguar",
    "enxaguáramos": "enxaguar",
    "enxaguárei": "enxaguar",
    "enxaguáreis": "enxaguar",
    "enxaguásseis": "enxaguar",
    "enxaguássemos": "enxaguar",
    "enxaguávamo": "enxaguar",
    "enxaguávamos": "enxaguar",
    "enxaguávei": "enxaguar",
    "enxaguáveis": "enxaguar",
    "enxaguões": "enxaguão",
    "enxagúe": "enxaguar",
    "enxagúem": "enxaguar",
    "enxagúes": "enxaguar",
    "enxaimeles": "enxaimel",
    "enxaiméis": "enxaimel",
    "enxairelada": "enxairelado",
    "enxaireladas": "enxairelado",
    "enxairelados": "enxairelado",
    "enxalava": "enxalavar",
    "enxalavada": "enxalavar",
    "enxalavadas": "enxalavar",
    "enxalavado": "enxalavar",
    "enxalavados": "enxalavar",
    "enxalavai": "enxalavar",
    "enxalavais": "enxalavar",
    "enxalavam": "enxalavar",
    "enxalavamo": "enxalavar",
    "enxalavamos": "enxalavar",
    "enxalavando": "enxalavar",
    "enxalavara": "enxalavar",
    "enxalavaram": "enxalavar",
    "enxalavaras": "enxalavar",
    "enxalavarde": "enxalavar",
    "enxalavardes": "enxalavar",
    "enxalavare": "enxalavar",
    "enxalavarei": "enxalavar",
    "enxalavareis": "enxalavar",
    "enxalavarem": "enxalavar",
    "enxalavaremos": "enxalavar",
    "enxalavares": "enxalavar",
    "enxalavaria": "enxalavar",
    "enxalavariam": "enxalavar",
    "enxalavarias": "enxalavar",
    "enxalavarmo": "enxalavar",
    "enxalavarmos": "enxalavar",
    "enxalavará": "enxalavar",
    "enxalavarás": "enxalavar",
    "enxalavarão": "enxalavar",
    "enxalavaríamos": "enxalavar",
    "enxalavaríeis": "enxalavar",
    "enxalavas": "enxalavar",
    "enxalavasse": "enxalavar",
    "enxalavassem": "enxalavar",
    "enxalavasses": "enxalavar",
    "enxalavaste": "enxalavar",
    "enxalavastes": "enxalavar",
    "enxalavava": "enxalavar",
    "enxalavavam": "enxalavar",
    "enxalavavas": "enxalavar",
    "enxalave": "enxalavar",
    "enxalavei": "enxalavar",
    "enxalaveis": "enxalavar",
    "enxalavem": "enxalavar",
    "enxalavemo": "enxalavar",
    "enxalavemos": "enxalavar",
    "enxalaves": "enxalavar",
    "enxalavia": "enxalaviar",
    "enxalaviada": "enxalaviar",
    "enxalaviadas": "enxalaviar",
    "enxalaviado": "enxalaviar",
    "enxalaviadora": "enxalaviador",
    "enxalaviadoras": "enxalaviador",
    "enxalaviadores": "enxalaviador",
    "enxalaviados": "enxalaviar",
    "enxalaviaduras": "enxalaviadura",
    "enxalaviai": "enxalaviar",
    "enxalaviais": "enxalaviar",
    "enxalaviam": "enxalaviar",
    "enxalaviamo": "enxalaviar",
    "enxalaviamos": "enxalaviar",
    "enxalaviando": "enxalaviar",
    "enxalaviara": "enxalaviar",
    "enxalaviaram": "enxalaviar",
    "enxalaviaras": "enxalaviar",
    "enxalaviarde": "enxalaviar",
    "enxalaviardes": "enxalaviar",
    "enxalaviare": "enxalaviar",
    "enxalaviarei": "enxalaviar",
    "enxalaviareis": "enxalaviar",
    "enxalaviarem": "enxalaviar",
    "enxalaviaremos": "enxalaviar",
    "enxalaviares": "enxalaviar",
    "enxalaviaria": "enxalaviar",
    "enxalaviariam": "enxalaviar",
    "enxalaviarias": "enxalaviar",
    "enxalaviarmo": "enxalaviar",
    "enxalaviarmos": "enxalaviar",
    "enxalaviará": "enxalaviar",
    "enxalaviarás": "enxalaviar",
    "enxalaviarão": "enxalaviar",
    "enxalaviaríamos": "enxalaviar",
    "enxalaviaríeis": "enxalaviar",
    "enxalavias": "enxalaviar",
    "enxalaviasse": "enxalaviar",
    "enxalaviassem": "enxalaviar",
    "enxalaviasses": "enxalaviar",
    "enxalaviaste": "enxalaviar",
    "enxalaviastes": "enxalaviar",
    "enxalaviava": "enxalaviar",
    "enxalaviavam": "enxalaviar",
    "enxalaviavas": "enxalaviar",
    "enxalavie": "enxalaviar",
    "enxalaviei": "enxalaviar",
    "enxalavieis": "enxalaviar",
    "enxalaviem": "enxalaviar",
    "enxalaviemo": "enxalaviar",
    "enxalaviemos": "enxalaviar",
    "enxalavies": "enxalaviar",
    "enxalavio": "enxalaviar",
    "enxalaviou": "enxalaviar",
    "enxalaviá": "enxalaviar",
    "enxalaviámo": "enxalaviar",
    "enxalaviámos": "enxalaviar",
    "enxalaviáramo": "enxalaviar",
    "enxalaviáramos": "enxalaviar",
    "enxalaviárei": "enxalaviar",
    "enxalaviáreis": "enxalaviar",
    "enxalaviásseis": "enxalaviar",
    "enxalaviássemos": "enxalaviar",
    "enxalaviávamo": "enxalaviar",
    "enxalaviávamos": "enxalaviar",
    "enxalaviávei": "enxalaviar",
    "enxalaviáveis": "enxalaviar",
    "enxalavo": "enxalavar",
    "enxalavou": "enxalavar",
    "enxalavá": "enxalavar",
    "enxalavámo": "enxalavar",
    "enxalavámos": "enxalavar",
    "enxalaváramo": "enxalavar",
    "enxalaváramos": "enxalavar",
    "enxalavárei": "enxalavar",
    "enxalaváreis": "enxalavar",
    "enxalavásseis": "enxalavar",
    "enxalavássemos": "enxalavar",
    "enxalavávamo": "enxalavar",
    "enxalavávamos": "enxalavar",
    "enxalavávei": "enxalavar",
    "enxalaváveis": "enxalavar",
    "enxalma": "enxalmar",
    "enxalmada": "enxalmar",
    "enxalmadas": "enxalmar",
    "enxalmado": "enxalmar",
    "enxalmadora": "enxalmador",
    "enxalmadoras": "enxalmador",
    "enxalmadores": "enxalmador",
    "enxalmados": "enxalmar",
    "enxalmai": "enxalmar",
    "enxalmais": "enxalmar",
    "enxalmam": "enxalmar",
    "enxalmamo": "enxalmar",
    "enxalmamos": "enxalmar",
    "enxalmando": "enxalmar",
    "enxalmara": "enxalmar",
    "enxalmaram": "enxalmar",
    "enxalmaras": "enxalmar",
    "enxalmarde": "enxalmar",
    "enxalmardes": "enxalmar",
    "enxalmare": "enxalmar",
    "enxalmarei": "enxalmar",
    "enxalmareis": "enxalmar",
    "enxalmarem": "enxalmar",
    "enxalmaremos": "enxalmar",
    "enxalmares": "enxalmar",
    "enxalmaria": "enxalmar",
    "enxalmariam": "enxalmar",
    "enxalmarias": "enxalmar",
    "enxalmarmo": "enxalmar",
    "enxalmarmos": "enxalmar",
    "enxalmará": "enxalmar",
    "enxalmarás": "enxalmar",
    "enxalmarão": "enxalmar",
    "enxalmaríamos": "enxalmar",
    "enxalmaríeis": "enxalmar",
    "enxalmas": "enxalmar",
    "enxalmasse": "enxalmar",
    "enxalmassem": "enxalmar",
    "enxalmasses": "enxalmar",
    "enxalmaste": "enxalmar",
    "enxalmastes": "enxalmar",
    "enxalmava": "enxalmar",
    "enxalmavam": "enxalmar",
    "enxalmavas": "enxalmar",
    "enxalme": "enxalmar",
    "enxalmei": "enxalmar",
    "enxalmeiros": "enxalmeiro",
    "enxalmeis": "enxalmar",
    "enxalmem": "enxalmar",
    "enxalmemo": "enxalmar",
    "enxalmemos": "enxalmar",
    "enxalmes": "enxalmar",
    "enxalmo": "enxalmar",
    "enxalmos": "enxalmo",
    "enxalmou": "enxalmar",
    "enxalmá": "enxalmar",
    "enxalmámo": "enxalmar",
    "enxalmámos": "enxalmar",
    "enxalmáramo": "enxalmar",
    "enxalmáramos": "enxalmar",
    "enxalmárei": "enxalmar",
    "enxalmáreis": "enxalmar",
    "enxalmásseis": "enxalmar",
    "enxalmássemos": "enxalmar",
    "enxalmávamo": "enxalmar",
    "enxalmávamos": "enxalmar",
    "enxalmávei": "enxalmar",
    "enxalmáveis": "enxalmar",
    "enxamas": "enxama",
    "enxambla": "enxamblar",
    "enxamblada": "enxamblar",
    "enxambladas": "enxamblar",
    "enxamblado": "enxamblar",
    "enxambladora": "enxamblador",
    "enxambladoras": "enxamblador",
    "enxambladores": "enxamblador",
    "enxamblados": "enxamblar",
    "enxamblai": "enxamblar",
    "enxamblais": "enxamblar",
    "enxamblam": "enxamblar",
    "enxamblamo": "enxamblar",
    "enxamblamos": "enxamblar",
    "enxamblando": "enxamblar",
    "enxamblara": "enxamblar",
    "enxamblaram": "enxamblar",
    "enxamblaras": "enxamblar",
    "enxamblarde": "enxamblar",
    "enxamblardes": "enxamblar",
    "enxamblare": "enxamblar",
    "enxamblarei": "enxamblar",
    "enxamblareis": "enxamblar",
    "enxamblarem": "enxamblar",
    "enxamblaremos": "enxamblar",
    "enxamblares": "enxamblar",
    "enxamblaria": "enxamblar",
    "enxamblariam": "enxamblar",
    "enxamblarias": "enxamblar",
    "enxamblarmo": "enxamblar",
    "enxamblarmos": "enxamblar",
    "enxamblará": "enxamblar",
    "enxamblarás": "enxamblar",
    "enxamblarão": "enxamblar",
    "enxamblaríamos": "enxamblar",
    "enxamblaríeis": "enxamblar",
    "enxamblas": "enxamblar",
    "enxamblasse": "enxamblar",
    "enxamblassem": "enxamblar",
    "enxamblasses": "enxamblar",
    "enxamblaste": "enxamblar",
    "enxamblastes": "enxamblar",
    "enxamblava": "enxamblar",
    "enxamblavam": "enxamblar",
    "enxamblavas": "enxamblar",
    "enxamble": "enxamblar",
    "enxamblei": "enxamblar",
    "enxambleis": "enxamblar",
    "enxamblem": "enxamblar",
    "enxamblemo": "enxamblar",
    "enxamblemos": "enxamblar",
    "enxambles": "enxamblar",
    "enxamblo": "enxamblar",
    "enxamblou": "enxamblar",
    "enxamblá": "enxamblar",
    "enxamblámo": "enxamblar",
    "enxamblámos": "enxamblar",
    "enxambláramo": "enxamblar",
    "enxambláramos": "enxamblar",
    "enxamblárei": "enxamblar",
    "enxambláreis": "enxamblar",
    "enxamblásseis": "enxamblar",
    "enxamblássemos": "enxamblar",
    "enxamblávamo": "enxamblar",
    "enxamblávamos": "enxamblar",
    "enxamblávei": "enxamblar",
    "enxambláveis": "enxamblar",
    "enxambra": "enxambrar",
    "enxambrada": "enxambrar",
    "enxambradas": "enxambrar",
    "enxambrado": "enxambrar",
    "enxambrados": "enxambrar",
    "enxambrai": "enxambrar",
    "enxambrais": "enxambrar",
    "enxambram": "enxambrar",
    "enxambramo": "enxambrar",
    "enxambramos": "enxambrar",
    "enxambrando": "enxambrar",
    "enxambrara": "enxambrar",
    "enxambraram": "enxambrar",
    "enxambraras": "enxambrar",
    "enxambrarde": "enxambrar",
    "enxambrardes": "enxambrar",
    "enxambrare": "enxambrar",
    "enxambrarei": "enxambrar",
    "enxambrareis": "enxambrar",
    "enxambrarem": "enxambrar",
    "enxambraremos": "enxambrar",
    "enxambrares": "enxambrar",
    "enxambraria": "enxambrar",
    "enxambrariam": "enxambrar",
    "enxambrarias": "enxambrar",
    "enxambrarmo": "enxambrar",
    "enxambrarmos": "enxambrar",
    "enxambrará": "enxambrar",
    "enxambrarás": "enxambrar",
    "enxambrarão": "enxambrar",
    "enxambraríamos": "enxambrar",
    "enxambraríeis": "enxambrar",
    "enxambras": "enxambrar",
    "enxambrasse": "enxambrar",
    "enxambrassem": "enxambrar",
    "enxambrasses": "enxambrar",
    "enxambraste": "enxambrar",
    "enxambrastes": "enxambrar",
    "enxambrava": "enxambrar",
    "enxambravam": "enxambrar",
    "enxambravas": "enxambrar",
    "enxambre": "enxambrar",
    "enxambrei": "enxambrar",
    "enxambreis": "enxambrar",
    "enxambrem": "enxambrar",
    "enxambremo": "enxambrar",
    "enxambremos": "enxambrar",
    "enxambres": "enxambrar",
    "enxambro": "enxambrar",
    "enxambrou": "enxambrar",
    "enxambrá": "enxambrar",
    "enxambrámo": "enxambrar",
    "enxambrámos": "enxambrar",
    "enxambráramo": "enxambrar",
    "enxambráramos": "enxambrar",
    "enxambrárei": "enxambrar",
    "enxambráreis": "enxambrar",
    "enxambrásseis": "enxambrar",
    "enxambrássemos": "enxambrar",
    "enxambrávamo": "enxambrar",
    "enxambrávamos": "enxambrar",
    "enxambrávei": "enxambrar",
    "enxambráveis": "enxambrar",
    "enxameada": "enxamear",
    "enxameadas": "enxamear",
    "enxameado": "enxamear",
    "enxameadora": "enxameador",
    "enxameadoras": "enxameador",
    "enxameadores": "enxameador",
    "enxameados": "enxamear",
    "enxameai": "enxamear",
    "enxameais": "enxamear",
    "enxameamentos": "enxameamento",
    "enxameamo": "enxamear",
    "enxameamos": "enxamear",
    "enxameando": "enxamear",
    "enxameara": "enxamear",
    "enxamearam": "enxamear",
    "enxamearas": "enxamear",
    "enxamearde": "enxamear",
    "enxameardes": "enxamear",
    "enxameare": "enxamear",
    "enxamearei": "enxamear",
    "enxameareis": "enxamear",
    "enxamearem": "enxamear",
    "enxamearemos": "enxamear",
    "enxameares": "enxamear",
    "enxamearia": "enxamear",
    "enxameariam": "enxamear",
    "enxamearias": "enxamear",
    "enxamearmo": "enxamear",
    "enxamearmos": "enxamear",
    "enxameará": "enxamear",
    "enxamearás": "enxamear",
    "enxamearão": "enxamear",
    "enxamearíamos": "enxamear",
    "enxamearíeis": "enxamear",
    "enxameasse": "enxamear",
    "enxameassem": "enxamear",
    "enxameasses": "enxamear",
    "enxameaste": "enxamear",
    "enxameastes": "enxamear",
    "enxameava": "enxamear",
    "enxameavam": "enxamear",
    "enxameavas": "enxamear",
    "enxameações": "enxameação",
    "enxameei": "enxamear",
    "enxameeis": "enxamear",
    "enxameemo": "enxamear",
    "enxameemos": "enxamear",
    "enxameia": "enxamear",
    "enxameiam": "enxamear",
    "enxameias": "enxamear",
    "enxameie": "enxamear",
    "enxameiem": "enxamear",
    "enxameies": "enxamear",
    "enxameio": "enxamear",
    "enxameou": "enxamear",
    "enxames": "enxame",
    "enxameá": "enxamear",
    "enxameámo": "enxamear",
    "enxameámos": "enxamear",
    "enxameáramo": "enxamear",
    "enxameáramos": "enxamear",
    "enxameárei": "enxamear",
    "enxameáreis": "enxamear",
    "enxameásseis": "enxamear",
    "enxameássemos": "enxamear",
    "enxameávamo": "enxamear",
    "enxameávamos": "enxamear",
    "enxameávei": "enxamear",
    "enxameáveis": "enxamear",
    "enxaquecas": "enxaqueca",
    "enxaquetada": "enxaquetado",
    "enxaquetadas": "enxaquetado",
    "enxaquetados": "enxaquetado",
    "enxaras": "enxara",
    "enxaravias": "enxaravia",
    "enxarcia": "enxarciar",
    "enxarciada": "enxarciar",
    "enxarciadas": "enxarciar",
    "enxarciado": "enxarciar",
    "enxarciados": "enxarciar",
    "enxarciai": "enxarciar",
    "enxarciais": "enxarciar",
    "enxarciam": "enxarciar",
    "enxarciamo": "enxarciar",
    "enxarciamos": "enxarciar",
    "enxarciando": "enxarciar",
    "enxarciara": "enxarciar",
    "enxarciaram": "enxarciar",
    "enxarciaras": "enxarciar",
    "enxarciarde": "enxarciar",
    "enxarciardes": "enxarciar",
    "enxarciare": "enxarciar",
    "enxarciarei": "enxarciar",
    "enxarciareis": "enxarciar",
    "enxarciarem": "enxarciar",
    "enxarciaremos": "enxarciar",
    "enxarciares": "enxarciar",
    "enxarciaria": "enxarciar",
    "enxarciariam": "enxarciar",
    "enxarciarias": "enxarciar",
    "enxarciarmo": "enxarciar",
    "enxarciarmos": "enxarciar",
    "enxarciará": "enxarciar",
    "enxarciarás": "enxarciar",
    "enxarciarão": "enxarciar",
    "enxarciaríamos": "enxarciar",
    "enxarciaríeis": "enxarciar",
    "enxarcias": "enxarciar",
    "enxarciasse": "enxarciar",
    "enxarciassem": "enxarciar",
    "enxarciasses": "enxarciar",
    "enxarciaste": "enxarciar",
    "enxarciastes": "enxarciar",
    "enxarciava": "enxarciar",
    "enxarciavam": "enxarciar",
    "enxarciavas": "enxarciar",
    "enxarcie": "enxarciar",
    "enxarciei": "enxarciar",
    "enxarcieis": "enxarciar",
    "enxarciem": "enxarciar",
    "enxarciemo": "enxarciar",
    "enxarciemos": "enxarciar",
    "enxarcies": "enxarciar",
    "enxarcio": "enxarciar",
    "enxarciou": "enxarciar",
    "enxarciá": "enxarciar",
    "enxarciámo": "enxarciar",
    "enxarciámos": "enxarciar",
    "enxarciáramo": "enxarciar",
    "enxarciáramos": "enxarciar",
    "enxarciárei": "enxarciar",
    "enxarciáreis": "enxarciar",
    "enxarciásseis": "enxarciar",
    "enxarciássemos": "enxarciar",
    "enxarciávamo": "enxarciar",
    "enxarciávamos": "enxarciar",
    "enxarciávei": "enxarciar",
    "enxarciáveis": "enxarciar",
    "enxaropa": "enxaropar",
    "enxaropada": "enxaropar",
    "enxaropadas": "enxaropar",
    "enxaropado": "enxaropar",
    "enxaropados": "enxaropar",
    "enxaropai": "enxaropar",
    "enxaropais": "enxaropar",
    "enxaropam": "enxaropar",
    "enxaropamo": "enxaropar",
    "enxaropamos": "enxaropar",
    "enxaropando": "enxaropar",
    "enxaropara": "enxaropar",
    "enxaroparam": "enxaropar",
    "enxaroparas": "enxaropar",
    "enxaroparde": "enxaropar",
    "enxaropardes": "enxaropar",
    "enxaropare": "enxaropar",
    "enxaroparei": "enxaropar",
    "enxaropareis": "enxaropar",
    "enxaroparem": "enxaropar",
    "enxaroparemos": "enxaropar",
    "enxaropares": "enxaropar",
    "enxaroparia": "enxaropar",
    "enxaropariam": "enxaropar",
    "enxaroparias": "enxaropar",
    "enxaroparmo": "enxaropar",
    "enxaroparmos": "enxaropar",
    "enxaropará": "enxaropar",
    "enxaroparás": "enxaropar",
    "enxaroparão": "enxaropar",
    "enxaroparíamos": "enxaropar",
    "enxaroparíeis": "enxaropar",
    "enxaropas": "enxaropar",
    "enxaropasse": "enxaropar",
    "enxaropassem": "enxaropar",
    "enxaropasses": "enxaropar",
    "enxaropaste": "enxaropar",
    "enxaropastes": "enxaropar",
    "enxaropava": "enxaropar",
    "enxaropavam": "enxaropar",
    "enxaropavas": "enxaropar",
    "enxarope": "enxaropar",
    "enxaropei": "enxaropar",
    "enxaropeis": "enxaropar",
    "enxaropem": "enxaropar",
    "enxaropemo": "enxaropar",
    "enxaropemos": "enxaropar",
    "enxaropes": "enxaropar",
    "enxaropo": "enxaropar",
    "enxaropou": "enxaropar",
    "enxaropá": "enxaropar",
    "enxaropámo": "enxaropar",
    "enxaropámos": "enxaropar",
    "enxaropáramo": "enxaropar",
    "enxaropáramos": "enxaropar",
    "enxaropárei": "enxaropar",
    "enxaropáreis": "enxaropar",
    "enxaropásseis": "enxaropar",
    "enxaropássemos": "enxaropar",
    "enxaropávamo": "enxaropar",
    "enxaropávamos": "enxaropar",
    "enxaropávei": "enxaropar",
    "enxaropáveis": "enxaropar",
    "enxarrocos": "enxarroco",
    "enxauga": "enxaugar",
    "enxaugada": "enxaugar",
    "enxaugadas": "enxaugar",
    "enxaugado": "enxaugar",
    "enxaugados": "enxaugar",
    "enxaugai": "enxaugar",
    "enxaugais": "enxaugar",
    "enxaugam": "enxaugar",
    "enxaugamo": "enxaugar",
    "enxaugamos": "enxaugar",
    "enxaugando": "enxaugar",
    "enxaugara": "enxaugar",
    "enxaugaram": "enxaugar",
    "enxaugaras": "enxaugar",
    "enxaugarde": "enxaugar",
    "enxaugardes": "enxaugar",
    "enxaugare": "enxaugar",
    "enxaugarei": "enxaugar",
    "enxaugareis": "enxaugar",
    "enxaugarem": "enxaugar",
    "enxaugaremos": "enxaugar",
    "enxaugares": "enxaugar",
    "enxaugaria": "enxaugar",
    "enxaugariam": "enxaugar",
    "enxaugarias": "enxaugar",
    "enxaugarmo": "enxaugar",
    "enxaugarmos": "enxaugar",
    "enxaugará": "enxaugar",
    "enxaugarás": "enxaugar",
    "enxaugarão": "enxaugar",
    "enxaugaríamos": "enxaugar",
    "enxaugaríeis": "enxaugar",
    "enxaugas": "enxaugar",
    "enxaugasse": "enxaugar",
    "enxaugassem": "enxaugar",
    "enxaugasses": "enxaugar",
    "enxaugaste": "enxaugar",
    "enxaugastes": "enxaugar",
    "enxaugava": "enxaugar",
    "enxaugavam": "enxaugar",
    "enxaugavas": "enxaugar",
    "enxaugo": "enxaugar",
    "enxaugou": "enxaugar",
    "enxaugue": "enxaugar",
    "enxauguei": "enxaugar",
    "enxaugueis": "enxaugar",
    "enxauguem": "enxaugar",
    "enxauguemo": "enxaugar",
    "enxauguemos": "enxaugar",
    "enxaugues": "enxaugar",
    "enxaugá": "enxaugar",
    "enxaugámo": "enxaugar",
    "enxaugámos": "enxaugar",
    "enxaugáramo": "enxaugar",
    "enxaugáramos": "enxaugar",
    "enxaugárei": "enxaugar",
    "enxaugáreis": "enxaugar",
    "enxaugásseis": "enxaugar",
    "enxaugássemos": "enxaugar",
    "enxaugávamo": "enxaugar",
    "enxaugávamos": "enxaugar",
    "enxaugávei": "enxaugar",
    "enxaugáveis": "enxaugar",
    "enxerca": "enxercar",
    "enxercada": "enxercar",
    "enxercadas": "enxercar",
    "enxercado": "enxercar",
    "enxercados": "enxercar",
    "enxercai": "enxercar",
    "enxercais": "enxercar",
    "enxercam": "enxercar",
    "enxercamo": "enxercar",
    "enxercamos": "enxercar",
    "enxercando": "enxercar",
    "enxercara": "enxercar",
    "enxercaram": "enxercar",
    "enxercaras": "enxercar",
    "enxercarde": "enxercar",
    "enxercardes": "enxercar",
    "enxercare": "enxercar",
    "enxercarei": "enxercar",
    "enxercareis": "enxercar",
    "enxercarem": "enxercar",
    "enxercaremos": "enxercar",
    "enxercares": "enxercar",
    "enxercaria": "enxercar",
    "enxercariam": "enxercar",
    "enxercarias": "enxercar",
    "enxercarmo": "enxercar",
    "enxercarmos": "enxercar",
    "enxercará": "enxercar",
    "enxercarás": "enxercar",
    "enxercarão": "enxercar",
    "enxercaríamos": "enxercar",
    "enxercaríeis": "enxercar",
    "enxercas": "enxercar",
    "enxercasse": "enxercar",
    "enxercassem": "enxercar",
    "enxercasses": "enxercar",
    "enxercaste": "enxercar",
    "enxercastes": "enxercar",
    "enxercava": "enxercar",
    "enxercavam": "enxercar",
    "enxercavas": "enxercar",
    "enxerco": "enxercar",
    "enxercou": "enxercar",
    "enxercá": "enxercar",
    "enxercámo": "enxercar",
    "enxercámos": "enxercar",
    "enxercáramo": "enxercar",
    "enxercáramos": "enxercar",
    "enxercárei": "enxercar",
    "enxercáreis": "enxercar",
    "enxercásseis": "enxercar",
    "enxercássemos": "enxercar",
    "enxercávamo": "enxercar",
    "enxercávamos": "enxercar",
    "enxercávei": "enxercar",
    "enxercáveis": "enxercar",
    "enxere": "enxerir",
    "enxerem": "enxerir",
    "enxeres": "enxerir",
    "enxerga": "enxergar",
    "enxergada": "enxergar",
    "enxergadas": "enxergar",
    "enxergado": "enxergar",
    "enxergados": "enxergar",
    "enxergai": "enxergar",
    "enxergais": "enxergar",
    "enxergam": "enxergar",
    "enxergamo": "enxergar",
    "enxergamos": "enxergar",
    "enxergando": "enxergar",
    "enxergara": "enxergar",
    "enxergaram": "enxergar",
    "enxergaras": "enxergar",
    "enxergarde": "enxergar",
    "enxergardes": "enxergar",
    "enxergare": "enxergar",
    "enxergarei": "enxergar",
    "enxergareis": "enxergar",
    "enxergarem": "enxergar",
    "enxergaremos": "enxergar",
    "enxergares": "enxergar",
    "enxergaria": "enxergar",
    "enxergariam": "enxergar",
    "enxergarias": "enxergar",
    "enxergarmo": "enxergar",
    "enxergarmos": "enxergar",
    "enxergará": "enxergar",
    "enxergarás": "enxergar",
    "enxergarão": "enxergar",
    "enxergaríamos": "enxergar",
    "enxergaríeis": "enxergar",
    "enxergas": "enxergar",
    "enxergasse": "enxergar",
    "enxergassem": "enxergar",
    "enxergasses": "enxergar",
    "enxergaste": "enxergar",
    "enxergastes": "enxergar",
    "enxergava": "enxergar",
    "enxergavam": "enxergar",
    "enxergavas": "enxergar",
    "enxergo": "enxergar",
    "enxergou": "enxergar",
    "enxergue": "enxergar",
    "enxerguei": "enxergar",
    "enxergueis": "enxergar",
    "enxerguem": "enxergar",
    "enxerguemo": "enxergar",
    "enxerguemos": "enxergar",
    "enxergues": "enxergar",
    "enxergá": "enxergar",
    "enxergámo": "enxergar",
    "enxergámos": "enxergar",
    "enxergáramo": "enxergar",
    "enxergáramos": "enxergar",
    "enxergárei": "enxergar",
    "enxergáreis": "enxergar",
    "enxergásseis": "enxergar",
    "enxergássemos": "enxergar",
    "enxergávamo": "enxergar",
    "enxergávamos": "enxergar",
    "enxergávei": "enxergar",
    "enxergáveis": "enxergar",
    "enxergões": "enxergão",
    "enxeri": "enxerir",
    "enxeria": "enxerir",
    "enxeriam": "enxerir",
    "enxerias": "enxerir",
    "enxerida": "enxerir",
    "enxeridas": "enxerir",
    "enxerido": "enxerir",
    "enxeridos": "enxerir",
    "enxerimo": "enxerir",
    "enxerimos": "enxerir",
    "enxerindo": "enxerir",
    "enxerira": "enxerir",
    "enxeriram": "enxerir",
    "enxeriras": "enxerir",
    "enxerirde": "enxerir",
    "enxerirdes": "enxerir",
    "enxerire": "enxerir",
    "enxerirei": "enxerir",
    "enxerireis": "enxerir",
    "enxerirem": "enxerir",
    "enxeriremos": "enxerir",
    "enxerires": "enxerir",
    "enxeriria": "enxerir",
    "enxeririam": "enxerir",
    "enxeririas": "enxerir",
    "enxerirmo": "enxerir",
    "enxerirmos": "enxerir",
    "enxerirá": "enxerir",
    "enxerirás": "enxerir",
    "enxerirão": "enxerir",
    "enxeriríamos": "enxerir",
    "enxeriríeis": "enxerir",
    "enxeris": "enxerir",
    "enxerisse": "enxerir",
    "enxerissem": "enxerir",
    "enxerisses": "enxerir",
    "enxeriste": "enxerir",
    "enxeristes": "enxerir",
    "enxeriu": "enxerir",
    "enxerque": "enxercar",
    "enxerquei": "enxercar",
    "enxerqueiros": "enxerqueiro",
    "enxerqueis": "enxercar",
    "enxerquem": "enxercar",
    "enxerquemo": "enxercar",
    "enxerquemos": "enxercar",
    "enxerques": "enxercar",
    "enxerta": "enxertar",
    "enxertada": "enxertar",
    "enxertadas": "enxertar",
    "enxertadeiras": "enxertadeira",
    "enxertado": "enxertar",
    "enxertadora": "enxertador",
    "enxertadoras": "enxertador",
    "enxertadores": "enxertador",
    "enxertadors": "enxertador",
    "enxertados": "enxertar",
    "enxertaduras": "enxertadura",
    "enxertai": "enxertar",
    "enxertais": "enxertar",
    "enxertam": "enxertar",
    "enxertamo": "enxertar",
    "enxertamos": "enxertar",
    "enxertando": "enxertar",
    "enxertara": "enxertar",
    "enxertaram": "enxertar",
    "enxertaras": "enxertar",
    "enxertarde": "enxertar",
    "enxertardes": "enxertar",
    "enxertare": "enxertar",
    "enxertarei": "enxertar",
    "enxertareis": "enxertar",
    "enxertarem": "enxertar",
    "enxertaremos": "enxertar",
    "enxertares": "enxertar",
    "enxertaria": "enxertar",
    "enxertariam": "enxertar",
    "enxertarias": "enxertar",
    "enxertarmo": "enxertar",
    "enxertarmos": "enxertar",
    "enxertará": "enxertar",
    "enxertarás": "enxertar",
    "enxertarão": "enxertar",
    "enxertaríamos": "enxertar",
    "enxertaríeis": "enxertar",
    "enxertas": "enxertar",
    "enxertasse": "enxertar",
    "enxertassem": "enxertar",
    "enxertasses": "enxertar",
    "enxertaste": "enxertar",
    "enxertastes": "enxertar",
    "enxertava": "enxertar",
    "enxertavam": "enxertar",
    "enxertavas": "enxertar",
    "enxerte": "enxertar",
    "enxertei": "enxertar",
    "enxerteis": "enxertar",
    "enxertem": "enxertar",
    "enxertemo": "enxertar",
    "enxertemos": "enxertar",
    "enxertes": "enxertar",
    "enxertias": "enxertia",
    "enxerto": "enxertar",
    "enxertos": "enxerto",
    "enxertou": "enxertar",
    "enxertá": "enxertar",
    "enxertámo": "enxertar",
    "enxertámos": "enxertar",
    "enxertáramo": "enxertar",
    "enxertáramos": "enxertar",
    "enxertárei": "enxertar",
    "enxertáreis": "enxertar",
    "enxertários": "enxertário",
    "enxertásseis": "enxertar",
    "enxertássemos": "enxertar",
    "enxertávamo": "enxertar",
    "enxertávamos": "enxertar",
    "enxertávei": "enxertar",
    "enxertáveis": "enxertável",
    "enxeríamo": "enxerir",
    "enxeríamos": "enxerir",
    "enxeríei": "enxerir",
    "enxeríeis": "enxerir",
    "enxeríramo": "enxerir",
    "enxeríramos": "enxerir",
    "enxerírei": "enxerir",
    "enxeríreis": "enxerir",
    "enxerísseis": "enxerir",
    "enxeríssemos": "enxerir",
    "enxia": "enxiar",
    "enxiada": "enxiar",
    "enxiadas": "enxiar",
    "enxiado": "enxiar",
    "enxiados": "enxiar",
    "enxiai": "enxiar",
    "enxiais": "enxiar",
    "enxiam": "enxiar",
    "enxiamo": "enxiar",
    "enxiamos": "enxiar",
    "enxiando": "enxiar",
    "enxiara": "enxiar",
    "enxiaram": "enxiar",
    "enxiaras": "enxiar",
    "enxiarde": "enxiar",
    "enxiardes": "enxiar",
    "enxiare": "enxiar",
    "enxiarei": "enxiar",
    "enxiareis": "enxiar",
    "enxiarem": "enxiar",
    "enxiaremos": "enxiar",
    "enxiares": "enxiar",
    "enxiaria": "enxiar",
    "enxiariam": "enxiar",
    "enxiarias": "enxiar",
    "enxiarmo": "enxiar",
    "enxiarmos": "enxiar",
    "enxiará": "enxiar",
    "enxiarás": "enxiar",
    "enxiarão": "enxiar",
    "enxiaríamos": "enxiar",
    "enxiaríeis": "enxiar",
    "enxias": "enxiar",
    "enxiasse": "enxiar",
    "enxiassem": "enxiar",
    "enxiasses": "enxiar",
    "enxiaste": "enxiar",
    "enxiastes": "enxiar",
    "enxiava": "enxiar",
    "enxiavam": "enxiar",
    "enxiavas": "enxiar",
    "enxie": "enxiar",
    "enxiei": "enxiar",
    "enxieis": "enxiar",
    "enxiem": "enxiar",
    "enxiemo": "enxiar",
    "enxiemos": "enxiar",
    "enxies": "enxiar",
    "enxio": "enxiar",
    "enxiou": "enxiar",
    "enxira": "enxerir",
    "enxirais": "enxerir",
    "enxiram": "enxerir",
    "enxiramo": "enxerir",
    "enxiramos": "enxerir",
    "enxiras": "enxerir",
    "enxiro": "enxerir",
    "enxiá": "enxiar",
    "enxiámo": "enxiar",
    "enxiámos": "enxiar",
    "enxiáramo": "enxiar",
    "enxiáramos": "enxiar",
    "enxiárei": "enxiar",
    "enxiáreis": "enxiar",
    "enxiásseis": "enxiar",
    "enxiássemos": "enxiar",
    "enxiávamo": "enxiar",
    "enxiávamos": "enxiar",
    "enxiávei": "enxiar",
    "enxiáveis": "enxiar",
    "enxoadas": "enxoada",
    "enxofra": "enxofrar",
    "enxofrada": "enxofrar",
    "enxofradas": "enxofrar",
    "enxofradeiras": "enxofradeira",
    "enxofrado": "enxofrar",
    "enxofradora": "enxofrador",
    "enxofradoras": "enxofrador",
    "enxofradores": "enxofrador",
    "enxofrados": "enxofrar",
    "enxofradíssima": "enxofrado",
    "enxofradíssimas": "enxofrado",
    "enxofradíssimo": "enxofrado",
    "enxofradíssimos": "enxofrado",
    "enxofrai": "enxofrar",
    "enxofrais": "enxofrar",
    "enxofram": "enxofrar",
    "enxoframentos": "enxoframento",
    "enxoframo": "enxofrar",
    "enxoframos": "enxofrar",
    "enxofrando": "enxofrar",
    "enxofrara": "enxofrar",
    "enxofraram": "enxofrar",
    "enxofraras": "enxofrar",
    "enxofrarde": "enxofrar",
    "enxofrardes": "enxofrar",
    "enxofrare": "enxofrar",
    "enxofrarei": "enxofrar",
    "enxofrareis": "enxofrar",
    "enxofrarem": "enxofrar",
    "enxofraremos": "enxofrar",
    "enxofrares": "enxofrar",
    "enxofraria": "enxofrar",
    "enxofrariam": "enxofrar",
    "enxofrarias": "enxofrar",
    "enxofrarmo": "enxofrar",
    "enxofrarmos": "enxofrar",
    "enxofrará": "enxofrar",
    "enxofrarás": "enxofrar",
    "enxofrarão": "enxofrar",
    "enxofraríamos": "enxofrar",
    "enxofraríeis": "enxofrar",
    "enxofras": "enxofrar",
    "enxofrasse": "enxofrar",
    "enxofrassem": "enxofrar",
    "enxofrasses": "enxofrar",
    "enxofraste": "enxofrar",
    "enxofrastes": "enxofrar",
    "enxofrava": "enxofrar",
    "enxofravam": "enxofrar",
    "enxofravas": "enxofrar",
    "enxofrações": "enxofração",
    "enxofre": "enxofrar",
    "enxofrei": "enxofrar",
    "enxofreiras": "enxofreira",
    "enxofreis": "enxofrar",
    "enxofrem": "enxofrar",
    "enxofremo": "enxofrar",
    "enxofremos": "enxofrar",
    "enxofrenta": "enxofrento",
    "enxofrentas": "enxofrento",
    "enxofrentos": "enxofrento",
    "enxofres": "enxofre",
    "enxofrias": "enxofria",
    "enxofro": "enxofrar",
    "enxofrou": "enxofrar",
    "enxofrá": "enxofrar",
    "enxofrámo": "enxofrar",
    "enxofrámos": "enxofrar",
    "enxofráramo": "enxofrar",
    "enxofráramos": "enxofrar",
    "enxofrárei": "enxofrar",
    "enxofráreis": "enxofrar",
    "enxofrásseis": "enxofrar",
    "enxofrássemos": "enxofrar",
    "enxofrávamo": "enxofrar",
    "enxofrávamos": "enxofrar",
    "enxofrávei": "enxofrar",
    "enxofráveis": "enxofrar",
    "enxota": "enxotar",
    "enxotada": "enxotar",
    "enxotadas": "enxotar",
    "enxotado": "enxotar",
    "enxotadora": "enxotador",
    "enxotadoras": "enxotador",
    "enxotadores": "enxotador",
    "enxotados": "enxotar",
    "enxotai": "enxotar",
    "enxotais": "enxotar",
    "enxotam": "enxotar",
    "enxotamentos": "enxotamento",
    "enxotamo": "enxotar",
    "enxotamos": "enxotar",
    "enxotando": "enxotar",
    "enxotara": "enxotar",
    "enxotaram": "enxotar",
    "enxotaras": "enxotar",
    "enxotarde": "enxotar",
    "enxotardes": "enxotar",
    "enxotare": "enxotar",
    "enxotarei": "enxotar",
    "enxotareis": "enxotar",
    "enxotarem": "enxotar",
    "enxotaremos": "enxotar",
    "enxotares": "enxotar",
    "enxotaria": "enxotar",
    "enxotariam": "enxotar",
    "enxotarias": "enxotar",
    "enxotarmo": "enxotar",
    "enxotarmos": "enxotar",
    "enxotará": "enxotar",
    "enxotarás": "enxotar",
    "enxotarão": "enxotar",
    "enxotaríamos": "enxotar",
    "enxotaríeis": "enxotar",
    "enxotas": "enxotar",
    "enxotasse": "enxotar",
    "enxotassem": "enxotar",
    "enxotasses": "enxotar",
    "enxotaste": "enxotar",
    "enxotastes": "enxotar",
    "enxotava": "enxotar",
    "enxotavam": "enxotar",
    "enxotavas": "enxotar",
    "enxote": "enxotar",
    "enxotei": "enxotar",
    "enxoteis": "enxotar",
    "enxotem": "enxotar",
    "enxotemo": "enxotar",
    "enxotemos": "enxotar",
    "enxotes": "enxotar",
    "enxoto": "enxotar",
    "enxotou": "enxotar",
    "enxotá": "enxotar",
    "enxotámo": "enxotar",
    "enxotámos": "enxotar",
    "enxotáramo": "enxotar",
    "enxotáramos": "enxotar",
    "enxotárei": "enxotar",
    "enxotáreis": "enxotar",
    "enxotásseis": "enxotar",
    "enxotássemos": "enxotar",
    "enxotávamo": "enxotar",
    "enxotávamos": "enxotar",
    "enxotávei": "enxotar",
    "enxotáveis": "enxotar",
    "enxovais": "enxoval",
    "enxovalha": "enxovalhar",
    "enxovalhada": "enxovalhar",
    "enxovalhadas": "enxovalhar",
    "enxovalhado": "enxovalhar",
    "enxovalhados": "enxovalhar",
    "enxovalhadíssima": "enxovalhado",
    "enxovalhadíssimas": "enxovalhado",
    "enxovalhadíssimo": "enxovalhado",
    "enxovalhadíssimos": "enxovalhado",
    "enxovalhai": "enxovalhar",
    "enxovalhais": "enxovalhar",
    "enxovalham": "enxovalhar",
    "enxovalhamentos": "enxovalhamento",
    "enxovalhamo": "enxovalhar",
    "enxovalhamos": "enxovalhar",
    "enxovalhando": "enxovalhar",
    "enxovalhantes": "enxovalhante",
    "enxovalhara": "enxovalhar",
    "enxovalharam": "enxovalhar",
    "enxovalharas": "enxovalhar",
    "enxovalharde": "enxovalhar",
    "enxovalhardes": "enxovalhar",
    "enxovalhare": "enxovalhar",
    "enxovalharei": "enxovalhar",
    "enxovalhareis": "enxovalhar",
    "enxovalharem": "enxovalhar",
    "enxovalharemos": "enxovalhar",
    "enxovalhares": "enxovalhar",
    "enxovalharia": "enxovalhar",
    "enxovalhariam": "enxovalhar",
    "enxovalharias": "enxovalhar",
    "enxovalharmo": "enxovalhar",
    "enxovalharmos": "enxovalhar",
    "enxovalhará": "enxovalhar",
    "enxovalharás": "enxovalhar",
    "enxovalharão": "enxovalhar",
    "enxovalharíamos": "enxovalhar",
    "enxovalharíeis": "enxovalhar",
    "enxovalhas": "enxovalhar",
    "enxovalhasse": "enxovalhar",
    "enxovalhassem": "enxovalhar",
    "enxovalhasses": "enxovalhar",
    "enxovalhaste": "enxovalhar",
    "enxovalhastes": "enxovalhar",
    "enxovalhava": "enxovalhar",
    "enxovalhavam": "enxovalhar",
    "enxovalhavas": "enxovalhar",
    "enxovalhe": "enxovalhar",
    "enxovalhei": "enxovalhar",
    "enxovalheis": "enxovalhar",
    "enxovalhem": "enxovalhar",
    "enxovalhemo": "enxovalhar",
    "enxovalhemos": "enxovalhar",
    "enxovalhes": "enxovalhar",
    "enxovalho": "enxovalhar",
    "enxovalhos": "enxovalho",
    "enxovalhou": "enxovalhar",
    "enxovalhá": "enxovalhar",
    "enxovalhámo": "enxovalhar",
    "enxovalhámos": "enxovalhar",
    "enxovalháramo": "enxovalhar",
    "enxovalháramos": "enxovalhar",
    "enxovalhárei": "enxovalhar",
    "enxovalháreis": "enxovalhar",
    "enxovalhásseis": "enxovalhar",
    "enxovalhássemos": "enxovalhar",
    "enxovalhávamo": "enxovalhar",
    "enxovalhávamos": "enxovalhar",
    "enxovalhávei": "enxovalhar",
    "enxovalháveis": "enxovalhar",
    "enxovas": "enxova",
    "enxovias": "enxovia",
    "enxudreira": "enxudreiro",
    "enxudreiras": "enxudreiro",
    "enxudreiros": "enxudreiro",
    "enxuga": "enxugar",
    "enxugada": "enxugar",
    "enxugadas": "enxugar",
    "enxugadeiras": "enxugadeira",
    "enxugado": "enxugar",
    "enxugadoiros": "enxugadoiro",
    "enxugados": "enxugar",
    "enxugadouros": "enxugadouro",
    "enxugai": "enxugar",
    "enxugais": "enxugar",
    "enxugam": "enxugar",
    "enxugamentos": "enxugamento",
    "enxugamo": "enxugar",
    "enxugamos": "enxugar",
    "enxugando": "enxugar",
    "enxugara": "enxugar",
    "enxugaram": "enxugar",
    "enxugaras": "enxugar",
    "enxugarde": "enxugar",
    "enxugardes": "enxugar",
    "enxugare": "enxugar",
    "enxugarei": "enxugar",
    "enxugareis": "enxugar",
    "enxugarem": "enxugar",
    "enxugaremos": "enxugar",
    "enxugares": "enxugar",
    "enxugaria": "enxugar",
    "enxugariam": "enxugar",
    "enxugarias": "enxugar",
    "enxugarmo": "enxugar",
    "enxugarmos": "enxugar",
    "enxugará": "enxugar",
    "enxugarás": "enxugar",
    "enxugarão": "enxugar",
    "enxugaríamos": "enxugar",
    "enxugaríeis": "enxugar",
    "enxugas": "enxugar",
    "enxugasse": "enxugar",
    "enxugassem": "enxugar",
    "enxugasses": "enxugar",
    "enxugaste": "enxugar",
    "enxugastes": "enxugar",
    "enxugava": "enxugar",
    "enxugavam": "enxugar",
    "enxugavas": "enxugar",
    "enxugo": "enxugar",
    "enxugos": "enxugo",
    "enxugou": "enxugar",
    "enxugue": "enxugar",
    "enxuguei": "enxugar",
    "enxugueis": "enxugar",
    "enxuguem": "enxugar",
    "enxuguemo": "enxugar",
    "enxuguemos": "enxugar",
    "enxugues": "enxugar",
    "enxugá": "enxugar",
    "enxugámo": "enxugar",
    "enxugámos": "enxugar",
    "enxugáramo": "enxugar",
    "enxugáramos": "enxugar",
    "enxugárei": "enxugar",
    "enxugáreis": "enxugar",
    "enxugásseis": "enxugar",
    "enxugássemos": "enxugar",
    "enxugávamo": "enxugar",
    "enxugávamos": "enxugar",
    "enxugávei": "enxugar",
    "enxugáveis": "enxugar",
    "enxumbra": "enxumbrar",
    "enxumbrada": "enxumbrar",
    "enxumbradas": "enxumbrar",
    "enxumbrado": "enxumbrar",
    "enxumbrados": "enxumbrar",
    "enxumbrai": "enxumbrar",
    "enxumbrais": "enxumbrar",
    "enxumbram": "enxumbrar",
    "enxumbramo": "enxumbrar",
    "enxumbramos": "enxumbrar",
    "enxumbrando": "enxumbrar",
    "enxumbrara": "enxumbrar",
    "enxumbraram": "enxumbrar",
    "enxumbraras": "enxumbrar",
    "enxumbrarde": "enxumbrar",
    "enxumbrardes": "enxumbrar",
    "enxumbrare": "enxumbrar",
    "enxumbrarei": "enxumbrar",
    "enxumbrareis": "enxumbrar",
    "enxumbrarem": "enxumbrar",
    "enxumbraremos": "enxumbrar",
    "enxumbrares": "enxumbrar",
    "enxumbraria": "enxumbrar",
    "enxumbrariam": "enxumbrar",
    "enxumbrarias": "enxumbrar",
    "enxumbrarmo": "enxumbrar",
    "enxumbrarmos": "enxumbrar",
    "enxumbrará": "enxumbrar",
    "enxumbrarás": "enxumbrar",
    "enxumbrarão": "enxumbrar",
    "enxumbraríamos": "enxumbrar",
    "enxumbraríeis": "enxumbrar",
    "enxumbras": "enxumbrar",
    "enxumbrasse": "enxumbrar",
    "enxumbrassem": "enxumbrar",
    "enxumbrasses": "enxumbrar",
    "enxumbraste": "enxumbrar",
    "enxumbrastes": "enxumbrar",
    "enxumbrava": "enxumbrar",
    "enxumbravam": "enxumbrar",
    "enxumbravas": "enxumbrar",
    "enxumbre": "enxumbrar",
    "enxumbrei": "enxumbrar",
    "enxumbreis": "enxumbrar",
    "enxumbrem": "enxumbrar",
    "enxumbremo": "enxumbrar",
    "enxumbremos": "enxumbrar",
    "enxumbres": "enxumbrar",
    "enxumbro": "enxumbrar",
    "enxumbrou": "enxumbrar",
    "enxumbrá": "enxumbrar",
    "enxumbrámo": "enxumbrar",
    "enxumbrámos": "enxumbrar",
    "enxumbráramo": "enxumbrar",
    "enxumbráramos": "enxumbrar",
    "enxumbrárei": "enxumbrar",
    "enxumbráreis": "enxumbrar",
    "enxumbrásseis": "enxumbrar",
    "enxumbrássemos": "enxumbrar",
    "enxumbrávamo": "enxumbrar",
    "enxumbrávamos": "enxumbrar",
    "enxumbrávei": "enxumbrar",
    "enxumbráveis": "enxumbrar",
    "enxundiosa": "enxundioso",
    "enxundiosas": "enxundioso",
    "enxundiosos": "enxundioso",
    "enxurda": "enxurdar",
    "enxurdada": "enxurdar",
    "enxurdadas": "enxurdar",
    "enxurdado": "enxurdar",
    "enxurdados": "enxurdar",
    "enxurdai": "enxurdar",
    "enxurdais": "enxurdar",
    "enxurdam": "enxurdar",
    "enxurdamo": "enxurdar",
    "enxurdamos": "enxurdar",
    "enxurdando": "enxurdar",
    "enxurdara": "enxurdar",
    "enxurdaram": "enxurdar",
    "enxurdaras": "enxurdar",
    "enxurdarde": "enxurdar",
    "enxurdardes": "enxurdar",
    "enxurdare": "enxurdar",
    "enxurdarei": "enxurdar",
    "enxurdareis": "enxurdar",
    "enxurdarem": "enxurdar",
    "enxurdaremos": "enxurdar",
    "enxurdares": "enxurdar",
    "enxurdaria": "enxurdar",
    "enxurdariam": "enxurdar",
    "enxurdarias": "enxurdar",
    "enxurdarmo": "enxurdar",
    "enxurdarmos": "enxurdar",
    "enxurdará": "enxurdar",
    "enxurdarás": "enxurdar",
    "enxurdarão": "enxurdar",
    "enxurdaríamos": "enxurdar",
    "enxurdaríeis": "enxurdar",
    "enxurdas": "enxurdar",
    "enxurdasse": "enxurdar",
    "enxurdassem": "enxurdar",
    "enxurdasses": "enxurdar",
    "enxurdaste": "enxurdar",
    "enxurdastes": "enxurdar",
    "enxurdava": "enxurdar",
    "enxurdavam": "enxurdar",
    "enxurdavas": "enxurdar",
    "enxurde": "enxurdar",
    "enxurdei": "enxurdar",
    "enxurdeiros": "enxurdeiro",
    "enxurdeis": "enxurdar",
    "enxurdem": "enxurdar",
    "enxurdemo": "enxurdar",
    "enxurdemos": "enxurdar",
    "enxurdes": "enxurdar",
    "enxurdo": "enxurdar",
    "enxurdou": "enxurdar",
    "enxurdá": "enxurdar",
    "enxurdámo": "enxurdar",
    "enxurdámos": "enxurdar",
    "enxurdáramo": "enxurdar",
    "enxurdáramos": "enxurdar",
    "enxurdárei": "enxurdar",
    "enxurdáreis": "enxurdar",
    "enxurdásseis": "enxurdar",
    "enxurdássemos": "enxurdar",
    "enxurdávamo": "enxurdar",
    "enxurdávamos": "enxurdar",
    "enxurdávei": "enxurdar",
    "enxurdáveis": "enxurdar",
    "enxurra": "enxurrar",
    "enxurrada": "enxurrar",
    "enxurradas": "enxurrar",
    "enxurrado": "enxurrar",
    "enxurrados": "enxurrar",
    "enxurrai": "enxurrar",
    "enxurrais": "enxurrar",
    "enxurram": "enxurrar",
    "enxurramo": "enxurrar",
    "enxurramos": "enxurrar",
    "enxurrando": "enxurrar",
    "enxurrara": "enxurrar",
    "enxurraram": "enxurrar",
    "enxurraras": "enxurrar",
    "enxurrarde": "enxurrar",
    "enxurrardes": "enxurrar",
    "enxurrare": "enxurrar",
    "enxurrarei": "enxurrar",
    "enxurrareis": "enxurrar",
    "enxurrarem": "enxurrar",
    "enxurraremos": "enxurrar",
    "enxurrares": "enxurrar",
    "enxurraria": "enxurrar",
    "enxurrariam": "enxurrar",
    "enxurrarias": "enxurrar",
    "enxurrarmo": "enxurrar",
    "enxurrarmos": "enxurrar",
    "enxurrará": "enxurrar",
    "enxurrarás": "enxurrar",
    "enxurrarão": "enxurrar",
    "enxurraríamos": "enxurrar",
    "enxurraríeis": "enxurrar",
    "enxurras": "enxurrar",
    "enxurrasse": "enxurrar",
    "enxurrassem": "enxurrar",
    "enxurrasses": "enxurrar",
    "enxurraste": "enxurrar",
    "enxurrastes": "enxurrar",
    "enxurrava": "enxurrar",
    "enxurravam": "enxurrar",
    "enxurravas": "enxurrar",
    "enxurre": "enxurrar",
    "enxurrei": "enxurrar",
    "enxurreira": "enxurreiro",
    "enxurreiras": "enxurreiro",
    "enxurreiros": "enxurreiro",
    "enxurreis": "enxurrar",
    "enxurrem": "enxurrar",
    "enxurremo": "enxurrar",
    "enxurremos": "enxurrar",
    "enxurres": "enxurrar",
    "enxurro": "enxurrar",
    "enxurros": "enxurro",
    "enxurrou": "enxurrar",
    "enxurrá": "enxurrar",
    "enxurrámo": "enxurrar",
    "enxurrámos": "enxurrar",
    "enxurráramo": "enxurrar",
    "enxurráramos": "enxurrar",
    "enxurrárei": "enxurrar",
    "enxurráreis": "enxurrar",
    "enxurrásseis": "enxurrar",
    "enxurrássemos": "enxurrar",
    "enxurrávamo": "enxurrar",
    "enxurrávamos": "enxurrar",
    "enxurrávei": "enxurrar",
    "enxurráveis": "enxurrar",
    "enxuta": "enxuto",
    "enxutadora": "enxutador",
    "enxutadoras": "enxutador",
    "enxutadores": "enxutador",
    "enxutas": "enxuto",
    "enxutos": "enxuto",
    "enxárcias": "enxárcia",
    "enxávegas": "enxávega",
    "enxós": "enxó",
    "enxúndias": "enxúndia",
    "enzampa": "enzampar",
    "enzampada": "enzampar",
    "enzampadas": "enzampar",
    "enzampado": "enzampar",
    "enzampados": "enzampar",
    "enzampai": "enzampar",
    "enzampais": "enzampar",
    "enzampam": "enzampar",
    "enzampamo": "enzampar",
    "enzampamos": "enzampar",
    "enzampando": "enzampar",
    "enzampara": "enzampar",
    "enzamparam": "enzampar",
    "enzamparas": "enzampar",
    "enzamparde": "enzampar",
    "enzampardes": "enzampar",
    "enzampare": "enzampar",
    "enzamparei": "enzampar",
    "enzampareis": "enzampar",
    "enzamparem": "enzampar",
    "enzamparemos": "enzampar",
    "enzampares": "enzampar",
    "enzamparia": "enzampar",
    "enzampariam": "enzampar",
    "enzamparias": "enzampar",
    "enzamparmo": "enzampar",
    "enzamparmos": "enzampar",
    "enzampará": "enzampar",
    "enzamparás": "enzampar",
    "enzamparão": "enzampar",
    "enzamparíamos": "enzampar",
    "enzamparíeis": "enzampar",
    "enzampas": "enzampar",
    "enzampasse": "enzampar",
    "enzampassem": "enzampar",
    "enzampasses": "enzampar",
    "enzampaste": "enzampar",
    "enzampastes": "enzampar",
    "enzampava": "enzampar",
    "enzampavam": "enzampar",
    "enzampavas": "enzampar",
    "enzampe": "enzampar",
    "enzampei": "enzampar",
    "enzampeis": "enzampar",
    "enzampem": "enzampar",
    "enzampemo": "enzampar",
    "enzampemos": "enzampar",
    "enzampes": "enzampar",
    "enzampo": "enzampar",
    "enzampou": "enzampar",
    "enzampá": "enzampar",
    "enzampámo": "enzampar",
    "enzampámos": "enzampar",
    "enzampáramo": "enzampar",
    "enzampáramos": "enzampar",
    "enzampárei": "enzampar",
    "enzampáreis": "enzampar",
    "enzampásseis": "enzampar",
    "enzampássemos": "enzampar",
    "enzampávamo": "enzampar",
    "enzampávamos": "enzampar",
    "enzampávei": "enzampar",
    "enzampáveis": "enzampar",
    "enzimas": "enzima",
    "enzimática": "enzimático",
    "enzimáticas": "enzimático",
    "enzimáticos": "enzimático",
    "enzinhas": "enzinha",
    "enzinheiras": "enzinheira",
    "enzinheiros": "enzinheiro",
    "enzona": "enzonar",
    "enzonada": "enzonar",
    "enzonadas": "enzonar",
    "enzonado": "enzonar",
    "enzonados": "enzonar",
    "enzonai": "enzonar",
    "enzonais": "enzonar",
    "enzonam": "enzonar",
    "enzonamo": "enzonar",
    "enzonamos": "enzonar",
    "enzonando": "enzonar",
    "enzonara": "enzonar",
    "enzonaram": "enzonar",
    "enzonaras": "enzonar",
    "enzonardes": "enzonar",
    "enzonarei": "enzonar",
    "enzonareis": "enzonar",
    "enzonarem": "enzonar",
    "enzonaremos": "enzonar",
    "enzonares": "enzonar",
    "enzonaria": "enzonar",
    "enzonariam": "enzonar",
    "enzonarias": "enzonar",
    "enzonarmo": "enzonar",
    "enzonarmos": "enzonar",
    "enzonará": "enzonar",
    "enzonarás": "enzonar",
    "enzonarão": "enzonar",
    "enzonaríamos": "enzonar",
    "enzonaríeis": "enzonar",
    "enzonas": "enzonar",
    "enzonasse": "enzonar",
    "enzonassem": "enzonar",
    "enzonasses": "enzonar",
    "enzonaste": "enzonar",
    "enzonastes": "enzonar",
    "enzonava": "enzonar",
    "enzonavam": "enzonar",
    "enzonavas": "enzonar",
    "enzone": "enzonar",
    "enzonei": "enzonar",
    "enzoneiros": "enzoneiro",
    "enzoneis": "enzonar",
    "enzonem": "enzonar",
    "enzonemo": "enzonar",
    "enzonemos": "enzonar",
    "enzones": "enzonar",
    "enzonices": "enzonice",
    "enzono": "enzonar",
    "enzonou": "enzonar",
    "enzonámo": "enzonar",
    "enzonámos": "enzonar",
    "enzonáramo": "enzonar",
    "enzonáramos": "enzonar",
    "enzonáreis": "enzonar",
    "enzonásseis": "enzonar",
    "enzonássemos": "enzonar",
    "enzonávamo": "enzonar",
    "enzonávamos": "enzonar",
    "enzonáveis": "enzonar",
    "enzootias": "enzootia",
    "enzoótica": "enzoótico",
    "enzoóticas": "enzoótico",
    "enzoóticos": "enzoótico",
    "enzóica": "enzóico",
    "enzóicas": "enzóico",
    "enzóicos": "enzóico",
    "enáguas": "enágua",
    "enálages": "enálage",
    "enântica": "enântico",
    "enânticas": "enântico",
    "enânticos": "enântico",
    "enérgeias": "enérgeia",
    "enérgica": "enérgico",
    "enérgicas": "enérgico",
    "enérgicos": "enérgico",
    "enérgides": "enérgide",
    "enésima": "enésimo",
    "enésimas": "enésimo",
    "enésimos": "enésimo",
    "enícolas": "enícola",
    "enídrides": "enídride",
    "enófila": "enófilo",
    "enófilas": "enófilo",
    "enófilos": "enófilo",
    "enófoba": "enófobo",
    "enófobas": "enófobo",
    "enófobias": "enófobia",
    "enófobos": "enófobo",
    "enóforos": "enóforo",
    "enógrafos": "enógrafo",
    "enóis": "enol",
    "enóleos": "enóleo",
    "enólica": "enólico",
    "enólicas": "enólico",
    "enólicos": "enólico",
    "enóloga": "enólogo",
    "enólogas": "enólogo",
    "enólogos": "enólogo",
    "enómana": "enómano",
    "enómanas": "enómano",
    "enómanos": "enómano",
    "enómetros": "enómetro",
    "eoa": "eoo",
    "eoas": "eoo",
    "eocena": "eoceno",
    "eocenas": "eoceno",
    "eocenos": "eoceno",
    "eocénica": "eocénico",
    "eocénicas": "eocénico",
    "eocénicos": "eocénico",
    "eolinas": "eolina",
    "eolitos": "eolito",
    "eolípilas": "eolípila",
    "eolítica": "eolítico",
    "eolíticas": "eolítico",
    "eolíticos": "eolítico",
    "eoos": "eoo",
    "eosinas": "eosina",
    "eosinófilos": "eosinófilo",
    "eozóica": "eozóico",
    "eozóicas": "eozóico",
    "eozóicos": "eozóico",
    "epacmástica": "epacmástico",
    "epacmásticas": "epacmástico",
    "epacmásticos": "epacmástico",
    "epacridácea": "epacridáceo",
    "epacridáceas": "epacridáceo",
    "epacridáceos": "epacridáceo",
    "epacrídea": "epacrídeo",
    "epacrídeas": "epacrídeo",
    "epacrídeos": "epacrídeo",
    "epactais": "epactal",
    "epactas": "epacta",
    "epagoga": "epagogo",
    "epagogas": "epagogo",
    "epagoges": "epagoge",
    "epagogos": "epagogo",
    "epagógica": "epagógico",
    "epagógicas": "epagógico",
    "epagógicos": "epagógico",
    "epanadiploses": "epanadiplose",
    "epanadiplósica": "epanadiplósico",
    "epanadiplósicas": "epanadiplósico",
    "epanadiplósicos": "epanadiplósico",
    "epanafórica": "epanafórico",
    "epanafóricas": "epanafórico",
    "epanafóricos": "epanafórico",
    "epanalepses": "epanalepse",
    "epanaléptica": "epanaléptico",
    "epanalépticas": "epanaléptico",
    "epanalépticos": "epanaléptico",
    "epanastrófica": "epanastrófico",
    "epanastróficas": "epanastrófico",
    "epanastróficos": "epanastrófico",
    "epanortoses": "epanortose",
    "epanortósica": "epanortósico",
    "epanortósicas": "epanortósico",
    "epanortósicos": "epanortósico",
    "epanáforas": "epanáfora",
    "epanástrofes": "epanástrofe",
    "epanódica": "epanódico",
    "epanódicas": "epanódico",
    "epanódicos": "epanódico",
    "eparquias": "eparquia",
    "ependimária": "ependimário",
    "ependimárias": "ependimário",
    "ependimários": "ependimário",
    "ependímica": "ependímico",
    "ependímicas": "ependímico",
    "ependímicos": "ependímico",
    "epentética": "epentético",
    "epentéticas": "epentético",
    "epentéticos": "epentético",
    "epexegeses": "epexegese",
    "epexegésica": "epexegésico",
    "epexegésicas": "epexegésico",
    "epexegésicos": "epexegésico",
    "epiblastos": "epiblasto",
    "epiblástica": "epiblástico",
    "epiblásticas": "epiblástico",
    "epiblásticos": "epiblástico",
    "epibolias": "epibolia",
    "epibolitos": "epibolito",
    "epibólica": "epibólico",
    "epibólicas": "epibólico",
    "epibólicos": "epibólico",
    "epicais": "epical",
    "epicalícias": "epicalícia",
    "epicarpos": "epicarpo",
    "epicaules": "epicaule",
    "epicefalias": "epicefalia",
    "epicefálica": "epicefálico",
    "epicefálicas": "epicefálico",
    "epicefálicos": "epicefálico",
    "epiceias": "epiceia",
    "epicena": "epiceno",
    "epicenas": "epiceno",
    "epicenos": "epiceno",
    "epicentrais": "epicentral",
    "epicentros": "epicentro",
    "epiciclos": "epiciclo",
    "epiciclóides": "epiciclóide",
    "epicleses": "epiclese",
    "epiclina": "epiclino",
    "epiclinas": "epiclino",
    "epiclinos": "epiclino",
    "epicondílica": "epicondílico",
    "epicondílicas": "epicondílico",
    "epicondílicos": "epicondílico",
    "epicontinentais": "epicontinental",
    "epicraniana": "epicraniano",
    "epicranianas": "epicraniano",
    "epicranianos": "epicraniano",
    "epicrâneos": "epicrâneo",
    "epicrânia": "epicrânio",
    "epicrânias": "epicrânio",
    "epicrânica": "epicrânico",
    "epicrânicas": "epicrânico",
    "epicrânicos": "epicrânico",
    "epicrânios": "epicrânio",
    "epicrítica": "epicrítico",
    "epicríticas": "epicrítico",
    "epicríticos": "epicrítico",
    "epicureia": "epicureu",
    "epicureias": "epicureu",
    "epicureus": "epicureu",
    "epicurismos": "epicurismo",
    "epicuristas": "epicurista",
    "epicálices": "epicálice",
    "epicárpica": "epicárpico",
    "epicárpicas": "epicárpico",
    "epicárpicos": "epicárpico",
    "epicárpios": "epicárpio",
    "epicédios": "epicédio",
    "epicéfala": "epicéfalo",
    "epicéfalas": "epicéfalo",
    "epicéfalos": "epicéfalo",
    "epicótilos": "epicótilo",
    "epicôndilos": "epicôndilo",
    "epidemia": "epidemiar",
    "epidemiada": "epidemiar",
    "epidemiadas": "epidemiar",
    "epidemiado": "epidemiar",
    "epidemiados": "epidemiar",
    "epidemiai": "epidemiar",
    "epidemiais": "epidemiar",
    "epidemiam": "epidemiar",
    "epidemiamo": "epidemiar",
    "epidemiamos": "epidemiar",
    "epidemiando": "epidemiar",
    "epidemiara": "epidemiar",
    "epidemiaram": "epidemiar",
    "epidemiaras": "epidemiar",
    "epidemiarde": "epidemiar",
    "epidemiardes": "epidemiar",
    "epidemiare": "epidemiar",
    "epidemiarei": "epidemiar",
    "epidemiareis": "epidemiar",
    "epidemiarem": "epidemiar",
    "epidemiaremos": "epidemiar",
    "epidemiares": "epidemiar",
    "epidemiaria": "epidemiar",
    "epidemiariam": "epidemiar",
    "epidemiarias": "epidemiar",
    "epidemiarmo": "epidemiar",
    "epidemiarmos": "epidemiar",
    "epidemiará": "epidemiar",
    "epidemiarás": "epidemiar",
    "epidemiarão": "epidemiar",
    "epidemiaríamos": "epidemiar",
    "epidemiaríeis": "epidemiar",
    "epidemias": "epidemiar",
    "epidemiasse": "epidemiar",
    "epidemiassem": "epidemiar",
    "epidemiasses": "epidemiar",
    "epidemiaste": "epidemiar",
    "epidemiastes": "epidemiar",
    "epidemiava": "epidemiar",
    "epidemiavam": "epidemiar",
    "epidemiavas": "epidemiar",
    "epidemicidades": "epidemicidade",
    "epidemie": "epidemiar",
    "epidemiei": "epidemiar",
    "epidemieis": "epidemiar",
    "epidemiem": "epidemiar",
    "epidemiemo": "epidemiar",
    "epidemiemos": "epidemiar",
    "epidemies": "epidemiar",
    "epidemio": "epidemiar",
    "epidemiologias": "epidemiologia",
    "epidemiologistas": "epidemiologista",
    "epidemiológica": "epidemiológico",
    "epidemiológicas": "epidemiológico",
    "epidemiológicos": "epidemiológico",
    "epidemiou": "epidemiar",
    "epidemiá": "epidemiar",
    "epidemiámo": "epidemiar",
    "epidemiámos": "epidemiar",
    "epidemiáramo": "epidemiar",
    "epidemiáramos": "epidemiar",
    "epidemiárei": "epidemiar",
    "epidemiáreis": "epidemiar",
    "epidemiásseis": "epidemiar",
    "epidemiássemos": "epidemiar",
    "epidemiávamo": "epidemiar",
    "epidemiávamos": "epidemiar",
    "epidemiávei": "epidemiar",
    "epidemiáveis": "epidemiar",
    "epidermes": "epiderme",
    "epidermóides": "epidermóide",
    "epidiascópica": "epidiascópico",
    "epidiascópicas": "epidiascópico",
    "epidiascópicos": "epidiascópico",
    "epidémica": "epidémico",
    "epidémicas": "epidémico",
    "epidémicos": "epidémico",
    "epidérmica": "epidérmico",
    "epidérmicas": "epidérmico",
    "epidérmicos": "epidérmico",
    "epidíctica": "epidíctico",
    "epidícticas": "epidíctico",
    "epidícticos": "epidíctico",
    "epidídimos": "epidídimo",
    "epidímica": "epidímico",
    "epidímicas": "epidímico",
    "epidímicos": "epidímico",
    "epifanias": "epifania",
    "epifenomenalismos": "epifenomenalismo",
    "epifenoménica": "epifenoménico",
    "epifenoménicas": "epifenoménico",
    "epifenoménicos": "epifenoménico",
    "epifenómenos": "epifenómeno",
    "epifila": "epifilo",
    "epifilas": "epifilo",
    "epifilos": "epifilo",
    "epifitias": "epifitia",
    "epifonemas": "epifonema",
    "epifragmas": "epifragma",
    "epifragmática": "epifragmático",
    "epifragmáticas": "epifragmático",
    "epifragmáticos": "epifragmático",
    "epifrásica": "epifrásico",
    "epifrásicas": "epifrásico",
    "epifrásicos": "epifrásico",
    "epifânica": "epifânico",
    "epifânicas": "epifânico",
    "epifânicos": "epifânico",
    "epigamias": "epigamia",
    "epigastralgias": "epigastralgia",
    "epigastriálgica": "epigastriálgico",
    "epigastriálgicas": "epigastriálgico",
    "epigastriálgicos": "epigastriálgico",
    "epigastros": "epigastro",
    "epigeia": "epigeu",
    "epigeias": "epigeu",
    "epigenesias": "epigenesia",
    "epigenias": "epigenia",
    "epigenésica": "epigenésico",
    "epigenésicas": "epigenésico",
    "epigenésicos": "epigenésico",
    "epigenética": "epigenético",
    "epigenéticas": "epigenético",
    "epigenéticos": "epigenético",
    "epigeus": "epigeu",
    "epiginias": "epiginia",
    "epiglossa": "epiglosso",
    "epiglossas": "epiglosso",
    "epiglossos": "epiglosso",
    "epiglotes": "epiglote",
    "epiglotites": "epiglotite",
    "epiglótica": "epiglótico",
    "epiglóticas": "epiglótico",
    "epiglóticos": "epiglótico",
    "epigrafa": "epigrafar",
    "epigrafada": "epigrafar",
    "epigrafadas": "epigrafar",
    "epigrafado": "epigrafar",
    "epigrafados": "epigrafar",
    "epigrafai": "epigrafar",
    "epigrafais": "epigrafar",
    "epigrafam": "epigrafar",
    "epigrafamo": "epigrafar",
    "epigrafamos": "epigrafar",
    "epigrafando": "epigrafar",
    "epigrafara": "epigrafar",
    "epigrafaram": "epigrafar",
    "epigrafaras": "epigrafar",
    "epigrafarde": "epigrafar",
    "epigrafardes": "epigrafar",
    "epigrafare": "epigrafar",
    "epigrafarei": "epigrafar",
    "epigrafareis": "epigrafar",
    "epigrafarem": "epigrafar",
    "epigrafaremos": "epigrafar",
    "epigrafares": "epigrafar",
    "epigrafaria": "epigrafar",
    "epigrafariam": "epigrafar",
    "epigrafarias": "epigrafar",
    "epigrafarmo": "epigrafar",
    "epigrafarmos": "epigrafar",
    "epigrafará": "epigrafar",
    "epigrafarás": "epigrafar",
    "epigrafarão": "epigrafar",
    "epigrafaríamos": "epigrafar",
    "epigrafaríeis": "epigrafar",
    "epigrafas": "epigrafar",
    "epigrafasse": "epigrafar",
    "epigrafassem": "epigrafar",
    "epigrafasses": "epigrafar",
    "epigrafaste": "epigrafar",
    "epigrafastes": "epigrafar",
    "epigrafava": "epigrafar",
    "epigrafavam": "epigrafar",
    "epigrafavas": "epigrafar",
    "epigrafe": "epigrafar",
    "epigrafei": "epigrafar",
    "epigrafeis": "epigrafar",
    "epigrafem": "epigrafar",
    "epigrafemo": "epigrafar",
    "epigrafemos": "epigrafar",
    "epigrafes": "epigrafar",
    "epigrafias": "epigrafia",
    "epigrafistas": "epigrafista",
    "epigrafo": "epigrafar",
    "epigrafou": "epigrafar",
    "epigrafá": "epigrafar",
    "epigrafámo": "epigrafar",
    "epigrafámos": "epigrafar",
    "epigrafáramo": "epigrafar",
    "epigrafáramos": "epigrafar",
    "epigrafárei": "epigrafar",
    "epigrafáreis": "epigrafar",
    "epigrafásseis": "epigrafar",
    "epigrafássemos": "epigrafar",
    "epigrafávamo": "epigrafar",
    "epigrafávamos": "epigrafar",
    "epigrafávei": "epigrafar",
    "epigrafáveis": "epigrafar",
    "epigramas": "epigrama",
    "epigramatistas": "epigramatista",
    "epigramatiza": "epigramatizar",
    "epigramatizada": "epigramatizar",
    "epigramatizadas": "epigramatizar",
    "epigramatizado": "epigramatizar",
    "epigramatizados": "epigramatizar",
    "epigramatizai": "epigramatizar",
    "epigramatizais": "epigramatizar",
    "epigramatizam": "epigramatizar",
    "epigramatizamo": "epigramatizar",
    "epigramatizamos": "epigramatizar",
    "epigramatizando": "epigramatizar",
    "epigramatizara": "epigramatizar",
    "epigramatizaram": "epigramatizar",
    "epigramatizaras": "epigramatizar",
    "epigramatizarde": "epigramatizar",
    "epigramatizardes": "epigramatizar",
    "epigramatizare": "epigramatizar",
    "epigramatizarei": "epigramatizar",
    "epigramatizareis": "epigramatizar",
    "epigramatizarem": "epigramatizar",
    "epigramatizaremos": "epigramatizar",
    "epigramatizares": "epigramatizar",
    "epigramatizaria": "epigramatizar",
    "epigramatizariam": "epigramatizar",
    "epigramatizarias": "epigramatizar",
    "epigramatizarmo": "epigramatizar",
    "epigramatizarmos": "epigramatizar",
    "epigramatizará": "epigramatizar",
    "epigramatizarás": "epigramatizar",
    "epigramatizarão": "epigramatizar",
    "epigramatizaríamos": "epigramatizar",
    "epigramatizaríeis": "epigramatizar",
    "epigramatizas": "epigramatizar",
    "epigramatizasse": "epigramatizar",
    "epigramatizassem": "epigramatizar",
    "epigramatizasses": "epigramatizar",
    "epigramatizaste": "epigramatizar",
    "epigramatizastes": "epigramatizar",
    "epigramatizava": "epigramatizar",
    "epigramatizavam": "epigramatizar",
    "epigramatizavas": "epigramatizar",
    "epigramatize": "epigramatizar",
    "epigramatizei": "epigramatizar",
    "epigramatizeis": "epigramatizar",
    "epigramatizem": "epigramatizar",
    "epigramatizemo": "epigramatizar",
    "epigramatizemos": "epigramatizar",
    "epigramatizes": "epigramatizar",
    "epigramatizo": "epigramatizar",
    "epigramatizou": "epigramatizar",
    "epigramatizá": "epigramatizar",
    "epigramatizámo": "epigramatizar",
    "epigramatizámos": "epigramatizar",
    "epigramatizáramo": "epigramatizar",
    "epigramatizáramos": "epigramatizar",
    "epigramatizárei": "epigramatizar",
    "epigramatizáreis": "epigramatizar",
    "epigramatizásseis": "epigramatizar",
    "epigramatizássemos": "epigramatizar",
    "epigramatizávamo": "epigramatizar",
    "epigramatizávamos": "epigramatizar",
    "epigramatizávei": "epigramatizar",
    "epigramatizáveis": "epigramatizar",
    "epigramática": "epigramático",
    "epigramáticas": "epigramático",
    "epigramáticos": "epigramático",
    "epigráfica": "epigráfico",
    "epigráficas": "epigráfico",
    "epigráficos": "epigráfico",
    "epigástrica": "epigástrico",
    "epigástricas": "epigástrico",
    "epigástricos": "epigástrico",
    "epigástrios": "epigástrio",
    "epigâmica": "epigâmico",
    "epigâmicas": "epigâmico",
    "epigâmicos": "epigâmico",
    "epigéneses": "epigénese",
    "epigénica": "epigénico",
    "epigénicas": "epigénico",
    "epigénicos": "epigénico",
    "epigínica": "epigínico",
    "epigínicas": "epigínico",
    "epigínicos": "epigínico",
    "epigónia": "epigónio",
    "epigónias": "epigónio",
    "epigónios": "epigónio",
    "epilatória": "epilatório",
    "epilatórias": "epilatório",
    "epilatórios": "epilatório",
    "epilações": "epilação",
    "epilepsias": "epilepsia",
    "epileptiformes": "epileptiforme",
    "epileptóides": "epileptóide",
    "epilobiácea": "epilobiáceo",
    "epilobiáceas": "epilobiáceo",
    "epilobiáceos": "epilobiáceo",
    "epiloga": "epilogar",
    "epilogada": "epilogar",
    "epilogadas": "epilogar",
    "epilogado": "epilogar",
    "epilogadora": "epilogador",
    "epilogadoras": "epilogador",
    "epilogadores": "epilogador",
    "epilogados": "epilogar",
    "epilogai": "epilogar",
    "epilogais": "epilogar",
    "epilogam": "epilogar",
    "epilogamo": "epilogar",
    "epilogamos": "epilogar",
    "epilogando": "epilogar",
    "epilogara": "epilogar",
    "epilogaram": "epilogar",
    "epilogaras": "epilogar",
    "epilogarde": "epilogar",
    "epilogardes": "epilogar",
    "epilogare": "epilogar",
    "epilogarei": "epilogar",
    "epilogareis": "epilogar",
    "epilogarem": "epilogar",
    "epilogaremos": "epilogar",
    "epilogares": "epilogar",
    "epilogaria": "epilogar",
    "epilogariam": "epilogar",
    "epilogarias": "epilogar",
    "epilogarmo": "epilogar",
    "epilogarmos": "epilogar",
    "epilogará": "epilogar",
    "epilogarás": "epilogar",
    "epilogarão": "epilogar",
    "epilogaríamos": "epilogar",
    "epilogaríeis": "epilogar",
    "epilogas": "epilogar",
    "epilogasse": "epilogar",
    "epilogassem": "epilogar",
    "epilogasses": "epilogar",
    "epilogaste": "epilogar",
    "epilogastes": "epilogar",
    "epilogava": "epilogar",
    "epilogavam": "epilogar",
    "epilogavas": "epilogar",
    "epilogações": "epilogação",
    "epilogo": "epilogar",
    "epilogou": "epilogar",
    "epilogue": "epilogar",
    "epiloguei": "epilogar",
    "epilogueis": "epilogar",
    "epiloguem": "epilogar",
    "epiloguemo": "epilogar",
    "epiloguemos": "epilogar",
    "epilogues": "epilogar",
    "epilogá": "epilogar",
    "epilogámo": "epilogar",
    "epilogámos": "epilogar",
    "epilogáramo": "epilogar",
    "epilogáramos": "epilogar",
    "epilogárei": "epilogar",
    "epilogáreis": "epilogar",
    "epilogásseis": "epilogar",
    "epilogássemos": "epilogar",
    "epilogávamo": "epilogar",
    "epilogávamos": "epilogar",
    "epilogávei": "epilogar",
    "epilogáveis": "epilogar",
    "epiléptica": "epiléptico",
    "epilépticas": "epiléptico",
    "epilépticos": "epiléptico",
    "epimérica": "epimérico",
    "epiméricas": "epimérico",
    "epiméricos": "epimérico",
    "epinefrinas": "epinefrina",
    "epinemas": "epinema",
    "epinícia": "epinício",
    "epinícias": "epinício",
    "epinícios": "epinício",
    "epioolítica": "epioolítico",
    "epioolíticas": "epioolítico",
    "epioolíticos": "epioolítico",
    "epiploones": "epiploon",
    "epipétala": "epipétalo",
    "epipétalas": "epipétalo",
    "epipétalos": "epipétalo",
    "epipódios": "epipódio",
    "epipóditos": "epipódito",
    "epiqueias": "epiqueia",
    "epiquiremas": "epiquirema",
    "epiroforeses": "epiroforese",
    "epirogénica": "epirogénico",
    "epirogénicas": "epirogénico",
    "epirogénicos": "epirogénico",
    "epirotas": "epirota",
    "episcopados": "episcopado",
    "episcopais": "episcopal",
    "episcopaliana": "episcopaliano",
    "episcopalianas": "episcopaliano",
    "episcopalianos": "episcopaliano",
    "episcopisas": "episcopisa",
    "episcénios": "episcénio",
    "episcópica": "episcópico",
    "episcópicas": "episcópico",
    "episcópicos": "episcópico",
    "episcópios": "episcópio",
    "episodia": "episodiar",
    "episodiada": "episodiar",
    "episodiadas": "episodiar",
    "episodiado": "episodiar",
    "episodiadora": "episodiador",
    "episodiadoras": "episodiador",
    "episodiadores": "episodiador",
    "episodiados": "episodiar",
    "episodiai": "episodiar",
    "episodiais": "episodiar",
    "episodiam": "episodiar",
    "episodiamo": "episodiar",
    "episodiamos": "episodiar",
    "episodiando": "episodiar",
    "episodiara": "episodiar",
    "episodiaram": "episodiar",
    "episodiaras": "episodiar",
    "episodiarde": "episodiar",
    "episodiardes": "episodiar",
    "episodiare": "episodiar",
    "episodiarei": "episodiar",
    "episodiareis": "episodiar",
    "episodiarem": "episodiar",
    "episodiaremos": "episodiar",
    "episodiares": "episodiar",
    "episodiaria": "episodiar",
    "episodiariam": "episodiar",
    "episodiarias": "episodiar",
    "episodiarmo": "episodiar",
    "episodiarmos": "episodiar",
    "episodiará": "episodiar",
    "episodiarás": "episodiar",
    "episodiarão": "episodiar",
    "episodiaríamos": "episodiar",
    "episodiaríeis": "episodiar",
    "episodias": "episodiar",
    "episodiasse": "episodiar",
    "episodiassem": "episodiar",
    "episodiasses": "episodiar",
    "episodiaste": "episodiar",
    "episodiastes": "episodiar",
    "episodiava": "episodiar",
    "episodiavam": "episodiar",
    "episodiavas": "episodiar",
    "episodie": "episodiar",
    "episodiei": "episodiar",
    "episodieis": "episodiar",
    "episodiem": "episodiar",
    "episodiemo": "episodiar",
    "episodiemos": "episodiar",
    "episodies": "episodiar",
    "episodio": "episodiar",
    "episodiou": "episodiar",
    "episodiá": "episodiar",
    "episodiámo": "episodiar",
    "episodiámos": "episodiar",
    "episodiáramo": "episodiar",
    "episodiáramos": "episodiar",
    "episodiárei": "episodiar",
    "episodiáreis": "episodiar",
    "episodiásseis": "episodiar",
    "episodiássemos": "episodiar",
    "episodiávamo": "episodiar",
    "episodiávamos": "episodiar",
    "episodiávei": "episodiar",
    "episodiáveis": "episodiar",
    "epispermas": "episperma",
    "epispermática": "epispermático",
    "epispermáticas": "epispermático",
    "epispermáticos": "epispermático",
    "epissilogismos": "epissilogismo",
    "epissomas": "epissoma",
    "epissépala": "epissépalo",
    "epissépalas": "epissépalo",
    "epissépalos": "epissépalo",
    "epista": "epistar",
    "epistada": "epistar",
    "epistadas": "epistar",
    "epistado": "epistar",
    "epistados": "epistar",
    "epistai": "epistar",
    "epistais": "epistar",
    "epistam": "epistar",
    "epistaminada": "epistaminado",
    "epistaminadas": "epistaminado",
    "epistaminados": "epistaminado",
    "epistamo": "epistar",
    "epistamos": "epistar",
    "epistando": "epistar",
    "epistara": "epistar",
    "epistaram": "epistar",
    "epistaras": "epistar",
    "epistarde": "epistar",
    "epistardes": "epistar",
    "epistare": "epistar",
    "epistarei": "epistar",
    "epistareis": "epistar",
    "epistarem": "epistar",
    "epistaremos": "epistar",
    "epistares": "epistar",
    "epistaria": "epistar",
    "epistariam": "epistar",
    "epistarias": "epistar",
    "epistarmo": "epistar",
    "epistarmos": "epistar",
    "epistará": "epistar",
    "epistarás": "epistar",
    "epistarão": "epistar",
    "epistaríamos": "epistar",
    "epistaríeis": "epistar",
    "epistas": "epistar",
    "epistasse": "epistar",
    "epistassem": "epistar",
    "epistasses": "epistar",
    "epistaste": "epistar",
    "epistastes": "epistar",
    "epistava": "epistar",
    "epistavam": "epistar",
    "epistavas": "epistar",
    "epistaxes": "epistaxe",
    "epistações": "epistação",
    "episte": "epistar",
    "epistei": "epistar",
    "episteis": "epistar",
    "epistem": "epistar",
    "epistemas": "epistema",
    "epistemo": "epistar",
    "epistemologias": "epistemologia",
    "epistemologistas": "epistemologista",
    "epistemológica": "epistemológico",
    "epistemológicas": "epistemológico",
    "epistemológicos": "epistemológico",
    "epistemos": "epistar",
    "epistemólogos": "epistemólogo",
    "episternos": "episterno",
    "epistes": "epistar",
    "episto": "epistar",
    "epistola": "epistolar",
    "epistolada": "epistolar",
    "epistoladas": "epistolar",
    "epistolado": "epistolar",
    "epistolados": "epistolar",
    "epistolai": "epistolar",
    "epistolais": "epistolar",
    "epistolam": "epistolar",
    "epistolamo": "epistolar",
    "epistolamos": "epistolar",
    "epistolando": "epistolar",
    "epistolara": "epistolar",
    "epistolaram": "epistolar",
    "epistolaras": "epistolar",
    "epistolarde": "epistolar",
    "epistolardes": "epistolar",
    "epistolare": "epistolar",
    "epistolarei": "epistolar",
    "epistolareis": "epistolar",
    "epistolarem": "epistolar",
    "epistolaremos": "epistolar",
    "epistolares": "epistolar",
    "epistolaria": "epistolar",
    "epistolariam": "epistolar",
    "epistolarias": "epistolar",
    "epistolarmo": "epistolar",
    "epistolarmos": "epistolar",
    "epistolará": "epistolar",
    "epistolarás": "epistolar",
    "epistolarão": "epistolar",
    "epistolaríamos": "epistolar",
    "epistolaríeis": "epistolar",
    "epistolas": "epistolar",
    "epistolasse": "epistolar",
    "epistolassem": "epistolar",
    "epistolasses": "epistolar",
    "epistolaste": "epistolar",
    "epistolastes": "epistolar",
    "epistolava": "epistolar",
    "epistolavam": "epistolar",
    "epistolavas": "epistolar",
    "epistole": "epistolar",
    "epistolei": "epistolar",
    "epistoleis": "epistolar",
    "epistolem": "epistolar",
    "epistolemo": "epistolar",
    "epistolemos": "epistolar",
    "epistoles": "epistolar",
    "epistolo": "epistolar",
    "epistologias": "epistologia",
    "epistolografias": "epistolografia",
    "epistolográfica": "epistolográfico",
    "epistolográficas": "epistolográfico",
    "epistolográficos": "epistolográfico",
    "epistolou": "epistolar",
    "epistolá": "epistolar",
    "epistolámo": "epistolar",
    "epistolámos": "epistolar",
    "epistoláramo": "epistolar",
    "epistoláramos": "epistolar",
    "epistolárei": "epistolar",
    "epistoláreis": "epistolar",
    "epistolários": "epistolário",
    "epistolásseis": "epistolar",
    "epistolássemos": "epistolar",
    "epistolávamo": "epistolar",
    "epistolávamos": "epistolar",
    "epistolávei": "epistolar",
    "epistoláveis": "epistolar",
    "epistológrafa": "epistológrafo",
    "epistológrafas": "epistológrafo",
    "epistológrafos": "epistológrafo",
    "epistomas": "epistoma",
    "epistou": "epistar",
    "epistá": "epistar",
    "epistámo": "epistar",
    "epistámos": "epistar",
    "epistáramo": "epistar",
    "epistáramos": "epistar",
    "epistárei": "epistar",
    "epistáreis": "epistar",
    "epistásseis": "epistar",
    "epistássemos": "epistar",
    "epistávamo": "epistar",
    "epistávamos": "epistar",
    "epistávei": "epistar",
    "epistáveis": "epistar",
    "epistílios": "epistílio",
    "epistómios": "epistómio",
    "episódica": "episódico",
    "episódicas": "episódico",
    "episódicos": "episódico",
    "episódios": "episódio",
    "epitafistas": "epitafista",
    "epitalâmica": "epitalâmico",
    "epitalâmicas": "epitalâmico",
    "epitalâmicos": "epitalâmico",
    "epitalâmios": "epitalâmio",
    "epitaxias": "epitaxia",
    "epiteliais": "epitelial",
    "epiteliomas": "epitelioma",
    "epiteliomatosa": "epiteliomatoso",
    "epiteliomatosas": "epiteliomatoso",
    "epiteliomatosos": "epiteliomatoso",
    "epiteliomática": "epiteliomático",
    "epiteliomáticas": "epiteliomático",
    "epiteliomáticos": "epiteliomático",
    "epitelióides": "epitelióide",
    "epitemática": "epitemático",
    "epitemáticas": "epitemático",
    "epitemáticos": "epitemático",
    "epiteta": "epitetar",
    "epitetada": "epitetar",
    "epitetadas": "epitetar",
    "epitetado": "epitetar",
    "epitetados": "epitetar",
    "epitetai": "epitetar",
    "epitetais": "epitetar",
    "epitetam": "epitetar",
    "epitetamo": "epitetar",
    "epitetamos": "epitetar",
    "epitetando": "epitetar",
    "epitetara": "epitetar",
    "epitetaram": "epitetar",
    "epitetaras": "epitetar",
    "epitetarde": "epitetar",
    "epitetardes": "epitetar",
    "epitetare": "epitetar",
    "epitetarei": "epitetar",
    "epitetareis": "epitetar",
    "epitetarem": "epitetar",
    "epitetaremos": "epitetar",
    "epitetares": "epitetar",
    "epitetaria": "epitetar",
    "epitetariam": "epitetar",
    "epitetarias": "epitetar",
    "epitetarmo": "epitetar",
    "epitetarmos": "epitetar",
    "epitetará": "epitetar",
    "epitetarás": "epitetar",
    "epitetarão": "epitetar",
    "epitetaríamos": "epitetar",
    "epitetaríeis": "epitetar",
    "epitetas": "epitetar",
    "epitetasse": "epitetar",
    "epitetassem": "epitetar",
    "epitetasses": "epitetar",
    "epitetaste": "epitetar",
    "epitetastes": "epitetar",
    "epitetava": "epitetar",
    "epitetavam": "epitetar",
    "epitetavas": "epitetar",
    "epitete": "epitetar",
    "epitetei": "epitetar",
    "epiteteis": "epitetar",
    "epitetem": "epitetar",
    "epitetemo": "epitetar",
    "epitetemos": "epitetar",
    "epitetes": "epitetar",
    "epitetismos": "epitetismo",
    "epiteto": "epitetar",
    "epitetou": "epitetar",
    "epitetá": "epitetar",
    "epitetámo": "epitetar",
    "epitetámos": "epitetar",
    "epitetáramo": "epitetar",
    "epitetáramos": "epitetar",
    "epitetárei": "epitetar",
    "epitetáreis": "epitetar",
    "epitetásseis": "epitetar",
    "epitetássemos": "epitetar",
    "epitetávamo": "epitetar",
    "epitetávamos": "epitetar",
    "epitetávei": "epitetar",
    "epitetáveis": "epitetar",
    "epitimologias": "epitimologia",
    "epitimológica": "epitimológico",
    "epitimológicas": "epitimológico",
    "epitimológicos": "epitimológico",
    "epitimotécnica": "epitimotécnico",
    "epitimotécnicas": "epitimotécnico",
    "epitimotécnicos": "epitimotécnico",
    "epitoma": "epitomar",
    "epitomada": "epitomar",
    "epitomadas": "epitomar",
    "epitomado": "epitomar",
    "epitomados": "epitomar",
    "epitomai": "epitomar",
    "epitomais": "epitomar",
    "epitomam": "epitomar",
    "epitomamo": "epitomar",
    "epitomamos": "epitomar",
    "epitomando": "epitomar",
    "epitomara": "epitomar",
    "epitomaram": "epitomar",
    "epitomaras": "epitomar",
    "epitomarde": "epitomar",
    "epitomardes": "epitomar",
    "epitomare": "epitomar",
    "epitomarei": "epitomar",
    "epitomareis": "epitomar",
    "epitomarem": "epitomar",
    "epitomaremos": "epitomar",
    "epitomares": "epitomar",
    "epitomaria": "epitomar",
    "epitomariam": "epitomar",
    "epitomarias": "epitomar",
    "epitomarmo": "epitomar",
    "epitomarmos": "epitomar",
    "epitomará": "epitomar",
    "epitomarás": "epitomar",
    "epitomarão": "epitomar",
    "epitomaríamos": "epitomar",
    "epitomaríeis": "epitomar",
    "epitomas": "epitomar",
    "epitomasse": "epitomar",
    "epitomassem": "epitomar",
    "epitomasses": "epitomar",
    "epitomaste": "epitomar",
    "epitomastes": "epitomar",
    "epitomava": "epitomar",
    "epitomavam": "epitomar",
    "epitomavas": "epitomar",
    "epitome": "epitomar",
    "epitomei": "epitomar",
    "epitomeis": "epitomar",
    "epitomem": "epitomar",
    "epitomemo": "epitomar",
    "epitomemos": "epitomar",
    "epitomes": "epitomar",
    "epitomo": "epitomar",
    "epitomou": "epitomar",
    "epitomá": "epitomar",
    "epitomámo": "epitomar",
    "epitomámos": "epitomar",
    "epitomáramo": "epitomar",
    "epitomáramos": "epitomar",
    "epitomárei": "epitomar",
    "epitomáreis": "epitomar",
    "epitomásseis": "epitomar",
    "epitomássemos": "epitomar",
    "epitomávamo": "epitomar",
    "epitomávamos": "epitomar",
    "epitomávei": "epitomar",
    "epitomáveis": "epitomar",
    "epitrita": "epitrito",
    "epitritas": "epitrito",
    "epitritos": "epitrito",
    "epituitária": "epituitário",
    "epituitárias": "epituitário",
    "epituitários": "epituitário",
    "epitáfios": "epitáfio",
    "epitálamos": "epitálamo",
    "epitáxica": "epitáxico",
    "epitáxicas": "epitáxico",
    "epitáxicos": "epitáxico",
    "epitélica": "epitélico",
    "epitélicas": "epitélico",
    "epitélicos": "epitélico",
    "epitélios": "epitélio",
    "epitética": "epitético",
    "epitéticas": "epitético",
    "epitéticos": "epitético",
    "epitógios": "epitógio",
    "epitómica": "epitómico",
    "epitómicas": "epitómico",
    "epitómicos": "epitómico",
    "epizeuxes": "epizeuxe",
    "epizonas": "epizona",
    "epizootias": "epizootia",
    "epizoária": "epizoário",
    "epizoárias": "epizoário",
    "epizoários": "epizoário",
    "epizoótica": "epizoótico",
    "epizoóticas": "epizoótico",
    "epizoóticos": "epizoótico",
    "epizêuxica": "epizêuxico",
    "epizêuxicas": "epizêuxico",
    "epizêuxicos": "epizêuxico",
    "epizóica": "epizóico",
    "epizóicas": "epizóico",
    "epizóicos": "epizóico",
    "epióptica": "epióptico",
    "epiópticas": "epióptico",
    "epiópticos": "epióptico",
    "epióticos": "epiótico",
    "epocais": "epocal",
    "epodos": "epodo",
    "epolótica": "epolótico",
    "epolóticas": "epolótico",
    "epolóticos": "epolótico",
    "eponímias": "eponímia",
    "eponímica": "eponímico",
    "eponímicas": "eponímico",
    "eponímicos": "eponímico",
    "epopeias": "epopeia",
    "epopeica": "epopeico",
    "epopeicas": "epopeico",
    "epopeicos": "epopeico",
    "epulões": "epulão",
    "epácridas": "epácrida",
    "epânodos": "epânodo",
    "epêndimas": "epêndima",
    "epênteses": "epêntese",
    "epícrises": "epícrise",
    "epídemas": "epídema",
    "epídotos": "epídoto",
    "epífises": "epífise",
    "epífita": "epífito",
    "epífitas": "epífito",
    "epífitos": "epífito",
    "epíforas": "epífora",
    "epífrases": "epífrase",
    "epígea": "epígeo",
    "epígeas": "epígeo",
    "epígeos": "epígeo",
    "epígina": "epígino",
    "epíginas": "epígino",
    "epíginos": "epígino",
    "epígona": "epígono",
    "epígonas": "epígono",
    "epígonos": "epígono",
    "epígrafes": "epígrafe",
    "epílogos": "epílogo",
    "epímera": "epímero",
    "epímeras": "epímero",
    "epímeros": "epímero",
    "epíploos": "epíploo",
    "epíscopos": "epíscopo",
    "epístolas": "epístola",
    "epístomos": "epístomo",
    "epístrofes": "epístrofe",
    "epítases": "epítase",
    "epítemas": "epítema",
    "epíteses": "epítese",
    "epítetos": "epíteto",
    "epítomes": "epítome",
    "epítropes": "epítrope",
    "epódica": "epódico",
    "epódicas": "epódico",
    "epódicos": "epódico",
    "epónimos": "epónimo",
    "epúlidas": "epúlida",
    "epúlides": "epúlide",
    "equabilidades": "equabilidade",
    "equaciona": "equacionar",
    "equacionada": "equacionar",
    "equacionadas": "equacionar",
    "equacionado": "equacionar",
    "equacionadora": "equacionador",
    "equacionadoras": "equacionador",
    "equacionadores": "equacionador",
    "equacionados": "equacionar",
    "equacionai": "equacionar",
    "equacionais": "equacionar",
    "equacionam": "equacionar",
    "equacionamentos": "equacionamento",
    "equacionamo": "equacionar",
    "equacionamos": "equacionar",
    "equacionando": "equacionar",
    "equacionara": "equacionar",
    "equacionaram": "equacionar",
    "equacionaras": "equacionar",
    "equacionarde": "equacionar",
    "equacionardes": "equacionar",
    "equacionare": "equacionar",
    "equacionarei": "equacionar",
    "equacionareis": "equacionar",
    "equacionarem": "equacionar",
    "equacionaremos": "equacionar",
    "equacionares": "equacionar",
    "equacionaria": "equacionar",
    "equacionariam": "equacionar",
    "equacionarias": "equacionar",
    "equacionarmo": "equacionar",
    "equacionarmos": "equacionar",
    "equacionará": "equacionar",
    "equacionarás": "equacionar",
    "equacionarão": "equacionar",
    "equacionaríamos": "equacionar",
    "equacionaríeis": "equacionar",
    "equacionas": "equacionar",
    "equacionasse": "equacionar",
    "equacionassem": "equacionar",
    "equacionasses": "equacionar",
    "equacionaste": "equacionar",
    "equacionastes": "equacionar",
    "equacionava": "equacionar",
    "equacionavam": "equacionar",
    "equacionavas": "equacionar",
    "equacione": "equacionar",
    "equacionei": "equacionar",
    "equacioneis": "equacionar",
    "equacionem": "equacionar",
    "equacionemo": "equacionar",
    "equacionemos": "equacionar",
    "equaciones": "equacionar",
    "equaciono": "equacionar",
    "equacionou": "equacionar",
    "equacioná": "equacionar",
    "equacionámo": "equacionar",
    "equacionámos": "equacionar",
    "equacionáramo": "equacionar",
    "equacionáramos": "equacionar",
    "equacionárei": "equacionar",
    "equacionáreis": "equacionar",
    "equacionásseis": "equacionar",
    "equacionássemos": "equacionar",
    "equacionávamo": "equacionar",
    "equacionávamos": "equacionar",
    "equacionávei": "equacionar",
    "equacionáveis": "equacionável",
    "equadores": "equador",
    "equalizadores": "equalizador",
    "equalizações": "equalização",
    "equanimidades": "equanimidade",
    "equatoriais": "equatorial",
    "equatoriana": "equatoriano",
    "equatorianas": "equatoriano",
    "equatorianos": "equatoriano",
    "equações": "equação",
    "equestres": "equestre",
    "equeva": "equevo",
    "equevas": "equevo",
    "equevos": "equevo",
    "equicrurais": "equicrural",
    "equidades": "equidade",
    "equidiferentes": "equidiferente",
    "equidiferenças": "equidiferença",
    "equidista": "equidistar",
    "equidistada": "equidistar",
    "equidistadas": "equidistar",
    "equidistado": "equidistar",
    "equidistados": "equidistar",
    "equidistai": "equidistar",
    "equidistais": "equidistar",
    "equidistam": "equidistar",
    "equidistamo": "equidistar",
    "equidistamos": "equidistar",
    "equidistando": "equidistar",
    "equidistantes": "equidistante",
    "equidistara": "equidistar",
    "equidistaram": "equidistar",
    "equidistaras": "equidistar",
    "equidistardes": "equidistar",
    "equidistarei": "equidistar",
    "equidistareis": "equidistar",
    "equidistarem": "equidistar",
    "equidistaremos": "equidistar",
    "equidistares": "equidistar",
    "equidistaria": "equidistar",
    "equidistariam": "equidistar",
    "equidistarias": "equidistar",
    "equidistarmo": "equidistar",
    "equidistarmos": "equidistar",
    "equidistará": "equidistar",
    "equidistarás": "equidistar",
    "equidistarão": "equidistar",
    "equidistaríamos": "equidistar",
    "equidistaríeis": "equidistar",
    "equidistas": "equidistar",
    "equidistasse": "equidistar",
    "equidistassem": "equidistar",
    "equidistasses": "equidistar",
    "equidistaste": "equidistar",
    "equidistastes": "equidistar",
    "equidistava": "equidistar",
    "equidistavam": "equidistar",
    "equidistavas": "equidistar",
    "equidiste": "equidistar",
    "equidistei": "equidistar",
    "equidisteis": "equidistar",
    "equidistem": "equidistar",
    "equidistemo": "equidistar",
    "equidistemos": "equidistar",
    "equidistes": "equidistar",
    "equidisto": "equidistar",
    "equidistou": "equidistar",
    "equidistámo": "equidistar",
    "equidistámos": "equidistar",
    "equidistáramo": "equidistar",
    "equidistáramos": "equidistar",
    "equidistáreis": "equidistar",
    "equidistásseis": "equidistar",
    "equidistássemos": "equidistar",
    "equidistávamo": "equidistar",
    "equidistávamos": "equidistar",
    "equidistáveis": "equidistar",
    "equidistâncias": "equidistância",
    "equidnas": "equidna",
    "equidnos": "equidno",
    "equifaciais": "equifacial",
    "equilaterais": "equilateral",
    "equilibra": "equilibrar",
    "equilibrada": "equilibrar",
    "equilibradas": "equilibrar",
    "equilibrado": "equilibrar",
    "equilibradora": "equilibrador",
    "equilibradoras": "equilibrador",
    "equilibradores": "equilibrador",
    "equilibrados": "equilibrar",
    "equilibradíssima": "equilibrado",
    "equilibradíssimas": "equilibrado",
    "equilibradíssimo": "equilibrado",
    "equilibradíssimos": "equilibrado",
    "equilibrai": "equilibrar",
    "equilibrais": "equilibrar",
    "equilibram": "equilibrar",
    "equilibramo": "equilibrar",
    "equilibramos": "equilibrar",
    "equilibrando": "equilibrar",
    "equilibrantes": "equilibrante",
    "equilibrara": "equilibrar",
    "equilibraram": "equilibrar",
    "equilibraras": "equilibrar",
    "equilibrarde": "equilibrar",
    "equilibrardes": "equilibrar",
    "equilibrare": "equilibrar",
    "equilibrarei": "equilibrar",
    "equilibrareis": "equilibrar",
    "equilibrarem": "equilibrar",
    "equilibraremos": "equilibrar",
    "equilibrares": "equilibrar",
    "equilibraria": "equilibrar",
    "equilibrariam": "equilibrar",
    "equilibrarias": "equilibrar",
    "equilibrarmo": "equilibrar",
    "equilibrarmos": "equilibrar",
    "equilibrará": "equilibrar",
    "equilibrarás": "equilibrar",
    "equilibrarão": "equilibrar",
    "equilibraríamos": "equilibrar",
    "equilibraríeis": "equilibrar",
    "equilibras": "equilibrar",
    "equilibrasse": "equilibrar",
    "equilibrassem": "equilibrar",
    "equilibrasses": "equilibrar",
    "equilibraste": "equilibrar",
    "equilibrastes": "equilibrar",
    "equilibrava": "equilibrar",
    "equilibravam": "equilibrar",
    "equilibravas": "equilibrar",
    "equilibrações": "equilibração",
    "equilibre": "equilibrar",
    "equilibrei": "equilibrar",
    "equilibreis": "equilibrar",
    "equilibrem": "equilibrar",
    "equilibremo": "equilibrar",
    "equilibremos": "equilibrar",
    "equilibres": "equilibrar",
    "equilibrismos": "equilibrismo",
    "equilibristas": "equilibrista",
    "equilibro": "equilibrar",
    "equilibrou": "equilibrar",
    "equilibrá": "equilibrar",
    "equilibrámo": "equilibrar",
    "equilibrámos": "equilibrar",
    "equilibráramo": "equilibrar",
    "equilibráramos": "equilibrar",
    "equilibrárei": "equilibrar",
    "equilibráreis": "equilibrar",
    "equilibrásseis": "equilibrar",
    "equilibrássemos": "equilibrar",
    "equilibrávamo": "equilibrar",
    "equilibrávamos": "equilibrar",
    "equilibrávei": "equilibrar",
    "equilibráveis": "equilibrável",
    "equilátera": "equilátero",
    "equiláteras": "equilátero",
    "equiláteros": "equilátero",
    "equilíbrios": "equilíbrio",
    "equimoleculares": "equimolecular",
    "equimosa": "equimosar",
    "equimosada": "equimosar",
    "equimosadas": "equimosar",
    "equimosado": "equimosar",
    "equimosados": "equimosar",
    "equimosai": "equimosar",
    "equimosais": "equimosar",
    "equimosam": "equimosar",
    "equimosamo": "equimosar",
    "equimosamos": "equimosar",
    "equimosando": "equimosar",
    "equimosara": "equimosar",
    "equimosaram": "equimosar",
    "equimosaras": "equimosar",
    "equimosarde": "equimosar",
    "equimosardes": "equimosar",
    "equimosare": "equimosar",
    "equimosarei": "equimosar",
    "equimosareis": "equimosar",
    "equimosarem": "equimosar",
    "equimosaremos": "equimosar",
    "equimosares": "equimosar",
    "equimosaria": "equimosar",
    "equimosariam": "equimosar",
    "equimosarias": "equimosar",
    "equimosarmo": "equimosar",
    "equimosarmos": "equimosar",
    "equimosará": "equimosar",
    "equimosarás": "equimosar",
    "equimosarão": "equimosar",
    "equimosaríamos": "equimosar",
    "equimosaríeis": "equimosar",
    "equimosas": "equimosar",
    "equimosasse": "equimosar",
    "equimosassem": "equimosar",
    "equimosasses": "equimosar",
    "equimosaste": "equimosar",
    "equimosastes": "equimosar",
    "equimosava": "equimosar",
    "equimosavam": "equimosar",
    "equimosavas": "equimosar",
    "equimose": "equimosar",
    "equimosei": "equimosar",
    "equimoseis": "equimosar",
    "equimosem": "equimosar",
    "equimosemo": "equimosar",
    "equimosemos": "equimosar",
    "equimoses": "equimose",
    "equimoso": "equimosar",
    "equimosou": "equimosar",
    "equimosá": "equimosar",
    "equimosámo": "equimosar",
    "equimosámos": "equimosar",
    "equimosáramo": "equimosar",
    "equimosáramos": "equimosar",
    "equimosárei": "equimosar",
    "equimosáreis": "equimosar",
    "equimosásseis": "equimosar",
    "equimosássemos": "equimosar",
    "equimosávamo": "equimosar",
    "equimosávamos": "equimosar",
    "equimosávei": "equimosar",
    "equimosáveis": "equimosar",
    "equimótica": "equimótico",
    "equimóticas": "equimótico",
    "equimóticos": "equimótico",
    "equimúltipla": "equimúltiplo",
    "equimúltiplas": "equimúltiplo",
    "equimúltiplos": "equimúltiplo",
    "equina": "equino",
    "equinas": "equino",
    "equinociais": "equinocial",
    "equinococoses": "equinococose",
    "equinoculturas": "equinocultura",
    "equinodermos": "equinodermo",
    "equinos": "equino",
    "equinídea": "equinídeo",
    "equinídeas": "equinídeo",
    "equinídeos": "equinídeo",
    "equinídia": "equinídio",
    "equinídias": "equinídio",
    "equinídios": "equinídio",
    "equinócios": "equinócio",
    "equinóides": "equinóide",
    "equipa": "equipar",
    "equipada": "equipar",
    "equipadas": "equipar",
    "equipado": "equipar",
    "equipados": "equipar",
    "equipadíssima": "equipado",
    "equipadíssimas": "equipado",
    "equipadíssimo": "equipado",
    "equipadíssimos": "equipado",
    "equipagens": "equipagem",
    "equipai": "equipar",
    "equipais": "equipar",
    "equipam": "equipar",
    "equipamentos": "equipamento",
    "equipamo": "equipar",
    "equipamos": "equipar",
    "equipando": "equipar",
    "equipara": "equiparar",
    "equiparada": "equiparar",
    "equiparadas": "equiparar",
    "equiparado": "equiparar",
    "equiparados": "equiparar",
    "equiparai": "equiparar",
    "equiparais": "equiparar",
    "equiparam": "equiparar",
    "equiparamo": "equiparar",
    "equiparamos": "equiparar",
    "equiparando": "equiparar",
    "equiparara": "equiparar",
    "equipararam": "equiparar",
    "equipararas": "equiparar",
    "equipararde": "equiparar",
    "equiparardes": "equiparar",
    "equiparare": "equiparar",
    "equipararei": "equiparar",
    "equiparareis": "equiparar",
    "equipararem": "equiparar",
    "equipararemos": "equiparar",
    "equiparares": "equiparar",
    "equipararia": "equiparar",
    "equiparariam": "equiparar",
    "equipararias": "equiparar",
    "equipararmo": "equiparar",
    "equipararmos": "equiparar",
    "equiparará": "equiparar",
    "equipararás": "equiparar",
    "equipararão": "equiparar",
    "equipararíamos": "equiparar",
    "equipararíeis": "equiparar",
    "equiparas": "equiparar",
    "equiparasse": "equiparar",
    "equiparassem": "equiparar",
    "equiparasses": "equiparar",
    "equiparaste": "equiparar",
    "equiparastes": "equiparar",
    "equiparava": "equiparar",
    "equiparavam": "equiparar",
    "equiparavas": "equiparar",
    "equiparações": "equiparação",
    "equiparde": "equipar",
    "equipardes": "equipar",
    "equipare": "equiparar",
    "equiparei": "equiparar",
    "equipareis": "equiparar",
    "equiparem": "equiparar",
    "equiparemo": "equiparar",
    "equiparemos": "equiparar",
    "equipares": "equiparar",
    "equiparia": "equipar",
    "equipariam": "equipar",
    "equiparias": "equipar",
    "equiparmo": "equipar",
    "equiparmos": "equipar",
    "equiparo": "equiparar",
    "equiparou": "equiparar",
    "equipará": "equiparar",
    "equiparámo": "equiparar",
    "equiparámos": "equiparar",
    "equiparáramo": "equiparar",
    "equiparáramos": "equiparar",
    "equiparárei": "equiparar",
    "equiparáreis": "equiparar",
    "equiparás": "equipar",
    "equiparásseis": "equiparar",
    "equiparássemos": "equiparar",
    "equiparávamo": "equiparar",
    "equiparávamos": "equiparar",
    "equiparávei": "equiparar",
    "equiparáveis": "equiparável",
    "equiparão": "equipar",
    "equiparíamos": "equipar",
    "equiparíeis": "equipar",
    "equipas": "equipar",
    "equipasse": "equipar",
    "equipassem": "equipar",
    "equipasses": "equipar",
    "equipaste": "equipar",
    "equipastes": "equipar",
    "equipava": "equipar",
    "equipavam": "equipar",
    "equipavas": "equipar",
    "equipe": "equipar",
    "equipei": "equipar",
    "equipeis": "equipar",
    "equipem": "equipar",
    "equipemo": "equipar",
    "equipemos": "equipar",
    "equipendentes": "equipendente",
    "equipendências": "equipendência",
    "equipes": "equipar",
    "equipo": "equipar",
    "equipolentes": "equipolente",
    "equipolências": "equipolência",
    "equipondera": "equiponderar",
    "equiponderada": "equiponderar",
    "equiponderadas": "equiponderar",
    "equiponderado": "equiponderar",
    "equiponderados": "equiponderar",
    "equiponderai": "equiponderar",
    "equiponderais": "equiponderar",
    "equiponderam": "equiponderar",
    "equiponderamo": "equiponderar",
    "equiponderamos": "equiponderar",
    "equiponderando": "equiponderar",
    "equiponderantes": "equiponderante",
    "equiponderara": "equiponderar",
    "equiponderaram": "equiponderar",
    "equiponderaras": "equiponderar",
    "equiponderarde": "equiponderar",
    "equiponderardes": "equiponderar",
    "equiponderare": "equiponderar",
    "equiponderarei": "equiponderar",
    "equiponderareis": "equiponderar",
    "equiponderarem": "equiponderar",
    "equiponderaremos": "equiponderar",
    "equiponderares": "equiponderar",
    "equiponderaria": "equiponderar",
    "equiponderariam": "equiponderar",
    "equiponderarias": "equiponderar",
    "equiponderarmo": "equiponderar",
    "equiponderarmos": "equiponderar",
    "equiponderará": "equiponderar",
    "equiponderarás": "equiponderar",
    "equiponderarão": "equiponderar",
    "equiponderaríamos": "equiponderar",
    "equiponderaríeis": "equiponderar",
    "equiponderas": "equiponderar",
    "equiponderasse": "equiponderar",
    "equiponderassem": "equiponderar",
    "equiponderasses": "equiponderar",
    "equiponderaste": "equiponderar",
    "equiponderastes": "equiponderar",
    "equiponderava": "equiponderar",
    "equiponderavam": "equiponderar",
    "equiponderavas": "equiponderar",
    "equipondere": "equiponderar",
    "equiponderei": "equiponderar",
    "equipondereis": "equiponderar",
    "equiponderem": "equiponderar",
    "equiponderemo": "equiponderar",
    "equiponderemos": "equiponderar",
    "equiponderes": "equiponderar",
    "equipondero": "equiponderar",
    "equiponderou": "equiponderar",
    "equiponderá": "equiponderar",
    "equiponderámo": "equiponderar",
    "equiponderámos": "equiponderar",
    "equiponderáramo": "equiponderar",
    "equiponderáramos": "equiponderar",
    "equiponderárei": "equiponderar",
    "equiponderáreis": "equiponderar",
    "equiponderásseis": "equiponderar",
    "equiponderássemos": "equiponderar",
    "equiponderávamo": "equiponderar",
    "equiponderávamos": "equiponderar",
    "equiponderávei": "equiponderar",
    "equiponderáveis": "equiponderar",
    "equiponderâncias": "equiponderância",
    "equipotenciais": "equipotencial",
    "equipou": "equipar",
    "equiprobabilismos": "equiprobabilismo",
    "equiprováveis": "equiprovável",
    "equipá": "equipar",
    "equipámo": "equipar",
    "equipámos": "equipar",
    "equipáramo": "equipar",
    "equipáramos": "equipar",
    "equipárei": "equipar",
    "equipáreis": "equipar",
    "equipásseis": "equipar",
    "equipássemos": "equipar",
    "equipávamo": "equipar",
    "equipávamos": "equipar",
    "equipávei": "equipar",
    "equipáveis": "equipar",
    "equipétala": "equipétalo",
    "equipétalas": "equipétalo",
    "equipétalos": "equipétalo",
    "equissetácea": "equissetáceo",
    "equissetáceas": "equissetáceo",
    "equissetáceos": "equissetáceo",
    "equissetínea": "equissetíneo",
    "equissetíneas": "equissetíneo",
    "equissetíneos": "equissetíneo",
    "equissonantes": "equissonante",
    "equissonâncias": "equissonância",
    "equitadora": "equitador",
    "equitadoras": "equitador",
    "equitadores": "equitador",
    "equitativa": "equitativo",
    "equitativas": "equitativo",
    "equitativos": "equitativo",
    "equitações": "equitação",
    "equivala": "equivaler",
    "equivalais": "equivaler",
    "equivalam": "equivaler",
    "equivalamo": "equivaler",
    "equivalamos": "equivaler",
    "equivalas": "equivaler",
    "equivale": "equivaler",
    "equivalei": "equivaler",
    "equivaleis": "equivaler",
    "equivalem": "equivaler",
    "equivalemo": "equivaler",
    "equivalemos": "equivaler",
    "equivalendo": "equivaler",
    "equivalentes": "equivalente",
    "equivalera": "equivaler",
    "equivaleram": "equivaler",
    "equivaleras": "equivaler",
    "equivalerdes": "equivaler",
    "equivalerei": "equivaler",
    "equivalereis": "equivaler",
    "equivalerem": "equivaler",
    "equivaleremos": "equivaler",
    "equivaleres": "equivaler",
    "equivaleria": "equivaler",
    "equivaleriam": "equivaler",
    "equivalerias": "equivaler",
    "equivalermo": "equivaler",
    "equivalermos": "equivaler",
    "equivalerá": "equivaler",
    "equivalerás": "equivaler",
    "equivalerão": "equivaler",
    "equivaleríamos": "equivaler",
    "equivaleríeis": "equivaler",
    "equivales": "equivaler",
    "equivalesse": "equivaler",
    "equivalessem": "equivaler",
    "equivalesses": "equivaler",
    "equivaleste": "equivaler",
    "equivalestes": "equivaler",
    "equivaleu": "equivaler",
    "equivali": "equivaler",
    "equivalia": "equivaler",
    "equivaliam": "equivaler",
    "equivalias": "equivaler",
    "equivalida": "equivaler",
    "equivalidas": "equivaler",
    "equivalido": "equivaler",
    "equivalidos": "equivaler",
    "equivalo": "equivaler",
    "equivalves": "equivalve",
    "equivalências": "equivalência",
    "equivalêramo": "equivaler",
    "equivalêramos": "equivaler",
    "equivalêreis": "equivaler",
    "equivalêsseis": "equivaler",
    "equivalêssemos": "equivaler",
    "equivalíamo": "equivaler",
    "equivalíamos": "equivaler",
    "equivalíeis": "equivaler",
    "equivoca": "equivocar",
    "equivocada": "equivocar",
    "equivocadas": "equivocar",
    "equivocado": "equivocar",
    "equivocados": "equivocar",
    "equivocai": "equivocar",
    "equivocais": "equivocar",
    "equivocam": "equivocar",
    "equivocamo": "equivocar",
    "equivocamos": "equivocar",
    "equivocando": "equivocar",
    "equivocara": "equivocar",
    "equivocaram": "equivocar",
    "equivocaras": "equivocar",
    "equivocarde": "equivocar",
    "equivocardes": "equivocar",
    "equivocare": "equivocar",
    "equivocarei": "equivocar",
    "equivocareis": "equivocar",
    "equivocarem": "equivocar",
    "equivocaremos": "equivocar",
    "equivocares": "equivocar",
    "equivocaria": "equivocar",
    "equivocariam": "equivocar",
    "equivocarias": "equivocar",
    "equivocarmo": "equivocar",
    "equivocarmos": "equivocar",
    "equivocará": "equivocar",
    "equivocarás": "equivocar",
    "equivocarão": "equivocar",
    "equivocaríamos": "equivocar",
    "equivocaríeis": "equivocar",
    "equivocas": "equivocar",
    "equivocasse": "equivocar",
    "equivocassem": "equivocar",
    "equivocasses": "equivocar",
    "equivocaste": "equivocar",
    "equivocastes": "equivocar",
    "equivocava": "equivocar",
    "equivocavam": "equivocar",
    "equivocavas": "equivocar",
    "equivocações": "equivocação",
    "equivocidades": "equivocidade",
    "equivoco": "equivocar",
    "equivocou": "equivocar",
    "equivocá": "equivocar",
    "equivocámo": "equivocar",
    "equivocámos": "equivocar",
    "equivocáramo": "equivocar",
    "equivocáramos": "equivocar",
    "equivocárei": "equivocar",
    "equivocáreis": "equivocar",
    "equivocásseis": "equivocar",
    "equivocássemos": "equivocar",
    "equivocávamo": "equivocar",
    "equivocávamos": "equivocar",
    "equivocávei": "equivocar",
    "equivocáveis": "equivocar",
    "equivoque": "equivocar",
    "equivoquei": "equivocar",
    "equivoqueis": "equivocar",
    "equivoquem": "equivocar",
    "equivoquemo": "equivocar",
    "equivoquemos": "equivocar",
    "equivoques": "equivocar",
    "equivoquistas": "equivoquista",
    "equiângula": "equiângulo",
    "equiângulas": "equiângulo",
    "equiângulos": "equiângulo",
    "equáveis": "equável",
    "equânima": "equânimo",
    "equânimas": "equânimo",
    "equânimes": "equânime",
    "equânimos": "equânimo",
    "equícolas": "equícola",
    "equídeos": "equídeo",
    "equídia": "equídio",
    "equídias": "equídio",
    "equídios": "equídio",
    "equífera": "equífero",
    "equíferas": "equífero",
    "equíferos": "equífero",
    "equínidas": "equínida",
    "equípedes": "equípede",
    "equívoca": "equívoco",
    "equívocas": "equívoco",
    "equívocos": "equívoco",
    "equórea": "equóreo",
    "equóreas": "equóreo",
    "equóreos": "equóreo",
    "era": "ser",
    "eram": "ser",
    "eras": "ser",
    "erasmiana": "erasmiano",
    "erasmianas": "erasmiano",
    "erasmianos": "erasmiano",
    "erebos": "erebo",
    "erecta": "erecto",
    "erectas": "erecto",
    "erectilidades": "erectilidade",
    "erectora": "erector",
    "erectoras": "erector",
    "erectores": "erector",
    "erectos": "erecto",
    "erecções": "erecção",
    "eremitas": "eremita",
    "eremítica": "eremítico",
    "eremíticas": "eremítico",
    "eremíticos": "eremítico",
    "erepsinas": "erepsina",
    "eretismais": "eretismal",
    "eretismoa": "eretismo",
    "eretismoas": "eretismo",
    "eretismoes": "eretismo",
    "ereutofobias": "ereutofobia",
    "ereutófoba": "ereutófobo",
    "ereutófobas": "ereutófobo",
    "ereutófobos": "ereutófobo",
    "erga": "erguer",
    "ergais": "erguer",
    "ergam": "erguer",
    "ergamo": "erguer",
    "ergamos": "erguer",
    "ergas": "erguer",
    "ergastenias": "ergastenia",
    "ergastoplasmas": "ergastoplasma",
    "ergastoplasmática": "ergastoplasmático",
    "ergastoplasmáticas": "ergastoplasmático",
    "ergastoplasmáticos": "ergastoplasmático",
    "ergastulária": "ergastulário",
    "ergastulárias": "ergastulário",
    "ergastulários": "ergastulário",
    "ergasténica": "ergasténico",
    "ergasténicas": "ergasténico",
    "ergasténicos": "ergasténico",
    "ergo": "erguer",
    "ergofobias": "ergofobia",
    "ergografias": "ergografia",
    "ergográfica": "ergográfico",
    "ergográficas": "ergográfico",
    "ergográficos": "ergográfico",
    "ergologias": "ergologia",
    "ergologistas": "ergologista",
    "ergológica": "ergológico",
    "ergológicas": "ergológico",
    "ergológicos": "ergológico",
    "ergometrias": "ergometria",
    "ergométrica": "ergométrico",
    "ergométricas": "ergométrico",
    "ergométricos": "ergométrico",
    "ergonomias": "ergonomia",
    "ergonómica": "ergonómico",
    "ergonómicas": "ergonómico",
    "ergonómicos": "ergonómico",
    "ergos": "ergo",
    "ergoterapeutas": "ergoterapeuta",
    "ergoterapias": "ergoterapia",
    "ergoterapêutica": "ergoterapêutico",
    "ergoterapêuticas": "ergoterapêutico",
    "ergoterapêuticos": "ergoterapêutico",
    "ergoterápica": "ergoterápico",
    "ergoterápicas": "ergoterápico",
    "ergoterápicos": "ergoterápico",
    "ergotinas": "ergotina",
    "ergotinos": "ergotino",
    "ergotismos": "ergotismo",
    "ergs": "erg",
    "ergue": "erguer",
    "erguei": "erguer",
    "ergueis": "erguer",
    "erguem": "erguer",
    "erguemo": "erguer",
    "erguemos": "erguer",
    "erguendo": "erguer",
    "erguera": "erguer",
    "ergueram": "erguer",
    "ergueras": "erguer",
    "erguerde": "erguer",
    "erguerdes": "erguer",
    "erguere": "erguer",
    "erguerei": "erguer",
    "erguereis": "erguer",
    "erguerem": "erguer",
    "ergueremos": "erguer",
    "ergueres": "erguer",
    "ergueria": "erguer",
    "ergueriam": "erguer",
    "erguerias": "erguer",
    "erguermo": "erguer",
    "erguermos": "erguer",
    "erguerá": "erguer",
    "erguerás": "erguer",
    "erguerão": "erguer",
    "ergueríamos": "erguer",
    "ergueríeis": "erguer",
    "ergues": "erguer",
    "erguesse": "erguer",
    "erguessem": "erguer",
    "erguesses": "erguer",
    "ergueste": "erguer",
    "erguestes": "erguer",
    "ergueu": "erguer",
    "ergui": "erguer",
    "erguia": "erguer",
    "erguiam": "erguer",
    "erguias": "erguer",
    "erguida": "erguido",
    "erguidas": "erguido",
    "erguido": "erguer",
    "erguidos": "erguido",
    "erguê": "erguer",
    "erguêramo": "erguer",
    "erguêramos": "erguer",
    "erguêrei": "erguer",
    "erguêreis": "erguer",
    "erguêsseis": "erguer",
    "erguêssemos": "erguer",
    "erguíamo": "erguer",
    "erguíamos": "erguer",
    "erguíei": "erguer",
    "erguíeis": "erguer",
    "ergástulos": "ergástulo",
    "ergófoba": "ergófobo",
    "ergófobas": "ergófobo",
    "ergófobos": "ergófobo",
    "ergógrafos": "ergógrafo",
    "ergómetros": "ergómetro",
    "erice": "eriçar",
    "ericei": "eriçar",
    "ericeis": "eriçar",
    "ericem": "eriçar",
    "ericemo": "eriçar",
    "ericemos": "eriçar",
    "erices": "erice",
    "ericácea": "ericáceo",
    "ericáceas": "ericáceo",
    "ericáceos": "ericáceo",
    "ericícolas": "ericícola",
    "ericófila": "ericófilo",
    "ericófilas": "ericófilo",
    "ericófilos": "ericófilo",
    "erige": "erigir",
    "erigem": "erigir",
    "eriges": "erigir",
    "erigi": "erigir",
    "erigia": "erigir",
    "erigiam": "erigir",
    "erigias": "erigir",
    "erigida": "erigir",
    "erigidas": "erigir",
    "erigido": "erigir",
    "erigidos": "erigir",
    "erigimo": "erigir",
    "erigimos": "erigir",
    "erigindo": "erigir",
    "erigira": "erigir",
    "erigiram": "erigir",
    "erigiras": "erigir",
    "erigirde": "erigir",
    "erigirdes": "erigir",
    "erigire": "erigir",
    "erigirei": "erigir",
    "erigireis": "erigir",
    "erigirem": "erigir",
    "erigiremos": "erigir",
    "erigires": "erigir",
    "erigiria": "erigir",
    "erigiriam": "erigir",
    "erigirias": "erigir",
    "erigirmo": "erigir",
    "erigirmos": "erigir",
    "erigirá": "erigir",
    "erigirás": "erigir",
    "erigirão": "erigir",
    "erigiríamos": "erigir",
    "erigiríeis": "erigir",
    "erigis": "erigir",
    "erigisse": "erigir",
    "erigissem": "erigir",
    "erigisses": "erigir",
    "erigiste": "erigir",
    "erigistes": "erigir",
    "erigiu": "erigir",
    "erigíamo": "erigir",
    "erigíamos": "erigir",
    "erigíei": "erigir",
    "erigíeis": "erigir",
    "erigíramo": "erigir",
    "erigíramos": "erigir",
    "erigírei": "erigir",
    "erigíreis": "erigir",
    "erigísseis": "erigir",
    "erigíssemos": "erigir",
    "erija": "erigir",
    "erijais": "erigir",
    "erijam": "erigir",
    "erijamo": "erigir",
    "erijamos": "erigir",
    "erijas": "erigir",
    "erijo": "erigir",
    "erinacídea": "erinacídeo",
    "erinacídeas": "erinacídeo",
    "erinacídeos": "erinacídeo",
    "erinoses": "erinose",
    "erinácea": "erináceo",
    "erináceas": "erináceo",
    "erináceos": "erináceo",
    "eris": "eril",
    "erisipela": "erisipelar",
    "erisipelada": "erisipelar",
    "erisipeladas": "erisipelar",
    "erisipelado": "erisipelar",
    "erisipelados": "erisipelar",
    "erisipelai": "erisipelar",
    "erisipelais": "erisipelar",
    "erisipelam": "erisipelar",
    "erisipelamo": "erisipelar",
    "erisipelamos": "erisipelar",
    "erisipelando": "erisipelar",
    "erisipelara": "erisipelar",
    "erisipelaram": "erisipelar",
    "erisipelaras": "erisipelar",
    "erisipelardes": "erisipelar",
    "erisipelarei": "erisipelar",
    "erisipelareis": "erisipelar",
    "erisipelarem": "erisipelar",
    "erisipelaremos": "erisipelar",
    "erisipelares": "erisipelar",
    "erisipelaria": "erisipelar",
    "erisipelariam": "erisipelar",
    "erisipelarias": "erisipelar",
    "erisipelarmo": "erisipelar",
    "erisipelarmos": "erisipelar",
    "erisipelará": "erisipelar",
    "erisipelarás": "erisipelar",
    "erisipelarão": "erisipelar",
    "erisipelaríamos": "erisipelar",
    "erisipelaríeis": "erisipelar",
    "erisipelas": "erisipelar",
    "erisipelasse": "erisipelar",
    "erisipelassem": "erisipelar",
    "erisipelasses": "erisipelar",
    "erisipelaste": "erisipelar",
    "erisipelastes": "erisipelar",
    "erisipelatosa": "erisipelatoso",
    "erisipelatosas": "erisipelatoso",
    "erisipelatosos": "erisipelatoso",
    "erisipelava": "erisipelar",
    "erisipelavam": "erisipelar",
    "erisipelavas": "erisipelar",
    "erisipele": "erisipelar",
    "erisipelei": "erisipelar",
    "erisipeleis": "erisipelar",
    "erisipelem": "erisipelar",
    "erisipelemo": "erisipelar",
    "erisipelemos": "erisipelar",
    "erisipeles": "erisipelar",
    "erisipelo": "erisipelar",
    "erisipelosa": "erisipeloso",
    "erisipelosas": "erisipeloso",
    "erisipelosos": "erisipeloso",
    "erisipelou": "erisipelar",
    "erisipelámo": "erisipelar",
    "erisipelámos": "erisipelar",
    "erisipeláramo": "erisipelar",
    "erisipeláramos": "erisipelar",
    "erisipeláreis": "erisipelar",
    "erisipelásseis": "erisipelar",
    "erisipelássemos": "erisipelar",
    "erisipelávamo": "erisipelar",
    "erisipelávamos": "erisipelar",
    "erisipeláveis": "erisipelar",
    "erisipelões": "erisipelão",
    "eritemas": "eritema",
    "eritematosa": "eritematoso",
    "eritematosas": "eritematoso",
    "eritematosos": "eritematoso",
    "eritemática": "eritemático",
    "eritemáticas": "eritemático",
    "eritemáticos": "eritemático",
    "eritemóides": "eritemóide",
    "eritremias": "eritremia",
    "eritrinas": "eritrina",
    "eritroblastos": "eritroblasto",
    "eritroblástica": "eritroblástico",
    "eritroblásticas": "eritroblástico",
    "eritroblásticos": "eritroblástico",
    "eritrocarpa": "eritrocarpo",
    "eritrocarpas": "eritrocarpo",
    "eritrocarpos": "eritrocarpo",
    "eritrocárpica": "eritrocárpico",
    "eritrocárpicas": "eritrocárpico",
    "eritrocárpicos": "eritrocárpico",
    "eritroderma": "eritrodermo",
    "eritrodermas": "eritrodermo",
    "eritrodermias": "eritrodermia",
    "eritrodermos": "eritrodermo",
    "eritrodáctila": "eritrodáctilo",
    "eritrodáctilas": "eritrodáctilo",
    "eritrodáctilos": "eritrodáctilo",
    "eritrodérmica": "eritrodérmico",
    "eritrodérmicas": "eritrodérmico",
    "eritrodérmicos": "eritrodérmico",
    "eritrofila": "eritrofilo",
    "eritrofilas": "eritrofilo",
    "eritrofilos": "eritrofilo",
    "eritrofobias": "eritrofobia",
    "eritrogástrea": "eritrogástreo",
    "eritrogástreas": "eritrogástreo",
    "eritrogástreos": "eritrogástreo",
    "eritrogástrica": "eritrogástrico",
    "eritrogástricas": "eritrogástrico",
    "eritrogástricos": "eritrogástrico",
    "eritromicinas": "eritromicina",
    "eritropsias": "eritropsia",
    "eritroses": "eritrose",
    "eritrosperma": "eritrospermo",
    "eritrospermas": "eritrospermo",
    "eritrospermos": "eritrospermo",
    "eritroxilácea": "eritroxiláceo",
    "eritroxiláceas": "eritroxiláceo",
    "eritroxiláceos": "eritroxiláceo",
    "eritrémica": "eritrémico",
    "eritrémicas": "eritrémico",
    "eritrémicos": "eritrémico",
    "eritrócera": "eritrócero",
    "eritróceras": "eritrócero",
    "eritróceros": "eritrócero",
    "eritrócitos": "eritrócito",
    "eritrófoba": "eritrófobo",
    "eritrófobas": "eritrófobo",
    "eritrófobos": "eritrófobo",
    "eritróides": "eritróide",
    "eritrópodes": "eritrópode",
    "eritróptera": "eritróptero",
    "eritrópteras": "eritróptero",
    "eritrópteros": "eritróptero",
    "eritróptica": "eritróptico",
    "eritrópticas": "eritróptico",
    "eritrópticos": "eritróptico",
    "eritróraces": "eritrórace",
    "eritróstoma": "eritróstomo",
    "eritróstomas": "eritróstomo",
    "eritróstomos": "eritróstomo",
    "eritróxila": "eritróxilo",
    "eritróxilas": "eritróxilo",
    "eritróxilos": "eritróxilo",
    "eriça": "eriçar",
    "eriçada": "eriçar",
    "eriçadas": "eriçar",
    "eriçado": "eriçar",
    "eriçados": "eriçar",
    "eriçadíssima": "eriçado",
    "eriçadíssimas": "eriçado",
    "eriçadíssimo": "eriçado",
    "eriçadíssimos": "eriçado",
    "eriçai": "eriçar",
    "eriçais": "eriçar",
    "eriçam": "eriçar",
    "eriçamentos": "eriçamento",
    "eriçamo": "eriçar",
    "eriçamos": "eriçar",
    "eriçando": "eriçar",
    "eriçara": "eriçar",
    "eriçaram": "eriçar",
    "eriçaras": "eriçar",
    "eriçarde": "eriçar",
    "eriçardes": "eriçar",
    "eriçare": "eriçar",
    "eriçarei": "eriçar",
    "eriçareis": "eriçar",
    "eriçarem": "eriçar",
    "eriçaremos": "eriçar",
    "eriçares": "eriçar",
    "eriçaria": "eriçar",
    "eriçariam": "eriçar",
    "eriçarias": "eriçar",
    "eriçarmo": "eriçar",
    "eriçarmos": "eriçar",
    "eriçará": "eriçar",
    "eriçarás": "eriçar",
    "eriçarão": "eriçar",
    "eriçaríamos": "eriçar",
    "eriçaríeis": "eriçar",
    "eriças": "eriçar",
    "eriçasse": "eriçar",
    "eriçassem": "eriçar",
    "eriçasses": "eriçar",
    "eriçaste": "eriçar",
    "eriçastes": "eriçar",
    "eriçava": "eriçar",
    "eriçavam": "eriçar",
    "eriçavas": "eriçar",
    "eriço": "eriçar",
    "eriçou": "eriçar",
    "eriçá": "eriçar",
    "eriçámo": "eriçar",
    "eriçámos": "eriçar",
    "eriçáramo": "eriçar",
    "eriçáramos": "eriçar",
    "eriçárei": "eriçar",
    "eriçáreis": "eriçar",
    "eriçásseis": "eriçar",
    "eriçássemos": "eriçar",
    "eriçávamo": "eriçar",
    "eriçávamos": "eriçar",
    "eriçávei": "eriçar",
    "eriçáveis": "eriçar",
    "eriócoma": "eriócomo",
    "eriócomas": "eriócomo",
    "eriócomos": "eriócomo",
    "eriófila": "eriófilo",
    "eriófilas": "eriófilo",
    "eriófilos": "eriófilo",
    "erma": "ermo",
    "ermada": "ermar",
    "ermadas": "ermar",
    "ermado": "ermar",
    "ermados": "ermar",
    "ermai": "ermar",
    "ermais": "ermar",
    "ermam": "ermar",
    "ermamentos": "ermamento",
    "ermamo": "ermar",
    "ermamos": "ermar",
    "ermando": "ermar",
    "ermara": "ermar",
    "ermaram": "ermar",
    "ermaras": "ermar",
    "ermarde": "ermar",
    "ermardes": "ermar",
    "ermare": "ermar",
    "ermarei": "ermar",
    "ermareis": "ermar",
    "ermarem": "ermar",
    "ermaremos": "ermar",
    "ermares": "ermar",
    "ermaria": "ermar",
    "ermariam": "ermar",
    "ermarias": "ermar",
    "ermarmo": "ermar",
    "ermarmos": "ermar",
    "ermará": "ermar",
    "ermarás": "ermar",
    "ermarão": "ermar",
    "ermaríamos": "ermar",
    "ermaríeis": "ermar",
    "ermas": "ermo",
    "ermasse": "ermar",
    "ermassem": "ermar",
    "ermasses": "ermar",
    "ermaste": "ermar",
    "ermastes": "ermar",
    "ermava": "ermar",
    "ermavam": "ermar",
    "ermavas": "ermar",
    "erme": "ermar",
    "ermei": "ermar",
    "ermeis": "ermar",
    "ermem": "ermar",
    "ermemo": "ermar",
    "ermemos": "ermar",
    "ermes": "ermar",
    "ermidas": "ermida",
    "ermitagens": "ermitagem",
    "ermitanias": "ermitania",
    "ermitas": "ermita",
    "ermitoa": "ermitão",
    "ermitoas": "ermitão",
    "ermitã": "ermitão",
    "ermitãos": "ermitão",
    "ermitãs": "ermitão",
    "ermitérios": "ermitério",
    "ermitões": "ermitão",
    "ermo": "ermar",
    "ermos": "ermo",
    "ermou": "ermar",
    "ermá": "ermar",
    "ermámo": "ermar",
    "ermámos": "ermar",
    "ermáramo": "ermar",
    "ermáramos": "ermar",
    "ermárei": "ermar",
    "ermáreis": "ermar",
    "ermásseis": "ermar",
    "ermássemos": "ermar",
    "ermávamo": "ermar",
    "ermávamos": "ermar",
    "ermávei": "ermar",
    "ermáveis": "ermar",
    "erodentes": "erodente",
    "erosiva": "erosivo",
    "erosivas": "erosivo",
    "erosivos": "erosivo",
    "erosões": "erosão",
    "erotemática": "erotemático",
    "erotemáticas": "erotemático",
    "erotemáticos": "erotemático",
    "erotismos": "erotismo",
    "erotiza": "erotizar",
    "erotizada": "erotizar",
    "erotizadas": "erotizar",
    "erotizado": "erotizar",
    "erotizados": "erotizar",
    "erotizai": "erotizar",
    "erotizais": "erotizar",
    "erotizam": "erotizar",
    "erotizamo": "erotizar",
    "erotizamos": "erotizar",
    "erotizando": "erotizar",
    "erotizara": "erotizar",
    "erotizaram": "erotizar",
    "erotizaras": "erotizar",
    "erotizarde": "erotizar",
    "erotizardes": "erotizar",
    "erotizare": "erotizar",
    "erotizarei": "erotizar",
    "erotizareis": "erotizar",
    "erotizarem": "erotizar",
    "erotizaremos": "erotizar",
    "erotizares": "erotizar",
    "erotizaria": "erotizar",
    "erotizariam": "erotizar",
    "erotizarias": "erotizar",
    "erotizarmo": "erotizar",
    "erotizarmos": "erotizar",
    "erotizará": "erotizar",
    "erotizarás": "erotizar",
    "erotizarão": "erotizar",
    "erotizaríamos": "erotizar",
    "erotizaríeis": "erotizar",
    "erotizas": "erotizar",
    "erotizasse": "erotizar",
    "erotizassem": "erotizar",
    "erotizasses": "erotizar",
    "erotizaste": "erotizar",
    "erotizastes": "erotizar",
    "erotizava": "erotizar",
    "erotizavam": "erotizar",
    "erotizavas": "erotizar",
    "erotizações": "erotização",
    "erotize": "erotizar",
    "erotizei": "erotizar",
    "erotizeis": "erotizar",
    "erotizem": "erotizar",
    "erotizemo": "erotizar",
    "erotizemos": "erotizar",
    "erotizes": "erotizar",
    "erotizo": "erotizar",
    "erotizou": "erotizar",
    "erotizá": "erotizar",
    "erotizámo": "erotizar",
    "erotizámos": "erotizar",
    "erotizáramo": "erotizar",
    "erotizáramos": "erotizar",
    "erotizárei": "erotizar",
    "erotizáreis": "erotizar",
    "erotizásseis": "erotizar",
    "erotizássemos": "erotizar",
    "erotizávamo": "erotizar",
    "erotizávamos": "erotizar",
    "erotizávei": "erotizar",
    "erotizáveis": "erotizar",
    "erotomanias": "erotomania",
    "erotomaníaca": "erotomaníaco",
    "erotomaníacas": "erotomaníaco",
    "erotomaníacos": "erotomaníaco",
    "erotómana": "erotómano",
    "erotómanas": "erotómano",
    "erotómanos": "erotómano",
    "erra": "errar",
    "errabunda": "errabundo",
    "errabundas": "errabundo",
    "errabundos": "errabundo",
    "errada": "errar",
    "erradas": "errar",
    "erradia": "erradio",
    "erradias": "erradio",
    "erradica": "erradicar",
    "erradicada": "erradicar",
    "erradicadas": "erradicar",
    "erradicado": "erradicar",
    "erradicados": "erradicar",
    "erradicai": "erradicar",
    "erradicais": "erradicar",
    "erradicam": "erradicar",
    "erradicamo": "erradicar",
    "erradicamos": "erradicar",
    "erradicando": "erradicar",
    "erradicara": "erradicar",
    "erradicaram": "erradicar",
    "erradicaras": "erradicar",
    "erradicarde": "erradicar",
    "erradicardes": "erradicar",
    "erradicare": "erradicar",
    "erradicarei": "erradicar",
    "erradicareis": "erradicar",
    "erradicarem": "erradicar",
    "erradicaremos": "erradicar",
    "erradicares": "erradicar",
    "erradicaria": "erradicar",
    "erradicariam": "erradicar",
    "erradicarias": "erradicar",
    "erradicarmo": "erradicar",
    "erradicarmos": "erradicar",
    "erradicará": "erradicar",
    "erradicarás": "erradicar",
    "erradicarão": "erradicar",
    "erradicaríamos": "erradicar",
    "erradicaríeis": "erradicar",
    "erradicas": "erradicar",
    "erradicasse": "erradicar",
    "erradicassem": "erradicar",
    "erradicasses": "erradicar",
    "erradicaste": "erradicar",
    "erradicastes": "erradicar",
    "erradicativa": "erradicativo",
    "erradicativas": "erradicativo",
    "erradicativos": "erradicativo",
    "erradicava": "erradicar",
    "erradicavam": "erradicar",
    "erradicavas": "erradicar",
    "erradicações": "erradicação",
    "erradico": "erradicar",
    "erradicou": "erradicar",
    "erradicá": "erradicar",
    "erradicámo": "erradicar",
    "erradicámos": "erradicar",
    "erradicáramo": "erradicar",
    "erradicáramos": "erradicar",
    "erradicárei": "erradicar",
    "erradicáreis": "erradicar",
    "erradicásseis": "erradicar",
    "erradicássemos": "erradicar",
    "erradicávamo": "erradicar",
    "erradicávamos": "erradicar",
    "erradicávei": "erradicar",
    "erradicáveis": "erradicar",
    "erradios": "erradio",
    "erradique": "erradicar",
    "erradiquei": "erradicar",
    "erradiqueis": "erradicar",
    "erradiquem": "erradicar",
    "erradiquemo": "erradicar",
    "erradiquemos": "erradicar",
    "erradiques": "erradicar",
    "errado": "errar",
    "errados": "errar",
    "errai": "errar",
    "errais": "errar",
    "erram": "errar",
    "erramo": "errar",
    "erramos": "errar",
    "errando": "errar",
    "errantes": "errante",
    "errara": "errar",
    "erraram": "errar",
    "erraras": "errar",
    "errarde": "errar",
    "errardes": "errar",
    "errare": "errar",
    "errarei": "errar",
    "errareis": "errar",
    "errarem": "errar",
    "erraremos": "errar",
    "errares": "errar",
    "erraria": "errar",
    "errariam": "errar",
    "errarias": "errar",
    "errarmo": "errar",
    "errarmos": "errar",
    "errará": "errar",
    "errarás": "errar",
    "errarão": "errar",
    "erraríamos": "errar",
    "erraríeis": "errar",
    "erras": "errar",
    "errasse": "errar",
    "errassem": "errar",
    "errasses": "errar",
    "erraste": "errar",
    "errastes": "errar",
    "erratas": "errata",
    "erratibilidades": "erratibilidade",
    "errava": "errar",
    "erravam": "errar",
    "erravas": "errar",
    "erre": "errar",
    "errei": "errar",
    "erreira": "erreiro",
    "erreiras": "erreiro",
    "erreiros": "erreiro",
    "erreis": "errar",
    "errem": "errar",
    "erremo": "errar",
    "erremos": "errar",
    "erres": "erre",
    "errina": "errino",
    "errinas": "errino",
    "errinos": "errino",
    "erro": "errar",
    "erronias": "erronia",
    "errores": "error",
    "erros": "erro",
    "errou": "errar",
    "errozinho": "erro",
    "errozinhos": "erro",
    "errozito": "erro",
    "errozitos": "erro",
    "errá": "errar",
    "errámo": "errar",
    "errámos": "errar",
    "erráramo": "errar",
    "erráramos": "errar",
    "errárei": "errar",
    "erráreis": "errar",
    "errásseis": "errar",
    "errássemos": "errar",
    "errática": "errático",
    "erráticas": "errático",
    "erráticos": "errático",
    "errávamo": "errar",
    "errávamos": "errar",
    "errávei": "errar",
    "erráveis": "errar",
    "errónea": "erróneo",
    "erróneas": "erróneo",
    "erróneos": "erróneo",
    "erses": "erse",
    "erubesce": "erubescer",
    "erubescei": "erubescer",
    "erubesceis": "erubescer",
    "erubescem": "erubescer",
    "erubescemo": "erubescer",
    "erubescemos": "erubescer",
    "erubescendo": "erubescer",
    "erubescera": "erubescer",
    "erubesceram": "erubescer",
    "erubesceras": "erubescer",
    "erubescerde": "erubescer",
    "erubescerdes": "erubescer",
    "erubescere": "erubescer",
    "erubescerei": "erubescer",
    "erubescereis": "erubescer",
    "erubescerem": "erubescer",
    "erubesceremos": "erubescer",
    "erubesceres": "erubescer",
    "erubesceria": "erubescer",
    "erubesceriam": "erubescer",
    "erubescerias": "erubescer",
    "erubescermo": "erubescer",
    "erubescermos": "erubescer",
    "erubescerá": "erubescer",
    "erubescerás": "erubescer",
    "erubescerão": "erubescer",
    "erubesceríamos": "erubescer",
    "erubesceríeis": "erubescer",
    "erubesces": "erubescer",
    "erubescesse": "erubescer",
    "erubescessem": "erubescer",
    "erubescesses": "erubescer",
    "erubesceste": "erubescer",
    "erubescestes": "erubescer",
    "erubesceu": "erubescer",
    "erubesci": "erubescer",
    "erubescia": "erubescer",
    "erubesciam": "erubescer",
    "erubescias": "erubescer",
    "erubescida": "erubescido",
    "erubescidas": "erubescido",
    "erubescido": "erubescer",
    "erubescidos": "erubescido",
    "erubescê": "erubescer",
    "erubescências": "erubescência",
    "erubescêramo": "erubescer",
    "erubescêramos": "erubescer",
    "erubescêrei": "erubescer",
    "erubescêreis": "erubescer",
    "erubescêsseis": "erubescer",
    "erubescêssemos": "erubescer",
    "erubescíamo": "erubescer",
    "erubescíamos": "erubescer",
    "erubescíei": "erubescer",
    "erubescíeis": "erubescer",
    "erubesça": "erubescer",
    "erubesçais": "erubescer",
    "erubesçam": "erubescer",
    "erubesçamo": "erubescer",
    "erubesçamos": "erubescer",
    "erubesças": "erubescer",
    "erubesço": "erubescer",
    "erucas": "eruca",
    "eruciformes": "eruciforme",
    "eructa": "eructar",
    "eructada": "eructar",
    "eructadas": "eructar",
    "eructado": "eructar",
    "eructados": "eructar",
    "eructai": "eructar",
    "eructais": "eructar",
    "eructam": "eructar",
    "eructamo": "eructar",
    "eructamos": "eructar",
    "eructando": "eructar",
    "eructara": "eructar",
    "eructaram": "eructar",
    "eructaras": "eructar",
    "eructardes": "eructar",
    "eructarei": "eructar",
    "eructareis": "eructar",
    "eructarem": "eructar",
    "eructaremos": "eructar",
    "eructares": "eructar",
    "eructaria": "eructar",
    "eructariam": "eructar",
    "eructarias": "eructar",
    "eructarmo": "eructar",
    "eructarmos": "eructar",
    "eructará": "eructar",
    "eructarás": "eructar",
    "eructarão": "eructar",
    "eructaríamos": "eructar",
    "eructaríeis": "eructar",
    "eructas": "eructar",
    "eructasse": "eructar",
    "eructassem": "eructar",
    "eructasses": "eructar",
    "eructaste": "eructar",
    "eructastes": "eructar",
    "eructava": "eructar",
    "eructavam": "eructar",
    "eructavas": "eructar",
    "eructações": "eructação",
    "eructe": "eructar",
    "eructei": "eructar",
    "eructeis": "eructar",
    "eructem": "eructar",
    "eructemo": "eructar",
    "eructemos": "eructar",
    "eructes": "eructar",
    "eructo": "eructar",
    "eructou": "eructar",
    "eructámo": "eructar",
    "eructámos": "eructar",
    "eructáramo": "eructar",
    "eructáramos": "eructar",
    "eructáreis": "eructar",
    "eructásseis": "eructar",
    "eructássemos": "eructar",
    "eructávamo": "eructar",
    "eructávamos": "eructar",
    "eructáveis": "eructar",
    "erudescentes": "erudescente",
    "erudita": "erudito",
    "eruditas": "erudito",
    "eruditismos": "eruditismo",
    "eruditos": "erudito",
    "erudições": "erudição",
    "erugenosa": "erugenoso",
    "erugenosas": "erugenoso",
    "erugenosos": "erugenoso",
    "eruptiva": "eruptivo",
    "eruptivas": "eruptivo",
    "eruptivos": "eruptivo",
    "erupções": "erupção",
    "ervada": "ervado",
    "ervadas": "ervado",
    "ervados": "ervado",
    "ervagens": "ervagem",
    "ervais": "erval",
    "ervanarias": "ervanaria",
    "ervanária": "ervanário",
    "ervanárias": "ervanário",
    "ervanários": "ervanário",
    "ervançais": "ervançal",
    "ervanços": "ervanço",
    "ervas": "erva",
    "ervascais": "ervascal",
    "ervascos": "ervasco",
    "ervatões": "ervatão",
    "ervaçais": "ervaçal",
    "ervece": "ervecer",
    "ervecei": "ervecer",
    "erveceis": "ervecer",
    "ervecem": "ervecer",
    "ervecemo": "ervecer",
    "ervecemos": "ervecer",
    "ervecendo": "ervecer",
    "ervecera": "ervecer",
    "erveceram": "ervecer",
    "erveceras": "ervecer",
    "ervecerdes": "ervecer",
    "ervecerei": "ervecer",
    "ervecereis": "ervecer",
    "ervecerem": "ervecer",
    "erveceremos": "ervecer",
    "erveceres": "ervecer",
    "erveceria": "ervecer",
    "erveceriam": "ervecer",
    "ervecerias": "ervecer",
    "ervecermo": "ervecer",
    "ervecermos": "ervecer",
    "ervecerá": "ervecer",
    "ervecerás": "ervecer",
    "ervecerão": "ervecer",
    "erveceríamos": "ervecer",
    "erveceríeis": "ervecer",
    "erveces": "ervecer",
    "ervecesse": "ervecer",
    "ervecessem": "ervecer",
    "ervecesses": "ervecer",
    "erveceste": "ervecer",
    "ervecestes": "ervecer",
    "erveceu": "ervecer",
    "erveci": "ervecer",
    "ervecia": "ervecer",
    "erveciam": "ervecer",
    "ervecias": "ervecer",
    "ervecida": "ervecer",
    "ervecidas": "ervecer",
    "ervecido": "ervecer",
    "ervecidos": "ervecer",
    "ervecêramo": "ervecer",
    "ervecêramos": "ervecer",
    "ervecêreis": "ervecer",
    "ervecêsseis": "ervecer",
    "ervecêssemos": "ervecer",
    "ervecíamo": "ervecer",
    "ervecíamos": "ervecer",
    "ervecíeis": "ervecer",
    "ervedais": "ervedal",
    "ervedeira": "ervedeiro",
    "ervedeiras": "ervedeiro",
    "ervedeiros": "ervedeiro",
    "ervedos": "ervedo",
    "erveira": "erveiro",
    "erveiras": "erveiro",
    "erveiros": "erveiro",
    "erveça": "ervecer",
    "erveçais": "ervecer",
    "erveçam": "ervecer",
    "erveçamo": "ervecer",
    "erveçamos": "ervecer",
    "erveças": "ervecer",
    "erveço": "ervecer",
    "ervicidas": "ervicida",
    "ervilha": "ervilhar",
    "ervilhacas": "ervilhaca",
    "ervilhada": "ervilhar",
    "ervilhadas": "ervilhar",
    "ervilhado": "ervilhar",
    "ervilhados": "ervilhar",
    "ervilhai": "ervilhar",
    "ervilhais": "ervilhar",
    "ervilham": "ervilhar",
    "ervilhames": "ervilhame",
    "ervilhamo": "ervilhar",
    "ervilhamos": "ervilhar",
    "ervilhando": "ervilhar",
    "ervilhara": "ervilhar",
    "ervilharam": "ervilhar",
    "ervilharas": "ervilhar",
    "ervilhardes": "ervilhar",
    "ervilharei": "ervilhar",
    "ervilhareis": "ervilhar",
    "ervilharem": "ervilhar",
    "ervilharemos": "ervilhar",
    "ervilhares": "ervilhar",
    "ervilharia": "ervilhar",
    "ervilhariam": "ervilhar",
    "ervilharias": "ervilhar",
    "ervilharmo": "ervilhar",
    "ervilharmos": "ervilhar",
    "ervilhará": "ervilhar",
    "ervilharás": "ervilhar",
    "ervilharão": "ervilhar",
    "ervilharíamos": "ervilhar",
    "ervilharíeis": "ervilhar",
    "ervilhas": "ervilhar",
    "ervilhasse": "ervilhar",
    "ervilhassem": "ervilhar",
    "ervilhasses": "ervilhar",
    "ervilhaste": "ervilhar",
    "ervilhastes": "ervilhar",
    "ervilhava": "ervilhar",
    "ervilhavam": "ervilhar",
    "ervilhavas": "ervilhar",
    "ervilhe": "ervilhar",
    "ervilhei": "ervilhar",
    "ervilheiras": "ervilheira",
    "ervilheis": "ervilhar",
    "ervilhem": "ervilhar",
    "ervilhemo": "ervilhar",
    "ervilhemos": "ervilhar",
    "ervilhes": "ervilhar",
    "ervilho": "ervilhar",
    "ervilhou": "ervilhar",
    "ervilhámo": "ervilhar",
    "ervilhámos": "ervilhar",
    "ervilháramo": "ervilhar",
    "ervilháramos": "ervilhar",
    "ervilháreis": "ervilhar",
    "ervilhásseis": "ervilhar",
    "ervilhássemos": "ervilhar",
    "ervilhávamo": "ervilhar",
    "ervilhávamos": "ervilhar",
    "ervilháveis": "ervilhar",
    "ervilhões": "ervilhão",
    "ervinha": "erva",
    "ervinhas": "erva",
    "ervita": "erva",
    "ervitas": "erva",
    "erviços": "erviço",
    "ervosa": "ervoso",
    "ervosas": "ervoso",
    "ervosos": "ervoso",
    "ervários": "ervário",
    "erácea": "eráceo",
    "eráceas": "eráceo",
    "eráceos": "eráceo",
    "erários": "erário",
    "erásmica": "erásmico",
    "erásmicas": "erásmico",
    "erásmicos": "erásmico",
    "erécteis": "eréctil",
    "erétrias": "erétria",
    "erícios": "erício",
    "erípedes": "erípede",
    "erísticas": "erística",
    "erótica": "erótico",
    "eróticas": "erótico",
    "eróticos": "erótico",
    "esbafora": "esbaforir",
    "esbaforais": "esbaforir",
    "esbaforam": "esbaforir",
    "esbaforamo": "esbaforir",
    "esbaforamos": "esbaforir",
    "esbaforas": "esbaforir",
    "esbafore": "esbaforir",
    "esbaforem": "esbaforir",
    "esbafores": "esbaforir",
    "esbafori": "esbaforir",
    "esbaforia": "esbaforir",
    "esbaforiam": "esbaforir",
    "esbaforias": "esbaforir",
    "esbaforida": "esbaforir",
    "esbaforidas": "esbaforir",
    "esbaforido": "esbaforir",
    "esbaforidos": "esbaforir",
    "esbaforimo": "esbaforir",
    "esbaforimos": "esbaforir",
    "esbaforindo": "esbaforir",
    "esbaforira": "esbaforir",
    "esbaforiram": "esbaforir",
    "esbaforiras": "esbaforir",
    "esbaforirdes": "esbaforir",
    "esbaforirei": "esbaforir",
    "esbaforireis": "esbaforir",
    "esbaforirem": "esbaforir",
    "esbaforiremos": "esbaforir",
    "esbaforires": "esbaforir",
    "esbaforiria": "esbaforir",
    "esbafoririam": "esbaforir",
    "esbaforirias": "esbaforir",
    "esbaforirmo": "esbaforir",
    "esbaforirmos": "esbaforir",
    "esbaforirá": "esbaforir",
    "esbaforirás": "esbaforir",
    "esbaforirão": "esbaforir",
    "esbaforiríamos": "esbaforir",
    "esbaforiríeis": "esbaforir",
    "esbaforis": "esbaforir",
    "esbaforisse": "esbaforir",
    "esbaforissem": "esbaforir",
    "esbaforisses": "esbaforir",
    "esbaforiste": "esbaforir",
    "esbaforistes": "esbaforir",
    "esbaforiu": "esbaforir",
    "esbaforo": "esbaforir",
    "esbaforíamo": "esbaforir",
    "esbaforíamos": "esbaforir",
    "esbaforíeis": "esbaforir",
    "esbaforíramo": "esbaforir",
    "esbaforíramos": "esbaforir",
    "esbaforíreis": "esbaforir",
    "esbaforísseis": "esbaforir",
    "esbaforíssemos": "esbaforir",
    "esbagace": "esbagaçar",
    "esbagacei": "esbagaçar",
    "esbagaceis": "esbagaçar",
    "esbagacem": "esbagaçar",
    "esbagacemo": "esbagaçar",
    "esbagacemos": "esbagaçar",
    "esbagaces": "esbagaçar",
    "esbaganha": "esbaganhar",
    "esbaganhada": "esbaganhar",
    "esbaganhadas": "esbaganhar",
    "esbaganhado": "esbaganhar",
    "esbaganhados": "esbaganhar",
    "esbaganhai": "esbaganhar",
    "esbaganhais": "esbaganhar",
    "esbaganham": "esbaganhar",
    "esbaganhamo": "esbaganhar",
    "esbaganhamos": "esbaganhar",
    "esbaganhando": "esbaganhar",
    "esbaganhara": "esbaganhar",
    "esbaganharam": "esbaganhar",
    "esbaganharas": "esbaganhar",
    "esbaganharde": "esbaganhar",
    "esbaganhardes": "esbaganhar",
    "esbaganhare": "esbaganhar",
    "esbaganharei": "esbaganhar",
    "esbaganhareis": "esbaganhar",
    "esbaganharem": "esbaganhar",
    "esbaganharemos": "esbaganhar",
    "esbaganhares": "esbaganhar",
    "esbaganharia": "esbaganhar",
    "esbaganhariam": "esbaganhar",
    "esbaganharias": "esbaganhar",
    "esbaganharmo": "esbaganhar",
    "esbaganharmos": "esbaganhar",
    "esbaganhará": "esbaganhar",
    "esbaganharás": "esbaganhar",
    "esbaganharão": "esbaganhar",
    "esbaganharíamos": "esbaganhar",
    "esbaganharíeis": "esbaganhar",
    "esbaganhas": "esbaganhar",
    "esbaganhasse": "esbaganhar",
    "esbaganhassem": "esbaganhar",
    "esbaganhasses": "esbaganhar",
    "esbaganhaste": "esbaganhar",
    "esbaganhastes": "esbaganhar",
    "esbaganhava": "esbaganhar",
    "esbaganhavam": "esbaganhar",
    "esbaganhavas": "esbaganhar",
    "esbaganhe": "esbaganhar",
    "esbaganhei": "esbaganhar",
    "esbaganheis": "esbaganhar",
    "esbaganhem": "esbaganhar",
    "esbaganhemo": "esbaganhar",
    "esbaganhemos": "esbaganhar",
    "esbaganhes": "esbaganhar",
    "esbaganho": "esbaganhar",
    "esbaganhou": "esbaganhar",
    "esbaganhá": "esbaganhar",
    "esbaganhámo": "esbaganhar",
    "esbaganhámos": "esbaganhar",
    "esbaganháramo": "esbaganhar",
    "esbaganháramos": "esbaganhar",
    "esbaganhárei": "esbaganhar",
    "esbaganháreis": "esbaganhar",
    "esbaganhásseis": "esbaganhar",
    "esbaganhássemos": "esbaganhar",
    "esbaganhávamo": "esbaganhar",
    "esbaganhávamos": "esbaganhar",
    "esbaganhávei": "esbaganhar",
    "esbaganháveis": "esbaganhar",
    "esbagaça": "esbagaçar",
    "esbagaçada": "esbagaçar",
    "esbagaçadas": "esbagaçar",
    "esbagaçado": "esbagaçar",
    "esbagaçados": "esbagaçar",
    "esbagaçai": "esbagaçar",
    "esbagaçais": "esbagaçar",
    "esbagaçam": "esbagaçar",
    "esbagaçamo": "esbagaçar",
    "esbagaçamos": "esbagaçar",
    "esbagaçando": "esbagaçar",
    "esbagaçara": "esbagaçar",
    "esbagaçaram": "esbagaçar",
    "esbagaçaras": "esbagaçar",
    "esbagaçarde": "esbagaçar",
    "esbagaçardes": "esbagaçar",
    "esbagaçare": "esbagaçar",
    "esbagaçarei": "esbagaçar",
    "esbagaçareis": "esbagaçar",
    "esbagaçarem": "esbagaçar",
    "esbagaçaremos": "esbagaçar",
    "esbagaçares": "esbagaçar",
    "esbagaçaria": "esbagaçar",
    "esbagaçariam": "esbagaçar",
    "esbagaçarias": "esbagaçar",
    "esbagaçarmo": "esbagaçar",
    "esbagaçarmos": "esbagaçar",
    "esbagaçará": "esbagaçar",
    "esbagaçarás": "esbagaçar",
    "esbagaçarão": "esbagaçar",
    "esbagaçaríamos": "esbagaçar",
    "esbagaçaríeis": "esbagaçar",
    "esbagaças": "esbagaçar",
    "esbagaçasse": "esbagaçar",
    "esbagaçassem": "esbagaçar",
    "esbagaçasses": "esbagaçar",
    "esbagaçaste": "esbagaçar",
    "esbagaçastes": "esbagaçar",
    "esbagaçava": "esbagaçar",
    "esbagaçavam": "esbagaçar",
    "esbagaçavas": "esbagaçar",
    "esbagaço": "esbagaçar",
    "esbagaçou": "esbagaçar",
    "esbagaçá": "esbagaçar",
    "esbagaçámo": "esbagaçar",
    "esbagaçámos": "esbagaçar",
    "esbagaçáramo": "esbagaçar",
    "esbagaçáramos": "esbagaçar",
    "esbagaçárei": "esbagaçar",
    "esbagaçáreis": "esbagaçar",
    "esbagaçásseis": "esbagaçar",
    "esbagaçássemos": "esbagaçar",
    "esbagaçávamo": "esbagaçar",
    "esbagaçávamos": "esbagaçar",
    "esbagaçávei": "esbagaçar",
    "esbagaçáveis": "esbagaçar",
    "esbagoa": "esbagoar",
    "esbagoada": "esbagoar",
    "esbagoadas": "esbagoar",
    "esbagoado": "esbagoar",
    "esbagoados": "esbagoar",
    "esbagoai": "esbagoar",
    "esbagoais": "esbagoar",
    "esbagoam": "esbagoar",
    "esbagoamo": "esbagoar",
    "esbagoamos": "esbagoar",
    "esbagoando": "esbagoar",
    "esbagoara": "esbagoar",
    "esbagoaram": "esbagoar",
    "esbagoaras": "esbagoar",
    "esbagoarde": "esbagoar",
    "esbagoardes": "esbagoar",
    "esbagoare": "esbagoar",
    "esbagoarei": "esbagoar",
    "esbagoareis": "esbagoar",
    "esbagoarem": "esbagoar",
    "esbagoaremos": "esbagoar",
    "esbagoares": "esbagoar",
    "esbagoaria": "esbagoar",
    "esbagoariam": "esbagoar",
    "esbagoarias": "esbagoar",
    "esbagoarmo": "esbagoar",
    "esbagoarmos": "esbagoar",
    "esbagoará": "esbagoar",
    "esbagoarás": "esbagoar",
    "esbagoarão": "esbagoar",
    "esbagoaríamos": "esbagoar",
    "esbagoaríeis": "esbagoar",
    "esbagoas": "esbagoar",
    "esbagoasse": "esbagoar",
    "esbagoassem": "esbagoar",
    "esbagoasses": "esbagoar",
    "esbagoaste": "esbagoar",
    "esbagoastes": "esbagoar",
    "esbagoava": "esbagoar",
    "esbagoavam": "esbagoar",
    "esbagoavas": "esbagoar",
    "esbagoe": "esbagoar",
    "esbagoei": "esbagoar",
    "esbagoeis": "esbagoar",
    "esbagoem": "esbagoar",
    "esbagoemo": "esbagoar",
    "esbagoemos": "esbagoar",
    "esbagoes": "esbagoar",
    "esbagoo": "esbagoar",
    "esbagoou": "esbagoar",
    "esbagoá": "esbagoar",
    "esbagoámo": "esbagoar",
    "esbagoámos": "esbagoar",
    "esbagoáramo": "esbagoar",
    "esbagoáramos": "esbagoar",
    "esbagoárei": "esbagoar",
    "esbagoáreis": "esbagoar",
    "esbagoásseis": "esbagoar",
    "esbagoássemos": "esbagoar",
    "esbagoávamo": "esbagoar",
    "esbagoávamos": "esbagoar",
    "esbagoávei": "esbagoar",
    "esbagoáveis": "esbagoar",
    "esbagulha": "esbagulhar",
    "esbagulhada": "esbagulhar",
    "esbagulhadas": "esbagulhar",
    "esbagulhado": "esbagulhar",
    "esbagulhados": "esbagulhar",
    "esbagulhai": "esbagulhar",
    "esbagulhais": "esbagulhar",
    "esbagulham": "esbagulhar",
    "esbagulhamo": "esbagulhar",
    "esbagulhamos": "esbagulhar",
    "esbagulhando": "esbagulhar",
    "esbagulhara": "esbagulhar",
    "esbagulharam": "esbagulhar",
    "esbagulharas": "esbagulhar",
    "esbagulharde": "esbagulhar",
    "esbagulhardes": "esbagulhar",
    "esbagulhare": "esbagulhar",
    "esbagulharei": "esbagulhar",
    "esbagulhareis": "esbagulhar",
    "esbagulharem": "esbagulhar",
    "esbagulharemos": "esbagulhar",
    "esbagulhares": "esbagulhar",
    "esbagulharia": "esbagulhar",
    "esbagulhariam": "esbagulhar",
    "esbagulharias": "esbagulhar",
    "esbagulharmo": "esbagulhar",
    "esbagulharmos": "esbagulhar",
    "esbagulhará": "esbagulhar",
    "esbagulharás": "esbagulhar",
    "esbagulharão": "esbagulhar",
    "esbagulharíamos": "esbagulhar",
    "esbagulharíeis": "esbagulhar",
    "esbagulhas": "esbagulhar",
    "esbagulhasse": "esbagulhar",
    "esbagulhassem": "esbagulhar",
    "esbagulhasses": "esbagulhar",
    "esbagulhaste": "esbagulhar",
    "esbagulhastes": "esbagulhar",
    "esbagulhava": "esbagulhar",
    "esbagulhavam": "esbagulhar",
    "esbagulhavas": "esbagulhar",
    "esbagulhe": "esbagulhar",
    "esbagulhei": "esbagulhar",
    "esbagulheis": "esbagulhar",
    "esbagulhem": "esbagulhar",
    "esbagulhemo": "esbagulhar",
    "esbagulhemos": "esbagulhar",
    "esbagulhes": "esbagulhar",
    "esbagulho": "esbagulhar",
    "esbagulhou": "esbagulhar",
    "esbagulhá": "esbagulhar",
    "esbagulhámo": "esbagulhar",
    "esbagulhámos": "esbagulhar",
    "esbagulháramo": "esbagulhar",
    "esbagulháramos": "esbagulhar",
    "esbagulhárei": "esbagulhar",
    "esbagulháreis": "esbagulhar",
    "esbagulhásseis": "esbagulhar",
    "esbagulhássemos": "esbagulhar",
    "esbagulhávamo": "esbagulhar",
    "esbagulhávamos": "esbagulhar",
    "esbagulhávei": "esbagulhar",
    "esbagulháveis": "esbagulhar",
    "esbalge": "esbalgir",
    "esbalgem": "esbalgir",
    "esbalges": "esbalgir",
    "esbalgi": "esbalgir",
    "esbalgia": "esbalgir",
    "esbalgiam": "esbalgir",
    "esbalgias": "esbalgir",
    "esbalgida": "esbalgir",
    "esbalgidas": "esbalgir",
    "esbalgido": "esbalgir",
    "esbalgidora": "esbalgidor",
    "esbalgidoras": "esbalgidor",
    "esbalgidores": "esbalgidor",
    "esbalgidos": "esbalgir",
    "esbalgimo": "esbalgir",
    "esbalgimos": "esbalgir",
    "esbalgindo": "esbalgir",
    "esbalgira": "esbalgir",
    "esbalgiram": "esbalgir",
    "esbalgiras": "esbalgir",
    "esbalgirde": "esbalgir",
    "esbalgirdes": "esbalgir",
    "esbalgire": "esbalgir",
    "esbalgirei": "esbalgir",
    "esbalgireis": "esbalgir",
    "esbalgirem": "esbalgir",
    "esbalgiremos": "esbalgir",
    "esbalgires": "esbalgir",
    "esbalgiria": "esbalgir",
    "esbalgiriam": "esbalgir",
    "esbalgirias": "esbalgir",
    "esbalgirmo": "esbalgir",
    "esbalgirmos": "esbalgir",
    "esbalgirá": "esbalgir",
    "esbalgirás": "esbalgir",
    "esbalgirão": "esbalgir",
    "esbalgiríamos": "esbalgir",
    "esbalgiríeis": "esbalgir",
    "esbalgis": "esbalgir",
    "esbalgisse": "esbalgir",
    "esbalgissem": "esbalgir",
    "esbalgisses": "esbalgir",
    "esbalgiste": "esbalgir",
    "esbalgistes": "esbalgir",
    "esbalgiu": "esbalgir",
    "esbalgíamo": "esbalgir",
    "esbalgíamos": "esbalgir",
    "esbalgíei": "esbalgir",
    "esbalgíeis": "esbalgir",
    "esbalgíramo": "esbalgir",
    "esbalgíramos": "esbalgir",
    "esbalgírei": "esbalgir",
    "esbalgíreis": "esbalgir",
    "esbalgísseis": "esbalgir",
    "esbalgíssemos": "esbalgir",
    "esbalja": "esbalgir",
    "esbaljais": "esbalgir",
    "esbaljam": "esbalgir",
    "esbaljamo": "esbalgir",
    "esbaljamos": "esbalgir",
    "esbaljas": "esbalgir",
    "esbaljo": "esbalgir",
    "esbaluartada": "esbaluartado",
    "esbaluartadas": "esbaluartado",
    "esbaluartados": "esbaluartado",
    "esbambalhada": "esbambalhado",
    "esbambalhadas": "esbambalhado",
    "esbambalhados": "esbambalhado",
    "esbambeada": "esbambear",
    "esbambeadas": "esbambear",
    "esbambeado": "esbambear",
    "esbambeados": "esbambear",
    "esbambeai": "esbambear",
    "esbambeais": "esbambear",
    "esbambeamo": "esbambear",
    "esbambeamos": "esbambear",
    "esbambeando": "esbambear",
    "esbambeara": "esbambear",
    "esbambearam": "esbambear",
    "esbambearas": "esbambear",
    "esbambearde": "esbambear",
    "esbambeardes": "esbambear",
    "esbambeare": "esbambear",
    "esbambearei": "esbambear",
    "esbambeareis": "esbambear",
    "esbambearem": "esbambear",
    "esbambearemos": "esbambear",
    "esbambeares": "esbambear",
    "esbambearia": "esbambear",
    "esbambeariam": "esbambear",
    "esbambearias": "esbambear",
    "esbambearmo": "esbambear",
    "esbambearmos": "esbambear",
    "esbambeará": "esbambear",
    "esbambearás": "esbambear",
    "esbambearão": "esbambear",
    "esbambearíamos": "esbambear",
    "esbambearíeis": "esbambear",
    "esbambeasse": "esbambear",
    "esbambeassem": "esbambear",
    "esbambeasses": "esbambear",
    "esbambeaste": "esbambear",
    "esbambeastes": "esbambear",
    "esbambeava": "esbambear",
    "esbambeavam": "esbambear",
    "esbambeavas": "esbambear",
    "esbambeei": "esbambear",
    "esbambeeis": "esbambear",
    "esbambeemo": "esbambear",
    "esbambeemos": "esbambear",
    "esbambeia": "esbambear",
    "esbambeiam": "esbambear",
    "esbambeias": "esbambear",
    "esbambeie": "esbambear",
    "esbambeiem": "esbambear",
    "esbambeies": "esbambear",
    "esbambeio": "esbambear",
    "esbambeou": "esbambear",
    "esbambeá": "esbambear",
    "esbambeámo": "esbambear",
    "esbambeámos": "esbambear",
    "esbambeáramo": "esbambear",
    "esbambeáramos": "esbambear",
    "esbambeárei": "esbambear",
    "esbambeáreis": "esbambear",
    "esbambeásseis": "esbambear",
    "esbambeássemos": "esbambear",
    "esbambeávamo": "esbambear",
    "esbambeávamos": "esbambear",
    "esbambeávei": "esbambear",
    "esbambeáveis": "esbambear",
    "esbamboleada": "esbambolear",
    "esbamboleadas": "esbambolear",
    "esbamboleado": "esbambolear",
    "esbamboleados": "esbambolear",
    "esbamboleai": "esbambolear",
    "esbamboleais": "esbambolear",
    "esbamboleamo": "esbambolear",
    "esbamboleamos": "esbambolear",
    "esbamboleando": "esbambolear",
    "esbamboleara": "esbambolear",
    "esbambolearam": "esbambolear",
    "esbambolearas": "esbambolear",
    "esbambolearde": "esbambolear",
    "esbamboleardes": "esbambolear",
    "esbamboleare": "esbambolear",
    "esbambolearei": "esbambolear",
    "esbamboleareis": "esbambolear",
    "esbambolearem": "esbambolear",
    "esbambolearemos": "esbambolear",
    "esbamboleares": "esbambolear",
    "esbambolearia": "esbambolear",
    "esbamboleariam": "esbambolear",
    "esbambolearias": "esbambolear",
    "esbambolearmo": "esbambolear",
    "esbambolearmos": "esbambolear",
    "esbamboleará": "esbambolear",
    "esbambolearás": "esbambolear",
    "esbambolearão": "esbambolear",
    "esbambolearíamos": "esbambolear",
    "esbambolearíeis": "esbambolear",
    "esbamboleasse": "esbambolear",
    "esbamboleassem": "esbambolear",
    "esbamboleasses": "esbambolear",
    "esbamboleaste": "esbambolear",
    "esbamboleastes": "esbambolear",
    "esbamboleava": "esbambolear",
    "esbamboleavam": "esbambolear",
    "esbamboleavas": "esbambolear",
    "esbamboleei": "esbambolear",
    "esbamboleeis": "esbambolear",
    "esbamboleemo": "esbambolear",
    "esbamboleemos": "esbambolear",
    "esbamboleia": "esbambolear",
    "esbamboleiam": "esbambolear",
    "esbamboleias": "esbambolear",
    "esbamboleie": "esbambolear",
    "esbamboleiem": "esbambolear",
    "esbamboleies": "esbambolear",
    "esbamboleio": "esbambolear",
    "esbamboleou": "esbambolear",
    "esbamboleá": "esbambolear",
    "esbamboleámo": "esbambolear",
    "esbamboleámos": "esbambolear",
    "esbamboleáramo": "esbambolear",
    "esbamboleáramos": "esbambolear",
    "esbamboleárei": "esbambolear",
    "esbamboleáreis": "esbambolear",
    "esbamboleásseis": "esbambolear",
    "esbamboleássemos": "esbambolear",
    "esbamboleávamo": "esbambolear",
    "esbamboleávamos": "esbambolear",
    "esbamboleávei": "esbambolear",
    "esbamboleáveis": "esbambolear",
    "esbandalha": "esbandalhar",
    "esbandalhada": "esbandalhar",
    "esbandalhadas": "esbandalhar",
    "esbandalhado": "esbandalhar",
    "esbandalhados": "esbandalhar",
    "esbandalhai": "esbandalhar",
    "esbandalhais": "esbandalhar",
    "esbandalham": "esbandalhar",
    "esbandalhamo": "esbandalhar",
    "esbandalhamos": "esbandalhar",
    "esbandalhando": "esbandalhar",
    "esbandalhara": "esbandalhar",
    "esbandalharam": "esbandalhar",
    "esbandalharas": "esbandalhar",
    "esbandalharde": "esbandalhar",
    "esbandalhardes": "esbandalhar",
    "esbandalhare": "esbandalhar",
    "esbandalharei": "esbandalhar",
    "esbandalhareis": "esbandalhar",
    "esbandalharem": "esbandalhar",
    "esbandalharemos": "esbandalhar",
    "esbandalhares": "esbandalhar",
    "esbandalharia": "esbandalhar",
    "esbandalhariam": "esbandalhar",
    "esbandalharias": "esbandalhar",
    "esbandalharmo": "esbandalhar",
    "esbandalharmos": "esbandalhar",
    "esbandalhará": "esbandalhar",
    "esbandalharás": "esbandalhar",
    "esbandalharão": "esbandalhar",
    "esbandalharíamos": "esbandalhar",
    "esbandalharíeis": "esbandalhar",
    "esbandalhas": "esbandalhar",
    "esbandalhasse": "esbandalhar",
    "esbandalhassem": "esbandalhar",
    "esbandalhasses": "esbandalhar",
    "esbandalhaste": "esbandalhar",
    "esbandalhastes": "esbandalhar",
    "esbandalhava": "esbandalhar",
    "esbandalhavam": "esbandalhar",
    "esbandalhavas": "esbandalhar",
    "esbandalhe": "esbandalhar",
    "esbandalhei": "esbandalhar",
    "esbandalheis": "esbandalhar",
    "esbandalhem": "esbandalhar",
    "esbandalhemo": "esbandalhar",
    "esbandalhemos": "esbandalhar",
    "esbandalhes": "esbandalhar",
    "esbandalho": "esbandalhar",
    "esbandalhou": "esbandalhar",
    "esbandalhá": "esbandalhar",
    "esbandalhámo": "esbandalhar",
    "esbandalhámos": "esbandalhar",
    "esbandalháramo": "esbandalhar",
    "esbandalháramos": "esbandalhar",
    "esbandalhárei": "esbandalhar",
    "esbandalháreis": "esbandalhar",
    "esbandalhásseis": "esbandalhar",
    "esbandalhássemos": "esbandalhar",
    "esbandalhávamo": "esbandalhar",
    "esbandalhávamos": "esbandalhar",
    "esbandalhávei": "esbandalhar",
    "esbandalháveis": "esbandalhar",
    "esbandeira": "esbandeirar",
    "esbandeirada": "esbandeirar",
    "esbandeiradas": "esbandeirar",
    "esbandeirado": "esbandeirar",
    "esbandeirados": "esbandeirar",
    "esbandeirai": "esbandeirar",
    "esbandeirais": "esbandeirar",
    "esbandeiram": "esbandeirar",
    "esbandeiramo": "esbandeirar",
    "esbandeiramos": "esbandeirar",
    "esbandeirando": "esbandeirar",
    "esbandeirara": "esbandeirar",
    "esbandeiraram": "esbandeirar",
    "esbandeiraras": "esbandeirar",
    "esbandeirarde": "esbandeirar",
    "esbandeirardes": "esbandeirar",
    "esbandeirare": "esbandeirar",
    "esbandeirarei": "esbandeirar",
    "esbandeirareis": "esbandeirar",
    "esbandeirarem": "esbandeirar",
    "esbandeiraremos": "esbandeirar",
    "esbandeirares": "esbandeirar",
    "esbandeiraria": "esbandeirar",
    "esbandeirariam": "esbandeirar",
    "esbandeirarias": "esbandeirar",
    "esbandeirarmo": "esbandeirar",
    "esbandeirarmos": "esbandeirar",
    "esbandeirará": "esbandeirar",
    "esbandeirarás": "esbandeirar",
    "esbandeirarão": "esbandeirar",
    "esbandeiraríamos": "esbandeirar",
    "esbandeiraríeis": "esbandeirar",
    "esbandeiras": "esbandeirar",
    "esbandeirasse": "esbandeirar",
    "esbandeirassem": "esbandeirar",
    "esbandeirasses": "esbandeirar",
    "esbandeiraste": "esbandeirar",
    "esbandeirastes": "esbandeirar",
    "esbandeirava": "esbandeirar",
    "esbandeiravam": "esbandeirar",
    "esbandeiravas": "esbandeirar",
    "esbandeire": "esbandeirar",
    "esbandeirei": "esbandeirar",
    "esbandeireis": "esbandeirar",
    "esbandeirem": "esbandeirar",
    "esbandeiremo": "esbandeirar",
    "esbandeiremos": "esbandeirar",
    "esbandeires": "esbandeirar",
    "esbandeiro": "esbandeirar",
    "esbandeirou": "esbandeirar",
    "esbandeirá": "esbandeirar",
    "esbandeirámo": "esbandeirar",
    "esbandeirámos": "esbandeirar",
    "esbandeiráramo": "esbandeirar",
    "esbandeiráramos": "esbandeirar",
    "esbandeirárei": "esbandeirar",
    "esbandeiráreis": "esbandeirar",
    "esbandeirásseis": "esbandeirar",
    "esbandeirássemos": "esbandeirar",
    "esbandeirávamo": "esbandeirar",
    "esbandeirávamos": "esbandeirar",
    "esbandeirávei": "esbandeirar",
    "esbandeiráveis": "esbandeirar",
    "esbandulha": "esbandulhar",
    "esbandulhada": "esbandulhar",
    "esbandulhadas": "esbandulhar",
    "esbandulhado": "esbandulhar",
    "esbandulhados": "esbandulhar",
    "esbandulhai": "esbandulhar",
    "esbandulhais": "esbandulhar",
    "esbandulham": "esbandulhar",
    "esbandulhamo": "esbandulhar",
    "esbandulhamos": "esbandulhar",
    "esbandulhando": "esbandulhar",
    "esbandulhara": "esbandulhar",
    "esbandulharam": "esbandulhar",
    "esbandulharas": "esbandulhar",
    "esbandulharde": "esbandulhar",
    "esbandulhardes": "esbandulhar",
    "esbandulhare": "esbandulhar",
    "esbandulharei": "esbandulhar",
    "esbandulhareis": "esbandulhar",
    "esbandulharem": "esbandulhar",
    "esbandulharemos": "esbandulhar",
    "esbandulhares": "esbandulhar",
    "esbandulharia": "esbandulhar",
    "esbandulhariam": "esbandulhar",
    "esbandulharias": "esbandulhar",
    "esbandulharmo": "esbandulhar",
    "esbandulharmos": "esbandulhar",
    "esbandulhará": "esbandulhar",
    "esbandulharás": "esbandulhar",
    "esbandulharão": "esbandulhar",
    "esbandulharíamos": "esbandulhar",
    "esbandulharíeis": "esbandulhar",
    "esbandulhas": "esbandulhar",
    "esbandulhasse": "esbandulhar",
    "esbandulhassem": "esbandulhar",
    "esbandulhasses": "esbandulhar",
    "esbandulhaste": "esbandulhar",
    "esbandulhastes": "esbandulhar",
    "esbandulhava": "esbandulhar",
    "esbandulhavam": "esbandulhar",
    "esbandulhavas": "esbandulhar",
    "esbandulhe": "esbandulhar",
    "esbandulhei": "esbandulhar",
    "esbandulheis": "esbandulhar",
    "esbandulhem": "esbandulhar",
    "esbandulhemo": "esbandulhar",
    "esbandulhemos": "esbandulhar",
    "esbandulhes": "esbandulhar",
    "esbandulho": "esbandulhar",
    "esbandulhou": "esbandulhar",
    "esbandulhá": "esbandulhar",
    "esbandulhámo": "esbandulhar",
    "esbandulhámos": "esbandulhar",
    "esbandulháramo": "esbandulhar",
    "esbandulháramos": "esbandulhar",
    "esbandulhárei": "esbandulhar",
    "esbandulháreis": "esbandulhar",
    "esbandulhásseis": "esbandulhar",
    "esbandulhássemos": "esbandulhar",
    "esbandulhávamo": "esbandulhar",
    "esbandulhávamos": "esbandulhar",
    "esbandulhávei": "esbandulhar",
    "esbandulháveis": "esbandulhar",
    "esbanja": "esbanjar",
    "esbanjada": "esbanjar",
    "esbanjadas": "esbanjar",
    "esbanjado": "esbanjar",
    "esbanjadora": "esbanjador",
    "esbanjadoras": "esbanjador",
    "esbanjadores": "esbanjador",
    "esbanjados": "esbanjar",
    "esbanjai": "esbanjar",
    "esbanjais": "esbanjar",
    "esbanjam": "esbanjar",
    "esbanjamentos": "esbanjamento",
    "esbanjamo": "esbanjar",
    "esbanjamos": "esbanjar",
    "esbanjando": "esbanjar",
    "esbanjara": "esbanjar",
    "esbanjaram": "esbanjar",
    "esbanjaras": "esbanjar",
    "esbanjarde": "esbanjar",
    "esbanjardes": "esbanjar",
    "esbanjare": "esbanjar",
    "esbanjarei": "esbanjar",
    "esbanjareis": "esbanjar",
    "esbanjarem": "esbanjar",
    "esbanjaremos": "esbanjar",
    "esbanjares": "esbanjar",
    "esbanjaria": "esbanjar",
    "esbanjariam": "esbanjar",
    "esbanjarias": "esbanjar",
    "esbanjarmo": "esbanjar",
    "esbanjarmos": "esbanjar",
    "esbanjará": "esbanjar",
    "esbanjarás": "esbanjar",
    "esbanjarão": "esbanjar",
    "esbanjaríamos": "esbanjar",
    "esbanjaríeis": "esbanjar",
    "esbanjas": "esbanjar",
    "esbanjasse": "esbanjar",
    "esbanjassem": "esbanjar",
    "esbanjasses": "esbanjar",
    "esbanjaste": "esbanjar",
    "esbanjastes": "esbanjar",
    "esbanjava": "esbanjar",
    "esbanjavam": "esbanjar",
    "esbanjavas": "esbanjar",
    "esbanje": "esbanjar",
    "esbanjei": "esbanjar",
    "esbanjeis": "esbanjar",
    "esbanjem": "esbanjar",
    "esbanjemo": "esbanjar",
    "esbanjemos": "esbanjar",
    "esbanjes": "esbanjar",
    "esbanjo": "esbanjar",
    "esbanjou": "esbanjar",
    "esbanjá": "esbanjar",
    "esbanjámo": "esbanjar",
    "esbanjámos": "esbanjar",
    "esbanjáramo": "esbanjar",
    "esbanjáramos": "esbanjar",
    "esbanjárei": "esbanjar",
    "esbanjáreis": "esbanjar",
    "esbanjásseis": "esbanjar",
    "esbanjássemos": "esbanjar",
    "esbanjávamo": "esbanjar",
    "esbanjávamos": "esbanjar",
    "esbanjávei": "esbanjar",
    "esbanjáveis": "esbanjável",
    "esbaralha": "esbaralhar",
    "esbaralhada": "esbaralhar",
    "esbaralhadas": "esbaralhar",
    "esbaralhado": "esbaralhar",
    "esbaralhados": "esbaralhar",
    "esbaralhai": "esbaralhar",
    "esbaralhais": "esbaralhar",
    "esbaralham": "esbaralhar",
    "esbaralhamo": "esbaralhar",
    "esbaralhamos": "esbaralhar",
    "esbaralhando": "esbaralhar",
    "esbaralhara": "esbaralhar",
    "esbaralharam": "esbaralhar",
    "esbaralharas": "esbaralhar",
    "esbaralharde": "esbaralhar",
    "esbaralhardes": "esbaralhar",
    "esbaralhare": "esbaralhar",
    "esbaralharei": "esbaralhar",
    "esbaralhareis": "esbaralhar",
    "esbaralharem": "esbaralhar",
    "esbaralharemos": "esbaralhar",
    "esbaralhares": "esbaralhar",
    "esbaralharia": "esbaralhar",
    "esbaralhariam": "esbaralhar",
    "esbaralharias": "esbaralhar",
    "esbaralharmo": "esbaralhar",
    "esbaralharmos": "esbaralhar",
    "esbaralhará": "esbaralhar",
    "esbaralharás": "esbaralhar",
    "esbaralharão": "esbaralhar",
    "esbaralharíamos": "esbaralhar",
    "esbaralharíeis": "esbaralhar",
    "esbaralhas": "esbaralhar",
    "esbaralhasse": "esbaralhar",
    "esbaralhassem": "esbaralhar",
    "esbaralhasses": "esbaralhar",
    "esbaralhaste": "esbaralhar",
    "esbaralhastes": "esbaralhar",
    "esbaralhava": "esbaralhar",
    "esbaralhavam": "esbaralhar",
    "esbaralhavas": "esbaralhar",
    "esbaralhe": "esbaralhar",
    "esbaralhei": "esbaralhar",
    "esbaralheis": "esbaralhar",
    "esbaralhem": "esbaralhar",
    "esbaralhemo": "esbaralhar",
    "esbaralhemos": "esbaralhar",
    "esbaralhes": "esbaralhar",
    "esbaralho": "esbaralhar",
    "esbaralhou": "esbaralhar",
    "esbaralhá": "esbaralhar",
    "esbaralhámo": "esbaralhar",
    "esbaralhámos": "esbaralhar",
    "esbaralháramo": "esbaralhar",
    "esbaralháramos": "esbaralhar",
    "esbaralhárei": "esbaralhar",
    "esbaralháreis": "esbaralhar",
    "esbaralhásseis": "esbaralhar",
    "esbaralhássemos": "esbaralhar",
    "esbaralhávamo": "esbaralhar",
    "esbaralhávamos": "esbaralhar",
    "esbaralhávei": "esbaralhar",
    "esbaralháveis": "esbaralhar",
    "esbarba": "esbarbar",
    "esbarbada": "esbarbar",
    "esbarbadas": "esbarbar",
    "esbarbado": "esbarbar",
    "esbarbados": "esbarbar",
    "esbarbai": "esbarbar",
    "esbarbais": "esbarbar",
    "esbarbam": "esbarbar",
    "esbarbamo": "esbarbar",
    "esbarbamos": "esbarbar",
    "esbarbando": "esbarbar",
    "esbarbara": "esbarbar",
    "esbarbaram": "esbarbar",
    "esbarbaras": "esbarbar",
    "esbarbarde": "esbarbar",
    "esbarbardes": "esbarbar",
    "esbarbare": "esbarbar",
    "esbarbarei": "esbarbar",
    "esbarbareis": "esbarbar",
    "esbarbarem": "esbarbar",
    "esbarbaremos": "esbarbar",
    "esbarbares": "esbarbar",
    "esbarbaria": "esbarbar",
    "esbarbariam": "esbarbar",
    "esbarbarias": "esbarbar",
    "esbarbarmo": "esbarbar",
    "esbarbarmos": "esbarbar",
    "esbarbará": "esbarbar",
    "esbarbarás": "esbarbar",
    "esbarbarão": "esbarbar",
    "esbarbaríamos": "esbarbar",
    "esbarbaríeis": "esbarbar",
    "esbarbas": "esbarbar",
    "esbarbasse": "esbarbar",
    "esbarbassem": "esbarbar",
    "esbarbasses": "esbarbar",
    "esbarbaste": "esbarbar",
    "esbarbastes": "esbarbar",
    "esbarbava": "esbarbar",
    "esbarbavam": "esbarbar",
    "esbarbavas": "esbarbar",
    "esbarbe": "esbarbar",
    "esbarbei": "esbarbar",
    "esbarbeis": "esbarbar",
    "esbarbem": "esbarbar",
    "esbarbemo": "esbarbar",
    "esbarbemos": "esbarbar",
    "esbarbes": "esbarbar",
    "esbarbo": "esbarbar",
    "esbarbota": "esbarbotar",
    "esbarbotada": "esbarbotar",
    "esbarbotadas": "esbarbotar",
    "esbarbotado": "esbarbotar",
    "esbarbotados": "esbarbotar",
    "esbarbotai": "esbarbotar",
    "esbarbotais": "esbarbotar",
    "esbarbotam": "esbarbotar",
    "esbarbotamo": "esbarbotar",
    "esbarbotamos": "esbarbotar",
    "esbarbotando": "esbarbotar",
    "esbarbotara": "esbarbotar",
    "esbarbotaram": "esbarbotar",
    "esbarbotaras": "esbarbotar",
    "esbarbotarde": "esbarbotar",
    "esbarbotardes": "esbarbotar",
    "esbarbotare": "esbarbotar",
    "esbarbotarei": "esbarbotar",
    "esbarbotareis": "esbarbotar",
    "esbarbotarem": "esbarbotar",
    "esbarbotaremos": "esbarbotar",
    "esbarbotares": "esbarbotar",
    "esbarbotaria": "esbarbotar",
    "esbarbotariam": "esbarbotar",
    "esbarbotarias": "esbarbotar",
    "esbarbotarmo": "esbarbotar",
    "esbarbotarmos": "esbarbotar",
    "esbarbotará": "esbarbotar",
    "esbarbotarás": "esbarbotar",
    "esbarbotarão": "esbarbotar",
    "esbarbotaríamos": "esbarbotar",
    "esbarbotaríeis": "esbarbotar",
    "esbarbotas": "esbarbotar",
    "esbarbotasse": "esbarbotar",
    "esbarbotassem": "esbarbotar",
    "esbarbotasses": "esbarbotar",
    "esbarbotaste": "esbarbotar",
    "esbarbotastes": "esbarbotar",
    "esbarbotava": "esbarbotar",
    "esbarbotavam": "esbarbotar",
    "esbarbotavas": "esbarbotar",
    "esbarbote": "esbarbotar",
    "esbarbotei": "esbarbotar",
    "esbarboteis": "esbarbotar",
    "esbarbotem": "esbarbotar",
    "esbarbotemo": "esbarbotar",
    "esbarbotemos": "esbarbotar",
    "esbarbotes": "esbarbotar",
    "esbarboto": "esbarbotar",
    "esbarbotou": "esbarbotar",
    "esbarbotá": "esbarbotar",
    "esbarbotámo": "esbarbotar",
    "esbarbotámos": "esbarbotar",
    "esbarbotáramo": "esbarbotar",
    "esbarbotáramos": "esbarbotar",
    "esbarbotárei": "esbarbotar",
    "esbarbotáreis": "esbarbotar",
    "esbarbotásseis": "esbarbotar",
    "esbarbotássemos": "esbarbotar",
    "esbarbotávamo": "esbarbotar",
    "esbarbotávamos": "esbarbotar",
    "esbarbotávei": "esbarbotar",
    "esbarbotáveis": "esbarbotar",
    "esbarbou": "esbarbar",
    "esbarbá": "esbarbar",
    "esbarbámo": "esbarbar",
    "esbarbámos": "esbarbar",
    "esbarbáramo": "esbarbar",
    "esbarbáramos": "esbarbar",
    "esbarbárei": "esbarbar",
    "esbarbáreis": "esbarbar",
    "esbarbásseis": "esbarbar",
    "esbarbássemos": "esbarbar",
    "esbarbávamo": "esbarbar",
    "esbarbávamos": "esbarbar",
    "esbarbávei": "esbarbar",
    "esbarbáveis": "esbarbar",
    "esbarra": "esbarrar",
    "esbarrada": "esbarrar",
    "esbarradas": "esbarrar",
    "esbarrado": "esbarrar",
    "esbarrados": "esbarrar",
    "esbarrai": "esbarrar",
    "esbarrais": "esbarrar",
    "esbarram": "esbarrar",
    "esbarramo": "esbarrar",
    "esbarramos": "esbarrar",
    "esbarrancada": "esbarrancado",
    "esbarrancadas": "esbarrancado",
    "esbarrancados": "esbarrancado",
    "esbarrando": "esbarrar",
    "esbarrara": "esbarrar",
    "esbarraram": "esbarrar",
    "esbarraras": "esbarrar",
    "esbarrardes": "esbarrar",
    "esbarrarei": "esbarrar",
    "esbarrareis": "esbarrar",
    "esbarrarem": "esbarrar",
    "esbarraremos": "esbarrar",
    "esbarrares": "esbarrar",
    "esbarraria": "esbarrar",
    "esbarrariam": "esbarrar",
    "esbarrarias": "esbarrar",
    "esbarrarmo": "esbarrar",
    "esbarrarmos": "esbarrar",
    "esbarrará": "esbarrar",
    "esbarrarás": "esbarrar",
    "esbarrarão": "esbarrar",
    "esbarraríamos": "esbarrar",
    "esbarraríeis": "esbarrar",
    "esbarras": "esbarrar",
    "esbarrasse": "esbarrar",
    "esbarrassem": "esbarrar",
    "esbarrasses": "esbarrar",
    "esbarraste": "esbarrar",
    "esbarrastes": "esbarrar",
    "esbarrava": "esbarrar",
    "esbarravam": "esbarrar",
    "esbarravas": "esbarrar",
    "esbarre": "esbarrar",
    "esbarrei": "esbarrar",
    "esbarreis": "esbarrar",
    "esbarrem": "esbarrar",
    "esbarremo": "esbarrar",
    "esbarremos": "esbarrar",
    "esbarres": "esbarrar",
    "esbarriga": "esbarrigar",
    "esbarrigada": "esbarrigar",
    "esbarrigadas": "esbarrigar",
    "esbarrigado": "esbarrigar",
    "esbarrigados": "esbarrigar",
    "esbarrigai": "esbarrigar",
    "esbarrigais": "esbarrigar",
    "esbarrigam": "esbarrigar",
    "esbarrigamo": "esbarrigar",
    "esbarrigamos": "esbarrigar",
    "esbarrigando": "esbarrigar",
    "esbarrigara": "esbarrigar",
    "esbarrigaram": "esbarrigar",
    "esbarrigaras": "esbarrigar",
    "esbarrigarde": "esbarrigar",
    "esbarrigardes": "esbarrigar",
    "esbarrigare": "esbarrigar",
    "esbarrigarei": "esbarrigar",
    "esbarrigareis": "esbarrigar",
    "esbarrigarem": "esbarrigar",
    "esbarrigaremos": "esbarrigar",
    "esbarrigares": "esbarrigar",
    "esbarrigaria": "esbarrigar",
    "esbarrigariam": "esbarrigar",
    "esbarrigarias": "esbarrigar",
    "esbarrigarmo": "esbarrigar",
    "esbarrigarmos": "esbarrigar",
    "esbarrigará": "esbarrigar",
    "esbarrigarás": "esbarrigar",
    "esbarrigarão": "esbarrigar",
    "esbarrigaríamos": "esbarrigar",
    "esbarrigaríeis": "esbarrigar",
    "esbarrigas": "esbarrigar",
    "esbarrigasse": "esbarrigar",
    "esbarrigassem": "esbarrigar",
    "esbarrigasses": "esbarrigar",
    "esbarrigaste": "esbarrigar",
    "esbarrigastes": "esbarrigar",
    "esbarrigava": "esbarrigar",
    "esbarrigavam": "esbarrigar",
    "esbarrigavas": "esbarrigar",
    "esbarrigo": "esbarrigar",
    "esbarrigou": "esbarrigar",
    "esbarrigue": "esbarrigar",
    "esbarriguei": "esbarrigar",
    "esbarrigueis": "esbarrigar",
    "esbarriguem": "esbarrigar",
    "esbarriguemo": "esbarrigar",
    "esbarriguemos": "esbarrigar",
    "esbarrigues": "esbarrigar",
    "esbarrigá": "esbarrigar",
    "esbarrigámo": "esbarrigar",
    "esbarrigámos": "esbarrigar",
    "esbarrigáramo": "esbarrigar",
    "esbarrigáramos": "esbarrigar",
    "esbarrigárei": "esbarrigar",
    "esbarrigáreis": "esbarrigar",
    "esbarrigásseis": "esbarrigar",
    "esbarrigássemos": "esbarrigar",
    "esbarrigávamo": "esbarrigar",
    "esbarrigávamos": "esbarrigar",
    "esbarrigávei": "esbarrigar",
    "esbarrigáveis": "esbarrigar",
    "esbarro": "esbarrar",
    "esbarroca": "esbarrocar",
    "esbarrocada": "esbarrocar",
    "esbarrocadas": "esbarrocar",
    "esbarrocado": "esbarrocar",
    "esbarrocados": "esbarrocar",
    "esbarrocai": "esbarrocar",
    "esbarrocais": "esbarrocar",
    "esbarrocam": "esbarrocar",
    "esbarrocamentos": "esbarrocamento",
    "esbarrocamo": "esbarrocar",
    "esbarrocamos": "esbarrocar",
    "esbarrocando": "esbarrocar",
    "esbarrocara": "esbarrocar",
    "esbarrocaram": "esbarrocar",
    "esbarrocaras": "esbarrocar",
    "esbarrocarde": "esbarrocar",
    "esbarrocardes": "esbarrocar",
    "esbarrocare": "esbarrocar",
    "esbarrocarei": "esbarrocar",
    "esbarrocareis": "esbarrocar",
    "esbarrocarem": "esbarrocar",
    "esbarrocaremos": "esbarrocar",
    "esbarrocares": "esbarrocar",
    "esbarrocaria": "esbarrocar",
    "esbarrocariam": "esbarrocar",
    "esbarrocarias": "esbarrocar",
    "esbarrocarmo": "esbarrocar",
    "esbarrocarmos": "esbarrocar",
    "esbarrocará": "esbarrocar",
    "esbarrocarás": "esbarrocar",
    "esbarrocarão": "esbarrocar",
    "esbarrocaríamos": "esbarrocar",
    "esbarrocaríeis": "esbarrocar",
    "esbarrocas": "esbarrocar",
    "esbarrocasse": "esbarrocar",
    "esbarrocassem": "esbarrocar",
    "esbarrocasses": "esbarrocar",
    "esbarrocaste": "esbarrocar",
    "esbarrocastes": "esbarrocar",
    "esbarrocava": "esbarrocar",
    "esbarrocavam": "esbarrocar",
    "esbarrocavas": "esbarrocar",
    "esbarroco": "esbarrocar",
    "esbarrocou": "esbarrocar",
    "esbarrocá": "esbarrocar",
    "esbarrocámo": "esbarrocar",
    "esbarrocámos": "esbarrocar",
    "esbarrocáramo": "esbarrocar",
    "esbarrocáramos": "esbarrocar",
    "esbarrocárei": "esbarrocar",
    "esbarrocáreis": "esbarrocar",
    "esbarrocásseis": "esbarrocar",
    "esbarrocássemos": "esbarrocar",
    "esbarrocávamo": "esbarrocar",
    "esbarrocávamos": "esbarrocar",
    "esbarrocávei": "esbarrocar",
    "esbarrocáveis": "esbarrocar",
    "esbarronda": "esbarrondar",
    "esbarrondada": "esbarrondar",
    "esbarrondadas": "esbarrondar",
    "esbarrondadeiros": "esbarrondadeiro",
    "esbarrondado": "esbarrondar",
    "esbarrondados": "esbarrondar",
    "esbarrondai": "esbarrondar",
    "esbarrondais": "esbarrondar",
    "esbarrondam": "esbarrondar",
    "esbarrondamentos": "esbarrondamento",
    "esbarrondamo": "esbarrondar",
    "esbarrondamos": "esbarrondar",
    "esbarrondando": "esbarrondar",
    "esbarrondara": "esbarrondar",
    "esbarrondaram": "esbarrondar",
    "esbarrondaras": "esbarrondar",
    "esbarrondarde": "esbarrondar",
    "esbarrondardes": "esbarrondar",
    "esbarrondare": "esbarrondar",
    "esbarrondarei": "esbarrondar",
    "esbarrondareis": "esbarrondar",
    "esbarrondarem": "esbarrondar",
    "esbarrondaremos": "esbarrondar",
    "esbarrondares": "esbarrondar",
    "esbarrondaria": "esbarrondar",
    "esbarrondariam": "esbarrondar",
    "esbarrondarias": "esbarrondar",
    "esbarrondarmo": "esbarrondar",
    "esbarrondarmos": "esbarrondar",
    "esbarrondará": "esbarrondar",
    "esbarrondarás": "esbarrondar",
    "esbarrondarão": "esbarrondar",
    "esbarrondaríamos": "esbarrondar",
    "esbarrondaríeis": "esbarrondar",
    "esbarrondas": "esbarrondar",
    "esbarrondasse": "esbarrondar",
    "esbarrondassem": "esbarrondar",
    "esbarrondasses": "esbarrondar",
    "esbarrondaste": "esbarrondar",
    "esbarrondastes": "esbarrondar",
    "esbarrondava": "esbarrondar",
    "esbarrondavam": "esbarrondar",
    "esbarrondavas": "esbarrondar",
    "esbarronde": "esbarrondar",
    "esbarrondei": "esbarrondar",
    "esbarrondeis": "esbarrondar",
    "esbarrondem": "esbarrondar",
    "esbarrondemo": "esbarrondar",
    "esbarrondemos": "esbarrondar",
    "esbarrondes": "esbarrondar",
    "esbarrondo": "esbarrondar",
    "esbarrondou": "esbarrondar",
    "esbarrondá": "esbarrondar",
    "esbarrondámo": "esbarrondar",
    "esbarrondámos": "esbarrondar",
    "esbarrondáramo": "esbarrondar",
    "esbarrondáramos": "esbarrondar",
    "esbarrondárei": "esbarrondar",
    "esbarrondáreis": "esbarrondar",
    "esbarrondásseis": "esbarrondar",
    "esbarrondássemos": "esbarrondar",
    "esbarrondávamo": "esbarrondar",
    "esbarrondávamos": "esbarrondar",
    "esbarrondávei": "esbarrondar",
    "esbarrondáveis": "esbarrondar",
    "esbarroque": "esbarrocar",
    "esbarroquei": "esbarrocar",
    "esbarroqueis": "esbarrocar",
    "esbarroquem": "esbarrocar",
    "esbarroquemo": "esbarrocar",
    "esbarroquemos": "esbarrocar",
    "esbarroques": "esbarrocar",
    "esbarros": "esbarro",
    "esbarrota": "esbarrotar",
    "esbarrotada": "esbarrotar",
    "esbarrotadas": "esbarrotar",
    "esbarrotado": "esbarrotar",
    "esbarrotados": "esbarrotar",
    "esbarrotai": "esbarrotar",
    "esbarrotais": "esbarrotar",
    "esbarrotam": "esbarrotar",
    "esbarrotamo": "esbarrotar",
    "esbarrotamos": "esbarrotar",
    "esbarrotando": "esbarrotar",
    "esbarrotara": "esbarrotar",
    "esbarrotaram": "esbarrotar",
    "esbarrotaras": "esbarrotar",
    "esbarrotardes": "esbarrotar",
    "esbarrotarei": "esbarrotar",
    "esbarrotareis": "esbarrotar",
    "esbarrotarem": "esbarrotar",
    "esbarrotaremos": "esbarrotar",
    "esbarrotares": "esbarrotar",
    "esbarrotaria": "esbarrotar",
    "esbarrotariam": "esbarrotar",
    "esbarrotarias": "esbarrotar",
    "esbarrotarmo": "esbarrotar",
    "esbarrotarmos": "esbarrotar",
    "esbarrotará": "esbarrotar",
    "esbarrotarás": "esbarrotar",
    "esbarrotarão": "esbarrotar",
    "esbarrotaríamos": "esbarrotar",
    "esbarrotaríeis": "esbarrotar",
    "esbarrotas": "esbarrotar",
    "esbarrotasse": "esbarrotar",
    "esbarrotassem": "esbarrotar",
    "esbarrotasses": "esbarrotar",
    "esbarrotaste": "esbarrotar",
    "esbarrotastes": "esbarrotar",
    "esbarrotava": "esbarrotar",
    "esbarrotavam": "esbarrotar",
    "esbarrotavas": "esbarrotar",
    "esbarrote": "esbarrotar",
    "esbarrotei": "esbarrotar",
    "esbarroteis": "esbarrotar",
    "esbarrotem": "esbarrotar",
    "esbarrotemo": "esbarrotar",
    "esbarrotemos": "esbarrotar",
    "esbarrotes": "esbarrotar",
    "esbarroto": "esbarrotar",
    "esbarrotou": "esbarrotar",
    "esbarrotámo": "esbarrotar",
    "esbarrotámos": "esbarrotar",
    "esbarrotáramo": "esbarrotar",
    "esbarrotáramos": "esbarrotar",
    "esbarrotáreis": "esbarrotar",
    "esbarrotásseis": "esbarrotar",
    "esbarrotássemos": "esbarrotar",
    "esbarrotávamo": "esbarrotar",
    "esbarrotávamos": "esbarrotar",
    "esbarrotáveis": "esbarrotar",
    "esbarrou": "esbarrar",
    "esbarrunta": "esbarruntar",
    "esbarruntada": "esbarruntar",
    "esbarruntadas": "esbarruntar",
    "esbarruntado": "esbarruntar",
    "esbarruntados": "esbarruntar",
    "esbarruntai": "esbarruntar",
    "esbarruntais": "esbarruntar",
    "esbarruntam": "esbarruntar",
    "esbarruntamo": "esbarruntar",
    "esbarruntamos": "esbarruntar",
    "esbarruntando": "esbarruntar",
    "esbarruntara": "esbarruntar",
    "esbarruntaram": "esbarruntar",
    "esbarruntaras": "esbarruntar",
    "esbarruntarde": "esbarruntar",
    "esbarruntardes": "esbarruntar",
    "esbarruntare": "esbarruntar",
    "esbarruntarei": "esbarruntar",
    "esbarruntareis": "esbarruntar",
    "esbarruntarem": "esbarruntar",
    "esbarruntaremos": "esbarruntar",
    "esbarruntares": "esbarruntar",
    "esbarruntaria": "esbarruntar",
    "esbarruntariam": "esbarruntar",
    "esbarruntarias": "esbarruntar",
    "esbarruntarmo": "esbarruntar",
    "esbarruntarmos": "esbarruntar",
    "esbarruntará": "esbarruntar",
    "esbarruntarás": "esbarruntar",
    "esbarruntarão": "esbarruntar",
    "esbarruntaríamos": "esbarruntar",
    "esbarruntaríeis": "esbarruntar",
    "esbarruntas": "esbarruntar",
    "esbarruntasse": "esbarruntar",
    "esbarruntassem": "esbarruntar",
    "esbarruntasses": "esbarruntar",
    "esbarruntaste": "esbarruntar",
    "esbarruntastes": "esbarruntar",
    "esbarruntava": "esbarruntar",
    "esbarruntavam": "esbarruntar",
    "esbarruntavas": "esbarruntar",
    "esbarrunte": "esbarruntar",
    "esbarruntei": "esbarruntar",
    "esbarrunteis": "esbarruntar",
    "esbarruntem": "esbarruntar",
    "esbarruntemo": "esbarruntar",
    "esbarruntemos": "esbarruntar",
    "esbarruntes": "esbarruntar",
    "esbarrunto": "esbarruntar",
    "esbarruntos": "esbarrunto",
    "esbarruntou": "esbarruntar",
    "esbarruntá": "esbarruntar",
    "esbarruntámo": "esbarruntar",
    "esbarruntámos": "esbarruntar",
    "esbarruntáramo": "esbarruntar",
    "esbarruntáramos": "esbarruntar",
    "esbarruntárei": "esbarruntar",
    "esbarruntáreis": "esbarruntar",
    "esbarruntásseis": "esbarruntar",
    "esbarruntássemos": "esbarruntar",
    "esbarruntávamo": "esbarruntar",
    "esbarruntávamos": "esbarruntar",
    "esbarruntávei": "esbarruntar",
    "esbarruntáveis": "esbarruntar",
    "esbarrámo": "esbarrar",
    "esbarrámos": "esbarrar",
    "esbarráramo": "esbarrar",
    "esbarráramos": "esbarrar",
    "esbarráreis": "esbarrar",
    "esbarrásseis": "esbarrar",
    "esbarrássemos": "esbarrar",
    "esbarrávamo": "esbarrar",
    "esbarrávamos": "esbarrar",
    "esbarráveis": "esbarrar",
    "esbata": "esbater",
    "esbatais": "esbater",
    "esbatam": "esbater",
    "esbatamo": "esbater",
    "esbatamos": "esbater",
    "esbatas": "esbater",
    "esbate": "esbater",
    "esbatei": "esbater",
    "esbateis": "esbater",
    "esbatem": "esbater",
    "esbatemo": "esbater",
    "esbatemos": "esbater",
    "esbatendo": "esbater",
    "esbatera": "esbater",
    "esbateram": "esbater",
    "esbateras": "esbater",
    "esbaterde": "esbater",
    "esbaterdes": "esbater",
    "esbatere": "esbater",
    "esbaterei": "esbater",
    "esbatereis": "esbater",
    "esbaterem": "esbater",
    "esbateremos": "esbater",
    "esbateres": "esbater",
    "esbateria": "esbater",
    "esbateriam": "esbater",
    "esbaterias": "esbater",
    "esbatermo": "esbater",
    "esbatermos": "esbater",
    "esbaterá": "esbater",
    "esbaterás": "esbater",
    "esbaterão": "esbater",
    "esbateríamos": "esbater",
    "esbateríeis": "esbater",
    "esbates": "esbater",
    "esbatesse": "esbater",
    "esbatessem": "esbater",
    "esbatesses": "esbater",
    "esbateste": "esbater",
    "esbatestes": "esbater",
    "esbateu": "esbater",
    "esbati": "esbater",
    "esbatia": "esbater",
    "esbatiam": "esbater",
    "esbatias": "esbater",
    "esbatida": "esbatido",
    "esbatidas": "esbatido",
    "esbatido": "esbater",
    "esbatidos": "esbatido",
    "esbatimentos": "esbatimento",
    "esbato": "esbater",
    "esbatê": "esbater",
    "esbatêramo": "esbater",
    "esbatêramos": "esbater",
    "esbatêrei": "esbater",
    "esbatêreis": "esbater",
    "esbatêsseis": "esbater",
    "esbatêssemos": "esbater",
    "esbatíamo": "esbater",
    "esbatíamos": "esbater",
    "esbatíei": "esbater",
    "esbatíeis": "esbater",
    "esbeice": "esbeiçar",
    "esbeicei": "esbeiçar",
    "esbeiceis": "esbeiçar",
    "esbeicem": "esbeiçar",
    "esbeicemo": "esbeiçar",
    "esbeicemos": "esbeiçar",
    "esbeices": "esbeiçar",
    "esbeiça": "esbeiçar",
    "esbeiçada": "esbeiçar",
    "esbeiçadas": "esbeiçar",
    "esbeiçado": "esbeiçar",
    "esbeiçados": "esbeiçar",
    "esbeiçai": "esbeiçar",
    "esbeiçais": "esbeiçar",
    "esbeiçam": "esbeiçar",
    "esbeiçamo": "esbeiçar",
    "esbeiçamos": "esbeiçar",
    "esbeiçando": "esbeiçar",
    "esbeiçara": "esbeiçar",
    "esbeiçaram": "esbeiçar",
    "esbeiçaras": "esbeiçar",
    "esbeiçardes": "esbeiçar",
    "esbeiçarei": "esbeiçar",
    "esbeiçareis": "esbeiçar",
    "esbeiçarem": "esbeiçar",
    "esbeiçaremos": "esbeiçar",
    "esbeiçares": "esbeiçar",
    "esbeiçaria": "esbeiçar",
    "esbeiçariam": "esbeiçar",
    "esbeiçarias": "esbeiçar",
    "esbeiçarmo": "esbeiçar",
    "esbeiçarmos": "esbeiçar",
    "esbeiçará": "esbeiçar",
    "esbeiçarás": "esbeiçar",
    "esbeiçarão": "esbeiçar",
    "esbeiçaríamos": "esbeiçar",
    "esbeiçaríeis": "esbeiçar",
    "esbeiças": "esbeiçar",
    "esbeiçasse": "esbeiçar",
    "esbeiçassem": "esbeiçar",
    "esbeiçasses": "esbeiçar",
    "esbeiçaste": "esbeiçar",
    "esbeiçastes": "esbeiçar",
    "esbeiçava": "esbeiçar",
    "esbeiçavam": "esbeiçar",
    "esbeiçavas": "esbeiçar",
    "esbeiço": "esbeiçar",
    "esbeiçou": "esbeiçar",
    "esbeiçámo": "esbeiçar",
    "esbeiçámos": "esbeiçar",
    "esbeiçáramo": "esbeiçar",
    "esbeiçáramos": "esbeiçar",
    "esbeiçáreis": "esbeiçar",
    "esbeiçásseis": "esbeiçar",
    "esbeiçássemos": "esbeiçar",
    "esbeiçávamo": "esbeiçar",
    "esbeiçávamos": "esbeiçar",
    "esbeiçáveis": "esbeiçar",
    "esbelta": "esbelto",
    "esbeltada": "esbeltar",
    "esbeltadas": "esbeltar",
    "esbeltado": "esbeltar",
    "esbeltados": "esbeltar",
    "esbeltai": "esbeltar",
    "esbeltais": "esbeltar",
    "esbeltam": "esbeltar",
    "esbeltamo": "esbeltar",
    "esbeltamos": "esbeltar",
    "esbeltando": "esbeltar",
    "esbeltara": "esbeltar",
    "esbeltaram": "esbeltar",
    "esbeltaras": "esbeltar",
    "esbeltarde": "esbeltar",
    "esbeltardes": "esbeltar",
    "esbeltare": "esbeltar",
    "esbeltarei": "esbeltar",
    "esbeltareis": "esbeltar",
    "esbeltarem": "esbeltar",
    "esbeltaremos": "esbeltar",
    "esbeltares": "esbeltar",
    "esbeltaria": "esbeltar",
    "esbeltariam": "esbeltar",
    "esbeltarias": "esbeltar",
    "esbeltarmo": "esbeltar",
    "esbeltarmos": "esbeltar",
    "esbeltará": "esbeltar",
    "esbeltarás": "esbeltar",
    "esbeltarão": "esbeltar",
    "esbeltaríamos": "esbeltar",
    "esbeltaríeis": "esbeltar",
    "esbeltas": "esbelto",
    "esbeltasse": "esbeltar",
    "esbeltassem": "esbeltar",
    "esbeltasses": "esbeltar",
    "esbeltaste": "esbeltar",
    "esbeltastes": "esbeltar",
    "esbeltava": "esbeltar",
    "esbeltavam": "esbeltar",
    "esbeltavas": "esbeltar",
    "esbelte": "esbeltar",
    "esbeltei": "esbeltar",
    "esbelteis": "esbeltar",
    "esbeltem": "esbeltar",
    "esbeltemo": "esbeltar",
    "esbeltemos": "esbeltar",
    "esbeltes": "esbeltar",
    "esbeltezas": "esbelteza",
    "esbelto": "esbeltar",
    "esbeltos": "esbelto",
    "esbeltou": "esbeltar",
    "esbeltá": "esbeltar",
    "esbeltámo": "esbeltar",
    "esbeltámos": "esbeltar",
    "esbeltáramo": "esbeltar",
    "esbeltáramos": "esbeltar",
    "esbeltárei": "esbeltar",
    "esbeltáreis": "esbeltar",
    "esbeltásseis": "esbeltar",
    "esbeltássemos": "esbeltar",
    "esbeltávamo": "esbeltar",
    "esbeltávamos": "esbeltar",
    "esbeltávei": "esbeltar",
    "esbeltáveis": "esbeltar",
    "esbeltíssima": "esbelto",
    "esbeltíssimas": "esbelto",
    "esbeltíssimo": "esbelto",
    "esbeltíssimos": "esbelto",
    "esbija": "esbijar",
    "esbijada": "esbijar",
    "esbijadas": "esbijar",
    "esbijado": "esbijar",
    "esbijados": "esbijar",
    "esbijai": "esbijar",
    "esbijais": "esbijar",
    "esbijam": "esbijar",
    "esbijamo": "esbijar",
    "esbijamos": "esbijar",
    "esbijando": "esbijar",
    "esbijara": "esbijar",
    "esbijaram": "esbijar",
    "esbijaras": "esbijar",
    "esbijarde": "esbijar",
    "esbijardes": "esbijar",
    "esbijare": "esbijar",
    "esbijarei": "esbijar",
    "esbijareis": "esbijar",
    "esbijarem": "esbijar",
    "esbijaremos": "esbijar",
    "esbijares": "esbijar",
    "esbijaria": "esbijar",
    "esbijariam": "esbijar",
    "esbijarias": "esbijar",
    "esbijarmo": "esbijar",
    "esbijarmos": "esbijar",
    "esbijará": "esbijar",
    "esbijarás": "esbijar",
    "esbijarão": "esbijar",
    "esbijaríamos": "esbijar",
    "esbijaríeis": "esbijar",
    "esbijas": "esbijar",
    "esbijasse": "esbijar",
    "esbijassem": "esbijar",
    "esbijasses": "esbijar",
    "esbijaste": "esbijar",
    "esbijastes": "esbijar",
    "esbijava": "esbijar",
    "esbijavam": "esbijar",
    "esbijavas": "esbijar",
    "esbije": "esbijar",
    "esbijei": "esbijar",
    "esbijeis": "esbijar",
    "esbijem": "esbijar",
    "esbijemo": "esbijar",
    "esbijemos": "esbijar",
    "esbijes": "esbijar",
    "esbijo": "esbijar",
    "esbijou": "esbijar",
    "esbijá": "esbijar",
    "esbijámo": "esbijar",
    "esbijámos": "esbijar",
    "esbijáramo": "esbijar",
    "esbijáramos": "esbijar",
    "esbijárei": "esbijar",
    "esbijáreis": "esbijar",
    "esbijásseis": "esbijar",
    "esbijássemos": "esbijar",
    "esbijávamo": "esbijar",
    "esbijávamos": "esbijar",
    "esbijávei": "esbijar",
    "esbijáveis": "esbijar",
    "esbilros": "esbilro",
    "esbirros": "esbirro",
    "esboce": "esboçar",
    "esbocei": "esboçar",
    "esboceis": "esboçar",
    "esbocela": "esbocelar",
    "esbocelada": "esbocelar",
    "esboceladas": "esbocelar",
    "esbocelado": "esbocelar",
    "esbocelados": "esbocelar",
    "esbocelai": "esbocelar",
    "esbocelais": "esbocelar",
    "esbocelam": "esbocelar",
    "esbocelamo": "esbocelar",
    "esbocelamos": "esbocelar",
    "esbocelando": "esbocelar",
    "esbocelara": "esbocelar",
    "esbocelaram": "esbocelar",
    "esbocelaras": "esbocelar",
    "esbocelarde": "esbocelar",
    "esbocelardes": "esbocelar",
    "esbocelare": "esbocelar",
    "esbocelarei": "esbocelar",
    "esbocelareis": "esbocelar",
    "esbocelarem": "esbocelar",
    "esbocelaremos": "esbocelar",
    "esbocelares": "esbocelar",
    "esbocelaria": "esbocelar",
    "esbocelariam": "esbocelar",
    "esbocelarias": "esbocelar",
    "esbocelarmo": "esbocelar",
    "esbocelarmos": "esbocelar",
    "esbocelará": "esbocelar",
    "esbocelarás": "esbocelar",
    "esbocelarão": "esbocelar",
    "esbocelaríamos": "esbocelar",
    "esbocelaríeis": "esbocelar",
    "esbocelas": "esbocelar",
    "esbocelasse": "esbocelar",
    "esbocelassem": "esbocelar",
    "esbocelasses": "esbocelar",
    "esbocelaste": "esbocelar",
    "esbocelastes": "esbocelar",
    "esbocelava": "esbocelar",
    "esbocelavam": "esbocelar",
    "esbocelavas": "esbocelar",
    "esbocele": "esbocelar",
    "esbocelei": "esbocelar",
    "esboceleis": "esbocelar",
    "esbocelem": "esbocelar",
    "esbocelemo": "esbocelar",
    "esbocelemos": "esbocelar",
    "esboceles": "esbocelar",
    "esbocelo": "esbocelar",
    "esbocelou": "esbocelar",
    "esbocelá": "esbocelar",
    "esbocelámo": "esbocelar",
    "esbocelámos": "esbocelar",
    "esboceláramo": "esbocelar",
    "esboceláramos": "esbocelar",
    "esbocelárei": "esbocelar",
    "esboceláreis": "esbocelar",
    "esbocelásseis": "esbocelar",
    "esbocelássemos": "esbocelar",
    "esbocelávamo": "esbocelar",
    "esbocelávamos": "esbocelar",
    "esbocelávei": "esbocelar",
    "esboceláveis": "esbocelar",
    "esbocem": "esboçar",
    "esbocemo": "esboçar",
    "esbocemos": "esboçar",
    "esboces": "esboçar",
    "esbocetos": "esboceto",
    "esbodega": "esbodegar",
    "esbodegada": "esbodegar",
    "esbodegadas": "esbodegar",
    "esbodegado": "esbodegar",
    "esbodegados": "esbodegar",
    "esbodegai": "esbodegar",
    "esbodegais": "esbodegar",
    "esbodegam": "esbodegar",
    "esbodegamo": "esbodegar",
    "esbodegamos": "esbodegar",
    "esbodegando": "esbodegar",
    "esbodegara": "esbodegar",
    "esbodegaram": "esbodegar",
    "esbodegaras": "esbodegar",
    "esbodegarde": "esbodegar",
    "esbodegardes": "esbodegar",
    "esbodegare": "esbodegar",
    "esbodegarei": "esbodegar",
    "esbodegareis": "esbodegar",
    "esbodegarem": "esbodegar",
    "esbodegaremos": "esbodegar",
    "esbodegares": "esbodegar",
    "esbodegaria": "esbodegar",
    "esbodegariam": "esbodegar",
    "esbodegarias": "esbodegar",
    "esbodegarmo": "esbodegar",
    "esbodegarmos": "esbodegar",
    "esbodegará": "esbodegar",
    "esbodegarás": "esbodegar",
    "esbodegarão": "esbodegar",
    "esbodegaríamos": "esbodegar",
    "esbodegaríeis": "esbodegar",
    "esbodegas": "esbodegar",
    "esbodegasse": "esbodegar",
    "esbodegassem": "esbodegar",
    "esbodegasses": "esbodegar",
    "esbodegaste": "esbodegar",
    "esbodegastes": "esbodegar",
    "esbodegava": "esbodegar",
    "esbodegavam": "esbodegar",
    "esbodegavas": "esbodegar",
    "esbodegações": "esbodegação",
    "esbodego": "esbodegar",
    "esbodegou": "esbodegar",
    "esbodegue": "esbodegar",
    "esbodeguei": "esbodegar",
    "esbodegueis": "esbodegar",
    "esbodeguem": "esbodegar",
    "esbodeguemo": "esbodegar",
    "esbodeguemos": "esbodegar",
    "esbodegues": "esbodegar",
    "esbodegá": "esbodegar",
    "esbodegámo": "esbodegar",
    "esbodegámos": "esbodegar",
    "esbodegáramo": "esbodegar",
    "esbodegáramos": "esbodegar",
    "esbodegárei": "esbodegar",
    "esbodegáreis": "esbodegar",
    "esbodegásseis": "esbodegar",
    "esbodegássemos": "esbodegar",
    "esbodegávamo": "esbodegar",
    "esbodegávamos": "esbodegar",
    "esbodegávei": "esbodegar",
    "esbodegáveis": "esbodegar",
    "esbofa": "esbofar",
    "esbofada": "esbofar",
    "esbofadas": "esbofar",
    "esbofado": "esbofar",
    "esbofados": "esbofar",
    "esbofai": "esbofar",
    "esbofais": "esbofar",
    "esbofam": "esbofar",
    "esbofamentos": "esbofamento",
    "esbofamo": "esbofar",
    "esbofamos": "esbofar",
    "esbofando": "esbofar",
    "esbofara": "esbofar",
    "esbofaram": "esbofar",
    "esbofaras": "esbofar",
    "esbofarde": "esbofar",
    "esbofardes": "esbofar",
    "esbofare": "esbofar",
    "esbofarei": "esbofar",
    "esbofareis": "esbofar",
    "esbofarem": "esbofar",
    "esbofaremos": "esbofar",
    "esbofares": "esbofar",
    "esbofaria": "esbofar",
    "esbofariam": "esbofar",
    "esbofarias": "esbofar",
    "esbofarmo": "esbofar",
    "esbofarmos": "esbofar",
    "esbofará": "esbofar",
    "esbofarás": "esbofar",
    "esbofarão": "esbofar",
    "esbofaríamos": "esbofar",
    "esbofaríeis": "esbofar",
    "esbofas": "esbofar",
    "esbofasse": "esbofar",
    "esbofassem": "esbofar",
    "esbofasses": "esbofar",
    "esbofaste": "esbofar",
    "esbofastes": "esbofar",
    "esbofava": "esbofar",
    "esbofavam": "esbofar",
    "esbofavas": "esbofar",
    "esbofe": "esbofar",
    "esbofei": "esbofar",
    "esbofeis": "esbofar",
    "esbofem": "esbofar",
    "esbofemo": "esbofar",
    "esbofemos": "esbofar",
    "esbofes": "esbofar",
    "esbofeteada": "esbofetear",
    "esbofeteadas": "esbofetear",
    "esbofeteado": "esbofetear",
    "esbofeteadora": "esbofeteador",
    "esbofeteadoras": "esbofeteador",
    "esbofeteadores": "esbofeteador",
    "esbofeteados": "esbofetear",
    "esbofeteai": "esbofetear",
    "esbofeteais": "esbofetear",
    "esbofeteamo": "esbofetear",
    "esbofeteamos": "esbofetear",
    "esbofeteando": "esbofetear",
    "esbofeteara": "esbofetear",
    "esbofetearam": "esbofetear",
    "esbofetearas": "esbofetear",
    "esbofetearde": "esbofetear",
    "esbofeteardes": "esbofetear",
    "esbofeteare": "esbofetear",
    "esbofetearei": "esbofetear",
    "esbofeteareis": "esbofetear",
    "esbofetearem": "esbofetear",
    "esbofetearemos": "esbofetear",
    "esbofeteares": "esbofetear",
    "esbofetearia": "esbofetear",
    "esbofeteariam": "esbofetear",
    "esbofetearias": "esbofetear",
    "esbofetearmo": "esbofetear",
    "esbofetearmos": "esbofetear",
    "esbofeteará": "esbofetear",
    "esbofetearás": "esbofetear",
    "esbofetearão": "esbofetear",
    "esbofetearíamos": "esbofetear",
    "esbofetearíeis": "esbofetear",
    "esbofeteasse": "esbofetear",
    "esbofeteassem": "esbofetear",
    "esbofeteasses": "esbofetear",
    "esbofeteaste": "esbofetear",
    "esbofeteastes": "esbofetear",
    "esbofeteava": "esbofetear",
    "esbofeteavam": "esbofetear",
    "esbofeteavas": "esbofetear",
    "esbofeteei": "esbofetear",
    "esbofeteeis": "esbofetear",
    "esbofeteemo": "esbofetear",
    "esbofeteemos": "esbofetear",
    "esbofeteia": "esbofetear",
    "esbofeteiam": "esbofetear",
    "esbofeteias": "esbofetear",
    "esbofeteie": "esbofetear",
    "esbofeteiem": "esbofetear",
    "esbofeteies": "esbofetear",
    "esbofeteio": "esbofetear",
    "esbofeteou": "esbofetear",
    "esbofeteá": "esbofetear",
    "esbofeteámo": "esbofetear",
    "esbofeteámos": "esbofetear",
    "esbofeteáramo": "esbofetear",
    "esbofeteáramos": "esbofetear",
    "esbofeteárei": "esbofetear",
    "esbofeteáreis": "esbofetear",
    "esbofeteásseis": "esbofetear",
    "esbofeteássemos": "esbofetear",
    "esbofeteávamo": "esbofetear",
    "esbofeteávamos": "esbofetear",
    "esbofeteávei": "esbofetear",
    "esbofeteáveis": "esbofetear",
    "esbofo": "esbofar",
    "esbofou": "esbofar",
    "esbofá": "esbofar",
    "esbofámo": "esbofar",
    "esbofámos": "esbofar",
    "esbofáramo": "esbofar",
    "esbofáramos": "esbofar",
    "esbofárei": "esbofar",
    "esbofáreis": "esbofar",
    "esbofásseis": "esbofar",
    "esbofássemos": "esbofar",
    "esbofávamo": "esbofar",
    "esbofávamos": "esbofar",
    "esbofávei": "esbofar",
    "esbofáveis": "esbofar",
    "esboice": "esboiçar",
    "esboicei": "esboiçar",
    "esboiceis": "esboiçar",
    "esboicela": "esboicelar",
    "esboicelada": "esboicelar",
    "esboiceladas": "esboicelar",
    "esboicelado": "esboicelar",
    "esboicelados": "esboicelar",
    "esboicelai": "esboicelar",
    "esboicelais": "esboicelar",
    "esboicelam": "esboicelar",
    "esboicelamo": "esboicelar",
    "esboicelamos": "esboicelar",
    "esboicelando": "esboicelar",
    "esboicelara": "esboicelar",
    "esboicelaram": "esboicelar",
    "esboicelaras": "esboicelar",
    "esboicelarde": "esboicelar",
    "esboicelardes": "esboicelar",
    "esboicelare": "esboicelar",
    "esboicelarei": "esboicelar",
    "esboicelareis": "esboicelar",
    "esboicelarem": "esboicelar",
    "esboicelaremos": "esboicelar",
    "esboicelares": "esboicelar",
    "esboicelaria": "esboicelar",
    "esboicelariam": "esboicelar",
    "esboicelarias": "esboicelar",
    "esboicelarmo": "esboicelar",
    "esboicelarmos": "esboicelar",
    "esboicelará": "esboicelar",
    "esboicelarás": "esboicelar",
    "esboicelarão": "esboicelar",
    "esboicelaríamos": "esboicelar",
    "esboicelaríeis": "esboicelar",
    "esboicelas": "esboicelar",
    "esboicelasse": "esboicelar",
    "esboicelassem": "esboicelar",
    "esboicelasses": "esboicelar",
    "esboicelaste": "esboicelar",
    "esboicelastes": "esboicelar",
    "esboicelava": "esboicelar",
    "esboicelavam": "esboicelar",
    "esboicelavas": "esboicelar",
    "esboicele": "esboicelar",
    "esboicelei": "esboicelar",
    "esboiceleis": "esboicelar",
    "esboicelem": "esboicelar",
    "esboicelemo": "esboicelar",
    "esboicelemos": "esboicelar",
    "esboiceles": "esboicelar",
    "esboicelo": "esboicelar",
    "esboicelou": "esboicelar",
    "esboicelá": "esboicelar",
    "esboicelámo": "esboicelar",
    "esboicelámos": "esboicelar",
    "esboiceláramo": "esboicelar",
    "esboiceláramos": "esboicelar",
    "esboicelárei": "esboicelar",
    "esboiceláreis": "esboicelar",
    "esboicelásseis": "esboicelar",
    "esboicelássemos": "esboicelar",
    "esboicelávamo": "esboicelar",
    "esboicelávamos": "esboicelar",
    "esboicelávei": "esboicelar",
    "esboiceláveis": "esboicelar",
    "esboicem": "esboiçar",
    "esboicemo": "esboiçar",
    "esboicemos": "esboiçar",
    "esboices": "esboiçar",
    "esboiça": "esboiçar",
    "esboiçada": "esboiçar",
    "esboiçadas": "esboiçar",
    "esboiçado": "esboiçar",
    "esboiçados": "esboiçar",
    "esboiçai": "esboiçar",
    "esboiçais": "esboiçar",
    "esboiçam": "esboiçar",
    "esboiçamo": "esboiçar",
    "esboiçamos": "esboiçar",
    "esboiçando": "esboiçar",
    "esboiçara": "esboiçar",
    "esboiçaram": "esboiçar",
    "esboiçaras": "esboiçar",
    "esboiçarde": "esboiçar",
    "esboiçardes": "esboiçar",
    "esboiçare": "esboiçar",
    "esboiçarei": "esboiçar",
    "esboiçareis": "esboiçar",
    "esboiçarem": "esboiçar",
    "esboiçaremos": "esboiçar",
    "esboiçares": "esboiçar",
    "esboiçaria": "esboiçar",
    "esboiçariam": "esboiçar",
    "esboiçarias": "esboiçar",
    "esboiçarmo": "esboiçar",
    "esboiçarmos": "esboiçar",
    "esboiçará": "esboiçar",
    "esboiçarás": "esboiçar",
    "esboiçarão": "esboiçar",
    "esboiçaríamos": "esboiçar",
    "esboiçaríeis": "esboiçar",
    "esboiças": "esboiçar",
    "esboiçasse": "esboiçar",
    "esboiçassem": "esboiçar",
    "esboiçasses": "esboiçar",
    "esboiçaste": "esboiçar",
    "esboiçastes": "esboiçar",
    "esboiçava": "esboiçar",
    "esboiçavam": "esboiçar",
    "esboiçavas": "esboiçar",
    "esboiço": "esboiçar",
    "esboiçou": "esboiçar",
    "esboiçá": "esboiçar",
    "esboiçámo": "esboiçar",
    "esboiçámos": "esboiçar",
    "esboiçáramo": "esboiçar",
    "esboiçáramos": "esboiçar",
    "esboiçárei": "esboiçar",
    "esboiçáreis": "esboiçar",
    "esboiçásseis": "esboiçar",
    "esboiçássemos": "esboiçar",
    "esboiçávamo": "esboiçar",
    "esboiçávamos": "esboiçar",
    "esboiçávei": "esboiçar",
    "esboiçáveis": "esboiçar",
    "esbombarda": "esbombardar",
    "esbombardada": "esbombardar",
    "esbombardadas": "esbombardar",
    "esbombardado": "esbombardar",
    "esbombardados": "esbombardar",
    "esbombardai": "esbombardar",
    "esbombardais": "esbombardar",
    "esbombardam": "esbombardar",
    "esbombardamo": "esbombardar",
    "esbombardamos": "esbombardar",
    "esbombardando": "esbombardar",
    "esbombardara": "esbombardar",
    "esbombardaram": "esbombardar",
    "esbombardaras": "esbombardar",
    "esbombardarde": "esbombardar",
    "esbombardardes": "esbombardar",
    "esbombardare": "esbombardar",
    "esbombardarei": "esbombardar",
    "esbombardareis": "esbombardar",
    "esbombardarem": "esbombardar",
    "esbombardaremos": "esbombardar",
    "esbombardares": "esbombardar",
    "esbombardaria": "esbombardar",
    "esbombardariam": "esbombardar",
    "esbombardarias": "esbombardar",
    "esbombardarmo": "esbombardar",
    "esbombardarmos": "esbombardar",
    "esbombardará": "esbombardar",
    "esbombardarás": "esbombardar",
    "esbombardarão": "esbombardar",
    "esbombardaríamos": "esbombardar",
    "esbombardaríeis": "esbombardar",
    "esbombardas": "esbombardar",
    "esbombardasse": "esbombardar",
    "esbombardassem": "esbombardar",
    "esbombardasses": "esbombardar",
    "esbombardaste": "esbombardar",
    "esbombardastes": "esbombardar",
    "esbombardava": "esbombardar",
    "esbombardavam": "esbombardar",
    "esbombardavas": "esbombardar",
    "esbombarde": "esbombardar",
    "esbombardeada": "esbombardear",
    "esbombardeadas": "esbombardear",
    "esbombardeado": "esbombardear",
    "esbombardeados": "esbombardear",
    "esbombardeai": "esbombardear",
    "esbombardeais": "esbombardear",
    "esbombardeamo": "esbombardear",
    "esbombardeamos": "esbombardear",
    "esbombardeando": "esbombardear",
    "esbombardeara": "esbombardear",
    "esbombardearam": "esbombardear",
    "esbombardearas": "esbombardear",
    "esbombardearde": "esbombardear",
    "esbombardeardes": "esbombardear",
    "esbombardeare": "esbombardear",
    "esbombardearei": "esbombardear",
    "esbombardeareis": "esbombardear",
    "esbombardearem": "esbombardear",
    "esbombardearemos": "esbombardear",
    "esbombardeares": "esbombardear",
    "esbombardearia": "esbombardear",
    "esbombardeariam": "esbombardear",
    "esbombardearias": "esbombardear",
    "esbombardearmo": "esbombardear",
    "esbombardearmos": "esbombardear",
    "esbombardeará": "esbombardear",
    "esbombardearás": "esbombardear",
    "esbombardearão": "esbombardear",
    "esbombardearíamos": "esbombardear",
    "esbombardearíeis": "esbombardear",
    "esbombardeasse": "esbombardear",
    "esbombardeassem": "esbombardear",
    "esbombardeasses": "esbombardear",
    "esbombardeaste": "esbombardear",
    "esbombardeastes": "esbombardear",
    "esbombardeava": "esbombardear",
    "esbombardeavam": "esbombardear",
    "esbombardeavas": "esbombardear",
    "esbombardeei": "esbombardear",
    "esbombardeeis": "esbombardear",
    "esbombardeemo": "esbombardear",
    "esbombardeemos": "esbombardear",
    "esbombardei": "esbombardar",
    "esbombardeia": "esbombardear",
    "esbombardeiam": "esbombardear",
    "esbombardeias": "esbombardear",
    "esbombardeie": "esbombardear",
    "esbombardeiem": "esbombardear",
    "esbombardeies": "esbombardear",
    "esbombardeio": "esbombardear",
    "esbombardeis": "esbombardar",
    "esbombardem": "esbombardar",
    "esbombardemo": "esbombardar",
    "esbombardemos": "esbombardar",
    "esbombardeou": "esbombardear",
    "esbombardes": "esbombardar",
    "esbombardeá": "esbombardear",
    "esbombardeámo": "esbombardear",
    "esbombardeámos": "esbombardear",
    "esbombardeáramo": "esbombardear",
    "esbombardeáramos": "esbombardear",
    "esbombardeárei": "esbombardear",
    "esbombardeáreis": "esbombardear",
    "esbombardeásseis": "esbombardear",
    "esbombardeássemos": "esbombardear",
    "esbombardeávamo": "esbombardear",
    "esbombardeávamos": "esbombardear",
    "esbombardeávei": "esbombardear",
    "esbombardeáveis": "esbombardear",
    "esbombardo": "esbombardar",
    "esbombardou": "esbombardar",
    "esbombardá": "esbombardar",
    "esbombardámo": "esbombardar",
    "esbombardámos": "esbombardar",
    "esbombardáramo": "esbombardar",
    "esbombardáramos": "esbombardar",
    "esbombardárei": "esbombardar",
    "esbombardáreis": "esbombardar",
    "esbombardásseis": "esbombardar",
    "esbombardássemos": "esbombardar",
    "esbombardávamo": "esbombardar",
    "esbombardávamos": "esbombardar",
    "esbombardávei": "esbombardar",
    "esbombardáveis": "esbombardar",
    "esborcela": "esborcelar",
    "esborcelada": "esborcelar",
    "esborceladas": "esborcelar",
    "esborcelado": "esborcelar",
    "esborcelados": "esborcelar",
    "esborcelai": "esborcelar",
    "esborcelais": "esborcelar",
    "esborcelam": "esborcelar",
    "esborcelamo": "esborcelar",
    "esborcelamos": "esborcelar",
    "esborcelando": "esborcelar",
    "esborcelara": "esborcelar",
    "esborcelaram": "esborcelar",
    "esborcelaras": "esborcelar",
    "esborcelarde": "esborcelar",
    "esborcelardes": "esborcelar",
    "esborcelare": "esborcelar",
    "esborcelarei": "esborcelar",
    "esborcelareis": "esborcelar",
    "esborcelarem": "esborcelar",
    "esborcelaremos": "esborcelar",
    "esborcelares": "esborcelar",
    "esborcelaria": "esborcelar",
    "esborcelariam": "esborcelar",
    "esborcelarias": "esborcelar",
    "esborcelarmo": "esborcelar",
    "esborcelarmos": "esborcelar",
    "esborcelará": "esborcelar",
    "esborcelarás": "esborcelar",
    "esborcelarão": "esborcelar",
    "esborcelaríamos": "esborcelar",
    "esborcelaríeis": "esborcelar",
    "esborcelas": "esborcelar",
    "esborcelasse": "esborcelar",
    "esborcelassem": "esborcelar",
    "esborcelasses": "esborcelar",
    "esborcelaste": "esborcelar",
    "esborcelastes": "esborcelar",
    "esborcelava": "esborcelar",
    "esborcelavam": "esborcelar",
    "esborcelavas": "esborcelar",
    "esborcele": "esborcelar",
    "esborcelei": "esborcelar",
    "esborceleis": "esborcelar",
    "esborcelem": "esborcelar",
    "esborcelemo": "esborcelar",
    "esborcelemos": "esborcelar",
    "esborceles": "esborcelar",
    "esborcelo": "esborcelar",
    "esborcelou": "esborcelar",
    "esborcelá": "esborcelar",
    "esborcelámo": "esborcelar",
    "esborcelámos": "esborcelar",
    "esborceláramo": "esborcelar",
    "esborceláramos": "esborcelar",
    "esborcelárei": "esborcelar",
    "esborceláreis": "esborcelar",
    "esborcelásseis": "esborcelar",
    "esborcelássemos": "esborcelar",
    "esborcelávamo": "esborcelar",
    "esborcelávamos": "esborcelar",
    "esborcelávei": "esborcelar",
    "esborceláveis": "esborcelar",
    "esborcina": "esborcinar",
    "esborcinada": "esborcinar",
    "esborcinadas": "esborcinar",
    "esborcinado": "esborcinar",
    "esborcinados": "esborcinar",
    "esborcinai": "esborcinar",
    "esborcinais": "esborcinar",
    "esborcinam": "esborcinar",
    "esborcinamo": "esborcinar",
    "esborcinamos": "esborcinar",
    "esborcinando": "esborcinar",
    "esborcinara": "esborcinar",
    "esborcinaram": "esborcinar",
    "esborcinaras": "esborcinar",
    "esborcinarde": "esborcinar",
    "esborcinardes": "esborcinar",
    "esborcinare": "esborcinar",
    "esborcinarei": "esborcinar",
    "esborcinareis": "esborcinar",
    "esborcinarem": "esborcinar",
    "esborcinaremos": "esborcinar",
    "esborcinares": "esborcinar",
    "esborcinaria": "esborcinar",
    "esborcinariam": "esborcinar",
    "esborcinarias": "esborcinar",
    "esborcinarmo": "esborcinar",
    "esborcinarmos": "esborcinar",
    "esborcinará": "esborcinar",
    "esborcinarás": "esborcinar",
    "esborcinarão": "esborcinar",
    "esborcinaríamos": "esborcinar",
    "esborcinaríeis": "esborcinar",
    "esborcinas": "esborcinar",
    "esborcinasse": "esborcinar",
    "esborcinassem": "esborcinar",
    "esborcinasses": "esborcinar",
    "esborcinaste": "esborcinar",
    "esborcinastes": "esborcinar",
    "esborcinava": "esborcinar",
    "esborcinavam": "esborcinar",
    "esborcinavas": "esborcinar",
    "esborcine": "esborcinar",
    "esborcinei": "esborcinar",
    "esborcineis": "esborcinar",
    "esborcinem": "esborcinar",
    "esborcinemo": "esborcinar",
    "esborcinemos": "esborcinar",
    "esborcines": "esborcinar",
    "esborcino": "esborcinar",
    "esborcinou": "esborcinar",
    "esborciná": "esborcinar",
    "esborcinámo": "esborcinar",
    "esborcinámos": "esborcinar",
    "esborcináramo": "esborcinar",
    "esborcináramos": "esborcinar",
    "esborcinárei": "esborcinar",
    "esborcináreis": "esborcinar",
    "esborcinásseis": "esborcinar",
    "esborcinássemos": "esborcinar",
    "esborcinávamo": "esborcinar",
    "esborcinávamos": "esborcinar",
    "esborcinávei": "esborcinar",
    "esborcináveis": "esborcinar",
    "esborda": "esbordar",
    "esbordada": "esbordar",
    "esbordadas": "esbordar",
    "esbordado": "esbordar",
    "esbordados": "esbordar",
    "esbordai": "esbordar",
    "esbordais": "esbordar",
    "esbordam": "esbordar",
    "esbordamo": "esbordar",
    "esbordamos": "esbordar",
    "esbordando": "esbordar",
    "esbordara": "esbordar",
    "esbordaram": "esbordar",
    "esbordaras": "esbordar",
    "esbordardes": "esbordar",
    "esbordarei": "esbordar",
    "esbordareis": "esbordar",
    "esbordarem": "esbordar",
    "esbordaremos": "esbordar",
    "esbordares": "esbordar",
    "esbordaria": "esbordar",
    "esbordariam": "esbordar",
    "esbordarias": "esbordar",
    "esbordarmo": "esbordar",
    "esbordarmos": "esbordar",
    "esbordará": "esbordar",
    "esbordarás": "esbordar",
    "esbordarão": "esbordar",
    "esbordaríamos": "esbordar",
    "esbordaríeis": "esbordar",
    "esbordas": "esbordar",
    "esbordasse": "esbordar",
    "esbordassem": "esbordar",
    "esbordasses": "esbordar",
    "esbordaste": "esbordar",
    "esbordastes": "esbordar",
    "esbordava": "esbordar",
    "esbordavam": "esbordar",
    "esbordavas": "esbordar",
    "esborde": "esbordar",
    "esbordei": "esbordar",
    "esbordeis": "esbordar",
    "esbordem": "esbordar",
    "esbordemo": "esbordar",
    "esbordemos": "esbordar",
    "esbordes": "esbordar",
    "esbordo": "esbordar",
    "esbordoa": "esbordoar",
    "esbordoada": "esbordoar",
    "esbordoadas": "esbordoar",
    "esbordoado": "esbordoar",
    "esbordoados": "esbordoar",
    "esbordoai": "esbordoar",
    "esbordoais": "esbordoar",
    "esbordoam": "esbordoar",
    "esbordoamo": "esbordoar",
    "esbordoamos": "esbordoar",
    "esbordoando": "esbordoar",
    "esbordoara": "esbordoar",
    "esbordoaram": "esbordoar",
    "esbordoaras": "esbordoar",
    "esbordoarde": "esbordoar",
    "esbordoardes": "esbordoar",
    "esbordoare": "esbordoar",
    "esbordoarei": "esbordoar",
    "esbordoareis": "esbordoar",
    "esbordoarem": "esbordoar",
    "esbordoaremos": "esbordoar",
    "esbordoares": "esbordoar",
    "esbordoaria": "esbordoar",
    "esbordoariam": "esbordoar",
    "esbordoarias": "esbordoar",
    "esbordoarmo": "esbordoar",
    "esbordoarmos": "esbordoar",
    "esbordoará": "esbordoar",
    "esbordoarás": "esbordoar",
    "esbordoarão": "esbordoar",
    "esbordoaríamos": "esbordoar",
    "esbordoaríeis": "esbordoar",
    "esbordoas": "esbordoar",
    "esbordoasse": "esbordoar",
    "esbordoassem": "esbordoar",
    "esbordoasses": "esbordoar",
    "esbordoaste": "esbordoar",
    "esbordoastes": "esbordoar",
    "esbordoava": "esbordoar",
    "esbordoavam": "esbordoar",
    "esbordoavas": "esbordoar",
    "esbordoe": "esbordoar",
    "esbordoei": "esbordoar",
    "esbordoeis": "esbordoar",
    "esbordoem": "esbordoar",
    "esbordoemo": "esbordoar",
    "esbordoemos": "esbordoar",
    "esbordoes": "esbordoar",
    "esbordoo": "esbordoar",
    "esbordoou": "esbordoar",
    "esbordou": "esbordar",
    "esbordoá": "esbordoar",
    "esbordoámo": "esbordoar",
    "esbordoámos": "esbordoar",
    "esbordoáramo": "esbordoar",
    "esbordoáramos": "esbordoar",
    "esbordoárei": "esbordoar",
    "esbordoáreis": "esbordoar",
    "esbordoásseis": "esbordoar",
    "esbordoássemos": "esbordoar",
    "esbordoávamo": "esbordoar",
    "esbordoávamos": "esbordoar",
    "esbordoávei": "esbordoar",
    "esbordoáveis": "esbordoar",
    "esbordámo": "esbordar",
    "esbordámos": "esbordar",
    "esbordáramo": "esbordar",
    "esbordáramos": "esbordar",
    "esbordáreis": "esbordar",
    "esbordásseis": "esbordar",
    "esbordássemos": "esbordar",
    "esbordávamo": "esbordar",
    "esbordávamos": "esbordar",
    "esbordáveis": "esbordar",
    "esboroa": "esboroar",
    "esboroada": "esboroar",
    "esboroadas": "esboroar",
    "esboroado": "esboroar",
    "esboroados": "esboroar",
    "esboroai": "esboroar",
    "esboroais": "esboroar",
    "esboroam": "esboroar",
    "esboroamentos": "esboroamento",
    "esboroamo": "esboroar",
    "esboroamos": "esboroar",
    "esboroando": "esboroar",
    "esboroara": "esboroar",
    "esboroaram": "esboroar",
    "esboroaras": "esboroar",
    "esboroarde": "esboroar",
    "esboroardes": "esboroar",
    "esboroare": "esboroar",
    "esboroarei": "esboroar",
    "esboroareis": "esboroar",
    "esboroarem": "esboroar",
    "esboroaremos": "esboroar",
    "esboroares": "esboroar",
    "esboroaria": "esboroar",
    "esboroariam": "esboroar",
    "esboroarias": "esboroar",
    "esboroarmo": "esboroar",
    "esboroarmos": "esboroar",
    "esboroará": "esboroar",
    "esboroarás": "esboroar",
    "esboroarão": "esboroar",
    "esboroaríamos": "esboroar",
    "esboroaríeis": "esboroar",
    "esboroas": "esboroar",
    "esboroasse": "esboroar",
    "esboroassem": "esboroar",
    "esboroasses": "esboroar",
    "esboroaste": "esboroar",
    "esboroastes": "esboroar",
    "esboroava": "esboroar",
    "esboroavam": "esboroar",
    "esboroavas": "esboroar",
    "esboroe": "esboroar",
    "esboroei": "esboroar",
    "esboroeis": "esboroar",
    "esboroem": "esboroar",
    "esboroemo": "esboroar",
    "esboroemos": "esboroar",
    "esboroes": "esboroar",
    "esboroo": "esboroar",
    "esboroos": "esboroo",
    "esboroou": "esboroar",
    "esboroá": "esboroar",
    "esboroámo": "esboroar",
    "esboroámos": "esboroar",
    "esboroáramo": "esboroar",
    "esboroáramos": "esboroar",
    "esboroárei": "esboroar",
    "esboroáreis": "esboroar",
    "esboroásseis": "esboroar",
    "esboroássemos": "esboroar",
    "esboroávamo": "esboroar",
    "esboroávamos": "esboroar",
    "esboroávei": "esboroar",
    "esboroáveis": "esboroar",
    "esborra": "esborrar",
    "esborrace": "esborraçar",
    "esborracei": "esborraçar",
    "esborraceis": "esborraçar",
    "esborracem": "esborraçar",
    "esborracemo": "esborraçar",
    "esborracemos": "esborraçar",
    "esborraces": "esborraçar",
    "esborracha": "esborrachar",
    "esborrachada": "esborrachar",
    "esborrachadas": "esborrachar",
    "esborrachado": "esborrachar",
    "esborrachados": "esborrachar",
    "esborrachai": "esborrachar",
    "esborrachais": "esborrachar",
    "esborracham": "esborrachar",
    "esborrachamo": "esborrachar",
    "esborrachamos": "esborrachar",
    "esborrachando": "esborrachar",
    "esborrachara": "esborrachar",
    "esborracharam": "esborrachar",
    "esborracharas": "esborrachar",
    "esborracharde": "esborrachar",
    "esborrachardes": "esborrachar",
    "esborrachare": "esborrachar",
    "esborracharei": "esborrachar",
    "esborrachareis": "esborrachar",
    "esborracharem": "esborrachar",
    "esborracharemos": "esborrachar",
    "esborrachares": "esborrachar",
    "esborracharia": "esborrachar",
    "esborrachariam": "esborrachar",
    "esborracharias": "esborrachar",
    "esborracharmo": "esborrachar",
    "esborracharmos": "esborrachar",
    "esborrachará": "esborrachar",
    "esborracharás": "esborrachar",
    "esborracharão": "esborrachar",
    "esborracharíamos": "esborrachar",
    "esborracharíeis": "esborrachar",
    "esborrachas": "esborrachar",
    "esborrachasse": "esborrachar",
    "esborrachassem": "esborrachar",
    "esborrachasses": "esborrachar",
    "esborrachaste": "esborrachar",
    "esborrachastes": "esborrachar",
    "esborrachava": "esborrachar",
    "esborrachavam": "esborrachar",
    "esborrachavas": "esborrachar",
    "esborrache": "esborrachar",
    "esborrachei": "esborrachar",
    "esborracheis": "esborrachar",
    "esborrachem": "esborrachar",
    "esborrachemo": "esborrachar",
    "esborrachemos": "esborrachar",
    "esborraches": "esborrachar",
    "esborracho": "esborrachar",
    "esborrachou": "esborrachar",
    "esborrachá": "esborrachar",
    "esborrachámo": "esborrachar",
    "esborrachámos": "esborrachar",
    "esborracháramo": "esborrachar",
    "esborracháramos": "esborrachar",
    "esborrachárei": "esborrachar",
    "esborracháreis": "esborrachar",
    "esborrachásseis": "esborrachar",
    "esborrachássemos": "esborrachar",
    "esborrachávamo": "esborrachar",
    "esborrachávamos": "esborrachar",
    "esborrachávei": "esborrachar",
    "esborracháveis": "esborrachar",
    "esborrada": "esborrar",
    "esborradas": "esborrar",
    "esborrado": "esborrar",
    "esborrados": "esborrar",
    "esborrai": "esborrar",
    "esborrais": "esborrar",
    "esborralha": "esborralhar",
    "esborralhada": "esborralhar",
    "esborralhadas": "esborralhar",
    "esborralhado": "esborralhar",
    "esborralhadoiros": "esborralhadoiro",
    "esborralhadora": "esborralhador",
    "esborralhadoras": "esborralhador",
    "esborralhadores": "esborralhador",
    "esborralhados": "esborralhar",
    "esborralhadouros": "esborralhadouro",
    "esborralhai": "esborralhar",
    "esborralhais": "esborralhar",
    "esborralham": "esborralhar",
    "esborralhamo": "esborralhar",
    "esborralhamos": "esborralhar",
    "esborralhando": "esborralhar",
    "esborralhara": "esborralhar",
    "esborralharam": "esborralhar",
    "esborralharas": "esborralhar",
    "esborralharde": "esborralhar",
    "esborralhardes": "esborralhar",
    "esborralhare": "esborralhar",
    "esborralharei": "esborralhar",
    "esborralhareis": "esborralhar",
    "esborralharem": "esborralhar",
    "esborralharemos": "esborralhar",
    "esborralhares": "esborralhar",
    "esborralharia": "esborralhar",
    "esborralhariam": "esborralhar",
    "esborralharias": "esborralhar",
    "esborralharmo": "esborralhar",
    "esborralharmos": "esborralhar",
    "esborralhará": "esborralhar",
    "esborralharás": "esborralhar",
    "esborralharão": "esborralhar",
    "esborralharíamos": "esborralhar",
    "esborralharíeis": "esborralhar",
    "esborralhas": "esborralhar",
    "esborralhasse": "esborralhar",
    "esborralhassem": "esborralhar",
    "esborralhasses": "esborralhar",
    "esborralhaste": "esborralhar",
    "esborralhastes": "esborralhar",
    "esborralhava": "esborralhar",
    "esborralhavam": "esborralhar",
    "esborralhavas": "esborralhar",
    "esborralhe": "esborralhar",
    "esborralhei": "esborralhar",
    "esborralheis": "esborralhar",
    "esborralhem": "esborralhar",
    "esborralhemo": "esborralhar",
    "esborralhemos": "esborralhar",
    "esborralhes": "esborralhar",
    "esborralho": "esborralhar",
    "esborralhou": "esborralhar",
    "esborralhá": "esborralhar",
    "esborralhámo": "esborralhar",
    "esborralhámos": "esborralhar",
    "esborralháramo": "esborralhar",
    "esborralháramos": "esborralhar",
    "esborralhárei": "esborralhar",
    "esborralháreis": "esborralhar",
    "esborralhásseis": "esborralhar",
    "esborralhássemos": "esborralhar",
    "esborralhávamo": "esborralhar",
    "esborralhávamos": "esborralhar",
    "esborralhávei": "esborralhar",
    "esborralháveis": "esborralhar",
    "esborram": "esborrar",
    "esborramo": "esborrar",
    "esborramos": "esborrar",
    "esborrando": "esborrar",
    "esborrara": "esborrar",
    "esborraram": "esborrar",
    "esborraras": "esborrar",
    "esborrarde": "esborrar",
    "esborrardes": "esborrar",
    "esborrare": "esborrar",
    "esborrarei": "esborrar",
    "esborrareis": "esborrar",
    "esborrarem": "esborrar",
    "esborraremos": "esborrar",
    "esborrares": "esborrar",
    "esborraria": "esborrar",
    "esborrariam": "esborrar",
    "esborrarias": "esborrar",
    "esborrarmo": "esborrar",
    "esborrarmos": "esborrar",
    "esborrará": "esborrar",
    "esborrarás": "esborrar",
    "esborrarão": "esborrar",
    "esborraríamos": "esborrar",
    "esborraríeis": "esborrar",
    "esborras": "esborrar",
    "esborrasse": "esborrar",
    "esborrassem": "esborrar",
    "esborrasses": "esborrar",
    "esborraste": "esborrar",
    "esborrastes": "esborrar",
    "esborrata": "esborratar",
    "esborratada": "esborratar",
    "esborratadas": "esborratar",
    "esborratadelas": "esborratadela",
    "esborratado": "esborratar",
    "esborratados": "esborratar",
    "esborratai": "esborratar",
    "esborratais": "esborratar",
    "esborratam": "esborratar",
    "esborratamo": "esborratar",
    "esborratamos": "esborratar",
    "esborratando": "esborratar",
    "esborratara": "esborratar",
    "esborrataram": "esborratar",
    "esborrataras": "esborratar",
    "esborratarde": "esborratar",
    "esborratardes": "esborratar",
    "esborratare": "esborratar",
    "esborratarei": "esborratar",
    "esborratareis": "esborratar",
    "esborratarem": "esborratar",
    "esborrataremos": "esborratar",
    "esborratares": "esborratar",
    "esborrataria": "esborratar",
    "esborratariam": "esborratar",
    "esborratarias": "esborratar",
    "esborratarmo": "esborratar",
    "esborratarmos": "esborratar",
    "esborratará": "esborratar",
    "esborratarás": "esborratar",
    "esborratarão": "esborratar",
    "esborrataríamos": "esborratar",
    "esborrataríeis": "esborratar",
    "esborratas": "esborratar",
    "esborratasse": "esborratar",
    "esborratassem": "esborratar",
    "esborratasses": "esborratar",
    "esborrataste": "esborratar",
    "esborratastes": "esborratar",
    "esborratava": "esborratar",
    "esborratavam": "esborratar",
    "esborratavas": "esborratar",
    "esborrate": "esborratar",
    "esborratei": "esborratar",
    "esborrateis": "esborratar",
    "esborratem": "esborratar",
    "esborratemo": "esborratar",
    "esborratemos": "esborratar",
    "esborrates": "esborratar",
    "esborrato": "esborratar",
    "esborratou": "esborratar",
    "esborratá": "esborratar",
    "esborratámo": "esborratar",
    "esborratámos": "esborratar",
    "esborratáramo": "esborratar",
    "esborratáramos": "esborratar",
    "esborratárei": "esborratar",
    "esborratáreis": "esborratar",
    "esborratásseis": "esborratar",
    "esborratássemos": "esborratar",
    "esborratávamo": "esborratar",
    "esborratávamos": "esborratar",
    "esborratávei": "esborratar",
    "esborratáveis": "esborratar",
    "esborrava": "esborrar",
    "esborravam": "esborrar",
    "esborravas": "esborrar",
    "esborraça": "esborraçar",
    "esborraçada": "esborraçar",
    "esborraçadas": "esborraçar",
    "esborraçado": "esborraçar",
    "esborraçados": "esborraçar",
    "esborraçai": "esborraçar",
    "esborraçais": "esborraçar",
    "esborraçam": "esborraçar",
    "esborraçamo": "esborraçar",
    "esborraçamos": "esborraçar",
    "esborraçando": "esborraçar",
    "esborraçara": "esborraçar",
    "esborraçaram": "esborraçar",
    "esborraçaras": "esborraçar",
    "esborraçarde": "esborraçar",
    "esborraçardes": "esborraçar",
    "esborraçare": "esborraçar",
    "esborraçarei": "esborraçar",
    "esborraçareis": "esborraçar",
    "esborraçarem": "esborraçar",
    "esborraçaremos": "esborraçar",
    "esborraçares": "esborraçar",
    "esborraçaria": "esborraçar",
    "esborraçariam": "esborraçar",
    "esborraçarias": "esborraçar",
    "esborraçarmo": "esborraçar",
    "esborraçarmos": "esborraçar",
    "esborraçará": "esborraçar",
    "esborraçarás": "esborraçar",
    "esborraçarão": "esborraçar",
    "esborraçaríamos": "esborraçar",
    "esborraçaríeis": "esborraçar",
    "esborraças": "esborraçar",
    "esborraçasse": "esborraçar",
    "esborraçassem": "esborraçar",
    "esborraçasses": "esborraçar",
    "esborraçaste": "esborraçar",
    "esborraçastes": "esborraçar",
    "esborraçava": "esborraçar",
    "esborraçavam": "esborraçar",
    "esborraçavas": "esborraçar",
    "esborraço": "esborraçar",
    "esborraçou": "esborraçar",
    "esborraçá": "esborraçar",
    "esborraçámo": "esborraçar",
    "esborraçámos": "esborraçar",
    "esborraçáramo": "esborraçar",
    "esborraçáramos": "esborraçar",
    "esborraçárei": "esborraçar",
    "esborraçáreis": "esborraçar",
    "esborraçásseis": "esborraçar",
    "esborraçássemos": "esborraçar",
    "esborraçávamo": "esborraçar",
    "esborraçávamos": "esborraçar",
    "esborraçávei": "esborraçar",
    "esborraçáveis": "esborraçar",
    "esborre": "esborrar",
    "esborrega": "esborregar",
    "esborregada": "esborregar",
    "esborregadas": "esborregar",
    "esborregado": "esborregar",
    "esborregados": "esborregar",
    "esborregai": "esborregar",
    "esborregais": "esborregar",
    "esborregam": "esborregar",
    "esborregamo": "esborregar",
    "esborregamos": "esborregar",
    "esborregando": "esborregar",
    "esborregara": "esborregar",
    "esborregaram": "esborregar",
    "esborregaras": "esborregar",
    "esborregarde": "esborregar",
    "esborregardes": "esborregar",
    "esborregare": "esborregar",
    "esborregarei": "esborregar",
    "esborregareis": "esborregar",
    "esborregarem": "esborregar",
    "esborregaremos": "esborregar",
    "esborregares": "esborregar",
    "esborregaria": "esborregar",
    "esborregariam": "esborregar",
    "esborregarias": "esborregar",
    "esborregarmo": "esborregar",
    "esborregarmos": "esborregar",
    "esborregará": "esborregar",
    "esborregarás": "esborregar",
    "esborregarão": "esborregar",
    "esborregaríamos": "esborregar",
    "esborregaríeis": "esborregar",
    "esborregas": "esborregar",
    "esborregasse": "esborregar",
    "esborregassem": "esborregar",
    "esborregasses": "esborregar",
    "esborregaste": "esborregar",
    "esborregastes": "esborregar",
    "esborregava": "esborregar",
    "esborregavam": "esborregar",
    "esborregavas": "esborregar",
    "esborrego": "esborregar",
    "esborregou": "esborregar",
    "esborregue": "esborregar",
    "esborreguei": "esborregar",
    "esborregueis": "esborregar",
    "esborreguem": "esborregar",
    "esborreguemo": "esborregar",
    "esborreguemos": "esborregar",
    "esborregues": "esborregar",
    "esborregá": "esborregar",
    "esborregámo": "esborregar",
    "esborregámos": "esborregar",
    "esborregáramo": "esborregar",
    "esborregáramos": "esborregar",
    "esborregárei": "esborregar",
    "esborregáreis": "esborregar",
    "esborregásseis": "esborregar",
    "esborregássemos": "esborregar",
    "esborregávamo": "esborregar",
    "esborregávamos": "esborregar",
    "esborregávei": "esborregar",
    "esborregáveis": "esborregar",
    "esborrei": "esborrar",
    "esborreis": "esborrar",
    "esborrem": "esborrar",
    "esborremo": "esborrar",
    "esborremos": "esborrar",
    "esborres": "esborrar",
    "esborro": "esborrar",
    "esborrou": "esborrar",
    "esborrá": "esborrar",
    "esborrámo": "esborrar",
    "esborrámos": "esborrar",
    "esborráramo": "esborrar",
    "esborráramos": "esborrar",
    "esborrárei": "esborrar",
    "esborráreis": "esborrar",
    "esborrásseis": "esborrar",
    "esborrássemos": "esborrar",
    "esborrávamo": "esborrar",
    "esborrávamos": "esborrar",
    "esborrávei": "esborrar",
    "esborráveis": "esborrar",
    "esbotena": "esbotenar",
    "esbotenada": "esbotenar",
    "esbotenadas": "esbotenar",
    "esbotenado": "esbotenar",
    "esbotenados": "esbotenar",
    "esbotenai": "esbotenar",
    "esbotenais": "esbotenar",
    "esbotenam": "esbotenar",
    "esbotenamo": "esbotenar",
    "esbotenamos": "esbotenar",
    "esbotenando": "esbotenar",
    "esbotenara": "esbotenar",
    "esbotenaram": "esbotenar",
    "esbotenaras": "esbotenar",
    "esbotenarde": "esbotenar",
    "esbotenardes": "esbotenar",
    "esbotenare": "esbotenar",
    "esbotenarei": "esbotenar",
    "esbotenareis": "esbotenar",
    "esbotenarem": "esbotenar",
    "esbotenaremos": "esbotenar",
    "esbotenares": "esbotenar",
    "esbotenaria": "esbotenar",
    "esbotenariam": "esbotenar",
    "esbotenarias": "esbotenar",
    "esbotenarmo": "esbotenar",
    "esbotenarmos": "esbotenar",
    "esbotenará": "esbotenar",
    "esbotenarás": "esbotenar",
    "esbotenarão": "esbotenar",
    "esbotenaríamos": "esbotenar",
    "esbotenaríeis": "esbotenar",
    "esbotenas": "esbotenar",
    "esbotenasse": "esbotenar",
    "esbotenassem": "esbotenar",
    "esbotenasses": "esbotenar",
    "esbotenaste": "esbotenar",
    "esbotenastes": "esbotenar",
    "esbotenava": "esbotenar",
    "esbotenavam": "esbotenar",
    "esbotenavas": "esbotenar",
    "esbotene": "esbotenar",
    "esbotenei": "esbotenar",
    "esboteneis": "esbotenar",
    "esbotenem": "esbotenar",
    "esbotenemo": "esbotenar",
    "esbotenemos": "esbotenar",
    "esbotenes": "esbotenar",
    "esboteno": "esbotenar",
    "esbotenou": "esbotenar",
    "esbotená": "esbotenar",
    "esbotenámo": "esbotenar",
    "esbotenámos": "esbotenar",
    "esbotenáramo": "esbotenar",
    "esbotenáramos": "esbotenar",
    "esbotenárei": "esbotenar",
    "esbotenáreis": "esbotenar",
    "esbotenásseis": "esbotenar",
    "esbotenássemos": "esbotenar",
    "esbotenávamo": "esbotenar",
    "esbotenávamos": "esbotenar",
    "esbotenávei": "esbotenar",
    "esbotenáveis": "esbotenar",
    "esbouce": "esbouçar",
    "esboucei": "esbouçar",
    "esbouceis": "esbouçar",
    "esboucela": "esboucelar",
    "esboucelada": "esboucelar",
    "esbouceladas": "esboucelar",
    "esboucelado": "esboucelar",
    "esboucelados": "esboucelar",
    "esboucelai": "esboucelar",
    "esboucelais": "esboucelar",
    "esboucelam": "esboucelar",
    "esboucelamo": "esboucelar",
    "esboucelamos": "esboucelar",
    "esboucelando": "esboucelar",
    "esboucelara": "esboucelar",
    "esboucelaram": "esboucelar",
    "esboucelaras": "esboucelar",
    "esboucelarde": "esboucelar",
    "esboucelardes": "esboucelar",
    "esboucelare": "esboucelar",
    "esboucelarei": "esboucelar",
    "esboucelareis": "esboucelar",
    "esboucelarem": "esboucelar",
    "esboucelaremos": "esboucelar",
    "esboucelares": "esboucelar",
    "esboucelaria": "esboucelar",
    "esboucelariam": "esboucelar",
    "esboucelarias": "esboucelar",
    "esboucelarmo": "esboucelar",
    "esboucelarmos": "esboucelar",
    "esboucelará": "esboucelar",
    "esboucelarás": "esboucelar",
    "esboucelarão": "esboucelar",
    "esboucelaríamos": "esboucelar",
    "esboucelaríeis": "esboucelar",
    "esboucelas": "esboucelar",
    "esboucelasse": "esboucelar",
    "esboucelassem": "esboucelar",
    "esboucelasses": "esboucelar",
    "esboucelaste": "esboucelar",
    "esboucelastes": "esboucelar",
    "esboucelava": "esboucelar",
    "esboucelavam": "esboucelar",
    "esboucelavas": "esboucelar",
    "esboucele": "esboucelar",
    "esboucelei": "esboucelar",
    "esbouceleis": "esboucelar",
    "esboucelem": "esboucelar",
    "esboucelemo": "esboucelar",
    "esboucelemos": "esboucelar",
    "esbouceles": "esboucelar",
    "esboucelo": "esboucelar",
    "esboucelou": "esboucelar",
    "esboucelá": "esboucelar",
    "esboucelámo": "esboucelar",
    "esboucelámos": "esboucelar",
    "esbouceláramo": "esboucelar",
    "esbouceláramos": "esboucelar",
    "esboucelárei": "esboucelar",
    "esbouceláreis": "esboucelar",
    "esboucelásseis": "esboucelar",
    "esboucelássemos": "esboucelar",
    "esboucelávamo": "esboucelar",
    "esboucelávamos": "esboucelar",
    "esboucelávei": "esboucelar",
    "esbouceláveis": "esboucelar",
    "esboucem": "esbouçar",
    "esboucemo": "esbouçar",
    "esboucemos": "esbouçar",
    "esbouces": "esbouçar",
    "esbouça": "esbouçar",
    "esbouçada": "esbouçar",
    "esbouçadas": "esbouçar",
    "esbouçado": "esbouçar",
    "esbouçados": "esbouçar",
    "esbouçai": "esbouçar",
    "esbouçais": "esbouçar",
    "esbouçam": "esbouçar",
    "esbouçamo": "esbouçar",
    "esbouçamos": "esbouçar",
    "esbouçando": "esbouçar",
    "esbouçara": "esbouçar",
    "esbouçaram": "esbouçar",
    "esbouçaras": "esbouçar",
    "esbouçarde": "esbouçar",
    "esbouçardes": "esbouçar",
    "esbouçare": "esbouçar",
    "esbouçarei": "esbouçar",
    "esbouçareis": "esbouçar",
    "esbouçarem": "esbouçar",
    "esbouçaremos": "esbouçar",
    "esbouçares": "esbouçar",
    "esbouçaria": "esbouçar",
    "esbouçariam": "esbouçar",
    "esbouçarias": "esbouçar",
    "esbouçarmo": "esbouçar",
    "esbouçarmos": "esbouçar",
    "esbouçará": "esbouçar",
    "esbouçarás": "esbouçar",
    "esbouçarão": "esbouçar",
    "esbouçaríamos": "esbouçar",
    "esbouçaríeis": "esbouçar",
    "esbouças": "esbouçar",
    "esbouçasse": "esbouçar",
    "esbouçassem": "esbouçar",
    "esbouçasses": "esbouçar",
    "esbouçaste": "esbouçar",
    "esbouçastes": "esbouçar",
    "esbouçava": "esbouçar",
    "esbouçavam": "esbouçar",
    "esbouçavas": "esbouçar",
    "esbouço": "esbouçar",
    "esbouçou": "esbouçar",
    "esbouçá": "esbouçar",
    "esbouçámo": "esbouçar",
    "esbouçámos": "esbouçar",
    "esbouçáramo": "esbouçar",
    "esbouçáramos": "esbouçar",
    "esbouçárei": "esbouçar",
    "esbouçáreis": "esbouçar",
    "esbouçásseis": "esbouçar",
    "esbouçássemos": "esbouçar",
    "esbouçávamo": "esbouçar",
    "esbouçávamos": "esbouçar",
    "esbouçávei": "esbouçar",
    "esbouçáveis": "esbouçar",
    "esboça": "esboçar",
    "esboçada": "esboçar",
    "esboçadas": "esboçar",
    "esboçado": "esboçar",
    "esboçados": "esboçar",
    "esboçai": "esboçar",
    "esboçais": "esboçar",
    "esboçam": "esboçar",
    "esboçamo": "esboçar",
    "esboçamos": "esboçar",
    "esboçando": "esboçar",
    "esboçara": "esboçar",
    "esboçaram": "esboçar",
    "esboçaras": "esboçar",
    "esboçarde": "esboçar",
    "esboçardes": "esboçar",
    "esboçare": "esboçar",
    "esboçarei": "esboçar",
    "esboçareis": "esboçar",
    "esboçarem": "esboçar",
    "esboçaremos": "esboçar",
    "esboçares": "esboçar",
    "esboçaria": "esboçar",
    "esboçariam": "esboçar",
    "esboçarias": "esboçar",
    "esboçarmo": "esboçar",
    "esboçarmos": "esboçar",
    "esboçará": "esboçar",
    "esboçarás": "esboçar",
    "esboçarão": "esboçar",
    "esboçaríamos": "esboçar",
    "esboçaríeis": "esboçar",
    "esboças": "esboçar",
    "esboçasse": "esboçar",
    "esboçassem": "esboçar",
    "esboçasses": "esboçar",
    "esboçaste": "esboçar",
    "esboçastes": "esboçar",
    "esboçava": "esboçar",
    "esboçavam": "esboçar",
    "esboçavas": "esboçar",
    "esboço": "esboçar",
    "esboços": "esboço",
    "esboçou": "esboçar",
    "esboçá": "esboçar",
    "esboçámo": "esboçar",
    "esboçámos": "esboçar",
    "esboçáramo": "esboçar",
    "esboçáramos": "esboçar",
    "esboçárei": "esboçar",
    "esboçáreis": "esboçar",
    "esboçásseis": "esboçar",
    "esboçássemos": "esboçar",
    "esboçávamo": "esboçar",
    "esboçávamos": "esboçar",
    "esboçávei": "esboçar",
    "esboçáveis": "esboçar",
    "esbraceja": "esbracejar",
    "esbracejada": "esbracejar",
    "esbracejadas": "esbracejar",
    "esbracejado": "esbracejar",
    "esbracejados": "esbracejar",
    "esbracejai": "esbracejar",
    "esbracejais": "esbracejar",
    "esbracejam": "esbracejar",
    "esbracejamo": "esbracejar",
    "esbracejamos": "esbracejar",
    "esbracejando": "esbracejar",
    "esbracejara": "esbracejar",
    "esbracejaram": "esbracejar",
    "esbracejaras": "esbracejar",
    "esbracejardes": "esbracejar",
    "esbracejarei": "esbracejar",
    "esbracejareis": "esbracejar",
    "esbracejarem": "esbracejar",
    "esbracejaremos": "esbracejar",
    "esbracejares": "esbracejar",
    "esbracejaria": "esbracejar",
    "esbracejariam": "esbracejar",
    "esbracejarias": "esbracejar",
    "esbracejarmo": "esbracejar",
    "esbracejarmos": "esbracejar",
    "esbracejará": "esbracejar",
    "esbracejarás": "esbracejar",
    "esbracejarão": "esbracejar",
    "esbracejaríamos": "esbracejar",
    "esbracejaríeis": "esbracejar",
    "esbracejas": "esbracejar",
    "esbracejasse": "esbracejar",
    "esbracejassem": "esbracejar",
    "esbracejasses": "esbracejar",
    "esbracejaste": "esbracejar",
    "esbracejastes": "esbracejar",
    "esbracejava": "esbracejar",
    "esbracejavam": "esbracejar",
    "esbracejavas": "esbracejar",
    "esbraceje": "esbracejar",
    "esbracejei": "esbracejar",
    "esbracejeis": "esbracejar",
    "esbracejem": "esbracejar",
    "esbracejemo": "esbracejar",
    "esbracejemos": "esbracejar",
    "esbracejes": "esbracejar",
    "esbracejo": "esbracejar",
    "esbracejou": "esbracejar",
    "esbracejámo": "esbracejar",
    "esbracejámos": "esbracejar",
    "esbracejáramo": "esbracejar",
    "esbracejáramos": "esbracejar",
    "esbracejáreis": "esbracejar",
    "esbracejásseis": "esbracejar",
    "esbracejássemos": "esbracejar",
    "esbracejávamo": "esbracejar",
    "esbracejávamos": "esbracejar",
    "esbracejáveis": "esbracejar",
    "esbraguilhada": "esbraguilhado",
    "esbraguilhadas": "esbraguilhado",
    "esbraguilhados": "esbraguilhado",
    "esbranquice": "esbranquiçar",
    "esbranquicei": "esbranquiçar",
    "esbranquiceis": "esbranquiçar",
    "esbranquicem": "esbranquiçar",
    "esbranquicemo": "esbranquiçar",
    "esbranquicemos": "esbranquiçar",
    "esbranquices": "esbranquiçar",
    "esbranquiça": "esbranquiçar",
    "esbranquiçada": "esbranquiçar",
    "esbranquiçadas": "esbranquiçar",
    "esbranquiçado": "esbranquiçar",
    "esbranquiçados": "esbranquiçar",
    "esbranquiçai": "esbranquiçar",
    "esbranquiçais": "esbranquiçar",
    "esbranquiçam": "esbranquiçar",
    "esbranquiçamo": "esbranquiçar",
    "esbranquiçamos": "esbranquiçar",
    "esbranquiçando": "esbranquiçar",
    "esbranquiçara": "esbranquiçar",
    "esbranquiçaram": "esbranquiçar",
    "esbranquiçaras": "esbranquiçar",
    "esbranquiçarde": "esbranquiçar",
    "esbranquiçardes": "esbranquiçar",
    "esbranquiçare": "esbranquiçar",
    "esbranquiçarei": "esbranquiçar",
    "esbranquiçareis": "esbranquiçar",
    "esbranquiçarem": "esbranquiçar",
    "esbranquiçaremos": "esbranquiçar",
    "esbranquiçares": "esbranquiçar",
    "esbranquiçaria": "esbranquiçar",
    "esbranquiçariam": "esbranquiçar",
    "esbranquiçarias": "esbranquiçar",
    "esbranquiçarmo": "esbranquiçar",
    "esbranquiçarmos": "esbranquiçar",
    "esbranquiçará": "esbranquiçar",
    "esbranquiçarás": "esbranquiçar",
    "esbranquiçarão": "esbranquiçar",
    "esbranquiçaríamos": "esbranquiçar",
    "esbranquiçaríeis": "esbranquiçar",
    "esbranquiças": "esbranquiçar",
    "esbranquiçasse": "esbranquiçar",
    "esbranquiçassem": "esbranquiçar",
    "esbranquiçasses": "esbranquiçar",
    "esbranquiçaste": "esbranquiçar",
    "esbranquiçastes": "esbranquiçar",
    "esbranquiçava": "esbranquiçar",
    "esbranquiçavam": "esbranquiçar",
    "esbranquiçavas": "esbranquiçar",
    "esbranquiço": "esbranquiçar",
    "esbranquiçou": "esbranquiçar",
    "esbranquiçá": "esbranquiçar",
    "esbranquiçámo": "esbranquiçar",
    "esbranquiçámos": "esbranquiçar",
    "esbranquiçáramo": "esbranquiçar",
    "esbranquiçáramos": "esbranquiçar",
    "esbranquiçárei": "esbranquiçar",
    "esbranquiçáreis": "esbranquiçar",
    "esbranquiçásseis": "esbranquiçar",
    "esbranquiçássemos": "esbranquiçar",
    "esbranquiçávamo": "esbranquiçar",
    "esbranquiçávamos": "esbranquiçar",
    "esbranquiçávei": "esbranquiçar",
    "esbranquiçáveis": "esbranquiçar",
    "esbraseada": "esbrasear",
    "esbraseadas": "esbrasear",
    "esbraseado": "esbrasear",
    "esbraseados": "esbrasear",
    "esbraseai": "esbrasear",
    "esbraseais": "esbrasear",
    "esbraseamo": "esbrasear",
    "esbraseamos": "esbrasear",
    "esbraseando": "esbrasear",
    "esbraseantes": "esbraseante",
    "esbraseara": "esbrasear",
    "esbrasearam": "esbrasear",
    "esbrasearas": "esbrasear",
    "esbrasearde": "esbrasear",
    "esbraseardes": "esbrasear",
    "esbraseare": "esbrasear",
    "esbrasearei": "esbrasear",
    "esbraseareis": "esbrasear",
    "esbrasearem": "esbrasear",
    "esbrasearemos": "esbrasear",
    "esbraseares": "esbrasear",
    "esbrasearia": "esbrasear",
    "esbraseariam": "esbrasear",
    "esbrasearias": "esbrasear",
    "esbrasearmo": "esbrasear",
    "esbrasearmos": "esbrasear",
    "esbraseará": "esbrasear",
    "esbrasearás": "esbrasear",
    "esbrasearão": "esbrasear",
    "esbrasearíamos": "esbrasear",
    "esbrasearíeis": "esbrasear",
    "esbraseasse": "esbrasear",
    "esbraseassem": "esbrasear",
    "esbraseasses": "esbrasear",
    "esbraseaste": "esbrasear",
    "esbraseastes": "esbrasear",
    "esbraseava": "esbrasear",
    "esbraseavam": "esbrasear",
    "esbraseavas": "esbrasear",
    "esbraseei": "esbrasear",
    "esbraseeis": "esbrasear",
    "esbraseemo": "esbrasear",
    "esbraseemos": "esbrasear",
    "esbraseia": "esbrasear",
    "esbraseiam": "esbrasear",
    "esbraseias": "esbrasear",
    "esbraseie": "esbrasear",
    "esbraseiem": "esbrasear",
    "esbraseies": "esbrasear",
    "esbraseio": "esbrasear",
    "esbraseou": "esbrasear",
    "esbraseá": "esbrasear",
    "esbraseámo": "esbrasear",
    "esbraseámos": "esbrasear",
    "esbraseáramo": "esbrasear",
    "esbraseáramos": "esbrasear",
    "esbraseárei": "esbrasear",
    "esbraseáreis": "esbrasear",
    "esbraseásseis": "esbrasear",
    "esbraseássemos": "esbrasear",
    "esbraseávamo": "esbrasear",
    "esbraseávamos": "esbrasear",
    "esbraseávei": "esbrasear",
    "esbraseáveis": "esbrasear",
    "esbraveada": "esbravear",
    "esbraveadas": "esbravear",
    "esbraveado": "esbravear",
    "esbraveados": "esbravear",
    "esbraveai": "esbravear",
    "esbraveais": "esbravear",
    "esbraveamo": "esbravear",
    "esbraveamos": "esbravear",
    "esbraveando": "esbravear",
    "esbraveara": "esbravear",
    "esbravearam": "esbravear",
    "esbravearas": "esbravear",
    "esbravearde": "esbravear",
    "esbraveardes": "esbravear",
    "esbraveare": "esbravear",
    "esbravearei": "esbravear",
    "esbraveareis": "esbravear",
    "esbravearem": "esbravear",
    "esbravearemos": "esbravear",
    "esbraveares": "esbravear",
    "esbravearia": "esbravear",
    "esbraveariam": "esbravear",
    "esbravearias": "esbravear",
    "esbravearmo": "esbravear",
    "esbravearmos": "esbravear",
    "esbraveará": "esbravear",
    "esbravearás": "esbravear",
    "esbravearão": "esbravear",
    "esbravearíamos": "esbravear",
    "esbravearíeis": "esbravear",
    "esbraveasse": "esbravear",
    "esbraveassem": "esbravear",
    "esbraveasses": "esbravear",
    "esbraveaste": "esbravear",
    "esbraveastes": "esbravear",
    "esbraveava": "esbravear",
    "esbraveavam": "esbravear",
    "esbraveavas": "esbravear",
    "esbravece": "esbravecer",
    "esbravecei": "esbravecer",
    "esbraveceis": "esbravecer",
    "esbravecem": "esbravecer",
    "esbravecemo": "esbravecer",
    "esbravecemos": "esbravecer",
    "esbravecendo": "esbravecer",
    "esbravecera": "esbravecer",
    "esbraveceram": "esbravecer",
    "esbraveceras": "esbravecer",
    "esbravecerdes": "esbravecer",
    "esbravecerei": "esbravecer",
    "esbravecereis": "esbravecer",
    "esbravecerem": "esbravecer",
    "esbraveceremos": "esbravecer",
    "esbraveceres": "esbravecer",
    "esbraveceria": "esbravecer",
    "esbraveceriam": "esbravecer",
    "esbravecerias": "esbravecer",
    "esbravecermo": "esbravecer",
    "esbravecermos": "esbravecer",
    "esbravecerá": "esbravecer",
    "esbravecerás": "esbravecer",
    "esbravecerão": "esbravecer",
    "esbraveceríamos": "esbravecer",
    "esbraveceríeis": "esbravecer",
    "esbraveces": "esbravecer",
    "esbravecesse": "esbravecer",
    "esbravecessem": "esbravecer",
    "esbravecesses": "esbravecer",
    "esbraveceste": "esbravecer",
    "esbravecestes": "esbravecer",
    "esbraveceu": "esbravecer",
    "esbraveci": "esbravecer",
    "esbravecia": "esbravecer",
    "esbraveciam": "esbravecer",
    "esbravecias": "esbravecer",
    "esbravecida": "esbravecer",
    "esbravecidas": "esbravecer",
    "esbravecido": "esbravecer",
    "esbravecidos": "esbravecer",
    "esbravecêramo": "esbravecer",
    "esbravecêramos": "esbravecer",
    "esbravecêreis": "esbravecer",
    "esbravecêsseis": "esbravecer",
    "esbravecêssemos": "esbravecer",
    "esbravecíamo": "esbravecer",
    "esbravecíamos": "esbravecer",
    "esbravecíeis": "esbravecer",
    "esbraveei": "esbravear",
    "esbraveeis": "esbravear",
    "esbraveemo": "esbravear",
    "esbraveemos": "esbravear",
    "esbraveia": "esbravear",
    "esbraveiam": "esbravear",
    "esbraveias": "esbravear",
    "esbraveie": "esbravear",
    "esbraveiem": "esbravear",
    "esbraveies": "esbravear",
    "esbraveio": "esbravear",
    "esbraveja": "esbravejar",
    "esbravejada": "esbravejar",
    "esbravejadas": "esbravejar",
    "esbravejado": "esbravejar",
    "esbravejados": "esbravejar",
    "esbravejai": "esbravejar",
    "esbravejais": "esbravejar",
    "esbravejam": "esbravejar",
    "esbravejamo": "esbravejar",
    "esbravejamos": "esbravejar",
    "esbravejando": "esbravejar",
    "esbravejara": "esbravejar",
    "esbravejaram": "esbravejar",
    "esbravejaras": "esbravejar",
    "esbravejardes": "esbravejar",
    "esbravejarei": "esbravejar",
    "esbravejareis": "esbravejar",
    "esbravejarem": "esbravejar",
    "esbravejaremos": "esbravejar",
    "esbravejares": "esbravejar",
    "esbravejaria": "esbravejar",
    "esbravejariam": "esbravejar",
    "esbravejarias": "esbravejar",
    "esbravejarmo": "esbravejar",
    "esbravejarmos": "esbravejar",
    "esbravejará": "esbravejar",
    "esbravejarás": "esbravejar",
    "esbravejarão": "esbravejar",
    "esbravejaríamos": "esbravejar",
    "esbravejaríeis": "esbravejar",
    "esbravejas": "esbravejar",
    "esbravejasse": "esbravejar",
    "esbravejassem": "esbravejar",
    "esbravejasses": "esbravejar",
    "esbravejaste": "esbravejar",
    "esbravejastes": "esbravejar",
    "esbravejava": "esbravejar",
    "esbravejavam": "esbravejar",
    "esbravejavas": "esbravejar",
    "esbraveje": "esbravejar",
    "esbravejei": "esbravejar",
    "esbravejeis": "esbravejar",
    "esbravejem": "esbravejar",
    "esbravejemo": "esbravejar",
    "esbravejemos": "esbravejar",
    "esbravejes": "esbravejar",
    "esbravejo": "esbravejar",
    "esbravejou": "esbravejar",
    "esbravejámo": "esbravejar",
    "esbravejámos": "esbravejar",
    "esbravejáramo": "esbravejar",
    "esbravejáramos": "esbravejar",
    "esbravejáreis": "esbravejar",
    "esbravejásseis": "esbravejar",
    "esbravejássemos": "esbravejar",
    "esbravejávamo": "esbravejar",
    "esbravejávamos": "esbravejar",
    "esbravejáveis": "esbravejar",
    "esbraveou": "esbravear",
    "esbraveá": "esbravear",
    "esbraveámo": "esbravear",
    "esbraveámos": "esbravear",
    "esbraveáramo": "esbravear",
    "esbraveáramos": "esbravear",
    "esbraveárei": "esbravear",
    "esbraveáreis": "esbravear",
    "esbraveásseis": "esbravear",
    "esbraveássemos": "esbravear",
    "esbraveávamo": "esbravear",
    "esbraveávamos": "esbravear",
    "esbraveávei": "esbravear",
    "esbraveáveis": "esbravear",
    "esbraveça": "esbravecer",
    "esbraveçais": "esbravecer",
    "esbraveçam": "esbravecer",
    "esbraveçamo": "esbravecer",
    "esbraveçamos": "esbravecer",
    "esbraveças": "esbravecer",
    "esbraveço": "esbravecer",
    "esbrazeamentos": "esbrazeamento",
    "esbruga": "esbrugar",
    "esbrugada": "esbrugar",
    "esbrugadas": "esbrugar",
    "esbrugado": "esbrugar",
    "esbrugados": "esbrugar",
    "esbrugai": "esbrugar",
    "esbrugais": "esbrugar",
    "esbrugam": "esbrugar",
    "esbrugamo": "esbrugar",
    "esbrugamos": "esbrugar",
    "esbrugando": "esbrugar",
    "esbrugara": "esbrugar",
    "esbrugaram": "esbrugar",
    "esbrugaras": "esbrugar",
    "esbrugarde": "esbrugar",
    "esbrugardes": "esbrugar",
    "esbrugare": "esbrugar",
    "esbrugarei": "esbrugar",
    "esbrugareis": "esbrugar",
    "esbrugarem": "esbrugar",
    "esbrugaremos": "esbrugar",
    "esbrugares": "esbrugar",
    "esbrugaria": "esbrugar",
    "esbrugariam": "esbrugar",
    "esbrugarias": "esbrugar",
    "esbrugarmo": "esbrugar",
    "esbrugarmos": "esbrugar",
    "esbrugará": "esbrugar",
    "esbrugarás": "esbrugar",
    "esbrugarão": "esbrugar",
    "esbrugaríamos": "esbrugar",
    "esbrugaríeis": "esbrugar",
    "esbrugas": "esbrugar",
    "esbrugasse": "esbrugar",
    "esbrugassem": "esbrugar",
    "esbrugasses": "esbrugar",
    "esbrugaste": "esbrugar",
    "esbrugastes": "esbrugar",
    "esbrugava": "esbrugar",
    "esbrugavam": "esbrugar",
    "esbrugavas": "esbrugar",
    "esbrugo": "esbrugar",
    "esbrugou": "esbrugar",
    "esbrugue": "esbrugar",
    "esbruguei": "esbrugar",
    "esbrugueis": "esbrugar",
    "esbruguem": "esbrugar",
    "esbruguemo": "esbrugar",
    "esbruguemos": "esbrugar",
    "esbrugues": "esbrugar",
    "esbrugá": "esbrugar",
    "esbrugámo": "esbrugar",
    "esbrugámos": "esbrugar",
    "esbrugáramo": "esbrugar",
    "esbrugáramos": "esbrugar",
    "esbrugárei": "esbrugar",
    "esbrugáreis": "esbrugar",
    "esbrugásseis": "esbrugar",
    "esbrugássemos": "esbrugar",
    "esbrugávamo": "esbrugar",
    "esbrugávamos": "esbrugar",
    "esbrugávei": "esbrugar",
    "esbrugáveis": "esbrugar",
    "esbugalha": "esbugalhar",
    "esbugalhada": "esbugalhar",
    "esbugalhadas": "esbugalhar",
    "esbugalhado": "esbugalhar",
    "esbugalhados": "esbugalhar",
    "esbugalhai": "esbugalhar",
    "esbugalhais": "esbugalhar",
    "esbugalham": "esbugalhar",
    "esbugalhamo": "esbugalhar",
    "esbugalhamos": "esbugalhar",
    "esbugalhando": "esbugalhar",
    "esbugalhara": "esbugalhar",
    "esbugalharam": "esbugalhar",
    "esbugalharas": "esbugalhar",
    "esbugalharde": "esbugalhar",
    "esbugalhardes": "esbugalhar",
    "esbugalhare": "esbugalhar",
    "esbugalharei": "esbugalhar",
    "esbugalhareis": "esbugalhar",
    "esbugalharem": "esbugalhar",
    "esbugalharemos": "esbugalhar",
    "esbugalhares": "esbugalhar",
    "esbugalharia": "esbugalhar",
    "esbugalhariam": "esbugalhar",
    "esbugalharias": "esbugalhar",
    "esbugalharmo": "esbugalhar",
    "esbugalharmos": "esbugalhar",
    "esbugalhará": "esbugalhar",
    "esbugalharás": "esbugalhar",
    "esbugalharão": "esbugalhar",
    "esbugalharíamos": "esbugalhar",
    "esbugalharíeis": "esbugalhar",
    "esbugalhas": "esbugalhar",
    "esbugalhasse": "esbugalhar",
    "esbugalhassem": "esbugalhar",
    "esbugalhasses": "esbugalhar",
    "esbugalhaste": "esbugalhar",
    "esbugalhastes": "esbugalhar",
    "esbugalhava": "esbugalhar",
    "esbugalhavam": "esbugalhar",
    "esbugalhavas": "esbugalhar",
    "esbugalhe": "esbugalhar",
    "esbugalhei": "esbugalhar",
    "esbugalheis": "esbugalhar",
    "esbugalhem": "esbugalhar",
    "esbugalhemo": "esbugalhar",
    "esbugalhemos": "esbugalhar",
    "esbugalhes": "esbugalhar",
    "esbugalho": "esbugalhar",
    "esbugalhou": "esbugalhar",
    "esbugalhá": "esbugalhar",
    "esbugalhámo": "esbugalhar",
    "esbugalhámos": "esbugalhar",
    "esbugalháramo": "esbugalhar",
    "esbugalháramos": "esbugalhar",
    "esbugalhárei": "esbugalhar",
    "esbugalháreis": "esbugalhar",
    "esbugalhásseis": "esbugalhar",
    "esbugalhássemos": "esbugalhar",
    "esbugalhávamo": "esbugalhar",
    "esbugalhávamos": "esbugalhar",
    "esbugalhávei": "esbugalhar",
    "esbugalháveis": "esbugalhar",
    "esbulha": "esbulhar",
    "esbulhada": "esbulhar",
    "esbulhadas": "esbulhar",
    "esbulhado": "esbulhar",
    "esbulhadora": "esbulhador",
    "esbulhadoras": "esbulhador",
    "esbulhadores": "esbulhador",
    "esbulhados": "esbulhar",
    "esbulhai": "esbulhar",
    "esbulhais": "esbulhar",
    "esbulham": "esbulhar",
    "esbulhamo": "esbulhar",
    "esbulhamos": "esbulhar",
    "esbulhando": "esbulhar",
    "esbulhara": "esbulhar",
    "esbulharam": "esbulhar",
    "esbulharas": "esbulhar",
    "esbulharde": "esbulhar",
    "esbulhardes": "esbulhar",
    "esbulhare": "esbulhar",
    "esbulharei": "esbulhar",
    "esbulhareis": "esbulhar",
    "esbulharem": "esbulhar",
    "esbulharemos": "esbulhar",
    "esbulhares": "esbulhar",
    "esbulharia": "esbulhar",
    "esbulhariam": "esbulhar",
    "esbulharias": "esbulhar",
    "esbulharmo": "esbulhar",
    "esbulharmos": "esbulhar",
    "esbulhará": "esbulhar",
    "esbulharás": "esbulhar",
    "esbulharão": "esbulhar",
    "esbulharíamos": "esbulhar",
    "esbulharíeis": "esbulhar",
    "esbulhas": "esbulhar",
    "esbulhasse": "esbulhar",
    "esbulhassem": "esbulhar",
    "esbulhasses": "esbulhar",
    "esbulhaste": "esbulhar",
    "esbulhastes": "esbulhar",
    "esbulhava": "esbulhar",
    "esbulhavam": "esbulhar",
    "esbulhavas": "esbulhar",
    "esbulhe": "esbulhar",
    "esbulhei": "esbulhar",
    "esbulheis": "esbulhar",
    "esbulhem": "esbulhar",
    "esbulhemo": "esbulhar",
    "esbulhemos": "esbulhar",
    "esbulhes": "esbulhar",
    "esbulho": "esbulhar",
    "esbulhos": "esbulho",
    "esbulhou": "esbulhar",
    "esbulhá": "esbulhar",
    "esbulhámo": "esbulhar",
    "esbulhámos": "esbulhar",
    "esbulháramo": "esbulhar",
    "esbulháramos": "esbulhar",
    "esbulhárei": "esbulhar",
    "esbulháreis": "esbulhar",
    "esbulhásseis": "esbulhar",
    "esbulhássemos": "esbulhar",
    "esbulhávamo": "esbulhar",
    "esbulhávamos": "esbulhar",
    "esbulhávei": "esbulhar",
    "esbulháveis": "esbulhar",
    "esburaca": "esburacar",
    "esburacada": "esburacar",
    "esburacadas": "esburacar",
    "esburacado": "esburacar",
    "esburacados": "esburacar",
    "esburacai": "esburacar",
    "esburacais": "esburacar",
    "esburacam": "esburacar",
    "esburacamo": "esburacar",
    "esburacamos": "esburacar",
    "esburacando": "esburacar",
    "esburacara": "esburacar",
    "esburacaram": "esburacar",
    "esburacaras": "esburacar",
    "esburacarde": "esburacar",
    "esburacardes": "esburacar",
    "esburacare": "esburacar",
    "esburacarei": "esburacar",
    "esburacareis": "esburacar",
    "esburacarem": "esburacar",
    "esburacaremos": "esburacar",
    "esburacares": "esburacar",
    "esburacaria": "esburacar",
    "esburacariam": "esburacar",
    "esburacarias": "esburacar",
    "esburacarmo": "esburacar",
    "esburacarmos": "esburacar",
    "esburacará": "esburacar",
    "esburacarás": "esburacar",
    "esburacarão": "esburacar",
    "esburacaríamos": "esburacar",
    "esburacaríeis": "esburacar",
    "esburacas": "esburacar",
    "esburacasse": "esburacar",
    "esburacassem": "esburacar",
    "esburacasses": "esburacar",
    "esburacaste": "esburacar",
    "esburacastes": "esburacar",
    "esburacava": "esburacar",
    "esburacavam": "esburacar",
    "esburacavas": "esburacar",
    "esburaco": "esburacar",
    "esburacou": "esburacar",
    "esburacá": "esburacar",
    "esburacámo": "esburacar",
    "esburacámos": "esburacar",
    "esburacáramo": "esburacar",
    "esburacáramos": "esburacar",
    "esburacárei": "esburacar",
    "esburacáreis": "esburacar",
    "esburacásseis": "esburacar",
    "esburacássemos": "esburacar",
    "esburacávamo": "esburacar",
    "esburacávamos": "esburacar",
    "esburacávei": "esburacar",
    "esburacáveis": "esburacar",
    "esburaque": "esburacar",
    "esburaquei": "esburacar",
    "esburaqueis": "esburacar",
    "esburaquem": "esburacar",
    "esburaquemo": "esburacar",
    "esburaquemos": "esburacar",
    "esburaques": "esburacar",
    "esburga": "esburgar",
    "esburgada": "esburgar",
    "esburgadas": "esburgar",
    "esburgado": "esburgar",
    "esburgados": "esburgar",
    "esburgai": "esburgar",
    "esburgais": "esburgar",
    "esburgam": "esburgar",
    "esburgamo": "esburgar",
    "esburgamos": "esburgar",
    "esburgando": "esburgar",
    "esburgara": "esburgar",
    "esburgaram": "esburgar",
    "esburgaras": "esburgar",
    "esburgarde": "esburgar",
    "esburgardes": "esburgar",
    "esburgare": "esburgar",
    "esburgarei": "esburgar",
    "esburgareis": "esburgar",
    "esburgarem": "esburgar",
    "esburgaremos": "esburgar",
    "esburgares": "esburgar",
    "esburgaria": "esburgar",
    "esburgariam": "esburgar",
    "esburgarias": "esburgar",
    "esburgarmo": "esburgar",
    "esburgarmos": "esburgar",
    "esburgará": "esburgar",
    "esburgarás": "esburgar",
    "esburgarão": "esburgar",
    "esburgaríamos": "esburgar",
    "esburgaríeis": "esburgar",
    "esburgas": "esburgar",
    "esburgasse": "esburgar",
    "esburgassem": "esburgar",
    "esburgasses": "esburgar",
    "esburgaste": "esburgar",
    "esburgastes": "esburgar",
    "esburgava": "esburgar",
    "esburgavam": "esburgar",
    "esburgavas": "esburgar",
    "esburgo": "esburgar",
    "esburgou": "esburgar",
    "esburgue": "esburgar",
    "esburguei": "esburgar",
    "esburgueis": "esburgar",
    "esburguem": "esburgar",
    "esburguemo": "esburgar",
    "esburguemos": "esburgar",
    "esburgues": "esburgar",
    "esburgá": "esburgar",
    "esburgámo": "esburgar",
    "esburgámos": "esburgar",
    "esburgáramo": "esburgar",
    "esburgáramos": "esburgar",
    "esburgárei": "esburgar",
    "esburgáreis": "esburgar",
    "esburgásseis": "esburgar",
    "esburgássemos": "esburgar",
    "esburgávamo": "esburgar",
    "esburgávamos": "esburgar",
    "esburgávei": "esburgar",
    "esburgáveis": "esburgar",
    "escabece": "escabeçar",
    "escabeceada": "escabecear",
    "escabeceadas": "escabecear",
    "escabeceado": "escabecear",
    "escabeceados": "escabecear",
    "escabeceai": "escabecear",
    "escabeceais": "escabecear",
    "escabeceamo": "escabecear",
    "escabeceamos": "escabecear",
    "escabeceando": "escabecear",
    "escabeceara": "escabecear",
    "escabecearam": "escabecear",
    "escabecearas": "escabecear",
    "escabecearde": "escabecear",
    "escabeceardes": "escabecear",
    "escabeceare": "escabecear",
    "escabecearei": "escabecear",
    "escabeceareis": "escabecear",
    "escabecearem": "escabecear",
    "escabecearemos": "escabecear",
    "escabeceares": "escabecear",
    "escabecearia": "escabecear",
    "escabeceariam": "escabecear",
    "escabecearias": "escabecear",
    "escabecearmo": "escabecear",
    "escabecearmos": "escabecear",
    "escabeceará": "escabecear",
    "escabecearás": "escabecear",
    "escabecearão": "escabecear",
    "escabecearíamos": "escabecear",
    "escabecearíeis": "escabecear",
    "escabeceasse": "escabecear",
    "escabeceassem": "escabecear",
    "escabeceasses": "escabecear",
    "escabeceaste": "escabecear",
    "escabeceastes": "escabecear",
    "escabeceava": "escabecear",
    "escabeceavam": "escabecear",
    "escabeceavas": "escabecear",
    "escabeceei": "escabecear",
    "escabeceeis": "escabecear",
    "escabeceemo": "escabecear",
    "escabeceemos": "escabecear",
    "escabecei": "escabeçar",
    "escabeceia": "escabecear",
    "escabeceiam": "escabecear",
    "escabeceias": "escabecear",
    "escabeceie": "escabecear",
    "escabeceiem": "escabecear",
    "escabeceies": "escabecear",
    "escabeceio": "escabecear",
    "escabeceis": "escabeçar",
    "escabecem": "escabeçar",
    "escabecemo": "escabeçar",
    "escabecemos": "escabeçar",
    "escabeceou": "escabecear",
    "escabeces": "escabeçar",
    "escabeceá": "escabecear",
    "escabeceámo": "escabecear",
    "escabeceámos": "escabecear",
    "escabeceáramo": "escabecear",
    "escabeceáramos": "escabecear",
    "escabeceárei": "escabecear",
    "escabeceáreis": "escabecear",
    "escabeceásseis": "escabecear",
    "escabeceássemos": "escabecear",
    "escabeceávamo": "escabecear",
    "escabeceávamos": "escabecear",
    "escabeceávei": "escabecear",
    "escabeceáveis": "escabecear",
    "escabecha": "escabechar",
    "escabechada": "escabechar",
    "escabechadas": "escabechar",
    "escabechado": "escabechar",
    "escabechados": "escabechar",
    "escabechai": "escabechar",
    "escabechais": "escabechar",
    "escabecham": "escabechar",
    "escabechamo": "escabechar",
    "escabechamos": "escabechar",
    "escabechando": "escabechar",
    "escabechara": "escabechar",
    "escabecharam": "escabechar",
    "escabecharas": "escabechar",
    "escabechardes": "escabechar",
    "escabecharei": "escabechar",
    "escabechareis": "escabechar",
    "escabecharem": "escabechar",
    "escabecharemos": "escabechar",
    "escabechares": "escabechar",
    "escabecharia": "escabechar",
    "escabechariam": "escabechar",
    "escabecharias": "escabechar",
    "escabecharmo": "escabechar",
    "escabecharmos": "escabechar",
    "escabechará": "escabechar",
    "escabecharás": "escabechar",
    "escabecharão": "escabechar",
    "escabecharíamos": "escabechar",
    "escabecharíeis": "escabechar",
    "escabechas": "escabechar",
    "escabechasse": "escabechar",
    "escabechassem": "escabechar",
    "escabechasses": "escabechar",
    "escabechaste": "escabechar",
    "escabechastes": "escabechar",
    "escabechava": "escabechar",
    "escabechavam": "escabechar",
    "escabechavas": "escabechar",
    "escabeche": "escabechar",
    "escabechei": "escabechar",
    "escabecheis": "escabechar",
    "escabechem": "escabechar",
    "escabechemo": "escabechar",
    "escabechemos": "escabechar",
    "escabeches": "escabeche",
    "escabecho": "escabechar",
    "escabechou": "escabechar",
    "escabechámo": "escabechar",
    "escabechámos": "escabechar",
    "escabecháramo": "escabechar",
    "escabecháramos": "escabechar",
    "escabecháreis": "escabechar",
    "escabechásseis": "escabechar",
    "escabechássemos": "escabechar",
    "escabechávamo": "escabechar",
    "escabechávamos": "escabechar",
    "escabecháveis": "escabechar",
    "escabela": "escabelar",
    "escabelada": "escabelar",
    "escabeladas": "escabelar",
    "escabelado": "escabelar",
    "escabelados": "escabelar",
    "escabelai": "escabelar",
    "escabelais": "escabelar",
    "escabelam": "escabelar",
    "escabelamo": "escabelar",
    "escabelamos": "escabelar",
    "escabelando": "escabelar",
    "escabelara": "escabelar",
    "escabelaram": "escabelar",
    "escabelaras": "escabelar",
    "escabelarde": "escabelar",
    "escabelardes": "escabelar",
    "escabelare": "escabelar",
    "escabelarei": "escabelar",
    "escabelareis": "escabelar",
    "escabelarem": "escabelar",
    "escabelaremos": "escabelar",
    "escabelares": "escabelar",
    "escabelaria": "escabelar",
    "escabelariam": "escabelar",
    "escabelarias": "escabelar",
    "escabelarmo": "escabelar",
    "escabelarmos": "escabelar",
    "escabelará": "escabelar",
    "escabelarás": "escabelar",
    "escabelarão": "escabelar",
    "escabelaríamos": "escabelar",
    "escabelaríeis": "escabelar",
    "escabelas": "escabelar",
    "escabelasse": "escabelar",
    "escabelassem": "escabelar",
    "escabelasses": "escabelar",
    "escabelaste": "escabelar",
    "escabelastes": "escabelar",
    "escabelava": "escabelar",
    "escabelavam": "escabelar",
    "escabelavas": "escabelar",
    "escabele": "escabelar",
    "escabelei": "escabelar",
    "escabeleira": "escabeleirar",
    "escabeleirada": "escabeleirar",
    "escabeleiradas": "escabeleirar",
    "escabeleirado": "escabeleirar",
    "escabeleirados": "escabeleirar",
    "escabeleirai": "escabeleirar",
    "escabeleirais": "escabeleirar",
    "escabeleiram": "escabeleirar",
    "escabeleiramo": "escabeleirar",
    "escabeleiramos": "escabeleirar",
    "escabeleirando": "escabeleirar",
    "escabeleirara": "escabeleirar",
    "escabeleiraram": "escabeleirar",
    "escabeleiraras": "escabeleirar",
    "escabeleirarde": "escabeleirar",
    "escabeleirardes": "escabeleirar",
    "escabeleirare": "escabeleirar",
    "escabeleirarei": "escabeleirar",
    "escabeleirareis": "escabeleirar",
    "escabeleirarem": "escabeleirar",
    "escabeleiraremos": "escabeleirar",
    "escabeleirares": "escabeleirar",
    "escabeleiraria": "escabeleirar",
    "escabeleirariam": "escabeleirar",
    "escabeleirarias": "escabeleirar",
    "escabeleirarmo": "escabeleirar",
    "escabeleirarmos": "escabeleirar",
    "escabeleirará": "escabeleirar",
    "escabeleirarás": "escabeleirar",
    "escabeleirarão": "escabeleirar",
    "escabeleiraríamos": "escabeleirar",
    "escabeleiraríeis": "escabeleirar",
    "escabeleiras": "escabeleirar",
    "escabeleirasse": "escabeleirar",
    "escabeleirassem": "escabeleirar",
    "escabeleirasses": "escabeleirar",
    "escabeleiraste": "escabeleirar",
    "escabeleirastes": "escabeleirar",
    "escabeleirava": "escabeleirar",
    "escabeleiravam": "escabeleirar",
    "escabeleiravas": "escabeleirar",
    "escabeleire": "escabeleirar",
    "escabeleirei": "escabeleirar",
    "escabeleireis": "escabeleirar",
    "escabeleirem": "escabeleirar",
    "escabeleiremo": "escabeleirar",
    "escabeleiremos": "escabeleirar",
    "escabeleires": "escabeleirar",
    "escabeleiro": "escabeleirar",
    "escabeleirou": "escabeleirar",
    "escabeleirá": "escabeleirar",
    "escabeleirámo": "escabeleirar",
    "escabeleirámos": "escabeleirar",
    "escabeleiráramo": "escabeleirar",
    "escabeleiráramos": "escabeleirar",
    "escabeleirárei": "escabeleirar",
    "escabeleiráreis": "escabeleirar",
    "escabeleirásseis": "escabeleirar",
    "escabeleirássemos": "escabeleirar",
    "escabeleirávamo": "escabeleirar",
    "escabeleirávamos": "escabeleirar",
    "escabeleirávei": "escabeleirar",
    "escabeleiráveis": "escabeleirar",
    "escabeleis": "escabelar",
    "escabelem": "escabelar",
    "escabelemo": "escabelar",
    "escabelemos": "escabelar",
    "escabeles": "escabelar",
    "escabelo": "escabelar",
    "escabelos": "escabelo",
    "escabelou": "escabelar",
    "escabelá": "escabelar",
    "escabelámo": "escabelar",
    "escabelámos": "escabelar",
    "escabeláramo": "escabelar",
    "escabeláramos": "escabelar",
    "escabelárei": "escabelar",
    "escabeláreis": "escabelar",
    "escabelásseis": "escabelar",
    "escabelássemos": "escabelar",
    "escabelávamo": "escabelar",
    "escabelávamos": "escabelar",
    "escabelávei": "escabelar",
    "escabeláveis": "escabelar",
    "escabeça": "escabeçar",
    "escabeçada": "escabeçar",
    "escabeçadas": "escabeçar",
    "escabeçado": "escabeçar",
    "escabeçados": "escabeçar",
    "escabeçai": "escabeçar",
    "escabeçais": "escabeçar",
    "escabeçam": "escabeçar",
    "escabeçamo": "escabeçar",
    "escabeçamos": "escabeçar",
    "escabeçando": "escabeçar",
    "escabeçara": "escabeçar",
    "escabeçaram": "escabeçar",
    "escabeçaras": "escabeçar",
    "escabeçarde": "escabeçar",
    "escabeçardes": "escabeçar",
    "escabeçare": "escabeçar",
    "escabeçarei": "escabeçar",
    "escabeçareis": "escabeçar",
    "escabeçarem": "escabeçar",
    "escabeçaremos": "escabeçar",
    "escabeçares": "escabeçar",
    "escabeçaria": "escabeçar",
    "escabeçariam": "escabeçar",
    "escabeçarias": "escabeçar",
    "escabeçarmo": "escabeçar",
    "escabeçarmos": "escabeçar",
    "escabeçará": "escabeçar",
    "escabeçarás": "escabeçar",
    "escabeçarão": "escabeçar",
    "escabeçaríamos": "escabeçar",
    "escabeçaríeis": "escabeçar",
    "escabeças": "escabeçar",
    "escabeçasse": "escabeçar",
    "escabeçassem": "escabeçar",
    "escabeçasses": "escabeçar",
    "escabeçaste": "escabeçar",
    "escabeçastes": "escabeçar",
    "escabeçava": "escabeçar",
    "escabeçavam": "escabeçar",
    "escabeçavas": "escabeçar",
    "escabeço": "escabeçar",
    "escabeçou": "escabeçar",
    "escabeçá": "escabeçar",
    "escabeçámo": "escabeçar",
    "escabeçámos": "escabeçar",
    "escabeçáramo": "escabeçar",
    "escabeçáramos": "escabeçar",
    "escabeçárei": "escabeçar",
    "escabeçáreis": "escabeçar",
    "escabeçásseis": "escabeçar",
    "escabeçássemos": "escabeçar",
    "escabeçávamo": "escabeçar",
    "escabeçávamos": "escabeçar",
    "escabeçávei": "escabeçar",
    "escabeçáveis": "escabeçar",
    "escabicha": "escabichar",
    "escabichada": "escabichar",
    "escabichadas": "escabichar",
    "escabichado": "escabichar",
    "escabichadora": "escabichador",
    "escabichadoras": "escabichador",
    "escabichadores": "escabichador",
    "escabichados": "escabichar",
    "escabichai": "escabichar",
    "escabichais": "escabichar",
    "escabicham": "escabichar",
    "escabichamo": "escabichar",
    "escabichamos": "escabichar",
    "escabichando": "escabichar",
    "escabichara": "escabichar",
    "escabicharam": "escabichar",
    "escabicharas": "escabichar",
    "escabicharde": "escabichar",
    "escabichardes": "escabichar",
    "escabichare": "escabichar",
    "escabicharei": "escabichar",
    "escabichareis": "escabichar",
    "escabicharem": "escabichar",
    "escabicharemos": "escabichar",
    "escabichares": "escabichar",
    "escabicharia": "escabichar",
    "escabichariam": "escabichar",
    "escabicharias": "escabichar",
    "escabicharmo": "escabichar",
    "escabicharmos": "escabichar",
    "escabichará": "escabichar",
    "escabicharás": "escabichar",
    "escabicharão": "escabichar",
    "escabicharíamos": "escabichar",
    "escabicharíeis": "escabichar",
    "escabichas": "escabichar",
    "escabichasse": "escabichar",
    "escabichassem": "escabichar",
    "escabichasses": "escabichar",
    "escabichaste": "escabichar",
    "escabichastes": "escabichar",
    "escabichava": "escabichar",
    "escabichavam": "escabichar",
    "escabichavas": "escabichar",
    "escabiche": "escabichar",
    "escabichei": "escabichar",
    "escabicheiras": "escabicheira",
    "escabicheis": "escabichar",
    "escabichem": "escabichar",
    "escabichemo": "escabichar",
    "escabichemos": "escabichar",
    "escabiches": "escabichar",
    "escabicho": "escabichar",
    "escabichou": "escabichar",
    "escabichá": "escabichar",
    "escabichámo": "escabichar",
    "escabichámos": "escabichar",
    "escabicháramo": "escabichar",
    "escabicháramos": "escabichar",
    "escabichárei": "escabichar",
    "escabicháreis": "escabichar",
    "escabichásseis": "escabichar",
    "escabichássemos": "escabichar",
    "escabichávamo": "escabichar",
    "escabichávamos": "escabichar",
    "escabichávei": "escabichar",
    "escabicháveis": "escabichar",
    "escabiosa": "escabioso",
    "escabiosas": "escabioso",
    "escabiosos": "escabioso",
    "escabra": "escabro",
    "escabras": "escabro",
    "escabreada": "escabrear",
    "escabreadas": "escabrear",
    "escabreado": "escabrear",
    "escabreados": "escabrear",
    "escabreai": "escabrear",
    "escabreais": "escabrear",
    "escabreamo": "escabrear",
    "escabreamos": "escabrear",
    "escabreando": "escabrear",
    "escabreara": "escabrear",
    "escabrearam": "escabrear",
    "escabrearas": "escabrear",
    "escabreardes": "escabrear",
    "escabrearei": "escabrear",
    "escabreareis": "escabrear",
    "escabrearem": "escabrear",
    "escabrearemos": "escabrear",
    "escabreares": "escabrear",
    "escabrearia": "escabrear",
    "escabreariam": "escabrear",
    "escabrearias": "escabrear",
    "escabrearmo": "escabrear",
    "escabrearmos": "escabrear",
    "escabreará": "escabrear",
    "escabrearás": "escabrear",
    "escabrearão": "escabrear",
    "escabrearíamos": "escabrear",
    "escabrearíeis": "escabrear",
    "escabreasse": "escabrear",
    "escabreassem": "escabrear",
    "escabreasses": "escabrear",
    "escabreaste": "escabrear",
    "escabreastes": "escabrear",
    "escabreava": "escabrear",
    "escabreavam": "escabrear",
    "escabreavas": "escabrear",
    "escabreações": "escabreação",
    "escabreei": "escabrear",
    "escabreeis": "escabrear",
    "escabreemo": "escabrear",
    "escabreemos": "escabrear",
    "escabreia": "escabrear",
    "escabreiam": "escabrear",
    "escabreias": "escabrear",
    "escabreie": "escabrear",
    "escabreiem": "escabrear",
    "escabreies": "escabrear",
    "escabreio": "escabrear",
    "escabreou": "escabrear",
    "escabreámo": "escabrear",
    "escabreámos": "escabrear",
    "escabreáramo": "escabrear",
    "escabreáramos": "escabrear",
    "escabreáreis": "escabrear",
    "escabreásseis": "escabrear",
    "escabreássemos": "escabrear",
    "escabreávamo": "escabrear",
    "escabreávamos": "escabrear",
    "escabreáveis": "escabrear",
    "escabros": "escabro",
    "escabrosa": "escabroso",
    "escabrosas": "escabroso",
    "escabrosidades": "escabrosidade",
    "escabrosos": "escabroso",
    "escabuja": "escabujar",
    "escabujada": "escabujar",
    "escabujadas": "escabujar",
    "escabujado": "escabujar",
    "escabujados": "escabujar",
    "escabujai": "escabujar",
    "escabujais": "escabujar",
    "escabujam": "escabujar",
    "escabujamo": "escabujar",
    "escabujamos": "escabujar",
    "escabujando": "escabujar",
    "escabujara": "escabujar",
    "escabujaram": "escabujar",
    "escabujaras": "escabujar",
    "escabujardes": "escabujar",
    "escabujarei": "escabujar",
    "escabujareis": "escabujar",
    "escabujarem": "escabujar",
    "escabujaremos": "escabujar",
    "escabujares": "escabujar",
    "escabujaria": "escabujar",
    "escabujariam": "escabujar",
    "escabujarias": "escabujar",
    "escabujarmo": "escabujar",
    "escabujarmos": "escabujar",
    "escabujará": "escabujar",
    "escabujarás": "escabujar",
    "escabujarão": "escabujar",
    "escabujaríamos": "escabujar",
    "escabujaríeis": "escabujar",
    "escabujas": "escabujar",
    "escabujasse": "escabujar",
    "escabujassem": "escabujar",
    "escabujasses": "escabujar",
    "escabujaste": "escabujar",
    "escabujastes": "escabujar",
    "escabujava": "escabujar",
    "escabujavam": "escabujar",
    "escabujavas": "escabujar",
    "escabuje": "escabujar",
    "escabujei": "escabujar",
    "escabujeis": "escabujar",
    "escabujem": "escabujar",
    "escabujemo": "escabujar",
    "escabujemos": "escabujar",
    "escabujes": "escabujar",
    "escabujo": "escabujar",
    "escabujou": "escabujar",
    "escabujámo": "escabujar",
    "escabujámos": "escabujar",
    "escabujáramo": "escabujar",
    "escabujáramos": "escabujar",
    "escabujáreis": "escabujar",
    "escabujásseis": "escabujar",
    "escabujássemos": "escabujar",
    "escabujávamo": "escabujar",
    "escabujávamos": "escabujar",
    "escabujáveis": "escabujar",
    "escabulha": "escabulhar",
    "escabulhada": "escabulhar",
    "escabulhadas": "escabulhar",
    "escabulhado": "escabulhar",
    "escabulhados": "escabulhar",
    "escabulhai": "escabulhar",
    "escabulhais": "escabulhar",
    "escabulham": "escabulhar",
    "escabulhamo": "escabulhar",
    "escabulhamos": "escabulhar",
    "escabulhando": "escabulhar",
    "escabulhara": "escabulhar",
    "escabulharam": "escabulhar",
    "escabulharas": "escabulhar",
    "escabulharde": "escabulhar",
    "escabulhardes": "escabulhar",
    "escabulhare": "escabulhar",
    "escabulharei": "escabulhar",
    "escabulhareis": "escabulhar",
    "escabulharem": "escabulhar",
    "escabulharemos": "escabulhar",
    "escabulhares": "escabulhar",
    "escabulharia": "escabulhar",
    "escabulhariam": "escabulhar",
    "escabulharias": "escabulhar",
    "escabulharmo": "escabulhar",
    "escabulharmos": "escabulhar",
    "escabulhará": "escabulhar",
    "escabulharás": "escabulhar",
    "escabulharão": "escabulhar",
    "escabulharíamos": "escabulhar",
    "escabulharíeis": "escabulhar",
    "escabulhas": "escabulhar",
    "escabulhasse": "escabulhar",
    "escabulhassem": "escabulhar",
    "escabulhasses": "escabulhar",
    "escabulhaste": "escabulhar",
    "escabulhastes": "escabulhar",
    "escabulhava": "escabulhar",
    "escabulhavam": "escabulhar",
    "escabulhavas": "escabulhar",
    "escabulhe": "escabulhar",
    "escabulhei": "escabulhar",
    "escabulheis": "escabulhar",
    "escabulhem": "escabulhar",
    "escabulhemo": "escabulhar",
    "escabulhemos": "escabulhar",
    "escabulhes": "escabulhar",
    "escabulho": "escabulhar",
    "escabulhos": "escabulho",
    "escabulhou": "escabulhar",
    "escabulhá": "escabulhar",
    "escabulhámo": "escabulhar",
    "escabulhámos": "escabulhar",
    "escabulháramo": "escabulhar",
    "escabulháramos": "escabulhar",
    "escabulhárei": "escabulhar",
    "escabulháreis": "escabulhar",
    "escabulhásseis": "escabulhar",
    "escabulhássemos": "escabulhar",
    "escabulhávamo": "escabulhar",
    "escabulhávamos": "escabulhar",
    "escabulhávei": "escabulhar",
    "escabulháveis": "escabulhar",
    "escaca": "escacar",
    "escacada": "escacar",
    "escacadas": "escacar",
    "escacado": "escacar",
    "escacados": "escacar",
    "escacai": "escacar",
    "escacais": "escacar",
    "escacam": "escacar",
    "escacamo": "escacar",
    "escacamos": "escacar",
    "escacando": "escacar",
    "escacara": "escacar",
    "escacaram": "escacar",
    "escacaras": "escacar",
    "escacarde": "escacar",
    "escacardes": "escacar",
    "escacare": "escacar",
    "escacarei": "escacar",
    "escacareis": "escacar",
    "escacarem": "escacar",
    "escacaremos": "escacar",
    "escacares": "escacar",
    "escacaria": "escacar",
    "escacariam": "escacar",
    "escacarias": "escacar",
    "escacarmo": "escacar",
    "escacarmos": "escacar",
    "escacará": "escacar",
    "escacarás": "escacar",
    "escacarão": "escacar",
    "escacaríamos": "escacar",
    "escacaríeis": "escacar",
    "escacas": "escacar",
    "escacasse": "escacar",
    "escacassem": "escacar",
    "escacasses": "escacar",
    "escacaste": "escacar",
    "escacastes": "escacar",
    "escacava": "escacar",
    "escacavam": "escacar",
    "escacavas": "escacar",
    "escacha": "escachar",
    "escachada": "escachar",
    "escachadas": "escachar",
    "escachado": "escachar",
    "escachados": "escachar",
    "escachai": "escachar",
    "escachais": "escachar",
    "escacham": "escachar",
    "escachamo": "escachar",
    "escachamos": "escachar",
    "escachando": "escachar",
    "escachara": "escachar",
    "escacharam": "escachar",
    "escacharas": "escachar",
    "escacharde": "escachar",
    "escachardes": "escachar",
    "escachare": "escachar",
    "escacharei": "escachar",
    "escachareis": "escachar",
    "escacharem": "escachar",
    "escacharemos": "escachar",
    "escachares": "escachar",
    "escacharia": "escachar",
    "escachariam": "escachar",
    "escacharias": "escachar",
    "escacharmo": "escachar",
    "escacharmos": "escachar",
    "escachará": "escachar",
    "escacharás": "escachar",
    "escacharão": "escachar",
    "escacharíamos": "escachar",
    "escacharíeis": "escachar",
    "escachas": "escachar",
    "escachasse": "escachar",
    "escachassem": "escachar",
    "escachasses": "escachar",
    "escachaste": "escachar",
    "escachastes": "escachar",
    "escachava": "escachar",
    "escachavam": "escachar",
    "escachavas": "escachar",
    "escache": "escachar",
    "escachei": "escachar",
    "escacheis": "escachar",
    "escachem": "escachar",
    "escachemo": "escachar",
    "escachemos": "escachar",
    "escaches": "escachar",
    "escacho": "escachar",
    "escachoa": "escachoar",
    "escachoada": "escachoar",
    "escachoadas": "escachoar",
    "escachoado": "escachoar",
    "escachoados": "escachoar",
    "escachoai": "escachoar",
    "escachoais": "escachoar",
    "escachoam": "escachoar",
    "escachoamo": "escachoar",
    "escachoamos": "escachoar",
    "escachoando": "escachoar",
    "escachoantes": "escachoante",
    "escachoara": "escachoar",
    "escachoaram": "escachoar",
    "escachoaras": "escachoar",
    "escachoardes": "escachoar",
    "escachoarei": "escachoar",
    "escachoareis": "escachoar",
    "escachoarem": "escachoar",
    "escachoaremos": "escachoar",
    "escachoares": "escachoar",
    "escachoaria": "escachoar",
    "escachoariam": "escachoar",
    "escachoarias": "escachoar",
    "escachoarmo": "escachoar",
    "escachoarmos": "escachoar",
    "escachoará": "escachoar",
    "escachoarás": "escachoar",
    "escachoarão": "escachoar",
    "escachoaríamos": "escachoar",
    "escachoaríeis": "escachoar",
    "escachoas": "escachoar",
    "escachoasse": "escachoar",
    "escachoassem": "escachoar",
    "escachoasses": "escachoar",
    "escachoaste": "escachoar",
    "escachoastes": "escachoar",
    "escachoava": "escachoar",
    "escachoavam": "escachoar",
    "escachoavas": "escachoar",
    "escachoe": "escachoar",
    "escachoei": "escachoar",
    "escachoeis": "escachoar",
    "escachoem": "escachoar",
    "escachoemo": "escachoar",
    "escachoemos": "escachoar",
    "escachoes": "escachoar",
    "escachola": "escacholar",
    "escacholada": "escacholar",
    "escacholadas": "escacholar",
    "escacholado": "escacholar",
    "escacholados": "escacholar",
    "escacholai": "escacholar",
    "escacholais": "escacholar",
    "escacholam": "escacholar",
    "escacholamo": "escacholar",
    "escacholamos": "escacholar",
    "escacholando": "escacholar",
    "escacholara": "escacholar",
    "escacholaram": "escacholar",
    "escacholaras": "escacholar",
    "escacholarde": "escacholar",
    "escacholardes": "escacholar",
    "escacholare": "escacholar",
    "escacholarei": "escacholar",
    "escacholareis": "escacholar",
    "escacholarem": "escacholar",
    "escacholaremos": "escacholar",
    "escacholares": "escacholar",
    "escacholaria": "escacholar",
    "escacholariam": "escacholar",
    "escacholarias": "escacholar",
    "escacholarmo": "escacholar",
    "escacholarmos": "escacholar",
    "escacholará": "escacholar",
    "escacholarás": "escacholar",
    "escacholarão": "escacholar",
    "escacholaríamos": "escacholar",
    "escacholaríeis": "escacholar",
    "escacholas": "escacholar",
    "escacholasse": "escacholar",
    "escacholassem": "escacholar",
    "escacholasses": "escacholar",
    "escacholaste": "escacholar",
    "escacholastes": "escacholar",
    "escacholava": "escacholar",
    "escacholavam": "escacholar",
    "escacholavas": "escacholar",
    "escachole": "escacholar",
    "escacholei": "escacholar",
    "escacholeis": "escacholar",
    "escacholem": "escacholar",
    "escacholemo": "escacholar",
    "escacholemos": "escacholar",
    "escacholes": "escacholar",
    "escacholo": "escacholar",
    "escacholou": "escacholar",
    "escacholá": "escacholar",
    "escacholámo": "escacholar",
    "escacholámos": "escacholar",
    "escacholáramo": "escacholar",
    "escacholáramos": "escacholar",
    "escacholárei": "escacholar",
    "escacholáreis": "escacholar",
    "escacholásseis": "escacholar",
    "escacholássemos": "escacholar",
    "escacholávamo": "escacholar",
    "escacholávamos": "escacholar",
    "escacholávei": "escacholar",
    "escacholáveis": "escacholar",
    "escachoo": "escachoar",
    "escachoou": "escachoar",
    "escachou": "escachar",
    "escachouce": "escachouçar",
    "escachoucei": "escachouçar",
    "escachouceis": "escachouçar",
    "escachoucem": "escachouçar",
    "escachoucemo": "escachouçar",
    "escachoucemos": "escachouçar",
    "escachouces": "escachouçar",
    "escachouça": "escachouçar",
    "escachouçada": "escachouçar",
    "escachouçadas": "escachouçar",
    "escachouçado": "escachouçar",
    "escachouçados": "escachouçar",
    "escachouçai": "escachouçar",
    "escachouçais": "escachouçar",
    "escachouçam": "escachouçar",
    "escachouçamo": "escachouçar",
    "escachouçamos": "escachouçar",
    "escachouçando": "escachouçar",
    "escachouçara": "escachouçar",
    "escachouçaram": "escachouçar",
    "escachouçaras": "escachouçar",
    "escachouçarde": "escachouçar",
    "escachouçardes": "escachouçar",
    "escachouçare": "escachouçar",
    "escachouçarei": "escachouçar",
    "escachouçareis": "escachouçar",
    "escachouçarem": "escachouçar",
    "escachouçaremos": "escachouçar",
    "escachouçares": "escachouçar",
    "escachouçaria": "escachouçar",
    "escachouçariam": "escachouçar",
    "escachouçarias": "escachouçar",
    "escachouçarmo": "escachouçar",
    "escachouçarmos": "escachouçar",
    "escachouçará": "escachouçar",
    "escachouçarás": "escachouçar",
    "escachouçarão": "escachouçar",
    "escachouçaríamos": "escachouçar",
    "escachouçaríeis": "escachouçar",
    "escachouças": "escachouçar",
    "escachouçasse": "escachouçar",
    "escachouçassem": "escachouçar",
    "escachouçasses": "escachouçar",
    "escachouçaste": "escachouçar",
    "escachouçastes": "escachouçar",
    "escachouçava": "escachouçar",
    "escachouçavam": "escachouçar",
    "escachouçavas": "escachouçar",
    "escachouço": "escachouçar",
    "escachouçou": "escachouçar",
    "escachouçá": "escachouçar",
    "escachouçámo": "escachouçar",
    "escachouçámos": "escachouçar",
    "escachouçáramo": "escachouçar",
    "escachouçáramos": "escachouçar",
    "escachouçárei": "escachouçar",
    "escachouçáreis": "escachouçar",
    "escachouçásseis": "escachouçar",
    "escachouçássemos": "escachouçar",
    "escachouçávamo": "escachouçar",
    "escachouçávamos": "escachouçar",
    "escachouçávei": "escachouçar",
    "escachouçáveis": "escachouçar",
    "escachoámo": "escachoar",
    "escachoámos": "escachoar",
    "escachoáramo": "escachoar",
    "escachoáramos": "escachoar",
    "escachoáreis": "escachoar",
    "escachoásseis": "escachoar",
    "escachoássemos": "escachoar",
    "escachoávamo": "escachoar",
    "escachoávamos": "escachoar",
    "escachoáveis": "escachoar",
    "escachá": "escachar",
    "escachámo": "escachar",
    "escachámos": "escachar",
    "escacháramo": "escachar",
    "escacháramos": "escachar",
    "escachárei": "escachar",
    "escacháreis": "escachar",
    "escachásseis": "escachar",
    "escachássemos": "escachar",
    "escachávamo": "escachar",
    "escachávamos": "escachar",
    "escachávei": "escachar",
    "escacháveis": "escachar",
    "escaco": "escacar",
    "escacou": "escacar",
    "escacá": "escacar",
    "escacámo": "escacar",
    "escacámos": "escacar",
    "escacáramo": "escacar",
    "escacáramos": "escacar",
    "escacárei": "escacar",
    "escacáreis": "escacar",
    "escacásseis": "escacar",
    "escacássemos": "escacar",
    "escacávamo": "escacar",
    "escacávamos": "escacar",
    "escacávei": "escacar",
    "escacáveis": "escacar",
    "escadarias": "escadaria",
    "escadas": "escada",
    "escadeada": "escadear",
    "escadeadas": "escadear",
    "escadeado": "escadear",
    "escadeados": "escadear",
    "escadeai": "escadear",
    "escadeais": "escadear",
    "escadeamo": "escadear",
    "escadeamos": "escadear",
    "escadeando": "escadear",
    "escadeara": "escadear",
    "escadearam": "escadear",
    "escadearas": "escadear",
    "escadearde": "escadear",
    "escadeardes": "escadear",
    "escadeare": "escadear",
    "escadearei": "escadear",
    "escadeareis": "escadear",
    "escadearem": "escadear",
    "escadearemos": "escadear",
    "escadeares": "escadear",
    "escadearia": "escadear",
    "escadeariam": "escadear",
    "escadearias": "escadear",
    "escadearmo": "escadear",
    "escadearmos": "escadear",
    "escadeará": "escadear",
    "escadearás": "escadear",
    "escadearão": "escadear",
    "escadearíamos": "escadear",
    "escadearíeis": "escadear",
    "escadeasse": "escadear",
    "escadeassem": "escadear",
    "escadeasses": "escadear",
    "escadeaste": "escadear",
    "escadeastes": "escadear",
    "escadeava": "escadear",
    "escadeavam": "escadear",
    "escadeavas": "escadear",
    "escadeei": "escadear",
    "escadeeis": "escadear",
    "escadeemo": "escadear",
    "escadeemos": "escadear",
    "escadeia": "escadear",
    "escadeiam": "escadear",
    "escadeias": "escadear",
    "escadeie": "escadear",
    "escadeiem": "escadear",
    "escadeies": "escadear",
    "escadeio": "escadear",
    "escadeira": "escadeirar",
    "escadeirada": "escadeirar",
    "escadeiradas": "escadeirar",
    "escadeirado": "escadeirar",
    "escadeirados": "escadeirar",
    "escadeirai": "escadeirar",
    "escadeirais": "escadeirar",
    "escadeiram": "escadeirar",
    "escadeiramo": "escadeirar",
    "escadeiramos": "escadeirar",
    "escadeirando": "escadeirar",
    "escadeirara": "escadeirar",
    "escadeiraram": "escadeirar",
    "escadeiraras": "escadeirar",
    "escadeirarde": "escadeirar",
    "escadeirardes": "escadeirar",
    "escadeirare": "escadeirar",
    "escadeirarei": "escadeirar",
    "escadeirareis": "escadeirar",
    "escadeirarem": "escadeirar",
    "escadeiraremos": "escadeirar",
    "escadeirares": "escadeirar",
    "escadeiraria": "escadeirar",
    "escadeirariam": "escadeirar",
    "escadeirarias": "escadeirar",
    "escadeirarmo": "escadeirar",
    "escadeirarmos": "escadeirar",
    "escadeirará": "escadeirar",
    "escadeirarás": "escadeirar",
    "escadeirarão": "escadeirar",
    "escadeiraríamos": "escadeirar",
    "escadeiraríeis": "escadeirar",
    "escadeiras": "escadeirar",
    "escadeirasse": "escadeirar",
    "escadeirassem": "escadeirar",
    "escadeirasses": "escadeirar",
    "escadeiraste": "escadeirar",
    "escadeirastes": "escadeirar",
    "escadeirava": "escadeirar",
    "escadeiravam": "escadeirar",
    "escadeiravas": "escadeirar",
    "escadeire": "escadeirar",
    "escadeirei": "escadeirar",
    "escadeireis": "escadeirar",
    "escadeirem": "escadeirar",
    "escadeiremo": "escadeirar",
    "escadeiremos": "escadeirar",
    "escadeires": "escadeirar",
    "escadeiro": "escadeirar",
    "escadeirou": "escadeirar",
    "escadeirá": "escadeirar",
    "escadeirámo": "escadeirar",
    "escadeirámos": "escadeirar",
    "escadeiráramo": "escadeirar",
    "escadeiráramos": "escadeirar",
    "escadeirárei": "escadeirar",
    "escadeiráreis": "escadeirar",
    "escadeirásseis": "escadeirar",
    "escadeirássemos": "escadeirar",
    "escadeirávamo": "escadeirar",
    "escadeirávamos": "escadeirar",
    "escadeirávei": "escadeirar",
    "escadeiráveis": "escadeirar",
    "escadelece": "escadelecer",
    "escadelecei": "escadelecer",
    "escadeleceis": "escadelecer",
    "escadelecem": "escadelecer",
    "escadelecemo": "escadelecer",
    "escadelecemos": "escadelecer",
    "escadelecendo": "escadelecer",
    "escadelecera": "escadelecer",
    "escadeleceram": "escadelecer",
    "escadeleceras": "escadelecer",
    "escadelecerdes": "escadelecer",
    "escadelecerei": "escadelecer",
    "escadelecereis": "escadelecer",
    "escadelecerem": "escadelecer",
    "escadeleceremos": "escadelecer",
    "escadeleceres": "escadelecer",
    "escadeleceria": "escadelecer",
    "escadeleceriam": "escadelecer",
    "escadelecerias": "escadelecer",
    "escadelecermo": "escadelecer",
    "escadelecermos": "escadelecer",
    "escadelecerá": "escadelecer",
    "escadelecerás": "escadelecer",
    "escadelecerão": "escadelecer",
    "escadeleceríamos": "escadelecer",
    "escadeleceríeis": "escadelecer",
    "escadeleces": "escadelecer",
    "escadelecesse": "escadelecer",
    "escadelecessem": "escadelecer",
    "escadelecesses": "escadelecer",
    "escadeleceste": "escadelecer",
    "escadelecestes": "escadelecer",
    "escadeleceu": "escadelecer",
    "escadeleci": "escadelecer",
    "escadelecia": "escadelecer",
    "escadeleciam": "escadelecer",
    "escadelecias": "escadelecer",
    "escadelecida": "escadelecer",
    "escadelecidas": "escadelecer",
    "escadelecido": "escadelecer",
    "escadelecidos": "escadelecer",
    "escadelecêramo": "escadelecer",
    "escadelecêramos": "escadelecer",
    "escadelecêreis": "escadelecer",
    "escadelecêsseis": "escadelecer",
    "escadelecêssemos": "escadelecer",
    "escadelecíamo": "escadelecer",
    "escadelecíamos": "escadelecer",
    "escadelecíeis": "escadelecer",
    "escadeleça": "escadelecer",
    "escadeleçais": "escadelecer",
    "escadeleçam": "escadelecer",
    "escadeleçamo": "escadelecer",
    "escadeleçamos": "escadelecer",
    "escadeleças": "escadelecer",
    "escadeleço": "escadelecer",
    "escadeou": "escadear",
    "escadeá": "escadear",
    "escadeámo": "escadear",
    "escadeámos": "escadear",
    "escadeáramo": "escadear",
    "escadeáramos": "escadear",
    "escadeárei": "escadear",
    "escadeáreis": "escadear",
    "escadeásseis": "escadear",
    "escadeássemos": "escadear",
    "escadeávamo": "escadear",
    "escadeávamos": "escadear",
    "escadeávei": "escadear",
    "escadeáveis": "escadear",
    "escadinha": "escada",
    "escadinhas": "escadinha",
    "escadita": "escada",
    "escaditas": "escada",
    "escadotes": "escadote",
    "escadrace": "escadraçar",
    "escadracei": "escadraçar",
    "escadraceis": "escadraçar",
    "escadracem": "escadraçar",
    "escadracemo": "escadraçar",
    "escadracemos": "escadraçar",
    "escadraces": "escadraçar",
    "escadraça": "escadraçar",
    "escadraçada": "escadraçar",
    "escadraçadas": "escadraçar",
    "escadraçado": "escadraçar",
    "escadraçados": "escadraçar",
    "escadraçai": "escadraçar",
    "escadraçais": "escadraçar",
    "escadraçam": "escadraçar",
    "escadraçamo": "escadraçar",
    "escadraçamos": "escadraçar",
    "escadraçando": "escadraçar",
    "escadraçara": "escadraçar",
    "escadraçaram": "escadraçar",
    "escadraçaras": "escadraçar",
    "escadraçarde": "escadraçar",
    "escadraçardes": "escadraçar",
    "escadraçare": "escadraçar",
    "escadraçarei": "escadraçar",
    "escadraçareis": "escadraçar",
    "escadraçarem": "escadraçar",
    "escadraçaremos": "escadraçar",
    "escadraçares": "escadraçar",
    "escadraçaria": "escadraçar",
    "escadraçariam": "escadraçar",
    "escadraçarias": "escadraçar",
    "escadraçarmo": "escadraçar",
    "escadraçarmos": "escadraçar",
    "escadraçará": "escadraçar",
    "escadraçarás": "escadraçar",
    "escadraçarão": "escadraçar",
    "escadraçaríamos": "escadraçar",
    "escadraçaríeis": "escadraçar",
    "escadraças": "escadraçar",
    "escadraçasse": "escadraçar",
    "escadraçassem": "escadraçar",
    "escadraçasses": "escadraçar",
    "escadraçaste": "escadraçar",
    "escadraçastes": "escadraçar",
    "escadraçava": "escadraçar",
    "escadraçavam": "escadraçar",
    "escadraçavas": "escadraçar",
    "escadraço": "escadraçar",
    "escadraçou": "escadraçar",
    "escadraçá": "escadraçar",
    "escadraçámo": "escadraçar",
    "escadraçámos": "escadraçar",
    "escadraçáramo": "escadraçar",
    "escadraçáramos": "escadraçar",
    "escadraçárei": "escadraçar",
    "escadraçáreis": "escadraçar",
    "escadraçásseis": "escadraçar",
    "escadraçássemos": "escadraçar",
    "escadraçávamo": "escadraçar",
    "escadraçávamos": "escadraçar",
    "escadraçávei": "escadraçar",
    "escadraçáveis": "escadraçar",
    "escadórios": "escadório",
    "escadões": "escadão",
    "escafandristas": "escafandrista",
    "escafandros": "escafandro",
    "escafeda": "escafeder",
    "escafedais": "escafeder",
    "escafedam": "escafeder",
    "escafedamo": "escafeder",
    "escafedamos": "escafeder",
    "escafedas": "escafeder",
    "escafede": "escafeder",
    "escafedei": "escafeder",
    "escafedeis": "escafeder",
    "escafedem": "escafeder",
    "escafedemo": "escafeder",
    "escafedemos": "escafeder",
    "escafedendo": "escafeder",
    "escafedera": "escafeder",
    "escafederam": "escafeder",
    "escafederas": "escafeder",
    "escafederde": "escafeder",
    "escafederdes": "escafeder",
    "escafedere": "escafeder",
    "escafederei": "escafeder",
    "escafedereis": "escafeder",
    "escafederem": "escafeder",
    "escafederemos": "escafeder",
    "escafederes": "escafeder",
    "escafederia": "escafeder",
    "escafederiam": "escafeder",
    "escafederias": "escafeder",
    "escafedermo": "escafeder",
    "escafedermos": "escafeder",
    "escafederá": "escafeder",
    "escafederás": "escafeder",
    "escafederão": "escafeder",
    "escafederíamos": "escafeder",
    "escafederíeis": "escafeder",
    "escafedes": "escafeder",
    "escafedesse": "escafeder",
    "escafedessem": "escafeder",
    "escafedesses": "escafeder",
    "escafedeste": "escafeder",
    "escafedestes": "escafeder",
    "escafedeu": "escafeder",
    "escafedi": "escafeder",
    "escafedia": "escafeder",
    "escafediam": "escafeder",
    "escafedias": "escafeder",
    "escafedida": "escafeder",
    "escafedidas": "escafeder",
    "escafedido": "escafeder",
    "escafedidos": "escafeder",
    "escafedo": "escafeder",
    "escafedê": "escafeder",
    "escafedêramo": "escafeder",
    "escafedêramos": "escafeder",
    "escafedêrei": "escafeder",
    "escafedêreis": "escafeder",
    "escafedêsseis": "escafeder",
    "escafedêssemos": "escafeder",
    "escafedíamo": "escafeder",
    "escafedíamos": "escafeder",
    "escafedíei": "escafeder",
    "escafedíeis": "escafeder",
    "escafoladas": "escafolada",
    "escafóides": "escafóide",
    "escafópodes": "escafópode",
    "escagace": "escagaçar",
    "escagacei": "escagaçar",
    "escagaceis": "escagaçar",
    "escagacem": "escagaçar",
    "escagacemo": "escagaçar",
    "escagacemos": "escagaçar",
    "escagaces": "escagaçar",
    "escagarrinha": "escagarrinhar",
    "escagarrinhada": "escagarrinhar",
    "escagarrinhadas": "escagarrinhar",
    "escagarrinhado": "escagarrinhar",
    "escagarrinhados": "escagarrinhar",
    "escagarrinhai": "escagarrinhar",
    "escagarrinhais": "escagarrinhar",
    "escagarrinham": "escagarrinhar",
    "escagarrinhamo": "escagarrinhar",
    "escagarrinhamos": "escagarrinhar",
    "escagarrinhando": "escagarrinhar",
    "escagarrinhara": "escagarrinhar",
    "escagarrinharam": "escagarrinhar",
    "escagarrinharas": "escagarrinhar",
    "escagarrinharde": "escagarrinhar",
    "escagarrinhardes": "escagarrinhar",
    "escagarrinhare": "escagarrinhar",
    "escagarrinharei": "escagarrinhar",
    "escagarrinhareis": "escagarrinhar",
    "escagarrinharem": "escagarrinhar",
    "escagarrinharemos": "escagarrinhar",
    "escagarrinhares": "escagarrinhar",
    "escagarrinharia": "escagarrinhar",
    "escagarrinhariam": "escagarrinhar",
    "escagarrinharias": "escagarrinhar",
    "escagarrinharmo": "escagarrinhar",
    "escagarrinharmos": "escagarrinhar",
    "escagarrinhará": "escagarrinhar",
    "escagarrinharás": "escagarrinhar",
    "escagarrinharão": "escagarrinhar",
    "escagarrinharíamos": "escagarrinhar",
    "escagarrinharíeis": "escagarrinhar",
    "escagarrinhas": "escagarrinhar",
    "escagarrinhasse": "escagarrinhar",
    "escagarrinhassem": "escagarrinhar",
    "escagarrinhasses": "escagarrinhar",
    "escagarrinhaste": "escagarrinhar",
    "escagarrinhastes": "escagarrinhar",
    "escagarrinhava": "escagarrinhar",
    "escagarrinhavam": "escagarrinhar",
    "escagarrinhavas": "escagarrinhar",
    "escagarrinhe": "escagarrinhar",
    "escagarrinhei": "escagarrinhar",
    "escagarrinheis": "escagarrinhar",
    "escagarrinhem": "escagarrinhar",
    "escagarrinhemo": "escagarrinhar",
    "escagarrinhemos": "escagarrinhar",
    "escagarrinhes": "escagarrinhar",
    "escagarrinho": "escagarrinhar",
    "escagarrinhou": "escagarrinhar",
    "escagarrinhá": "escagarrinhar",
    "escagarrinhámo": "escagarrinhar",
    "escagarrinhámos": "escagarrinhar",
    "escagarrinháramo": "escagarrinhar",
    "escagarrinháramos": "escagarrinhar",
    "escagarrinhárei": "escagarrinhar",
    "escagarrinháreis": "escagarrinhar",
    "escagarrinhásseis": "escagarrinhar",
    "escagarrinhássemos": "escagarrinhar",
    "escagarrinhávamo": "escagarrinhar",
    "escagarrinhávamos": "escagarrinhar",
    "escagarrinhávei": "escagarrinhar",
    "escagarrinháveis": "escagarrinhar",
    "escagaça": "escagaçar",
    "escagaçada": "escagaçar",
    "escagaçadas": "escagaçar",
    "escagaçado": "escagaçar",
    "escagaçados": "escagaçar",
    "escagaçai": "escagaçar",
    "escagaçais": "escagaçar",
    "escagaçam": "escagaçar",
    "escagaçamo": "escagaçar",
    "escagaçamos": "escagaçar",
    "escagaçando": "escagaçar",
    "escagaçara": "escagaçar",
    "escagaçaram": "escagaçar",
    "escagaçaras": "escagaçar",
    "escagaçarde": "escagaçar",
    "escagaçardes": "escagaçar",
    "escagaçare": "escagaçar",
    "escagaçarei": "escagaçar",
    "escagaçareis": "escagaçar",
    "escagaçarem": "escagaçar",
    "escagaçaremos": "escagaçar",
    "escagaçares": "escagaçar",
    "escagaçaria": "escagaçar",
    "escagaçariam": "escagaçar",
    "escagaçarias": "escagaçar",
    "escagaçarmo": "escagaçar",
    "escagaçarmos": "escagaçar",
    "escagaçará": "escagaçar",
    "escagaçarás": "escagaçar",
    "escagaçarão": "escagaçar",
    "escagaçaríamos": "escagaçar",
    "escagaçaríeis": "escagaçar",
    "escagaças": "escagaçar",
    "escagaçasse": "escagaçar",
    "escagaçassem": "escagaçar",
    "escagaçasses": "escagaçar",
    "escagaçaste": "escagaçar",
    "escagaçastes": "escagaçar",
    "escagaçava": "escagaçar",
    "escagaçavam": "escagaçar",
    "escagaçavas": "escagaçar",
    "escagaço": "escagaçar",
    "escagaçou": "escagaçar",
    "escagaçá": "escagaçar",
    "escagaçámo": "escagaçar",
    "escagaçámos": "escagaçar",
    "escagaçáramo": "escagaçar",
    "escagaçáramos": "escagaçar",
    "escagaçárei": "escagaçar",
    "escagaçáreis": "escagaçar",
    "escagaçásseis": "escagaçar",
    "escagaçássemos": "escagaçar",
    "escagaçávamo": "escagaçar",
    "escagaçávamos": "escagaçar",
    "escagaçávei": "escagaçar",
    "escagaçáveis": "escagaçar",
    "escaiola": "escaiolar",
    "escaiolada": "escaiolar",
    "escaioladas": "escaiolar",
    "escaiolado": "escaiolar",
    "escaioladora": "escaiolador",
    "escaioladoras": "escaiolador",
    "escaioladores": "escaiolador",
    "escaiolados": "escaiolar",
    "escaiolai": "escaiolar",
    "escaiolais": "escaiolar",
    "escaiolam": "escaiolar",
    "escaiolamo": "escaiolar",
    "escaiolamos": "escaiolar",
    "escaiolando": "escaiolar",
    "escaiolara": "escaiolar",
    "escaiolaram": "escaiolar",
    "escaiolaras": "escaiolar",
    "escaiolarde": "escaiolar",
    "escaiolardes": "escaiolar",
    "escaiolare": "escaiolar",
    "escaiolarei": "escaiolar",
    "escaiolareis": "escaiolar",
    "escaiolarem": "escaiolar",
    "escaiolaremos": "escaiolar",
    "escaiolares": "escaiolar",
    "escaiolaria": "escaiolar",
    "escaiolariam": "escaiolar",
    "escaiolarias": "escaiolar",
    "escaiolarmo": "escaiolar",
    "escaiolarmos": "escaiolar",
    "escaiolará": "escaiolar",
    "escaiolarás": "escaiolar",
    "escaiolarão": "escaiolar",
    "escaiolaríamos": "escaiolar",
    "escaiolaríeis": "escaiolar",
    "escaiolas": "escaiolar",
    "escaiolasse": "escaiolar",
    "escaiolassem": "escaiolar",
    "escaiolasses": "escaiolar",
    "escaiolaste": "escaiolar",
    "escaiolastes": "escaiolar",
    "escaiolava": "escaiolar",
    "escaiolavam": "escaiolar",
    "escaiolavas": "escaiolar",
    "escaiole": "escaiolar",
    "escaiolei": "escaiolar",
    "escaioleis": "escaiolar",
    "escaiolem": "escaiolar",
    "escaiolemo": "escaiolar",
    "escaiolemos": "escaiolar",
    "escaioles": "escaiolar",
    "escaiolo": "escaiolar",
    "escaiolou": "escaiolar",
    "escaiolá": "escaiolar",
    "escaiolámo": "escaiolar",
    "escaiolámos": "escaiolar",
    "escaioláramo": "escaiolar",
    "escaioláramos": "escaiolar",
    "escaiolárei": "escaiolar",
    "escaioláreis": "escaiolar",
    "escaiolásseis": "escaiolar",
    "escaiolássemos": "escaiolar",
    "escaiolávamo": "escaiolar",
    "escaiolávamos": "escaiolar",
    "escaiolávei": "escaiolar",
    "escaioláveis": "escaiolar",
    "escala": "escalar",
    "escalabitana": "escalabitano",
    "escalabitanas": "escalabitano",
    "escalabitanos": "escalabitano",
    "escalada": "escalar",
    "escaladas": "escalar",
    "escalado": "escalar",
    "escaladora": "escalador",
    "escaladoras": "escalador",
    "escaladores": "escalador",
    "escalados": "escalar",
    "escalafrios": "escalafrio",
    "escalai": "escalar",
    "escalais": "escalar",
    "escalam": "escalar",
    "escalamentos": "escalamento",
    "escalamo": "escalar",
    "escalamos": "escalar",
    "escalando": "escalar",
    "escalara": "escalar",
    "escalaram": "escalar",
    "escalaras": "escalar",
    "escalarde": "escalar",
    "escalardes": "escalar",
    "escalare": "escalar",
    "escalarei": "escalar",
    "escalareis": "escalar",
    "escalarem": "escalar",
    "escalaremos": "escalar",
    "escalares": "escalar",
    "escalaria": "escalar",
    "escalariam": "escalar",
    "escalarias": "escalar",
    "escalarmo": "escalar",
    "escalarmos": "escalar",
    "escalará": "escalar",
    "escalarás": "escalar",
    "escalarão": "escalar",
    "escalaríamos": "escalar",
    "escalaríeis": "escalar",
    "escalas": "escalar",
    "escalasse": "escalar",
    "escalassem": "escalar",
    "escalasses": "escalar",
    "escalaste": "escalar",
    "escalastes": "escalar",
    "escalava": "escalar",
    "escalavam": "escalar",
    "escalavas": "escalar",
    "escalavra": "escalavrar",
    "escalavrada": "escalavrar",
    "escalavradas": "escalavrar",
    "escalavrado": "escalavrar",
    "escalavrados": "escalavrar",
    "escalavraduras": "escalavradura",
    "escalavrai": "escalavrar",
    "escalavrais": "escalavrar",
    "escalavram": "escalavrar",
    "escalavramentos": "escalavramento",
    "escalavramo": "escalavrar",
    "escalavramos": "escalavrar",
    "escalavrando": "escalavrar",
    "escalavrara": "escalavrar",
    "escalavraram": "escalavrar",
    "escalavraras": "escalavrar",
    "escalavrarde": "escalavrar",
    "escalavrardes": "escalavrar",
    "escalavrare": "escalavrar",
    "escalavrarei": "escalavrar",
    "escalavrareis": "escalavrar",
    "escalavrarem": "escalavrar",
    "escalavraremos": "escalavrar",
    "escalavrares": "escalavrar",
    "escalavraria": "escalavrar",
    "escalavrariam": "escalavrar",
    "escalavrarias": "escalavrar",
    "escalavrarmo": "escalavrar",
    "escalavrarmos": "escalavrar",
    "escalavrará": "escalavrar",
    "escalavrarás": "escalavrar",
    "escalavrarão": "escalavrar",
    "escalavraríamos": "escalavrar",
    "escalavraríeis": "escalavrar",
    "escalavras": "escalavrar",
    "escalavrasse": "escalavrar",
    "escalavrassem": "escalavrar",
    "escalavrasses": "escalavrar",
    "escalavraste": "escalavrar",
    "escalavrastes": "escalavrar",
    "escalavrava": "escalavrar",
    "escalavravam": "escalavrar",
    "escalavravas": "escalavrar",
    "escalavre": "escalavrar",
    "escalavrei": "escalavrar",
    "escalavreis": "escalavrar",
    "escalavrem": "escalavrar",
    "escalavremo": "escalavrar",
    "escalavremos": "escalavrar",
    "escalavres": "escalavrar",
    "escalavro": "escalavrar",
    "escalavros": "escalavro",
    "escalavrou": "escalavrar",
    "escalavrá": "escalavrar",
    "escalavrámo": "escalavrar",
    "escalavrámos": "escalavrar",
    "escalavráramo": "escalavrar",
    "escalavráramos": "escalavrar",
    "escalavrárei": "escalavrar",
    "escalavráreis": "escalavrar",
    "escalavrásseis": "escalavrar",
    "escalavrássemos": "escalavrar",
    "escalavrávamo": "escalavrar",
    "escalavrávamos": "escalavrar",
    "escalavrávei": "escalavrar",
    "escalavráveis": "escalavrar",
    "escalda": "escaldar",
    "escaldada": "escaldar",
    "escaldadas": "escaldar",
    "escaldadelas": "escaldadela",
    "escaldadiça": "escaldadiço",
    "escaldadiças": "escaldadiço",
    "escaldadiços": "escaldadiço",
    "escaldado": "escaldar",
    "escaldadora": "escaldador",
    "escaldadoras": "escaldador",
    "escaldadores": "escaldador",
    "escaldados": "escaldar",
    "escaldaduras": "escaldadura",
    "escaldadíssima": "escaldado",
    "escaldadíssimas": "escaldado",
    "escaldadíssimo": "escaldado",
    "escaldadíssimos": "escaldado",
    "escaldai": "escaldar",
    "escaldais": "escaldar",
    "escaldam": "escaldar",
    "escaldamo": "escaldar",
    "escaldamos": "escaldar",
    "escaldando": "escaldar",
    "escaldantes": "escaldante",
    "escaldara": "escaldar",
    "escaldaram": "escaldar",
    "escaldaras": "escaldar",
    "escaldarde": "escaldar",
    "escaldardes": "escaldar",
    "escaldare": "escaldar",
    "escaldarei": "escaldar",
    "escaldareis": "escaldar",
    "escaldarem": "escaldar",
    "escaldaremos": "escaldar",
    "escaldares": "escaldar",
    "escaldaria": "escaldar",
    "escaldariam": "escaldar",
    "escaldarias": "escaldar",
    "escaldarmo": "escaldar",
    "escaldarmos": "escaldar",
    "escaldará": "escaldar",
    "escaldarás": "escaldar",
    "escaldarão": "escaldar",
    "escaldaríamos": "escaldar",
    "escaldaríeis": "escaldar",
    "escaldas": "escaldar",
    "escaldasse": "escaldar",
    "escaldassem": "escaldar",
    "escaldasses": "escaldar",
    "escaldaste": "escaldar",
    "escaldastes": "escaldar",
    "escaldava": "escaldar",
    "escaldavam": "escaldar",
    "escaldavas": "escaldar",
    "escalde": "escaldar",
    "escaldeada": "escaldear",
    "escaldeadas": "escaldear",
    "escaldeado": "escaldear",
    "escaldeados": "escaldear",
    "escaldeai": "escaldear",
    "escaldeais": "escaldear",
    "escaldeamo": "escaldear",
    "escaldeamos": "escaldear",
    "escaldeando": "escaldear",
    "escaldeara": "escaldear",
    "escaldearam": "escaldear",
    "escaldearas": "escaldear",
    "escaldearde": "escaldear",
    "escaldeardes": "escaldear",
    "escaldeare": "escaldear",
    "escaldearei": "escaldear",
    "escaldeareis": "escaldear",
    "escaldearem": "escaldear",
    "escaldearemos": "escaldear",
    "escaldeares": "escaldear",
    "escaldearia": "escaldear",
    "escaldeariam": "escaldear",
    "escaldearias": "escaldear",
    "escaldearmo": "escaldear",
    "escaldearmos": "escaldear",
    "escaldeará": "escaldear",
    "escaldearás": "escaldear",
    "escaldearão": "escaldear",
    "escaldearíamos": "escaldear",
    "escaldearíeis": "escaldear",
    "escaldeasse": "escaldear",
    "escaldeassem": "escaldear",
    "escaldeasses": "escaldear",
    "escaldeaste": "escaldear",
    "escaldeastes": "escaldear",
    "escaldeava": "escaldear",
    "escaldeavam": "escaldear",
    "escaldeavas": "escaldear",
    "escaldeei": "escaldear",
    "escaldeeis": "escaldear",
    "escaldeemo": "escaldear",
    "escaldeemos": "escaldear",
    "escaldei": "escaldar",
    "escaldeia": "escaldear",
    "escaldeiam": "escaldear",
    "escaldeias": "escaldear",
    "escaldeie": "escaldear",
    "escaldeiem": "escaldear",
    "escaldeies": "escaldear",
    "escaldeio": "escaldear",
    "escaldeira": "escaldeirar",
    "escaldeirada": "escaldeirar",
    "escaldeiradas": "escaldeirar",
    "escaldeirado": "escaldeirar",
    "escaldeirados": "escaldeirar",
    "escaldeirai": "escaldeirar",
    "escaldeirais": "escaldeirar",
    "escaldeiram": "escaldeirar",
    "escaldeiramo": "escaldeirar",
    "escaldeiramos": "escaldeirar",
    "escaldeirando": "escaldeirar",
    "escaldeirara": "escaldeirar",
    "escaldeiraram": "escaldeirar",
    "escaldeiraras": "escaldeirar",
    "escaldeirarde": "escaldeirar",
    "escaldeirardes": "escaldeirar",
    "escaldeirare": "escaldeirar",
    "escaldeirarei": "escaldeirar",
    "escaldeirareis": "escaldeirar",
    "escaldeirarem": "escaldeirar",
    "escaldeiraremos": "escaldeirar",
    "escaldeirares": "escaldeirar",
    "escaldeiraria": "escaldeirar",
    "escaldeirariam": "escaldeirar",
    "escaldeirarias": "escaldeirar",
    "escaldeirarmo": "escaldeirar",
    "escaldeirarmos": "escaldeirar",
    "escaldeirará": "escaldeirar",
    "escaldeirarás": "escaldeirar",
    "escaldeirarão": "escaldeirar",
    "escaldeiraríamos": "escaldeirar",
    "escaldeiraríeis": "escaldeirar",
    "escaldeiras": "escaldeirar",
    "escaldeirasse": "escaldeirar",
    "escaldeirassem": "escaldeirar",
    "escaldeirasses": "escaldeirar",
    "escaldeiraste": "escaldeirar",
    "escaldeirastes": "escaldeirar",
    "escaldeirava": "escaldeirar",
    "escaldeiravam": "escaldeirar",
    "escaldeiravas": "escaldeirar",
    "escaldeire": "escaldeirar",
    "escaldeirei": "escaldeirar",
    "escaldeireis": "escaldeirar",
    "escaldeirem": "escaldeirar",
    "escaldeiremo": "escaldeirar",
    "escaldeiremos": "escaldeirar",
    "escaldeires": "escaldeirar",
    "escaldeiro": "escaldeirar",
    "escaldeirou": "escaldeirar",
    "escaldeirá": "escaldeirar",
    "escaldeirámo": "escaldeirar",
    "escaldeirámos": "escaldeirar",
    "escaldeiráramo": "escaldeirar",
    "escaldeiráramos": "escaldeirar",
    "escaldeirárei": "escaldeirar",
    "escaldeiráreis": "escaldeirar",
    "escaldeirásseis": "escaldeirar",
    "escaldeirássemos": "escaldeirar",
    "escaldeirávamo": "escaldeirar",
    "escaldeirávamos": "escaldeirar",
    "escaldeirávei": "escaldeirar",
    "escaldeiráveis": "escaldeirar",
    "escaldeis": "escaldar",
    "escaldem": "escaldar",
    "escaldemo": "escaldar",
    "escaldemos": "escaldar",
    "escaldeou": "escaldear",
    "escaldes": "escaldar",
    "escaldeá": "escaldear",
    "escaldeámo": "escaldear",
    "escaldeámos": "escaldear",
    "escaldeáramo": "escaldear",
    "escaldeáramos": "escaldear",
    "escaldeárei": "escaldear",
    "escaldeáreis": "escaldear",
    "escaldeásseis": "escaldear",
    "escaldeássemos": "escaldear",
    "escaldeávamo": "escaldear",
    "escaldeávamos": "escaldear",
    "escaldeávei": "escaldear",
    "escaldeáveis": "escaldear",
    "escaldo": "escaldar",
    "escaldou": "escaldar",
    "escaldá": "escaldar",
    "escaldámo": "escaldar",
    "escaldámos": "escaldar",
    "escaldáramo": "escaldar",
    "escaldáramos": "escaldar",
    "escaldárei": "escaldar",
    "escaldáreis": "escaldar",
    "escaldásseis": "escaldar",
    "escaldássemos": "escaldar",
    "escaldávamo": "escaldar",
    "escaldávamos": "escaldar",
    "escaldávei": "escaldar",
    "escaldáveis": "escaldar",
    "escaldões": "escaldão",
    "escale": "escalar",
    "escalei": "escalar",
    "escaleiras": "escaleira",
    "escaleis": "escalar",
    "escalem": "escalar",
    "escalemo": "escalar",
    "escalemos": "escalar",
    "escalena": "escaleno",
    "escalenas": "escaleno",
    "escalenoedros": "escalenoedro",
    "escalenos": "escaleno",
    "escaleres": "escaler",
    "escales": "escalar",
    "escaletas": "escaleta",
    "escalfa": "escalfar",
    "escalfada": "escalfar",
    "escalfadas": "escalfar",
    "escalfado": "escalfar",
    "escalfadores": "escalfador",
    "escalfados": "escalfar",
    "escalfai": "escalfar",
    "escalfais": "escalfar",
    "escalfam": "escalfar",
    "escalfamo": "escalfar",
    "escalfamos": "escalfar",
    "escalfando": "escalfar",
    "escalfara": "escalfar",
    "escalfaram": "escalfar",
    "escalfaras": "escalfar",
    "escalfarde": "escalfar",
    "escalfardes": "escalfar",
    "escalfare": "escalfar",
    "escalfarei": "escalfar",
    "escalfareis": "escalfar",
    "escalfarem": "escalfar",
    "escalfaremos": "escalfar",
    "escalfares": "escalfar",
    "escalfaria": "escalfar",
    "escalfariam": "escalfar",
    "escalfarias": "escalfar",
    "escalfarmo": "escalfar",
    "escalfarmos": "escalfar",
    "escalfará": "escalfar",
    "escalfarás": "escalfar",
    "escalfarão": "escalfar",
    "escalfaríamos": "escalfar",
    "escalfaríeis": "escalfar",
    "escalfas": "escalfar",
    "escalfasse": "escalfar",
    "escalfassem": "escalfar",
    "escalfasses": "escalfar",
    "escalfaste": "escalfar",
    "escalfastes": "escalfar",
    "escalfava": "escalfar",
    "escalfavam": "escalfar",
    "escalfavas": "escalfar",
    "escalfe": "escalfar",
    "escalfei": "escalfar",
    "escalfeis": "escalfar",
    "escalfem": "escalfar",
    "escalfemo": "escalfar",
    "escalfemos": "escalfar",
    "escalfes": "escalfar",
    "escalfetas": "escalfeta",
    "escalfo": "escalfar",
    "escalfou": "escalfar",
    "escalfá": "escalfar",
    "escalfámo": "escalfar",
    "escalfámos": "escalfar",
    "escalfáramo": "escalfar",
    "escalfáramos": "escalfar",
    "escalfárei": "escalfar",
    "escalfáreis": "escalfar",
    "escalfásseis": "escalfar",
    "escalfássemos": "escalfar",
    "escalfávamo": "escalfar",
    "escalfávamos": "escalfar",
    "escalfávei": "escalfar",
    "escalfáveis": "escalfar",
    "escalheiros": "escalheiro",
    "escalhos": "escalho",
    "escalice": "escaliçar",
    "escalicei": "escaliçar",
    "escaliceis": "escaliçar",
    "escalicem": "escaliçar",
    "escalicemo": "escaliçar",
    "escalicemos": "escaliçar",
    "escalices": "escaliçar",
    "escalinatas": "escalinata",
    "escaliça": "escaliçar",
    "escaliçada": "escaliçar",
    "escaliçadas": "escaliçar",
    "escaliçado": "escaliçar",
    "escaliçados": "escaliçar",
    "escaliçai": "escaliçar",
    "escaliçais": "escaliçar",
    "escaliçam": "escaliçar",
    "escaliçamo": "escaliçar",
    "escaliçamos": "escaliçar",
    "escaliçando": "escaliçar",
    "escaliçara": "escaliçar",
    "escaliçaram": "escaliçar",
    "escaliçaras": "escaliçar",
    "escaliçarde": "escaliçar",
    "escaliçardes": "escaliçar",
    "escaliçare": "escaliçar",
    "escaliçarei": "escaliçar",
    "escaliçareis": "escaliçar",
    "escaliçarem": "escaliçar",
    "escaliçaremos": "escaliçar",
    "escaliçares": "escaliçar",
    "escaliçaria": "escaliçar",
    "escaliçariam": "escaliçar",
    "escaliçarias": "escaliçar",
    "escaliçarmo": "escaliçar",
    "escaliçarmos": "escaliçar",
    "escaliçará": "escaliçar",
    "escaliçarás": "escaliçar",
    "escaliçarão": "escaliçar",
    "escaliçaríamos": "escaliçar",
    "escaliçaríeis": "escaliçar",
    "escaliças": "escaliçar",
    "escaliçasse": "escaliçar",
    "escaliçassem": "escaliçar",
    "escaliçasses": "escaliçar",
    "escaliçaste": "escaliçar",
    "escaliçastes": "escaliçar",
    "escaliçava": "escaliçar",
    "escaliçavam": "escaliçar",
    "escaliçavas": "escaliçar",
    "escaliço": "escaliçar",
    "escaliçou": "escaliçar",
    "escaliçá": "escaliçar",
    "escaliçámo": "escaliçar",
    "escaliçámos": "escaliçar",
    "escaliçáramo": "escaliçar",
    "escaliçáramos": "escaliçar",
    "escaliçárei": "escaliçar",
    "escaliçáreis": "escaliçar",
    "escaliçásseis": "escaliçar",
    "escaliçássemos": "escaliçar",
    "escaliçávamo": "escaliçar",
    "escaliçávamos": "escaliçar",
    "escaliçávei": "escaliçar",
    "escaliçáveis": "escaliçar",
    "escalmos": "escalmo",
    "escalo": "escalar",
    "escalona": "escalonar",
    "escalonada": "escalonar",
    "escalonadas": "escalonar",
    "escalonado": "escalonar",
    "escalonados": "escalonar",
    "escalonai": "escalonar",
    "escalonais": "escalonar",
    "escalonam": "escalonar",
    "escalonamentos": "escalonamento",
    "escalonamo": "escalonar",
    "escalonamos": "escalonar",
    "escalonando": "escalonar",
    "escalonara": "escalonar",
    "escalonaram": "escalonar",
    "escalonaras": "escalonar",
    "escalonarde": "escalonar",
    "escalonardes": "escalonar",
    "escalonare": "escalonar",
    "escalonarei": "escalonar",
    "escalonareis": "escalonar",
    "escalonarem": "escalonar",
    "escalonaremos": "escalonar",
    "escalonares": "escalonar",
    "escalonaria": "escalonar",
    "escalonariam": "escalonar",
    "escalonarias": "escalonar",
    "escalonarmo": "escalonar",
    "escalonarmos": "escalonar",
    "escalonará": "escalonar",
    "escalonarás": "escalonar",
    "escalonarão": "escalonar",
    "escalonaríamos": "escalonar",
    "escalonaríeis": "escalonar",
    "escalonas": "escalonar",
    "escalonasse": "escalonar",
    "escalonassem": "escalonar",
    "escalonasses": "escalonar",
    "escalonaste": "escalonar",
    "escalonastes": "escalonar",
    "escalonava": "escalonar",
    "escalonavam": "escalonar",
    "escalonavas": "escalonar",
    "escalone": "escalonar",
    "escalonei": "escalonar",
    "escaloneis": "escalonar",
    "escalonem": "escalonar",
    "escalonemo": "escalonar",
    "escalonemos": "escalonar",
    "escalones": "escalonar",
    "escalono": "escalonar",
    "escalonou": "escalonar",
    "escaloná": "escalonar",
    "escalonámo": "escalonar",
    "escalonámos": "escalonar",
    "escalonáramo": "escalonar",
    "escalonáramos": "escalonar",
    "escalonárei": "escalonar",
    "escalonáreis": "escalonar",
    "escalonásseis": "escalonar",
    "escalonássemos": "escalonar",
    "escalonávamo": "escalonar",
    "escalonávamos": "escalonar",
    "escalonávei": "escalonar",
    "escalonáveis": "escalonável",
    "escalopes": "escalope",
    "escalos": "escalo",
    "escalou": "escalar",
    "escalpa": "escalpar",
    "escalpada": "escalpar",
    "escalpadas": "escalpar",
    "escalpado": "escalpar",
    "escalpados": "escalpar",
    "escalpai": "escalpar",
    "escalpais": "escalpar",
    "escalpam": "escalpar",
    "escalpamentos": "escalpamento",
    "escalpamo": "escalpar",
    "escalpamos": "escalpar",
    "escalpando": "escalpar",
    "escalpara": "escalpar",
    "escalparam": "escalpar",
    "escalparas": "escalpar",
    "escalparde": "escalpar",
    "escalpardes": "escalpar",
    "escalpare": "escalpar",
    "escalparei": "escalpar",
    "escalpareis": "escalpar",
    "escalparem": "escalpar",
    "escalparemos": "escalpar",
    "escalpares": "escalpar",
    "escalparia": "escalpar",
    "escalpariam": "escalpar",
    "escalparias": "escalpar",
    "escalparmo": "escalpar",
    "escalparmos": "escalpar",
    "escalpará": "escalpar",
    "escalparás": "escalpar",
    "escalparão": "escalpar",
    "escalparíamos": "escalpar",
    "escalparíeis": "escalpar",
    "escalpas": "escalpar",
    "escalpasse": "escalpar",
    "escalpassem": "escalpar",
    "escalpasses": "escalpar",
    "escalpaste": "escalpar",
    "escalpastes": "escalpar",
    "escalpava": "escalpar",
    "escalpavam": "escalpar",
    "escalpavas": "escalpar",
    "escalpe": "escalpar",
    "escalpei": "escalpar",
    "escalpeis": "escalpar",
    "escalpela": "escalpelar",
    "escalpelada": "escalpelar",
    "escalpeladas": "escalpelar",
    "escalpelado": "escalpelar",
    "escalpelados": "escalpelar",
    "escalpelai": "escalpelar",
    "escalpelais": "escalpelar",
    "escalpelam": "escalpelar",
    "escalpelamo": "escalpelar",
    "escalpelamos": "escalpelar",
    "escalpelando": "escalpelar",
    "escalpelara": "escalpelar",
    "escalpelaram": "escalpelar",
    "escalpelaras": "escalpelar",
    "escalpelarde": "escalpelar",
    "escalpelardes": "escalpelar",
    "escalpelare": "escalpelar",
    "escalpelarei": "escalpelar",
    "escalpelareis": "escalpelar",
    "escalpelarem": "escalpelar",
    "escalpelaremos": "escalpelar",
    "escalpelares": "escalpelar",
    "escalpelaria": "escalpelar",
    "escalpelariam": "escalpelar",
    "escalpelarias": "escalpelar",
    "escalpelarmo": "escalpelar",
    "escalpelarmos": "escalpelar",
    "escalpelará": "escalpelar",
    "escalpelarás": "escalpelar",
    "escalpelarão": "escalpelar",
    "escalpelaríamos": "escalpelar",
    "escalpelaríeis": "escalpelar",
    "escalpelas": "escalpelar",
    "escalpelasse": "escalpelar",
    "escalpelassem": "escalpelar",
    "escalpelasses": "escalpelar",
    "escalpelaste": "escalpelar",
    "escalpelastes": "escalpelar",
    "escalpelava": "escalpelar",
    "escalpelavam": "escalpelar",
    "escalpelavas": "escalpelar",
    "escalpele": "escalpelar",
    "escalpelei": "escalpelar",
    "escalpeleis": "escalpelar",
    "escalpelem": "escalpelar",
    "escalpelemo": "escalpelar",
    "escalpelemos": "escalpelar",
    "escalpeles": "escalpelar",
    "escalpeliza": "escalpelizar",
    "escalpelizada": "escalpelizar",
    "escalpelizadas": "escalpelizar",
    "escalpelizado": "escalpelizar",
    "escalpelizadora": "escalpelizador",
    "escalpelizadoras": "escalpelizador",
    "escalpelizadores": "escalpelizador",
    "escalpelizados": "escalpelizar",
    "escalpelizai": "escalpelizar",
    "escalpelizais": "escalpelizar",
    "escalpelizam": "escalpelizar",
    "escalpelizamo": "escalpelizar",
    "escalpelizamos": "escalpelizar",
    "escalpelizando": "escalpelizar",
    "escalpelizara": "escalpelizar",
    "escalpelizaram": "escalpelizar",
    "escalpelizaras": "escalpelizar",
    "escalpelizarde": "escalpelizar",
    "escalpelizardes": "escalpelizar",
    "escalpelizare": "escalpelizar",
    "escalpelizarei": "escalpelizar",
    "escalpelizareis": "escalpelizar",
    "escalpelizarem": "escalpelizar",
    "escalpelizaremos": "escalpelizar",
    "escalpelizares": "escalpelizar",
    "escalpelizaria": "escalpelizar",
    "escalpelizariam": "escalpelizar",
    "escalpelizarias": "escalpelizar",
    "escalpelizarmo": "escalpelizar",
    "escalpelizarmos": "escalpelizar",
    "escalpelizará": "escalpelizar",
    "escalpelizarás": "escalpelizar",
    "escalpelizarão": "escalpelizar",
    "escalpelizaríamos": "escalpelizar",
    "escalpelizaríeis": "escalpelizar",
    "escalpelizas": "escalpelizar",
    "escalpelizasse": "escalpelizar",
    "escalpelizassem": "escalpelizar",
    "escalpelizasses": "escalpelizar",
    "escalpelizaste": "escalpelizar",
    "escalpelizastes": "escalpelizar",
    "escalpelizava": "escalpelizar",
    "escalpelizavam": "escalpelizar",
    "escalpelizavas": "escalpelizar",
    "escalpelize": "escalpelizar",
    "escalpelizei": "escalpelizar",
    "escalpelizeis": "escalpelizar",
    "escalpelizem": "escalpelizar",
    "escalpelizemo": "escalpelizar",
    "escalpelizemos": "escalpelizar",
    "escalpelizes": "escalpelizar",
    "escalpelizo": "escalpelizar",
    "escalpelizou": "escalpelizar",
    "escalpelizá": "escalpelizar",
    "escalpelizámo": "escalpelizar",
    "escalpelizámos": "escalpelizar",
    "escalpelizáramo": "escalpelizar",
    "escalpelizáramos": "escalpelizar",
    "escalpelizárei": "escalpelizar",
    "escalpelizáreis": "escalpelizar",
    "escalpelizásseis": "escalpelizar",
    "escalpelizássemos": "escalpelizar",
    "escalpelizávamo": "escalpelizar",
    "escalpelizávamos": "escalpelizar",
    "escalpelizávei": "escalpelizar",
    "escalpelizáveis": "escalpelizar",
    "escalpelo": "escalpelar",
    "escalpelos": "escalpelo",
    "escalpelou": "escalpelar",
    "escalpelá": "escalpelar",
    "escalpelámo": "escalpelar",
    "escalpelámos": "escalpelar",
    "escalpeláramo": "escalpelar",
    "escalpeláramos": "escalpelar",
    "escalpelárei": "escalpelar",
    "escalpeláreis": "escalpelar",
    "escalpelásseis": "escalpelar",
    "escalpelássemos": "escalpelar",
    "escalpelávamo": "escalpelar",
    "escalpelávamos": "escalpelar",
    "escalpelávei": "escalpelar",
    "escalpeláveis": "escalpelar",
    "escalpem": "escalpar",
    "escalpemo": "escalpar",
    "escalpemos": "escalpar",
    "escalpes": "escalpe",
    "escalpo": "escalpar",
    "escalpos": "escalpo",
    "escalpou": "escalpar",
    "escalpá": "escalpar",
    "escalpámo": "escalpar",
    "escalpámos": "escalpar",
    "escalpáramo": "escalpar",
    "escalpáramos": "escalpar",
    "escalpárei": "escalpar",
    "escalpáreis": "escalpar",
    "escalpásseis": "escalpar",
    "escalpássemos": "escalpar",
    "escalpávamo": "escalpar",
    "escalpávamos": "escalpar",
    "escalpávei": "escalpar",
    "escalpáveis": "escalpar",
    "escalracha": "escalrachar",
    "escalrachada": "escalrachar",
    "escalrachadas": "escalrachar",
    "escalrachado": "escalrachar",
    "escalrachados": "escalrachar",
    "escalrachai": "escalrachar",
    "escalrachais": "escalrachar",
    "escalracham": "escalrachar",
    "escalrachamo": "escalrachar",
    "escalrachamos": "escalrachar",
    "escalrachando": "escalrachar",
    "escalrachara": "escalrachar",
    "escalracharam": "escalrachar",
    "escalracharas": "escalrachar",
    "escalrachardes": "escalrachar",
    "escalracharei": "escalrachar",
    "escalrachareis": "escalrachar",
    "escalracharem": "escalrachar",
    "escalracharemos": "escalrachar",
    "escalrachares": "escalrachar",
    "escalracharia": "escalrachar",
    "escalrachariam": "escalrachar",
    "escalracharias": "escalrachar",
    "escalracharmo": "escalrachar",
    "escalracharmos": "escalrachar",
    "escalrachará": "escalrachar",
    "escalracharás": "escalrachar",
    "escalracharão": "escalrachar",
    "escalracharíamos": "escalrachar",
    "escalracharíeis": "escalrachar",
    "escalrachas": "escalrachar",
    "escalrachasse": "escalrachar",
    "escalrachassem": "escalrachar",
    "escalrachasses": "escalrachar",
    "escalrachaste": "escalrachar",
    "escalrachastes": "escalrachar",
    "escalrachava": "escalrachar",
    "escalrachavam": "escalrachar",
    "escalrachavas": "escalrachar",
    "escalrache": "escalrachar",
    "escalrachei": "escalrachar",
    "escalracheis": "escalrachar",
    "escalrachem": "escalrachar",
    "escalrachemo": "escalrachar",
    "escalrachemos": "escalrachar",
    "escalraches": "escalrachar",
    "escalracho": "escalrachar",
    "escalrachos": "escalracho",
    "escalrachou": "escalrachar",
    "escalrachámo": "escalrachar",
    "escalrachámos": "escalrachar",
    "escalracháramo": "escalrachar",
    "escalracháramos": "escalrachar",
    "escalracháreis": "escalrachar",
    "escalrachásseis": "escalrachar",
    "escalrachássemos": "escalrachar",
    "escalrachávamo": "escalrachar",
    "escalrachávamos": "escalrachar",
    "escalracháveis": "escalrachar",
    "escalva": "escalvar",
    "escalvada": "escalvar",
    "escalvadas": "escalvar",
    "escalvado": "escalvar",
    "escalvados": "escalvar",
    "escalvai": "escalvar",
    "escalvais": "escalvar",
    "escalvam": "escalvar",
    "escalvamo": "escalvar",
    "escalvamos": "escalvar",
    "escalvando": "escalvar",
    "escalvara": "escalvar",
    "escalvaram": "escalvar",
    "escalvaras": "escalvar",
    "escalvarde": "escalvar",
    "escalvardes": "escalvar",
    "escalvare": "escalvar",
    "escalvarei": "escalvar",
    "escalvareis": "escalvar",
    "escalvarem": "escalvar",
    "escalvaremos": "escalvar",
    "escalvares": "escalvar",
    "escalvaria": "escalvar",
    "escalvariam": "escalvar",
    "escalvarias": "escalvar",
    "escalvarmo": "escalvar",
    "escalvarmos": "escalvar",
    "escalvará": "escalvar",
    "escalvarás": "escalvar",
    "escalvarão": "escalvar",
    "escalvaríamos": "escalvar",
    "escalvaríeis": "escalvar",
    "escalvas": "escalvar",
    "escalvasse": "escalvar",
    "escalvassem": "escalvar",
    "escalvasses": "escalvar",
    "escalvaste": "escalvar",
    "escalvastes": "escalvar",
    "escalvava": "escalvar",
    "escalvavam": "escalvar",
    "escalvavas": "escalvar",
    "escalvações": "escalvação",
    "escalve": "escalvar",
    "escalvei": "escalvar",
    "escalveis": "escalvar",
    "escalvem": "escalvar",
    "escalvemo": "escalvar",
    "escalvemos": "escalvar",
    "escalves": "escalvar",
    "escalvo": "escalvar",
    "escalvou": "escalvar",
    "escalvá": "escalvar",
    "escalvámo": "escalvar",
    "escalvámos": "escalvar",
    "escalváramo": "escalvar",
    "escalváramos": "escalvar",
    "escalvárei": "escalvar",
    "escalváreis": "escalvar",
    "escalvásseis": "escalvar",
    "escalvássemos": "escalvar",
    "escalvávamo": "escalvar",
    "escalvávamos": "escalvar",
    "escalvávei": "escalvar",
    "escalváveis": "escalvar",
    "escalá": "escalar",
    "escalámo": "escalar",
    "escalámos": "escalar",
    "escaláramo": "escalar",
    "escaláramos": "escalar",
    "escalárei": "escalar",
    "escaláreis": "escalar",
    "escalásseis": "escalar",
    "escalássemos": "escalar",
    "escalávamo": "escalar",
    "escalávamos": "escalar",
    "escalávei": "escalar",
    "escaláveis": "escalar",
    "escalões": "escalão",
    "escama": "escamo",
    "escamada": "escamar",
    "escamadas": "escamar",
    "escamadeiras": "escamadeira",
    "escamado": "escamar",
    "escamadores": "escamador",
    "escamados": "escamar",
    "escamaduras": "escamadura",
    "escamai": "escamar",
    "escamais": "escamar",
    "escamam": "escamar",
    "escamamo": "escamar",
    "escamamos": "escamar",
    "escamando": "escamar",
    "escamara": "escamar",
    "escamaram": "escamar",
    "escamaras": "escamar",
    "escamarde": "escamar",
    "escamardes": "escamar",
    "escamare": "escamar",
    "escamarei": "escamar",
    "escamareis": "escamar",
    "escamarem": "escamar",
    "escamaremos": "escamar",
    "escamares": "escamar",
    "escamaria": "escamar",
    "escamariam": "escamar",
    "escamarias": "escamaria",
    "escamarmo": "escamar",
    "escamarmos": "escamar",
    "escamará": "escamar",
    "escamarás": "escamar",
    "escamarão": "escamar",
    "escamaríamos": "escamar",
    "escamaríeis": "escamar",
    "escamas": "escamo",
    "escamasse": "escamar",
    "escamassem": "escamar",
    "escamasses": "escamar",
    "escamaste": "escamar",
    "escamastes": "escamar",
    "escamava": "escamar",
    "escamavam": "escamar",
    "escamavas": "escamar",
    "escamações": "escamação",
    "escamba": "escambar",
    "escambada": "escambar",
    "escambadas": "escambar",
    "escambado": "escambar",
    "escambados": "escambar",
    "escambai": "escambar",
    "escambais": "escambar",
    "escambam": "escambar",
    "escambamo": "escambar",
    "escambamos": "escambar",
    "escambando": "escambar",
    "escambara": "escambar",
    "escambaram": "escambar",
    "escambaras": "escambar",
    "escambarde": "escambar",
    "escambardes": "escambar",
    "escambare": "escambar",
    "escambarei": "escambar",
    "escambareis": "escambar",
    "escambarem": "escambar",
    "escambaremos": "escambar",
    "escambares": "escambar",
    "escambaria": "escambar",
    "escambariam": "escambar",
    "escambarias": "escambar",
    "escambarmo": "escambar",
    "escambarmos": "escambar",
    "escambará": "escambar",
    "escambarás": "escambar",
    "escambarão": "escambar",
    "escambaríamos": "escambar",
    "escambaríeis": "escambar",
    "escambas": "escambar",
    "escambasse": "escambar",
    "escambassem": "escambar",
    "escambasses": "escambar",
    "escambaste": "escambar",
    "escambastes": "escambar",
    "escambava": "escambar",
    "escambavam": "escambar",
    "escambavas": "escambar",
    "escambe": "escambar",
    "escambei": "escambar",
    "escambeis": "escambar",
    "escambem": "escambar",
    "escambemo": "escambar",
    "escambemos": "escambar",
    "escambes": "escambar",
    "escambia": "escambiar",
    "escambiada": "escambiar",
    "escambiadas": "escambiar",
    "escambiado": "escambiar",
    "escambiados": "escambiar",
    "escambiai": "escambiar",
    "escambiais": "escambiar",
    "escambiam": "escambiar",
    "escambiamo": "escambiar",
    "escambiamos": "escambiar",
    "escambiando": "escambiar",
    "escambiara": "escambiar",
    "escambiaram": "escambiar",
    "escambiaras": "escambiar",
    "escambiarde": "escambiar",
    "escambiardes": "escambiar",
    "escambiare": "escambiar",
    "escambiarei": "escambiar",
    "escambiareis": "escambiar",
    "escambiarem": "escambiar",
    "escambiaremos": "escambiar",
    "escambiares": "escambiar",
    "escambiaria": "escambiar",
    "escambiariam": "escambiar",
    "escambiarias": "escambiar",
    "escambiarmo": "escambiar",
    "escambiarmos": "escambiar",
    "escambiará": "escambiar",
    "escambiarás": "escambiar",
    "escambiarão": "escambiar",
    "escambiaríamos": "escambiar",
    "escambiaríeis": "escambiar",
    "escambias": "escambiar",
    "escambiasse": "escambiar",
    "escambiassem": "escambiar",
    "escambiasses": "escambiar",
    "escambiaste": "escambiar",
    "escambiastes": "escambiar",
    "escambiava": "escambiar",
    "escambiavam": "escambiar",
    "escambiavas": "escambiar",
    "escambie": "escambiar",
    "escambiei": "escambiar",
    "escambieis": "escambiar",
    "escambiem": "escambiar",
    "escambiemo": "escambiar",
    "escambiemos": "escambiar",
    "escambies": "escambiar",
    "escambio": "escambiar",
    "escambiou": "escambiar",
    "escambiá": "escambiar",
    "escambiámo": "escambiar",
    "escambiámos": "escambiar",
    "escambiáramo": "escambiar",
    "escambiáramos": "escambiar",
    "escambiárei": "escambiar",
    "escambiáreis": "escambiar",
    "escambiásseis": "escambiar",
    "escambiássemos": "escambiar",
    "escambiávamo": "escambiar",
    "escambiávamos": "escambiar",
    "escambiávei": "escambiar",
    "escambiáveis": "escambiar",
    "escambo": "escambar",
    "escambos": "escambo",
    "escambou": "escambar",
    "escambra": "escambrar",
    "escambrada": "escambrar",
    "escambradas": "escambrar",
    "escambrado": "escambrar",
    "escambrados": "escambrar",
    "escambrai": "escambrar",
    "escambrais": "escambrar",
    "escambram": "escambrar",
    "escambramo": "escambrar",
    "escambramos": "escambrar",
    "escambrando": "escambrar",
    "escambrara": "escambrar",
    "escambraram": "escambrar",
    "escambraras": "escambrar",
    "escambrarde": "escambrar",
    "escambrardes": "escambrar",
    "escambrare": "escambrar",
    "escambrarei": "escambrar",
    "escambrareis": "escambrar",
    "escambrarem": "escambrar",
    "escambraremos": "escambrar",
    "escambrares": "escambrar",
    "escambraria": "escambrar",
    "escambrariam": "escambrar",
    "escambrarias": "escambrar",
    "escambrarmo": "escambrar",
    "escambrarmos": "escambrar",
    "escambrará": "escambrar",
    "escambrarás": "escambrar",
    "escambrarão": "escambrar",
    "escambraríamos": "escambrar",
    "escambraríeis": "escambrar",
    "escambras": "escambrar",
    "escambrasse": "escambrar",
    "escambrassem": "escambrar",
    "escambrasses": "escambrar",
    "escambraste": "escambrar",
    "escambrastes": "escambrar",
    "escambrava": "escambrar",
    "escambravam": "escambrar",
    "escambravas": "escambrar",
    "escambre": "escambrar",
    "escambrei": "escambrar",
    "escambreis": "escambrar",
    "escambrem": "escambrar",
    "escambremo": "escambrar",
    "escambremos": "escambrar",
    "escambres": "escambrar",
    "escambro": "escambrar",
    "escambroeiros": "escambroeiro",
    "escambrou": "escambrar",
    "escambrá": "escambrar",
    "escambrámo": "escambrar",
    "escambrámos": "escambrar",
    "escambráramo": "escambrar",
    "escambráramos": "escambrar",
    "escambrárei": "escambrar",
    "escambráreis": "escambrar",
    "escambrásseis": "escambrar",
    "escambrássemos": "escambrar",
    "escambrávamo": "escambrar",
    "escambrávamos": "escambrar",
    "escambrávei": "escambrar",
    "escambráveis": "escambrar",
    "escambrões": "escambrão",
    "escambá": "escambar",
    "escambámo": "escambar",
    "escambámos": "escambar",
    "escambáramo": "escambar",
    "escambáramos": "escambar",
    "escambárei": "escambar",
    "escambáreis": "escambar",
    "escambásseis": "escambar",
    "escambássemos": "escambar",
    "escambávamo": "escambar",
    "escambávamos": "escambar",
    "escambávei": "escambar",
    "escambáveis": "escambar",
    "escame": "escamar",
    "escameada": "escameado",
    "escameadas": "escameado",
    "escameados": "escameado",
    "escamei": "escamar",
    "escameis": "escamar",
    "escamem": "escamar",
    "escamemo": "escamar",
    "escamemos": "escamar",
    "escamentos": "escamento",
    "escames": "escamar",
    "escameta": "escameto",
    "escametas": "escameto",
    "escametos": "escameto",
    "escamiformes": "escamiforme",
    "escamisa": "escamisar",
    "escamisada": "escamisar",
    "escamisadas": "escamisar",
    "escamisado": "escamisar",
    "escamisados": "escamisar",
    "escamisai": "escamisar",
    "escamisais": "escamisar",
    "escamisam": "escamisar",
    "escamisamo": "escamisar",
    "escamisamos": "escamisar",
    "escamisando": "escamisar",
    "escamisara": "escamisar",
    "escamisaram": "escamisar",
    "escamisaras": "escamisar",
    "escamisarde": "escamisar",
    "escamisardes": "escamisar",
    "escamisare": "escamisar",
    "escamisarei": "escamisar",
    "escamisareis": "escamisar",
    "escamisarem": "escamisar",
    "escamisaremos": "escamisar",
    "escamisares": "escamisar",
    "escamisaria": "escamisar",
    "escamisariam": "escamisar",
    "escamisarias": "escamisar",
    "escamisarmo": "escamisar",
    "escamisarmos": "escamisar",
    "escamisará": "escamisar",
    "escamisarás": "escamisar",
    "escamisarão": "escamisar",
    "escamisaríamos": "escamisar",
    "escamisaríeis": "escamisar",
    "escamisas": "escamisar",
    "escamisasse": "escamisar",
    "escamisassem": "escamisar",
    "escamisasses": "escamisar",
    "escamisaste": "escamisar",
    "escamisastes": "escamisar",
    "escamisava": "escamisar",
    "escamisavam": "escamisar",
    "escamisavas": "escamisar",
    "escamise": "escamisar",
    "escamisei": "escamisar",
    "escamiseis": "escamisar",
    "escamisem": "escamisar",
    "escamisemo": "escamisar",
    "escamisemos": "escamisar",
    "escamises": "escamisar",
    "escamiso": "escamisar",
    "escamisou": "escamisar",
    "escamisá": "escamisar",
    "escamisámo": "escamisar",
    "escamisámos": "escamisar",
    "escamisáramo": "escamisar",
    "escamisáramos": "escamisar",
    "escamisárei": "escamisar",
    "escamisáreis": "escamisar",
    "escamisásseis": "escamisar",
    "escamisássemos": "escamisar",
    "escamisávamo": "escamisar",
    "escamisávamos": "escamisar",
    "escamisávei": "escamisar",
    "escamisáveis": "escamisar",
    "escamo": "escamar",
    "escamonda": "escamondar",
    "escamondada": "escamondar",
    "escamondadas": "escamondar",
    "escamondado": "escamondar",
    "escamondados": "escamondar",
    "escamondai": "escamondar",
    "escamondais": "escamondar",
    "escamondam": "escamondar",
    "escamondamo": "escamondar",
    "escamondamos": "escamondar",
    "escamondando": "escamondar",
    "escamondara": "escamondar",
    "escamondaram": "escamondar",
    "escamondaras": "escamondar",
    "escamondarde": "escamondar",
    "escamondardes": "escamondar",
    "escamondare": "escamondar",
    "escamondarei": "escamondar",
    "escamondareis": "escamondar",
    "escamondarem": "escamondar",
    "escamondaremos": "escamondar",
    "escamondares": "escamondar",
    "escamondaria": "escamondar",
    "escamondariam": "escamondar",
    "escamondarias": "escamondar",
    "escamondarmo": "escamondar",
    "escamondarmos": "escamondar",
    "escamondará": "escamondar",
    "escamondarás": "escamondar",
    "escamondarão": "escamondar",
    "escamondaríamos": "escamondar",
    "escamondaríeis": "escamondar",
    "escamondas": "escamondar",
    "escamondasse": "escamondar",
    "escamondassem": "escamondar",
    "escamondasses": "escamondar",
    "escamondaste": "escamondar",
    "escamondastes": "escamondar",
    "escamondava": "escamondar",
    "escamondavam": "escamondar",
    "escamondavas": "escamondar",
    "escamonde": "escamondar",
    "escamondei": "escamondar",
    "escamondeis": "escamondar",
    "escamondem": "escamondar",
    "escamondemo": "escamondar",
    "escamondemos": "escamondar",
    "escamondes": "escamondar",
    "escamondo": "escamondar",
    "escamondou": "escamondar",
    "escamondá": "escamondar",
    "escamondámo": "escamondar",
    "escamondámos": "escamondar",
    "escamondáramo": "escamondar",
    "escamondáramos": "escamondar",
    "escamondárei": "escamondar",
    "escamondáreis": "escamondar",
    "escamondásseis": "escamondar",
    "escamondássemos": "escamondar",
    "escamondávamo": "escamondar",
    "escamondávamos": "escamondar",
    "escamondávei": "escamondar",
    "escamondáveis": "escamondar",
    "escamos": "escamo",
    "escamosa": "escamoso",
    "escamosais": "escamosal",
    "escamosas": "escamoso",
    "escamosos": "escamoso",
    "escamota": "escamotar",
    "escamotada": "escamotar",
    "escamotadas": "escamotar",
    "escamotado": "escamotar",
    "escamotados": "escamotar",
    "escamotai": "escamotar",
    "escamotais": "escamotar",
    "escamotam": "escamotar",
    "escamotamo": "escamotar",
    "escamotamos": "escamotar",
    "escamotando": "escamotar",
    "escamotara": "escamotar",
    "escamotaram": "escamotar",
    "escamotaras": "escamotar",
    "escamotarde": "escamotar",
    "escamotardes": "escamotar",
    "escamotare": "escamotar",
    "escamotarei": "escamotar",
    "escamotareis": "escamotar",
    "escamotarem": "escamotar",
    "escamotaremos": "escamotar",
    "escamotares": "escamotar",
    "escamotaria": "escamotar",
    "escamotariam": "escamotar",
    "escamotarias": "escamotar",
    "escamotarmo": "escamotar",
    "escamotarmos": "escamotar",
    "escamotará": "escamotar",
    "escamotarás": "escamotar",
    "escamotarão": "escamotar",
    "escamotaríamos": "escamotar",
    "escamotaríeis": "escamotar",
    "escamotas": "escamotar",
    "escamotasse": "escamotar",
    "escamotassem": "escamotar",
    "escamotasses": "escamotar",
    "escamotaste": "escamotar",
    "escamotastes": "escamotar",
    "escamotava": "escamotar",
    "escamotavam": "escamotar",
    "escamotavas": "escamotar",
    "escamotações": "escamotação",
    "escamote": "escamotar",
    "escamoteada": "escamotear",
    "escamoteadas": "escamotear",
    "escamoteado": "escamotear",
    "escamoteadora": "escamoteador",
    "escamoteadoras": "escamoteador",
    "escamoteadores": "escamoteador",
    "escamoteados": "escamotear",
    "escamoteai": "escamotear",
    "escamoteais": "escamotear",
    "escamoteamo": "escamotear",
    "escamoteamos": "escamotear",
    "escamoteando": "escamotear",
    "escamoteara": "escamotear",
    "escamotearam": "escamotear",
    "escamotearas": "escamotear",
    "escamotearde": "escamotear",
    "escamoteardes": "escamotear",
    "escamoteare": "escamotear",
    "escamotearei": "escamotear",
    "escamoteareis": "escamotear",
    "escamotearem": "escamotear",
    "escamotearemos": "escamotear",
    "escamoteares": "escamotear",
    "escamotearia": "escamotear",
    "escamoteariam": "escamotear",
    "escamotearias": "escamotear",
    "escamotearmo": "escamotear",
    "escamotearmos": "escamotear",
    "escamoteará": "escamotear",
    "escamotearás": "escamotear",
    "escamotearão": "escamotear",
    "escamotearíamos": "escamotear",
    "escamotearíeis": "escamotear",
    "escamoteasse": "escamotear",
    "escamoteassem": "escamotear",
    "escamoteasses": "escamotear",
    "escamoteaste": "escamotear",
    "escamoteastes": "escamotear",
    "escamoteava": "escamotear",
    "escamoteavam": "escamotear",
    "escamoteavas": "escamotear",
    "escamoteações": "escamoteação",
    "escamoteei": "escamotear",
    "escamoteeis": "escamotear",
    "escamoteemo": "escamotear",
    "escamoteemos": "escamotear",
    "escamotei": "escamotar",
    "escamoteia": "escamotear",
    "escamoteiam": "escamotear",
    "escamoteias": "escamotear",
    "escamoteie": "escamotear",
    "escamoteiem": "escamotear",
    "escamoteies": "escamotear",
    "escamoteio": "escamotear",
    "escamoteios": "escamoteio",
    "escamoteis": "escamotar",
    "escamotem": "escamotar",
    "escamotemo": "escamotar",
    "escamotemos": "escamotar",
    "escamoteou": "escamotear",
    "escamotes": "escamotar",
    "escamoteá": "escamotear",
    "escamoteámo": "escamotear",
    "escamoteámos": "escamotear",
    "escamoteáramo": "escamotear",
    "escamoteáramos": "escamotear",
    "escamoteárei": "escamotear",
    "escamoteáreis": "escamotear",
    "escamoteásseis": "escamotear",
    "escamoteássemos": "escamotear",
    "escamoteávamo": "escamotear",
    "escamoteávamos": "escamotear",
    "escamoteávei": "escamotear",
    "escamoteáveis": "escamoteável",
    "escamoto": "escamotar",
    "escamotou": "escamotar",
    "escamotá": "escamotar",
    "escamotámo": "escamotar",
    "escamotámos": "escamotar",
    "escamotáramo": "escamotar",
    "escamotáramos": "escamotar",
    "escamotárei": "escamotar",
    "escamotáreis": "escamotar",
    "escamotásseis": "escamotar",
    "escamotássemos": "escamotar",
    "escamotávamo": "escamotar",
    "escamotávamos": "escamotar",
    "escamotávei": "escamotar",
    "escamotáveis": "escamotar",
    "escamou": "escamar",
    "escampa": "escampo",
    "escampada": "escampar",
    "escampadas": "escampar",
    "escampado": "escampar",
    "escampados": "escampar",
    "escampai": "escampar",
    "escampais": "escampar",
    "escampam": "escampar",
    "escampamo": "escampar",
    "escampamos": "escampar",
    "escampando": "escampar",
    "escampara": "escampar",
    "escamparam": "escampar",
    "escamparas": "escampar",
    "escampardes": "escampar",
    "escamparei": "escampar",
    "escampareis": "escampar",
    "escamparem": "escampar",
    "escamparemos": "escampar",
    "escampares": "escampar",
    "escamparia": "escampar",
    "escampariam": "escampar",
    "escamparias": "escampar",
    "escamparmo": "escampar",
    "escamparmos": "escampar",
    "escampará": "escampar",
    "escamparás": "escampar",
    "escamparão": "escampar",
    "escamparíamos": "escampar",
    "escamparíeis": "escampar",
    "escampas": "escampo",
    "escampasse": "escampar",
    "escampassem": "escampar",
    "escampasses": "escampar",
    "escampaste": "escampar",
    "escampastes": "escampar",
    "escampava": "escampar",
    "escampavam": "escampar",
    "escampavas": "escampar",
    "escampe": "escampar",
    "escampei": "escampar",
    "escampeis": "escampar",
    "escampem": "escampar",
    "escampemo": "escampar",
    "escampemos": "escampar",
    "escampes": "escampar",
    "escampo": "escampar",
    "escampos": "escampo",
    "escampou": "escampar",
    "escampámo": "escampar",
    "escampámos": "escampar",
    "escampáramo": "escampar",
    "escampáramos": "escampar",
    "escampáreis": "escampar",
    "escampásseis": "escampar",
    "escampássemos": "escampar",
    "escampávamo": "escampar",
    "escampávamos": "escampar",
    "escampáveis": "escampar",
    "escamuda": "escamudo",
    "escamudas": "escamudo",
    "escamudos": "escamudo",
    "escamuge": "escamugir",
    "escamugem": "escamugir",
    "escamuges": "escamugir",
    "escamugi": "escamugir",
    "escamugia": "escamugir",
    "escamugiam": "escamugir",
    "escamugias": "escamugir",
    "escamugida": "escamugir",
    "escamugidas": "escamugir",
    "escamugido": "escamugir",
    "escamugidos": "escamugir",
    "escamugimo": "escamugir",
    "escamugimos": "escamugir",
    "escamugindo": "escamugir",
    "escamugira": "escamugir",
    "escamugiram": "escamugir",
    "escamugiras": "escamugir",
    "escamugirde": "escamugir",
    "escamugirdes": "escamugir",
    "escamugire": "escamugir",
    "escamugirei": "escamugir",
    "escamugireis": "escamugir",
    "escamugirem": "escamugir",
    "escamugiremos": "escamugir",
    "escamugires": "escamugir",
    "escamugiria": "escamugir",
    "escamugiriam": "escamugir",
    "escamugirias": "escamugir",
    "escamugirmo": "escamugir",
    "escamugirmos": "escamugir",
    "escamugirá": "escamugir",
    "escamugirás": "escamugir",
    "escamugirão": "escamugir",
    "escamugiríamos": "escamugir",
    "escamugiríeis": "escamugir",
    "escamugis": "escamugir",
    "escamugisse": "escamugir",
    "escamugissem": "escamugir",
    "escamugisses": "escamugir",
    "escamugiste": "escamugir",
    "escamugistes": "escamugir",
    "escamugiu": "escamugir",
    "escamugíamo": "escamugir",
    "escamugíamos": "escamugir",
    "escamugíei": "escamugir",
    "escamugíeis": "escamugir",
    "escamugíramo": "escamugir",
    "escamugíramos": "escamugir",
    "escamugírei": "escamugir",
    "escamugíreis": "escamugir",
    "escamugísseis": "escamugir",
    "escamugíssemos": "escamugir",
    "escamuja": "escamugir",
    "escamujais": "escamugir",
    "escamujam": "escamugir",
    "escamujamo": "escamugir",
    "escamujamos": "escamugir",
    "escamujas": "escamugir",
    "escamujo": "escamugir",
    "escamá": "escamar",
    "escamámo": "escamar",
    "escamámos": "escamar",
    "escamáramo": "escamar",
    "escamáramos": "escamar",
    "escamárei": "escamar",
    "escamáreis": "escamar",
    "escamásseis": "escamar",
    "escamássemos": "escamar",
    "escamávamo": "escamar",
    "escamávamos": "escamar",
    "escamávei": "escamar",
    "escamáveis": "escamar",
    "escaméis": "escamel",
    "escamífera": "escamífero",
    "escamíferas": "escamífero",
    "escamíferos": "escamífero",
    "escamígera": "escamígero",
    "escamígeras": "escamígero",
    "escamígeros": "escamígero",
    "escamóneas": "escamónea",
    "escamões": "escamão",
    "escana": "escanar",
    "escanada": "escanar",
    "escanadas": "escanar",
    "escanado": "escanar",
    "escanados": "escanar",
    "escanai": "escanar",
    "escanais": "escanar",
    "escanam": "escanar",
    "escanamo": "escanar",
    "escanamos": "escanar",
    "escanando": "escanar",
    "escanara": "escanar",
    "escanaram": "escanar",
    "escanaras": "escanar",
    "escanarde": "escanar",
    "escanardes": "escanar",
    "escanare": "escanar",
    "escanarei": "escanar",
    "escanareis": "escanar",
    "escanarem": "escanar",
    "escanaremos": "escanar",
    "escanares": "escanar",
    "escanaria": "escanar",
    "escanariam": "escanar",
    "escanarias": "escanar",
    "escanarmo": "escanar",
    "escanarmos": "escanar",
    "escanará": "escanar",
    "escanarás": "escanar",
    "escanarão": "escanar",
    "escanaríamos": "escanar",
    "escanaríeis": "escanar",
    "escanas": "escanar",
    "escanasse": "escanar",
    "escanassem": "escanar",
    "escanasses": "escanar",
    "escanaste": "escanar",
    "escanastes": "escanar",
    "escanastrada": "escanastrado",
    "escanastradas": "escanastrado",
    "escanastrados": "escanastrado",
    "escanava": "escanar",
    "escanavam": "escanar",
    "escanavas": "escanar",
    "escancara": "escancarar",
    "escancarada": "escancarar",
    "escancaradas": "escancarar",
    "escancarado": "escancarar",
    "escancarados": "escancarar",
    "escancarai": "escancarar",
    "escancarais": "escancarar",
    "escancaram": "escancarar",
    "escancaramo": "escancarar",
    "escancaramos": "escancarar",
    "escancarando": "escancarar",
    "escancarara": "escancarar",
    "escancararam": "escancarar",
    "escancararas": "escancarar",
    "escancararde": "escancarar",
    "escancarardes": "escancarar",
    "escancarare": "escancarar",
    "escancararei": "escancarar",
    "escancarareis": "escancarar",
    "escancararem": "escancarar",
    "escancararemos": "escancarar",
    "escancarares": "escancarar",
    "escancararia": "escancarar",
    "escancarariam": "escancarar",
    "escancararias": "escancarar",
    "escancararmo": "escancarar",
    "escancararmos": "escancarar",
    "escancarará": "escancarar",
    "escancararás": "escancarar",
    "escancararão": "escancarar",
    "escancararíamos": "escancarar",
    "escancararíeis": "escancarar",
    "escancaras": "escancarar",
    "escancarasse": "escancarar",
    "escancarassem": "escancarar",
    "escancarasses": "escancarar",
    "escancaraste": "escancarar",
    "escancarastes": "escancarar",
    "escancarava": "escancarar",
    "escancaravam": "escancarar",
    "escancaravas": "escancarar",
    "escancarações": "escancaração",
    "escancare": "escancarar",
    "escancarei": "escancarar",
    "escancareis": "escancarar",
    "escancarem": "escancarar",
    "escancaremo": "escancarar",
    "escancaremos": "escancarar",
    "escancares": "escancarar",
    "escancaro": "escancarar",
    "escancarou": "escancarar",
    "escancará": "escancarar",
    "escancarámo": "escancarar",
    "escancarámos": "escancarar",
    "escancaráramo": "escancarar",
    "escancaráramos": "escancarar",
    "escancarárei": "escancarar",
    "escancaráreis": "escancarar",
    "escancarásseis": "escancarar",
    "escancarássemos": "escancarar",
    "escancarávamo": "escancarar",
    "escancarávamos": "escancarar",
    "escancarávei": "escancarar",
    "escancaráveis": "escancarar",
    "escance": "escançar",
    "escanceada": "escancear",
    "escanceadas": "escancear",
    "escanceado": "escancear",
    "escanceados": "escancear",
    "escanceai": "escancear",
    "escanceais": "escancear",
    "escanceamo": "escancear",
    "escanceamos": "escancear",
    "escanceando": "escancear",
    "escanceara": "escancear",
    "escancearam": "escancear",
    "escancearas": "escancear",
    "escancearde": "escancear",
    "escanceardes": "escancear",
    "escanceare": "escancear",
    "escancearei": "escancear",
    "escanceareis": "escancear",
    "escancearem": "escancear",
    "escancearemos": "escancear",
    "escanceares": "escancear",
    "escancearia": "escancear",
    "escanceariam": "escancear",
    "escancearias": "escancear",
    "escancearmo": "escancear",
    "escancearmos": "escancear",
    "escanceará": "escancear",
    "escancearás": "escancear",
    "escancearão": "escancear",
    "escancearíamos": "escancear",
    "escancearíeis": "escancear",
    "escanceasse": "escancear",
    "escanceassem": "escancear",
    "escanceasses": "escancear",
    "escanceaste": "escancear",
    "escanceastes": "escancear",
    "escanceava": "escancear",
    "escanceavam": "escancear",
    "escanceavas": "escancear",
    "escanceei": "escancear",
    "escanceeis": "escancear",
    "escanceemo": "escancear",
    "escanceemos": "escancear",
    "escancei": "escançar",
    "escanceia": "escancear",
    "escanceiam": "escancear",
    "escanceias": "escancear",
    "escanceie": "escancear",
    "escanceiem": "escancear",
    "escanceies": "escancear",
    "escanceio": "escancear",
    "escanceis": "escançar",
    "escancem": "escançar",
    "escancemo": "escançar",
    "escancemos": "escançar",
    "escanceou": "escancear",
    "escances": "escançar",
    "escanceá": "escancear",
    "escanceámo": "escancear",
    "escanceámos": "escancear",
    "escanceáramo": "escancear",
    "escanceáramos": "escancear",
    "escanceárei": "escancear",
    "escanceáreis": "escancear",
    "escanceásseis": "escancear",
    "escanceássemos": "escancear",
    "escanceávamo": "escancear",
    "escanceávamos": "escancear",
    "escanceávei": "escancear",
    "escanceáveis": "escancear",
    "escancha": "escanchar",
    "escanchada": "escanchar",
    "escanchadas": "escanchar",
    "escanchado": "escanchar",
    "escanchados": "escanchar",
    "escanchai": "escanchar",
    "escanchais": "escanchar",
    "escancham": "escanchar",
    "escanchamo": "escanchar",
    "escanchamos": "escanchar",
    "escanchando": "escanchar",
    "escanchara": "escanchar",
    "escancharam": "escanchar",
    "escancharas": "escanchar",
    "escancharde": "escanchar",
    "escanchardes": "escanchar",
    "escanchare": "escanchar",
    "escancharei": "escanchar",
    "escanchareis": "escanchar",
    "escancharem": "escanchar",
    "escancharemos": "escanchar",
    "escanchares": "escanchar",
    "escancharia": "escanchar",
    "escanchariam": "escanchar",
    "escancharias": "escanchar",
    "escancharmo": "escanchar",
    "escancharmos": "escanchar",
    "escanchará": "escanchar",
    "escancharás": "escanchar",
    "escancharão": "escanchar",
    "escancharíamos": "escanchar",
    "escancharíeis": "escanchar",
    "escanchas": "escanchar",
    "escanchasse": "escanchar",
    "escanchassem": "escanchar",
    "escanchasses": "escanchar",
    "escanchaste": "escanchar",
    "escanchastes": "escanchar",
    "escanchava": "escanchar",
    "escanchavam": "escanchar",
    "escanchavas": "escanchar",
    "escanche": "escanchar",
    "escanchei": "escanchar",
    "escancheis": "escanchar",
    "escanchem": "escanchar",
    "escanchemo": "escanchar",
    "escanchemos": "escanchar",
    "escanches": "escanchar",
    "escancho": "escanchar",
    "escanchou": "escanchar",
    "escanchá": "escanchar",
    "escanchámo": "escanchar",
    "escanchámos": "escanchar",
    "escancháramo": "escanchar",
    "escancháramos": "escanchar",
    "escanchárei": "escanchar",
    "escancháreis": "escanchar",
    "escanchásseis": "escanchar",
    "escanchássemos": "escanchar",
    "escanchávamo": "escanchar",
    "escanchávamos": "escanchar",
    "escanchávei": "escanchar",
    "escancháveis": "escanchar",
    "escanda": "escandir",
    "escandais": "escandir",
    "escandaleiras": "escandaleira",
    "escandaliza": "escandalizar",
    "escandalizada": "escandalizar",
    "escandalizadas": "escandalizar",
    "escandalizado": "escandalizar",
    "escandalizadora": "escandalizador",
    "escandalizadoras": "escandalizador",
    "escandalizadores": "escandalizador",
    "escandalizados": "escandalizar",
    "escandalizadíssima": "escandalizado",
    "escandalizadíssimas": "escandalizado",
    "escandalizadíssimo": "escandalizado",
    "escandalizadíssimos": "escandalizado",
    "escandalizai": "escandalizar",
    "escandalizais": "escandalizar",
    "escandalizam": "escandalizar",
    "escandalizamo": "escandalizar",
    "escandalizamos": "escandalizar",
    "escandalizando": "escandalizar",
    "escandalizara": "escandalizar",
    "escandalizaram": "escandalizar",
    "escandalizaras": "escandalizar",
    "escandalizarde": "escandalizar",
    "escandalizardes": "escandalizar",
    "escandalizare": "escandalizar",
    "escandalizarei": "escandalizar",
    "escandalizareis": "escandalizar",
    "escandalizarem": "escandalizar",
    "escandalizaremos": "escandalizar",
    "escandalizares": "escandalizar",
    "escandalizaria": "escandalizar",
    "escandalizariam": "escandalizar",
    "escandalizarias": "escandalizar",
    "escandalizarmo": "escandalizar",
    "escandalizarmos": "escandalizar",
    "escandalizará": "escandalizar",
    "escandalizarás": "escandalizar",
    "escandalizarão": "escandalizar",
    "escandalizaríamos": "escandalizar",
    "escandalizaríeis": "escandalizar",
    "escandalizas": "escandalizar",
    "escandalizasse": "escandalizar",
    "escandalizassem": "escandalizar",
    "escandalizasses": "escandalizar",
    "escandalizaste": "escandalizar",
    "escandalizastes": "escandalizar",
    "escandalizava": "escandalizar",
    "escandalizavam": "escandalizar",
    "escandalizavas": "escandalizar",
    "escandalizações": "escandalização",
    "escandalize": "escandalizar",
    "escandalizei": "escandalizar",
    "escandalizeis": "escandalizar",
    "escandalizem": "escandalizar",
    "escandalizemo": "escandalizar",
    "escandalizemos": "escandalizar",
    "escandalizes": "escandalizar",
    "escandalizo": "escandalizar",
    "escandalizou": "escandalizar",
    "escandalizá": "escandalizar",
    "escandalizámo": "escandalizar",
    "escandalizámos": "escandalizar",
    "escandalizáramo": "escandalizar",
    "escandalizáramos": "escandalizar",
    "escandalizárei": "escandalizar",
    "escandalizáreis": "escandalizar",
    "escandalizásseis": "escandalizar",
    "escandalizássemos": "escandalizar",
    "escandalizávamo": "escandalizar",
    "escandalizávamos": "escandalizar",
    "escandalizávei": "escandalizar",
    "escandalizáveis": "escandalizável",
    "escandalosa": "escandaloso",
    "escandalosas": "escandaloso",
    "escandalosos": "escandaloso",
    "escandam": "escandir",
    "escandamo": "escandir",
    "escandamos": "escandir",
    "escandas": "escandir",
    "escande": "escandir",
    "escandece": "escandecer",
    "escandecei": "escandecer",
    "escandeceis": "escandecer",
    "escandecem": "escandecer",
    "escandecemo": "escandecer",
    "escandecemos": "escandecer",
    "escandecendo": "escandecer",
    "escandecentes": "escandecente",
    "escandecera": "escandecer",
    "escandeceram": "escandecer",
    "escandeceras": "escandecer",
    "escandecerdes": "escandecer",
    "escandecerei": "escandecer",
    "escandecereis": "escandecer",
    "escandecerem": "escandecer",
    "escandeceremos": "escandecer",
    "escandeceres": "escandecer",
    "escandeceria": "escandecer",
    "escandeceriam": "escandecer",
    "escandecerias": "escandecer",
    "escandecermo": "escandecer",
    "escandecermos": "escandecer",
    "escandecerá": "escandecer",
    "escandecerás": "escandecer",
    "escandecerão": "escandecer",
    "escandeceríamos": "escandecer",
    "escandeceríeis": "escandecer",
    "escandeces": "escandecer",
    "escandecesse": "escandecer",
    "escandecessem": "escandecer",
    "escandecesses": "escandecer",
    "escandeceste": "escandecer",
    "escandecestes": "escandecer",
    "escandeceu": "escandecer",
    "escandeci": "escandecer",
    "escandecia": "escandecer",
    "escandeciam": "escandecer",
    "escandecias": "escandecer",
    "escandecida": "escandecido",
    "escandecidas": "escandecido",
    "escandecido": "escandecer",
    "escandecidos": "escandecido",
    "escandecências": "escandecência",
    "escandecêramo": "escandecer",
    "escandecêramos": "escandecer",
    "escandecêreis": "escandecer",
    "escandecêsseis": "escandecer",
    "escandecêssemos": "escandecer",
    "escandecíamo": "escandecer",
    "escandecíamos": "escandecer",
    "escandecíeis": "escandecer",
    "escandem": "escandir",
    "escandes": "escandir",
    "escandeça": "escandecer",
    "escandeçais": "escandecer",
    "escandeçam": "escandecer",
    "escandeçamo": "escandecer",
    "escandeçamos": "escandecer",
    "escandeças": "escandecer",
    "escandeço": "escandecer",
    "escandi": "escandir",
    "escandia": "escandir",
    "escandiam": "escandir",
    "escandias": "escandir",
    "escandida": "escandir",
    "escandidas": "escandir",
    "escandido": "escandir",
    "escandidos": "escandir",
    "escandimo": "escandir",
    "escandimos": "escandir",
    "escandinava": "escandinavo",
    "escandinavas": "escandinavo",
    "escandinavos": "escandinavo",
    "escandindo": "escandir",
    "escandira": "escandir",
    "escandiram": "escandir",
    "escandiras": "escandir",
    "escandirde": "escandir",
    "escandirdes": "escandir",
    "escandire": "escandir",
    "escandirei": "escandir",
    "escandireis": "escandir",
    "escandirem": "escandir",
    "escandiremos": "escandir",
    "escandires": "escandir",
    "escandiria": "escandir",
    "escandiriam": "escandir",
    "escandirias": "escandir",
    "escandirmo": "escandir",
    "escandirmos": "escandir",
    "escandirá": "escandir",
    "escandirás": "escandir",
    "escandirão": "escandir",
    "escandiríamos": "escandir",
    "escandiríeis": "escandir",
    "escandis": "escandir",
    "escandisse": "escandir",
    "escandissem": "escandir",
    "escandisses": "escandir",
    "escandiste": "escandir",
    "escandistes": "escandir",
    "escandiu": "escandir",
    "escando": "escandir",
    "escandíamo": "escandir",
    "escandíamos": "escandir",
    "escandíei": "escandir",
    "escandíeis": "escandir",
    "escandíramo": "escandir",
    "escandíramos": "escandir",
    "escandírei": "escandir",
    "escandíreis": "escandir",
    "escandísseis": "escandir",
    "escandíssemos": "escandir",
    "escane": "escanar",
    "escanei": "escanar",
    "escaneis": "escanar",
    "escanelada": "escanelado",
    "escaneladas": "escanelado",
    "escanelados": "escanelado",
    "escanem": "escanar",
    "escanemo": "escanar",
    "escanemos": "escanar",
    "escanes": "escanar",
    "escanga": "escangar",
    "escangada": "escangar",
    "escangadas": "escangar",
    "escangado": "escangar",
    "escangados": "escangar",
    "escangai": "escangar",
    "escangais": "escangar",
    "escangalha": "escangalhar",
    "escangalhada": "escangalhar",
    "escangalhadas": "escangalhar",
    "escangalhado": "escangalhar",
    "escangalhados": "escangalhar",
    "escangalhai": "escangalhar",
    "escangalhais": "escangalhar",
    "escangalham": "escangalhar",
    "escangalhamo": "escangalhar",
    "escangalhamos": "escangalhar",
    "escangalhando": "escangalhar",
    "escangalhara": "escangalhar",
    "escangalharam": "escangalhar",
    "escangalharas": "escangalhar",
    "escangalharde": "escangalhar",
    "escangalhardes": "escangalhar",
    "escangalhare": "escangalhar",
    "escangalharei": "escangalhar",
    "escangalhareis": "escangalhar",
    "escangalharem": "escangalhar",
    "escangalharemos": "escangalhar",
    "escangalhares": "escangalhar",
    "escangalharia": "escangalhar",
    "escangalhariam": "escangalhar",
    "escangalharias": "escangalhar",
    "escangalharmo": "escangalhar",
    "escangalharmos": "escangalhar",
    "escangalhará": "escangalhar",
    "escangalharás": "escangalhar",
    "escangalharão": "escangalhar",
    "escangalharíamos": "escangalhar",
    "escangalharíeis": "escangalhar",
    "escangalhas": "escangalhar",
    "escangalhasse": "escangalhar",
    "escangalhassem": "escangalhar",
    "escangalhasses": "escangalhar",
    "escangalhaste": "escangalhar",
    "escangalhastes": "escangalhar",
    "escangalhava": "escangalhar",
    "escangalhavam": "escangalhar",
    "escangalhavas": "escangalhar",
    "escangalhações": "escangalhação",
    "escangalhe": "escangalhar",
    "escangalhei": "escangalhar",
    "escangalheis": "escangalhar",
    "escangalhem": "escangalhar",
    "escangalhemo": "escangalhar",
    "escangalhemos": "escangalhar",
    "escangalhes": "escangalhar",
    "escangalho": "escangalhar",
    "escangalhou": "escangalhar",
    "escangalhá": "escangalhar",
    "escangalhámo": "escangalhar",
    "escangalhámos": "escangalhar",
    "escangalháramo": "escangalhar",
    "escangalháramos": "escangalhar",
    "escangalhárei": "escangalhar",
    "escangalháreis": "escangalhar",
    "escangalhásseis": "escangalhar",
    "escangalhássemos": "escangalhar",
    "escangalhávamo": "escangalhar",
    "escangalhávamos": "escangalhar",
    "escangalhávei": "escangalhar",
    "escangalháveis": "escangalhar",
    "escangam": "escangar",
    "escangamo": "escangar",
    "escangamos": "escangar",
    "escangando": "escangar",
    "escanganha": "escanganhar",
    "escanganhada": "escanganhar",
    "escanganhadas": "escanganhar",
    "escanganhadeiras": "escanganhadeira",
    "escanganhado": "escanganhar",
    "escanganhados": "escanganhar",
    "escanganhai": "escanganhar",
    "escanganhais": "escanganhar",
    "escanganham": "escanganhar",
    "escanganhamo": "escanganhar",
    "escanganhamos": "escanganhar",
    "escanganhando": "escanganhar",
    "escanganhara": "escanganhar",
    "escanganharam": "escanganhar",
    "escanganharas": "escanganhar",
    "escanganharde": "escanganhar",
    "escanganhardes": "escanganhar",
    "escanganhare": "escanganhar",
    "escanganharei": "escanganhar",
    "escanganhareis": "escanganhar",
    "escanganharem": "escanganhar",
    "escanganharemos": "escanganhar",
    "escanganhares": "escanganhar",
    "escanganharia": "escanganhar",
    "escanganhariam": "escanganhar",
    "escanganharias": "escanganhar",
    "escanganharmo": "escanganhar",
    "escanganharmos": "escanganhar",
    "escanganhará": "escanganhar",
    "escanganharás": "escanganhar",
    "escanganharão": "escanganhar",
    "escanganharíamos": "escanganhar",
    "escanganharíeis": "escanganhar",
    "escanganhas": "escanganhar",
    "escanganhasse": "escanganhar",
    "escanganhassem": "escanganhar",
    "escanganhasses": "escanganhar",
    "escanganhaste": "escanganhar",
    "escanganhastes": "escanganhar",
    "escanganhava": "escanganhar",
    "escanganhavam": "escanganhar",
    "escanganhavas": "escanganhar",
    "escanganhe": "escanganhar",
    "escanganhei": "escanganhar",
    "escanganheis": "escanganhar",
    "escanganhem": "escanganhar",
    "escanganhemo": "escanganhar",
    "escanganhemos": "escanganhar",
    "escanganhes": "escanganhar",
    "escanganho": "escanganhar",
    "escanganhos": "escanganho",
    "escanganhou": "escanganhar",
    "escanganhá": "escanganhar",
    "escanganhámo": "escanganhar",
    "escanganhámos": "escanganhar",
    "escanganháramo": "escanganhar",
    "escanganháramos": "escanganhar",
    "escanganhárei": "escanganhar",
    "escanganháreis": "escanganhar",
    "escanganhásseis": "escanganhar",
    "escanganhássemos": "escanganhar",
    "escanganhávamo": "escanganhar",
    "escanganhávamos": "escanganhar",
    "escanganhávei": "escanganhar",
    "escanganháveis": "escanganhar",
    "escangara": "escangar",
    "escangaram": "escangar",
    "escangaras": "escangar",
    "escangarde": "escangar",
    "escangardes": "escangar",
    "escangare": "escangar",
    "escangarei": "escangar",
    "escangareis": "escangar",
    "escangarem": "escangar",
    "escangaremos": "escangar",
    "escangares": "escangar",
    "escangaria": "escangar",
    "escangariam": "escangar",
    "escangarias": "escangar",
    "escangarmo": "escangar",
    "escangarmos": "escangar",
    "escangará": "escangar",
    "escangarás": "escangar",
    "escangarão": "escangar",
    "escangaríamos": "escangar",
    "escangaríeis": "escangar",
    "escangas": "escangar",
    "escangasse": "escangar",
    "escangassem": "escangar",
    "escangasses": "escangar",
    "escangaste": "escangar",
    "escangastes": "escangar",
    "escangava": "escangar",
    "escangavam": "escangar",
    "escangavas": "escangar",
    "escango": "escangar",
    "escangou": "escangar",
    "escangue": "escangar",
    "escanguei": "escangar",
    "escangueis": "escangar",
    "escanguem": "escangar",
    "escanguemo": "escangar",
    "escanguemos": "escangar",
    "escangues": "escangar",
    "escangá": "escangar",
    "escangámo": "escangar",
    "escangámos": "escangar",
    "escangáramo": "escangar",
    "escangáramos": "escangar",
    "escangárei": "escangar",
    "escangáreis": "escangar",
    "escangásseis": "escangar",
    "escangássemos": "escangar",
    "escangávamo": "escangar",
    "escangávamos": "escangar",
    "escangávei": "escangar",
    "escangáveis": "escangar",
    "escanhoa": "escanhoar",
    "escanhoada": "escanhoar",
    "escanhoadas": "escanhoar",
    "escanhoadelas": "escanhoadela",
    "escanhoado": "escanhoar",
    "escanhoadores": "escanhoador",
    "escanhoados": "escanhoar",
    "escanhoai": "escanhoar",
    "escanhoais": "escanhoar",
    "escanhoam": "escanhoar",
    "escanhoamentos": "escanhoamento",
    "escanhoamo": "escanhoar",
    "escanhoamos": "escanhoar",
    "escanhoando": "escanhoar",
    "escanhoara": "escanhoar",
    "escanhoaram": "escanhoar",
    "escanhoaras": "escanhoar",
    "escanhoarde": "escanhoar",
    "escanhoardes": "escanhoar",
    "escanhoare": "escanhoar",
    "escanhoarei": "escanhoar",
    "escanhoareis": "escanhoar",
    "escanhoarem": "escanhoar",
    "escanhoaremos": "escanhoar",
    "escanhoares": "escanhoar",
    "escanhoaria": "escanhoar",
    "escanhoariam": "escanhoar",
    "escanhoarias": "escanhoar",
    "escanhoarmo": "escanhoar",
    "escanhoarmos": "escanhoar",
    "escanhoará": "escanhoar",
    "escanhoarás": "escanhoar",
    "escanhoarão": "escanhoar",
    "escanhoaríamos": "escanhoar",
    "escanhoaríeis": "escanhoar",
    "escanhoas": "escanhoar",
    "escanhoasse": "escanhoar",
    "escanhoassem": "escanhoar",
    "escanhoasses": "escanhoar",
    "escanhoaste": "escanhoar",
    "escanhoastes": "escanhoar",
    "escanhoava": "escanhoar",
    "escanhoavam": "escanhoar",
    "escanhoavas": "escanhoar",
    "escanhoe": "escanhoar",
    "escanhoei": "escanhoar",
    "escanhoeis": "escanhoar",
    "escanhoem": "escanhoar",
    "escanhoemo": "escanhoar",
    "escanhoemos": "escanhoar",
    "escanhoes": "escanhoar",
    "escanhoo": "escanhoar",
    "escanhoou": "escanhoar",
    "escanhos": "escanho",
    "escanhota": "escanhotar",
    "escanhotada": "escanhotar",
    "escanhotadas": "escanhotar",
    "escanhotado": "escanhotar",
    "escanhotadora": "escanhotador",
    "escanhotadoras": "escanhotador",
    "escanhotadores": "escanhotador",
    "escanhotados": "escanhotar",
    "escanhotai": "escanhotar",
    "escanhotais": "escanhotar",
    "escanhotam": "escanhotar",
    "escanhotamo": "escanhotar",
    "escanhotamos": "escanhotar",
    "escanhotando": "escanhotar",
    "escanhotara": "escanhotar",
    "escanhotaram": "escanhotar",
    "escanhotaras": "escanhotar",
    "escanhotarde": "escanhotar",
    "escanhotardes": "escanhotar",
    "escanhotare": "escanhotar",
    "escanhotarei": "escanhotar",
    "escanhotareis": "escanhotar",
    "escanhotarem": "escanhotar",
    "escanhotaremos": "escanhotar",
    "escanhotares": "escanhotar",
    "escanhotaria": "escanhotar",
    "escanhotariam": "escanhotar",
    "escanhotarias": "escanhotar",
    "escanhotarmo": "escanhotar",
    "escanhotarmos": "escanhotar",
    "escanhotará": "escanhotar",
    "escanhotarás": "escanhotar",
    "escanhotarão": "escanhotar",
    "escanhotaríamos": "escanhotar",
    "escanhotaríeis": "escanhotar",
    "escanhotas": "escanhotar",
    "escanhotasse": "escanhotar",
    "escanhotassem": "escanhotar",
    "escanhotasses": "escanhotar",
    "escanhotaste": "escanhotar",
    "escanhotastes": "escanhotar",
    "escanhotava": "escanhotar",
    "escanhotavam": "escanhotar",
    "escanhotavas": "escanhotar",
    "escanhote": "escanhotar",
    "escanhotei": "escanhotar",
    "escanhoteis": "escanhotar",
    "escanhotem": "escanhotar",
    "escanhotemo": "escanhotar",
    "escanhotemos": "escanhotar",
    "escanhotes": "escanhotar",
    "escanhoto": "escanhotar",
    "escanhotou": "escanhotar",
    "escanhotá": "escanhotar",
    "escanhotámo": "escanhotar",
    "escanhotámos": "escanhotar",
    "escanhotáramo": "escanhotar",
    "escanhotáramos": "escanhotar",
    "escanhotárei": "escanhotar",
    "escanhotáreis": "escanhotar",
    "escanhotásseis": "escanhotar",
    "escanhotássemos": "escanhotar",
    "escanhotávamo": "escanhotar",
    "escanhotávamos": "escanhotar",
    "escanhotávei": "escanhotar",
    "escanhotáveis": "escanhotar",
    "escanhoá": "escanhoar",
    "escanhoámo": "escanhoar",
    "escanhoámos": "escanhoar",
    "escanhoáramo": "escanhoar",
    "escanhoáramos": "escanhoar",
    "escanhoárei": "escanhoar",
    "escanhoáreis": "escanhoar",
    "escanhoásseis": "escanhoar",
    "escanhoássemos": "escanhoar",
    "escanhoávamo": "escanhoar",
    "escanhoávamos": "escanhoar",
    "escanhoávei": "escanhoar",
    "escanhoáveis": "escanhoar",
    "escanifra": "escanifrar",
    "escanifrada": "escanifrar",
    "escanifradas": "escanifrar",
    "escanifrado": "escanifrar",
    "escanifrados": "escanifrar",
    "escanifrai": "escanifrar",
    "escanifrais": "escanifrar",
    "escanifram": "escanifrar",
    "escaniframo": "escanifrar",
    "escaniframos": "escanifrar",
    "escanifrando": "escanifrar",
    "escanifrara": "escanifrar",
    "escanifraram": "escanifrar",
    "escanifraras": "escanifrar",
    "escanifrarde": "escanifrar",
    "escanifrardes": "escanifrar",
    "escanifrare": "escanifrar",
    "escanifrarei": "escanifrar",
    "escanifrareis": "escanifrar",
    "escanifrarem": "escanifrar",
    "escanifraremos": "escanifrar",
    "escanifrares": "escanifrar",
    "escanifraria": "escanifrar",
    "escanifrariam": "escanifrar",
    "escanifrarias": "escanifrar",
    "escanifrarmo": "escanifrar",
    "escanifrarmos": "escanifrar",
    "escanifrará": "escanifrar",
    "escanifrarás": "escanifrar",
    "escanifrarão": "escanifrar",
    "escanifraríamos": "escanifrar",
    "escanifraríeis": "escanifrar",
    "escanifras": "escanifrar",
    "escanifrasse": "escanifrar",
    "escanifrassem": "escanifrar",
    "escanifrasses": "escanifrar",
    "escanifraste": "escanifrar",
    "escanifrastes": "escanifrar",
    "escanifrava": "escanifrar",
    "escanifravam": "escanifrar",
    "escanifravas": "escanifrar",
    "escanifre": "escanifrar",
    "escanifrei": "escanifrar",
    "escanifreis": "escanifrar",
    "escanifrem": "escanifrar",
    "escanifremo": "escanifrar",
    "escanifremos": "escanifrar",
    "escanifres": "escanifre",
    "escanifro": "escanifrar",
    "escanifrou": "escanifrar",
    "escanifrá": "escanifrar",
    "escanifrámo": "escanifrar",
    "escanifrámos": "escanifrar",
    "escanifráramo": "escanifrar",
    "escanifráramos": "escanifrar",
    "escanifrárei": "escanifrar",
    "escanifráreis": "escanifrar",
    "escanifrásseis": "escanifrar",
    "escanifrássemos": "escanifrar",
    "escanifrávamo": "escanifrar",
    "escanifrávamos": "escanifrar",
    "escanifrávei": "escanifrar",
    "escanifráveis": "escanifrar",
    "escaninha": "escaninhar",
    "escaninhada": "escaninhar",
    "escaninhadas": "escaninhar",
    "escaninhado": "escaninhar",
    "escaninhados": "escaninhar",
    "escaninhai": "escaninhar",
    "escaninhais": "escaninhar",
    "escaninham": "escaninhar",
    "escaninhamo": "escaninhar",
    "escaninhamos": "escaninhar",
    "escaninhando": "escaninhar",
    "escaninhara": "escaninhar",
    "escaninharam": "escaninhar",
    "escaninharas": "escaninhar",
    "escaninharde": "escaninhar",
    "escaninhardes": "escaninhar",
    "escaninhare": "escaninhar",
    "escaninharei": "escaninhar",
    "escaninhareis": "escaninhar",
    "escaninharem": "escaninhar",
    "escaninharemos": "escaninhar",
    "escaninhares": "escaninhar",
    "escaninharia": "escaninhar",
    "escaninhariam": "escaninhar",
    "escaninharias": "escaninhar",
    "escaninharmo": "escaninhar",
    "escaninharmos": "escaninhar",
    "escaninhará": "escaninhar",
    "escaninharás": "escaninhar",
    "escaninharão": "escaninhar",
    "escaninharíamos": "escaninhar",
    "escaninharíeis": "escaninhar",
    "escaninhas": "escaninhar",
    "escaninhasse": "escaninhar",
    "escaninhassem": "escaninhar",
    "escaninhasses": "escaninhar",
    "escaninhaste": "escaninhar",
    "escaninhastes": "escaninhar",
    "escaninhava": "escaninhar",
    "escaninhavam": "escaninhar",
    "escaninhavas": "escaninhar",
    "escaninhe": "escaninhar",
    "escaninhei": "escaninhar",
    "escaninheis": "escaninhar",
    "escaninhem": "escaninhar",
    "escaninhemo": "escaninhar",
    "escaninhemos": "escaninhar",
    "escaninhes": "escaninhar",
    "escaninho": "escaninhar",
    "escaninhos": "escaninho",
    "escaninhou": "escaninhar",
    "escaninhá": "escaninhar",
    "escaninhámo": "escaninhar",
    "escaninhámos": "escaninhar",
    "escaninháramo": "escaninhar",
    "escaninháramos": "escaninhar",
    "escaninhárei": "escaninhar",
    "escaninháreis": "escaninhar",
    "escaninhásseis": "escaninhar",
    "escaninhássemos": "escaninhar",
    "escaninhávamo": "escaninhar",
    "escaninhávamos": "escaninhar",
    "escaninhávei": "escaninhar",
    "escaninháveis": "escaninhar",
    "escano": "escanar",
    "escanos": "escano",
    "escanou": "escanar",
    "escansões": "escansão",
    "escantada": "escantado",
    "escantadas": "escantado",
    "escantados": "escantado",
    "escanteada": "escanteado",
    "escanteadas": "escanteado",
    "escanteados": "escanteado",
    "escantilhões": "escantilhão",
    "escantuda": "escantudo",
    "escantudas": "escantudo",
    "escantudos": "escantudo",
    "escanzelada": "escanzelado",
    "escanzeladas": "escanzelado",
    "escanzelados": "escanzelado",
    "escanzelos": "escanzelo",
    "escaná": "escanar",
    "escanámo": "escanar",
    "escanámos": "escanar",
    "escanáramo": "escanar",
    "escanáramos": "escanar",
    "escanárei": "escanar",
    "escanáreis": "escanar",
    "escanásseis": "escanar",
    "escanássemos": "escanar",
    "escanávamo": "escanar",
    "escanávamos": "escanar",
    "escanávei": "escanar",
    "escanáveis": "escanar",
    "escança": "escançar",
    "escançada": "escançar",
    "escançadas": "escançar",
    "escançado": "escançar",
    "escançados": "escançar",
    "escançai": "escançar",
    "escançais": "escançar",
    "escançam": "escançar",
    "escançamo": "escançar",
    "escançamos": "escançar",
    "escançando": "escançar",
    "escançara": "escançar",
    "escançaram": "escançar",
    "escançaras": "escançar",
    "escançarde": "escançar",
    "escançardes": "escançar",
    "escançare": "escançar",
    "escançarei": "escançar",
    "escançareis": "escançar",
    "escançarem": "escançar",
    "escançaremos": "escançar",
    "escançares": "escançar",
    "escançaria": "escançar",
    "escançariam": "escançar",
    "escançarias": "escançar",
    "escançarmo": "escançar",
    "escançarmos": "escançar",
    "escançará": "escançar",
    "escançarás": "escançar",
    "escançarão": "escançar",
    "escançaríamos": "escançar",
    "escançaríeis": "escançar",
    "escanças": "escançar",
    "escançasse": "escançar",
    "escançassem": "escançar",
    "escançasses": "escançar",
    "escançaste": "escançar",
    "escançastes": "escançar",
    "escançava": "escançar",
    "escançavam": "escançar",
    "escançavas": "escançar",
    "escanço": "escançar",
    "escançou": "escançar",
    "escançá": "escançar",
    "escançámo": "escançar",
    "escançámos": "escançar",
    "escançáramo": "escançar",
    "escançáramos": "escançar",
    "escançárei": "escançar",
    "escançáreis": "escançar",
    "escançásseis": "escançar",
    "escançássemos": "escançar",
    "escançávamo": "escançar",
    "escançávamos": "escançar",
    "escançávei": "escançar",
    "escançáveis": "escançar",
    "escanções": "escanção",
    "escapa": "escapo",
    "escapada": "escapar",
    "escapadas": "escapar",
    "escapadelas": "escapadela",
    "escapadiça": "escapadiço",
    "escapadiças": "escapadiço",
    "escapadiços": "escapadiço",
    "escapado": "escapar",
    "escapados": "escapar",
    "escapai": "escapar",
    "escapais": "escapar",
    "escapam": "escapar",
    "escapamentos": "escapamento",
    "escapamo": "escapar",
    "escapamos": "escapar",
    "escapando": "escapar",
    "escapara": "escapar",
    "escaparam": "escapar",
    "escaparas": "escapar",
    "escaparates": "escaparate",
    "escapardes": "escapar",
    "escaparei": "escapar",
    "escapareis": "escapar",
    "escaparem": "escapar",
    "escaparemos": "escapar",
    "escapares": "escapar",
    "escaparia": "escapar",
    "escapariam": "escapar",
    "escaparias": "escapar",
    "escaparmo": "escapar",
    "escaparmos": "escapar",
    "escapará": "escapar",
    "escaparás": "escapar",
    "escaparão": "escapar",
    "escaparíamos": "escapar",
    "escaparíeis": "escapar",
    "escapas": "escapo",
    "escapasse": "escapar",
    "escapassem": "escapar",
    "escapasses": "escapar",
    "escapaste": "escapar",
    "escapastes": "escapar",
    "escapatória": "escapatório",
    "escapatórias": "escapatório",
    "escapatórios": "escapatório",
    "escapava": "escapar",
    "escapavam": "escapar",
    "escapavas": "escapar",
    "escape": "escapar",
    "escapei": "escapar",
    "escapeis": "escapar",
    "escapela": "escapelar",
    "escapelada": "escapelar",
    "escapeladas": "escapelar",
    "escapelado": "escapelar",
    "escapelados": "escapelar",
    "escapelai": "escapelar",
    "escapelais": "escapelar",
    "escapelam": "escapelar",
    "escapelamo": "escapelar",
    "escapelamos": "escapelar",
    "escapelando": "escapelar",
    "escapelara": "escapelar",
    "escapelaram": "escapelar",
    "escapelaras": "escapelar",
    "escapelarde": "escapelar",
    "escapelardes": "escapelar",
    "escapelare": "escapelar",
    "escapelarei": "escapelar",
    "escapelareis": "escapelar",
    "escapelarem": "escapelar",
    "escapelaremos": "escapelar",
    "escapelares": "escapelar",
    "escapelaria": "escapelar",
    "escapelariam": "escapelar",
    "escapelarias": "escapelar",
    "escapelarmo": "escapelar",
    "escapelarmos": "escapelar",
    "escapelará": "escapelar",
    "escapelarás": "escapelar",
    "escapelarão": "escapelar",
    "escapelaríamos": "escapelar",
    "escapelaríeis": "escapelar",
    "escapelas": "escapelar",
    "escapelasse": "escapelar",
    "escapelassem": "escapelar",
    "escapelasses": "escapelar",
    "escapelaste": "escapelar",
    "escapelastes": "escapelar",
    "escapelava": "escapelar",
    "escapelavam": "escapelar",
    "escapelavas": "escapelar",
    "escapele": "escapelar",
    "escapelei": "escapelar",
    "escapeleis": "escapelar",
    "escapelem": "escapelar",
    "escapelemo": "escapelar",
    "escapelemos": "escapelar",
    "escapeles": "escapelar",
    "escapelo": "escapelar",
    "escapelou": "escapelar",
    "escapelá": "escapelar",
    "escapelámo": "escapelar",
    "escapelámos": "escapelar",
    "escapeláramo": "escapelar",
    "escapeláramos": "escapelar",
    "escapelárei": "escapelar",
    "escapeláreis": "escapelar",
    "escapelásseis": "escapelar",
    "escapelássemos": "escapelar",
    "escapelávamo": "escapelar",
    "escapelávamos": "escapelar",
    "escapelávei": "escapelar",
    "escapeláveis": "escapelar",
    "escapem": "escapar",
    "escapemo": "escapar",
    "escapemos": "escapar",
    "escapes": "escape",
    "escapo": "escapar",
    "escapos": "escapo",
    "escapou": "escapar",
    "escapula": "escapulir",
    "escapulais": "escapulir",
    "escapulalgias": "escapulalgia",
    "escapulam": "escapulir",
    "escapulamo": "escapulir",
    "escapulamos": "escapulir",
    "escapulares": "escapular",
    "escapulas": "escapulir",
    "escapule": "escapulir",
    "escapulem": "escapulir",
    "escapules": "escapulir",
    "escapuli": "escapulir",
    "escapulia": "escapulir",
    "escapuliam": "escapulir",
    "escapulias": "escapulir",
    "escapulida": "escapulir",
    "escapulidas": "escapulir",
    "escapulido": "escapulir",
    "escapulidos": "escapulir",
    "escapulimo": "escapulir",
    "escapulimos": "escapulir",
    "escapulindo": "escapulir",
    "escapulira": "escapulir",
    "escapuliram": "escapulir",
    "escapuliras": "escapulir",
    "escapulirdes": "escapulir",
    "escapulirei": "escapulir",
    "escapulireis": "escapulir",
    "escapulirem": "escapulir",
    "escapuliremos": "escapulir",
    "escapulires": "escapulir",
    "escapuliria": "escapulir",
    "escapuliriam": "escapulir",
    "escapulirias": "escapulir",
    "escapulirmo": "escapulir",
    "escapulirmos": "escapulir",
    "escapulirá": "escapulir",
    "escapulirás": "escapulir",
    "escapulirão": "escapulir",
    "escapuliríamos": "escapulir",
    "escapuliríeis": "escapulir",
    "escapulis": "escapulir",
    "escapulisse": "escapulir",
    "escapulissem": "escapulir",
    "escapulisses": "escapulir",
    "escapuliste": "escapulir",
    "escapulistes": "escapulir",
    "escapuliu": "escapulir",
    "escapulo": "escapulir",
    "escapulários": "escapulário",
    "escapulíamo": "escapulir",
    "escapulíamos": "escapulir",
    "escapulíeis": "escapulir",
    "escapulíramo": "escapulir",
    "escapulíramos": "escapulir",
    "escapulíreis": "escapulir",
    "escapulísseis": "escapulir",
    "escapulíssemos": "escapulir",
    "escapámo": "escapar",
    "escapámos": "escapar",
    "escapáramo": "escapar",
    "escapáramos": "escapar",
    "escapáreis": "escapar",
    "escapásseis": "escapar",
    "escapássemos": "escapar",
    "escapávamo": "escapar",
    "escapávamos": "escapar",
    "escapáveis": "escapar",
    "escaque": "escacar",
    "escaqueada": "escaquear",
    "escaqueadas": "escaquear",
    "escaqueado": "escaquear",
    "escaqueados": "escaquear",
    "escaqueai": "escaquear",
    "escaqueais": "escaquear",
    "escaqueamo": "escaquear",
    "escaqueamos": "escaquear",
    "escaqueando": "escaquear",
    "escaqueara": "escaquear",
    "escaquearam": "escaquear",
    "escaquearas": "escaquear",
    "escaquearde": "escaquear",
    "escaqueardes": "escaquear",
    "escaqueare": "escaquear",
    "escaquearei": "escaquear",
    "escaqueareis": "escaquear",
    "escaquearem": "escaquear",
    "escaquearemos": "escaquear",
    "escaqueares": "escaquear",
    "escaquearia": "escaquear",
    "escaqueariam": "escaquear",
    "escaquearias": "escaquear",
    "escaquearmo": "escaquear",
    "escaquearmos": "escaquear",
    "escaqueará": "escaquear",
    "escaquearás": "escaquear",
    "escaquearão": "escaquear",
    "escaquearíamos": "escaquear",
    "escaquearíeis": "escaquear",
    "escaqueasse": "escaquear",
    "escaqueassem": "escaquear",
    "escaqueasses": "escaquear",
    "escaqueaste": "escaquear",
    "escaqueastes": "escaquear",
    "escaqueava": "escaquear",
    "escaqueavam": "escaquear",
    "escaqueavas": "escaquear",
    "escaqueei": "escaquear",
    "escaqueeis": "escaquear",
    "escaqueemo": "escaquear",
    "escaqueemos": "escaquear",
    "escaquei": "escacar",
    "escaqueia": "escaquear",
    "escaqueiam": "escaquear",
    "escaqueias": "escaquear",
    "escaqueie": "escaquear",
    "escaqueiem": "escaquear",
    "escaqueies": "escaquear",
    "escaqueio": "escaquear",
    "escaqueira": "escaqueirar",
    "escaqueirada": "escaqueirar",
    "escaqueiradas": "escaqueirar",
    "escaqueirado": "escaqueirar",
    "escaqueirados": "escaqueirar",
    "escaqueirai": "escaqueirar",
    "escaqueirais": "escaqueirar",
    "escaqueiram": "escaqueirar",
    "escaqueiramo": "escaqueirar",
    "escaqueiramos": "escaqueirar",
    "escaqueirando": "escaqueirar",
    "escaqueirara": "escaqueirar",
    "escaqueiraram": "escaqueirar",
    "escaqueiraras": "escaqueirar",
    "escaqueirarde": "escaqueirar",
    "escaqueirardes": "escaqueirar",
    "escaqueirare": "escaqueirar",
    "escaqueirarei": "escaqueirar",
    "escaqueirareis": "escaqueirar",
    "escaqueirarem": "escaqueirar",
    "escaqueiraremos": "escaqueirar",
    "escaqueirares": "escaqueirar",
    "escaqueiraria": "escaqueirar",
    "escaqueirariam": "escaqueirar",
    "escaqueirarias": "escaqueirar",
    "escaqueirarmo": "escaqueirar",
    "escaqueirarmos": "escaqueirar",
    "escaqueirará": "escaqueirar",
    "escaqueirarás": "escaqueirar",
    "escaqueirarão": "escaqueirar",
    "escaqueiraríamos": "escaqueirar",
    "escaqueiraríeis": "escaqueirar",
    "escaqueiras": "escaqueirar",
    "escaqueirasse": "escaqueirar",
    "escaqueirassem": "escaqueirar",
    "escaqueirasses": "escaqueirar",
    "escaqueiraste": "escaqueirar",
    "escaqueirastes": "escaqueirar",
    "escaqueirava": "escaqueirar",
    "escaqueiravam": "escaqueirar",
    "escaqueiravas": "escaqueirar",
    "escaqueire": "escaqueirar",
    "escaqueirei": "escaqueirar",
    "escaqueireis": "escaqueirar",
    "escaqueirem": "escaqueirar",
    "escaqueiremo": "escaqueirar",
    "escaqueiremos": "escaqueirar",
    "escaqueires": "escaqueirar",
    "escaqueiro": "escaqueirar",
    "escaqueirou": "escaqueirar",
    "escaqueirá": "escaqueirar",
    "escaqueirámo": "escaqueirar",
    "escaqueirámos": "escaqueirar",
    "escaqueiráramo": "escaqueirar",
    "escaqueiráramos": "escaqueirar",
    "escaqueirárei": "escaqueirar",
    "escaqueiráreis": "escaqueirar",
    "escaqueirásseis": "escaqueirar",
    "escaqueirássemos": "escaqueirar",
    "escaqueirávamo": "escaqueirar",
    "escaqueirávamos": "escaqueirar",
    "escaqueirávei": "escaqueirar",
    "escaqueiráveis": "escaqueirar",
    "escaqueis": "escacar",
    "escaquem": "escacar",
    "escaquemo": "escacar",
    "escaquemos": "escacar",
    "escaqueou": "escaquear",
    "escaques": "escaque",
    "escaqueá": "escaquear",
    "escaqueámo": "escaquear",
    "escaqueámos": "escaquear",
    "escaqueáramo": "escaquear",
    "escaqueáramos": "escaquear",
    "escaqueárei": "escaquear",
    "escaqueáreis": "escaquear",
    "escaqueásseis": "escaquear",
    "escaqueássemos": "escaquear",
    "escaqueávamo": "escaquear",
    "escaqueávamos": "escaquear",
    "escaqueávei": "escaquear",
    "escaqueáveis": "escaquear",
    "escarabeidas": "escarabeida",
    "escarabeída": "escarabeído",
    "escarabeídas": "escarabeído",
    "escarabeídeos": "escarabeídeo",
    "escarabeídos": "escarabeído",
    "escarabochos": "escarabocho",
    "escarabéus": "escarabéu",
    "escarafuncha": "escarafunchar",
    "escarafunchada": "escarafunchar",
    "escarafunchadas": "escarafunchar",
    "escarafunchado": "escarafunchar",
    "escarafunchadora": "escarafunchador",
    "escarafunchadoras": "escarafunchador",
    "escarafunchadores": "escarafunchador",
    "escarafunchados": "escarafunchar",
    "escarafunchai": "escarafunchar",
    "escarafunchais": "escarafunchar",
    "escarafuncham": "escarafunchar",
    "escarafunchamo": "escarafunchar",
    "escarafunchamos": "escarafunchar",
    "escarafunchando": "escarafunchar",
    "escarafunchara": "escarafunchar",
    "escarafuncharam": "escarafunchar",
    "escarafuncharas": "escarafunchar",
    "escarafuncharde": "escarafunchar",
    "escarafunchardes": "escarafunchar",
    "escarafunchare": "escarafunchar",
    "escarafuncharei": "escarafunchar",
    "escarafunchareis": "escarafunchar",
    "escarafuncharem": "escarafunchar",
    "escarafuncharemos": "escarafunchar",
    "escarafunchares": "escarafunchar",
    "escarafuncharia": "escarafunchar",
    "escarafunchariam": "escarafunchar",
    "escarafuncharias": "escarafunchar",
    "escarafuncharmo": "escarafunchar",
    "escarafuncharmos": "escarafunchar",
    "escarafunchará": "escarafunchar",
    "escarafuncharás": "escarafunchar",
    "escarafuncharão": "escarafunchar",
    "escarafuncharíamos": "escarafunchar",
    "escarafuncharíeis": "escarafunchar",
    "escarafunchas": "escarafunchar",
    "escarafunchasse": "escarafunchar",
    "escarafunchassem": "escarafunchar",
    "escarafunchasses": "escarafunchar",
    "escarafunchaste": "escarafunchar",
    "escarafunchastes": "escarafunchar",
    "escarafunchava": "escarafunchar",
    "escarafunchavam": "escarafunchar",
    "escarafunchavas": "escarafunchar",
    "escarafunche": "escarafunchar",
    "escarafunchei": "escarafunchar",
    "escarafuncheis": "escarafunchar",
    "escarafunchem": "escarafunchar",
    "escarafunchemo": "escarafunchar",
    "escarafunchemos": "escarafunchar",
    "escarafunches": "escarafunchar",
    "escarafuncho": "escarafunchar",
    "escarafunchos": "escarafuncho",
    "escarafunchou": "escarafunchar",
    "escarafunchá": "escarafunchar",
    "escarafunchámo": "escarafunchar",
    "escarafunchámos": "escarafunchar",
    "escarafuncháramo": "escarafunchar",
    "escarafuncháramos": "escarafunchar",
    "escarafunchárei": "escarafunchar",
    "escarafuncháreis": "escarafunchar",
    "escarafunchásseis": "escarafunchar",
    "escarafunchássemos": "escarafunchar",
    "escarafunchávamo": "escarafunchar",
    "escarafunchávamos": "escarafunchar",
    "escarafunchávei": "escarafunchar",
    "escarafuncháveis": "escarafunchar",
    "escaramba": "escarambar",
    "escarambada": "escarambar",
    "escarambadas": "escarambar",
    "escarambado": "escarambar",
    "escarambados": "escarambar",
    "escarambai": "escarambar",
    "escarambais": "escarambar",
    "escarambam": "escarambar",
    "escarambamo": "escarambar",
    "escarambamos": "escarambar",
    "escarambando": "escarambar",
    "escarambara": "escarambar",
    "escarambaram": "escarambar",
    "escarambaras": "escarambar",
    "escarambarde": "escarambar",
    "escarambardes": "escarambar",
    "escarambare": "escarambar",
    "escarambarei": "escarambar",
    "escarambareis": "escarambar",
    "escarambarem": "escarambar",
    "escarambaremos": "escarambar",
    "escarambares": "escarambar",
    "escarambaria": "escarambar",
    "escarambariam": "escarambar",
    "escarambarias": "escarambar",
    "escarambarmo": "escarambar",
    "escarambarmos": "escarambar",
    "escarambará": "escarambar",
    "escarambarás": "escarambar",
    "escarambarão": "escarambar",
    "escarambaríamos": "escarambar",
    "escarambaríeis": "escarambar",
    "escarambas": "escarambar",
    "escarambasse": "escarambar",
    "escarambassem": "escarambar",
    "escarambasses": "escarambar",
    "escarambaste": "escarambar",
    "escarambastes": "escarambar",
    "escarambava": "escarambar",
    "escarambavam": "escarambar",
    "escarambavas": "escarambar",
    "escarambe": "escarambar",
    "escarambei": "escarambar",
    "escarambeis": "escarambar",
    "escarambem": "escarambar",
    "escarambemo": "escarambar",
    "escarambemos": "escarambar",
    "escarambes": "escarambar",
    "escarambo": "escarambar",
    "escarambou": "escarambar",
    "escarambá": "escarambar",
    "escarambámo": "escarambar",
    "escarambámos": "escarambar",
    "escarambáramo": "escarambar",
    "escarambáramos": "escarambar",
    "escarambárei": "escarambar",
    "escarambáreis": "escarambar",
    "escarambásseis": "escarambar",
    "escarambássemos": "escarambar",
    "escarambávamo": "escarambar",
    "escarambávamos": "escarambar",
    "escarambávei": "escarambar",
    "escarambáveis": "escarambar",
    "escaramela": "escaramelar",
    "escaramelada": "escaramelar",
    "escarameladas": "escaramelar",
    "escaramelado": "escaramelar",
    "escaramelados": "escaramelar",
    "escaramelai": "escaramelar",
    "escaramelais": "escaramelar",
    "escaramelam": "escaramelar",
    "escaramelamo": "escaramelar",
    "escaramelamos": "escaramelar",
    "escaramelando": "escaramelar",
    "escaramelara": "escaramelar",
    "escaramelaram": "escaramelar",
    "escaramelaras": "escaramelar",
    "escaramelardes": "escaramelar",
    "escaramelarei": "escaramelar",
    "escaramelareis": "escaramelar",
    "escaramelarem": "escaramelar",
    "escaramelaremos": "escaramelar",
    "escaramelares": "escaramelar",
    "escaramelaria": "escaramelar",
    "escaramelariam": "escaramelar",
    "escaramelarias": "escaramelar",
    "escaramelarmo": "escaramelar",
    "escaramelarmos": "escaramelar",
    "escaramelará": "escaramelar",
    "escaramelarás": "escaramelar",
    "escaramelarão": "escaramelar",
    "escaramelaríamos": "escaramelar",
    "escaramelaríeis": "escaramelar",
    "escaramelas": "escaramelar",
    "escaramelasse": "escaramelar",
    "escaramelassem": "escaramelar",
    "escaramelasses": "escaramelar",
    "escaramelaste": "escaramelar",
    "escaramelastes": "escaramelar",
    "escaramelava": "escaramelar",
    "escaramelavam": "escaramelar",
    "escaramelavas": "escaramelar",
    "escaramele": "escaramelar",
    "escaramelei": "escaramelar",
    "escarameleis": "escaramelar",
    "escaramelem": "escaramelar",
    "escaramelemo": "escaramelar",
    "escaramelemos": "escaramelar",
    "escarameles": "escaramelar",
    "escaramelo": "escaramelar",
    "escaramelou": "escaramelar",
    "escaramelámo": "escaramelar",
    "escaramelámos": "escaramelar",
    "escarameláramo": "escaramelar",
    "escarameláramos": "escaramelar",
    "escarameláreis": "escaramelar",
    "escaramelásseis": "escaramelar",
    "escaramelássemos": "escaramelar",
    "escaramelávamo": "escaramelar",
    "escaramelávamos": "escaramelar",
    "escarameláveis": "escaramelar",
    "escaramuce": "escaramuçar",
    "escaramucei": "escaramuçar",
    "escaramuceis": "escaramuçar",
    "escaramucem": "escaramuçar",
    "escaramucemo": "escaramuçar",
    "escaramucemos": "escaramuçar",
    "escaramuces": "escaramuçar",
    "escaramuça": "escaramuçar",
    "escaramuçada": "escaramuçar",
    "escaramuçadas": "escaramuçar",
    "escaramuçado": "escaramuçar",
    "escaramuçadora": "escaramuçador",
    "escaramuçadoras": "escaramuçador",
    "escaramuçadores": "escaramuçador",
    "escaramuçados": "escaramuçar",
    "escaramuçai": "escaramuçar",
    "escaramuçais": "escaramuçar",
    "escaramuçam": "escaramuçar",
    "escaramuçamo": "escaramuçar",
    "escaramuçamos": "escaramuçar",
    "escaramuçando": "escaramuçar",
    "escaramuçara": "escaramuçar",
    "escaramuçaram": "escaramuçar",
    "escaramuçaras": "escaramuçar",
    "escaramuçardes": "escaramuçar",
    "escaramuçarei": "escaramuçar",
    "escaramuçareis": "escaramuçar",
    "escaramuçarem": "escaramuçar",
    "escaramuçaremos": "escaramuçar",
    "escaramuçares": "escaramuçar",
    "escaramuçaria": "escaramuçar",
    "escaramuçariam": "escaramuçar",
    "escaramuçarias": "escaramuçar",
    "escaramuçarmo": "escaramuçar",
    "escaramuçarmos": "escaramuçar",
    "escaramuçará": "escaramuçar",
    "escaramuçarás": "escaramuçar",
    "escaramuçarão": "escaramuçar",
    "escaramuçaríamos": "escaramuçar",
    "escaramuçaríeis": "escaramuçar",
    "escaramuças": "escaramuçar",
    "escaramuçasse": "escaramuçar",
    "escaramuçassem": "escaramuçar",
    "escaramuçasses": "escaramuçar",
    "escaramuçaste": "escaramuçar",
    "escaramuçastes": "escaramuçar",
    "escaramuçava": "escaramuçar",
    "escaramuçavam": "escaramuçar",
    "escaramuçavas": "escaramuçar",
    "escaramuço": "escaramuçar",
    "escaramuçou": "escaramuçar",
    "escaramuçámo": "escaramuçar",
    "escaramuçámos": "escaramuçar",
    "escaramuçáramo": "escaramuçar",
    "escaramuçáramos": "escaramuçar",
    "escaramuçáreis": "escaramuçar",
    "escaramuçásseis": "escaramuçar",
    "escaramuçássemos": "escaramuçar",
    "escaramuçávamo": "escaramuçar",
    "escaramuçávamos": "escaramuçar",
    "escaramuçáveis": "escaramuçar",
    "escarapela": "escarapelar",
    "escarapelada": "escarapelar",
    "escarapeladas": "escarapelar",
    "escarapelado": "escarapelar",
    "escarapelados": "escarapelar",
    "escarapelai": "escarapelar",
    "escarapelais": "escarapelar",
    "escarapelam": "escarapelar",
    "escarapelamo": "escarapelar",
    "escarapelamos": "escarapelar",
    "escarapelando": "escarapelar",
    "escarapelara": "escarapelar",
    "escarapelaram": "escarapelar",
    "escarapelaras": "escarapelar",
    "escarapelarde": "escarapelar",
    "escarapelardes": "escarapelar",
    "escarapelare": "escarapelar",
    "escarapelarei": "escarapelar",
    "escarapelareis": "escarapelar",
    "escarapelarem": "escarapelar",
    "escarapelaremos": "escarapelar",
    "escarapelares": "escarapelar",
    "escarapelaria": "escarapelar",
    "escarapelariam": "escarapelar",
    "escarapelarias": "escarapelar",
    "escarapelarmo": "escarapelar",
    "escarapelarmos": "escarapelar",
    "escarapelará": "escarapelar",
    "escarapelarás": "escarapelar",
    "escarapelarão": "escarapelar",
    "escarapelaríamos": "escarapelar",
    "escarapelaríeis": "escarapelar",
    "escarapelas": "escarapelar",
    "escarapelasse": "escarapelar",
    "escarapelassem": "escarapelar",
    "escarapelasses": "escarapelar",
    "escarapelaste": "escarapelar",
    "escarapelastes": "escarapelar",
    "escarapelava": "escarapelar",
    "escarapelavam": "escarapelar",
    "escarapelavas": "escarapelar",
    "escarapele": "escarapelar",
    "escarapelei": "escarapelar",
    "escarapeleis": "escarapelar",
    "escarapelem": "escarapelar",
    "escarapelemo": "escarapelar",
    "escarapelemos": "escarapelar",
    "escarapeles": "escarapelar",
    "escarapelo": "escarapelar",
    "escarapelou": "escarapelar",
    "escarapelá": "escarapelar",
    "escarapelámo": "escarapelar",
    "escarapelámos": "escarapelar",
    "escarapeláramo": "escarapelar",
    "escarapeláramos": "escarapelar",
    "escarapelárei": "escarapelar",
    "escarapeláreis": "escarapelar",
    "escarapelásseis": "escarapelar",
    "escarapelássemos": "escarapelar",
    "escarapelávamo": "escarapelar",
    "escarapelávamos": "escarapelar",
    "escarapelávei": "escarapelar",
    "escarapeláveis": "escarapelar",
    "escarapões": "escarapão",
    "escaras": "escara",
    "escaravelas": "escaravela",
    "escaravelhas": "escaravelha",
    "escaravelhos": "escaravelho",
    "escarcalha": "escarcalhar",
    "escarcalhada": "escarcalhar",
    "escarcalhadas": "escarcalhar",
    "escarcalhado": "escarcalhar",
    "escarcalhados": "escarcalhar",
    "escarcalhai": "escarcalhar",
    "escarcalhais": "escarcalhar",
    "escarcalham": "escarcalhar",
    "escarcalhamo": "escarcalhar",
    "escarcalhamos": "escarcalhar",
    "escarcalhando": "escarcalhar",
    "escarcalhara": "escarcalhar",
    "escarcalharam": "escarcalhar",
    "escarcalharas": "escarcalhar",
    "escarcalharde": "escarcalhar",
    "escarcalhardes": "escarcalhar",
    "escarcalhare": "escarcalhar",
    "escarcalharei": "escarcalhar",
    "escarcalhareis": "escarcalhar",
    "escarcalharem": "escarcalhar",
    "escarcalharemos": "escarcalhar",
    "escarcalhares": "escarcalhar",
    "escarcalharia": "escarcalhar",
    "escarcalhariam": "escarcalhar",
    "escarcalharias": "escarcalhar",
    "escarcalharmo": "escarcalhar",
    "escarcalharmos": "escarcalhar",
    "escarcalhará": "escarcalhar",
    "escarcalharás": "escarcalhar",
    "escarcalharão": "escarcalhar",
    "escarcalharíamos": "escarcalhar",
    "escarcalharíeis": "escarcalhar",
    "escarcalhas": "escarcalhar",
    "escarcalhasse": "escarcalhar",
    "escarcalhassem": "escarcalhar",
    "escarcalhasses": "escarcalhar",
    "escarcalhaste": "escarcalhar",
    "escarcalhastes": "escarcalhar",
    "escarcalhava": "escarcalhar",
    "escarcalhavam": "escarcalhar",
    "escarcalhavas": "escarcalhar",
    "escarcalhe": "escarcalhar",
    "escarcalhei": "escarcalhar",
    "escarcalheis": "escarcalhar",
    "escarcalhem": "escarcalhar",
    "escarcalhemo": "escarcalhar",
    "escarcalhemos": "escarcalhar",
    "escarcalhes": "escarcalhar",
    "escarcalho": "escarcalhar",
    "escarcalhou": "escarcalhar",
    "escarcalhá": "escarcalhar",
    "escarcalhámo": "escarcalhar",
    "escarcalhámos": "escarcalhar",
    "escarcalháramo": "escarcalhar",
    "escarcalháramos": "escarcalhar",
    "escarcalhárei": "escarcalhar",
    "escarcalháreis": "escarcalhar",
    "escarcalhásseis": "escarcalhar",
    "escarcalhássemos": "escarcalhar",
    "escarcalhávamo": "escarcalhar",
    "escarcalhávamos": "escarcalhar",
    "escarcalhávei": "escarcalhar",
    "escarcalháveis": "escarcalhar",
    "escarcavela": "escarcavelar",
    "escarcavelada": "escarcavelar",
    "escarcaveladas": "escarcavelar",
    "escarcavelado": "escarcavelar",
    "escarcavelados": "escarcavelar",
    "escarcavelai": "escarcavelar",
    "escarcavelais": "escarcavelar",
    "escarcavelam": "escarcavelar",
    "escarcavelamo": "escarcavelar",
    "escarcavelamos": "escarcavelar",
    "escarcavelando": "escarcavelar",
    "escarcavelara": "escarcavelar",
    "escarcavelaram": "escarcavelar",
    "escarcavelaras": "escarcavelar",
    "escarcavelarde": "escarcavelar",
    "escarcavelardes": "escarcavelar",
    "escarcavelare": "escarcavelar",
    "escarcavelarei": "escarcavelar",
    "escarcavelareis": "escarcavelar",
    "escarcavelarem": "escarcavelar",
    "escarcavelaremos": "escarcavelar",
    "escarcavelares": "escarcavelar",
    "escarcavelaria": "escarcavelar",
    "escarcavelariam": "escarcavelar",
    "escarcavelarias": "escarcavelar",
    "escarcavelarmo": "escarcavelar",
    "escarcavelarmos": "escarcavelar",
    "escarcavelará": "escarcavelar",
    "escarcavelarás": "escarcavelar",
    "escarcavelarão": "escarcavelar",
    "escarcavelaríamos": "escarcavelar",
    "escarcavelaríeis": "escarcavelar",
    "escarcavelas": "escarcavelar",
    "escarcavelasse": "escarcavelar",
    "escarcavelassem": "escarcavelar",
    "escarcavelasses": "escarcavelar",
    "escarcavelaste": "escarcavelar",
    "escarcavelastes": "escarcavelar",
    "escarcavelava": "escarcavelar",
    "escarcavelavam": "escarcavelar",
    "escarcavelavas": "escarcavelar",
    "escarcavele": "escarcavelar",
    "escarcavelei": "escarcavelar",
    "escarcaveleis": "escarcavelar",
    "escarcavelem": "escarcavelar",
    "escarcavelemo": "escarcavelar",
    "escarcavelemos": "escarcavelar",
    "escarcaveles": "escarcavelar",
    "escarcavelo": "escarcavelar",
    "escarcavelou": "escarcavelar",
    "escarcavelá": "escarcavelar",
    "escarcavelámo": "escarcavelar",
    "escarcavelámos": "escarcavelar",
    "escarcaveláramo": "escarcavelar",
    "escarcaveláramos": "escarcavelar",
    "escarcavelárei": "escarcavelar",
    "escarcaveláreis": "escarcavelar",
    "escarcavelásseis": "escarcavelar",
    "escarcavelássemos": "escarcavelar",
    "escarcavelávamo": "escarcavelar",
    "escarcavelávamos": "escarcavelar",
    "escarcavelávei": "escarcavelar",
    "escarcaveláveis": "escarcavelar",
    "escarce": "escarçar",
    "escarceada": "escarcear",
    "escarceadas": "escarcear",
    "escarceado": "escarcear",
    "escarceados": "escarcear",
    "escarceai": "escarcear",
    "escarceais": "escarcear",
    "escarceamo": "escarcear",
    "escarceamos": "escarcear",
    "escarceando": "escarcear",
    "escarceara": "escarcear",
    "escarcearam": "escarcear",
    "escarcearas": "escarcear",
    "escarcearde": "escarcear",
    "escarceardes": "escarcear",
    "escarceare": "escarcear",
    "escarcearei": "escarcear",
    "escarceareis": "escarcear",
    "escarcearem": "escarcear",
    "escarcearemos": "escarcear",
    "escarceares": "escarcear",
    "escarcearia": "escarcear",
    "escarceariam": "escarcear",
    "escarcearias": "escarcear",
    "escarcearmo": "escarcear",
    "escarcearmos": "escarcear",
    "escarceará": "escarcear",
    "escarcearás": "escarcear",
    "escarcearão": "escarcear",
    "escarcearíamos": "escarcear",
    "escarcearíeis": "escarcear",
    "escarceasse": "escarcear",
    "escarceassem": "escarcear",
    "escarceasses": "escarcear",
    "escarceaste": "escarcear",
    "escarceastes": "escarcear",
    "escarceava": "escarcear",
    "escarceavam": "escarcear",
    "escarceavas": "escarcear",
    "escarceei": "escarcear",
    "escarceeis": "escarcear",
    "escarceemo": "escarcear",
    "escarceemos": "escarcear",
    "escarcei": "escarçar",
    "escarceia": "escarcear",
    "escarceiam": "escarcear",
    "escarceias": "escarcear",
    "escarceie": "escarcear",
    "escarceiem": "escarcear",
    "escarceies": "escarcear",
    "escarceio": "escarcear",
    "escarceis": "escarçar",
    "escarcelas": "escarcela",
    "escarcem": "escarçar",
    "escarcemo": "escarçar",
    "escarcemos": "escarçar",
    "escarceou": "escarcear",
    "escarces": "escarçar",
    "escarceá": "escarcear",
    "escarceámo": "escarcear",
    "escarceámos": "escarcear",
    "escarceáramo": "escarcear",
    "escarceáramos": "escarcear",
    "escarceárei": "escarcear",
    "escarceáreis": "escarcear",
    "escarceásseis": "escarcear",
    "escarceássemos": "escarcear",
    "escarceávamo": "escarcear",
    "escarceávamos": "escarcear",
    "escarceávei": "escarcear",
    "escarceáveis": "escarcear",
    "escarcha": "escarchar",
    "escarchada": "escarchar",
    "escarchadas": "escarchar",
    "escarchado": "escarchar",
    "escarchados": "escarchar",
    "escarchai": "escarchar",
    "escarchais": "escarchar",
    "escarcham": "escarchar",
    "escarchamo": "escarchar",
    "escarchamos": "escarchar",
    "escarchando": "escarchar",
    "escarchara": "escarchar",
    "escarcharam": "escarchar",
    "escarcharas": "escarchar",
    "escarcharde": "escarchar",
    "escarchardes": "escarchar",
    "escarchare": "escarchar",
    "escarcharei": "escarchar",
    "escarchareis": "escarchar",
    "escarcharem": "escarchar",
    "escarcharemos": "escarchar",
    "escarchares": "escarchar",
    "escarcharia": "escarchar",
    "escarchariam": "escarchar",
    "escarcharias": "escarchar",
    "escarcharmo": "escarchar",
    "escarcharmos": "escarchar",
    "escarchará": "escarchar",
    "escarcharás": "escarchar",
    "escarcharão": "escarchar",
    "escarcharíamos": "escarchar",
    "escarcharíeis": "escarchar",
    "escarchas": "escarchar",
    "escarchasse": "escarchar",
    "escarchassem": "escarchar",
    "escarchasses": "escarchar",
    "escarchaste": "escarchar",
    "escarchastes": "escarchar",
    "escarchava": "escarchar",
    "escarchavam": "escarchar",
    "escarchavas": "escarchar",
    "escarche": "escarchar",
    "escarchei": "escarchar",
    "escarcheis": "escarchar",
    "escarchem": "escarchar",
    "escarchemo": "escarchar",
    "escarchemos": "escarchar",
    "escarches": "escarchar",
    "escarcho": "escarchar",
    "escarchou": "escarchar",
    "escarchá": "escarchar",
    "escarchámo": "escarchar",
    "escarchámos": "escarchar",
    "escarcháramo": "escarchar",
    "escarcháramos": "escarchar",
    "escarchárei": "escarchar",
    "escarcháreis": "escarchar",
    "escarchásseis": "escarchar",
    "escarchássemos": "escarchar",
    "escarchávamo": "escarchar",
    "escarchávamos": "escarchar",
    "escarchávei": "escarchar",
    "escarcháveis": "escarchar",
    "escarcéus": "escarcéu",
    "escarda": "escardar",
    "escardada": "escardar",
    "escardadas": "escardar",
    "escardado": "escardar",
    "escardados": "escardar",
    "escardai": "escardar",
    "escardais": "escardar",
    "escardam": "escardar",
    "escardamo": "escardar",
    "escardamos": "escardar",
    "escardando": "escardar",
    "escardara": "escardar",
    "escardaram": "escardar",
    "escardaras": "escardar",
    "escardarde": "escardar",
    "escardardes": "escardar",
    "escardare": "escardar",
    "escardarei": "escardar",
    "escardareis": "escardar",
    "escardarem": "escardar",
    "escardaremos": "escardar",
    "escardares": "escardar",
    "escardaria": "escardar",
    "escardariam": "escardar",
    "escardarias": "escardar",
    "escardarmo": "escardar",
    "escardarmos": "escardar",
    "escardará": "escardar",
    "escardarás": "escardar",
    "escardarão": "escardar",
    "escardaríamos": "escardar",
    "escardaríeis": "escardar",
    "escardas": "escardar",
    "escardasse": "escardar",
    "escardassem": "escardar",
    "escardasses": "escardar",
    "escardaste": "escardar",
    "escardastes": "escardar",
    "escardava": "escardar",
    "escardavam": "escardar",
    "escardavas": "escardar",
    "escarde": "escardar",
    "escardeada": "escardear",
    "escardeadas": "escardear",
    "escardeado": "escardear",
    "escardeados": "escardear",
    "escardeai": "escardear",
    "escardeais": "escardear",
    "escardeamo": "escardear",
    "escardeamos": "escardear",
    "escardeando": "escardear",
    "escardeara": "escardear",
    "escardearam": "escardear",
    "escardearas": "escardear",
    "escardearde": "escardear",
    "escardeardes": "escardear",
    "escardeare": "escardear",
    "escardearei": "escardear",
    "escardeareis": "escardear",
    "escardearem": "escardear",
    "escardearemos": "escardear",
    "escardeares": "escardear",
    "escardearia": "escardear",
    "escardeariam": "escardear",
    "escardearias": "escardear",
    "escardearmo": "escardear",
    "escardearmos": "escardear",
    "escardeará": "escardear",
    "escardearás": "escardear",
    "escardearão": "escardear",
    "escardearíamos": "escardear",
    "escardearíeis": "escardear",
    "escardeasse": "escardear",
    "escardeassem": "escardear",
    "escardeasses": "escardear",
    "escardeaste": "escardear",
    "escardeastes": "escardear",
    "escardeava": "escardear",
    "escardeavam": "escardear",
    "escardeavas": "escardear",
    "escardece": "escardecer",
    "escardecei": "escardecer",
    "escardeceis": "escardecer",
    "escardecem": "escardecer",
    "escardecemo": "escardecer",
    "escardecemos": "escardecer",
    "escardecendo": "escardecer",
    "escardecera": "escardecer",
    "escardeceram": "escardecer",
    "escardeceras": "escardecer",
    "escardecerdes": "escardecer",
    "escardecerei": "escardecer",
    "escardecereis": "escardecer",
    "escardecerem": "escardecer",
    "escardeceremos": "escardecer",
    "escardeceres": "escardecer",
    "escardeceria": "escardecer",
    "escardeceriam": "escardecer",
    "escardecerias": "escardecer",
    "escardecermo": "escardecer",
    "escardecermos": "escardecer",
    "escardecerá": "escardecer",
    "escardecerás": "escardecer",
    "escardecerão": "escardecer",
    "escardeceríamos": "escardecer",
    "escardeceríeis": "escardecer",
    "escardeces": "escardecer",
    "escardecesse": "escardecer",
    "escardecessem": "escardecer",
    "escardecesses": "escardecer",
    "escardeceste": "escardecer",
    "escardecestes": "escardecer",
    "escardeceu": "escardecer",
    "escardeci": "escardecer",
    "escardecia": "escardecer",
    "escardeciam": "escardecer",
    "escardecias": "escardecer",
    "escardecida": "escardecer",
    "escardecidas": "escardecer",
    "escardecido": "escardecer",
    "escardecidos": "escardecer",
    "escardecêramo": "escardecer",
    "escardecêramos": "escardecer",
    "escardecêreis": "escardecer",
    "escardecêsseis": "escardecer",
    "escardecêssemos": "escardecer",
    "escardecíamo": "escardecer",
    "escardecíamos": "escardecer",
    "escardecíeis": "escardecer",
    "escardeei": "escardear",
    "escardeeis": "escardear",
    "escardeemo": "escardear",
    "escardeemos": "escardear",
    "escardei": "escardar",
    "escardeia": "escardear",
    "escardeiam": "escardear",
    "escardeias": "escardear",
    "escardeie": "escardear",
    "escardeiem": "escardear",
    "escardeies": "escardear",
    "escardeio": "escardear",
    "escardeis": "escardar",
    "escardem": "escardar",
    "escardemo": "escardar",
    "escardemos": "escardar",
    "escardeou": "escardear",
    "escardes": "escardar",
    "escardeá": "escardear",
    "escardeámo": "escardear",
    "escardeámos": "escardear",
    "escardeáramo": "escardear",
    "escardeáramos": "escardear",
    "escardeárei": "escardear",
    "escardeáreis": "escardear",
    "escardeásseis": "escardear",
    "escardeássemos": "escardear",
    "escardeávamo": "escardear",
    "escardeávamos": "escardear",
    "escardeávei": "escardear",
    "escardeáveis": "escardear",
    "escardeça": "escardecer",
    "escardeçais": "escardecer",
    "escardeçam": "escardecer",
    "escardeçamo": "escardecer",
    "escardeçamos": "escardecer",
    "escardeças": "escardecer",
    "escardeço": "escardecer",
    "escardicha": "escardichar",
    "escardichada": "escardichar",
    "escardichadas": "escardichar",
    "escardichado": "escardichar",
    "escardichados": "escardichar",
    "escardichai": "escardichar",
    "escardichais": "escardichar",
    "escardicham": "escardichar",
    "escardichamo": "escardichar",
    "escardichamos": "escardichar",
    "escardichando": "escardichar",
    "escardichara": "escardichar",
    "escardicharam": "escardichar",
    "escardicharas": "escardichar",
    "escardicharde": "escardichar",
    "escardichardes": "escardichar",
    "escardichare": "escardichar",
    "escardicharei": "escardichar",
    "escardichareis": "escardichar",
    "escardicharem": "escardichar",
    "escardicharemos": "escardichar",
    "escardichares": "escardichar",
    "escardicharia": "escardichar",
    "escardichariam": "escardichar",
    "escardicharias": "escardichar",
    "escardicharmo": "escardichar",
    "escardicharmos": "escardichar",
    "escardichará": "escardichar",
    "escardicharás": "escardichar",
    "escardicharão": "escardichar",
    "escardicharíamos": "escardichar",
    "escardicharíeis": "escardichar",
    "escardichas": "escardichar",
    "escardichasse": "escardichar",
    "escardichassem": "escardichar",
    "escardichasses": "escardichar",
    "escardichaste": "escardichar",
    "escardichastes": "escardichar",
    "escardichava": "escardichar",
    "escardichavam": "escardichar",
    "escardichavas": "escardichar",
    "escardiche": "escardichar",
    "escardichei": "escardichar",
    "escardicheis": "escardichar",
    "escardichem": "escardichar",
    "escardichemo": "escardichar",
    "escardichemos": "escardichar",
    "escardiches": "escardichar",
    "escardicho": "escardichar",
    "escardichou": "escardichar",
    "escardichá": "escardichar",
    "escardichámo": "escardichar",
    "escardichámos": "escardichar",
    "escardicháramo": "escardichar",
    "escardicháramos": "escardichar",
    "escardichárei": "escardichar",
    "escardicháreis": "escardichar",
    "escardichásseis": "escardichar",
    "escardichássemos": "escardichar",
    "escardichávamo": "escardichar",
    "escardichávamos": "escardichar",
    "escardichávei": "escardichar",
    "escardicháveis": "escardichar",
    "escardilha": "escardilhar",
    "escardilhada": "escardilhar",
    "escardilhadas": "escardilhar",
    "escardilhado": "escardilhar",
    "escardilhados": "escardilhar",
    "escardilhai": "escardilhar",
    "escardilhais": "escardilhar",
    "escardilham": "escardilhar",
    "escardilhamo": "escardilhar",
    "escardilhamos": "escardilhar",
    "escardilhando": "escardilhar",
    "escardilhara": "escardilhar",
    "escardilharam": "escardilhar",
    "escardilharas": "escardilhar",
    "escardilharde": "escardilhar",
    "escardilhardes": "escardilhar",
    "escardilhare": "escardilhar",
    "escardilharei": "escardilhar",
    "escardilhareis": "escardilhar",
    "escardilharem": "escardilhar",
    "escardilharemos": "escardilhar",
    "escardilhares": "escardilhar",
    "escardilharia": "escardilhar",
    "escardilhariam": "escardilhar",
    "escardilharias": "escardilhar",
    "escardilharmo": "escardilhar",
    "escardilharmos": "escardilhar",
    "escardilhará": "escardilhar",
    "escardilharás": "escardilhar",
    "escardilharão": "escardilhar",
    "escardilharíamos": "escardilhar",
    "escardilharíeis": "escardilhar",
    "escardilhas": "escardilhar",
    "escardilhasse": "escardilhar",
    "escardilhassem": "escardilhar",
    "escardilhasses": "escardilhar",
    "escardilhaste": "escardilhar",
    "escardilhastes": "escardilhar",
    "escardilhava": "escardilhar",
    "escardilhavam": "escardilhar",
    "escardilhavas": "escardilhar",
    "escardilhe": "escardilhar",
    "escardilhei": "escardilhar",
    "escardilheis": "escardilhar",
    "escardilhem": "escardilhar",
    "escardilhemo": "escardilhar",
    "escardilhemos": "escardilhar",
    "escardilhes": "escardilhar",
    "escardilho": "escardilhar",
    "escardilhos": "escardilho",
    "escardilhou": "escardilhar",
    "escardilhá": "escardilhar",
    "escardilhámo": "escardilhar",
    "escardilhámos": "escardilhar",
    "escardilháramo": "escardilhar",
    "escardilháramos": "escardilhar",
    "escardilhárei": "escardilhar",
    "escardilháreis": "escardilhar",
    "escardilhásseis": "escardilhar",
    "escardilhássemos": "escardilhar",
    "escardilhávamo": "escardilhar",
    "escardilhávamos": "escardilhar",
    "escardilhávei": "escardilhar",
    "escardilháveis": "escardilhar",
    "escardo": "escardar",
    "escardou": "escardar",
    "escarduce": "escarduçar",
    "escarducei": "escarduçar",
    "escarduceis": "escarduçar",
    "escarducem": "escarduçar",
    "escarducemo": "escarduçar",
    "escarducemos": "escarduçar",
    "escarduces": "escarduçar",
    "escarduça": "escarduçar",
    "escarduçada": "escarduçar",
    "escarduçadas": "escarduçar",
    "escarduçado": "escarduçar",
    "escarduçadora": "escarduçador",
    "escarduçadoras": "escarduçador",
    "escarduçadores": "escarduçador",
    "escarduçados": "escarduçar",
    "escarduçai": "escarduçar",
    "escarduçais": "escarduçar",
    "escarduçam": "escarduçar",
    "escarduçamo": "escarduçar",
    "escarduçamos": "escarduçar",
    "escarduçando": "escarduçar",
    "escarduçara": "escarduçar",
    "escarduçaram": "escarduçar",
    "escarduçaras": "escarduçar",
    "escarduçarde": "escarduçar",
    "escarduçardes": "escarduçar",
    "escarduçare": "escarduçar",
    "escarduçarei": "escarduçar",
    "escarduçareis": "escarduçar",
    "escarduçarem": "escarduçar",
    "escarduçaremos": "escarduçar",
    "escarduçares": "escarduçar",
    "escarduçaria": "escarduçar",
    "escarduçariam": "escarduçar",
    "escarduçarias": "escarduçar",
    "escarduçarmo": "escarduçar",
    "escarduçarmos": "escarduçar",
    "escarduçará": "escarduçar",
    "escarduçarás": "escarduçar",
    "escarduçarão": "escarduçar",
    "escarduçaríamos": "escarduçar",
    "escarduçaríeis": "escarduçar",
    "escarduças": "escarduçar",
    "escarduçasse": "escarduçar",
    "escarduçassem": "escarduçar",
    "escarduçasses": "escarduçar",
    "escarduçaste": "escarduçar",
    "escarduçastes": "escarduçar",
    "escarduçava": "escarduçar",
    "escarduçavam": "escarduçar",
    "escarduçavas": "escarduçar",
    "escarduço": "escarduçar",
    "escarduçou": "escarduçar",
    "escarduçá": "escarduçar",
    "escarduçámo": "escarduçar",
    "escarduçámos": "escarduçar",
    "escarduçáramo": "escarduçar",
    "escarduçáramos": "escarduçar",
    "escarduçárei": "escarduçar",
    "escarduçáreis": "escarduçar",
    "escarduçásseis": "escarduçar",
    "escarduçássemos": "escarduçar",
    "escarduçávamo": "escarduçar",
    "escarduçávamos": "escarduçar",
    "escarduçávei": "escarduçar",
    "escarduçáveis": "escarduçar",
    "escardá": "escardar",
    "escardámo": "escardar",
    "escardámos": "escardar",
    "escardáramo": "escardar",
    "escardáramos": "escardar",
    "escardárei": "escardar",
    "escardáreis": "escardar",
    "escardásseis": "escardar",
    "escardássemos": "escardar",
    "escardávamo": "escardar",
    "escardávamos": "escardar",
    "escardávei": "escardar",
    "escardáveis": "escardar",
    "escareada": "escarear",
    "escareadas": "escarear",
    "escareado": "escarear",
    "escareadora": "escareador",
    "escareadoras": "escareador",
    "escareadores": "escareador",
    "escareados": "escarear",
    "escareai": "escarear",
    "escareais": "escarear",
    "escareamo": "escarear",
    "escareamos": "escarear",
    "escareando": "escarear",
    "escareara": "escarear",
    "escarearam": "escarear",
    "escarearas": "escarear",
    "escarearde": "escarear",
    "escareardes": "escarear",
    "escareare": "escarear",
    "escarearei": "escarear",
    "escareareis": "escarear",
    "escarearem": "escarear",
    "escarearemos": "escarear",
    "escareares": "escarear",
    "escarearia": "escarear",
    "escareariam": "escarear",
    "escarearias": "escarear",
    "escarearmo": "escarear",
    "escarearmos": "escarear",
    "escareará": "escarear",
    "escarearás": "escarear",
    "escarearão": "escarear",
    "escarearíamos": "escarear",
    "escarearíeis": "escarear",
    "escareasse": "escarear",
    "escareassem": "escarear",
    "escareasses": "escarear",
    "escareaste": "escarear",
    "escareastes": "escarear",
    "escareava": "escarear",
    "escareavam": "escarear",
    "escareavas": "escarear",
    "escareei": "escarear",
    "escareeis": "escarear",
    "escareemo": "escarear",
    "escareemos": "escarear",
    "escareia": "escarear",
    "escareiam": "escarear",
    "escareias": "escarear",
    "escareie": "escarear",
    "escareiem": "escarear",
    "escareies": "escarear",
    "escareio": "escarear",
    "escareou": "escarear",
    "escareá": "escarear",
    "escareámo": "escarear",
    "escareámos": "escarear",
    "escareáramo": "escarear",
    "escareáramos": "escarear",
    "escareárei": "escarear",
    "escareáreis": "escarear",
    "escareásseis": "escarear",
    "escareássemos": "escarear",
    "escareávamo": "escarear",
    "escareávamos": "escarear",
    "escareávei": "escarear",
    "escareáveis": "escarear",
    "escarifica": "escarificar",
    "escarificada": "escarificar",
    "escarificadas": "escarificar",
    "escarificado": "escarificar",
    "escarificadora": "escarificador",
    "escarificadoras": "escarificador",
    "escarificadores": "escarificador",
    "escarificados": "escarificar",
    "escarificai": "escarificar",
    "escarificais": "escarificar",
    "escarificam": "escarificar",
    "escarificamo": "escarificar",
    "escarificamos": "escarificar",
    "escarificando": "escarificar",
    "escarificara": "escarificar",
    "escarificaram": "escarificar",
    "escarificaras": "escarificar",
    "escarificarde": "escarificar",
    "escarificardes": "escarificar",
    "escarificare": "escarificar",
    "escarificarei": "escarificar",
    "escarificareis": "escarificar",
    "escarificarem": "escarificar",
    "escarificaremos": "escarificar",
    "escarificares": "escarificar",
    "escarificaria": "escarificar",
    "escarificariam": "escarificar",
    "escarificarias": "escarificar",
    "escarificarmo": "escarificar",
    "escarificarmos": "escarificar",
    "escarificará": "escarificar",
    "escarificarás": "escarificar",
    "escarificarão": "escarificar",
    "escarificaríamos": "escarificar",
    "escarificaríeis": "escarificar",
    "escarificas": "escarificar",
    "escarificasse": "escarificar",
    "escarificassem": "escarificar",
    "escarificasses": "escarificar",
    "escarificaste": "escarificar",
    "escarificastes": "escarificar",
    "escarificava": "escarificar",
    "escarificavam": "escarificar",
    "escarificavas": "escarificar",
    "escarificações": "escarificação",
    "escarifico": "escarificar",
    "escarificou": "escarificar",
    "escarificá": "escarificar",
    "escarificámo": "escarificar",
    "escarificámos": "escarificar",
    "escarificáramo": "escarificar",
    "escarificáramos": "escarificar",
    "escarificárei": "escarificar",
    "escarificáreis": "escarificar",
    "escarificásseis": "escarificar",
    "escarificássemos": "escarificar",
    "escarificávamo": "escarificar",
    "escarificávamos": "escarificar",
    "escarificávei": "escarificar",
    "escarificáveis": "escarificar",
    "escarifique": "escarificar",
    "escarifiquei": "escarificar",
    "escarifiqueis": "escarificar",
    "escarifiquem": "escarificar",
    "escarifiquemo": "escarificar",
    "escarifiquemos": "escarificar",
    "escarifiques": "escarificar",
    "escariolas": "escariola",
    "escariosa": "escarioso",
    "escariosas": "escarioso",
    "escariosos": "escarioso",
    "escarlatas": "escarlata",
    "escarlates": "escarlate",
    "escarlatinas": "escarlatina",
    "escarlatiniformes": "escarlatiniforme",
    "escarlatinosa": "escarlatinoso",
    "escarlatinosas": "escarlatinoso",
    "escarlatinosos": "escarlatinoso",
    "escarmenta": "escarmentar",
    "escarmentada": "escarmentar",
    "escarmentadas": "escarmentar",
    "escarmentado": "escarmentar",
    "escarmentados": "escarmentar",
    "escarmentadíssima": "escarmentado",
    "escarmentadíssimas": "escarmentado",
    "escarmentadíssimo": "escarmentado",
    "escarmentadíssimos": "escarmentado",
    "escarmentai": "escarmentar",
    "escarmentais": "escarmentar",
    "escarmentam": "escarmentar",
    "escarmentamo": "escarmentar",
    "escarmentamos": "escarmentar",
    "escarmentando": "escarmentar",
    "escarmentara": "escarmentar",
    "escarmentaram": "escarmentar",
    "escarmentaras": "escarmentar",
    "escarmentarde": "escarmentar",
    "escarmentardes": "escarmentar",
    "escarmentare": "escarmentar",
    "escarmentarei": "escarmentar",
    "escarmentareis": "escarmentar",
    "escarmentarem": "escarmentar",
    "escarmentaremos": "escarmentar",
    "escarmentares": "escarmentar",
    "escarmentaria": "escarmentar",
    "escarmentariam": "escarmentar",
    "escarmentarias": "escarmentar",
    "escarmentarmo": "escarmentar",
    "escarmentarmos": "escarmentar",
    "escarmentará": "escarmentar",
    "escarmentarás": "escarmentar",
    "escarmentarão": "escarmentar",
    "escarmentaríamos": "escarmentar",
    "escarmentaríeis": "escarmentar",
    "escarmentas": "escarmentar",
    "escarmentasse": "escarmentar",
    "escarmentassem": "escarmentar",
    "escarmentasses": "escarmentar",
    "escarmentaste": "escarmentar",
    "escarmentastes": "escarmentar",
    "escarmentava": "escarmentar",
    "escarmentavam": "escarmentar",
    "escarmentavas": "escarmentar",
    "escarmente": "escarmentar",
    "escarmentei": "escarmentar",
    "escarmenteis": "escarmentar",
    "escarmentem": "escarmentar",
    "escarmentemo": "escarmentar",
    "escarmentemos": "escarmentar",
    "escarmentes": "escarmentar",
    "escarmento": "escarmentar",
    "escarmentos": "escarmento",
    "escarmentou": "escarmentar",
    "escarmentá": "escarmentar",
    "escarmentámo": "escarmentar",
    "escarmentámos": "escarmentar",
    "escarmentáramo": "escarmentar",
    "escarmentáramos": "escarmentar",
    "escarmentárei": "escarmentar",
    "escarmentáreis": "escarmentar",
    "escarmentásseis": "escarmentar",
    "escarmentássemos": "escarmentar",
    "escarmentávamo": "escarmentar",
    "escarmentávamos": "escarmentar",
    "escarmentávei": "escarmentar",
    "escarmentáveis": "escarmentar",
    "escarna": "escarnir",
    "escarnada": "escarnar",
    "escarnadas": "escarnar",
    "escarnado": "escarnar",
    "escarnadora": "escarnador",
    "escarnadoras": "escarnador",
    "escarnadores": "escarnador",
    "escarnados": "escarnar",
    "escarnai": "escarnar",
    "escarnais": "escarnir",
    "escarnam": "escarnir",
    "escarnamo": "escarnir",
    "escarnamos": "escarnir",
    "escarnando": "escarnar",
    "escarnara": "escarnar",
    "escarnaram": "escarnar",
    "escarnaras": "escarnar",
    "escarnarde": "escarnar",
    "escarnardes": "escarnar",
    "escarnare": "escarnar",
    "escarnarei": "escarnar",
    "escarnareis": "escarnar",
    "escarnarem": "escarnar",
    "escarnaremos": "escarnar",
    "escarnares": "escarnar",
    "escarnaria": "escarnar",
    "escarnariam": "escarnar",
    "escarnarias": "escarnar",
    "escarnarmo": "escarnar",
    "escarnarmos": "escarnar",
    "escarnará": "escarnar",
    "escarnarás": "escarnar",
    "escarnarão": "escarnar",
    "escarnaríamos": "escarnar",
    "escarnaríeis": "escarnar",
    "escarnas": "escarnir",
    "escarnasse": "escarnar",
    "escarnassem": "escarnar",
    "escarnasses": "escarnar",
    "escarnaste": "escarnar",
    "escarnastes": "escarnar",
    "escarnava": "escarnar",
    "escarnavam": "escarnar",
    "escarnavas": "escarnar",
    "escarnações": "escarnação",
    "escarne": "escarnir",
    "escarnece": "escarnecer",
    "escarnecedora": "escarnecedor",
    "escarnecedoras": "escarnecedor",
    "escarnecedores": "escarnecedor",
    "escarnecei": "escarnecer",
    "escarneceis": "escarnecer",
    "escarnecem": "escarnecer",
    "escarnecemo": "escarnecer",
    "escarnecemos": "escarnecer",
    "escarnecendo": "escarnecer",
    "escarnecera": "escarnecer",
    "escarneceram": "escarnecer",
    "escarneceras": "escarnecer",
    "escarnecerde": "escarnecer",
    "escarnecerdes": "escarnecer",
    "escarnecere": "escarnecer",
    "escarnecerei": "escarnecer",
    "escarnecereis": "escarnecer",
    "escarnecerem": "escarnecer",
    "escarneceremos": "escarnecer",
    "escarneceres": "escarnecer",
    "escarneceria": "escarnecer",
    "escarneceriam": "escarnecer",
    "escarnecerias": "escarnecer",
    "escarnecermo": "escarnecer",
    "escarnecermos": "escarnecer",
    "escarnecerá": "escarnecer",
    "escarnecerás": "escarnecer",
    "escarnecerão": "escarnecer",
    "escarneceríamos": "escarnecer",
    "escarneceríeis": "escarnecer",
    "escarneces": "escarnecer",
    "escarnecesse": "escarnecer",
    "escarnecessem": "escarnecer",
    "escarnecesses": "escarnecer",
    "escarneceste": "escarnecer",
    "escarnecestes": "escarnecer",
    "escarneceu": "escarnecer",
    "escarneci": "escarnecer",
    "escarnecia": "escarnecer",
    "escarneciam": "escarnecer",
    "escarnecias": "escarnecer",
    "escarnecida": "escarnecido",
    "escarnecidas": "escarnecido",
    "escarnecido": "escarnecer",
    "escarnecidos": "escarnecido",
    "escarnecimentos": "escarnecimento",
    "escarnecê": "escarnecer",
    "escarnecêramo": "escarnecer",
    "escarnecêramos": "escarnecer",
    "escarnecêrei": "escarnecer",
    "escarnecêreis": "escarnecer",
    "escarnecêsseis": "escarnecer",
    "escarnecêssemos": "escarnecer",
    "escarnecíamo": "escarnecer",
    "escarnecíamos": "escarnecer",
    "escarnecíei": "escarnecer",
    "escarnecíeis": "escarnecer",
    "escarnecíveis": "escarnecível",
    "escarnei": "escarnar",
    "escarneis": "escarnar",
    "escarnem": "escarnir",
    "escarnemo": "escarnar",
    "escarnemos": "escarnar",
    "escarnes": "escarnir",
    "escarneça": "escarnecer",
    "escarneçais": "escarnecer",
    "escarneçam": "escarnecer",
    "escarneçamo": "escarnecer",
    "escarneçamos": "escarnecer",
    "escarneças": "escarnecer",
    "escarneço": "escarnecer",
    "escarni": "escarnir",
    "escarnia": "escarnir",
    "escarniada": "escarniar",
    "escarniadas": "escarniar",
    "escarniado": "escarniar",
    "escarniados": "escarniar",
    "escarniai": "escarniar",
    "escarniais": "escarniar",
    "escarniam": "escarnir",
    "escarniamo": "escarniar",
    "escarniamos": "escarniar",
    "escarniando": "escarniar",
    "escarniara": "escarniar",
    "escarniaram": "escarniar",
    "escarniaras": "escarniar",
    "escarniarde": "escarniar",
    "escarniardes": "escarniar",
    "escarniare": "escarniar",
    "escarniarei": "escarniar",
    "escarniareis": "escarniar",
    "escarniarem": "escarniar",
    "escarniaremos": "escarniar",
    "escarniares": "escarniar",
    "escarniaria": "escarniar",
    "escarniariam": "escarniar",
    "escarniarias": "escarniar",
    "escarniarmo": "escarniar",
    "escarniarmos": "escarniar",
    "escarniará": "escarniar",
    "escarniarás": "escarniar",
    "escarniarão": "escarniar",
    "escarniaríamos": "escarniar",
    "escarniaríeis": "escarniar",
    "escarnias": "escarnir",
    "escarniasse": "escarniar",
    "escarniassem": "escarniar",
    "escarniasses": "escarniar",
    "escarniaste": "escarniar",
    "escarniastes": "escarniar",
    "escarniava": "escarniar",
    "escarniavam": "escarniar",
    "escarniavas": "escarniar",
    "escarnica": "escarnicar",
    "escarnicada": "escarnicar",
    "escarnicadas": "escarnicar",
    "escarnicadeira": "escarnicador",
    "escarnicadeiras": "escarnicador",
    "escarnicado": "escarnicar",
    "escarnicadora": "escarnicador",
    "escarnicadoras": "escarnicador",
    "escarnicadores": "escarnicador",
    "escarnicados": "escarnicar",
    "escarnicai": "escarnicar",
    "escarnicais": "escarnicar",
    "escarnicam": "escarnicar",
    "escarnicamo": "escarnicar",
    "escarnicamos": "escarnicar",
    "escarnicando": "escarnicar",
    "escarnicara": "escarnicar",
    "escarnicaram": "escarnicar",
    "escarnicaras": "escarnicar",
    "escarnicarde": "escarnicar",
    "escarnicardes": "escarnicar",
    "escarnicare": "escarnicar",
    "escarnicarei": "escarnicar",
    "escarnicareis": "escarnicar",
    "escarnicarem": "escarnicar",
    "escarnicaremos": "escarnicar",
    "escarnicares": "escarnicar",
    "escarnicaria": "escarnicar",
    "escarnicariam": "escarnicar",
    "escarnicarias": "escarnicar",
    "escarnicarmo": "escarnicar",
    "escarnicarmos": "escarnicar",
    "escarnicará": "escarnicar",
    "escarnicarás": "escarnicar",
    "escarnicarão": "escarnicar",
    "escarnicaríamos": "escarnicar",
    "escarnicaríeis": "escarnicar",
    "escarnicas": "escarnicar",
    "escarnicasse": "escarnicar",
    "escarnicassem": "escarnicar",
    "escarnicasses": "escarnicar",
    "escarnicaste": "escarnicar",
    "escarnicastes": "escarnicar",
    "escarnicava": "escarnicar",
    "escarnicavam": "escarnicar",
    "escarnicavas": "escarnicar",
    "escarnico": "escarnicar",
    "escarnicou": "escarnicar",
    "escarnicá": "escarnicar",
    "escarnicámo": "escarnicar",
    "escarnicámos": "escarnicar",
    "escarnicáramo": "escarnicar",
    "escarnicáramos": "escarnicar",
    "escarnicárei": "escarnicar",
    "escarnicáreis": "escarnicar",
    "escarnicásseis": "escarnicar",
    "escarnicássemos": "escarnicar",
    "escarnicávamo": "escarnicar",
    "escarnicávamos": "escarnicar",
    "escarnicávei": "escarnicar",
    "escarnicáveis": "escarnicar",
    "escarnida": "escarnir",
    "escarnidas": "escarnir",
    "escarnido": "escarnir",
    "escarnidos": "escarnir",
    "escarnie": "escarniar",
    "escarniei": "escarniar",
    "escarnieis": "escarniar",
    "escarniem": "escarniar",
    "escarniemo": "escarniar",
    "escarniemos": "escarniar",
    "escarnies": "escarniar",
    "escarnifica": "escarnificar",
    "escarnificada": "escarnificar",
    "escarnificadas": "escarnificar",
    "escarnificado": "escarnificar",
    "escarnificados": "escarnificar",
    "escarnificai": "escarnificar",
    "escarnificais": "escarnificar",
    "escarnificam": "escarnificar",
    "escarnificamo": "escarnificar",
    "escarnificamos": "escarnificar",
    "escarnificando": "escarnificar",
    "escarnificara": "escarnificar",
    "escarnificaram": "escarnificar",
    "escarnificaras": "escarnificar",
    "escarnificarde": "escarnificar",
    "escarnificardes": "escarnificar",
    "escarnificare": "escarnificar",
    "escarnificarei": "escarnificar",
    "escarnificareis": "escarnificar",
    "escarnificarem": "escarnificar",
    "escarnificaremos": "escarnificar",
    "escarnificares": "escarnificar",
    "escarnificaria": "escarnificar",
    "escarnificariam": "escarnificar",
    "escarnificarias": "escarnificar",
    "escarnificarmo": "escarnificar",
    "escarnificarmos": "escarnificar",
    "escarnificará": "escarnificar",
    "escarnificarás": "escarnificar",
    "escarnificarão": "escarnificar",
    "escarnificaríamos": "escarnificar",
    "escarnificaríeis": "escarnificar",
    "escarnificas": "escarnificar",
    "escarnificasse": "escarnificar",
    "escarnificassem": "escarnificar",
    "escarnificasses": "escarnificar",
    "escarnificaste": "escarnificar",
    "escarnificastes": "escarnificar",
    "escarnificava": "escarnificar",
    "escarnificavam": "escarnificar",
    "escarnificavas": "escarnificar",
    "escarnificações": "escarnificação",
    "escarnifico": "escarnificar",
    "escarnificou": "escarnificar",
    "escarnificá": "escarnificar",
    "escarnificámo": "escarnificar",
    "escarnificámos": "escarnificar",
    "escarnificáramo": "escarnificar",
    "escarnificáramos": "escarnificar",
    "escarnificárei": "escarnificar",
    "escarnificáreis": "escarnificar",
    "escarnificásseis": "escarnificar",
    "escarnificássemos": "escarnificar",
    "escarnificávamo": "escarnificar",
    "escarnificávamos": "escarnificar",
    "escarnificávei": "escarnificar",
    "escarnificáveis": "escarnificar",
    "escarnifique": "escarnificar",
    "escarnifiquei": "escarnificar",
    "escarnifiqueis": "escarnificar",
    "escarnifiquem": "escarnificar",
    "escarnifiquemo": "escarnificar",
    "escarnifiquemos": "escarnificar",
    "escarnifiques": "escarnificar",
    "escarnimo": "escarnir",
    "escarnimos": "escarnir",
    "escarnindo": "escarnir",
    "escarninha": "escarninho",
    "escarninhada": "escarninhar",
    "escarninhadas": "escarninhar",
    "escarninhado": "escarninhar",
    "escarninhados": "escarninhar",
    "escarninhai": "escarninhar",
    "escarninhais": "escarninhar",
    "escarninham": "escarninhar",
    "escarninhamo": "escarninhar",
    "escarninhamos": "escarninhar",
    "escarninhando": "escarninhar",
    "escarninhara": "escarninhar",
    "escarninharam": "escarninhar",
    "escarninharas": "escarninhar",
    "escarninharde": "escarninhar",
    "escarninhardes": "escarninhar",
    "escarninhare": "escarninhar",
    "escarninharei": "escarninhar",
    "escarninhareis": "escarninhar",
    "escarninharem": "escarninhar",
    "escarninharemos": "escarninhar",
    "escarninhares": "escarninhar",
    "escarninharia": "escarninhar",
    "escarninhariam": "escarninhar",
    "escarninharias": "escarninhar",
    "escarninharmo": "escarninhar",
    "escarninharmos": "escarninhar",
    "escarninhará": "escarninhar",
    "escarninharás": "escarninhar",
    "escarninharão": "escarninhar",
    "escarninharíamos": "escarninhar",
    "escarninharíeis": "escarninhar",
    "escarninhas": "escarninho",
    "escarninhasse": "escarninhar",
    "escarninhassem": "escarninhar",
    "escarninhasses": "escarninhar",
    "escarninhaste": "escarninhar",
    "escarninhastes": "escarninhar",
    "escarninhava": "escarninhar",
    "escarninhavam": "escarninhar",
    "escarninhavas": "escarninhar",
    "escarninhe": "escarninhar",
    "escarninhei": "escarninhar",
    "escarninheis": "escarninhar",
    "escarninhem": "escarninhar",
    "escarninhemo": "escarninhar",
    "escarninhemos": "escarninhar",
    "escarninhes": "escarninhar",
    "escarninho": "escarninhar",
    "escarninhos": "escarninho",
    "escarninhou": "escarninhar",
    "escarninhá": "escarninhar",
    "escarninhámo": "escarninhar",
    "escarninhámos": "escarninhar",
    "escarninháramo": "escarninhar",
    "escarninháramos": "escarninhar",
    "escarninhárei": "escarninhar",
    "escarninháreis": "escarninhar",
    "escarninhásseis": "escarninhar",
    "escarninhássemos": "escarninhar",
    "escarninhávamo": "escarninhar",
    "escarninhávamos": "escarninhar",
    "escarninhávei": "escarninhar",
    "escarninháveis": "escarninhar",
    "escarnio": "escarniar",
    "escarniou": "escarniar",
    "escarnique": "escarnicar",
    "escarniquei": "escarnicar",
    "escarniqueis": "escarnicar",
    "escarniquem": "escarnicar",
    "escarniquemo": "escarnicar",
    "escarniquemos": "escarnicar",
    "escarniques": "escarnicar",
    "escarnira": "escarnir",
    "escarniram": "escarnir",
    "escarniras": "escarnir",
    "escarnirdes": "escarnir",
    "escarnirei": "escarnir",
    "escarnireis": "escarnir",
    "escarnirem": "escarnir",
    "escarniremos": "escarnir",
    "escarnires": "escarnir",
    "escarniria": "escarnir",
    "escarniriam": "escarnir",
    "escarnirias": "escarnir",
    "escarnirmo": "escarnir",
    "escarnirmos": "escarnir",
    "escarnirá": "escarnir",
    "escarnirás": "escarnir",
    "escarnirão": "escarnir",
    "escarniríamos": "escarnir",
    "escarniríeis": "escarnir",
    "escarnis": "escarnir",
    "escarnisse": "escarnir",
    "escarnissem": "escarnir",
    "escarnisses": "escarnir",
    "escarniste": "escarnir",
    "escarnistes": "escarnir",
    "escarnitos": "escarnito",
    "escarniu": "escarnir",
    "escarniá": "escarniar",
    "escarniámo": "escarniar",
    "escarniámos": "escarniar",
    "escarniáramo": "escarniar",
    "escarniáramos": "escarniar",
    "escarniárei": "escarniar",
    "escarniáreis": "escarniar",
    "escarniásseis": "escarniar",
    "escarniássemos": "escarniar",
    "escarniávamo": "escarniar",
    "escarniávamos": "escarniar",
    "escarniávei": "escarniar",
    "escarniáveis": "escarniar",
    "escarno": "escarnir",
    "escarnou": "escarnar",
    "escarná": "escarnar",
    "escarnámo": "escarnar",
    "escarnámos": "escarnar",
    "escarnáramo": "escarnar",
    "escarnáramos": "escarnar",
    "escarnárei": "escarnar",
    "escarnáreis": "escarnar",
    "escarnásseis": "escarnar",
    "escarnássemos": "escarnar",
    "escarnávamo": "escarnar",
    "escarnávamos": "escarnar",
    "escarnávei": "escarnar",
    "escarnáveis": "escarnar",
    "escarníamo": "escarnir",
    "escarníamos": "escarnir",
    "escarníeis": "escarnir",
    "escarníramo": "escarnir",
    "escarníramos": "escarnir",
    "escarníreis": "escarnir",
    "escarnísseis": "escarnir",
    "escarníssemos": "escarnir",
    "escarola": "escarolar",
    "escarolada": "escarolar",
    "escaroladas": "escarolar",
    "escarolado": "escarolar",
    "escaroladora": "escarolador",
    "escaroladoras": "escarolador",
    "escaroladores": "escarolador",
    "escarolados": "escarolar",
    "escarolai": "escarolar",
    "escarolais": "escarolar",
    "escarolam": "escarolar",
    "escarolamo": "escarolar",
    "escarolamos": "escarolar",
    "escarolando": "escarolar",
    "escarolara": "escarolar",
    "escarolaram": "escarolar",
    "escarolaras": "escarolar",
    "escarolarde": "escarolar",
    "escarolardes": "escarolar",
    "escarolare": "escarolar",
    "escarolarei": "escarolar",
    "escarolareis": "escarolar",
    "escarolarem": "escarolar",
    "escarolaremos": "escarolar",
    "escarolares": "escarolar",
    "escarolaria": "escarolar",
    "escarolariam": "escarolar",
    "escarolarias": "escarolar",
    "escarolarmo": "escarolar",
    "escarolarmos": "escarolar",
    "escarolará": "escarolar",
    "escarolarás": "escarolar",
    "escarolarão": "escarolar",
    "escarolaríamos": "escarolar",
    "escarolaríeis": "escarolar",
    "escarolas": "escarolar",
    "escarolasse": "escarolar",
    "escarolassem": "escarolar",
    "escarolasses": "escarolar",
    "escarolaste": "escarolar",
    "escarolastes": "escarolar",
    "escarolava": "escarolar",
    "escarolavam": "escarolar",
    "escarolavas": "escarolar",
    "escarole": "escarolar",
    "escarolei": "escarolar",
    "escaroleis": "escarolar",
    "escarolem": "escarolar",
    "escarolemo": "escarolar",
    "escarolemos": "escarolar",
    "escaroles": "escarolar",
    "escarolo": "escarolar",
    "escarolou": "escarolar",
    "escarolá": "escarolar",
    "escarolámo": "escarolar",
    "escarolámos": "escarolar",
    "escaroláramo": "escarolar",
    "escaroláramos": "escarolar",
    "escarolárei": "escarolar",
    "escaroláreis": "escarolar",
    "escarolásseis": "escarolar",
    "escarolássemos": "escarolar",
    "escarolávamo": "escarolar",
    "escarolávamos": "escarolar",
    "escarolávei": "escarolar",
    "escaroláveis": "escarolar",
    "escarpa": "escarpar",
    "escarpada": "escarpar",
    "escarpadas": "escarpar",
    "escarpado": "escarpar",
    "escarpados": "escarpar",
    "escarpaduras": "escarpadura",
    "escarpai": "escarpar",
    "escarpais": "escarpar",
    "escarpam": "escarpar",
    "escarpamentos": "escarpamento",
    "escarpamo": "escarpar",
    "escarpamos": "escarpar",
    "escarpando": "escarpar",
    "escarpara": "escarpar",
    "escarparam": "escarpar",
    "escarparas": "escarpar",
    "escarparde": "escarpar",
    "escarpardes": "escarpar",
    "escarpare": "escarpar",
    "escarparei": "escarpar",
    "escarpareis": "escarpar",
    "escarparem": "escarpar",
    "escarparemos": "escarpar",
    "escarpares": "escarpar",
    "escarparia": "escarpar",
    "escarpariam": "escarpar",
    "escarparias": "escarpar",
    "escarparmo": "escarpar",
    "escarparmos": "escarpar",
    "escarpará": "escarpar",
    "escarparás": "escarpar",
    "escarparão": "escarpar",
    "escarparíamos": "escarpar",
    "escarparíeis": "escarpar",
    "escarpas": "escarpar",
    "escarpasse": "escarpar",
    "escarpassem": "escarpar",
    "escarpasses": "escarpar",
    "escarpaste": "escarpar",
    "escarpastes": "escarpar",
    "escarpava": "escarpar",
    "escarpavam": "escarpar",
    "escarpavas": "escarpar",
    "escarpe": "escarpar",
    "escarpeada": "escarpear",
    "escarpeadas": "escarpear",
    "escarpeado": "escarpear",
    "escarpeados": "escarpear",
    "escarpeai": "escarpear",
    "escarpeais": "escarpear",
    "escarpeamo": "escarpear",
    "escarpeamos": "escarpear",
    "escarpeando": "escarpear",
    "escarpeara": "escarpear",
    "escarpearam": "escarpear",
    "escarpearas": "escarpear",
    "escarpearde": "escarpear",
    "escarpeardes": "escarpear",
    "escarpeare": "escarpear",
    "escarpearei": "escarpear",
    "escarpeareis": "escarpear",
    "escarpearem": "escarpear",
    "escarpearemos": "escarpear",
    "escarpeares": "escarpear",
    "escarpearia": "escarpear",
    "escarpeariam": "escarpear",
    "escarpearias": "escarpear",
    "escarpearmo": "escarpear",
    "escarpearmos": "escarpear",
    "escarpeará": "escarpear",
    "escarpearás": "escarpear",
    "escarpearão": "escarpear",
    "escarpearíamos": "escarpear",
    "escarpearíeis": "escarpear",
    "escarpeasse": "escarpear",
    "escarpeassem": "escarpear",
    "escarpeasses": "escarpear",
    "escarpeaste": "escarpear",
    "escarpeastes": "escarpear",
    "escarpeava": "escarpear",
    "escarpeavam": "escarpear",
    "escarpeavas": "escarpear",
    "escarpeei": "escarpear",
    "escarpeeis": "escarpear",
    "escarpeemo": "escarpear",
    "escarpeemos": "escarpear",
    "escarpei": "escarpar",
    "escarpeia": "escarpear",
    "escarpeiam": "escarpear",
    "escarpeias": "escarpear",
    "escarpeie": "escarpear",
    "escarpeiem": "escarpear",
    "escarpeies": "escarpear",
    "escarpeio": "escarpear",
    "escarpeis": "escarpar",
    "escarpela": "escarpelar",
    "escarpelada": "escarpelar",
    "escarpeladas": "escarpelar",
    "escarpelado": "escarpelar",
    "escarpelados": "escarpelar",
    "escarpelai": "escarpelar",
    "escarpelais": "escarpelar",
    "escarpelam": "escarpelar",
    "escarpelamo": "escarpelar",
    "escarpelamos": "escarpelar",
    "escarpelando": "escarpelar",
    "escarpelara": "escarpelar",
    "escarpelaram": "escarpelar",
    "escarpelaras": "escarpelar",
    "escarpelarde": "escarpelar",
    "escarpelardes": "escarpelar",
    "escarpelare": "escarpelar",
    "escarpelarei": "escarpelar",
    "escarpelareis": "escarpelar",
    "escarpelarem": "escarpelar",
    "escarpelaremos": "escarpelar",
    "escarpelares": "escarpelar",
    "escarpelaria": "escarpelar",
    "escarpelariam": "escarpelar",
    "escarpelarias": "escarpelar",
    "escarpelarmo": "escarpelar",
    "escarpelarmos": "escarpelar",
    "escarpelará": "escarpelar",
    "escarpelarás": "escarpelar",
    "escarpelarão": "escarpelar",
    "escarpelaríamos": "escarpelar",
    "escarpelaríeis": "escarpelar",
    "escarpelas": "escarpelar",
    "escarpelasse": "escarpelar",
    "escarpelassem": "escarpelar",
    "escarpelasses": "escarpelar",
    "escarpelaste": "escarpelar",
    "escarpelastes": "escarpelar",
    "escarpelava": "escarpelar",
    "escarpelavam": "escarpelar",
    "escarpelavas": "escarpelar",
    "escarpele": "escarpelar",
    "escarpelei": "escarpelar",
    "escarpeleis": "escarpelar",
    "escarpelem": "escarpelar",
    "escarpelemo": "escarpelar",
    "escarpelemos": "escarpelar",
    "escarpeles": "escarpelar",
    "escarpelo": "escarpelar",
    "escarpelou": "escarpelar",
    "escarpelá": "escarpelar",
    "escarpelámo": "escarpelar",
    "escarpelámos": "escarpelar",
    "escarpeláramo": "escarpelar",
    "escarpeláramos": "escarpelar",
    "escarpelárei": "escarpelar",
    "escarpeláreis": "escarpelar",
    "escarpelásseis": "escarpelar",
    "escarpelássemos": "escarpelar",
    "escarpelávamo": "escarpelar",
    "escarpelávamos": "escarpelar",
    "escarpelávei": "escarpelar",
    "escarpeláveis": "escarpelar",
    "escarpem": "escarpar",
    "escarpemo": "escarpar",
    "escarpemos": "escarpar",
    "escarpeou": "escarpear",
    "escarpes": "escarpe",
    "escarpeá": "escarpear",
    "escarpeámo": "escarpear",
    "escarpeámos": "escarpear",
    "escarpeáramo": "escarpear",
    "escarpeáramos": "escarpear",
    "escarpeárei": "escarpear",
    "escarpeáreis": "escarpear",
    "escarpeásseis": "escarpear",
    "escarpeássemos": "escarpear",
    "escarpeávamo": "escarpear",
    "escarpeávamos": "escarpear",
    "escarpeávei": "escarpear",
    "escarpeáveis": "escarpear",
    "escarpins": "escarpim",
    "escarpo": "escarpar",
    "escarpou": "escarpar",
    "escarpá": "escarpar",
    "escarpámo": "escarpar",
    "escarpámos": "escarpar",
    "escarpáramo": "escarpar",
    "escarpáramos": "escarpar",
    "escarpárei": "escarpar",
    "escarpáreis": "escarpar",
    "escarpásseis": "escarpar",
    "escarpássemos": "escarpar",
    "escarpávamo": "escarpar",
    "escarpávamos": "escarpar",
    "escarpávei": "escarpar",
    "escarpáveis": "escarpar",
    "escarra": "escarrar",
    "escarracha": "escarrachar",
    "escarrachada": "escarrachar",
    "escarrachadas": "escarrachar",
    "escarrachado": "escarrachar",
    "escarrachados": "escarrachar",
    "escarrachai": "escarrachar",
    "escarrachais": "escarrachar",
    "escarracham": "escarrachar",
    "escarrachamo": "escarrachar",
    "escarrachamos": "escarrachar",
    "escarrachando": "escarrachar",
    "escarrachara": "escarrachar",
    "escarracharam": "escarrachar",
    "escarracharas": "escarrachar",
    "escarracharde": "escarrachar",
    "escarrachardes": "escarrachar",
    "escarrachare": "escarrachar",
    "escarracharei": "escarrachar",
    "escarrachareis": "escarrachar",
    "escarracharem": "escarrachar",
    "escarracharemos": "escarrachar",
    "escarrachares": "escarrachar",
    "escarracharia": "escarrachar",
    "escarrachariam": "escarrachar",
    "escarracharias": "escarrachar",
    "escarracharmo": "escarrachar",
    "escarracharmos": "escarrachar",
    "escarrachará": "escarrachar",
    "escarracharás": "escarrachar",
    "escarracharão": "escarrachar",
    "escarracharíamos": "escarrachar",
    "escarracharíeis": "escarrachar",
    "escarrachas": "escarrachar",
    "escarrachasse": "escarrachar",
    "escarrachassem": "escarrachar",
    "escarrachasses": "escarrachar",
    "escarrachaste": "escarrachar",
    "escarrachastes": "escarrachar",
    "escarrachava": "escarrachar",
    "escarrachavam": "escarrachar",
    "escarrachavas": "escarrachar",
    "escarrache": "escarrachar",
    "escarrachei": "escarrachar",
    "escarracheis": "escarrachar",
    "escarrachem": "escarrachar",
    "escarrachemo": "escarrachar",
    "escarrachemos": "escarrachar",
    "escarraches": "escarrachar",
    "escarracho": "escarrachar",
    "escarrachou": "escarrachar",
    "escarrachá": "escarrachar",
    "escarrachámo": "escarrachar",
    "escarrachámos": "escarrachar",
    "escarracháramo": "escarrachar",
    "escarracháramos": "escarrachar",
    "escarrachárei": "escarrachar",
    "escarracháreis": "escarrachar",
    "escarrachásseis": "escarrachar",
    "escarrachássemos": "escarrachar",
    "escarrachávamo": "escarrachar",
    "escarrachávamos": "escarrachar",
    "escarrachávei": "escarrachar",
    "escarracháveis": "escarrachar",
    "escarrada": "escarrar",
    "escarradas": "escarrar",
    "escarradeiras": "escarradeira",
    "escarrado": "escarrar",
    "escarradora": "escarrador",
    "escarradoras": "escarrador",
    "escarradores": "escarrador",
    "escarrados": "escarrar",
    "escarraduras": "escarradura",
    "escarrai": "escarrar",
    "escarrais": "escarrar",
    "escarram": "escarrar",
    "escarramo": "escarrar",
    "escarramos": "escarrar",
    "escarrancha": "escarranchar",
    "escarranchada": "escarranchar",
    "escarranchadas": "escarranchar",
    "escarranchado": "escarranchar",
    "escarranchados": "escarranchar",
    "escarranchai": "escarranchar",
    "escarranchais": "escarranchar",
    "escarrancham": "escarranchar",
    "escarranchamo": "escarranchar",
    "escarranchamos": "escarranchar",
    "escarranchando": "escarranchar",
    "escarranchara": "escarranchar",
    "escarrancharam": "escarranchar",
    "escarrancharas": "escarranchar",
    "escarrancharde": "escarranchar",
    "escarranchardes": "escarranchar",
    "escarranchare": "escarranchar",
    "escarrancharei": "escarranchar",
    "escarranchareis": "escarranchar",
    "escarrancharem": "escarranchar",
    "escarrancharemos": "escarranchar",
    "escarranchares": "escarranchar",
    "escarrancharia": "escarranchar",
    "escarranchariam": "escarranchar",
    "escarrancharias": "escarranchar",
    "escarrancharmo": "escarranchar",
    "escarrancharmos": "escarranchar",
    "escarranchará": "escarranchar",
    "escarrancharás": "escarranchar",
    "escarrancharão": "escarranchar",
    "escarrancharíamos": "escarranchar",
    "escarrancharíeis": "escarranchar",
    "escarranchas": "escarranchar",
    "escarranchasse": "escarranchar",
    "escarranchassem": "escarranchar",
    "escarranchasses": "escarranchar",
    "escarranchaste": "escarranchar",
    "escarranchastes": "escarranchar",
    "escarranchava": "escarranchar",
    "escarranchavam": "escarranchar",
    "escarranchavas": "escarranchar",
    "escarranche": "escarranchar",
    "escarranchei": "escarranchar",
    "escarrancheis": "escarranchar",
    "escarranchem": "escarranchar",
    "escarranchemo": "escarranchar",
    "escarranchemos": "escarranchar",
    "escarranches": "escarranchar",
    "escarrancho": "escarranchar",
    "escarranchou": "escarranchar",
    "escarranchá": "escarranchar",
    "escarranchámo": "escarranchar",
    "escarranchámos": "escarranchar",
    "escarrancháramo": "escarranchar",
    "escarrancháramos": "escarranchar",
    "escarranchárei": "escarranchar",
    "escarrancháreis": "escarranchar",
    "escarranchásseis": "escarranchar",
    "escarranchássemos": "escarranchar",
    "escarranchávamo": "escarranchar",
    "escarranchávamos": "escarranchar",
    "escarranchávei": "escarranchar",
    "escarrancháveis": "escarranchar",
    "escarrando": "escarrar",
    "escarrapacha": "escarrapachar",
    "escarrapachada": "escarrapachar",
    "escarrapachadas": "escarrapachar",
    "escarrapachado": "escarrapachar",
    "escarrapachados": "escarrapachar",
    "escarrapachai": "escarrapachar",
    "escarrapachais": "escarrapachar",
    "escarrapacham": "escarrapachar",
    "escarrapachamo": "escarrapachar",
    "escarrapachamos": "escarrapachar",
    "escarrapachando": "escarrapachar",
    "escarrapachara": "escarrapachar",
    "escarrapacharam": "escarrapachar",
    "escarrapacharas": "escarrapachar",
    "escarrapacharde": "escarrapachar",
    "escarrapachardes": "escarrapachar",
    "escarrapachare": "escarrapachar",
    "escarrapacharei": "escarrapachar",
    "escarrapachareis": "escarrapachar",
    "escarrapacharem": "escarrapachar",
    "escarrapacharemos": "escarrapachar",
    "escarrapachares": "escarrapachar",
    "escarrapacharia": "escarrapachar",
    "escarrapachariam": "escarrapachar",
    "escarrapacharias": "escarrapachar",
    "escarrapacharmo": "escarrapachar",
    "escarrapacharmos": "escarrapachar",
    "escarrapachará": "escarrapachar",
    "escarrapacharás": "escarrapachar",
    "escarrapacharão": "escarrapachar",
    "escarrapacharíamos": "escarrapachar",
    "escarrapacharíeis": "escarrapachar",
    "escarrapachas": "escarrapachar",
    "escarrapachasse": "escarrapachar",
    "escarrapachassem": "escarrapachar",
    "escarrapachasses": "escarrapachar",
    "escarrapachaste": "escarrapachar",
    "escarrapachastes": "escarrapachar",
    "escarrapachava": "escarrapachar",
    "escarrapachavam": "escarrapachar",
    "escarrapachavas": "escarrapachar",
    "escarrapache": "escarrapachar",
    "escarrapachei": "escarrapachar",
    "escarrapacheis": "escarrapachar",
    "escarrapachem": "escarrapachar",
    "escarrapachemo": "escarrapachar",
    "escarrapachemos": "escarrapachar",
    "escarrapaches": "escarrapachar",
    "escarrapacho": "escarrapachar",
    "escarrapachou": "escarrapachar",
    "escarrapachá": "escarrapachar",
    "escarrapachámo": "escarrapachar",
    "escarrapachámos": "escarrapachar",
    "escarrapacháramo": "escarrapachar",
    "escarrapacháramos": "escarrapachar",
    "escarrapachárei": "escarrapachar",
    "escarrapacháreis": "escarrapachar",
    "escarrapachásseis": "escarrapachar",
    "escarrapachássemos": "escarrapachar",
    "escarrapachávamo": "escarrapachar",
    "escarrapachávamos": "escarrapachar",
    "escarrapachávei": "escarrapachar",
    "escarrapacháveis": "escarrapachar",
    "escarrapice": "escarrapiçar",
    "escarrapicei": "escarrapiçar",
    "escarrapiceis": "escarrapiçar",
    "escarrapicem": "escarrapiçar",
    "escarrapicemo": "escarrapiçar",
    "escarrapicemos": "escarrapiçar",
    "escarrapices": "escarrapiçar",
    "escarrapicha": "escarrapichar",
    "escarrapichada": "escarrapichar",
    "escarrapichadas": "escarrapichar",
    "escarrapichado": "escarrapichar",
    "escarrapichados": "escarrapichar",
    "escarrapichai": "escarrapichar",
    "escarrapichais": "escarrapichar",
    "escarrapicham": "escarrapichar",
    "escarrapichamo": "escarrapichar",
    "escarrapichamos": "escarrapichar",
    "escarrapichando": "escarrapichar",
    "escarrapichara": "escarrapichar",
    "escarrapicharam": "escarrapichar",
    "escarrapicharas": "escarrapichar",
    "escarrapicharde": "escarrapichar",
    "escarrapichardes": "escarrapichar",
    "escarrapichare": "escarrapichar",
    "escarrapicharei": "escarrapichar",
    "escarrapichareis": "escarrapichar",
    "escarrapicharem": "escarrapichar",
    "escarrapicharemos": "escarrapichar",
    "escarrapichares": "escarrapichar",
    "escarrapicharia": "escarrapichar",
    "escarrapichariam": "escarrapichar",
    "escarrapicharias": "escarrapichar",
    "escarrapicharmo": "escarrapichar",
    "escarrapicharmos": "escarrapichar",
    "escarrapichará": "escarrapichar",
    "escarrapicharás": "escarrapichar",
    "escarrapicharão": "escarrapichar",
    "escarrapicharíamos": "escarrapichar",
    "escarrapicharíeis": "escarrapichar",
    "escarrapichas": "escarrapichar",
    "escarrapichasse": "escarrapichar",
    "escarrapichassem": "escarrapichar",
    "escarrapichasses": "escarrapichar",
    "escarrapichaste": "escarrapichar",
    "escarrapichastes": "escarrapichar",
    "escarrapichava": "escarrapichar",
    "escarrapichavam": "escarrapichar",
    "escarrapichavas": "escarrapichar",
    "escarrapiche": "escarrapichar",
    "escarrapichei": "escarrapichar",
    "escarrapicheis": "escarrapichar",
    "escarrapichem": "escarrapichar",
    "escarrapichemo": "escarrapichar",
    "escarrapichemos": "escarrapichar",
    "escarrapiches": "escarrapichar",
    "escarrapicho": "escarrapichar",
    "escarrapichou": "escarrapichar",
    "escarrapichá": "escarrapichar",
    "escarrapichámo": "escarrapichar",
    "escarrapichámos": "escarrapichar",
    "escarrapicháramo": "escarrapichar",
    "escarrapicháramos": "escarrapichar",
    "escarrapichárei": "escarrapichar",
    "escarrapicháreis": "escarrapichar",
    "escarrapichásseis": "escarrapichar",
    "escarrapichássemos": "escarrapichar",
    "escarrapichávamo": "escarrapichar",
    "escarrapichávamos": "escarrapichar",
    "escarrapichávei": "escarrapichar",
    "escarrapicháveis": "escarrapichar",
    "escarrapiça": "escarrapiçar",
    "escarrapiçada": "escarrapiçar",
    "escarrapiçadas": "escarrapiçar",
    "escarrapiçado": "escarrapiçar",
    "escarrapiçados": "escarrapiçar",
    "escarrapiçai": "escarrapiçar",
    "escarrapiçais": "escarrapiçar",
    "escarrapiçam": "escarrapiçar",
    "escarrapiçamo": "escarrapiçar",
    "escarrapiçamos": "escarrapiçar",
    "escarrapiçando": "escarrapiçar",
    "escarrapiçara": "escarrapiçar",
    "escarrapiçaram": "escarrapiçar",
    "escarrapiçaras": "escarrapiçar",
    "escarrapiçarde": "escarrapiçar",
    "escarrapiçardes": "escarrapiçar",
    "escarrapiçare": "escarrapiçar",
    "escarrapiçarei": "escarrapiçar",
    "escarrapiçareis": "escarrapiçar",
    "escarrapiçarem": "escarrapiçar",
    "escarrapiçaremos": "escarrapiçar",
    "escarrapiçares": "escarrapiçar",
    "escarrapiçaria": "escarrapiçar",
    "escarrapiçariam": "escarrapiçar",
    "escarrapiçarias": "escarrapiçar",
    "escarrapiçarmo": "escarrapiçar",
    "escarrapiçarmos": "escarrapiçar",
    "escarrapiçará": "escarrapiçar",
    "escarrapiçarás": "escarrapiçar",
    "escarrapiçarão": "escarrapiçar",
    "escarrapiçaríamos": "escarrapiçar",
    "escarrapiçaríeis": "escarrapiçar",
    "escarrapiças": "escarrapiçar",
    "escarrapiçasse": "escarrapiçar",
    "escarrapiçassem": "escarrapiçar",
    "escarrapiçasses": "escarrapiçar",
    "escarrapiçaste": "escarrapiçar",
    "escarrapiçastes": "escarrapiçar",
    "escarrapiçava": "escarrapiçar",
    "escarrapiçavam": "escarrapiçar",
    "escarrapiçavas": "escarrapiçar",
    "escarrapiço": "escarrapiçar",
    "escarrapiçou": "escarrapiçar",
    "escarrapiçá": "escarrapiçar",
    "escarrapiçámo": "escarrapiçar",
    "escarrapiçámos": "escarrapiçar",
    "escarrapiçáramo": "escarrapiçar",
    "escarrapiçáramos": "escarrapiçar",
    "escarrapiçárei": "escarrapiçar",
    "escarrapiçáreis": "escarrapiçar",
    "escarrapiçásseis": "escarrapiçar",
    "escarrapiçássemos": "escarrapiçar",
    "escarrapiçávamo": "escarrapiçar",
    "escarrapiçávamos": "escarrapiçar",
    "escarrapiçávei": "escarrapiçar",
    "escarrapiçáveis": "escarrapiçar",
    "escarrara": "escarrar",
    "escarraram": "escarrar",
    "escarraras": "escarrar",
    "escarrarde": "escarrar",
    "escarrardes": "escarrar",
    "escarrare": "escarrar",
    "escarrarei": "escarrar",
    "escarrareis": "escarrar",
    "escarrarem": "escarrar",
    "escarraremos": "escarrar",
    "escarrares": "escarrar",
    "escarraria": "escarrar",
    "escarrariam": "escarrar",
    "escarrarias": "escarraria",
    "escarrarmo": "escarrar",
    "escarrarmos": "escarrar",
    "escarrará": "escarrar",
    "escarrarás": "escarrar",
    "escarrarão": "escarrar",
    "escarraríamos": "escarrar",
    "escarraríeis": "escarrar",
    "escarras": "escarrar",
    "escarrasse": "escarrar",
    "escarrassem": "escarrar",
    "escarrasses": "escarrar",
    "escarraste": "escarrar",
    "escarrastes": "escarrar",
    "escarrava": "escarrar",
    "escarravam": "escarrar",
    "escarravas": "escarrar",
    "escarre": "escarrar",
    "escarrei": "escarrar",
    "escarreis": "escarrar",
    "escarrem": "escarrar",
    "escarremo": "escarrar",
    "escarremos": "escarrar",
    "escarres": "escarrar",
    "escarro": "escarrar",
    "escarros": "escarro",
    "escarrou": "escarrar",
    "escarrá": "escarrar",
    "escarrámo": "escarrar",
    "escarrámos": "escarrar",
    "escarráramo": "escarrar",
    "escarráramos": "escarrar",
    "escarrárei": "escarrar",
    "escarráreis": "escarrar",
    "escarrásseis": "escarrar",
    "escarrássemos": "escarrar",
    "escarrávamo": "escarrar",
    "escarrávamos": "escarrar",
    "escarrávei": "escarrar",
    "escarráveis": "escarrar",
    "escaruma": "escarumar",
    "escarumada": "escarumar",
    "escarumadas": "escarumar",
    "escarumado": "escarumar",
    "escarumados": "escarumar",
    "escarumai": "escarumar",
    "escarumais": "escarumar",
    "escarumam": "escarumar",
    "escarumamo": "escarumar",
    "escarumamos": "escarumar",
    "escarumando": "escarumar",
    "escarumara": "escarumar",
    "escarumaram": "escarumar",
    "escarumaras": "escarumar",
    "escarumarde": "escarumar",
    "escarumardes": "escarumar",
    "escarumare": "escarumar",
    "escarumarei": "escarumar",
    "escarumareis": "escarumar",
    "escarumarem": "escarumar",
    "escarumaremos": "escarumar",
    "escarumares": "escarumar",
    "escarumaria": "escarumar",
    "escarumariam": "escarumar",
    "escarumarias": "escarumar",
    "escarumarmo": "escarumar",
    "escarumarmos": "escarumar",
    "escarumará": "escarumar",
    "escarumarás": "escarumar",
    "escarumarão": "escarumar",
    "escarumaríamos": "escarumar",
    "escarumaríeis": "escarumar",
    "escarumas": "escarumar",
    "escarumasse": "escarumar",
    "escarumassem": "escarumar",
    "escarumasses": "escarumar",
    "escarumaste": "escarumar",
    "escarumastes": "escarumar",
    "escarumava": "escarumar",
    "escarumavam": "escarumar",
    "escarumavas": "escarumar",
    "escarumbas": "escarumba",
    "escarume": "escarumar",
    "escarumei": "escarumar",
    "escarumeis": "escarumar",
    "escarumem": "escarumar",
    "escarumemo": "escarumar",
    "escarumemos": "escarumar",
    "escarumes": "escarumar",
    "escarumo": "escarumar",
    "escarumou": "escarumar",
    "escarumá": "escarumar",
    "escarumámo": "escarumar",
    "escarumámos": "escarumar",
    "escarumáramo": "escarumar",
    "escarumáramos": "escarumar",
    "escarumárei": "escarumar",
    "escarumáreis": "escarumar",
    "escarumásseis": "escarumar",
    "escarumássemos": "escarumar",
    "escarumávamo": "escarumar",
    "escarumávamos": "escarumar",
    "escarumávei": "escarumar",
    "escarumáveis": "escarumar",
    "escarva": "escarvar",
    "escarvada": "escarvar",
    "escarvadas": "escarvar",
    "escarvado": "escarvar",
    "escarvadora": "escarvador",
    "escarvadoras": "escarvador",
    "escarvadores": "escarvador",
    "escarvados": "escarvar",
    "escarvai": "escarvar",
    "escarvais": "escarvar",
    "escarvalhos": "escarvalho",
    "escarvam": "escarvar",
    "escarvamo": "escarvar",
    "escarvamos": "escarvar",
    "escarvando": "escarvar",
    "escarvara": "escarvar",
    "escarvaram": "escarvar",
    "escarvaras": "escarvar",
    "escarvarde": "escarvar",
    "escarvardes": "escarvar",
    "escarvare": "escarvar",
    "escarvarei": "escarvar",
    "escarvareis": "escarvar",
    "escarvarem": "escarvar",
    "escarvaremos": "escarvar",
    "escarvares": "escarvar",
    "escarvaria": "escarvar",
    "escarvariam": "escarvar",
    "escarvarias": "escarvar",
    "escarvarmo": "escarvar",
    "escarvarmos": "escarvar",
    "escarvará": "escarvar",
    "escarvarás": "escarvar",
    "escarvarão": "escarvar",
    "escarvaríamos": "escarvar",
    "escarvaríeis": "escarvar",
    "escarvas": "escarvar",
    "escarvasse": "escarvar",
    "escarvassem": "escarvar",
    "escarvasses": "escarvar",
    "escarvaste": "escarvar",
    "escarvastes": "escarvar",
    "escarvava": "escarvar",
    "escarvavam": "escarvar",
    "escarvavas": "escarvar",
    "escarve": "escarvar",
    "escarvei": "escarvar",
    "escarveis": "escarvar",
    "escarvem": "escarvar",
    "escarvemo": "escarvar",
    "escarvemos": "escarvar",
    "escarves": "escarvar",
    "escarvo": "escarvar",
    "escarvoa": "escarvoar",
    "escarvoada": "escarvoar",
    "escarvoadas": "escarvoar",
    "escarvoado": "escarvoar",
    "escarvoados": "escarvoar",
    "escarvoai": "escarvoar",
    "escarvoais": "escarvoar",
    "escarvoam": "escarvoar",
    "escarvoamo": "escarvoar",
    "escarvoamos": "escarvoar",
    "escarvoando": "escarvoar",
    "escarvoara": "escarvoar",
    "escarvoaram": "escarvoar",
    "escarvoaras": "escarvoar",
    "escarvoarde": "escarvoar",
    "escarvoardes": "escarvoar",
    "escarvoare": "escarvoar",
    "escarvoarei": "escarvoar",
    "escarvoareis": "escarvoar",
    "escarvoarem": "escarvoar",
    "escarvoaremos": "escarvoar",
    "escarvoares": "escarvoar",
    "escarvoaria": "escarvoar",
    "escarvoariam": "escarvoar",
    "escarvoarias": "escarvoar",
    "escarvoarmo": "escarvoar",
    "escarvoarmos": "escarvoar",
    "escarvoará": "escarvoar",
    "escarvoarás": "escarvoar",
    "escarvoarão": "escarvoar",
    "escarvoaríamos": "escarvoar",
    "escarvoaríeis": "escarvoar",
    "escarvoas": "escarvoar",
    "escarvoasse": "escarvoar",
    "escarvoassem": "escarvoar",
    "escarvoasses": "escarvoar",
    "escarvoaste": "escarvoar",
    "escarvoastes": "escarvoar",
    "escarvoava": "escarvoar",
    "escarvoavam": "escarvoar",
    "escarvoavas": "escarvoar",
    "escarvoe": "escarvoar",
    "escarvoei": "escarvoar",
    "escarvoeis": "escarvoar",
    "escarvoem": "escarvoar",
    "escarvoemo": "escarvoar",
    "escarvoemos": "escarvoar",
    "escarvoes": "escarvoar",
    "escarvoo": "escarvoar",
    "escarvoou": "escarvoar",
    "escarvou": "escarvar",
    "escarvoá": "escarvoar",
    "escarvoámo": "escarvoar",
    "escarvoámos": "escarvoar",
    "escarvoáramo": "escarvoar",
    "escarvoáramos": "escarvoar",
    "escarvoárei": "escarvoar",
    "escarvoáreis": "escarvoar",
    "escarvoásseis": "escarvoar",
    "escarvoássemos": "escarvoar",
    "escarvoávamo": "escarvoar",
    "escarvoávamos": "escarvoar",
    "escarvoávei": "escarvoar",
    "escarvoáveis": "escarvoar",
    "escarvá": "escarvar",
    "escarvámo": "escarvar",
    "escarvámos": "escarvar",
    "escarváramo": "escarvar",
    "escarváramos": "escarvar",
    "escarvárei": "escarvar",
    "escarváreis": "escarvar",
    "escarvásseis": "escarvar",
    "escarvássemos": "escarvar",
    "escarvávamo": "escarvar",
    "escarvávamos": "escarvar",
    "escarvávei": "escarvar",
    "escarváveis": "escarvar",
    "escarça": "escarçar",
    "escarçada": "escarçar",
    "escarçadas": "escarçar",
    "escarçado": "escarçar",
    "escarçados": "escarçar",
    "escarçai": "escarçar",
    "escarçais": "escarçar",
    "escarçam": "escarçar",
    "escarçamo": "escarçar",
    "escarçamos": "escarçar",
    "escarçando": "escarçar",
    "escarçara": "escarçar",
    "escarçaram": "escarçar",
    "escarçaras": "escarçar",
    "escarçarde": "escarçar",
    "escarçardes": "escarçar",
    "escarçare": "escarçar",
    "escarçarei": "escarçar",
    "escarçareis": "escarçar",
    "escarçarem": "escarçar",
    "escarçaremos": "escarçar",
    "escarçares": "escarçar",
    "escarçaria": "escarçar",
    "escarçariam": "escarçar",
    "escarçarias": "escarçar",
    "escarçarmo": "escarçar",
    "escarçarmos": "escarçar",
    "escarçará": "escarçar",
    "escarçarás": "escarçar",
    "escarçarão": "escarçar",
    "escarçaríamos": "escarçar",
    "escarçaríeis": "escarçar",
    "escarças": "escarçar",
    "escarçasse": "escarçar",
    "escarçassem": "escarçar",
    "escarçasses": "escarçar",
    "escarçaste": "escarçar",
    "escarçastes": "escarçar",
    "escarçava": "escarçar",
    "escarçavam": "escarçar",
    "escarçavas": "escarçar",
    "escarço": "escarçar",
    "escarços": "escarço",
    "escarçou": "escarçar",
    "escarçá": "escarçar",
    "escarçámo": "escarçar",
    "escarçámos": "escarçar",
    "escarçáramo": "escarçar",
    "escarçáramos": "escarçar",
    "escarçárei": "escarçar",
    "escarçáreis": "escarçar",
    "escarçásseis": "escarçar",
    "escarçássemos": "escarçar",
    "escarçávamo": "escarçar",
    "escarçávamos": "escarçar",
    "escarçávei": "escarçar",
    "escarçáveis": "escarçar",
    "escarções": "escarção",
    "escarótica": "escarótico",
    "escaróticas": "escarótico",
    "escaróticos": "escarótico",
    "escasca": "escascar",
    "escascada": "escascar",
    "escascadas": "escascar",
    "escascado": "escascar",
    "escascados": "escascar",
    "escascai": "escascar",
    "escascais": "escascar",
    "escascam": "escascar",
    "escascamo": "escascar",
    "escascamos": "escascar",
    "escascando": "escascar",
    "escascara": "escascar",
    "escascaram": "escascar",
    "escascaras": "escascar",
    "escascarde": "escascar",
    "escascardes": "escascar",
    "escascare": "escascar",
    "escascarei": "escascar",
    "escascareis": "escascar",
    "escascarem": "escascar",
    "escascaremos": "escascar",
    "escascares": "escascar",
    "escascaria": "escascar",
    "escascariam": "escascar",
    "escascarias": "escascar",
    "escascarmo": "escascar",
    "escascarmos": "escascar",
    "escascará": "escascar",
    "escascarás": "escascar",
    "escascarão": "escascar",
    "escascaríamos": "escascar",
    "escascaríeis": "escascar",
    "escascas": "escascar",
    "escascasse": "escascar",
    "escascassem": "escascar",
    "escascasses": "escascar",
    "escascaste": "escascar",
    "escascastes": "escascar",
    "escascava": "escascar",
    "escascavam": "escascar",
    "escascavas": "escascar",
    "escasco": "escascar",
    "escascou": "escascar",
    "escascá": "escascar",
    "escascámo": "escascar",
    "escascámos": "escascar",
    "escascáramo": "escascar",
    "escascáramos": "escascar",
    "escascárei": "escascar",
    "escascáreis": "escascar",
    "escascásseis": "escascar",
    "escascássemos": "escascar",
    "escascávamo": "escascar",
    "escascávamos": "escascar",
    "escascávei": "escascar",
    "escascáveis": "escascar",
    "escasque": "escascar",
    "escasqueada": "escasquear",
    "escasqueadas": "escasquear",
    "escasqueado": "escasquear",
    "escasqueados": "escasquear",
    "escasqueai": "escasquear",
    "escasqueais": "escasquear",
    "escasqueamo": "escasquear",
    "escasqueamos": "escasquear",
    "escasqueando": "escasquear",
    "escasqueara": "escasquear",
    "escasquearam": "escasquear",
    "escasquearas": "escasquear",
    "escasquearde": "escasquear",
    "escasqueardes": "escasquear",
    "escasqueare": "escasquear",
    "escasquearei": "escasquear",
    "escasqueareis": "escasquear",
    "escasquearem": "escasquear",
    "escasquearemos": "escasquear",
    "escasqueares": "escasquear",
    "escasquearia": "escasquear",
    "escasqueariam": "escasquear",
    "escasquearias": "escasquear",
    "escasquearmo": "escasquear",
    "escasquearmos": "escasquear",
    "escasqueará": "escasquear",
    "escasquearás": "escasquear",
    "escasquearão": "escasquear",
    "escasquearíamos": "escasquear",
    "escasquearíeis": "escasquear",
    "escasqueasse": "escasquear",
    "escasqueassem": "escasquear",
    "escasqueasses": "escasquear",
    "escasqueaste": "escasquear",
    "escasqueastes": "escasquear",
    "escasqueava": "escasquear",
    "escasqueavam": "escasquear",
    "escasqueavas": "escasquear",
    "escasqueei": "escasquear",
    "escasqueeis": "escasquear",
    "escasqueemo": "escasquear",
    "escasqueemos": "escasquear",
    "escasquei": "escascar",
    "escasqueia": "escasquear",
    "escasqueiam": "escasquear",
    "escasqueias": "escasquear",
    "escasqueie": "escasquear",
    "escasqueiem": "escasquear",
    "escasqueies": "escasquear",
    "escasqueio": "escasquear",
    "escasqueis": "escascar",
    "escasquem": "escascar",
    "escasquemo": "escascar",
    "escasquemos": "escascar",
    "escasqueou": "escasquear",
    "escasques": "escascar",
    "escasqueá": "escasquear",
    "escasqueámo": "escasquear",
    "escasqueámos": "escasquear",
    "escasqueáramo": "escasquear",
    "escasqueáramos": "escasquear",
    "escasqueárei": "escasquear",
    "escasqueáreis": "escasquear",
    "escasqueásseis": "escasquear",
    "escasqueássemos": "escasquear",
    "escasqueávamo": "escasquear",
    "escasqueávamos": "escasquear",
    "escasqueávei": "escasquear",
    "escasqueáveis": "escasquear",
    "escassa": "escasso",
    "escassas": "escasso",
    "escasseada": "escassear",
    "escasseadas": "escassear",
    "escasseado": "escassear",
    "escasseados": "escassear",
    "escasseai": "escassear",
    "escasseais": "escassear",
    "escasseamo": "escassear",
    "escasseamos": "escassear",
    "escasseando": "escassear",
    "escasseara": "escassear",
    "escassearam": "escassear",
    "escassearas": "escassear",
    "escasseardes": "escassear",
    "escassearei": "escassear",
    "escasseareis": "escassear",
    "escassearem": "escassear",
    "escassearemos": "escassear",
    "escasseares": "escassear",
    "escassearia": "escassear",
    "escasseariam": "escassear",
    "escassearias": "escassear",
    "escassearmo": "escassear",
    "escassearmos": "escassear",
    "escasseará": "escassear",
    "escassearás": "escassear",
    "escassearão": "escassear",
    "escassearíamos": "escassear",
    "escassearíeis": "escassear",
    "escasseasse": "escassear",
    "escasseassem": "escassear",
    "escasseasses": "escassear",
    "escasseaste": "escassear",
    "escasseastes": "escassear",
    "escasseava": "escassear",
    "escasseavam": "escassear",
    "escasseavas": "escassear",
    "escasseei": "escassear",
    "escasseeis": "escassear",
    "escasseemo": "escassear",
    "escasseemos": "escassear",
    "escasseia": "escassear",
    "escasseiam": "escassear",
    "escasseias": "escassear",
    "escasseie": "escassear",
    "escasseiem": "escassear",
    "escasseies": "escassear",
    "escasseio": "escassear",
    "escasseou": "escassear",
    "escassezas": "escasseza",
    "escasseámo": "escassear",
    "escasseámos": "escassear",
    "escasseáramo": "escassear",
    "escasseáramos": "escassear",
    "escasseáreis": "escassear",
    "escasseásseis": "escassear",
    "escasseássemos": "escassear",
    "escasseávamo": "escassear",
    "escasseávamos": "escassear",
    "escasseáveis": "escassear",
    "escassilhos": "escassilho",
    "escassos": "escasso",
    "escatofagias": "escatofagia",
    "escatofilias": "escatofilia",
    "escatologias": "escatologia",
    "escatológica": "escatológico",
    "escatológicas": "escatológico",
    "escatológicos": "escatológico",
    "escatomas": "escatoma",
    "escatomática": "escatomático",
    "escatomáticas": "escatomático",
    "escatomáticos": "escatomático",
    "escatéis": "escatel",
    "escatófaga": "escatófago",
    "escatófagas": "escatófago",
    "escatófagos": "escatófago",
    "escatófila": "escatófilo",
    "escatófilas": "escatófilo",
    "escatófilos": "escatófilo",
    "escatóis": "escatol",
    "escatóloga": "escatólogo",
    "escatólogas": "escatólogo",
    "escatólogos": "escatólogo",
    "escava": "escavar",
    "escavaca": "escavacar",
    "escavacada": "escavacar",
    "escavacadas": "escavacar",
    "escavacado": "escavacar",
    "escavacados": "escavacar",
    "escavacai": "escavacar",
    "escavacais": "escavacar",
    "escavacam": "escavacar",
    "escavacamo": "escavacar",
    "escavacamos": "escavacar",
    "escavacando": "escavacar",
    "escavacara": "escavacar",
    "escavacaram": "escavacar",
    "escavacaras": "escavacar",
    "escavacarde": "escavacar",
    "escavacardes": "escavacar",
    "escavacare": "escavacar",
    "escavacarei": "escavacar",
    "escavacareis": "escavacar",
    "escavacarem": "escavacar",
    "escavacaremos": "escavacar",
    "escavacares": "escavacar",
    "escavacaria": "escavacar",
    "escavacariam": "escavacar",
    "escavacarias": "escavacar",
    "escavacarmo": "escavacar",
    "escavacarmos": "escavacar",
    "escavacará": "escavacar",
    "escavacarás": "escavacar",
    "escavacarão": "escavacar",
    "escavacaríamos": "escavacar",
    "escavacaríeis": "escavacar",
    "escavacas": "escavacar",
    "escavacasse": "escavacar",
    "escavacassem": "escavacar",
    "escavacasses": "escavacar",
    "escavacaste": "escavacar",
    "escavacastes": "escavacar",
    "escavacava": "escavacar",
    "escavacavam": "escavacar",
    "escavacavas": "escavacar",
    "escavace": "escavaçar",
    "escavacei": "escavaçar",
    "escavaceis": "escavaçar",
    "escavacem": "escavaçar",
    "escavacemo": "escavaçar",
    "escavacemos": "escavaçar",
    "escavaces": "escavaçar",
    "escavaco": "escavacar",
    "escavacou": "escavacar",
    "escavacá": "escavacar",
    "escavacámo": "escavacar",
    "escavacámos": "escavacar",
    "escavacáramo": "escavacar",
    "escavacáramos": "escavacar",
    "escavacárei": "escavacar",
    "escavacáreis": "escavacar",
    "escavacásseis": "escavacar",
    "escavacássemos": "escavacar",
    "escavacávamo": "escavacar",
    "escavacávamos": "escavacar",
    "escavacávei": "escavacar",
    "escavacáveis": "escavacar",
    "escavada": "escavar",
    "escavadas": "escavar",
    "escavadeiras": "escavadeira",
    "escavado": "escavar",
    "escavadora": "escavador",
    "escavadoras": "escavadora",
    "escavadores": "escavador",
    "escavados": "escavar",
    "escavai": "escavar",
    "escavais": "escavar",
    "escavam": "escavar",
    "escavamo": "escavar",
    "escavamos": "escavar",
    "escavando": "escavar",
    "escavaque": "escavacar",
    "escavaquei": "escavacar",
    "escavaqueis": "escavacar",
    "escavaquem": "escavacar",
    "escavaquemo": "escavacar",
    "escavaquemos": "escavacar",
    "escavaques": "escavacar",
    "escavara": "escavar",
    "escavaram": "escavar",
    "escavaras": "escavar",
    "escavarde": "escavar",
    "escavardes": "escavar",
    "escavare": "escavar",
    "escavarei": "escavar",
    "escavareis": "escavar",
    "escavarem": "escavar",
    "escavaremos": "escavar",
    "escavares": "escavar",
    "escavaria": "escavar",
    "escavariam": "escavar",
    "escavarias": "escavar",
    "escavarmo": "escavar",
    "escavarmos": "escavar",
    "escavará": "escavar",
    "escavarás": "escavar",
    "escavarão": "escavar",
    "escavaríamos": "escavar",
    "escavaríeis": "escavar",
    "escavas": "escavar",
    "escavasse": "escavar",
    "escavassem": "escavar",
    "escavasses": "escavar",
    "escavaste": "escavar",
    "escavastes": "escavar",
    "escavava": "escavar",
    "escavavam": "escavar",
    "escavavas": "escavar",
    "escavaça": "escavaçar",
    "escavaçada": "escavaçar",
    "escavaçadas": "escavaçar",
    "escavaçado": "escavaçar",
    "escavaçados": "escavaçar",
    "escavaçai": "escavaçar",
    "escavaçais": "escavaçar",
    "escavaçam": "escavaçar",
    "escavaçamo": "escavaçar",
    "escavaçamos": "escavaçar",
    "escavaçando": "escavaçar",
    "escavaçara": "escavaçar",
    "escavaçaram": "escavaçar",
    "escavaçaras": "escavaçar",
    "escavaçarde": "escavaçar",
    "escavaçardes": "escavaçar",
    "escavaçare": "escavaçar",
    "escavaçarei": "escavaçar",
    "escavaçareis": "escavaçar",
    "escavaçarem": "escavaçar",
    "escavaçaremos": "escavaçar",
    "escavaçares": "escavaçar",
    "escavaçaria": "escavaçar",
    "escavaçariam": "escavaçar",
    "escavaçarias": "escavaçar",
    "escavaçarmo": "escavaçar",
    "escavaçarmos": "escavaçar",
    "escavaçará": "escavaçar",
    "escavaçarás": "escavaçar",
    "escavaçarão": "escavaçar",
    "escavaçaríamos": "escavaçar",
    "escavaçaríeis": "escavaçar",
    "escavaças": "escavaçar",
    "escavaçasse": "escavaçar",
    "escavaçassem": "escavaçar",
    "escavaçasses": "escavaçar",
    "escavaçaste": "escavaçar",
    "escavaçastes": "escavaçar",
    "escavaçava": "escavaçar",
    "escavaçavam": "escavaçar",
    "escavaçavas": "escavaçar",
    "escavaço": "escavaçar",
    "escavaçou": "escavaçar",
    "escavaçá": "escavaçar",
    "escavaçámo": "escavaçar",
    "escavaçámos": "escavaçar",
    "escavaçáramo": "escavaçar",
    "escavaçáramos": "escavaçar",
    "escavaçárei": "escavaçar",
    "escavaçáreis": "escavaçar",
    "escavaçásseis": "escavaçar",
    "escavaçássemos": "escavaçar",
    "escavaçávamo": "escavaçar",
    "escavaçávamos": "escavaçar",
    "escavaçávei": "escavaçar",
    "escavaçáveis": "escavaçar",
    "escavações": "escavação",
    "escave": "escavar",
    "escavei": "escavar",
    "escaveira": "escaveirar",
    "escaveirada": "escaveirar",
    "escaveiradas": "escaveirar",
    "escaveirado": "escaveirar",
    "escaveirados": "escaveirar",
    "escaveirai": "escaveirar",
    "escaveirais": "escaveirar",
    "escaveiram": "escaveirar",
    "escaveiramo": "escaveirar",
    "escaveiramos": "escaveirar",
    "escaveirando": "escaveirar",
    "escaveirara": "escaveirar",
    "escaveiraram": "escaveirar",
    "escaveiraras": "escaveirar",
    "escaveirarde": "escaveirar",
    "escaveirardes": "escaveirar",
    "escaveirare": "escaveirar",
    "escaveirarei": "escaveirar",
    "escaveirareis": "escaveirar",
    "escaveirarem": "escaveirar",
    "escaveiraremos": "escaveirar",
    "escaveirares": "escaveirar",
    "escaveiraria": "escaveirar",
    "escaveirariam": "escaveirar",
    "escaveirarias": "escaveirar",
    "escaveirarmo": "escaveirar",
    "escaveirarmos": "escaveirar",
    "escaveirará": "escaveirar",
    "escaveirarás": "escaveirar",
    "escaveirarão": "escaveirar",
    "escaveiraríamos": "escaveirar",
    "escaveiraríeis": "escaveirar",
    "escaveiras": "escaveirar",
    "escaveirasse": "escaveirar",
    "escaveirassem": "escaveirar",
    "escaveirasses": "escaveirar",
    "escaveiraste": "escaveirar",
    "escaveirastes": "escaveirar",
    "escaveirava": "escaveirar",
    "escaveiravam": "escaveirar",
    "escaveiravas": "escaveirar",
    "escaveire": "escaveirar",
    "escaveirei": "escaveirar",
    "escaveireis": "escaveirar",
    "escaveirem": "escaveirar",
    "escaveiremo": "escaveirar",
    "escaveiremos": "escaveirar",
    "escaveires": "escaveirar",
    "escaveiro": "escaveirar",
    "escaveirou": "escaveirar",
    "escaveirá": "escaveirar",
    "escaveirámo": "escaveirar",
    "escaveirámos": "escaveirar",
    "escaveiráramo": "escaveirar",
    "escaveiráramos": "escaveirar",
    "escaveirárei": "escaveirar",
    "escaveiráreis": "escaveirar",
    "escaveirásseis": "escaveirar",
    "escaveirássemos": "escaveirar",
    "escaveirávamo": "escaveirar",
    "escaveirávamos": "escaveirar",
    "escaveirávei": "escaveirar",
    "escaveiráveis": "escaveirar",
    "escaveis": "escavar",
    "escavem": "escavar",
    "escavemo": "escavar",
    "escavemos": "escavar",
    "escaves": "escavar",
    "escavo": "escavar",
    "escavou": "escavar",
    "escavá": "escavar",
    "escavámo": "escavar",
    "escavámos": "escavar",
    "escaváramo": "escavar",
    "escaváramos": "escavar",
    "escavárei": "escavar",
    "escaváreis": "escavar",
    "escavásseis": "escavar",
    "escavássemos": "escavar",
    "escavávamo": "escavar",
    "escavávamos": "escavar",
    "escavávei": "escavar",
    "escaváveis": "escavar",
    "escazontes": "escazonte",
    "escaços": "escaço",
    "escdruxuliza": "escdruxulizar",
    "escdruxulizada": "escdruxulizar",
    "escdruxulizadas": "escdruxulizar",
    "escdruxulizado": "escdruxulizar",
    "escdruxulizados": "escdruxulizar",
    "escdruxulizai": "escdruxulizar",
    "escdruxulizais": "escdruxulizar",
    "escdruxulizam": "escdruxulizar",
    "escdruxulizamo": "escdruxulizar",
    "escdruxulizamos": "escdruxulizar",
    "escdruxulizando": "escdruxulizar",
    "escdruxulizara": "escdruxulizar",
    "escdruxulizaram": "escdruxulizar",
    "escdruxulizaras": "escdruxulizar",
    "escdruxulizarde": "escdruxulizar",
    "escdruxulizardes": "escdruxulizar",
    "escdruxulizare": "escdruxulizar",
    "escdruxulizarei": "escdruxulizar",
    "escdruxulizareis": "escdruxulizar",
    "escdruxulizarem": "escdruxulizar",
    "escdruxulizaremos": "escdruxulizar",
    "escdruxulizares": "escdruxulizar",
    "escdruxulizaria": "escdruxulizar",
    "escdruxulizariam": "escdruxulizar",
    "escdruxulizarias": "escdruxulizar",
    "escdruxulizarmo": "escdruxulizar",
    "escdruxulizarmos": "escdruxulizar",
    "escdruxulizará": "escdruxulizar",
    "escdruxulizarás": "escdruxulizar",
    "escdruxulizarão": "escdruxulizar",
    "escdruxulizaríamos": "escdruxulizar",
    "escdruxulizaríeis": "escdruxulizar",
    "escdruxulizas": "escdruxulizar",
    "escdruxulizasse": "escdruxulizar",
    "escdruxulizassem": "escdruxulizar",
    "escdruxulizasses": "escdruxulizar",
    "escdruxulizaste": "escdruxulizar",
    "escdruxulizastes": "escdruxulizar",
    "escdruxulizava": "escdruxulizar",
    "escdruxulizavam": "escdruxulizar",
    "escdruxulizavas": "escdruxulizar",
    "escdruxulize": "escdruxulizar",
    "escdruxulizei": "escdruxulizar",
    "escdruxulizeis": "escdruxulizar",
    "escdruxulizem": "escdruxulizar",
    "escdruxulizemo": "escdruxulizar",
    "escdruxulizemos": "escdruxulizar",
    "escdruxulizes": "escdruxulizar",
    "escdruxulizo": "escdruxulizar",
    "escdruxulizou": "escdruxulizar",
    "escdruxulizá": "escdruxulizar",
    "escdruxulizámo": "escdruxulizar",
    "escdruxulizámos": "escdruxulizar",
    "escdruxulizáramo": "escdruxulizar",
    "escdruxulizáramos": "escdruxulizar",
    "escdruxulizárei": "escdruxulizar",
    "escdruxulizáreis": "escdruxulizar",
    "escdruxulizásseis": "escdruxulizar",
    "escdruxulizássemos": "escdruxulizar",
    "escdruxulizávamo": "escdruxulizar",
    "escdruxulizávamos": "escdruxulizar",
    "escdruxulizávei": "escdruxulizar",
    "escdruxulizáveis": "escdruxulizar",
    "esclarece": "esclarecer",
    "esclarecedora": "esclarecedor",
    "esclarecedoras": "esclarecedor",
    "esclarecedores": "esclarecedor",
    "esclarecei": "esclarecer",
    "esclareceis": "esclarecer",
    "esclarecem": "esclarecer",
    "esclarecemo": "esclarecer",
    "esclarecemos": "esclarecer",
    "esclarecendo": "esclarecer",
    "esclarecera": "esclarecer",
    "esclareceram": "esclarecer",
    "esclareceras": "esclarecer",
    "esclarecerde": "esclarecer",
    "esclarecerdes": "esclarecer",
    "esclarecere": "esclarecer",
    "esclarecerei": "esclarecer",
    "esclarecereis": "esclarecer",
    "esclarecerem": "esclarecer",
    "esclareceremos": "esclarecer",
    "esclareceres": "esclarecer",
    "esclareceria": "esclarecer",
    "esclareceriam": "esclarecer",
    "esclarecerias": "esclarecer",
    "esclarecermo": "esclarecer",
    "esclarecermos": "esclarecer",
    "esclarecerá": "esclarecer",
    "esclarecerás": "esclarecer",
    "esclarecerão": "esclarecer",
    "esclareceríamos": "esclarecer",
    "esclareceríeis": "esclarecer",
    "esclareces": "esclarecer",
    "esclarecesse": "esclarecer",
    "esclarecessem": "esclarecer",
    "esclarecesses": "esclarecer",
    "esclareceste": "esclarecer",
    "esclarecestes": "esclarecer",
    "esclareceu": "esclarecer",
    "esclareci": "esclarecer",
    "esclarecia": "esclarecer",
    "esclareciam": "esclarecer",
    "esclarecias": "esclarecer",
    "esclarecida": "esclarecido",
    "esclarecidas": "esclarecido",
    "esclarecido": "esclarecer",
    "esclarecidos": "esclarecido",
    "esclarecimentos": "esclarecimento",
    "esclarecê": "esclarecer",
    "esclarecêramo": "esclarecer",
    "esclarecêramos": "esclarecer",
    "esclarecêrei": "esclarecer",
    "esclarecêreis": "esclarecer",
    "esclarecêsseis": "esclarecer",
    "esclarecêssemos": "esclarecer",
    "esclarecíamo": "esclarecer",
    "esclarecíamos": "esclarecer",
    "esclarecíei": "esclarecer",
    "esclarecíeis": "esclarecer",
    "esclareça": "esclarecer",
    "esclareçais": "esclarecer",
    "esclareçam": "esclarecer",
    "esclareçamo": "esclarecer",
    "esclareçamos": "esclarecer",
    "esclareças": "esclarecer",
    "esclareço": "esclarecer",
    "esclava": "esclavo",
    "esclavas": "esclavo",
    "esclavinas": "esclavina",
    "esclavos": "esclavo",
    "esclavã": "esclavão",
    "esclavãos": "esclavão",
    "esclavãs": "esclavão",
    "esclavónia": "esclavónio",
    "esclavónias": "esclavónio",
    "esclavónica": "esclavónico",
    "esclavónicas": "esclavónico",
    "esclavónicos": "esclavónico",
    "esclavónios": "esclavónio",
    "esclerais": "escleral",
    "esclerectomias": "esclerectomia",
    "esclerectómica": "esclerectómico",
    "esclerectómicas": "esclerectómico",
    "esclerectómicos": "esclerectómico",
    "escleritos": "esclerito",
    "escleroderma": "esclerodermo",
    "esclerodermas": "esclerodermo",
    "esclerodermias": "esclerodermia",
    "esclerodermos": "esclerodermo",
    "esclerodérmica": "esclerodérmico",
    "esclerodérmicas": "esclerodérmico",
    "esclerodérmicos": "esclerodérmico",
    "escleroftalmias": "escleroftalmia",
    "escleroftálmica": "escleroftálmico",
    "escleroftálmicas": "escleroftálmico",
    "escleroftálmicos": "escleroftálmico",
    "escleromas": "escleroma",
    "escleroproteínas": "escleroproteína",
    "escleroprotéica": "escleroprotéico",
    "escleroprotéicas": "escleroprotéico",
    "escleroprotéicos": "escleroprotéico",
    "esclerosa": "esclerosar",
    "esclerosada": "esclerosar",
    "esclerosadas": "esclerosar",
    "esclerosado": "esclerosar",
    "esclerosados": "esclerosar",
    "esclerosai": "esclerosar",
    "esclerosais": "esclerosar",
    "esclerosam": "esclerosar",
    "esclerosamentos": "esclerosamento",
    "esclerosamo": "esclerosar",
    "esclerosamos": "esclerosar",
    "esclerosando": "esclerosar",
    "esclerosara": "esclerosar",
    "esclerosaram": "esclerosar",
    "esclerosaras": "esclerosar",
    "esclerosarde": "esclerosar",
    "esclerosardes": "esclerosar",
    "esclerosare": "esclerosar",
    "esclerosarei": "esclerosar",
    "esclerosareis": "esclerosar",
    "esclerosarem": "esclerosar",
    "esclerosaremos": "esclerosar",
    "esclerosares": "esclerosar",
    "esclerosaria": "esclerosar",
    "esclerosariam": "esclerosar",
    "esclerosarias": "esclerosar",
    "esclerosarmo": "esclerosar",
    "esclerosarmos": "esclerosar",
    "esclerosará": "esclerosar",
    "esclerosarás": "esclerosar",
    "esclerosarão": "esclerosar",
    "esclerosaríamos": "esclerosar",
    "esclerosaríeis": "esclerosar",
    "esclerosas": "esclerosar",
    "esclerosasse": "esclerosar",
    "esclerosassem": "esclerosar",
    "esclerosasses": "esclerosar",
    "esclerosaste": "esclerosar",
    "esclerosastes": "esclerosar",
    "esclerosava": "esclerosar",
    "esclerosavam": "esclerosar",
    "esclerosavas": "esclerosar",
    "esclerose": "esclerosar",
    "esclerosei": "esclerosar",
    "escleroseis": "esclerosar",
    "esclerosem": "esclerosar",
    "esclerosemo": "esclerosar",
    "esclerosemos": "esclerosar",
    "escleroses": "esclerose",
    "escleroso": "esclerosar",
    "esclerosou": "esclerosar",
    "esclerosá": "esclerosar",
    "esclerosámo": "esclerosar",
    "esclerosámos": "esclerosar",
    "esclerosáramo": "esclerosar",
    "esclerosáramos": "esclerosar",
    "esclerosárei": "esclerosar",
    "esclerosáreis": "esclerosar",
    "esclerosásseis": "esclerosar",
    "esclerosássemos": "esclerosar",
    "esclerosávamo": "esclerosar",
    "esclerosávamos": "esclerosar",
    "esclerosávei": "esclerosar",
    "esclerosáveis": "esclerosar",
    "esclerotes": "esclerote",
    "escleroticotomias": "escleroticotomia",
    "escleroticotómica": "escleroticotómico",
    "escleroticotómicas": "escleroticotómico",
    "escleroticotómicos": "escleroticotómico",
    "esclerotites": "esclerotite",
    "esclerotos": "escleroto",
    "esclerotítica": "esclerotítico",
    "esclerotíticas": "esclerotítico",
    "esclerotíticos": "esclerotítico",
    "esclerênquimas": "esclerênquima",
    "esclerócitos": "esclerócito",
    "esclerótica": "esclerótico",
    "escleróticas": "esclerótico",
    "escleróticos": "esclerótico",
    "escoa": "escoar",
    "escoada": "escoar",
    "escoadas": "escoar",
    "escoadeiras": "escoadeira",
    "escoado": "escoar",
    "escoadoiros": "escoadoiro",
    "escoadora": "escoador",
    "escoadoras": "escoador",
    "escoadores": "escoador",
    "escoados": "escoar",
    "escoadouros": "escoadouro",
    "escoaduras": "escoadura",
    "escoai": "escoar",
    "escoais": "escoar",
    "escoalhas": "escoalha",
    "escoam": "escoar",
    "escoamentos": "escoamento",
    "escoamo": "escoar",
    "escoamos": "escoar",
    "escoando": "escoar",
    "escoantes": "escoante",
    "escoara": "escoar",
    "escoaram": "escoar",
    "escoaras": "escoar",
    "escoarde": "escoar",
    "escoardes": "escoar",
    "escoare": "escoar",
    "escoarei": "escoar",
    "escoareis": "escoar",
    "escoarem": "escoar",
    "escoaremos": "escoar",
    "escoares": "escoar",
    "escoaria": "escoar",
    "escoariam": "escoar",
    "escoarias": "escoar",
    "escoarmo": "escoar",
    "escoarmos": "escoar",
    "escoará": "escoar",
    "escoarás": "escoar",
    "escoarão": "escoar",
    "escoaríamos": "escoar",
    "escoaríeis": "escoar",
    "escoas": "escoar",
    "escoasse": "escoar",
    "escoassem": "escoar",
    "escoasses": "escoar",
    "escoaste": "escoar",
    "escoastes": "escoar",
    "escoava": "escoar",
    "escoavam": "escoar",
    "escoavas": "escoar",
    "escoações": "escoação",
    "escoca": "escocar",
    "escocada": "escocar",
    "escocadas": "escocar",
    "escocado": "escocar",
    "escocados": "escocar",
    "escocai": "escocar",
    "escocais": "escocar",
    "escocam": "escocar",
    "escocamo": "escocar",
    "escocamos": "escocar",
    "escocando": "escocar",
    "escocara": "escocar",
    "escocaram": "escocar",
    "escocaras": "escocar",
    "escocarde": "escocar",
    "escocardes": "escocar",
    "escocare": "escocar",
    "escocarei": "escocar",
    "escocareis": "escocar",
    "escocarem": "escocar",
    "escocaremos": "escocar",
    "escocares": "escocar",
    "escocaria": "escocar",
    "escocariam": "escocar",
    "escocarias": "escocar",
    "escocarmo": "escocar",
    "escocarmos": "escocar",
    "escocará": "escocar",
    "escocarás": "escocar",
    "escocarão": "escocar",
    "escocaríamos": "escocar",
    "escocaríeis": "escocar",
    "escocas": "escocar",
    "escocasse": "escocar",
    "escocassem": "escocar",
    "escocasses": "escocar",
    "escocaste": "escocar",
    "escocastes": "escocar",
    "escocava": "escocar",
    "escocavam": "escocar",
    "escocavas": "escocar",
    "escocesa": "escocês",
    "escocesas": "escocês",
    "escoceses": "escocês",
    "escocha": "escochar",
    "escochada": "escochar",
    "escochadas": "escochar",
    "escochado": "escochar",
    "escochados": "escochar",
    "escochai": "escochar",
    "escochais": "escochar",
    "escocham": "escochar",
    "escochamo": "escochar",
    "escochamos": "escochar",
    "escochando": "escochar",
    "escochara": "escochar",
    "escocharam": "escochar",
    "escocharas": "escochar",
    "escocharde": "escochar",
    "escochardes": "escochar",
    "escochare": "escochar",
    "escocharei": "escochar",
    "escochareis": "escochar",
    "escocharem": "escochar",
    "escocharemos": "escochar",
    "escochares": "escochar",
    "escocharia": "escochar",
    "escochariam": "escochar",
    "escocharias": "escochar",
    "escocharmo": "escochar",
    "escocharmos": "escochar",
    "escochará": "escochar",
    "escocharás": "escochar",
    "escocharão": "escochar",
    "escocharíamos": "escochar",
    "escocharíeis": "escochar",
    "escochas": "escochar",
    "escochasse": "escochar",
    "escochassem": "escochar",
    "escochasses": "escochar",
    "escochaste": "escochar",
    "escochastes": "escochar",
    "escochava": "escochar",
    "escochavam": "escochar",
    "escochavas": "escochar",
    "escoche": "escochar",
    "escochei": "escochar",
    "escocheis": "escochar",
    "escochem": "escochar",
    "escochemo": "escochar",
    "escochemos": "escochar",
    "escoches": "escochar",
    "escochina": "escochinar",
    "escochinada": "escochinar",
    "escochinadas": "escochinar",
    "escochinado": "escochinar",
    "escochinados": "escochinar",
    "escochinai": "escochinar",
    "escochinais": "escochinar",
    "escochinam": "escochinar",
    "escochinamo": "escochinar",
    "escochinamos": "escochinar",
    "escochinando": "escochinar",
    "escochinara": "escochinar",
    "escochinaram": "escochinar",
    "escochinaras": "escochinar",
    "escochinarde": "escochinar",
    "escochinardes": "escochinar",
    "escochinare": "escochinar",
    "escochinarei": "escochinar",
    "escochinareis": "escochinar",
    "escochinarem": "escochinar",
    "escochinaremos": "escochinar",
    "escochinares": "escochinar",
    "escochinaria": "escochinar",
    "escochinariam": "escochinar",
    "escochinarias": "escochinar",
    "escochinarmo": "escochinar",
    "escochinarmos": "escochinar",
    "escochinará": "escochinar",
    "escochinarás": "escochinar",
    "escochinarão": "escochinar",
    "escochinaríamos": "escochinar",
    "escochinaríeis": "escochinar",
    "escochinas": "escochinar",
    "escochinasse": "escochinar",
    "escochinassem": "escochinar",
    "escochinasses": "escochinar",
    "escochinaste": "escochinar",
    "escochinastes": "escochinar",
    "escochinava": "escochinar",
    "escochinavam": "escochinar",
    "escochinavas": "escochinar",
    "escochine": "escochinar",
    "escochinei": "escochinar",
    "escochineis": "escochinar",
    "escochinem": "escochinar",
    "escochinemo": "escochinar",
    "escochinemos": "escochinar",
    "escochines": "escochinar",
    "escochino": "escochinar",
    "escochinou": "escochinar",
    "escochiná": "escochinar",
    "escochinámo": "escochinar",
    "escochinámos": "escochinar",
    "escochináramo": "escochinar",
    "escochináramos": "escochinar",
    "escochinárei": "escochinar",
    "escochináreis": "escochinar",
    "escochinásseis": "escochinar",
    "escochinássemos": "escochinar",
    "escochinávamo": "escochinar",
    "escochinávamos": "escochinar",
    "escochinávei": "escochinar",
    "escochináveis": "escochinar",
    "escocho": "escochar",
    "escochou": "escochar",
    "escochá": "escochar",
    "escochámo": "escochar",
    "escochámos": "escochar",
    "escocháramo": "escochar",
    "escocháramos": "escochar",
    "escochárei": "escochar",
    "escocháreis": "escochar",
    "escochásseis": "escochar",
    "escochássemos": "escochar",
    "escochávamo": "escochar",
    "escochávamos": "escochar",
    "escochávei": "escochar",
    "escocháveis": "escochar",
    "escoco": "escocar",
    "escocou": "escocar",
    "escocá": "escocar",
    "escocámo": "escocar",
    "escocámos": "escocar",
    "escocáramo": "escocar",
    "escocáramos": "escocar",
    "escocárei": "escocar",
    "escocáreis": "escocar",
    "escocásseis": "escocar",
    "escocássemos": "escocar",
    "escocávamo": "escocar",
    "escocávamos": "escocar",
    "escocávei": "escocar",
    "escocáveis": "escocar",
    "escoda": "escodar",
    "escodada": "escodar",
    "escodadas": "escodar",
    "escodado": "escodar",
    "escodados": "escodar",
    "escodai": "escodar",
    "escodais": "escodar",
    "escodam": "escodar",
    "escodamo": "escodar",
    "escodamos": "escodar",
    "escodando": "escodar",
    "escodara": "escodar",
    "escodaram": "escodar",
    "escodaras": "escodar",
    "escodarde": "escodar",
    "escodardes": "escodar",
    "escodare": "escodar",
    "escodarei": "escodar",
    "escodareis": "escodar",
    "escodarem": "escodar",
    "escodaremos": "escodar",
    "escodares": "escodar",
    "escodaria": "escodar",
    "escodariam": "escodar",
    "escodarias": "escodar",
    "escodarmo": "escodar",
    "escodarmos": "escodar",
    "escodará": "escodar",
    "escodarás": "escodar",
    "escodarão": "escodar",
    "escodaríamos": "escodar",
    "escodaríeis": "escodar",
    "escodas": "escodar",
    "escodasse": "escodar",
    "escodassem": "escodar",
    "escodasses": "escodar",
    "escodaste": "escodar",
    "escodastes": "escodar",
    "escodava": "escodar",
    "escodavam": "escodar",
    "escodavas": "escodar",
    "escode": "escodar",
    "escodeada": "escodear",
    "escodeadas": "escodear",
    "escodeado": "escodear",
    "escodeados": "escodear",
    "escodeai": "escodear",
    "escodeais": "escodear",
    "escodeamo": "escodear",
    "escodeamos": "escodear",
    "escodeando": "escodear",
    "escodeara": "escodear",
    "escodearam": "escodear",
    "escodearas": "escodear",
    "escodearde": "escodear",
    "escodeardes": "escodear",
    "escodeare": "escodear",
    "escodearei": "escodear",
    "escodeareis": "escodear",
    "escodearem": "escodear",
    "escodearemos": "escodear",
    "escodeares": "escodear",
    "escodearia": "escodear",
    "escodeariam": "escodear",
    "escodearias": "escodear",
    "escodearmo": "escodear",
    "escodearmos": "escodear",
    "escodeará": "escodear",
    "escodearás": "escodear",
    "escodearão": "escodear",
    "escodearíamos": "escodear",
    "escodearíeis": "escodear",
    "escodeasse": "escodear",
    "escodeassem": "escodear",
    "escodeasses": "escodear",
    "escodeaste": "escodear",
    "escodeastes": "escodear",
    "escodeava": "escodear",
    "escodeavam": "escodear",
    "escodeavas": "escodear",
    "escodeei": "escodear",
    "escodeeis": "escodear",
    "escodeemo": "escodear",
    "escodeemos": "escodear",
    "escodei": "escodar",
    "escodeia": "escodear",
    "escodeiam": "escodear",
    "escodeias": "escodear",
    "escodeie": "escodear",
    "escodeiem": "escodear",
    "escodeies": "escodear",
    "escodeio": "escodear",
    "escodeis": "escodar",
    "escodem": "escodar",
    "escodemo": "escodar",
    "escodemos": "escodar",
    "escodeou": "escodear",
    "escodes": "escodar",
    "escodeá": "escodear",
    "escodeámo": "escodear",
    "escodeámos": "escodear",
    "escodeáramo": "escodear",
    "escodeáramos": "escodear",
    "escodeárei": "escodear",
    "escodeáreis": "escodear",
    "escodeásseis": "escodear",
    "escodeássemos": "escodear",
    "escodeávamo": "escodear",
    "escodeávamos": "escodear",
    "escodeávei": "escodear",
    "escodeáveis": "escodear",
    "escodo": "escodar",
    "escodou": "escodar",
    "escodá": "escodar",
    "escodámo": "escodar",
    "escodámos": "escodar",
    "escodáramo": "escodar",
    "escodáramos": "escodar",
    "escodárei": "escodar",
    "escodáreis": "escodar",
    "escodásseis": "escodar",
    "escodássemos": "escodar",
    "escodávamo": "escodar",
    "escodávamos": "escodar",
    "escodávei": "escodar",
    "escodáveis": "escodar",
    "escoe": "escoar",
    "escoei": "escoar",
    "escoeis": "escoar",
    "escoem": "escoar",
    "escoemo": "escoar",
    "escoemos": "escoar",
    "escoes": "escoar",
    "escoice": "escoiçar",
    "escoiceada": "escoicear",
    "escoiceadas": "escoicear",
    "escoiceado": "escoicear",
    "escoiceados": "escoicear",
    "escoiceai": "escoicear",
    "escoiceais": "escoicear",
    "escoiceamo": "escoicear",
    "escoiceamos": "escoicear",
    "escoiceando": "escoicear",
    "escoiceara": "escoicear",
    "escoicearam": "escoicear",
    "escoicearas": "escoicear",
    "escoicearde": "escoicear",
    "escoiceardes": "escoicear",
    "escoiceare": "escoicear",
    "escoicearei": "escoicear",
    "escoiceareis": "escoicear",
    "escoicearem": "escoicear",
    "escoicearemos": "escoicear",
    "escoiceares": "escoicear",
    "escoicearia": "escoicear",
    "escoiceariam": "escoicear",
    "escoicearias": "escoicear",
    "escoicearmo": "escoicear",
    "escoicearmos": "escoicear",
    "escoiceará": "escoicear",
    "escoicearás": "escoicear",
    "escoicearão": "escoicear",
    "escoicearíamos": "escoicear",
    "escoicearíeis": "escoicear",
    "escoiceasse": "escoicear",
    "escoiceassem": "escoicear",
    "escoiceasses": "escoicear",
    "escoiceaste": "escoicear",
    "escoiceastes": "escoicear",
    "escoiceava": "escoicear",
    "escoiceavam": "escoicear",
    "escoiceavas": "escoicear",
    "escoiceei": "escoicear",
    "escoiceeis": "escoicear",
    "escoiceemo": "escoicear",
    "escoiceemos": "escoicear",
    "escoicei": "escoiçar",
    "escoiceia": "escoicear",
    "escoiceiam": "escoicear",
    "escoiceias": "escoicear",
    "escoiceie": "escoicear",
    "escoiceiem": "escoicear",
    "escoiceies": "escoicear",
    "escoiceio": "escoicear",
    "escoiceis": "escoiçar",
    "escoicem": "escoiçar",
    "escoicemo": "escoiçar",
    "escoicemos": "escoiçar",
    "escoiceou": "escoicear",
    "escoices": "escoiçar",
    "escoiceá": "escoicear",
    "escoiceámo": "escoicear",
    "escoiceámos": "escoicear",
    "escoiceáramo": "escoicear",
    "escoiceáramos": "escoicear",
    "escoiceárei": "escoicear",
    "escoiceáreis": "escoicear",
    "escoiceásseis": "escoicear",
    "escoiceássemos": "escoicear",
    "escoiceávamo": "escoicear",
    "escoiceávamos": "escoicear",
    "escoiceávei": "escoicear",
    "escoiceáveis": "escoicear",
    "escoicinha": "escoicinhar",
    "escoicinhada": "escoicinhar",
    "escoicinhadas": "escoicinhar",
    "escoicinhado": "escoicinhar",
    "escoicinhadora": "escoicinhador",
    "escoicinhadoras": "escoicinhador",
    "escoicinhadores": "escoicinhador",
    "escoicinhados": "escoicinhar",
    "escoicinhai": "escoicinhar",
    "escoicinhais": "escoicinhar",
    "escoicinham": "escoicinhar",
    "escoicinhamo": "escoicinhar",
    "escoicinhamos": "escoicinhar",
    "escoicinhando": "escoicinhar",
    "escoicinhara": "escoicinhar",
    "escoicinharam": "escoicinhar",
    "escoicinharas": "escoicinhar",
    "escoicinharde": "escoicinhar",
    "escoicinhardes": "escoicinhar",
    "escoicinhare": "escoicinhar",
    "escoicinharei": "escoicinhar",
    "escoicinhareis": "escoicinhar",
    "escoicinharem": "escoicinhar",
    "escoicinharemos": "escoicinhar",
    "escoicinhares": "escoicinhar",
    "escoicinharia": "escoicinhar",
    "escoicinhariam": "escoicinhar",
    "escoicinharias": "escoicinhar",
    "escoicinharmo": "escoicinhar",
    "escoicinharmos": "escoicinhar",
    "escoicinhará": "escoicinhar",
    "escoicinharás": "escoicinhar",
    "escoicinharão": "escoicinhar",
    "escoicinharíamos": "escoicinhar",
    "escoicinharíeis": "escoicinhar",
    "escoicinhas": "escoicinhar",
    "escoicinhasse": "escoicinhar",
    "escoicinhassem": "escoicinhar",
    "escoicinhasses": "escoicinhar",
    "escoicinhaste": "escoicinhar",
    "escoicinhastes": "escoicinhar",
    "escoicinhava": "escoicinhar",
    "escoicinhavam": "escoicinhar",
    "escoicinhavas": "escoicinhar",
    "escoicinhe": "escoicinhar",
    "escoicinhei": "escoicinhar",
    "escoicinheis": "escoicinhar",
    "escoicinhem": "escoicinhar",
    "escoicinhemo": "escoicinhar",
    "escoicinhemos": "escoicinhar",
    "escoicinhes": "escoicinhar",
    "escoicinho": "escoicinhar",
    "escoicinhou": "escoicinhar",
    "escoicinhá": "escoicinhar",
    "escoicinhámo": "escoicinhar",
    "escoicinhámos": "escoicinhar",
    "escoicinháramo": "escoicinhar",
    "escoicinháramos": "escoicinhar",
    "escoicinhárei": "escoicinhar",
    "escoicinháreis": "escoicinhar",
    "escoicinhásseis": "escoicinhar",
    "escoicinhássemos": "escoicinhar",
    "escoicinhávamo": "escoicinhar",
    "escoicinhávamos": "escoicinhar",
    "escoicinhávei": "escoicinhar",
    "escoicinháveis": "escoicinhar",
    "escoima": "escoimar",
    "escoimada": "escoimar",
    "escoimadas": "escoimar",
    "escoimado": "escoimar",
    "escoimados": "escoimar",
    "escoimai": "escoimar",
    "escoimais": "escoimar",
    "escoimam": "escoimar",
    "escoimamo": "escoimar",
    "escoimamos": "escoimar",
    "escoimando": "escoimar",
    "escoimara": "escoimar",
    "escoimaram": "escoimar",
    "escoimaras": "escoimar",
    "escoimarde": "escoimar",
    "escoimardes": "escoimar",
    "escoimare": "escoimar",
    "escoimarei": "escoimar",
    "escoimareis": "escoimar",
    "escoimarem": "escoimar",
    "escoimaremos": "escoimar",
    "escoimares": "escoimar",
    "escoimaria": "escoimar",
    "escoimariam": "escoimar",
    "escoimarias": "escoimar",
    "escoimarmo": "escoimar",
    "escoimarmos": "escoimar",
    "escoimará": "escoimar",
    "escoimarás": "escoimar",
    "escoimarão": "escoimar",
    "escoimaríamos": "escoimar",
    "escoimaríeis": "escoimar",
    "escoimas": "escoimar",
    "escoimasse": "escoimar",
    "escoimassem": "escoimar",
    "escoimasses": "escoimar",
    "escoimaste": "escoimar",
    "escoimastes": "escoimar",
    "escoimava": "escoimar",
    "escoimavam": "escoimar",
    "escoimavas": "escoimar",
    "escoime": "escoimar",
    "escoimei": "escoimar",
    "escoimeis": "escoimar",
    "escoimem": "escoimar",
    "escoimemo": "escoimar",
    "escoimemos": "escoimar",
    "escoimes": "escoimar",
    "escoimo": "escoimar",
    "escoimou": "escoimar",
    "escoimá": "escoimar",
    "escoimámo": "escoimar",
    "escoimámos": "escoimar",
    "escoimáramo": "escoimar",
    "escoimáramos": "escoimar",
    "escoimárei": "escoimar",
    "escoimáreis": "escoimar",
    "escoimásseis": "escoimar",
    "escoimássemos": "escoimar",
    "escoimávamo": "escoimar",
    "escoimávamos": "escoimar",
    "escoimávei": "escoimar",
    "escoimáveis": "escoimar",
    "escoirais": "escoiral",
    "escoiras": "escoira",
    "escoiça": "escoiçar",
    "escoiçada": "escoiçar",
    "escoiçadas": "escoiçar",
    "escoiçado": "escoiçar",
    "escoiçados": "escoiçar",
    "escoiçai": "escoiçar",
    "escoiçais": "escoiçar",
    "escoiçam": "escoiçar",
    "escoiçamo": "escoiçar",
    "escoiçamos": "escoiçar",
    "escoiçando": "escoiçar",
    "escoiçara": "escoiçar",
    "escoiçaram": "escoiçar",
    "escoiçaras": "escoiçar",
    "escoiçarde": "escoiçar",
    "escoiçardes": "escoiçar",
    "escoiçare": "escoiçar",
    "escoiçarei": "escoiçar",
    "escoiçareis": "escoiçar",
    "escoiçarem": "escoiçar",
    "escoiçaremos": "escoiçar",
    "escoiçares": "escoiçar",
    "escoiçaria": "escoiçar",
    "escoiçariam": "escoiçar",
    "escoiçarias": "escoiçar",
    "escoiçarmo": "escoiçar",
    "escoiçarmos": "escoiçar",
    "escoiçará": "escoiçar",
    "escoiçarás": "escoiçar",
    "escoiçarão": "escoiçar",
    "escoiçaríamos": "escoiçar",
    "escoiçaríeis": "escoiçar",
    "escoiças": "escoiçar",
    "escoiçasse": "escoiçar",
    "escoiçassem": "escoiçar",
    "escoiçasses": "escoiçar",
    "escoiçaste": "escoiçar",
    "escoiçastes": "escoiçar",
    "escoiçava": "escoiçar",
    "escoiçavam": "escoiçar",
    "escoiçavas": "escoiçar",
    "escoiço": "escoiçar",
    "escoiçou": "escoiçar",
    "escoiçá": "escoiçar",
    "escoiçámo": "escoiçar",
    "escoiçámos": "escoiçar",
    "escoiçáramo": "escoiçar",
    "escoiçáramos": "escoiçar",
    "escoiçárei": "escoiçar",
    "escoiçáreis": "escoiçar",
    "escoiçásseis": "escoiçar",
    "escoiçássemos": "escoiçar",
    "escoiçávamo": "escoiçar",
    "escoiçávamos": "escoiçar",
    "escoiçávei": "escoiçar",
    "escoiçáveis": "escoiçar",
    "escolares": "escolar",
    "escolaridades": "escolaridade",
    "escolariza": "escolarizar",
    "escolarizada": "escolarizar",
    "escolarizadas": "escolarizar",
    "escolarizado": "escolarizar",
    "escolarizados": "escolarizar",
    "escolarizai": "escolarizar",
    "escolarizais": "escolarizar",
    "escolarizam": "escolarizar",
    "escolarizamo": "escolarizar",
    "escolarizamos": "escolarizar",
    "escolarizando": "escolarizar",
    "escolarizara": "escolarizar",
    "escolarizaram": "escolarizar",
    "escolarizaras": "escolarizar",
    "escolarizarde": "escolarizar",
    "escolarizardes": "escolarizar",
    "escolarizare": "escolarizar",
    "escolarizarei": "escolarizar",
    "escolarizareis": "escolarizar",
    "escolarizarem": "escolarizar",
    "escolarizaremos": "escolarizar",
    "escolarizares": "escolarizar",
    "escolarizaria": "escolarizar",
    "escolarizariam": "escolarizar",
    "escolarizarias": "escolarizar",
    "escolarizarmo": "escolarizar",
    "escolarizarmos": "escolarizar",
    "escolarizará": "escolarizar",
    "escolarizarás": "escolarizar",
    "escolarizarão": "escolarizar",
    "escolarizaríamos": "escolarizar",
    "escolarizaríeis": "escolarizar",
    "escolarizas": "escolarizar",
    "escolarizasse": "escolarizar",
    "escolarizassem": "escolarizar",
    "escolarizasses": "escolarizar",
    "escolarizaste": "escolarizar",
    "escolarizastes": "escolarizar",
    "escolarizava": "escolarizar",
    "escolarizavam": "escolarizar",
    "escolarizavas": "escolarizar",
    "escolarizações": "escolarização",
    "escolarize": "escolarizar",
    "escolarizei": "escolarizar",
    "escolarizeis": "escolarizar",
    "escolarizem": "escolarizar",
    "escolarizemo": "escolarizar",
    "escolarizemos": "escolarizar",
    "escolarizes": "escolarizar",
    "escolarizo": "escolarizar",
    "escolarizou": "escolarizar",
    "escolarizá": "escolarizar",
    "escolarizámo": "escolarizar",
    "escolarizámos": "escolarizar",
    "escolarizáramo": "escolarizar",
    "escolarizáramos": "escolarizar",
    "escolarizárei": "escolarizar",
    "escolarizáreis": "escolarizar",
    "escolarizásseis": "escolarizar",
    "escolarizássemos": "escolarizar",
    "escolarizávamo": "escolarizar",
    "escolarizávamos": "escolarizar",
    "escolarizávei": "escolarizar",
    "escolarizáveis": "escolarizar",
    "escolas": "escola",
    "escolasticismos": "escolasticismo",
    "escolha": "escolher",
    "escolhais": "escolher",
    "escolham": "escolher",
    "escolhamo": "escolher",
    "escolhamos": "escolher",
    "escolhas": "escolher",
    "escolhe": "escolher",
    "escolhedeiras": "escolhedeira",
    "escolhei": "escolher",
    "escolheis": "escolher",
    "escolheita": "escolheito",
    "escolheitas": "escolheito",
    "escolheitos": "escolheito",
    "escolhem": "escolher",
    "escolhemo": "escolher",
    "escolhemos": "escolher",
    "escolhendo": "escolher",
    "escolhera": "escolher",
    "escolheram": "escolher",
    "escolheras": "escolher",
    "escolherde": "escolher",
    "escolherdes": "escolher",
    "escolhere": "escolher",
    "escolherei": "escolher",
    "escolhereis": "escolher",
    "escolherem": "escolher",
    "escolheremos": "escolher",
    "escolheres": "escolher",
    "escolheria": "escolher",
    "escolheriam": "escolher",
    "escolherias": "escolher",
    "escolhermo": "escolher",
    "escolhermos": "escolher",
    "escolherá": "escolher",
    "escolherás": "escolher",
    "escolherão": "escolher",
    "escolheríamos": "escolher",
    "escolheríeis": "escolher",
    "escolhes": "escolher",
    "escolhesse": "escolher",
    "escolhessem": "escolher",
    "escolhesses": "escolher",
    "escolheste": "escolher",
    "escolhestes": "escolher",
    "escolheu": "escolher",
    "escolhi": "escolher",
    "escolhia": "escolher",
    "escolhiam": "escolher",
    "escolhias": "escolher",
    "escolhida": "escolhido",
    "escolhidas": "escolhido",
    "escolhido": "escolher",
    "escolhidos": "escolhido",
    "escolhimentos": "escolhimento",
    "escolho": "escolher",
    "escolhos": "escolho",
    "escolhê": "escolher",
    "escolhêramo": "escolher",
    "escolhêramos": "escolher",
    "escolhêrei": "escolher",
    "escolhêreis": "escolher",
    "escolhêsseis": "escolher",
    "escolhêssemos": "escolher",
    "escolhíamo": "escolher",
    "escolhíamos": "escolher",
    "escolhíei": "escolher",
    "escolhíeis": "escolher",
    "escoliastas": "escoliasta",
    "escolinha": "escola",
    "escolinhas": "escola",
    "escolioses": "escoliose",
    "escolita": "escola",
    "escolitas": "escola",
    "escoliótica": "escoliótico",
    "escolióticas": "escoliótico",
    "escolióticos": "escoliótico",
    "escolma": "escolmar",
    "escolmada": "escolmar",
    "escolmadas": "escolmar",
    "escolmado": "escolmar",
    "escolmados": "escolmar",
    "escolmai": "escolmar",
    "escolmais": "escolmar",
    "escolmam": "escolmar",
    "escolmamo": "escolmar",
    "escolmamos": "escolmar",
    "escolmando": "escolmar",
    "escolmara": "escolmar",
    "escolmaram": "escolmar",
    "escolmaras": "escolmar",
    "escolmarde": "escolmar",
    "escolmardes": "escolmar",
    "escolmare": "escolmar",
    "escolmarei": "escolmar",
    "escolmareis": "escolmar",
    "escolmarem": "escolmar",
    "escolmaremos": "escolmar",
    "escolmares": "escolmar",
    "escolmaria": "escolmar",
    "escolmariam": "escolmar",
    "escolmarias": "escolmar",
    "escolmarmo": "escolmar",
    "escolmarmos": "escolmar",
    "escolmará": "escolmar",
    "escolmarás": "escolmar",
    "escolmarão": "escolmar",
    "escolmaríamos": "escolmar",
    "escolmaríeis": "escolmar",
    "escolmas": "escolmar",
    "escolmasse": "escolmar",
    "escolmassem": "escolmar",
    "escolmasses": "escolmar",
    "escolmaste": "escolmar",
    "escolmastes": "escolmar",
    "escolmava": "escolmar",
    "escolmavam": "escolmar",
    "escolmavas": "escolmar",
    "escolme": "escolmar",
    "escolmei": "escolmar",
    "escolmeis": "escolmar",
    "escolmem": "escolmar",
    "escolmemo": "escolmar",
    "escolmemos": "escolmar",
    "escolmes": "escolmar",
    "escolmo": "escolmar",
    "escolmou": "escolmar",
    "escolmá": "escolmar",
    "escolmámo": "escolmar",
    "escolmámos": "escolmar",
    "escolmáramo": "escolmar",
    "escolmáramos": "escolmar",
    "escolmárei": "escolmar",
    "escolmáreis": "escolmar",
    "escolmásseis": "escolmar",
    "escolmássemos": "escolmar",
    "escolmávamo": "escolmar",
    "escolmávamos": "escolmar",
    "escolmávei": "escolmar",
    "escolmáveis": "escolmar",
    "escolopendras": "escolopendra",
    "escolta": "escoltar",
    "escoltada": "escoltar",
    "escoltadas": "escoltar",
    "escoltado": "escoltar",
    "escoltados": "escoltar",
    "escoltai": "escoltar",
    "escoltais": "escoltar",
    "escoltam": "escoltar",
    "escoltamo": "escoltar",
    "escoltamos": "escoltar",
    "escoltando": "escoltar",
    "escoltara": "escoltar",
    "escoltaram": "escoltar",
    "escoltaras": "escoltar",
    "escoltarde": "escoltar",
    "escoltardes": "escoltar",
    "escoltare": "escoltar",
    "escoltarei": "escoltar",
    "escoltareis": "escoltar",
    "escoltarem": "escoltar",
    "escoltaremos": "escoltar",
    "escoltares": "escoltar",
    "escoltaria": "escoltar",
    "escoltariam": "escoltar",
    "escoltarias": "escoltar",
    "escoltarmo": "escoltar",
    "escoltarmos": "escoltar",
    "escoltará": "escoltar",
    "escoltarás": "escoltar",
    "escoltarão": "escoltar",
    "escoltaríamos": "escoltar",
    "escoltaríeis": "escoltar",
    "escoltas": "escoltar",
    "escoltasse": "escoltar",
    "escoltassem": "escoltar",
    "escoltasses": "escoltar",
    "escoltaste": "escoltar",
    "escoltastes": "escoltar",
    "escoltava": "escoltar",
    "escoltavam": "escoltar",
    "escoltavas": "escoltar",
    "escolte": "escoltar",
    "escoltei": "escoltar",
    "escolteis": "escoltar",
    "escoltem": "escoltar",
    "escoltemo": "escoltar",
    "escoltemos": "escoltar",
    "escoltes": "escoltar",
    "escolto": "escoltar",
    "escoltou": "escoltar",
    "escoltá": "escoltar",
    "escoltámo": "escoltar",
    "escoltámos": "escoltar",
    "escoltáramo": "escoltar",
    "escoltáramos": "escoltar",
    "escoltárei": "escoltar",
    "escoltáreis": "escoltar",
    "escoltásseis": "escoltar",
    "escoltássemos": "escoltar",
    "escoltávamo": "escoltar",
    "escoltávamos": "escoltar",
    "escoltávei": "escoltar",
    "escoltáveis": "escoltar",
    "escolástica": "escolástico",
    "escolásticas": "escolástico",
    "escolásticos": "escolástico",
    "escombra": "escombrar",
    "escombrada": "escombrar",
    "escombradas": "escombrar",
    "escombrado": "escombrar",
    "escombrados": "escombrar",
    "escombrai": "escombrar",
    "escombrais": "escombrar",
    "escombram": "escombrar",
    "escombramo": "escombrar",
    "escombramos": "escombrar",
    "escombrando": "escombrar",
    "escombrara": "escombrar",
    "escombraram": "escombrar",
    "escombraras": "escombrar",
    "escombrarde": "escombrar",
    "escombrardes": "escombrar",
    "escombrare": "escombrar",
    "escombrarei": "escombrar",
    "escombrareis": "escombrar",
    "escombrarem": "escombrar",
    "escombraremos": "escombrar",
    "escombrares": "escombrar",
    "escombraria": "escombrar",
    "escombrariam": "escombrar",
    "escombrarias": "escombrar",
    "escombrarmo": "escombrar",
    "escombrarmos": "escombrar",
    "escombrará": "escombrar",
    "escombrarás": "escombrar",
    "escombrarão": "escombrar",
    "escombraríamos": "escombrar",
    "escombraríeis": "escombrar",
    "escombras": "escombrar",
    "escombrasse": "escombrar",
    "escombrassem": "escombrar",
    "escombrasses": "escombrar",
    "escombraste": "escombrar",
    "escombrastes": "escombrar",
    "escombrava": "escombrar",
    "escombravam": "escombrar",
    "escombravas": "escombrar",
    "escombre": "escombrar",
    "escombrei": "escombrar",
    "escombreis": "escombrar",
    "escombrem": "escombrar",
    "escombremo": "escombrar",
    "escombremos": "escombrar",
    "escombres": "escombrar",
    "escombriformes": "escombriforme",
    "escombro": "escombrar",
    "escombros": "escombro",
    "escombrou": "escombrar",
    "escombrá": "escombrar",
    "escombrámo": "escombrar",
    "escombrámos": "escombrar",
    "escombráramo": "escombrar",
    "escombráramos": "escombrar",
    "escombrárei": "escombrar",
    "escombráreis": "escombrar",
    "escombrásseis": "escombrar",
    "escombrássemos": "escombrar",
    "escombrávamo": "escombrar",
    "escombrávamos": "escombrar",
    "escombrávei": "escombrar",
    "escombráveis": "escombrar",
    "escombrídea": "escombrídeo",
    "escombrídeas": "escombrídeo",
    "escombrídeos": "escombrídeo",
    "esconda": "esconder",
    "escondais": "esconder",
    "escondam": "esconder",
    "escondamo": "esconder",
    "escondamos": "esconder",
    "escondas": "esconder",
    "esconde": "esconder",
    "escondedoiros": "escondedoiro",
    "escondedora": "escondedor",
    "escondedoras": "escondedor",
    "escondedores": "escondedor",
    "escondedouros": "escondedouro",
    "escondeduras": "escondedura",
    "escondei": "esconder",
    "escondeis": "esconder",
    "escondem": "esconder",
    "escondemo": "esconder",
    "escondemos": "esconder",
    "escondendo": "esconder",
    "escondera": "esconder",
    "esconderam": "esconder",
    "esconderas": "esconder",
    "esconderde": "esconder",
    "esconderdes": "esconder",
    "escondere": "esconder",
    "esconderei": "esconder",
    "escondereis": "esconder",
    "esconderem": "esconder",
    "esconderemos": "esconder",
    "esconderes": "esconder",
    "esconderia": "esconder",
    "esconderiam": "esconder",
    "esconderias": "esconder",
    "esconderijeiras": "esconderijeira",
    "esconderijos": "esconderijo",
    "esconderilhos": "esconderilho",
    "escondermo": "esconder",
    "escondermos": "esconder",
    "esconderá": "esconder",
    "esconderás": "esconder",
    "esconderão": "esconder",
    "esconderíamos": "esconder",
    "esconderíeis": "esconder",
    "escondes": "esconder",
    "escondesse": "esconder",
    "escondessem": "esconder",
    "escondesses": "esconder",
    "escondeste": "esconder",
    "escondestes": "esconder",
    "escondeu": "esconder",
    "escondi": "esconder",
    "escondia": "esconder",
    "escondiam": "esconder",
    "escondias": "esconder",
    "escondida": "escondido",
    "escondidas": "escondido",
    "escondidinha": "escondido",
    "escondidinhas": "escondido",
    "escondidinho": "escondido",
    "escondidinhos": "escondido",
    "escondidita": "escondido",
    "escondiditas": "escondido",
    "escondidito": "escondido",
    "escondiditos": "escondido",
    "escondido": "esconder",
    "escondidos": "escondido",
    "escondidíssima": "escondido",
    "escondidíssimas": "escondido",
    "escondidíssimo": "escondido",
    "escondidíssimos": "escondido",
    "escondimentos": "escondimento",
    "escondo": "esconder",
    "escondê": "esconder",
    "escondêramo": "esconder",
    "escondêramos": "esconder",
    "escondêrei": "esconder",
    "escondêreis": "esconder",
    "escondêsseis": "esconder",
    "escondêssemos": "esconder",
    "escondíamo": "esconder",
    "escondíamos": "esconder",
    "escondíei": "esconder",
    "escondíeis": "esconder",
    "esconjunta": "esconjuntar",
    "esconjuntada": "esconjuntar",
    "esconjuntadas": "esconjuntar",
    "esconjuntado": "esconjuntar",
    "esconjuntados": "esconjuntar",
    "esconjuntai": "esconjuntar",
    "esconjuntais": "esconjuntar",
    "esconjuntam": "esconjuntar",
    "esconjuntamo": "esconjuntar",
    "esconjuntamos": "esconjuntar",
    "esconjuntando": "esconjuntar",
    "esconjuntara": "esconjuntar",
    "esconjuntaram": "esconjuntar",
    "esconjuntaras": "esconjuntar",
    "esconjuntarde": "esconjuntar",
    "esconjuntardes": "esconjuntar",
    "esconjuntare": "esconjuntar",
    "esconjuntarei": "esconjuntar",
    "esconjuntareis": "esconjuntar",
    "esconjuntarem": "esconjuntar",
    "esconjuntaremos": "esconjuntar",
    "esconjuntares": "esconjuntar",
    "esconjuntaria": "esconjuntar",
    "esconjuntariam": "esconjuntar",
    "esconjuntarias": "esconjuntar",
    "esconjuntarmo": "esconjuntar",
    "esconjuntarmos": "esconjuntar",
    "esconjuntará": "esconjuntar",
    "esconjuntarás": "esconjuntar",
    "esconjuntarão": "esconjuntar",
    "esconjuntaríamos": "esconjuntar",
    "esconjuntaríeis": "esconjuntar",
    "esconjuntas": "esconjuntar",
    "esconjuntasse": "esconjuntar",
    "esconjuntassem": "esconjuntar",
    "esconjuntasses": "esconjuntar",
    "esconjuntaste": "esconjuntar",
    "esconjuntastes": "esconjuntar",
    "esconjuntava": "esconjuntar",
    "esconjuntavam": "esconjuntar",
    "esconjuntavas": "esconjuntar",
    "esconjunte": "esconjuntar",
    "esconjuntei": "esconjuntar",
    "esconjunteis": "esconjuntar",
    "esconjuntem": "esconjuntar",
    "esconjuntemo": "esconjuntar",
    "esconjuntemos": "esconjuntar",
    "esconjuntes": "esconjuntar",
    "esconjunto": "esconjuntar",
    "esconjuntou": "esconjuntar",
    "esconjuntá": "esconjuntar",
    "esconjuntámo": "esconjuntar",
    "esconjuntámos": "esconjuntar",
    "esconjuntáramo": "esconjuntar",
    "esconjuntáramos": "esconjuntar",
    "esconjuntárei": "esconjuntar",
    "esconjuntáreis": "esconjuntar",
    "esconjuntásseis": "esconjuntar",
    "esconjuntássemos": "esconjuntar",
    "esconjuntávamo": "esconjuntar",
    "esconjuntávamos": "esconjuntar",
    "esconjuntávei": "esconjuntar",
    "esconjuntáveis": "esconjuntar",
    "esconjura": "esconjurar",
    "esconjurada": "esconjurar",
    "esconjuradas": "esconjurar",
    "esconjurado": "esconjurar",
    "esconjuradora": "esconjurador",
    "esconjuradoras": "esconjurador",
    "esconjuradores": "esconjurador",
    "esconjurados": "esconjurar",
    "esconjurai": "esconjurar",
    "esconjurais": "esconjurar",
    "esconjuram": "esconjurar",
    "esconjuramo": "esconjurar",
    "esconjuramos": "esconjurar",
    "esconjurando": "esconjurar",
    "esconjurara": "esconjurar",
    "esconjuraram": "esconjurar",
    "esconjuraras": "esconjurar",
    "esconjurarde": "esconjurar",
    "esconjurardes": "esconjurar",
    "esconjurare": "esconjurar",
    "esconjurarei": "esconjurar",
    "esconjurareis": "esconjurar",
    "esconjurarem": "esconjurar",
    "esconjuraremos": "esconjurar",
    "esconjurares": "esconjurar",
    "esconjuraria": "esconjurar",
    "esconjurariam": "esconjurar",
    "esconjurarias": "esconjurar",
    "esconjurarmo": "esconjurar",
    "esconjurarmos": "esconjurar",
    "esconjurará": "esconjurar",
    "esconjurarás": "esconjurar",
    "esconjurarão": "esconjurar",
    "esconjuraríamos": "esconjurar",
    "esconjuraríeis": "esconjurar",
    "esconjuras": "esconjurar",
    "esconjurasse": "esconjurar",
    "esconjurassem": "esconjurar",
    "esconjurasses": "esconjurar",
    "esconjuraste": "esconjurar",
    "esconjurastes": "esconjurar",
    "esconjurava": "esconjurar",
    "esconjuravam": "esconjurar",
    "esconjuravas": "esconjurar",
    "esconjurações": "esconjuração",
    "esconjure": "esconjurar",
    "esconjurei": "esconjurar",
    "esconjureis": "esconjurar",
    "esconjurem": "esconjurar",
    "esconjuremo": "esconjurar",
    "esconjuremos": "esconjurar",
    "esconjures": "esconjurar",
    "esconjuro": "esconjurar",
    "esconjuros": "esconjuro",
    "esconjurou": "esconjurar",
    "esconjurá": "esconjurar",
    "esconjurámo": "esconjurar",
    "esconjurámos": "esconjurar",
    "esconjuráramo": "esconjurar",
    "esconjuráramos": "esconjurar",
    "esconjurárei": "esconjurar",
    "esconjuráreis": "esconjurar",
    "esconjurásseis": "esconjurar",
    "esconjurássemos": "esconjurar",
    "esconjurávamo": "esconjurar",
    "esconjurávamos": "esconjurar",
    "esconjurávei": "esconjurar",
    "esconjuráveis": "esconjurável",
    "esconsa": "esconsar",
    "esconsada": "esconsar",
    "esconsadas": "esconsar",
    "esconsado": "esconsar",
    "esconsados": "esconsar",
    "esconsai": "esconsar",
    "esconsais": "esconsar",
    "esconsam": "esconsar",
    "esconsamo": "esconsar",
    "esconsamos": "esconsar",
    "esconsando": "esconsar",
    "esconsara": "esconsar",
    "esconsaram": "esconsar",
    "esconsaras": "esconsar",
    "esconsarde": "esconsar",
    "esconsardes": "esconsar",
    "esconsare": "esconsar",
    "esconsarei": "esconsar",
    "esconsareis": "esconsar",
    "esconsarem": "esconsar",
    "esconsaremos": "esconsar",
    "esconsares": "esconsar",
    "esconsaria": "esconsar",
    "esconsariam": "esconsar",
    "esconsarias": "esconsar",
    "esconsarmo": "esconsar",
    "esconsarmos": "esconsar",
    "esconsará": "esconsar",
    "esconsarás": "esconsar",
    "esconsarão": "esconsar",
    "esconsaríamos": "esconsar",
    "esconsaríeis": "esconsar",
    "esconsas": "esconsar",
    "esconsasse": "esconsar",
    "esconsassem": "esconsar",
    "esconsasses": "esconsar",
    "esconsaste": "esconsar",
    "esconsastes": "esconsar",
    "esconsava": "esconsar",
    "esconsavam": "esconsar",
    "esconsavas": "esconsar",
    "esconse": "esconsar",
    "esconsei": "esconsar",
    "esconseis": "esconsar",
    "esconsem": "esconsar",
    "esconsemo": "esconsar",
    "esconsemos": "esconsar",
    "esconses": "esconsar",
    "esconso": "esconsar",
    "esconsos": "esconso",
    "esconsou": "esconsar",
    "esconsá": "esconsar",
    "esconsámo": "esconsar",
    "esconsámos": "esconsar",
    "esconsáramo": "esconsar",
    "esconsáramos": "esconsar",
    "esconsárei": "esconsar",
    "esconsáreis": "esconsar",
    "esconsásseis": "esconsar",
    "esconsássemos": "esconsar",
    "esconsávamo": "esconsar",
    "esconsávamos": "esconsar",
    "esconsávei": "esconsar",
    "esconsáveis": "esconsar",
    "escoo": "escoar",
    "escoou": "escoar",
    "escope": "escupir",
    "escopeiros": "escopeiro",
    "escopelismos": "escopelismo",
    "escopem": "escupir",
    "escopes": "escupir",
    "escopetarias": "escopetaria",
    "escopetas": "escopeta",
    "escopeteada": "escopetear",
    "escopeteadas": "escopetear",
    "escopeteado": "escopetear",
    "escopeteados": "escopetear",
    "escopeteai": "escopetear",
    "escopeteais": "escopetear",
    "escopeteamo": "escopetear",
    "escopeteamos": "escopetear",
    "escopeteando": "escopetear",
    "escopeteara": "escopetear",
    "escopetearam": "escopetear",
    "escopetearas": "escopetear",
    "escopetearde": "escopetear",
    "escopeteardes": "escopetear",
    "escopeteare": "escopetear",
    "escopetearei": "escopetear",
    "escopeteareis": "escopetear",
    "escopetearem": "escopetear",
    "escopetearemos": "escopetear",
    "escopeteares": "escopetear",
    "escopetearia": "escopetear",
    "escopeteariam": "escopetear",
    "escopetearias": "escopetear",
    "escopetearmo": "escopetear",
    "escopetearmos": "escopetear",
    "escopeteará": "escopetear",
    "escopetearás": "escopetear",
    "escopetearão": "escopetear",
    "escopetearíamos": "escopetear",
    "escopetearíeis": "escopetear",
    "escopeteasse": "escopetear",
    "escopeteassem": "escopetear",
    "escopeteasses": "escopetear",
    "escopeteaste": "escopetear",
    "escopeteastes": "escopetear",
    "escopeteava": "escopetear",
    "escopeteavam": "escopetear",
    "escopeteavas": "escopetear",
    "escopeteei": "escopetear",
    "escopeteeis": "escopetear",
    "escopeteemo": "escopetear",
    "escopeteemos": "escopetear",
    "escopeteia": "escopetear",
    "escopeteiam": "escopetear",
    "escopeteias": "escopetear",
    "escopeteie": "escopetear",
    "escopeteiem": "escopetear",
    "escopeteies": "escopetear",
    "escopeteio": "escopetear",
    "escopeteiros": "escopeteiro",
    "escopeteou": "escopetear",
    "escopeteá": "escopetear",
    "escopeteámo": "escopetear",
    "escopeteámos": "escopetear",
    "escopeteáramo": "escopetear",
    "escopeteáramos": "escopetear",
    "escopeteárei": "escopetear",
    "escopeteáreis": "escopetear",
    "escopeteásseis": "escopetear",
    "escopeteássemos": "escopetear",
    "escopeteávamo": "escopetear",
    "escopeteávamos": "escopetear",
    "escopeteávei": "escopetear",
    "escopeteáveis": "escopetear",
    "escopolaminas": "escopolamina",
    "escopos": "escopo",
    "escopros": "escopro",
    "escoque": "escocar",
    "escoquei": "escocar",
    "escoqueis": "escocar",
    "escoquem": "escocar",
    "escoquemo": "escocar",
    "escoquemos": "escocar",
    "escoques": "escocar",
    "escora": "escorar",
    "escorada": "escorar",
    "escoradas": "escorar",
    "escorado": "escorar",
    "escorados": "escorar",
    "escorai": "escorar",
    "escorais": "escorar",
    "escoram": "escorar",
    "escoramentos": "escoramento",
    "escoramo": "escorar",
    "escoramos": "escorar",
    "escorando": "escorar",
    "escorara": "escorar",
    "escoraram": "escorar",
    "escoraras": "escorar",
    "escorarde": "escorar",
    "escorardes": "escorar",
    "escorare": "escorar",
    "escorarei": "escorar",
    "escorareis": "escorar",
    "escorarem": "escorar",
    "escoraremos": "escorar",
    "escorares": "escorar",
    "escoraria": "escorar",
    "escorariam": "escorar",
    "escorarias": "escorar",
    "escorarmo": "escorar",
    "escorarmos": "escorar",
    "escorará": "escorar",
    "escorarás": "escorar",
    "escorarão": "escorar",
    "escoraríamos": "escorar",
    "escoraríeis": "escorar",
    "escoras": "escorar",
    "escorasse": "escorar",
    "escorassem": "escorar",
    "escorasses": "escorar",
    "escoraste": "escorar",
    "escorastes": "escorar",
    "escorava": "escorar",
    "escoravam": "escorar",
    "escoravas": "escorar",
    "escorbutos": "escorbuto",
    "escorbútica": "escorbútico",
    "escorbúticas": "escorbútico",
    "escorbúticos": "escorbútico",
    "escorce": "escorçar",
    "escorcei": "escorçar",
    "escorceis": "escorçar",
    "escorcem": "escorçar",
    "escorcemo": "escorçar",
    "escorcemos": "escorçar",
    "escorces": "escorçar",
    "escorcha": "escorchar",
    "escorchada": "escorchar",
    "escorchadas": "escorchar",
    "escorchado": "escorchar",
    "escorchadora": "escorchador",
    "escorchadoras": "escorchador",
    "escorchadores": "escorchador",
    "escorchados": "escorchar",
    "escorchai": "escorchar",
    "escorchais": "escorchar",
    "escorcham": "escorchar",
    "escorchamentos": "escorchamento",
    "escorchamo": "escorchar",
    "escorchamos": "escorchar",
    "escorchando": "escorchar",
    "escorchara": "escorchar",
    "escorcharam": "escorchar",
    "escorcharas": "escorchar",
    "escorcharde": "escorchar",
    "escorchardes": "escorchar",
    "escorchare": "escorchar",
    "escorcharei": "escorchar",
    "escorchareis": "escorchar",
    "escorcharem": "escorchar",
    "escorcharemos": "escorchar",
    "escorchares": "escorchar",
    "escorcharia": "escorchar",
    "escorchariam": "escorchar",
    "escorcharias": "escorchar",
    "escorcharmo": "escorchar",
    "escorcharmos": "escorchar",
    "escorchará": "escorchar",
    "escorcharás": "escorchar",
    "escorcharão": "escorchar",
    "escorcharíamos": "escorchar",
    "escorcharíeis": "escorchar",
    "escorchas": "escorchar",
    "escorchasse": "escorchar",
    "escorchassem": "escorchar",
    "escorchasses": "escorchar",
    "escorchaste": "escorchar",
    "escorchastes": "escorchar",
    "escorchava": "escorchar",
    "escorchavam": "escorchar",
    "escorchavas": "escorchar",
    "escorche": "escorchar",
    "escorchei": "escorchar",
    "escorcheis": "escorchar",
    "escorchem": "escorchar",
    "escorchemo": "escorchar",
    "escorchemos": "escorchar",
    "escorches": "escorchar",
    "escorcho": "escorchar",
    "escorchou": "escorchar",
    "escorchá": "escorchar",
    "escorchámo": "escorchar",
    "escorchámos": "escorchar",
    "escorcháramo": "escorchar",
    "escorcháramos": "escorchar",
    "escorchárei": "escorchar",
    "escorcháreis": "escorchar",
    "escorchásseis": "escorchar",
    "escorchássemos": "escorchar",
    "escorchávamo": "escorchar",
    "escorchávamos": "escorchar",
    "escorchávei": "escorchar",
    "escorcháveis": "escorchar",
    "escorcioneiras": "escorcioneira",
    "escore": "escorar",
    "escorei": "escorar",
    "escoreis": "escorar",
    "escorem": "escorar",
    "escoremo": "escorar",
    "escoremos": "escorar",
    "escores": "escorar",
    "escoria": "escoriar",
    "escoriada": "escoriar",
    "escoriadas": "escoriar",
    "escoriado": "escoriar",
    "escoriados": "escoriar",
    "escoriai": "escoriar",
    "escoriais": "escoriar",
    "escoriam": "escoriar",
    "escoriamo": "escoriar",
    "escoriamos": "escoriar",
    "escoriando": "escoriar",
    "escoriara": "escoriar",
    "escoriaram": "escoriar",
    "escoriaras": "escoriar",
    "escoriarde": "escoriar",
    "escoriardes": "escoriar",
    "escoriare": "escoriar",
    "escoriarei": "escoriar",
    "escoriareis": "escoriar",
    "escoriarem": "escoriar",
    "escoriaremos": "escoriar",
    "escoriares": "escoriar",
    "escoriaria": "escoriar",
    "escoriariam": "escoriar",
    "escoriarias": "escoriar",
    "escoriarmo": "escoriar",
    "escoriarmos": "escoriar",
    "escoriará": "escoriar",
    "escoriarás": "escoriar",
    "escoriarão": "escoriar",
    "escoriaríamos": "escoriar",
    "escoriaríeis": "escoriar",
    "escorias": "escoriar",
    "escoriasse": "escoriar",
    "escoriassem": "escoriar",
    "escoriasses": "escoriar",
    "escoriaste": "escoriar",
    "escoriastes": "escoriar",
    "escoriava": "escoriar",
    "escoriavam": "escoriar",
    "escoriavas": "escoriar",
    "escoriações": "escoriação",
    "escorie": "escoriar",
    "escoriei": "escoriar",
    "escorieis": "escoriar",
    "escoriem": "escoriar",
    "escoriemo": "escoriar",
    "escoriemos": "escoriar",
    "escories": "escoriar",
    "escorifica": "escorificar",
    "escorificada": "escorificar",
    "escorificadas": "escorificar",
    "escorificado": "escorificar",
    "escorificados": "escorificar",
    "escorificai": "escorificar",
    "escorificais": "escorificar",
    "escorificam": "escorificar",
    "escorificamo": "escorificar",
    "escorificamos": "escorificar",
    "escorificando": "escorificar",
    "escorificara": "escorificar",
    "escorificaram": "escorificar",
    "escorificaras": "escorificar",
    "escorificarde": "escorificar",
    "escorificardes": "escorificar",
    "escorificare": "escorificar",
    "escorificarei": "escorificar",
    "escorificareis": "escorificar",
    "escorificarem": "escorificar",
    "escorificaremos": "escorificar",
    "escorificares": "escorificar",
    "escorificaria": "escorificar",
    "escorificariam": "escorificar",
    "escorificarias": "escorificar",
    "escorificarmo": "escorificar",
    "escorificarmos": "escorificar",
    "escorificará": "escorificar",
    "escorificarás": "escorificar",
    "escorificarão": "escorificar",
    "escorificaríamos": "escorificar",
    "escorificaríeis": "escorificar",
    "escorificas": "escorificar",
    "escorificasse": "escorificar",
    "escorificassem": "escorificar",
    "escorificasses": "escorificar",
    "escorificaste": "escorificar",
    "escorificastes": "escorificar",
    "escorificatórios": "escorificatório",
    "escorificava": "escorificar",
    "escorificavam": "escorificar",
    "escorificavas": "escorificar",
    "escorificações": "escorificação",
    "escorifico": "escorificar",
    "escorificou": "escorificar",
    "escorificá": "escorificar",
    "escorificámo": "escorificar",
    "escorificámos": "escorificar",
    "escorificáramo": "escorificar",
    "escorificáramos": "escorificar",
    "escorificárei": "escorificar",
    "escorificáreis": "escorificar",
    "escorificásseis": "escorificar",
    "escorificássemos": "escorificar",
    "escorificávamo": "escorificar",
    "escorificávamos": "escorificar",
    "escorificávei": "escorificar",
    "escorificáveis": "escorificar",
    "escorifique": "escorificar",
    "escorifiquei": "escorificar",
    "escorifiqueis": "escorificar",
    "escorifiquem": "escorificar",
    "escorifiquemo": "escorificar",
    "escorifiquemos": "escorificar",
    "escorifiques": "escorificar",
    "escorio": "escoriar",
    "escoriou": "escoriar",
    "escoriá": "escoriar",
    "escoriámo": "escoriar",
    "escoriámos": "escoriar",
    "escoriáramo": "escoriar",
    "escoriáramos": "escoriar",
    "escoriárei": "escoriar",
    "escoriáreis": "escoriar",
    "escoriásseis": "escoriar",
    "escoriássemos": "escoriar",
    "escoriávamo": "escoriar",
    "escoriávamos": "escoriar",
    "escoriávei": "escoriar",
    "escoriáveis": "escoriar",
    "escorja": "escorjar",
    "escorjada": "escorjar",
    "escorjadas": "escorjar",
    "escorjado": "escorjar",
    "escorjados": "escorjar",
    "escorjai": "escorjar",
    "escorjais": "escorjar",
    "escorjam": "escorjar",
    "escorjamo": "escorjar",
    "escorjamos": "escorjar",
    "escorjando": "escorjar",
    "escorjara": "escorjar",
    "escorjaram": "escorjar",
    "escorjaras": "escorjar",
    "escorjarde": "escorjar",
    "escorjardes": "escorjar",
    "escorjare": "escorjar",
    "escorjarei": "escorjar",
    "escorjareis": "escorjar",
    "escorjarem": "escorjar",
    "escorjaremos": "escorjar",
    "escorjares": "escorjar",
    "escorjaria": "escorjar",
    "escorjariam": "escorjar",
    "escorjarias": "escorjar",
    "escorjarmo": "escorjar",
    "escorjarmos": "escorjar",
    "escorjará": "escorjar",
    "escorjarás": "escorjar",
    "escorjarão": "escorjar",
    "escorjaríamos": "escorjar",
    "escorjaríeis": "escorjar",
    "escorjas": "escorjar",
    "escorjasse": "escorjar",
    "escorjassem": "escorjar",
    "escorjasses": "escorjar",
    "escorjaste": "escorjar",
    "escorjastes": "escorjar",
    "escorjava": "escorjar",
    "escorjavam": "escorjar",
    "escorjavas": "escorjar",
    "escorje": "escorjar",
    "escorjei": "escorjar",
    "escorjeis": "escorjar",
    "escorjem": "escorjar",
    "escorjemo": "escorjar",
    "escorjemos": "escorjar",
    "escorjes": "escorjar",
    "escorjo": "escorjar",
    "escorjou": "escorjar",
    "escorjá": "escorjar",
    "escorjámo": "escorjar",
    "escorjámos": "escorjar",
    "escorjáramo": "escorjar",
    "escorjáramos": "escorjar",
    "escorjárei": "escorjar",
    "escorjáreis": "escorjar",
    "escorjásseis": "escorjar",
    "escorjássemos": "escorjar",
    "escorjávamo": "escorjar",
    "escorjávamos": "escorjar",
    "escorjávei": "escorjar",
    "escorjáveis": "escorjar",
    "escorna": "escornar",
    "escornada": "escornar",
    "escornadas": "escornar",
    "escornado": "escornar",
    "escornadora": "escornador",
    "escornadoras": "escornador",
    "escornadores": "escornador",
    "escornados": "escornar",
    "escornai": "escornar",
    "escornais": "escornar",
    "escornam": "escornar",
    "escornamo": "escornar",
    "escornamos": "escornar",
    "escornando": "escornar",
    "escornara": "escornar",
    "escornaram": "escornar",
    "escornaras": "escornar",
    "escornarde": "escornar",
    "escornardes": "escornar",
    "escornare": "escornar",
    "escornarei": "escornar",
    "escornareis": "escornar",
    "escornarem": "escornar",
    "escornaremos": "escornar",
    "escornares": "escornar",
    "escornaria": "escornar",
    "escornariam": "escornar",
    "escornarias": "escornar",
    "escornarmo": "escornar",
    "escornarmos": "escornar",
    "escornará": "escornar",
    "escornarás": "escornar",
    "escornarão": "escornar",
    "escornaríamos": "escornar",
    "escornaríeis": "escornar",
    "escornas": "escornar",
    "escornasse": "escornar",
    "escornassem": "escornar",
    "escornasses": "escornar",
    "escornaste": "escornar",
    "escornastes": "escornar",
    "escornava": "escornar",
    "escornavam": "escornar",
    "escornavas": "escornar",
    "escorne": "escornar",
    "escorneada": "escornear",
    "escorneadas": "escornear",
    "escorneado": "escornear",
    "escorneadora": "escorneador",
    "escorneadoras": "escorneador",
    "escorneadores": "escorneador",
    "escorneados": "escornear",
    "escorneai": "escornear",
    "escorneais": "escornear",
    "escorneamo": "escornear",
    "escorneamos": "escornear",
    "escorneando": "escornear",
    "escorneara": "escornear",
    "escornearam": "escornear",
    "escornearas": "escornear",
    "escornearde": "escornear",
    "escorneardes": "escornear",
    "escorneare": "escornear",
    "escornearei": "escornear",
    "escorneareis": "escornear",
    "escornearem": "escornear",
    "escornearemos": "escornear",
    "escorneares": "escornear",
    "escornearia": "escornear",
    "escorneariam": "escornear",
    "escornearias": "escornear",
    "escornearmo": "escornear",
    "escornearmos": "escornear",
    "escorneará": "escornear",
    "escornearás": "escornear",
    "escornearão": "escornear",
    "escornearíamos": "escornear",
    "escornearíeis": "escornear",
    "escorneasse": "escornear",
    "escorneassem": "escornear",
    "escorneasses": "escornear",
    "escorneaste": "escornear",
    "escorneastes": "escornear",
    "escorneava": "escornear",
    "escorneavam": "escornear",
    "escorneavas": "escornear",
    "escorneei": "escornear",
    "escorneeis": "escornear",
    "escorneemo": "escornear",
    "escorneemos": "escornear",
    "escornei": "escornar",
    "escorneia": "escornear",
    "escorneiam": "escornear",
    "escorneias": "escornear",
    "escorneie": "escornear",
    "escorneiem": "escornear",
    "escorneies": "escornear",
    "escorneio": "escornear",
    "escorneis": "escornar",
    "escornem": "escornar",
    "escornemo": "escornar",
    "escornemos": "escornar",
    "escorneou": "escornear",
    "escornes": "escornar",
    "escorneá": "escornear",
    "escorneámo": "escornear",
    "escorneámos": "escornear",
    "escorneáramo": "escornear",
    "escorneáramos": "escornear",
    "escorneárei": "escornear",
    "escorneáreis": "escornear",
    "escorneásseis": "escornear",
    "escorneássemos": "escornear",
    "escorneávamo": "escornear",
    "escorneávamos": "escornear",
    "escorneávei": "escornear",
    "escorneáveis": "escornear",
    "escornicha": "escornichar",
    "escornichada": "escornichar",
    "escornichadas": "escornichar",
    "escornichado": "escornichar",
    "escornichados": "escornichar",
    "escornichai": "escornichar",
    "escornichais": "escornichar",
    "escornicham": "escornichar",
    "escornichamo": "escornichar",
    "escornichamos": "escornichar",
    "escornichando": "escornichar",
    "escornichara": "escornichar",
    "escornicharam": "escornichar",
    "escornicharas": "escornichar",
    "escornicharde": "escornichar",
    "escornichardes": "escornichar",
    "escornichare": "escornichar",
    "escornicharei": "escornichar",
    "escornichareis": "escornichar",
    "escornicharem": "escornichar",
    "escornicharemos": "escornichar",
    "escornichares": "escornichar",
    "escornicharia": "escornichar",
    "escornichariam": "escornichar",
    "escornicharias": "escornichar",
    "escornicharmo": "escornichar",
    "escornicharmos": "escornichar",
    "escornichará": "escornichar",
    "escornicharás": "escornichar",
    "escornicharão": "escornichar",
    "escornicharíamos": "escornichar",
    "escornicharíeis": "escornichar",
    "escornichas": "escornichar",
    "escornichasse": "escornichar",
    "escornichassem": "escornichar",
    "escornichasses": "escornichar",
    "escornichaste": "escornichar",
    "escornichastes": "escornichar",
    "escornichava": "escornichar",
    "escornichavam": "escornichar",
    "escornichavas": "escornichar",
    "escorniche": "escornichar",
    "escornichei": "escornichar",
    "escornicheis": "escornichar",
    "escornichem": "escornichar",
    "escornichemo": "escornichar",
    "escornichemos": "escornichar",
    "escorniches": "escornichar",
    "escornicho": "escornichar",
    "escornichou": "escornichar",
    "escornichá": "escornichar",
    "escornichámo": "escornichar",
    "escornichámos": "escornichar",
    "escornicháramo": "escornichar",
    "escornicháramos": "escornichar",
    "escornichárei": "escornichar",
    "escornicháreis": "escornichar",
    "escornichásseis": "escornichar",
    "escornichássemos": "escornichar",
    "escornichávamo": "escornichar",
    "escornichávamos": "escornichar",
    "escornichávei": "escornichar",
    "escornicháveis": "escornichar",
    "escorno": "escornar",
    "escornou": "escornar",
    "escorná": "escornar",
    "escornámo": "escornar",
    "escornámos": "escornar",
    "escornáramo": "escornar",
    "escornáramos": "escornar",
    "escornárei": "escornar",
    "escornáreis": "escornar",
    "escornásseis": "escornar",
    "escornássemos": "escornar",
    "escornávamo": "escornar",
    "escornávamos": "escornar",
    "escornávei": "escornar",
    "escornáveis": "escornar",
    "escoro": "escorar",
    "escoroa": "escoroar",
    "escoroada": "escoroar",
    "escoroadas": "escoroar",
    "escoroado": "escoroar",
    "escoroados": "escoroar",
    "escoroai": "escoroar",
    "escoroais": "escoroar",
    "escoroam": "escoroar",
    "escoroamo": "escoroar",
    "escoroamos": "escoroar",
    "escoroando": "escoroar",
    "escoroara": "escoroar",
    "escoroaram": "escoroar",
    "escoroaras": "escoroar",
    "escoroarde": "escoroar",
    "escoroardes": "escoroar",
    "escoroare": "escoroar",
    "escoroarei": "escoroar",
    "escoroareis": "escoroar",
    "escoroarem": "escoroar",
    "escoroaremos": "escoroar",
    "escoroares": "escoroar",
    "escoroaria": "escoroar",
    "escoroariam": "escoroar",
    "escoroarias": "escoroar",
    "escoroarmo": "escoroar",
    "escoroarmos": "escoroar",
    "escoroará": "escoroar",
    "escoroarás": "escoroar",
    "escoroarão": "escoroar",
    "escoroaríamos": "escoroar",
    "escoroaríeis": "escoroar",
    "escoroas": "escoroar",
    "escoroasse": "escoroar",
    "escoroassem": "escoroar",
    "escoroasses": "escoroar",
    "escoroaste": "escoroar",
    "escoroastes": "escoroar",
    "escoroava": "escoroar",
    "escoroavam": "escoroar",
    "escoroavas": "escoroar",
    "escorodóneas": "escorodónea",
    "escoroe": "escoroar",
    "escoroei": "escoroar",
    "escoroeis": "escoroar",
    "escoroem": "escoroar",
    "escoroemo": "escoroar",
    "escoroemos": "escoroar",
    "escoroes": "escoroar",
    "escoroo": "escoroar",
    "escoroou": "escoroar",
    "escorou": "escorar",
    "escoroá": "escoroar",
    "escoroámo": "escoroar",
    "escoroámos": "escoroar",
    "escoroáramo": "escoroar",
    "escoroáramos": "escoroar",
    "escoroárei": "escoroar",
    "escoroáreis": "escoroar",
    "escoroásseis": "escoroar",
    "escoroássemos": "escoroar",
    "escoroávamo": "escoroar",
    "escoroávamos": "escoroar",
    "escoroávei": "escoroar",
    "escoroáveis": "escoroar",
    "escorpenídea": "escorpenídeo",
    "escorpenídeas": "escorpenídeo",
    "escorpenídeos": "escorpenídeo",
    "escorpióides": "escorpióide",
    "escorpiões": "escorpião",
    "escorpénidas": "escorpénida",
    "escorra": "escorrer",
    "escorrace": "escorraçar",
    "escorracei": "escorraçar",
    "escorraceis": "escorraçar",
    "escorracem": "escorraçar",
    "escorracemo": "escorraçar",
    "escorracemos": "escorraçar",
    "escorraces": "escorraçar",
    "escorrais": "escorrer",
    "escorralhas": "escorralha",
    "escorralhos": "escorralho",
    "escorram": "escorrer",
    "escorramo": "escorrer",
    "escorramos": "escorrer",
    "escorras": "escorrer",
    "escorraça": "escorraçar",
    "escorraçada": "escorraçar",
    "escorraçadas": "escorraçar",
    "escorraçado": "escorraçar",
    "escorraçados": "escorraçar",
    "escorraçai": "escorraçar",
    "escorraçais": "escorraçar",
    "escorraçam": "escorraçar",
    "escorraçamo": "escorraçar",
    "escorraçamos": "escorraçar",
    "escorraçando": "escorraçar",
    "escorraçara": "escorraçar",
    "escorraçaram": "escorraçar",
    "escorraçaras": "escorraçar",
    "escorraçarde": "escorraçar",
    "escorraçardes": "escorraçar",
    "escorraçare": "escorraçar",
    "escorraçarei": "escorraçar",
    "escorraçareis": "escorraçar",
    "escorraçarem": "escorraçar",
    "escorraçaremos": "escorraçar",
    "escorraçares": "escorraçar",
    "escorraçaria": "escorraçar",
    "escorraçariam": "escorraçar",
    "escorraçarias": "escorraçar",
    "escorraçarmo": "escorraçar",
    "escorraçarmos": "escorraçar",
    "escorraçará": "escorraçar",
    "escorraçarás": "escorraçar",
    "escorraçarão": "escorraçar",
    "escorraçaríamos": "escorraçar",
    "escorraçaríeis": "escorraçar",
    "escorraças": "escorraçar",
    "escorraçasse": "escorraçar",
    "escorraçassem": "escorraçar",
    "escorraçasses": "escorraçar",
    "escorraçaste": "escorraçar",
    "escorraçastes": "escorraçar",
    "escorraçava": "escorraçar",
    "escorraçavam": "escorraçar",
    "escorraçavas": "escorraçar",
    "escorraço": "escorraçar",
    "escorraçou": "escorraçar",
    "escorraçá": "escorraçar",
    "escorraçámo": "escorraçar",
    "escorraçámos": "escorraçar",
    "escorraçáramo": "escorraçar",
    "escorraçáramos": "escorraçar",
    "escorraçárei": "escorraçar",
    "escorraçáreis": "escorraçar",
    "escorraçásseis": "escorraçar",
    "escorraçássemos": "escorraçar",
    "escorraçávamo": "escorraçar",
    "escorraçávamos": "escorraçar",
    "escorraçávei": "escorraçar",
    "escorraçáveis": "escorraçável",
    "escorre": "escorrer",
    "escorredoiros": "escorredoiro",
    "escorredores": "escorredor",
    "escorredouros": "escorredouro",
    "escorreduras": "escorredura",
    "escorrega": "escorregar",
    "escorregada": "escorregar",
    "escorregadas": "escorregar",
    "escorregadelas": "escorregadela",
    "escorregadia": "escorregadio",
    "escorregadias": "escorregadio",
    "escorregadios": "escorregadio",
    "escorregadiça": "escorregadiço",
    "escorregadiças": "escorregadiço",
    "escorregadiços": "escorregadiço",
    "escorregado": "escorregar",
    "escorregadoiros": "escorregadoiro",
    "escorregados": "escorregar",
    "escorregadouros": "escorregadouro",
    "escorregaduras": "escorregadura",
    "escorregai": "escorregar",
    "escorregais": "escorregar",
    "escorregam": "escorregar",
    "escorregamentos": "escorregamento",
    "escorregamo": "escorregar",
    "escorregamos": "escorregar",
    "escorregando": "escorregar",
    "escorregara": "escorregar",
    "escorregaram": "escorregar",
    "escorregaras": "escorregar",
    "escorregardes": "escorregar",
    "escorregarei": "escorregar",
    "escorregareis": "escorregar",
    "escorregarem": "escorregar",
    "escorregaremos": "escorregar",
    "escorregares": "escorregar",
    "escorregaria": "escorregar",
    "escorregariam": "escorregar",
    "escorregarias": "escorregar",
    "escorregarmo": "escorregar",
    "escorregarmos": "escorregar",
    "escorregará": "escorregar",
    "escorregarás": "escorregar",
    "escorregarão": "escorregar",
    "escorregaríamos": "escorregar",
    "escorregaríeis": "escorregar",
    "escorregas": "escorregar",
    "escorregasse": "escorregar",
    "escorregassem": "escorregar",
    "escorregasses": "escorregar",
    "escorregaste": "escorregar",
    "escorregastes": "escorregar",
    "escorregava": "escorregar",
    "escorregavam": "escorregar",
    "escorregavas": "escorregar",
    "escorrego": "escorregar",
    "escorregos": "escorrego",
    "escorregou": "escorregar",
    "escorregue": "escorregar",
    "escorreguei": "escorregar",
    "escorregueis": "escorregar",
    "escorreguem": "escorregar",
    "escorreguemo": "escorregar",
    "escorreguemos": "escorregar",
    "escorregues": "escorregar",
    "escorregámo": "escorregar",
    "escorregámos": "escorregar",
    "escorregáramo": "escorregar",
    "escorregáramos": "escorregar",
    "escorregáreis": "escorregar",
    "escorregásseis": "escorregar",
    "escorregássemos": "escorregar",
    "escorregávamo": "escorregar",
    "escorregávamos": "escorregar",
    "escorregáveis": "escorregável",
    "escorregões": "escorregão",
    "escorrei": "escorrer",
    "escorreis": "escorrer",
    "escorreita": "escorreito",
    "escorreitas": "escorreito",
    "escorreitos": "escorreito",
    "escorrem": "escorrer",
    "escorremo": "escorrer",
    "escorremos": "escorrer",
    "escorrendo": "escorrer",
    "escorrera": "escorrer",
    "escorreram": "escorrer",
    "escorreras": "escorrer",
    "escorrerdes": "escorrer",
    "escorrerei": "escorrer",
    "escorrereis": "escorrer",
    "escorrerem": "escorrer",
    "escorreremos": "escorrer",
    "escorreres": "escorrer",
    "escorreria": "escorrer",
    "escorreriam": "escorrer",
    "escorrerias": "escorrer",
    "escorrermo": "escorrer",
    "escorrermos": "escorrer",
    "escorrerá": "escorrer",
    "escorrerás": "escorrer",
    "escorrerão": "escorrer",
    "escorreríamos": "escorrer",
    "escorreríeis": "escorrer",
    "escorres": "escorrer",
    "escorresse": "escorrer",
    "escorressem": "escorrer",
    "escorresses": "escorrer",
    "escorreste": "escorrer",
    "escorrestes": "escorrer",
    "escorreu": "escorrer",
    "escorri": "escorrer",
    "escorria": "escorrer",
    "escorriam": "escorrer",
    "escorrias": "escorrer",
    "escorricha": "escorrichar",
    "escorrichada": "escorrichar",
    "escorrichadas": "escorrichar",
    "escorrichado": "escorrichar",
    "escorrichados": "escorrichar",
    "escorrichai": "escorrichar",
    "escorrichais": "escorrichar",
    "escorricham": "escorrichar",
    "escorrichamo": "escorrichar",
    "escorrichamos": "escorrichar",
    "escorrichando": "escorrichar",
    "escorrichara": "escorrichar",
    "escorricharam": "escorrichar",
    "escorricharas": "escorrichar",
    "escorricharde": "escorrichar",
    "escorrichardes": "escorrichar",
    "escorrichare": "escorrichar",
    "escorricharei": "escorrichar",
    "escorrichareis": "escorrichar",
    "escorricharem": "escorrichar",
    "escorricharemos": "escorrichar",
    "escorrichares": "escorrichar",
    "escorricharia": "escorrichar",
    "escorrichariam": "escorrichar",
    "escorricharias": "escorrichar",
    "escorricharmo": "escorrichar",
    "escorricharmos": "escorrichar",
    "escorrichará": "escorrichar",
    "escorricharás": "escorrichar",
    "escorricharão": "escorrichar",
    "escorricharíamos": "escorrichar",
    "escorricharíeis": "escorrichar",
    "escorrichas": "escorrichar",
    "escorrichasse": "escorrichar",
    "escorrichassem": "escorrichar",
    "escorrichasses": "escorrichar",
    "escorrichaste": "escorrichar",
    "escorrichastes": "escorrichar",
    "escorrichava": "escorrichar",
    "escorrichavam": "escorrichar",
    "escorrichavas": "escorrichar",
    "escorriche": "escorrichar",
    "escorrichei": "escorrichar",
    "escorricheis": "escorrichar",
    "escorrichem": "escorrichar",
    "escorrichemo": "escorrichar",
    "escorrichemos": "escorrichar",
    "escorriches": "escorrichar",
    "escorricho": "escorrichar",
    "escorrichou": "escorrichar",
    "escorrichá": "escorrichar",
    "escorrichámo": "escorrichar",
    "escorrichámos": "escorrichar",
    "escorricháramo": "escorrichar",
    "escorricháramos": "escorrichar",
    "escorrichárei": "escorrichar",
    "escorricháreis": "escorrichar",
    "escorrichásseis": "escorrichar",
    "escorrichássemos": "escorrichar",
    "escorrichávamo": "escorrichar",
    "escorrichávamos": "escorrichar",
    "escorrichávei": "escorrichar",
    "escorricháveis": "escorrichar",
    "escorrida": "escorrido",
    "escorridas": "escorrido",
    "escorrido": "escorrer",
    "escorridos": "escorrido",
    "escorrimentos": "escorrimento",
    "escorripicha": "escorripichar",
    "escorripichada": "escorripichar",
    "escorripichadas": "escorripichar",
    "escorripichadelas": "escorripichadela",
    "escorripichado": "escorripichar",
    "escorripichados": "escorripichar",
    "escorripichai": "escorripichar",
    "escorripichais": "escorripichar",
    "escorripicham": "escorripichar",
    "escorripichamo": "escorripichar",
    "escorripichamos": "escorripichar",
    "escorripichando": "escorripichar",
    "escorripichara": "escorripichar",
    "escorripicharam": "escorripichar",
    "escorripicharas": "escorripichar",
    "escorripicharde": "escorripichar",
    "escorripichardes": "escorripichar",
    "escorripichare": "escorripichar",
    "escorripicharei": "escorripichar",
    "escorripichareis": "escorripichar",
    "escorripicharem": "escorripichar",
    "escorripicharemos": "escorripichar",
    "escorripichares": "escorripichar",
    "escorripicharia": "escorripichar",
    "escorripichariam": "escorripichar",
    "escorripicharias": "escorripichar",
    "escorripicharmo": "escorripichar",
    "escorripicharmos": "escorripichar",
    "escorripichará": "escorripichar",
    "escorripicharás": "escorripichar",
    "escorripicharão": "escorripichar",
    "escorripicharíamos": "escorripichar",
    "escorripicharíeis": "escorripichar",
    "escorripichas": "escorripichar",
    "escorripichasse": "escorripichar",
    "escorripichassem": "escorripichar",
    "escorripichasses": "escorripichar",
    "escorripichaste": "escorripichar",
    "escorripichastes": "escorripichar",
    "escorripichava": "escorripichar",
    "escorripichavam": "escorripichar",
    "escorripichavas": "escorripichar",
    "escorripiche": "escorripichar",
    "escorripichei": "escorripichar",
    "escorripicheis": "escorripichar",
    "escorripichem": "escorripichar",
    "escorripichemo": "escorripichar",
    "escorripichemos": "escorripichar",
    "escorripiches": "escorripichar",
    "escorripicho": "escorripichar",
    "escorripichou": "escorripichar",
    "escorripichá": "escorripichar",
    "escorripichámo": "escorripichar",
    "escorripichámos": "escorripichar",
    "escorripicháramo": "escorripichar",
    "escorripicháramos": "escorripichar",
    "escorripichárei": "escorripichar",
    "escorripicháreis": "escorripichar",
    "escorripichásseis": "escorripichar",
    "escorripichássemos": "escorripichar",
    "escorripichávamo": "escorripichar",
    "escorripichávamos": "escorripichar",
    "escorripichávei": "escorripichar",
    "escorripicháveis": "escorripichar",
    "escorro": "escorrer",
    "escorropicha": "escorropichar",
    "escorropichada": "escorropichar",
    "escorropichadas": "escorropichar",
    "escorropichado": "escorropichar",
    "escorropichados": "escorropichar",
    "escorropichai": "escorropichar",
    "escorropichais": "escorropichar",
    "escorropicham": "escorropichar",
    "escorropichamo": "escorropichar",
    "escorropichamos": "escorropichar",
    "escorropichando": "escorropichar",
    "escorropichara": "escorropichar",
    "escorropicharam": "escorropichar",
    "escorropicharas": "escorropichar",
    "escorropicharde": "escorropichar",
    "escorropichardes": "escorropichar",
    "escorropichare": "escorropichar",
    "escorropicharei": "escorropichar",
    "escorropichareis": "escorropichar",
    "escorropicharem": "escorropichar",
    "escorropicharemos": "escorropichar",
    "escorropichares": "escorropichar",
    "escorropicharia": "escorropichar",
    "escorropichariam": "escorropichar",
    "escorropicharias": "escorropichar",
    "escorropicharmo": "escorropichar",
    "escorropicharmos": "escorropichar",
    "escorropichará": "escorropichar",
    "escorropicharás": "escorropichar",
    "escorropicharão": "escorropichar",
    "escorropicharíamos": "escorropichar",
    "escorropicharíeis": "escorropichar",
    "escorropichas": "escorropichar",
    "escorropichasse": "escorropichar",
    "escorropichassem": "escorropichar",
    "escorropichasses": "escorropichar",
    "escorropichaste": "escorropichar",
    "escorropichastes": "escorropichar",
    "escorropichava": "escorropichar",
    "escorropichavam": "escorropichar",
    "escorropichavas": "escorropichar",
    "escorropiche": "escorropichar",
    "escorropichei": "escorropichar",
    "escorropicheis": "escorropichar",
    "escorropichem": "escorropichar",
    "escorropichemo": "escorropichar",
    "escorropichemos": "escorropichar",
    "escorropiches": "escorropichar",
    "escorropicho": "escorropichar",
    "escorropichou": "escorropichar",
    "escorropichá": "escorropichar",
    "escorropichámo": "escorropichar",
    "escorropichámos": "escorropichar",
    "escorropicháramo": "escorropichar",
    "escorropicháramos": "escorropichar",
    "escorropichárei": "escorropichar",
    "escorropicháreis": "escorropichar",
    "escorropichásseis": "escorropichar",
    "escorropichássemos": "escorropichar",
    "escorropichávamo": "escorropichar",
    "escorropichávamos": "escorropichar",
    "escorropichávei": "escorropichar",
    "escorropicháveis": "escorropichar",
    "escorrências": "escorrência",
    "escorrêramo": "escorrer",
    "escorrêramos": "escorrer",
    "escorrêreis": "escorrer",
    "escorrêsseis": "escorrer",
    "escorrêssemos": "escorrer",
    "escorríamo": "escorrer",
    "escorríamos": "escorrer",
    "escorríeis": "escorrer",
    "escortina": "escortinar",
    "escortinada": "escortinar",
    "escortinadas": "escortinar",
    "escortinado": "escortinar",
    "escortinados": "escortinar",
    "escortinai": "escortinar",
    "escortinais": "escortinar",
    "escortinam": "escortinar",
    "escortinamo": "escortinar",
    "escortinamos": "escortinar",
    "escortinando": "escortinar",
    "escortinara": "escortinar",
    "escortinaram": "escortinar",
    "escortinaras": "escortinar",
    "escortinarde": "escortinar",
    "escortinardes": "escortinar",
    "escortinare": "escortinar",
    "escortinarei": "escortinar",
    "escortinareis": "escortinar",
    "escortinarem": "escortinar",
    "escortinaremos": "escortinar",
    "escortinares": "escortinar",
    "escortinaria": "escortinar",
    "escortinariam": "escortinar",
    "escortinarias": "escortinar",
    "escortinarmo": "escortinar",
    "escortinarmos": "escortinar",
    "escortinará": "escortinar",
    "escortinarás": "escortinar",
    "escortinarão": "escortinar",
    "escortinaríamos": "escortinar",
    "escortinaríeis": "escortinar",
    "escortinas": "escortinar",
    "escortinasse": "escortinar",
    "escortinassem": "escortinar",
    "escortinasses": "escortinar",
    "escortinaste": "escortinar",
    "escortinastes": "escortinar",
    "escortinava": "escortinar",
    "escortinavam": "escortinar",
    "escortinavas": "escortinar",
    "escortine": "escortinar",
    "escortinei": "escortinar",
    "escortineis": "escortinar",
    "escortinem": "escortinar",
    "escortinemo": "escortinar",
    "escortinemos": "escortinar",
    "escortines": "escortinar",
    "escortino": "escortinar",
    "escortinou": "escortinar",
    "escortiná": "escortinar",
    "escortinámo": "escortinar",
    "escortinámos": "escortinar",
    "escortináramo": "escortinar",
    "escortináramos": "escortinar",
    "escortinárei": "escortinar",
    "escortináreis": "escortinar",
    "escortinásseis": "escortinar",
    "escortinássemos": "escortinar",
    "escortinávamo": "escortinar",
    "escortinávamos": "escortinar",
    "escortinávei": "escortinar",
    "escortináveis": "escortinar",
    "escorva": "escorvar",
    "escorvada": "escorvar",
    "escorvadas": "escorvar",
    "escorvado": "escorvar",
    "escorvadora": "escorvador",
    "escorvadoras": "escorvador",
    "escorvadores": "escorvador",
    "escorvados": "escorvar",
    "escorvai": "escorvar",
    "escorvais": "escorvar",
    "escorvam": "escorvar",
    "escorvamentos": "escorvamento",
    "escorvamo": "escorvar",
    "escorvamos": "escorvar",
    "escorvando": "escorvar",
    "escorvara": "escorvar",
    "escorvaram": "escorvar",
    "escorvaras": "escorvar",
    "escorvarde": "escorvar",
    "escorvardes": "escorvar",
    "escorvare": "escorvar",
    "escorvarei": "escorvar",
    "escorvareis": "escorvar",
    "escorvarem": "escorvar",
    "escorvaremos": "escorvar",
    "escorvares": "escorvar",
    "escorvaria": "escorvar",
    "escorvariam": "escorvar",
    "escorvarias": "escorvar",
    "escorvarmo": "escorvar",
    "escorvarmos": "escorvar",
    "escorvará": "escorvar",
    "escorvarás": "escorvar",
    "escorvarão": "escorvar",
    "escorvaríamos": "escorvar",
    "escorvaríeis": "escorvar",
    "escorvas": "escorvar",
    "escorvasse": "escorvar",
    "escorvassem": "escorvar",
    "escorvasses": "escorvar",
    "escorvaste": "escorvar",
    "escorvastes": "escorvar",
    "escorvava": "escorvar",
    "escorvavam": "escorvar",
    "escorvavas": "escorvar",
    "escorve": "escorvar",
    "escorvei": "escorvar",
    "escorveis": "escorvar",
    "escorvem": "escorvar",
    "escorvemo": "escorvar",
    "escorvemos": "escorvar",
    "escorves": "escorvar",
    "escorvo": "escorvar",
    "escorvou": "escorvar",
    "escorvá": "escorvar",
    "escorvámo": "escorvar",
    "escorvámos": "escorvar",
    "escorváramo": "escorvar",
    "escorváramos": "escorvar",
    "escorvárei": "escorvar",
    "escorváreis": "escorvar",
    "escorvásseis": "escorvar",
    "escorvássemos": "escorvar",
    "escorvávamo": "escorvar",
    "escorvávamos": "escorvar",
    "escorvávei": "escorvar",
    "escorváveis": "escorvar",
    "escorá": "escorar",
    "escorámo": "escorar",
    "escorámos": "escorar",
    "escoráramo": "escorar",
    "escoráramos": "escorar",
    "escorárei": "escorar",
    "escoráreis": "escorar",
    "escorásseis": "escorar",
    "escorássemos": "escorar",
    "escorávamo": "escorar",
    "escorávamos": "escorar",
    "escorávei": "escorar",
    "escoráveis": "escorar",
    "escorça": "escorçar",
    "escorçada": "escorçar",
    "escorçadas": "escorçar",
    "escorçado": "escorçar",
    "escorçados": "escorçar",
    "escorçai": "escorçar",
    "escorçais": "escorçar",
    "escorçam": "escorçar",
    "escorçamo": "escorçar",
    "escorçamos": "escorçar",
    "escorçando": "escorçar",
    "escorçara": "escorçar",
    "escorçaram": "escorçar",
    "escorçaras": "escorçar",
    "escorçarde": "escorçar",
    "escorçardes": "escorçar",
    "escorçare": "escorçar",
    "escorçarei": "escorçar",
    "escorçareis": "escorçar",
    "escorçarem": "escorçar",
    "escorçaremos": "escorçar",
    "escorçares": "escorçar",
    "escorçaria": "escorçar",
    "escorçariam": "escorçar",
    "escorçarias": "escorçar",
    "escorçarmo": "escorçar",
    "escorçarmos": "escorçar",
    "escorçará": "escorçar",
    "escorçarás": "escorçar",
    "escorçarão": "escorçar",
    "escorçaríamos": "escorçar",
    "escorçaríeis": "escorçar",
    "escorças": "escorçar",
    "escorçasse": "escorçar",
    "escorçassem": "escorçar",
    "escorçasses": "escorçar",
    "escorçaste": "escorçar",
    "escorçastes": "escorçar",
    "escorçava": "escorçar",
    "escorçavam": "escorçar",
    "escorçavas": "escorçar",
    "escorço": "escorçar",
    "escorços": "escorço",
    "escorçou": "escorçar",
    "escorçá": "escorçar",
    "escorçámo": "escorçar",
    "escorçámos": "escorçar",
    "escorçáramo": "escorçar",
    "escorçáramos": "escorçar",
    "escorçárei": "escorçar",
    "escorçáreis": "escorçar",
    "escorçásseis": "escorçar",
    "escorçássemos": "escorçar",
    "escorçávamo": "escorçar",
    "escorçávamos": "escorçar",
    "escorçávei": "escorçar",
    "escorçáveis": "escorçar",
    "escosipa": "escosipar",
    "escosipada": "escosipar",
    "escosipadas": "escosipar",
    "escosipado": "escosipar",
    "escosipados": "escosipar",
    "escosipai": "escosipar",
    "escosipais": "escosipar",
    "escosipam": "escosipar",
    "escosipamo": "escosipar",
    "escosipamos": "escosipar",
    "escosipando": "escosipar",
    "escosipara": "escosipar",
    "escosiparam": "escosipar",
    "escosiparas": "escosipar",
    "escosiparde": "escosipar",
    "escosipardes": "escosipar",
    "escosipare": "escosipar",
    "escosiparei": "escosipar",
    "escosipareis": "escosipar",
    "escosiparem": "escosipar",
    "escosiparemos": "escosipar",
    "escosipares": "escosipar",
    "escosiparia": "escosipar",
    "escosipariam": "escosipar",
    "escosiparias": "escosipar",
    "escosiparmo": "escosipar",
    "escosiparmos": "escosipar",
    "escosipará": "escosipar",
    "escosiparás": "escosipar",
    "escosiparão": "escosipar",
    "escosiparíamos": "escosipar",
    "escosiparíeis": "escosipar",
    "escosipas": "escosipar",
    "escosipasse": "escosipar",
    "escosipassem": "escosipar",
    "escosipasses": "escosipar",
    "escosipaste": "escosipar",
    "escosipastes": "escosipar",
    "escosipava": "escosipar",
    "escosipavam": "escosipar",
    "escosipavas": "escosipar",
    "escosipe": "escosipar",
    "escosipei": "escosipar",
    "escosipeis": "escosipar",
    "escosipem": "escosipar",
    "escosipemo": "escosipar",
    "escosipemos": "escosipar",
    "escosipes": "escosipar",
    "escosipo": "escosipar",
    "escosipou": "escosipar",
    "escosipá": "escosipar",
    "escosipámo": "escosipar",
    "escosipámos": "escosipar",
    "escosipáramo": "escosipar",
    "escosipáramos": "escosipar",
    "escosipárei": "escosipar",
    "escosipáreis": "escosipar",
    "escosipásseis": "escosipar",
    "escosipássemos": "escosipar",
    "escosipávamo": "escosipar",
    "escosipávamos": "escosipar",
    "escosipávei": "escosipar",
    "escosipáveis": "escosipar",
    "escotas": "escota",
    "escoteira": "escoteiro",
    "escoteiras": "escoteiro",
    "escoteiros": "escoteiro",
    "escotes": "escote",
    "escotilhas": "escotilha",
    "escotilhões": "escotilhão",
    "escotismos": "escotismo",
    "escotomas": "escotoma",
    "escotóforos": "escotóforo",
    "escotópica": "escotópico",
    "escotópicas": "escotópico",
    "escotópicos": "escotópico",
    "escouceada": "escoucear",
    "escouceadas": "escoucear",
    "escouceado": "escoucear",
    "escouceados": "escoucear",
    "escouceai": "escoucear",
    "escouceais": "escoucear",
    "escouceamo": "escoucear",
    "escouceamos": "escoucear",
    "escouceando": "escoucear",
    "escouceara": "escoucear",
    "escoucearam": "escoucear",
    "escoucearas": "escoucear",
    "escoucearde": "escoucear",
    "escouceardes": "escoucear",
    "escouceare": "escoucear",
    "escoucearei": "escoucear",
    "escouceareis": "escoucear",
    "escoucearem": "escoucear",
    "escoucearemos": "escoucear",
    "escouceares": "escoucear",
    "escoucearia": "escoucear",
    "escouceariam": "escoucear",
    "escoucearias": "escoucear",
    "escoucearmo": "escoucear",
    "escoucearmos": "escoucear",
    "escouceará": "escoucear",
    "escoucearás": "escoucear",
    "escoucearão": "escoucear",
    "escoucearíamos": "escoucear",
    "escoucearíeis": "escoucear",
    "escouceasse": "escoucear",
    "escouceassem": "escoucear",
    "escouceasses": "escoucear",
    "escouceaste": "escoucear",
    "escouceastes": "escoucear",
    "escouceava": "escoucear",
    "escouceavam": "escoucear",
    "escouceavas": "escoucear",
    "escouceei": "escoucear",
    "escouceeis": "escoucear",
    "escouceemo": "escoucear",
    "escouceemos": "escoucear",
    "escouceia": "escoucear",
    "escouceiam": "escoucear",
    "escouceias": "escoucear",
    "escouceie": "escoucear",
    "escouceiem": "escoucear",
    "escouceies": "escoucear",
    "escouceio": "escoucear",
    "escouceou": "escoucear",
    "escouceá": "escoucear",
    "escouceámo": "escoucear",
    "escouceámos": "escoucear",
    "escouceáramo": "escoucear",
    "escouceáramos": "escoucear",
    "escouceárei": "escoucear",
    "escouceáreis": "escoucear",
    "escouceásseis": "escoucear",
    "escouceássemos": "escoucear",
    "escouceávamo": "escoucear",
    "escouceávamos": "escoucear",
    "escouceávei": "escoucear",
    "escouceáveis": "escoucear",
    "escoucinha": "escoucinhar",
    "escoucinhada": "escoucinhar",
    "escoucinhadas": "escoucinhar",
    "escoucinhado": "escoucinhar",
    "escoucinhados": "escoucinhar",
    "escoucinhai": "escoucinhar",
    "escoucinhais": "escoucinhar",
    "escoucinham": "escoucinhar",
    "escoucinhamo": "escoucinhar",
    "escoucinhamos": "escoucinhar",
    "escoucinhando": "escoucinhar",
    "escoucinhara": "escoucinhar",
    "escoucinharam": "escoucinhar",
    "escoucinharas": "escoucinhar",
    "escoucinharde": "escoucinhar",
    "escoucinhardes": "escoucinhar",
    "escoucinhare": "escoucinhar",
    "escoucinharei": "escoucinhar",
    "escoucinhareis": "escoucinhar",
    "escoucinharem": "escoucinhar",
    "escoucinharemos": "escoucinhar",
    "escoucinhares": "escoucinhar",
    "escoucinharia": "escoucinhar",
    "escoucinhariam": "escoucinhar",
    "escoucinharias": "escoucinhar",
    "escoucinharmo": "escoucinhar",
    "escoucinharmos": "escoucinhar",
    "escoucinhará": "escoucinhar",
    "escoucinharás": "escoucinhar",
    "escoucinharão": "escoucinhar",
    "escoucinharíamos": "escoucinhar",
    "escoucinharíeis": "escoucinhar",
    "escoucinhas": "escoucinhar",
    "escoucinhasse": "escoucinhar",
    "escoucinhassem": "escoucinhar",
    "escoucinhasses": "escoucinhar",
    "escoucinhaste": "escoucinhar",
    "escoucinhastes": "escoucinhar",
    "escoucinhava": "escoucinhar",
    "escoucinhavam": "escoucinhar",
    "escoucinhavas": "escoucinhar",
    "escoucinhe": "escoucinhar",
    "escoucinhei": "escoucinhar",
    "escoucinheis": "escoucinhar",
    "escoucinhem": "escoucinhar",
    "escoucinhemo": "escoucinhar",
    "escoucinhemos": "escoucinhar",
    "escoucinhes": "escoucinhar",
    "escoucinho": "escoucinhar",
    "escoucinhou": "escoucinhar",
    "escoucinhá": "escoucinhar",
    "escoucinhámo": "escoucinhar",
    "escoucinhámos": "escoucinhar",
    "escoucinháramo": "escoucinhar",
    "escoucinháramos": "escoucinhar",
    "escoucinhárei": "escoucinhar",
    "escoucinháreis": "escoucinhar",
    "escoucinhásseis": "escoucinhar",
    "escoucinhássemos": "escoucinhar",
    "escoucinhávamo": "escoucinhar",
    "escoucinhávamos": "escoucinhar",
    "escoucinhávei": "escoucinhar",
    "escoucinháveis": "escoucinhar",
    "escova": "escovar",
    "escovada": "escovar",
    "escovadas": "escovar",
    "escovadeiras": "escovadeira",
    "escovadelas": "escovadela",
    "escovadinhos": "escovadinho",
    "escovado": "escovar",
    "escovadora": "escovador",
    "escovadoras": "escovador",
    "escovadores": "escovador",
    "escovados": "escovar",
    "escovai": "escovar",
    "escovais": "escovar",
    "escovalhos": "escovalho",
    "escovam": "escovar",
    "escovamo": "escovar",
    "escovamos": "escovar",
    "escovando": "escovar",
    "escovara": "escovar",
    "escovaram": "escovar",
    "escovaras": "escovar",
    "escovarde": "escovar",
    "escovardes": "escovar",
    "escovare": "escovar",
    "escovarei": "escovar",
    "escovareis": "escovar",
    "escovarem": "escovar",
    "escovaremos": "escovar",
    "escovares": "escovar",
    "escovaria": "escovar",
    "escovariam": "escovar",
    "escovarias": "escovar",
    "escovarmo": "escovar",
    "escovarmos": "escovar",
    "escovará": "escovar",
    "escovarás": "escovar",
    "escovarão": "escovar",
    "escovaríamos": "escovar",
    "escovaríeis": "escovar",
    "escovas": "escovar",
    "escovasse": "escovar",
    "escovassem": "escovar",
    "escovasses": "escovar",
    "escovaste": "escovar",
    "escovastes": "escovar",
    "escovava": "escovar",
    "escovavam": "escovar",
    "escovavas": "escovar",
    "escove": "escovar",
    "escovei": "escovar",
    "escoveiras": "escoveira",
    "escoveiros": "escoveiro",
    "escoveirões": "escoveirão",
    "escoveis": "escovar",
    "escovem": "escovar",
    "escovemo": "escovar",
    "escovemos": "escovar",
    "escoves": "escovar",
    "escovilha": "escovilhar",
    "escovilhada": "escovilhar",
    "escovilhadas": "escovilhar",
    "escovilhado": "escovilhar",
    "escovilhados": "escovilhar",
    "escovilhagens": "escovilhagem",
    "escovilhai": "escovilhar",
    "escovilhais": "escovilhar",
    "escovilham": "escovilhar",
    "escovilhamo": "escovilhar",
    "escovilhamos": "escovilhar",
    "escovilhando": "escovilhar",
    "escovilhara": "escovilhar",
    "escovilharam": "escovilhar",
    "escovilharas": "escovilhar",
    "escovilharde": "escovilhar",
    "escovilhardes": "escovilhar",
    "escovilhare": "escovilhar",
    "escovilharei": "escovilhar",
    "escovilhareis": "escovilhar",
    "escovilharem": "escovilhar",
    "escovilharemos": "escovilhar",
    "escovilhares": "escovilhar",
    "escovilharia": "escovilhar",
    "escovilhariam": "escovilhar",
    "escovilharias": "escovilhar",
    "escovilharmo": "escovilhar",
    "escovilharmos": "escovilhar",
    "escovilhará": "escovilhar",
    "escovilharás": "escovilhar",
    "escovilharão": "escovilhar",
    "escovilharíamos": "escovilhar",
    "escovilharíeis": "escovilhar",
    "escovilhas": "escovilhar",
    "escovilhasse": "escovilhar",
    "escovilhassem": "escovilhar",
    "escovilhasses": "escovilhar",
    "escovilhaste": "escovilhar",
    "escovilhastes": "escovilhar",
    "escovilhava": "escovilhar",
    "escovilhavam": "escovilhar",
    "escovilhavas": "escovilhar",
    "escovilhe": "escovilhar",
    "escovilhei": "escovilhar",
    "escovilheira": "escovilheiro",
    "escovilheiras": "escovilheiro",
    "escovilheiros": "escovilheiro",
    "escovilheis": "escovilhar",
    "escovilhem": "escovilhar",
    "escovilhemo": "escovilhar",
    "escovilhemos": "escovilhar",
    "escovilhes": "escovilhar",
    "escovilho": "escovilhar",
    "escovilhou": "escovilhar",
    "escovilhá": "escovilhar",
    "escovilhámo": "escovilhar",
    "escovilhámos": "escovilhar",
    "escovilháramo": "escovilhar",
    "escovilháramos": "escovilhar",
    "escovilhárei": "escovilhar",
    "escovilháreis": "escovilhar",
    "escovilhásseis": "escovilhar",
    "escovilhássemos": "escovilhar",
    "escovilhávamo": "escovilhar",
    "escovilhávamos": "escovilhar",
    "escovilhávei": "escovilhar",
    "escovilháveis": "escovilhar",
    "escovilhões": "escovilhão",
    "escovinha": "escova",
    "escovinhas": "escovinha",
    "escovita": "escova",
    "escovitas": "escova",
    "escovo": "escovar",
    "escovou": "escovar",
    "escová": "escovar",
    "escovámo": "escovar",
    "escovámos": "escovar",
    "escováramo": "escovar",
    "escováramos": "escovar",
    "escovárei": "escovar",
    "escováreis": "escovar",
    "escovásseis": "escovar",
    "escovássemos": "escovar",
    "escovávamo": "escovar",
    "escovávamos": "escovar",
    "escovávei": "escovar",
    "escováveis": "escovar",
    "escovéns": "escovém",
    "escozica": "escozicar",
    "escozicada": "escozicar",
    "escozicadas": "escozicar",
    "escozicado": "escozicar",
    "escozicados": "escozicar",
    "escozicai": "escozicar",
    "escozicais": "escozicar",
    "escozicam": "escozicar",
    "escozicamo": "escozicar",
    "escozicamos": "escozicar",
    "escozicando": "escozicar",
    "escozicara": "escozicar",
    "escozicaram": "escozicar",
    "escozicaras": "escozicar",
    "escozicarde": "escozicar",
    "escozicardes": "escozicar",
    "escozicare": "escozicar",
    "escozicarei": "escozicar",
    "escozicareis": "escozicar",
    "escozicarem": "escozicar",
    "escozicaremos": "escozicar",
    "escozicares": "escozicar",
    "escozicaria": "escozicar",
    "escozicariam": "escozicar",
    "escozicarias": "escozicar",
    "escozicarmo": "escozicar",
    "escozicarmos": "escozicar",
    "escozicará": "escozicar",
    "escozicarás": "escozicar",
    "escozicarão": "escozicar",
    "escozicaríamos": "escozicar",
    "escozicaríeis": "escozicar",
    "escozicas": "escozicar",
    "escozicasse": "escozicar",
    "escozicassem": "escozicar",
    "escozicasses": "escozicar",
    "escozicaste": "escozicar",
    "escozicastes": "escozicar",
    "escozicava": "escozicar",
    "escozicavam": "escozicar",
    "escozicavas": "escozicar",
    "escozico": "escozicar",
    "escozicou": "escozicar",
    "escozicá": "escozicar",
    "escozicámo": "escozicar",
    "escozicámos": "escozicar",
    "escozicáramo": "escozicar",
    "escozicáramos": "escozicar",
    "escozicárei": "escozicar",
    "escozicáreis": "escozicar",
    "escozicásseis": "escozicar",
    "escozicássemos": "escozicar",
    "escozicávamo": "escozicar",
    "escozicávamos": "escozicar",
    "escozicávei": "escozicar",
    "escozicáveis": "escozicar",
    "escozique": "escozicar",
    "escoziquei": "escozicar",
    "escoziqueis": "escozicar",
    "escoziquem": "escozicar",
    "escoziquemo": "escozicar",
    "escoziquemos": "escozicar",
    "escoziques": "escozicar",
    "escoá": "escoar",
    "escoámo": "escoar",
    "escoámos": "escoar",
    "escoáramo": "escoar",
    "escoáramos": "escoar",
    "escoárei": "escoar",
    "escoáreis": "escoar",
    "escoásseis": "escoar",
    "escoássemos": "escoar",
    "escoávamo": "escoar",
    "escoávamos": "escoar",
    "escoávei": "escoar",
    "escoáveis": "escoar",
    "escrapiadas": "escrapiada",
    "escrava": "escravo",
    "escravagistas": "escravagista",
    "escravarias": "escravaria",
    "escravas": "escravo",
    "escravaturas": "escravatura",
    "escravidões": "escravidão",
    "escraviza": "escravizar",
    "escravizada": "escravizar",
    "escravizadas": "escravizar",
    "escravizado": "escravizar",
    "escravizadora": "escravizador",
    "escravizadoras": "escravizador",
    "escravizadores": "escravizador",
    "escravizados": "escravizar",
    "escravizai": "escravizar",
    "escravizais": "escravizar",
    "escravizam": "escravizar",
    "escravizamo": "escravizar",
    "escravizamos": "escravizar",
    "escravizando": "escravizar",
    "escravizara": "escravizar",
    "escravizaram": "escravizar",
    "escravizaras": "escravizar",
    "escravizarde": "escravizar",
    "escravizardes": "escravizar",
    "escravizare": "escravizar",
    "escravizarei": "escravizar",
    "escravizareis": "escravizar",
    "escravizarem": "escravizar",
    "escravizaremos": "escravizar",
    "escravizares": "escravizar",
    "escravizaria": "escravizar",
    "escravizariam": "escravizar",
    "escravizarias": "escravizar",
    "escravizarmo": "escravizar",
    "escravizarmos": "escravizar",
    "escravizará": "escravizar",
    "escravizarás": "escravizar",
    "escravizarão": "escravizar",
    "escravizaríamos": "escravizar",
    "escravizaríeis": "escravizar",
    "escravizas": "escravizar",
    "escravizasse": "escravizar",
    "escravizassem": "escravizar",
    "escravizasses": "escravizar",
    "escravizaste": "escravizar",
    "escravizastes": "escravizar",
    "escravizava": "escravizar",
    "escravizavam": "escravizar",
    "escravizavas": "escravizar",
    "escravizações": "escravização",
    "escravize": "escravizar",
    "escravizei": "escravizar",
    "escravizeis": "escravizar",
    "escravizem": "escravizar",
    "escravizemo": "escravizar",
    "escravizemos": "escravizar",
    "escravizes": "escravizar",
    "escravizo": "escravizar",
    "escravizou": "escravizar",
    "escravizá": "escravizar",
    "escravizámo": "escravizar",
    "escravizámos": "escravizar",
    "escravizáramo": "escravizar",
    "escravizáramos": "escravizar",
    "escravizárei": "escravizar",
    "escravizáreis": "escravizar",
    "escravizásseis": "escravizar",
    "escravizássemos": "escravizar",
    "escravizávamo": "escravizar",
    "escravizávamos": "escravizar",
    "escravizávei": "escravizar",
    "escravizáveis": "escravizar",
    "escravocratas": "escravocrata",
    "escravos": "escravo",
    "escreva": "escrever",
    "escrevais": "escrever",
    "escrevam": "escrever",
    "escrevamo": "escrever",
    "escrevamos": "escrever",
    "escrevas": "escrever",
    "escreve": "escrever",
    "escrevedeiras": "escrevedeira",
    "escrevedora": "escrevedor",
    "escrevedoras": "escrevedor",
    "escrevedores": "escrevedor",
    "escreveduras": "escrevedura",
    "escrevei": "escrever",
    "escreveis": "escrever",
    "escrevem": "escrever",
    "escrevemo": "escrever",
    "escrevemos": "escrever",
    "escrevendo": "escrever",
    "escreveninas": "escrevenina",
    "escreventes": "escrevente",
    "escrevera": "escrever",
    "escreveram": "escrever",
    "escreveras": "escrever",
    "escreverde": "escrever",
    "escreverdes": "escrever",
    "escrevere": "escrever",
    "escreverei": "escrever",
    "escrevereis": "escrever",
    "escreverem": "escrever",
    "escreveremos": "escrever",
    "escreveres": "escrever",
    "escreveria": "escrever",
    "escreveriam": "escrever",
    "escreverias": "escrever",
    "escrevermo": "escrever",
    "escrevermos": "escrever",
    "escreverá": "escrever",
    "escreverás": "escrever",
    "escreverão": "escrever",
    "escreveríamos": "escrever",
    "escreveríeis": "escrever",
    "escreves": "escrever",
    "escrevesse": "escrever",
    "escrevessem": "escrever",
    "escrevesses": "escrever",
    "escreveste": "escrever",
    "escrevestes": "escrever",
    "escreveu": "escrever",
    "escrevi": "escrever",
    "escrevia": "escrever",
    "escreviam": "escrever",
    "escrevias": "escrever",
    "escrevinha": "escrevinhar",
    "escrevinhada": "escrevinhar",
    "escrevinhadas": "escrevinhar",
    "escrevinhado": "escrevinhar",
    "escrevinhadora": "escrevinhador",
    "escrevinhadoras": "escrevinhador",
    "escrevinhadores": "escrevinhador",
    "escrevinhados": "escrevinhar",
    "escrevinhaduras": "escrevinhadura",
    "escrevinhai": "escrevinhar",
    "escrevinhais": "escrevinhar",
    "escrevinham": "escrevinhar",
    "escrevinhamo": "escrevinhar",
    "escrevinhamos": "escrevinhar",
    "escrevinhando": "escrevinhar",
    "escrevinhara": "escrevinhar",
    "escrevinharam": "escrevinhar",
    "escrevinharas": "escrevinhar",
    "escrevinharde": "escrevinhar",
    "escrevinhardes": "escrevinhar",
    "escrevinhare": "escrevinhar",
    "escrevinharei": "escrevinhar",
    "escrevinhareis": "escrevinhar",
    "escrevinharem": "escrevinhar",
    "escrevinharemos": "escrevinhar",
    "escrevinhares": "escrevinhar",
    "escrevinharia": "escrevinhar",
    "escrevinhariam": "escrevinhar",
    "escrevinharias": "escrevinhar",
    "escrevinharmo": "escrevinhar",
    "escrevinharmos": "escrevinhar",
    "escrevinhará": "escrevinhar",
    "escrevinharás": "escrevinhar",
    "escrevinharão": "escrevinhar",
    "escrevinharíamos": "escrevinhar",
    "escrevinharíeis": "escrevinhar",
    "escrevinhas": "escrevinhar",
    "escrevinhasse": "escrevinhar",
    "escrevinhassem": "escrevinhar",
    "escrevinhasses": "escrevinhar",
    "escrevinhaste": "escrevinhar",
    "escrevinhastes": "escrevinhar",
    "escrevinhava": "escrevinhar",
    "escrevinhavam": "escrevinhar",
    "escrevinhavas": "escrevinhar",
    "escrevinhe": "escrevinhar",
    "escrevinhei": "escrevinhar",
    "escrevinheis": "escrevinhar",
    "escrevinhem": "escrevinhar",
    "escrevinhemo": "escrevinhar",
    "escrevinhemos": "escrevinhar",
    "escrevinhes": "escrevinhar",
    "escrevinho": "escrevinhar",
    "escrevinhou": "escrevinhar",
    "escrevinhá": "escrevinhar",
    "escrevinhámo": "escrevinhar",
    "escrevinhámos": "escrevinhar",
    "escrevinháramo": "escrevinhar",
    "escrevinháramos": "escrevinhar",
    "escrevinhárei": "escrevinhar",
    "escrevinháreis": "escrevinhar",
    "escrevinhásseis": "escrevinhar",
    "escrevinhássemos": "escrevinhar",
    "escrevinhávamo": "escrevinhar",
    "escrevinhávamos": "escrevinhar",
    "escrevinhávei": "escrevinhar",
    "escrevinháveis": "escrevinhar",
    "escrevo": "escrever",
    "escrevê": "escrever",
    "escrevêramo": "escrever",
    "escrevêramos": "escrever",
    "escrevêrei": "escrever",
    "escrevêreis": "escrever",
    "escrevêsseis": "escrever",
    "escrevêssemos": "escrever",
    "escrevíamo": "escrever",
    "escrevíamos": "escrever",
    "escrevíei": "escrever",
    "escrevíeis": "escrever",
    "escribas": "escriba",
    "escribomanias": "escribomania",
    "escribomaníaca": "escribomaníaco",
    "escribomaníacas": "escribomaníaco",
    "escribomaníacos": "escribomaníaco",
    "escribómana": "escribómano",
    "escribómanas": "escribómano",
    "escribómanos": "escribómano",
    "escrinhos": "escrinho",
    "escrita": "escrito",
    "escritas": "escrito",
    "escrito": "escrever",
    "escritora": "escritor",
    "escritoras": "escritor",
    "escritores": "escritor",
    "escritos": "escrito",
    "escritura": "escriturar",
    "escriturada": "escriturar",
    "escrituradas": "escriturar",
    "escriturado": "escriturar",
    "escriturados": "escriturar",
    "escriturai": "escriturar",
    "escriturais": "escriturar",
    "escrituram": "escriturar",
    "escrituramo": "escriturar",
    "escrituramos": "escriturar",
    "escriturando": "escriturar",
    "escriturara": "escriturar",
    "escrituraram": "escriturar",
    "escrituraras": "escriturar",
    "escriturarde": "escriturar",
    "escriturardes": "escriturar",
    "escriturare": "escriturar",
    "escriturarei": "escriturar",
    "escriturareis": "escriturar",
    "escriturarem": "escriturar",
    "escrituraremos": "escriturar",
    "escriturares": "escriturar",
    "escrituraria": "escriturar",
    "escriturariam": "escriturar",
    "escriturarias": "escriturar",
    "escriturarmo": "escriturar",
    "escriturarmos": "escriturar",
    "escriturará": "escriturar",
    "escriturarás": "escriturar",
    "escriturarão": "escriturar",
    "escrituraríamos": "escriturar",
    "escrituraríeis": "escriturar",
    "escrituras": "escriturar",
    "escriturasse": "escriturar",
    "escriturassem": "escriturar",
    "escriturasses": "escriturar",
    "escrituraste": "escriturar",
    "escriturastes": "escriturar",
    "escriturava": "escriturar",
    "escrituravam": "escriturar",
    "escrituravas": "escriturar",
    "escriturações": "escrituração",
    "escriture": "escriturar",
    "escriturei": "escriturar",
    "escritureis": "escriturar",
    "escriturem": "escriturar",
    "escrituremo": "escriturar",
    "escrituremos": "escriturar",
    "escritures": "escriturar",
    "escrituro": "escriturar",
    "escriturou": "escriturar",
    "escriturá": "escriturar",
    "escriturámo": "escriturar",
    "escriturámos": "escriturar",
    "escrituráramo": "escriturar",
    "escrituráramos": "escriturar",
    "escriturárei": "escriturar",
    "escrituráreis": "escriturar",
    "escriturária": "escriturário",
    "escriturárias": "escriturário",
    "escriturários": "escriturário",
    "escriturásseis": "escriturar",
    "escriturássemos": "escriturar",
    "escriturávamo": "escriturar",
    "escriturávamos": "escriturar",
    "escriturávei": "escriturar",
    "escrituráveis": "escriturar",
    "escritórios": "escritório",
    "escriva": "escrivar",
    "escrivada": "escrivar",
    "escrivadas": "escrivar",
    "escrivado": "escrivar",
    "escrivados": "escrivar",
    "escrivai": "escrivar",
    "escrivais": "escrivar",
    "escrivam": "escrivar",
    "escrivamo": "escrivar",
    "escrivamos": "escrivar",
    "escrivando": "escrivar",
    "escrivanias": "escrivania",
    "escrivaninhas": "escrivaninha",
    "escrivara": "escrivar",
    "escrivaram": "escrivar",
    "escrivaras": "escrivar",
    "escrivarde": "escrivar",
    "escrivardes": "escrivar",
    "escrivare": "escrivar",
    "escrivarei": "escrivar",
    "escrivareis": "escrivar",
    "escrivarem": "escrivar",
    "escrivaremos": "escrivar",
    "escrivares": "escrivar",
    "escrivaria": "escrivar",
    "escrivariam": "escrivar",
    "escrivarias": "escrivar",
    "escrivarmo": "escrivar",
    "escrivarmos": "escrivar",
    "escrivará": "escrivar",
    "escrivarás": "escrivar",
    "escrivarão": "escrivar",
    "escrivaríamos": "escrivar",
    "escrivaríeis": "escrivar",
    "escrivas": "escrivar",
    "escrivasse": "escrivar",
    "escrivassem": "escrivar",
    "escrivasses": "escrivar",
    "escrivaste": "escrivar",
    "escrivastes": "escrivar",
    "escrivava": "escrivar",
    "escrivavam": "escrivar",
    "escrivavas": "escrivar",
    "escrive": "escrivar",
    "escrivei": "escrivar",
    "escriveis": "escrivar",
    "escrivem": "escrivar",
    "escrivemo": "escrivar",
    "escrivemos": "escrivar",
    "escrives": "escrivar",
    "escrivo": "escrivar",
    "escrivou": "escrivar",
    "escrivá": "escrivar",
    "escrivámo": "escrivar",
    "escrivámos": "escrivar",
    "escriváramo": "escrivar",
    "escriváramos": "escrivar",
    "escrivárei": "escrivar",
    "escriváreis": "escrivar",
    "escrivásseis": "escrivar",
    "escrivássemos": "escrivar",
    "escrivávamo": "escrivar",
    "escrivávamos": "escrivar",
    "escrivávei": "escrivar",
    "escriváveis": "escrivar",
    "escrivã": "escrivão",
    "escrivães": "escrivão",
    "escrivãs": "escrivão",
    "escrofulariáceas": "escrofulariácea",
    "escrofulismos": "escrofulismo",
    "escrofulosa": "escrofuloso",
    "escrofulosas": "escrofuloso",
    "escrofuloses": "escrofulose",
    "escrofulosos": "escrofuloso",
    "escrofulárias": "escrofulária",
    "escroques": "escroque",
    "escrotais": "escrotal",
    "escrotos": "escroto",
    "escruncha": "escrunchar",
    "escrunchada": "escrunchar",
    "escrunchadas": "escrunchar",
    "escrunchado": "escrunchar",
    "escrunchados": "escrunchar",
    "escrunchai": "escrunchar",
    "escrunchais": "escrunchar",
    "escruncham": "escrunchar",
    "escrunchamo": "escrunchar",
    "escrunchamos": "escrunchar",
    "escrunchando": "escrunchar",
    "escrunchara": "escrunchar",
    "escruncharam": "escrunchar",
    "escruncharas": "escrunchar",
    "escruncharde": "escrunchar",
    "escrunchardes": "escrunchar",
    "escrunchare": "escrunchar",
    "escruncharei": "escrunchar",
    "escrunchareis": "escrunchar",
    "escruncharem": "escrunchar",
    "escruncharemos": "escrunchar",
    "escrunchares": "escrunchar",
    "escruncharia": "escrunchar",
    "escrunchariam": "escrunchar",
    "escruncharias": "escrunchar",
    "escruncharmo": "escrunchar",
    "escruncharmos": "escrunchar",
    "escrunchará": "escrunchar",
    "escruncharás": "escrunchar",
    "escruncharão": "escrunchar",
    "escruncharíamos": "escrunchar",
    "escruncharíeis": "escrunchar",
    "escrunchas": "escrunchar",
    "escrunchasse": "escrunchar",
    "escrunchassem": "escrunchar",
    "escrunchasses": "escrunchar",
    "escrunchaste": "escrunchar",
    "escrunchastes": "escrunchar",
    "escrunchava": "escrunchar",
    "escrunchavam": "escrunchar",
    "escrunchavas": "escrunchar",
    "escrunche": "escrunchar",
    "escrunchei": "escrunchar",
    "escruncheis": "escrunchar",
    "escrunchem": "escrunchar",
    "escrunchemo": "escrunchar",
    "escrunchemos": "escrunchar",
    "escrunches": "escrunchar",
    "escruncho": "escrunchar",
    "escrunchou": "escrunchar",
    "escrunchá": "escrunchar",
    "escrunchámo": "escrunchar",
    "escrunchámos": "escrunchar",
    "escruncháramo": "escrunchar",
    "escruncháramos": "escrunchar",
    "escrunchárei": "escrunchar",
    "escruncháreis": "escrunchar",
    "escrunchásseis": "escrunchar",
    "escrunchássemos": "escrunchar",
    "escrunchávamo": "escrunchar",
    "escrunchávamos": "escrunchar",
    "escrunchávei": "escrunchar",
    "escruncháveis": "escrunchar",
    "escrupularias": "escrupularia",
    "escrupuleada": "escrupulear",
    "escrupuleadas": "escrupulear",
    "escrupuleado": "escrupulear",
    "escrupuleados": "escrupulear",
    "escrupuleai": "escrupulear",
    "escrupuleais": "escrupulear",
    "escrupuleamo": "escrupulear",
    "escrupuleamos": "escrupulear",
    "escrupuleando": "escrupulear",
    "escrupuleara": "escrupulear",
    "escrupulearam": "escrupulear",
    "escrupulearas": "escrupulear",
    "escrupuleardes": "escrupulear",
    "escrupulearei": "escrupulear",
    "escrupuleareis": "escrupulear",
    "escrupulearem": "escrupulear",
    "escrupulearemos": "escrupulear",
    "escrupuleares": "escrupulear",
    "escrupulearia": "escrupulear",
    "escrupuleariam": "escrupulear",
    "escrupulearias": "escrupulear",
    "escrupulearmo": "escrupulear",
    "escrupulearmos": "escrupulear",
    "escrupuleará": "escrupulear",
    "escrupulearás": "escrupulear",
    "escrupulearão": "escrupulear",
    "escrupulearíamos": "escrupulear",
    "escrupulearíeis": "escrupulear",
    "escrupuleasse": "escrupulear",
    "escrupuleassem": "escrupulear",
    "escrupuleasses": "escrupulear",
    "escrupuleaste": "escrupulear",
    "escrupuleastes": "escrupulear",
    "escrupuleava": "escrupulear",
    "escrupuleavam": "escrupulear",
    "escrupuleavas": "escrupulear",
    "escrupuleei": "escrupulear",
    "escrupuleeis": "escrupulear",
    "escrupuleemo": "escrupulear",
    "escrupuleemos": "escrupulear",
    "escrupuleia": "escrupulear",
    "escrupuleiam": "escrupulear",
    "escrupuleias": "escrupulear",
    "escrupuleie": "escrupulear",
    "escrupuleiem": "escrupulear",
    "escrupuleies": "escrupulear",
    "escrupuleio": "escrupulear",
    "escrupuleou": "escrupulear",
    "escrupuleámo": "escrupulear",
    "escrupuleámos": "escrupulear",
    "escrupuleáramo": "escrupulear",
    "escrupuleáramos": "escrupulear",
    "escrupuleáreis": "escrupulear",
    "escrupuleásseis": "escrupulear",
    "escrupuleássemos": "escrupulear",
    "escrupuleávamo": "escrupulear",
    "escrupuleávamos": "escrupulear",
    "escrupuleáveis": "escrupulear",
    "escrupuliza": "escrupulizar",
    "escrupulizada": "escrupulizar",
    "escrupulizadas": "escrupulizar",
    "escrupulizado": "escrupulizar",
    "escrupulizados": "escrupulizar",
    "escrupulizai": "escrupulizar",
    "escrupulizais": "escrupulizar",
    "escrupulizam": "escrupulizar",
    "escrupulizamo": "escrupulizar",
    "escrupulizamos": "escrupulizar",
    "escrupulizando": "escrupulizar",
    "escrupulizara": "escrupulizar",
    "escrupulizaram": "escrupulizar",
    "escrupulizaras": "escrupulizar",
    "escrupulizarde": "escrupulizar",
    "escrupulizardes": "escrupulizar",
    "escrupulizare": "escrupulizar",
    "escrupulizarei": "escrupulizar",
    "escrupulizareis": "escrupulizar",
    "escrupulizarem": "escrupulizar",
    "escrupulizaremos": "escrupulizar",
    "escrupulizares": "escrupulizar",
    "escrupulizaria": "escrupulizar",
    "escrupulizariam": "escrupulizar",
    "escrupulizarias": "escrupulizar",
    "escrupulizarmo": "escrupulizar",
    "escrupulizarmos": "escrupulizar",
    "escrupulizará": "escrupulizar",
    "escrupulizarás": "escrupulizar",
    "escrupulizarão": "escrupulizar",
    "escrupulizaríamos": "escrupulizar",
    "escrupulizaríeis": "escrupulizar",
    "escrupulizas": "escrupulizar",
    "escrupulizasse": "escrupulizar",
    "escrupulizassem": "escrupulizar",
    "escrupulizasses": "escrupulizar",
    "escrupulizaste": "escrupulizar",
    "escrupulizastes": "escrupulizar",
    "escrupulizava": "escrupulizar",
    "escrupulizavam": "escrupulizar",
    "escrupulizavas": "escrupulizar",
    "escrupulize": "escrupulizar",
    "escrupulizei": "escrupulizar",
    "escrupulizeis": "escrupulizar",
    "escrupulizem": "escrupulizar",
    "escrupulizemo": "escrupulizar",
    "escrupulizemos": "escrupulizar",
    "escrupulizes": "escrupulizar",
    "escrupulizo": "escrupulizar",
    "escrupulizou": "escrupulizar",
    "escrupulizá": "escrupulizar",
    "escrupulizámo": "escrupulizar",
    "escrupulizámos": "escrupulizar",
    "escrupulizáramo": "escrupulizar",
    "escrupulizáramos": "escrupulizar",
    "escrupulizárei": "escrupulizar",
    "escrupulizáreis": "escrupulizar",
    "escrupulizásseis": "escrupulizar",
    "escrupulizássemos": "escrupulizar",
    "escrupulizávamo": "escrupulizar",
    "escrupulizávamos": "escrupulizar",
    "escrupulizávei": "escrupulizar",
    "escrupulizáveis": "escrupulizar",
    "escrupulosa": "escrupuloso",
    "escrupulosas": "escrupuloso",
    "escrupulosidades": "escrupulosidade",
    "escrupulosos": "escrupuloso",
    "escruta": "escrutar",
    "escrutada": "escrutar",
    "escrutadas": "escrutar",
    "escrutado": "escrutar",
    "escrutadora": "escrutador",
    "escrutadoras": "escrutador",
    "escrutadores": "escrutador",
    "escrutados": "escrutar",
    "escrutai": "escrutar",
    "escrutais": "escrutar",
    "escrutam": "escrutar",
    "escrutamo": "escrutar",
    "escrutamos": "escrutar",
    "escrutando": "escrutar",
    "escrutara": "escrutar",
    "escrutaram": "escrutar",
    "escrutaras": "escrutar",
    "escrutarde": "escrutar",
    "escrutardes": "escrutar",
    "escrutare": "escrutar",
    "escrutarei": "escrutar",
    "escrutareis": "escrutar",
    "escrutarem": "escrutar",
    "escrutaremos": "escrutar",
    "escrutares": "escrutar",
    "escrutaria": "escrutar",
    "escrutariam": "escrutar",
    "escrutarias": "escrutar",
    "escrutarmo": "escrutar",
    "escrutarmos": "escrutar",
    "escrutará": "escrutar",
    "escrutarás": "escrutar",
    "escrutarão": "escrutar",
    "escrutaríamos": "escrutar",
    "escrutaríeis": "escrutar",
    "escrutas": "escrutar",
    "escrutasse": "escrutar",
    "escrutassem": "escrutar",
    "escrutasses": "escrutar",
    "escrutaste": "escrutar",
    "escrutastes": "escrutar",
    "escrutava": "escrutar",
    "escrutavam": "escrutar",
    "escrutavas": "escrutar",
    "escrutações": "escrutação",
    "escrute": "escrutar",
    "escrutei": "escrutar",
    "escruteis": "escrutar",
    "escrutem": "escrutar",
    "escrutemo": "escrutar",
    "escrutemos": "escrutar",
    "escrutes": "escrutar",
    "escrutina": "escrutinar",
    "escrutinada": "escrutinar",
    "escrutinadas": "escrutinar",
    "escrutinado": "escrutinar",
    "escrutinadora": "escrutinador",
    "escrutinadoras": "escrutinador",
    "escrutinadores": "escrutinador",
    "escrutinados": "escrutinar",
    "escrutinai": "escrutinar",
    "escrutinais": "escrutinar",
    "escrutinam": "escrutinar",
    "escrutinamo": "escrutinar",
    "escrutinamos": "escrutinar",
    "escrutinando": "escrutinar",
    "escrutinara": "escrutinar",
    "escrutinaram": "escrutinar",
    "escrutinaras": "escrutinar",
    "escrutinarde": "escrutinar",
    "escrutinardes": "escrutinar",
    "escrutinare": "escrutinar",
    "escrutinarei": "escrutinar",
    "escrutinareis": "escrutinar",
    "escrutinarem": "escrutinar",
    "escrutinaremos": "escrutinar",
    "escrutinares": "escrutinar",
    "escrutinaria": "escrutinar",
    "escrutinariam": "escrutinar",
    "escrutinarias": "escrutinar",
    "escrutinarmo": "escrutinar",
    "escrutinarmos": "escrutinar",
    "escrutinará": "escrutinar",
    "escrutinarás": "escrutinar",
    "escrutinarão": "escrutinar",
    "escrutinaríamos": "escrutinar",
    "escrutinaríeis": "escrutinar",
    "escrutinas": "escrutinar",
    "escrutinasse": "escrutinar",
    "escrutinassem": "escrutinar",
    "escrutinasses": "escrutinar",
    "escrutinaste": "escrutinar",
    "escrutinastes": "escrutinar",
    "escrutinava": "escrutinar",
    "escrutinavam": "escrutinar",
    "escrutinavas": "escrutinar",
    "escrutinações": "escrutinação",
    "escrutine": "escrutinar",
    "escrutinei": "escrutinar",
    "escrutineis": "escrutinar",
    "escrutinem": "escrutinar",
    "escrutinemo": "escrutinar",
    "escrutinemos": "escrutinar",
    "escrutines": "escrutinar",
    "escrutino": "escrutinar",
    "escrutinou": "escrutinar",
    "escrutiná": "escrutinar",
    "escrutinámo": "escrutinar",
    "escrutinámos": "escrutinar",
    "escrutináramo": "escrutinar",
    "escrutináramos": "escrutinar",
    "escrutinárei": "escrutinar",
    "escrutináreis": "escrutinar",
    "escrutinásseis": "escrutinar",
    "escrutinássemos": "escrutinar",
    "escrutinávamo": "escrutinar",
    "escrutinávamos": "escrutinar",
    "escrutinávei": "escrutinar",
    "escrutináveis": "escrutinável",
    "escruto": "escrutar",
    "escrutou": "escrutar",
    "escrutá": "escrutar",
    "escrutámo": "escrutar",
    "escrutámos": "escrutar",
    "escrutáramo": "escrutar",
    "escrutáramos": "escrutar",
    "escrutárei": "escrutar",
    "escrutáreis": "escrutar",
    "escrutásseis": "escrutar",
    "escrutássemos": "escrutar",
    "escrutávamo": "escrutar",
    "escrutávamos": "escrutar",
    "escrutávei": "escrutar",
    "escrutáveis": "escrutável",
    "escrutínios": "escrutínio",
    "escrínios": "escrínio",
    "escrófulas": "escrófula",
    "escrópulos": "escrópulo",
    "escrúpulos": "escrúpulo",
    "escuda": "escudar",
    "escudada": "escudar",
    "escudadas": "escudar",
    "escudado": "escudar",
    "escudados": "escudar",
    "escudai": "escudar",
    "escudais": "escudar",
    "escudam": "escudar",
    "escudamo": "escudar",
    "escudamos": "escudar",
    "escudando": "escudar",
    "escudara": "escudar",
    "escudaram": "escudar",
    "escudaras": "escudar",
    "escudarde": "escudar",
    "escudardes": "escudar",
    "escudare": "escudar",
    "escudarei": "escudar",
    "escudareis": "escudar",
    "escudarem": "escudar",
    "escudaremos": "escudar",
    "escudares": "escudar",
    "escudaria": "escudar",
    "escudariam": "escudar",
    "escudarias": "escudar",
    "escudarmo": "escudar",
    "escudarmos": "escudar",
    "escudará": "escudar",
    "escudarás": "escudar",
    "escudarão": "escudar",
    "escudaríamos": "escudar",
    "escudaríeis": "escudar",
    "escudas": "escudar",
    "escudasse": "escudar",
    "escudassem": "escudar",
    "escudasses": "escudar",
    "escudaste": "escudar",
    "escudastes": "escudar",
    "escudava": "escudar",
    "escudavam": "escudar",
    "escudavas": "escudar",
    "escude": "escudar",
    "escudei": "escudar",
    "escudeira": "escudeirar",
    "escudeirada": "escudeirar",
    "escudeiradas": "escudeirar",
    "escudeirado": "escudeirar",
    "escudeirados": "escudeirar",
    "escudeirai": "escudeirar",
    "escudeirais": "escudeirar",
    "escudeiram": "escudeirar",
    "escudeiramo": "escudeirar",
    "escudeiramos": "escudeirar",
    "escudeirando": "escudeirar",
    "escudeirara": "escudeirar",
    "escudeiraram": "escudeirar",
    "escudeiraras": "escudeirar",
    "escudeirarde": "escudeirar",
    "escudeirardes": "escudeirar",
    "escudeirare": "escudeirar",
    "escudeirarei": "escudeirar",
    "escudeirareis": "escudeirar",
    "escudeirarem": "escudeirar",
    "escudeiraremos": "escudeirar",
    "escudeirares": "escudeirar",
    "escudeiraria": "escudeirar",
    "escudeirariam": "escudeirar",
    "escudeirarias": "escudeirar",
    "escudeirarmo": "escudeirar",
    "escudeirarmos": "escudeirar",
    "escudeirará": "escudeirar",
    "escudeirarás": "escudeirar",
    "escudeirarão": "escudeirar",
    "escudeiraríamos": "escudeirar",
    "escudeiraríeis": "escudeirar",
    "escudeiras": "escudeirar",
    "escudeirasse": "escudeirar",
    "escudeirassem": "escudeirar",
    "escudeirasses": "escudeirar",
    "escudeiraste": "escudeirar",
    "escudeirastes": "escudeirar",
    "escudeirava": "escudeirar",
    "escudeiravam": "escudeirar",
    "escudeiravas": "escudeirar",
    "escudeire": "escudeirar",
    "escudeirei": "escudeirar",
    "escudeireis": "escudeirar",
    "escudeirem": "escudeirar",
    "escudeiremo": "escudeirar",
    "escudeiremos": "escudeirar",
    "escudeires": "escudeirar",
    "escudeirices": "escudeirice",
    "escudeiro": "escudeirar",
    "escudeiros": "escudeiro",
    "escudeirou": "escudeirar",
    "escudeirá": "escudeirar",
    "escudeirámo": "escudeirar",
    "escudeirámos": "escudeirar",
    "escudeiráramo": "escudeirar",
    "escudeiráramos": "escudeirar",
    "escudeirárei": "escudeirar",
    "escudeiráreis": "escudeirar",
    "escudeirásseis": "escudeirar",
    "escudeirássemos": "escudeirar",
    "escudeirávamo": "escudeirar",
    "escudeirávamos": "escudeirar",
    "escudeirávei": "escudeirar",
    "escudeiráveis": "escudeirar",
    "escudeis": "escudar",
    "escudela": "escudelar",
    "escudelada": "escudelar",
    "escudeladas": "escudelar",
    "escudelado": "escudelar",
    "escudelados": "escudelar",
    "escudelai": "escudelar",
    "escudelais": "escudelar",
    "escudelam": "escudelar",
    "escudelamo": "escudelar",
    "escudelamos": "escudelar",
    "escudelando": "escudelar",
    "escudelara": "escudelar",
    "escudelaram": "escudelar",
    "escudelaras": "escudelar",
    "escudelarde": "escudelar",
    "escudelardes": "escudelar",
    "escudelare": "escudelar",
    "escudelarei": "escudelar",
    "escudelareis": "escudelar",
    "escudelarem": "escudelar",
    "escudelaremos": "escudelar",
    "escudelares": "escudelar",
    "escudelaria": "escudelar",
    "escudelariam": "escudelar",
    "escudelarias": "escudelar",
    "escudelarmo": "escudelar",
    "escudelarmos": "escudelar",
    "escudelará": "escudelar",
    "escudelarás": "escudelar",
    "escudelarão": "escudelar",
    "escudelaríamos": "escudelar",
    "escudelaríeis": "escudelar",
    "escudelas": "escudelar",
    "escudelasse": "escudelar",
    "escudelassem": "escudelar",
    "escudelasses": "escudelar",
    "escudelaste": "escudelar",
    "escudelastes": "escudelar",
    "escudelava": "escudelar",
    "escudelavam": "escudelar",
    "escudelavas": "escudelar",
    "escudele": "escudelar",
    "escudelei": "escudelar",
    "escudeleiros": "escudeleiro",
    "escudeleis": "escudelar",
    "escudelem": "escudelar",
    "escudelemo": "escudelar",
    "escudelemos": "escudelar",
    "escudeles": "escudelar",
    "escudelo": "escudelar",
    "escudelou": "escudelar",
    "escudelá": "escudelar",
    "escudelámo": "escudelar",
    "escudelámos": "escudelar",
    "escudeláramo": "escudelar",
    "escudeláramos": "escudelar",
    "escudelárei": "escudelar",
    "escudeláreis": "escudelar",
    "escudelásseis": "escudelar",
    "escudelássemos": "escudelar",
    "escudelávamo": "escudelar",
    "escudelávamos": "escudelar",
    "escudelávei": "escudelar",
    "escudeláveis": "escudelar",
    "escudem": "escudar",
    "escudemo": "escudar",
    "escudemos": "escudar",
    "escuderias": "escuderia",
    "escudes": "escudar",
    "escudetes": "escudete",
    "escudinhas": "escudinha",
    "escudo": "escudar",
    "escudos": "escudo",
    "escudou": "escudar",
    "escudá": "escudar",
    "escudámo": "escudar",
    "escudámos": "escudar",
    "escudáramo": "escudar",
    "escudáramos": "escudar",
    "escudárei": "escudar",
    "escudáreis": "escudar",
    "escudásseis": "escudar",
    "escudássemos": "escudar",
    "escudávamo": "escudar",
    "escudávamos": "escudar",
    "escudávei": "escudar",
    "escudáveis": "escudar",
    "esculcada": "esculcado",
    "esculcadas": "esculcado",
    "esculcados": "esculcado",
    "esculcas": "esculca",
    "esculenta": "esculento",
    "esculentas": "esculento",
    "esculentos": "esculento",
    "esculhambada": "esculhambado",
    "esculhambadas": "esculhambado",
    "esculhambados": "esculhambado",
    "esculinas": "esculina",
    "esculpa": "esculpir",
    "esculpais": "esculpir",
    "esculpam": "esculpir",
    "esculpamo": "esculpir",
    "esculpamos": "esculpir",
    "esculpas": "esculpir",
    "esculpe": "esculpir",
    "esculpem": "esculpir",
    "esculpes": "esculpir",
    "esculpi": "esculpir",
    "esculpia": "esculpir",
    "esculpiam": "esculpir",
    "esculpias": "esculpir",
    "esculpida": "esculpir",
    "esculpidas": "esculpir",
    "esculpido": "esculpir",
    "esculpidora": "esculpidor",
    "esculpidoras": "esculpidor",
    "esculpidores": "esculpidor",
    "esculpidos": "esculpir",
    "esculpimo": "esculpir",
    "esculpimos": "esculpir",
    "esculpindo": "esculpir",
    "esculpira": "esculpir",
    "esculpiram": "esculpir",
    "esculpiras": "esculpir",
    "esculpirde": "esculpir",
    "esculpirdes": "esculpir",
    "esculpire": "esculpir",
    "esculpirei": "esculpir",
    "esculpireis": "esculpir",
    "esculpirem": "esculpir",
    "esculpiremos": "esculpir",
    "esculpires": "esculpir",
    "esculpiria": "esculpir",
    "esculpiriam": "esculpir",
    "esculpirias": "esculpir",
    "esculpirmo": "esculpir",
    "esculpirmos": "esculpir",
    "esculpirá": "esculpir",
    "esculpirás": "esculpir",
    "esculpirão": "esculpir",
    "esculpiríamos": "esculpir",
    "esculpiríeis": "esculpir",
    "esculpis": "esculpir",
    "esculpisse": "esculpir",
    "esculpissem": "esculpir",
    "esculpisses": "esculpir",
    "esculpiste": "esculpir",
    "esculpistes": "esculpir",
    "esculpiu": "esculpir",
    "esculpo": "esculpir",
    "esculpíamo": "esculpir",
    "esculpíamos": "esculpir",
    "esculpíei": "esculpir",
    "esculpíeis": "esculpir",
    "esculpíramo": "esculpir",
    "esculpíramos": "esculpir",
    "esculpírei": "esculpir",
    "esculpíreis": "esculpir",
    "esculpísseis": "esculpir",
    "esculpíssemos": "esculpir",
    "esculpíveis": "esculpível",
    "escultora": "escultor",
    "escultoras": "escultor",
    "escultores": "escultor",
    "escultura": "esculturar",
    "esculturada": "esculturar",
    "esculturadas": "esculturar",
    "esculturado": "esculturar",
    "esculturados": "esculturar",
    "esculturai": "esculturar",
    "esculturais": "esculturar",
    "esculturam": "esculturar",
    "esculturamo": "esculturar",
    "esculturamos": "esculturar",
    "esculturando": "esculturar",
    "esculturara": "esculturar",
    "esculturaram": "esculturar",
    "esculturaras": "esculturar",
    "esculturarde": "esculturar",
    "esculturardes": "esculturar",
    "esculturare": "esculturar",
    "esculturarei": "esculturar",
    "esculturareis": "esculturar",
    "esculturarem": "esculturar",
    "esculturaremos": "esculturar",
    "esculturares": "esculturar",
    "esculturaria": "esculturar",
    "esculturariam": "esculturar",
    "esculturarias": "esculturar",
    "esculturarmo": "esculturar",
    "esculturarmos": "esculturar",
    "esculturará": "esculturar",
    "esculturarás": "esculturar",
    "esculturarão": "esculturar",
    "esculturaríamos": "esculturar",
    "esculturaríeis": "esculturar",
    "esculturas": "esculturar",
    "esculturasse": "esculturar",
    "esculturassem": "esculturar",
    "esculturasses": "esculturar",
    "esculturaste": "esculturar",
    "esculturastes": "esculturar",
    "esculturava": "esculturar",
    "esculturavam": "esculturar",
    "esculturavas": "esculturar",
    "esculture": "esculturar",
    "esculturei": "esculturar",
    "escultureis": "esculturar",
    "esculturem": "esculturar",
    "esculturemo": "esculturar",
    "esculturemos": "esculturar",
    "escultures": "esculturar",
    "esculturo": "esculturar",
    "esculturou": "esculturar",
    "esculturá": "esculturar",
    "esculturámo": "esculturar",
    "esculturámos": "esculturar",
    "esculturáramo": "esculturar",
    "esculturáramos": "esculturar",
    "esculturárei": "esculturar",
    "esculturáreis": "esculturar",
    "esculturásseis": "esculturar",
    "esculturássemos": "esculturar",
    "esculturávamo": "esculturar",
    "esculturávamos": "esculturar",
    "esculturávei": "esculturar",
    "esculturáveis": "esculturar",
    "escultórica": "escultórico",
    "escultóricas": "escultórico",
    "escultóricos": "escultórico",
    "esculápios": "esculápio",
    "escuma": "escumar",
    "escumada": "escumar",
    "escumadas": "escumar",
    "escumadeiras": "escumadeira",
    "escumado": "escumar",
    "escumadora": "escumador",
    "escumadoras": "escumador",
    "escumadores": "escumador",
    "escumados": "escumar",
    "escumai": "escumar",
    "escumais": "escumar",
    "escumalhas": "escumalha",
    "escumalhos": "escumalho",
    "escumam": "escumar",
    "escumamo": "escumar",
    "escumamos": "escumar",
    "escumando": "escumar",
    "escumantes": "escumante",
    "escumara": "escumar",
    "escumaradas": "escumarada",
    "escumaram": "escumar",
    "escumaras": "escumar",
    "escumardes": "escumar",
    "escumarei": "escumar",
    "escumareis": "escumar",
    "escumarem": "escumar",
    "escumaremos": "escumar",
    "escumares": "escumar",
    "escumaria": "escumar",
    "escumariam": "escumar",
    "escumarias": "escumar",
    "escumarmo": "escumar",
    "escumarmos": "escumar",
    "escumará": "escumar",
    "escumarás": "escumar",
    "escumarão": "escumar",
    "escumaríamos": "escumar",
    "escumaríeis": "escumar",
    "escumas": "escumar",
    "escumasse": "escumar",
    "escumassem": "escumar",
    "escumasses": "escumar",
    "escumaste": "escumar",
    "escumastes": "escumar",
    "escumava": "escumar",
    "escumavam": "escumar",
    "escumavas": "escumar",
    "escumações": "escumação",
    "escume": "escumar",
    "escumei": "escumar",
    "escumeis": "escumar",
    "escumem": "escumar",
    "escumemo": "escumar",
    "escumemos": "escumar",
    "escumes": "escumar",
    "escumilhas": "escumilha",
    "escumo": "escumar",
    "escumosa": "escumoso",
    "escumosas": "escumoso",
    "escumosos": "escumoso",
    "escumou": "escumar",
    "escumámo": "escumar",
    "escumámos": "escumar",
    "escumáramo": "escumar",
    "escumáramos": "escumar",
    "escumáreis": "escumar",
    "escumásseis": "escumar",
    "escumássemos": "escumar",
    "escumávamo": "escumar",
    "escumávamos": "escumar",
    "escumáveis": "escumar",
    "escunas": "escuna",
    "escupa": "escupir",
    "escupais": "escupir",
    "escupam": "escupir",
    "escupamo": "escupir",
    "escupamos": "escupir",
    "escupas": "escupir",
    "escupe": "escupir",
    "escupem": "escupir",
    "escupes": "escupir",
    "escupi": "escupir",
    "escupia": "escupir",
    "escupiam": "escupir",
    "escupias": "escupir",
    "escupida": "escupir",
    "escupidas": "escupir",
    "escupido": "escupir",
    "escupidos": "escupir",
    "escupimo": "escupir",
    "escupimos": "escupir",
    "escupindo": "escupir",
    "escupira": "escupir",
    "escupiram": "escupir",
    "escupiras": "escupir",
    "escupirde": "escupir",
    "escupirdes": "escupir",
    "escupire": "escupir",
    "escupirei": "escupir",
    "escupireis": "escupir",
    "escupirem": "escupir",
    "escupiremos": "escupir",
    "escupires": "escupir",
    "escupiria": "escupir",
    "escupiriam": "escupir",
    "escupirias": "escupir",
    "escupirmo": "escupir",
    "escupirmos": "escupir",
    "escupirá": "escupir",
    "escupirás": "escupir",
    "escupirão": "escupir",
    "escupiríamos": "escupir",
    "escupiríeis": "escupir",
    "escupis": "escupir",
    "escupisse": "escupir",
    "escupissem": "escupir",
    "escupisses": "escupir",
    "escupiste": "escupir",
    "escupistes": "escupir",
    "escupiu": "escupir",
    "escupo": "escupir",
    "escupíamo": "escupir",
    "escupíamos": "escupir",
    "escupíei": "escupir",
    "escupíeis": "escupir",
    "escupíramo": "escupir",
    "escupíramos": "escupir",
    "escupírei": "escupir",
    "escupíreis": "escupir",
    "escupísseis": "escupir",
    "escupíssemos": "escupir",
    "escura": "escuro",
    "escuras": "escuro",
    "escurece": "escurecer",
    "escurecedora": "escurecedor",
    "escurecedoras": "escurecedor",
    "escurecedores": "escurecedor",
    "escurecei": "escurecer",
    "escureceis": "escurecer",
    "escurecem": "escurecer",
    "escurecemo": "escurecer",
    "escurecemos": "escurecer",
    "escurecendo": "escurecer",
    "escurecera": "escurecer",
    "escureceram": "escurecer",
    "escureceras": "escurecer",
    "escurecerdes": "escurecer",
    "escurecerei": "escurecer",
    "escurecereis": "escurecer",
    "escurecerem": "escurecer",
    "escureceremos": "escurecer",
    "escureceres": "escurecer",
    "escureceria": "escurecer",
    "escureceriam": "escurecer",
    "escurecerias": "escurecer",
    "escurecermo": "escurecer",
    "escurecermos": "escurecer",
    "escurecerá": "escurecer",
    "escurecerás": "escurecer",
    "escurecerão": "escurecer",
    "escureceríamos": "escurecer",
    "escureceríeis": "escurecer",
    "escureces": "escurecer",
    "escurecesse": "escurecer",
    "escurecessem": "escurecer",
    "escurecesses": "escurecer",
    "escureceste": "escurecer",
    "escurecestes": "escurecer",
    "escureceu": "escurecer",
    "escureci": "escurecer",
    "escurecia": "escurecer",
    "escureciam": "escurecer",
    "escurecias": "escurecer",
    "escurecida": "escurecido",
    "escurecidas": "escurecido",
    "escurecido": "escurecer",
    "escurecidos": "escurecido",
    "escurecimentos": "escurecimento",
    "escurecêramo": "escurecer",
    "escurecêramos": "escurecer",
    "escurecêreis": "escurecer",
    "escurecêsseis": "escurecer",
    "escurecêssemos": "escurecer",
    "escurecíamo": "escurecer",
    "escurecíamos": "escurecer",
    "escurecíeis": "escurecer",
    "escurecíveis": "escurecível",
    "escureja": "escurejar",
    "escurejada": "escurejar",
    "escurejadas": "escurejar",
    "escurejado": "escurejar",
    "escurejados": "escurejar",
    "escurejai": "escurejar",
    "escurejais": "escurejar",
    "escurejam": "escurejar",
    "escurejamo": "escurejar",
    "escurejamos": "escurejar",
    "escurejando": "escurejar",
    "escurejara": "escurejar",
    "escurejaram": "escurejar",
    "escurejaras": "escurejar",
    "escurejarde": "escurejar",
    "escurejardes": "escurejar",
    "escurejare": "escurejar",
    "escurejarei": "escurejar",
    "escurejareis": "escurejar",
    "escurejarem": "escurejar",
    "escurejaremos": "escurejar",
    "escurejares": "escurejar",
    "escurejaria": "escurejar",
    "escurejariam": "escurejar",
    "escurejarias": "escurejar",
    "escurejarmo": "escurejar",
    "escurejarmos": "escurejar",
    "escurejará": "escurejar",
    "escurejarás": "escurejar",
    "escurejarão": "escurejar",
    "escurejaríamos": "escurejar",
    "escurejaríeis": "escurejar",
    "escurejas": "escurejar",
    "escurejasse": "escurejar",
    "escurejassem": "escurejar",
    "escurejasses": "escurejar",
    "escurejaste": "escurejar",
    "escurejastes": "escurejar",
    "escurejava": "escurejar",
    "escurejavam": "escurejar",
    "escurejavas": "escurejar",
    "escureje": "escurejar",
    "escurejei": "escurejar",
    "escurejeis": "escurejar",
    "escurejem": "escurejar",
    "escurejemo": "escurejar",
    "escurejemos": "escurejar",
    "escurejes": "escurejar",
    "escurejo": "escurejar",
    "escurejou": "escurejar",
    "escurejá": "escurejar",
    "escurejámo": "escurejar",
    "escurejámos": "escurejar",
    "escurejáramo": "escurejar",
    "escurejáramos": "escurejar",
    "escurejárei": "escurejar",
    "escurejáreis": "escurejar",
    "escurejásseis": "escurejar",
    "escurejássemos": "escurejar",
    "escurejávamo": "escurejar",
    "escurejávamos": "escurejar",
    "escurejávei": "escurejar",
    "escurejáveis": "escurejar",
    "escurenta": "escurentar",
    "escurentada": "escurentar",
    "escurentadas": "escurentar",
    "escurentado": "escurentar",
    "escurentados": "escurentar",
    "escurentai": "escurentar",
    "escurentais": "escurentar",
    "escurentam": "escurentar",
    "escurentamo": "escurentar",
    "escurentamos": "escurentar",
    "escurentando": "escurentar",
    "escurentara": "escurentar",
    "escurentaram": "escurentar",
    "escurentaras": "escurentar",
    "escurentarde": "escurentar",
    "escurentardes": "escurentar",
    "escurentare": "escurentar",
    "escurentarei": "escurentar",
    "escurentareis": "escurentar",
    "escurentarem": "escurentar",
    "escurentaremos": "escurentar",
    "escurentares": "escurentar",
    "escurentaria": "escurentar",
    "escurentariam": "escurentar",
    "escurentarias": "escurentar",
    "escurentarmo": "escurentar",
    "escurentarmos": "escurentar",
    "escurentará": "escurentar",
    "escurentarás": "escurentar",
    "escurentarão": "escurentar",
    "escurentaríamos": "escurentar",
    "escurentaríeis": "escurentar",
    "escurentas": "escurentar",
    "escurentasse": "escurentar",
    "escurentassem": "escurentar",
    "escurentasses": "escurentar",
    "escurentaste": "escurentar",
    "escurentastes": "escurentar",
    "escurentava": "escurentar",
    "escurentavam": "escurentar",
    "escurentavas": "escurentar",
    "escurente": "escurentar",
    "escurentei": "escurentar",
    "escurenteis": "escurentar",
    "escurentem": "escurentar",
    "escurentemo": "escurentar",
    "escurentemos": "escurentar",
    "escurentes": "escurentar",
    "escurento": "escurentar",
    "escurentou": "escurentar",
    "escurentá": "escurentar",
    "escurentámo": "escurentar",
    "escurentámos": "escurentar",
    "escurentáramo": "escurentar",
    "escurentáramos": "escurentar",
    "escurentárei": "escurentar",
    "escurentáreis": "escurentar",
    "escurentásseis": "escurentar",
    "escurentássemos": "escurentar",
    "escurentávamo": "escurentar",
    "escurentávamos": "escurentar",
    "escurentávei": "escurentar",
    "escurentáveis": "escurentar",
    "escurezas": "escureza",
    "escureça": "escurecer",
    "escureçais": "escurecer",
    "escureçam": "escurecer",
    "escureçamo": "escurecer",
    "escureçamos": "escurecer",
    "escureças": "escurecer",
    "escureço": "escurecer",
    "escuridades": "escuridade",
    "escuridões": "escuridão",
    "escurinha": "escuro",
    "escurinhas": "escuro",
    "escurinho": "escuro",
    "escurinhos": "escuro",
    "escurita": "escuro",
    "escuritas": "escuro",
    "escurito": "escuro",
    "escuritos": "escuro",
    "escuros": "escuro",
    "escurras": "escurra",
    "escurrilidades": "escurrilidade",
    "escurris": "escurril",
    "escusa": "escuso",
    "escusada": "escusar",
    "escusadas": "escusar",
    "escusado": "escusar",
    "escusados": "escusar",
    "escusai": "escusar",
    "escusais": "escusar",
    "escusam": "escusar",
    "escusamo": "escusar",
    "escusamos": "escusar",
    "escusando": "escusar",
    "escusara": "escusar",
    "escusaram": "escusar",
    "escusaras": "escusar",
    "escusarde": "escusar",
    "escusardes": "escusar",
    "escusare": "escusar",
    "escusarei": "escusar",
    "escusareis": "escusar",
    "escusarem": "escusar",
    "escusaremos": "escusar",
    "escusares": "escusar",
    "escusaria": "escusar",
    "escusariam": "escusar",
    "escusarias": "escusar",
    "escusarmo": "escusar",
    "escusarmos": "escusar",
    "escusará": "escusar",
    "escusarás": "escusar",
    "escusarão": "escusar",
    "escusaríamos": "escusar",
    "escusaríeis": "escusar",
    "escusas": "escuso",
    "escusasse": "escusar",
    "escusassem": "escusar",
    "escusasses": "escusar",
    "escusaste": "escusar",
    "escusastes": "escusar",
    "escusatória": "escusatório",
    "escusatórias": "escusatório",
    "escusatórios": "escusatório",
    "escusava": "escusar",
    "escusavam": "escusar",
    "escusavas": "escusar",
    "escuse": "escusar",
    "escusei": "escusar",
    "escuseis": "escusar",
    "escusem": "escusar",
    "escusemo": "escusar",
    "escusemos": "escusar",
    "escuses": "escusar",
    "escuso": "escusar",
    "escusos": "escuso",
    "escusou": "escusar",
    "escusá": "escusar",
    "escusámo": "escusar",
    "escusámos": "escusar",
    "escusáramo": "escusar",
    "escusáramos": "escusar",
    "escusárei": "escusar",
    "escusáreis": "escusar",
    "escusásseis": "escusar",
    "escusássemos": "escusar",
    "escusávamo": "escusar",
    "escusávamos": "escusar",
    "escusávei": "escusar",
    "escusáveis": "escusável",
    "escuta": "escutar",
    "escutada": "escutar",
    "escutadas": "escutar",
    "escutado": "escutar",
    "escutadora": "escutador",
    "escutadoras": "escutador",
    "escutadores": "escutador",
    "escutados": "escutar",
    "escutai": "escutar",
    "escutais": "escutar",
    "escutam": "escutar",
    "escutamo": "escutar",
    "escutamos": "escutar",
    "escutando": "escutar",
    "escutara": "escutar",
    "escutaram": "escutar",
    "escutaras": "escutar",
    "escutarde": "escutar",
    "escutardes": "escutar",
    "escutare": "escutar",
    "escutarei": "escutar",
    "escutareis": "escutar",
    "escutarem": "escutar",
    "escutaremos": "escutar",
    "escutares": "escutar",
    "escutaria": "escutar",
    "escutariam": "escutar",
    "escutarias": "escutar",
    "escutarmo": "escutar",
    "escutarmos": "escutar",
    "escutará": "escutar",
    "escutarás": "escutar",
    "escutarão": "escutar",
    "escutaríamos": "escutar",
    "escutaríeis": "escutar",
    "escutas": "escutar",
    "escutasse": "escutar",
    "escutassem": "escutar",
    "escutasses": "escutar",
    "escutaste": "escutar",
    "escutastes": "escutar",
    "escutava": "escutar",
    "escutavam": "escutar",
    "escutavas": "escutar",
    "escute": "escutar",
    "escutei": "escutar",
    "escuteira": "escuteiro",
    "escuteiras": "escuteiro",
    "escuteiros": "escuteiro",
    "escuteis": "escutar",
    "escutem": "escutar",
    "escutemo": "escutar",
    "escutemos": "escutar",
    "escutes": "escutar",
    "escutismos": "escutismo",
    "escutistas": "escutista",
    "escuto": "escutar",
    "escutou": "escutar",
    "escutá": "escutar",
    "escutámo": "escutar",
    "escutámos": "escutar",
    "escutáramo": "escutar",
    "escutáramos": "escutar",
    "escutárei": "escutar",
    "escutáreis": "escutar",
    "escutásseis": "escutar",
    "escutássemos": "escutar",
    "escutávamo": "escutar",
    "escutávamos": "escutar",
    "escutávei": "escutar",
    "escutáveis": "escutável",
    "escádeas": "escádea",
    "escápulas": "escápula",
    "escárnios": "escárnio",
    "escâmbios": "escâmbio",
    "escâmulas": "escâmula",
    "escâncaras": "escâncara",
    "escândalos": "escândalo",
    "escândeas": "escândea",
    "escândios": "escândio",
    "escãibos": "escãibo",
    "escócia": "escócio",
    "escócias": "escócio",
    "escócios": "escócio",
    "escóis": "escol",
    "escólexes": "escólex",
    "escólios": "escólio",
    "escórdios": "escórdio",
    "escórias": "escória",
    "escômbridas": "escômbrida",
    "esdruxula": "esdruxular",
    "esdruxulada": "esdruxular",
    "esdruxuladas": "esdruxular",
    "esdruxulado": "esdruxular",
    "esdruxulados": "esdruxular",
    "esdruxulai": "esdruxular",
    "esdruxulais": "esdruxular",
    "esdruxulam": "esdruxular",
    "esdruxulamo": "esdruxular",
    "esdruxulamos": "esdruxular",
    "esdruxulando": "esdruxular",
    "esdruxulara": "esdruxular",
    "esdruxularam": "esdruxular",
    "esdruxularas": "esdruxular",
    "esdruxularde": "esdruxular",
    "esdruxulardes": "esdruxular",
    "esdruxulare": "esdruxular",
    "esdruxularei": "esdruxular",
    "esdruxulareis": "esdruxular",
    "esdruxularem": "esdruxular",
    "esdruxularemos": "esdruxular",
    "esdruxulares": "esdruxular",
    "esdruxularia": "esdruxular",
    "esdruxulariam": "esdruxular",
    "esdruxularias": "esdruxularia",
    "esdruxularmo": "esdruxular",
    "esdruxularmos": "esdruxular",
    "esdruxulará": "esdruxular",
    "esdruxularás": "esdruxular",
    "esdruxularão": "esdruxular",
    "esdruxularíamos": "esdruxular",
    "esdruxularíeis": "esdruxular",
    "esdruxulas": "esdruxular",
    "esdruxulasse": "esdruxular",
    "esdruxulassem": "esdruxular",
    "esdruxulasses": "esdruxular",
    "esdruxulaste": "esdruxular",
    "esdruxulastes": "esdruxular",
    "esdruxulava": "esdruxular",
    "esdruxulavam": "esdruxular",
    "esdruxulavas": "esdruxular",
    "esdruxule": "esdruxular",
    "esdruxulei": "esdruxular",
    "esdruxuleis": "esdruxular",
    "esdruxulem": "esdruxular",
    "esdruxulemo": "esdruxular",
    "esdruxulemos": "esdruxular",
    "esdruxules": "esdruxular",
    "esdruxulo": "esdruxular",
    "esdruxulou": "esdruxular",
    "esdruxulá": "esdruxular",
    "esdruxulámo": "esdruxular",
    "esdruxulámos": "esdruxular",
    "esdruxuláramo": "esdruxular",
    "esdruxuláramos": "esdruxular",
    "esdruxulárei": "esdruxular",
    "esdruxuláreis": "esdruxular",
    "esdruxulásseis": "esdruxular",
    "esdruxulássemos": "esdruxular",
    "esdruxulávamo": "esdruxular",
    "esdruxulávamos": "esdruxular",
    "esdruxulávei": "esdruxular",
    "esdruxuláveis": "esdruxular",
    "esdrúxula": "esdrúxulo",
    "esdrúxulas": "esdrúxulo",
    "esdrúxulos": "esdrúxulo",
    "esfacela": "esfacelar",
    "esfacelada": "esfacelar",
    "esfaceladas": "esfacelar",
    "esfacelado": "esfacelar",
    "esfacelados": "esfacelar",
    "esfacelai": "esfacelar",
    "esfacelais": "esfacelar",
    "esfacelam": "esfacelar",
    "esfacelamentos": "esfacelamento",
    "esfacelamo": "esfacelar",
    "esfacelamos": "esfacelar",
    "esfacelando": "esfacelar",
    "esfacelara": "esfacelar",
    "esfacelaram": "esfacelar",
    "esfacelaras": "esfacelar",
    "esfacelarde": "esfacelar",
    "esfacelardes": "esfacelar",
    "esfacelare": "esfacelar",
    "esfacelarei": "esfacelar",
    "esfacelareis": "esfacelar",
    "esfacelarem": "esfacelar",
    "esfacelaremos": "esfacelar",
    "esfacelares": "esfacelar",
    "esfacelaria": "esfacelar",
    "esfacelariam": "esfacelar",
    "esfacelarias": "esfacelar",
    "esfacelarmo": "esfacelar",
    "esfacelarmos": "esfacelar",
    "esfacelará": "esfacelar",
    "esfacelarás": "esfacelar",
    "esfacelarão": "esfacelar",
    "esfacelaríamos": "esfacelar",
    "esfacelaríeis": "esfacelar",
    "esfacelas": "esfacelar",
    "esfacelasse": "esfacelar",
    "esfacelassem": "esfacelar",
    "esfacelasses": "esfacelar",
    "esfacelaste": "esfacelar",
    "esfacelastes": "esfacelar",
    "esfacelava": "esfacelar",
    "esfacelavam": "esfacelar",
    "esfacelavas": "esfacelar",
    "esfacele": "esfacelar",
    "esfacelei": "esfacelar",
    "esfaceleis": "esfacelar",
    "esfacelem": "esfacelar",
    "esfacelemo": "esfacelar",
    "esfacelemos": "esfacelar",
    "esfaceles": "esfacelar",
    "esfacelo": "esfacelar",
    "esfacelos": "esfacelo",
    "esfacelou": "esfacelar",
    "esfacelá": "esfacelar",
    "esfacelámo": "esfacelar",
    "esfacelámos": "esfacelar",
    "esfaceláramo": "esfacelar",
    "esfaceláramos": "esfacelar",
    "esfacelárei": "esfacelar",
    "esfaceláreis": "esfacelar",
    "esfacelásseis": "esfacelar",
    "esfacelássemos": "esfacelar",
    "esfacelávamo": "esfacelar",
    "esfacelávamos": "esfacelar",
    "esfacelávei": "esfacelar",
    "esfaceláveis": "esfacelar",
    "esfadigada": "esfadigado",
    "esfadigadas": "esfadigado",
    "esfadigados": "esfadigado",
    "esfaima": "esfaimar",
    "esfaimada": "esfaimar",
    "esfaimadas": "esfaimar",
    "esfaimado": "esfaimar",
    "esfaimados": "esfaimar",
    "esfaimai": "esfaimar",
    "esfaimais": "esfaimar",
    "esfaimam": "esfaimar",
    "esfaimamo": "esfaimar",
    "esfaimamos": "esfaimar",
    "esfaimando": "esfaimar",
    "esfaimara": "esfaimar",
    "esfaimaram": "esfaimar",
    "esfaimaras": "esfaimar",
    "esfaimarde": "esfaimar",
    "esfaimardes": "esfaimar",
    "esfaimare": "esfaimar",
    "esfaimarei": "esfaimar",
    "esfaimareis": "esfaimar",
    "esfaimarem": "esfaimar",
    "esfaimaremos": "esfaimar",
    "esfaimares": "esfaimar",
    "esfaimaria": "esfaimar",
    "esfaimariam": "esfaimar",
    "esfaimarias": "esfaimar",
    "esfaimarmo": "esfaimar",
    "esfaimarmos": "esfaimar",
    "esfaimará": "esfaimar",
    "esfaimarás": "esfaimar",
    "esfaimarão": "esfaimar",
    "esfaimaríamos": "esfaimar",
    "esfaimaríeis": "esfaimar",
    "esfaimas": "esfaimar",
    "esfaimasse": "esfaimar",
    "esfaimassem": "esfaimar",
    "esfaimasses": "esfaimar",
    "esfaimaste": "esfaimar",
    "esfaimastes": "esfaimar",
    "esfaimava": "esfaimar",
    "esfaimavam": "esfaimar",
    "esfaimavas": "esfaimar",
    "esfaime": "esfaimar",
    "esfaimei": "esfaimar",
    "esfaimeis": "esfaimar",
    "esfaimem": "esfaimar",
    "esfaimemo": "esfaimar",
    "esfaimemos": "esfaimar",
    "esfaimes": "esfaimar",
    "esfaimo": "esfaimar",
    "esfaimou": "esfaimar",
    "esfaimá": "esfaimar",
    "esfaimámo": "esfaimar",
    "esfaimámos": "esfaimar",
    "esfaimáramo": "esfaimar",
    "esfaimáramos": "esfaimar",
    "esfaimárei": "esfaimar",
    "esfaimáreis": "esfaimar",
    "esfaimásseis": "esfaimar",
    "esfaimássemos": "esfaimar",
    "esfaimávamo": "esfaimar",
    "esfaimávamos": "esfaimar",
    "esfaimávei": "esfaimar",
    "esfaimáveis": "esfaimar",
    "esfalcaçada": "esfalcaçado",
    "esfalcaçadas": "esfalcaçado",
    "esfalcaçados": "esfalcaçado",
    "esfalerites": "esfalerite",
    "esfalfa": "esfalfar",
    "esfalfada": "esfalfar",
    "esfalfadas": "esfalfar",
    "esfalfado": "esfalfar",
    "esfalfados": "esfalfar",
    "esfalfadíssima": "esfalfado",
    "esfalfadíssimas": "esfalfado",
    "esfalfadíssimo": "esfalfado",
    "esfalfadíssimos": "esfalfado",
    "esfalfai": "esfalfar",
    "esfalfais": "esfalfar",
    "esfalfam": "esfalfar",
    "esfalfamentos": "esfalfamento",
    "esfalfamo": "esfalfar",
    "esfalfamos": "esfalfar",
    "esfalfando": "esfalfar",
    "esfalfantes": "esfalfante",
    "esfalfara": "esfalfar",
    "esfalfaram": "esfalfar",
    "esfalfaras": "esfalfar",
    "esfalfarde": "esfalfar",
    "esfalfardes": "esfalfar",
    "esfalfare": "esfalfar",
    "esfalfarei": "esfalfar",
    "esfalfareis": "esfalfar",
    "esfalfarem": "esfalfar",
    "esfalfaremos": "esfalfar",
    "esfalfares": "esfalfar",
    "esfalfaria": "esfalfar",
    "esfalfariam": "esfalfar",
    "esfalfarias": "esfalfar",
    "esfalfarmo": "esfalfar",
    "esfalfarmos": "esfalfar",
    "esfalfará": "esfalfar",
    "esfalfarás": "esfalfar",
    "esfalfarão": "esfalfar",
    "esfalfaríamos": "esfalfar",
    "esfalfaríeis": "esfalfar",
    "esfalfas": "esfalfar",
    "esfalfasse": "esfalfar",
    "esfalfassem": "esfalfar",
    "esfalfasses": "esfalfar",
    "esfalfaste": "esfalfar",
    "esfalfastes": "esfalfar",
    "esfalfava": "esfalfar",
    "esfalfavam": "esfalfar",
    "esfalfavas": "esfalfar",
    "esfalfe": "esfalfar",
    "esfalfei": "esfalfar",
    "esfalfeis": "esfalfar",
    "esfalfem": "esfalfar",
    "esfalfemo": "esfalfar",
    "esfalfemos": "esfalfar",
    "esfalfes": "esfalfar",
    "esfalfo": "esfalfar",
    "esfalfou": "esfalfar",
    "esfalfá": "esfalfar",
    "esfalfámo": "esfalfar",
    "esfalfámos": "esfalfar",
    "esfalfáramo": "esfalfar",
    "esfalfáramos": "esfalfar",
    "esfalfárei": "esfalfar",
    "esfalfáreis": "esfalfar",
    "esfalfásseis": "esfalfar",
    "esfalfássemos": "esfalfar",
    "esfalfávamo": "esfalfar",
    "esfalfávamos": "esfalfar",
    "esfalfávei": "esfalfar",
    "esfalfáveis": "esfalfar",
    "esfanica": "esfanicar",
    "esfanicada": "esfanicar",
    "esfanicadas": "esfanicar",
    "esfanicado": "esfanicar",
    "esfanicados": "esfanicar",
    "esfanicai": "esfanicar",
    "esfanicais": "esfanicar",
    "esfanicam": "esfanicar",
    "esfanicamo": "esfanicar",
    "esfanicamos": "esfanicar",
    "esfanicando": "esfanicar",
    "esfanicara": "esfanicar",
    "esfanicaram": "esfanicar",
    "esfanicaras": "esfanicar",
    "esfanicarde": "esfanicar",
    "esfanicardes": "esfanicar",
    "esfanicare": "esfanicar",
    "esfanicarei": "esfanicar",
    "esfanicareis": "esfanicar",
    "esfanicarem": "esfanicar",
    "esfanicaremos": "esfanicar",
    "esfanicares": "esfanicar",
    "esfanicaria": "esfanicar",
    "esfanicariam": "esfanicar",
    "esfanicarias": "esfanicar",
    "esfanicarmo": "esfanicar",
    "esfanicarmos": "esfanicar",
    "esfanicará": "esfanicar",
    "esfanicarás": "esfanicar",
    "esfanicarão": "esfanicar",
    "esfanicaríamos": "esfanicar",
    "esfanicaríeis": "esfanicar",
    "esfanicas": "esfanicar",
    "esfanicasse": "esfanicar",
    "esfanicassem": "esfanicar",
    "esfanicasses": "esfanicar",
    "esfanicaste": "esfanicar",
    "esfanicastes": "esfanicar",
    "esfanicava": "esfanicar",
    "esfanicavam": "esfanicar",
    "esfanicavas": "esfanicar",
    "esfanico": "esfanicar",
    "esfanicou": "esfanicar",
    "esfanicá": "esfanicar",
    "esfanicámo": "esfanicar",
    "esfanicámos": "esfanicar",
    "esfanicáramo": "esfanicar",
    "esfanicáramos": "esfanicar",
    "esfanicárei": "esfanicar",
    "esfanicáreis": "esfanicar",
    "esfanicásseis": "esfanicar",
    "esfanicássemos": "esfanicar",
    "esfanicávamo": "esfanicar",
    "esfanicávamos": "esfanicar",
    "esfanicávei": "esfanicar",
    "esfanicáveis": "esfanicar",
    "esfanique": "esfanicar",
    "esfaniquei": "esfanicar",
    "esfaniqueis": "esfanicar",
    "esfaniquem": "esfanicar",
    "esfaniquemo": "esfanicar",
    "esfaniquemos": "esfanicar",
    "esfaniques": "esfanicar",
    "esfaqueada": "esfaquear",
    "esfaqueadas": "esfaquear",
    "esfaqueado": "esfaquear",
    "esfaqueadora": "esfaqueador",
    "esfaqueadoras": "esfaqueador",
    "esfaqueadores": "esfaqueador",
    "esfaqueados": "esfaquear",
    "esfaqueai": "esfaquear",
    "esfaqueais": "esfaquear",
    "esfaqueamentos": "esfaqueamento",
    "esfaqueamo": "esfaquear",
    "esfaqueamos": "esfaquear",
    "esfaqueando": "esfaquear",
    "esfaqueara": "esfaquear",
    "esfaquearam": "esfaquear",
    "esfaquearas": "esfaquear",
    "esfaquearde": "esfaquear",
    "esfaqueardes": "esfaquear",
    "esfaqueare": "esfaquear",
    "esfaquearei": "esfaquear",
    "esfaqueareis": "esfaquear",
    "esfaquearem": "esfaquear",
    "esfaquearemos": "esfaquear",
    "esfaqueares": "esfaquear",
    "esfaquearia": "esfaquear",
    "esfaqueariam": "esfaquear",
    "esfaquearias": "esfaquear",
    "esfaquearmo": "esfaquear",
    "esfaquearmos": "esfaquear",
    "esfaqueará": "esfaquear",
    "esfaquearás": "esfaquear",
    "esfaquearão": "esfaquear",
    "esfaquearíamos": "esfaquear",
    "esfaquearíeis": "esfaquear",
    "esfaqueasse": "esfaquear",
    "esfaqueassem": "esfaquear",
    "esfaqueasses": "esfaquear",
    "esfaqueaste": "esfaquear",
    "esfaqueastes": "esfaquear",
    "esfaqueava": "esfaquear",
    "esfaqueavam": "esfaquear",
    "esfaqueavas": "esfaquear",
    "esfaqueei": "esfaquear",
    "esfaqueeis": "esfaquear",
    "esfaqueemo": "esfaquear",
    "esfaqueemos": "esfaquear",
    "esfaqueia": "esfaquear",
    "esfaqueiam": "esfaquear",
    "esfaqueias": "esfaquear",
    "esfaqueie": "esfaquear",
    "esfaqueiem": "esfaquear",
    "esfaqueies": "esfaquear",
    "esfaqueio": "esfaquear",
    "esfaqueou": "esfaquear",
    "esfaqueá": "esfaquear",
    "esfaqueámo": "esfaquear",
    "esfaqueámos": "esfaquear",
    "esfaqueáramo": "esfaquear",
    "esfaqueáramos": "esfaquear",
    "esfaqueárei": "esfaquear",
    "esfaqueáreis": "esfaquear",
    "esfaqueásseis": "esfaquear",
    "esfaqueássemos": "esfaquear",
    "esfaqueávamo": "esfaquear",
    "esfaqueávamos": "esfaquear",
    "esfaqueávei": "esfaquear",
    "esfaqueáveis": "esfaquear",
    "esfarela": "esfarelar",
    "esfarelada": "esfarelar",
    "esfareladas": "esfarelar",
    "esfarelado": "esfarelar",
    "esfarelados": "esfarelar",
    "esfarelai": "esfarelar",
    "esfarelais": "esfarelar",
    "esfarelam": "esfarelar",
    "esfarelamentos": "esfarelamento",
    "esfarelamo": "esfarelar",
    "esfarelamos": "esfarelar",
    "esfarelando": "esfarelar",
    "esfarelara": "esfarelar",
    "esfarelaram": "esfarelar",
    "esfarelaras": "esfarelar",
    "esfarelarde": "esfarelar",
    "esfarelardes": "esfarelar",
    "esfarelare": "esfarelar",
    "esfarelarei": "esfarelar",
    "esfarelareis": "esfarelar",
    "esfarelarem": "esfarelar",
    "esfarelaremos": "esfarelar",
    "esfarelares": "esfarelar",
    "esfarelaria": "esfarelar",
    "esfarelariam": "esfarelar",
    "esfarelarias": "esfarelar",
    "esfarelarmo": "esfarelar",
    "esfarelarmos": "esfarelar",
    "esfarelará": "esfarelar",
    "esfarelarás": "esfarelar",
    "esfarelarão": "esfarelar",
    "esfarelaríamos": "esfarelar",
    "esfarelaríeis": "esfarelar",
    "esfarelas": "esfarelar",
    "esfarelasse": "esfarelar",
    "esfarelassem": "esfarelar",
    "esfarelasses": "esfarelar",
    "esfarelaste": "esfarelar",
    "esfarelastes": "esfarelar",
    "esfarelava": "esfarelar",
    "esfarelavam": "esfarelar",
    "esfarelavas": "esfarelar",
    "esfarele": "esfarelar",
    "esfarelei": "esfarelar",
    "esfareleis": "esfarelar",
    "esfarelem": "esfarelar",
    "esfarelemo": "esfarelar",
    "esfarelemos": "esfarelar",
    "esfareles": "esfarelar",
    "esfarelo": "esfarelar",
    "esfarelou": "esfarelar",
    "esfarelá": "esfarelar",
    "esfarelámo": "esfarelar",
    "esfarelámos": "esfarelar",
    "esfareláramo": "esfarelar",
    "esfareláramos": "esfarelar",
    "esfarelárei": "esfarelar",
    "esfareláreis": "esfarelar",
    "esfarelásseis": "esfarelar",
    "esfarelássemos": "esfarelar",
    "esfarelávamo": "esfarelar",
    "esfarelávamos": "esfarelar",
    "esfarelávei": "esfarelar",
    "esfareláveis": "esfarelar",
    "esfarfalha": "esfarfalhar",
    "esfarfalhada": "esfarfalhar",
    "esfarfalhadas": "esfarfalhar",
    "esfarfalhado": "esfarfalhar",
    "esfarfalhados": "esfarfalhar",
    "esfarfalhai": "esfarfalhar",
    "esfarfalhais": "esfarfalhar",
    "esfarfalham": "esfarfalhar",
    "esfarfalhamo": "esfarfalhar",
    "esfarfalhamos": "esfarfalhar",
    "esfarfalhando": "esfarfalhar",
    "esfarfalhara": "esfarfalhar",
    "esfarfalharam": "esfarfalhar",
    "esfarfalharas": "esfarfalhar",
    "esfarfalharde": "esfarfalhar",
    "esfarfalhardes": "esfarfalhar",
    "esfarfalhare": "esfarfalhar",
    "esfarfalharei": "esfarfalhar",
    "esfarfalhareis": "esfarfalhar",
    "esfarfalharem": "esfarfalhar",
    "esfarfalharemos": "esfarfalhar",
    "esfarfalhares": "esfarfalhar",
    "esfarfalharia": "esfarfalhar",
    "esfarfalhariam": "esfarfalhar",
    "esfarfalharias": "esfarfalhar",
    "esfarfalharmo": "esfarfalhar",
    "esfarfalharmos": "esfarfalhar",
    "esfarfalhará": "esfarfalhar",
    "esfarfalharás": "esfarfalhar",
    "esfarfalharão": "esfarfalhar",
    "esfarfalharíamos": "esfarfalhar",
    "esfarfalharíeis": "esfarfalhar",
    "esfarfalhas": "esfarfalhar",
    "esfarfalhasse": "esfarfalhar",
    "esfarfalhassem": "esfarfalhar",
    "esfarfalhasses": "esfarfalhar",
    "esfarfalhaste": "esfarfalhar",
    "esfarfalhastes": "esfarfalhar",
    "esfarfalhava": "esfarfalhar",
    "esfarfalhavam": "esfarfalhar",
    "esfarfalhavas": "esfarfalhar",
    "esfarfalhe": "esfarfalhar",
    "esfarfalhei": "esfarfalhar",
    "esfarfalheis": "esfarfalhar",
    "esfarfalhem": "esfarfalhar",
    "esfarfalhemo": "esfarfalhar",
    "esfarfalhemos": "esfarfalhar",
    "esfarfalhes": "esfarfalhar",
    "esfarfalho": "esfarfalhar",
    "esfarfalhou": "esfarfalhar",
    "esfarfalhá": "esfarfalhar",
    "esfarfalhámo": "esfarfalhar",
    "esfarfalhámos": "esfarfalhar",
    "esfarfalháramo": "esfarfalhar",
    "esfarfalháramos": "esfarfalhar",
    "esfarfalhárei": "esfarfalhar",
    "esfarfalháreis": "esfarfalhar",
    "esfarfalhásseis": "esfarfalhar",
    "esfarfalhássemos": "esfarfalhar",
    "esfarfalhávamo": "esfarfalhar",
    "esfarfalhávamos": "esfarfalhar",
    "esfarfalhávei": "esfarfalhar",
    "esfarfalháveis": "esfarfalhar",
    "esfarinha": "esfarinhar",
    "esfarinhada": "esfarinhar",
    "esfarinhadas": "esfarinhar",
    "esfarinhado": "esfarinhar",
    "esfarinhados": "esfarinhar",
    "esfarinhai": "esfarinhar",
    "esfarinhais": "esfarinhar",
    "esfarinham": "esfarinhar",
    "esfarinhamo": "esfarinhar",
    "esfarinhamos": "esfarinhar",
    "esfarinhando": "esfarinhar",
    "esfarinhara": "esfarinhar",
    "esfarinharam": "esfarinhar",
    "esfarinharas": "esfarinhar",
    "esfarinharde": "esfarinhar",
    "esfarinhardes": "esfarinhar",
    "esfarinhare": "esfarinhar",
    "esfarinharei": "esfarinhar",
    "esfarinhareis": "esfarinhar",
    "esfarinharem": "esfarinhar",
    "esfarinharemos": "esfarinhar",
    "esfarinhares": "esfarinhar",
    "esfarinharia": "esfarinhar",
    "esfarinhariam": "esfarinhar",
    "esfarinharias": "esfarinhar",
    "esfarinharmo": "esfarinhar",
    "esfarinharmos": "esfarinhar",
    "esfarinhará": "esfarinhar",
    "esfarinharás": "esfarinhar",
    "esfarinharão": "esfarinhar",
    "esfarinharíamos": "esfarinhar",
    "esfarinharíeis": "esfarinhar",
    "esfarinhas": "esfarinhar",
    "esfarinhasse": "esfarinhar",
    "esfarinhassem": "esfarinhar",
    "esfarinhasses": "esfarinhar",
    "esfarinhaste": "esfarinhar",
    "esfarinhastes": "esfarinhar",
    "esfarinhava": "esfarinhar",
    "esfarinhavam": "esfarinhar",
    "esfarinhavas": "esfarinhar",
    "esfarinhe": "esfarinhar",
    "esfarinhei": "esfarinhar",
    "esfarinheis": "esfarinhar",
    "esfarinhem": "esfarinhar",
    "esfarinhemo": "esfarinhar",
    "esfarinhemos": "esfarinhar",
    "esfarinhes": "esfarinhar",
    "esfarinho": "esfarinhar",
    "esfarinhou": "esfarinhar",
    "esfarinhá": "esfarinhar",
    "esfarinhámo": "esfarinhar",
    "esfarinhámos": "esfarinhar",
    "esfarinháramo": "esfarinhar",
    "esfarinháramos": "esfarinhar",
    "esfarinhárei": "esfarinhar",
    "esfarinháreis": "esfarinhar",
    "esfarinhásseis": "esfarinhar",
    "esfarinhássemos": "esfarinhar",
    "esfarinhávamo": "esfarinhar",
    "esfarinhávamos": "esfarinhar",
    "esfarinhávei": "esfarinhar",
    "esfarinháveis": "esfarinhar",
    "esfarpa": "esfarpar",
    "esfarpada": "esfarpar",
    "esfarpadas": "esfarpar",
    "esfarpadelas": "esfarpadela",
    "esfarpado": "esfarpar",
    "esfarpados": "esfarpar",
    "esfarpai": "esfarpar",
    "esfarpais": "esfarpar",
    "esfarpam": "esfarpar",
    "esfarpamo": "esfarpar",
    "esfarpamos": "esfarpar",
    "esfarpando": "esfarpar",
    "esfarpara": "esfarpar",
    "esfarparam": "esfarpar",
    "esfarparas": "esfarpar",
    "esfarparde": "esfarpar",
    "esfarpardes": "esfarpar",
    "esfarpare": "esfarpar",
    "esfarparei": "esfarpar",
    "esfarpareis": "esfarpar",
    "esfarparem": "esfarpar",
    "esfarparemos": "esfarpar",
    "esfarpares": "esfarpar",
    "esfarparia": "esfarpar",
    "esfarpariam": "esfarpar",
    "esfarparias": "esfarpar",
    "esfarparmo": "esfarpar",
    "esfarparmos": "esfarpar",
    "esfarpará": "esfarpar",
    "esfarparás": "esfarpar",
    "esfarparão": "esfarpar",
    "esfarparíamos": "esfarpar",
    "esfarparíeis": "esfarpar",
    "esfarpas": "esfarpar",
    "esfarpasse": "esfarpar",
    "esfarpassem": "esfarpar",
    "esfarpasses": "esfarpar",
    "esfarpaste": "esfarpar",
    "esfarpastes": "esfarpar",
    "esfarpava": "esfarpar",
    "esfarpavam": "esfarpar",
    "esfarpavas": "esfarpar",
    "esfarpe": "esfarpar",
    "esfarpei": "esfarpar",
    "esfarpeis": "esfarpar",
    "esfarpela": "esfarpelar",
    "esfarpelada": "esfarpelar",
    "esfarpeladas": "esfarpelar",
    "esfarpelado": "esfarpelar",
    "esfarpelados": "esfarpelar",
    "esfarpelai": "esfarpelar",
    "esfarpelais": "esfarpelar",
    "esfarpelam": "esfarpelar",
    "esfarpelamo": "esfarpelar",
    "esfarpelamos": "esfarpelar",
    "esfarpelando": "esfarpelar",
    "esfarpelara": "esfarpelar",
    "esfarpelaram": "esfarpelar",
    "esfarpelaras": "esfarpelar",
    "esfarpelarde": "esfarpelar",
    "esfarpelardes": "esfarpelar",
    "esfarpelare": "esfarpelar",
    "esfarpelarei": "esfarpelar",
    "esfarpelareis": "esfarpelar",
    "esfarpelarem": "esfarpelar",
    "esfarpelaremos": "esfarpelar",
    "esfarpelares": "esfarpelar",
    "esfarpelaria": "esfarpelar",
    "esfarpelariam": "esfarpelar",
    "esfarpelarias": "esfarpelar",
    "esfarpelarmo": "esfarpelar",
    "esfarpelarmos": "esfarpelar",
    "esfarpelará": "esfarpelar",
    "esfarpelarás": "esfarpelar",
    "esfarpelarão": "esfarpelar",
    "esfarpelaríamos": "esfarpelar",
    "esfarpelaríeis": "esfarpelar",
    "esfarpelas": "esfarpelar",
    "esfarpelasse": "esfarpelar",
    "esfarpelassem": "esfarpelar",
    "esfarpelasses": "esfarpelar",
    "esfarpelaste": "esfarpelar",
    "esfarpelastes": "esfarpelar",
    "esfarpelava": "esfarpelar",
    "esfarpelavam": "esfarpelar",
    "esfarpelavas": "esfarpelar",
    "esfarpele": "esfarpelar",
    "esfarpelei": "esfarpelar",
    "esfarpeleis": "esfarpelar",
    "esfarpelem": "esfarpelar",
    "esfarpelemo": "esfarpelar",
    "esfarpelemos": "esfarpelar",
    "esfarpeles": "esfarpelar",
    "esfarpelo": "esfarpelar",
    "esfarpelou": "esfarpelar",
    "esfarpelá": "esfarpelar",
    "esfarpelámo": "esfarpelar",
    "esfarpelámos": "esfarpelar",
    "esfarpeláramo": "esfarpelar",
    "esfarpeláramos": "esfarpelar",
    "esfarpelárei": "esfarpelar",
    "esfarpeláreis": "esfarpelar",
    "esfarpelásseis": "esfarpelar",
    "esfarpelássemos": "esfarpelar",
    "esfarpelávamo": "esfarpelar",
    "esfarpelávamos": "esfarpelar",
    "esfarpelávei": "esfarpelar",
    "esfarpeláveis": "esfarpelar",
    "esfarpem": "esfarpar",
    "esfarpemo": "esfarpar",
    "esfarpemos": "esfarpar",
    "esfarpes": "esfarpar",
    "esfarpo": "esfarpar",
    "esfarpou": "esfarpar",
    "esfarpá": "esfarpar",
    "esfarpámo": "esfarpar",
    "esfarpámos": "esfarpar",
    "esfarpáramo": "esfarpar",
    "esfarpáramos": "esfarpar",
    "esfarpárei": "esfarpar",
    "esfarpáreis": "esfarpar",
    "esfarpásseis": "esfarpar",
    "esfarpássemos": "esfarpar",
    "esfarpávamo": "esfarpar",
    "esfarpávamos": "esfarpar",
    "esfarpávei": "esfarpar",
    "esfarpáveis": "esfarpar",
    "esfarradeiras": "esfarradeira",
    "esfarrapa": "esfarrapar",
    "esfarrapada": "esfarrapar",
    "esfarrapadas": "esfarrapar",
    "esfarrapado": "esfarrapar",
    "esfarrapadores": "esfarrapador",
    "esfarrapados": "esfarrapar",
    "esfarrapai": "esfarrapar",
    "esfarrapais": "esfarrapar",
    "esfarrapam": "esfarrapar",
    "esfarrapamentos": "esfarrapamento",
    "esfarrapamo": "esfarrapar",
    "esfarrapamos": "esfarrapar",
    "esfarrapando": "esfarrapar",
    "esfarrapara": "esfarrapar",
    "esfarraparam": "esfarrapar",
    "esfarraparas": "esfarrapar",
    "esfarraparde": "esfarrapar",
    "esfarrapardes": "esfarrapar",
    "esfarrapare": "esfarrapar",
    "esfarraparei": "esfarrapar",
    "esfarrapareis": "esfarrapar",
    "esfarraparem": "esfarrapar",
    "esfarraparemos": "esfarrapar",
    "esfarrapares": "esfarrapar",
    "esfarraparia": "esfarrapar",
    "esfarrapariam": "esfarrapar",
    "esfarraparias": "esfarrapar",
    "esfarraparmo": "esfarrapar",
    "esfarraparmos": "esfarrapar",
    "esfarrapará": "esfarrapar",
    "esfarraparás": "esfarrapar",
    "esfarraparão": "esfarrapar",
    "esfarraparíamos": "esfarrapar",
    "esfarraparíeis": "esfarrapar",
    "esfarrapas": "esfarrapar",
    "esfarrapasse": "esfarrapar",
    "esfarrapassem": "esfarrapar",
    "esfarrapasses": "esfarrapar",
    "esfarrapaste": "esfarrapar",
    "esfarrapastes": "esfarrapar",
    "esfarrapava": "esfarrapar",
    "esfarrapavam": "esfarrapar",
    "esfarrapavas": "esfarrapar",
    "esfarrape": "esfarrapar",
    "esfarrapei": "esfarrapar",
    "esfarrapeis": "esfarrapar",
    "esfarrapem": "esfarrapar",
    "esfarrapemo": "esfarrapar",
    "esfarrapemos": "esfarrapar",
    "esfarrapes": "esfarrapar",
    "esfarrapo": "esfarrapar",
    "esfarrapou": "esfarrapar",
    "esfarrapá": "esfarrapar",
    "esfarrapámo": "esfarrapar",
    "esfarrapámos": "esfarrapar",
    "esfarrapáramo": "esfarrapar",
    "esfarrapáramos": "esfarrapar",
    "esfarrapárei": "esfarrapar",
    "esfarrapáreis": "esfarrapar",
    "esfarrapásseis": "esfarrapar",
    "esfarrapássemos": "esfarrapar",
    "esfarrapávamo": "esfarrapar",
    "esfarrapávamos": "esfarrapar",
    "esfarrapávei": "esfarrapar",
    "esfarrapáveis": "esfarrapar",
    "esfarripa": "esfarripar",
    "esfarripada": "esfarripar",
    "esfarripadas": "esfarripar",
    "esfarripado": "esfarripar",
    "esfarripadora": "esfarripador",
    "esfarripadoras": "esfarripador",
    "esfarripadores": "esfarripador",
    "esfarripados": "esfarripar",
    "esfarripai": "esfarripar",
    "esfarripais": "esfarripar",
    "esfarripam": "esfarripar",
    "esfarripamentos": "esfarripamento",
    "esfarripamo": "esfarripar",
    "esfarripamos": "esfarripar",
    "esfarripando": "esfarripar",
    "esfarripara": "esfarripar",
    "esfarriparam": "esfarripar",
    "esfarriparas": "esfarripar",
    "esfarriparde": "esfarripar",
    "esfarripardes": "esfarripar",
    "esfarripare": "esfarripar",
    "esfarriparei": "esfarripar",
    "esfarripareis": "esfarripar",
    "esfarriparem": "esfarripar",
    "esfarriparemos": "esfarripar",
    "esfarripares": "esfarripar",
    "esfarriparia": "esfarripar",
    "esfarripariam": "esfarripar",
    "esfarriparias": "esfarripar",
    "esfarriparmo": "esfarripar",
    "esfarriparmos": "esfarripar",
    "esfarripará": "esfarripar",
    "esfarriparás": "esfarripar",
    "esfarriparão": "esfarripar",
    "esfarriparíamos": "esfarripar",
    "esfarriparíeis": "esfarripar",
    "esfarripas": "esfarripar",
    "esfarripasse": "esfarripar",
    "esfarripassem": "esfarripar",
    "esfarripasses": "esfarripar",
    "esfarripaste": "esfarripar",
    "esfarripastes": "esfarripar",
    "esfarripava": "esfarripar",
    "esfarripavam": "esfarripar",
    "esfarripavas": "esfarripar",
    "esfarripe": "esfarripar",
    "esfarripei": "esfarripar",
    "esfarripeis": "esfarripar",
    "esfarripem": "esfarripar",
    "esfarripemo": "esfarripar",
    "esfarripemos": "esfarripar",
    "esfarripes": "esfarripar",
    "esfarripo": "esfarripar",
    "esfarripou": "esfarripar",
    "esfarripá": "esfarripar",
    "esfarripámo": "esfarripar",
    "esfarripámos": "esfarripar",
    "esfarripáramo": "esfarripar",
    "esfarripáramos": "esfarripar",
    "esfarripárei": "esfarripar",
    "esfarripáreis": "esfarripar",
    "esfarripásseis": "esfarripar",
    "esfarripássemos": "esfarripar",
    "esfarripávamo": "esfarripar",
    "esfarripávamos": "esfarripar",
    "esfarripávei": "esfarripar",
    "esfarripáveis": "esfarripar",
    "esfatia": "esfatiar",
    "esfatiada": "esfatiar",
    "esfatiadas": "esfatiar",
    "esfatiado": "esfatiar",
    "esfatiados": "esfatiar",
    "esfatiai": "esfatiar",
    "esfatiais": "esfatiar",
    "esfatiam": "esfatiar",
    "esfatiamo": "esfatiar",
    "esfatiamos": "esfatiar",
    "esfatiando": "esfatiar",
    "esfatiara": "esfatiar",
    "esfatiaram": "esfatiar",
    "esfatiaras": "esfatiar",
    "esfatiarde": "esfatiar",
    "esfatiardes": "esfatiar",
    "esfatiare": "esfatiar",
    "esfatiarei": "esfatiar",
    "esfatiareis": "esfatiar",
    "esfatiarem": "esfatiar",
    "esfatiaremos": "esfatiar",
    "esfatiares": "esfatiar",
    "esfatiaria": "esfatiar",
    "esfatiariam": "esfatiar",
    "esfatiarias": "esfatiar",
    "esfatiarmo": "esfatiar",
    "esfatiarmos": "esfatiar",
    "esfatiará": "esfatiar",
    "esfatiarás": "esfatiar",
    "esfatiarão": "esfatiar",
    "esfatiaríamos": "esfatiar",
    "esfatiaríeis": "esfatiar",
    "esfatias": "esfatiar",
    "esfatiasse": "esfatiar",
    "esfatiassem": "esfatiar",
    "esfatiasses": "esfatiar",
    "esfatiaste": "esfatiar",
    "esfatiastes": "esfatiar",
    "esfatiava": "esfatiar",
    "esfatiavam": "esfatiar",
    "esfatiavas": "esfatiar",
    "esfatie": "esfatiar",
    "esfatiei": "esfatiar",
    "esfatieis": "esfatiar",
    "esfatiem": "esfatiar",
    "esfatiemo": "esfatiar",
    "esfatiemos": "esfatiar",
    "esfaties": "esfatiar",
    "esfatio": "esfatiar",
    "esfatiou": "esfatiar",
    "esfatiá": "esfatiar",
    "esfatiámo": "esfatiar",
    "esfatiámos": "esfatiar",
    "esfatiáramo": "esfatiar",
    "esfatiáramos": "esfatiar",
    "esfatiárei": "esfatiar",
    "esfatiáreis": "esfatiar",
    "esfatiásseis": "esfatiar",
    "esfatiássemos": "esfatiar",
    "esfatiávamo": "esfatiar",
    "esfatiávamos": "esfatiar",
    "esfatiávei": "esfatiar",
    "esfatiáveis": "esfatiar",
    "esfenas": "esfena",
    "esfenisciformes": "esfenisciforme",
    "esfenoedros": "esfenoedro",
    "esfenoidais": "esfenoidal",
    "esfenóides": "esfenóide",
    "esfenóticos": "esfenótico",
    "esferas": "esfera",
    "esfericidades": "esfericidade",
    "esferistas": "esferista",
    "esferistérios": "esferistério",
    "esferográficas": "esferográfica",
    "esferoidais": "esferoidal",
    "esferométrica": "esferométrico",
    "esferométricas": "esferométrico",
    "esferométricos": "esferométrico",
    "esferorradianos": "esferorradiano",
    "esferovites": "esferovite",
    "esfervelhos": "esfervelho",
    "esfervilha": "esfervilhar",
    "esfervilhada": "esfervilhar",
    "esfervilhadas": "esfervilhar",
    "esfervilhado": "esfervilhar",
    "esfervilhados": "esfervilhar",
    "esfervilhai": "esfervilhar",
    "esfervilhais": "esfervilhar",
    "esfervilham": "esfervilhar",
    "esfervilhamentos": "esfervilhamento",
    "esfervilhamo": "esfervilhar",
    "esfervilhamos": "esfervilhar",
    "esfervilhando": "esfervilhar",
    "esfervilhara": "esfervilhar",
    "esfervilharam": "esfervilhar",
    "esfervilharas": "esfervilhar",
    "esfervilharde": "esfervilhar",
    "esfervilhardes": "esfervilhar",
    "esfervilhare": "esfervilhar",
    "esfervilharei": "esfervilhar",
    "esfervilhareis": "esfervilhar",
    "esfervilharem": "esfervilhar",
    "esfervilharemos": "esfervilhar",
    "esfervilhares": "esfervilhar",
    "esfervilharia": "esfervilhar",
    "esfervilhariam": "esfervilhar",
    "esfervilharias": "esfervilhar",
    "esfervilharmo": "esfervilhar",
    "esfervilharmos": "esfervilhar",
    "esfervilhará": "esfervilhar",
    "esfervilharás": "esfervilhar",
    "esfervilharão": "esfervilhar",
    "esfervilharíamos": "esfervilhar",
    "esfervilharíeis": "esfervilhar",
    "esfervilhas": "esfervilhar",
    "esfervilhasse": "esfervilhar",
    "esfervilhassem": "esfervilhar",
    "esfervilhasses": "esfervilhar",
    "esfervilhaste": "esfervilhar",
    "esfervilhastes": "esfervilhar",
    "esfervilhava": "esfervilhar",
    "esfervilhavam": "esfervilhar",
    "esfervilhavas": "esfervilhar",
    "esfervilhações": "esfervilhação",
    "esfervilhe": "esfervilhar",
    "esfervilhei": "esfervilhar",
    "esfervilheis": "esfervilhar",
    "esfervilhem": "esfervilhar",
    "esfervilhemo": "esfervilhar",
    "esfervilhemos": "esfervilhar",
    "esfervilhes": "esfervilhar",
    "esfervilho": "esfervilhar",
    "esfervilhou": "esfervilhar",
    "esfervilhá": "esfervilhar",
    "esfervilhámo": "esfervilhar",
    "esfervilhámos": "esfervilhar",
    "esfervilháramo": "esfervilhar",
    "esfervilháramos": "esfervilhar",
    "esfervilhárei": "esfervilhar",
    "esfervilháreis": "esfervilhar",
    "esfervilhásseis": "esfervilhar",
    "esfervilhássemos": "esfervilhar",
    "esfervilhávamo": "esfervilhar",
    "esfervilhávamos": "esfervilhar",
    "esfervilhávei": "esfervilhar",
    "esfervilháveis": "esfervilhar",
    "esferísticas": "esferística",
    "esferóides": "esferóide",
    "esferómetros": "esferómetro",
    "esfia": "esfiar",
    "esfiada": "esfiar",
    "esfiadas": "esfiar",
    "esfiado": "esfiar",
    "esfiados": "esfiar",
    "esfiai": "esfiar",
    "esfiais": "esfiar",
    "esfiam": "esfiar",
    "esfiamentos": "esfiamento",
    "esfiamo": "esfiar",
    "esfiamos": "esfiar",
    "esfiampa": "esfiampar",
    "esfiampada": "esfiampar",
    "esfiampadas": "esfiampar",
    "esfiampado": "esfiampar",
    "esfiampados": "esfiampar",
    "esfiampai": "esfiampar",
    "esfiampais": "esfiampar",
    "esfiampam": "esfiampar",
    "esfiampamo": "esfiampar",
    "esfiampamos": "esfiampar",
    "esfiampando": "esfiampar",
    "esfiampara": "esfiampar",
    "esfiamparam": "esfiampar",
    "esfiamparas": "esfiampar",
    "esfiamparde": "esfiampar",
    "esfiampardes": "esfiampar",
    "esfiampare": "esfiampar",
    "esfiamparei": "esfiampar",
    "esfiampareis": "esfiampar",
    "esfiamparem": "esfiampar",
    "esfiamparemos": "esfiampar",
    "esfiampares": "esfiampar",
    "esfiamparia": "esfiampar",
    "esfiampariam": "esfiampar",
    "esfiamparias": "esfiampar",
    "esfiamparmo": "esfiampar",
    "esfiamparmos": "esfiampar",
    "esfiampará": "esfiampar",
    "esfiamparás": "esfiampar",
    "esfiamparão": "esfiampar",
    "esfiamparíamos": "esfiampar",
    "esfiamparíeis": "esfiampar",
    "esfiampas": "esfiampar",
    "esfiampasse": "esfiampar",
    "esfiampassem": "esfiampar",
    "esfiampasses": "esfiampar",
    "esfiampaste": "esfiampar",
    "esfiampastes": "esfiampar",
    "esfiampava": "esfiampar",
    "esfiampavam": "esfiampar",
    "esfiampavas": "esfiampar",
    "esfiampe": "esfiampar",
    "esfiampei": "esfiampar",
    "esfiampeis": "esfiampar",
    "esfiampem": "esfiampar",
    "esfiampemo": "esfiampar",
    "esfiampemos": "esfiampar",
    "esfiampes": "esfiampar",
    "esfiampo": "esfiampar",
    "esfiampou": "esfiampar",
    "esfiampá": "esfiampar",
    "esfiampámo": "esfiampar",
    "esfiampámos": "esfiampar",
    "esfiampáramo": "esfiampar",
    "esfiampáramos": "esfiampar",
    "esfiampárei": "esfiampar",
    "esfiampáreis": "esfiampar",
    "esfiampásseis": "esfiampar",
    "esfiampássemos": "esfiampar",
    "esfiampávamo": "esfiampar",
    "esfiampávamos": "esfiampar",
    "esfiampávei": "esfiampar",
    "esfiampáveis": "esfiampar",
    "esfiando": "esfiar",
    "esfiapa": "esfiapar",
    "esfiapada": "esfiapar",
    "esfiapadas": "esfiapar",
    "esfiapado": "esfiapar",
    "esfiapados": "esfiapar",
    "esfiapai": "esfiapar",
    "esfiapais": "esfiapar",
    "esfiapam": "esfiapar",
    "esfiapamo": "esfiapar",
    "esfiapamos": "esfiapar",
    "esfiapando": "esfiapar",
    "esfiapara": "esfiapar",
    "esfiaparam": "esfiapar",
    "esfiaparas": "esfiapar",
    "esfiaparde": "esfiapar",
    "esfiapardes": "esfiapar",
    "esfiapare": "esfiapar",
    "esfiaparei": "esfiapar",
    "esfiapareis": "esfiapar",
    "esfiaparem": "esfiapar",
    "esfiaparemos": "esfiapar",
    "esfiapares": "esfiapar",
    "esfiaparia": "esfiapar",
    "esfiapariam": "esfiapar",
    "esfiaparias": "esfiapar",
    "esfiaparmo": "esfiapar",
    "esfiaparmos": "esfiapar",
    "esfiapará": "esfiapar",
    "esfiaparás": "esfiapar",
    "esfiaparão": "esfiapar",
    "esfiaparíamos": "esfiapar",
    "esfiaparíeis": "esfiapar",
    "esfiapas": "esfiapar",
    "esfiapasse": "esfiapar",
    "esfiapassem": "esfiapar",
    "esfiapasses": "esfiapar",
    "esfiapaste": "esfiapar",
    "esfiapastes": "esfiapar",
    "esfiapava": "esfiapar",
    "esfiapavam": "esfiapar",
    "esfiapavas": "esfiapar",
    "esfiape": "esfiapar",
    "esfiapei": "esfiapar",
    "esfiapeis": "esfiapar",
    "esfiapem": "esfiapar",
    "esfiapemo": "esfiapar",
    "esfiapemos": "esfiapar",
    "esfiapes": "esfiapar",
    "esfiapo": "esfiapar",
    "esfiapou": "esfiapar",
    "esfiapá": "esfiapar",
    "esfiapámo": "esfiapar",
    "esfiapámos": "esfiapar",
    "esfiapáramo": "esfiapar",
    "esfiapáramos": "esfiapar",
    "esfiapárei": "esfiapar",
    "esfiapáreis": "esfiapar",
    "esfiapásseis": "esfiapar",
    "esfiapássemos": "esfiapar",
    "esfiapávamo": "esfiapar",
    "esfiapávamos": "esfiapar",
    "esfiapávei": "esfiapar",
    "esfiapáveis": "esfiapar",
    "esfiara": "esfiar",
    "esfiaram": "esfiar",
    "esfiaras": "esfiar",
    "esfiarde": "esfiar",
    "esfiardes": "esfiar",
    "esfiare": "esfiar",
    "esfiarei": "esfiar",
    "esfiareis": "esfiar",
    "esfiarem": "esfiar",
    "esfiaremos": "esfiar",
    "esfiares": "esfiar",
    "esfiaria": "esfiar",
    "esfiariam": "esfiar",
    "esfiarias": "esfiar",
    "esfiarmo": "esfiar",
    "esfiarmos": "esfiar",
    "esfiará": "esfiar",
    "esfiarás": "esfiar",
    "esfiarão": "esfiar",
    "esfiaríamos": "esfiar",
    "esfiaríeis": "esfiar",
    "esfias": "esfiar",
    "esfiasse": "esfiar",
    "esfiassem": "esfiar",
    "esfiasses": "esfiar",
    "esfiaste": "esfiar",
    "esfiastes": "esfiar",
    "esfiava": "esfiar",
    "esfiavam": "esfiar",
    "esfiavas": "esfiar",
    "esfibra": "esfibrar",
    "esfibrada": "esfibrar",
    "esfibradas": "esfibrar",
    "esfibrado": "esfibrar",
    "esfibrados": "esfibrar",
    "esfibrai": "esfibrar",
    "esfibrais": "esfibrar",
    "esfibram": "esfibrar",
    "esfibramo": "esfibrar",
    "esfibramos": "esfibrar",
    "esfibrando": "esfibrar",
    "esfibrara": "esfibrar",
    "esfibraram": "esfibrar",
    "esfibraras": "esfibrar",
    "esfibrarde": "esfibrar",
    "esfibrardes": "esfibrar",
    "esfibrare": "esfibrar",
    "esfibrarei": "esfibrar",
    "esfibrareis": "esfibrar",
    "esfibrarem": "esfibrar",
    "esfibraremos": "esfibrar",
    "esfibrares": "esfibrar",
    "esfibraria": "esfibrar",
    "esfibrariam": "esfibrar",
    "esfibrarias": "esfibrar",
    "esfibrarmo": "esfibrar",
    "esfibrarmos": "esfibrar",
    "esfibrará": "esfibrar",
    "esfibrarás": "esfibrar",
    "esfibrarão": "esfibrar",
    "esfibraríamos": "esfibrar",
    "esfibraríeis": "esfibrar",
    "esfibras": "esfibrar",
    "esfibrasse": "esfibrar",
    "esfibrassem": "esfibrar",
    "esfibrasses": "esfibrar",
    "esfibraste": "esfibrar",
    "esfibrastes": "esfibrar",
    "esfibrava": "esfibrar",
    "esfibravam": "esfibrar",
    "esfibravas": "esfibrar",
    "esfibre": "esfibrar",
    "esfibrei": "esfibrar",
    "esfibreis": "esfibrar",
    "esfibrem": "esfibrar",
    "esfibremo": "esfibrar",
    "esfibremos": "esfibrar",
    "esfibres": "esfibrar",
    "esfibro": "esfibrar",
    "esfibrou": "esfibrar",
    "esfibrá": "esfibrar",
    "esfibrámo": "esfibrar",
    "esfibrámos": "esfibrar",
    "esfibráramo": "esfibrar",
    "esfibráramos": "esfibrar",
    "esfibrárei": "esfibrar",
    "esfibráreis": "esfibrar",
    "esfibrásseis": "esfibrar",
    "esfibrássemos": "esfibrar",
    "esfibrávamo": "esfibrar",
    "esfibrávamos": "esfibrar",
    "esfibrávei": "esfibrar",
    "esfibráveis": "esfibrar",
    "esfie": "esfiar",
    "esfiei": "esfiar",
    "esfieis": "esfiar",
    "esfiem": "esfiar",
    "esfiemo": "esfiar",
    "esfiemos": "esfiar",
    "esfies": "esfiar",
    "esfigmismos": "esfigmismo",
    "esfigmomanométrica": "esfigmomanométrico",
    "esfigmomanométricas": "esfigmomanométrico",
    "esfigmomanométricos": "esfigmomanométrico",
    "esfigmomanómetros": "esfigmomanómetro",
    "esfigmógrafos": "esfigmógrafo",
    "esfigmómetros": "esfigmómetro",
    "esfincterais": "esfincteral",
    "esfincteralgias": "esfincteralgia",
    "esfincterálgica": "esfincterálgico",
    "esfincterálgicas": "esfincterálgico",
    "esfincterálgicos": "esfincterálgico",
    "esfinges": "esfinge",
    "esfingídea": "esfingídeo",
    "esfingídeas": "esfingídeo",
    "esfingídeos": "esfingídeo",
    "esfio": "esfiar",
    "esfiou": "esfiar",
    "esfiá": "esfiar",
    "esfiámo": "esfiar",
    "esfiámos": "esfiar",
    "esfiáramo": "esfiar",
    "esfiáramos": "esfiar",
    "esfiárei": "esfiar",
    "esfiáreis": "esfiar",
    "esfiásseis": "esfiar",
    "esfiássemos": "esfiar",
    "esfiávamo": "esfiar",
    "esfiávamos": "esfiar",
    "esfiávei": "esfiar",
    "esfiáveis": "esfiar",
    "esflora": "esflorar",
    "esflorada": "esflorar",
    "esfloradas": "esflorar",
    "esflorado": "esflorar",
    "esflorados": "esflorar",
    "esflorai": "esflorar",
    "esflorais": "esflorar",
    "esfloram": "esflorar",
    "esfloramo": "esflorar",
    "esfloramos": "esflorar",
    "esflorando": "esflorar",
    "esflorara": "esflorar",
    "esfloraram": "esflorar",
    "esfloraras": "esflorar",
    "esflorarde": "esflorar",
    "esflorardes": "esflorar",
    "esflorare": "esflorar",
    "esflorarei": "esflorar",
    "esflorareis": "esflorar",
    "esflorarem": "esflorar",
    "esfloraremos": "esflorar",
    "esflorares": "esflorar",
    "esfloraria": "esflorar",
    "esflorariam": "esflorar",
    "esflorarias": "esflorar",
    "esflorarmo": "esflorar",
    "esflorarmos": "esflorar",
    "esflorará": "esflorar",
    "esflorarás": "esflorar",
    "esflorarão": "esflorar",
    "esfloraríamos": "esflorar",
    "esfloraríeis": "esflorar",
    "esfloras": "esflorar",
    "esflorasse": "esflorar",
    "esflorassem": "esflorar",
    "esflorasses": "esflorar",
    "esfloraste": "esflorar",
    "esflorastes": "esflorar",
    "esflorava": "esflorar",
    "esfloravam": "esflorar",
    "esfloravas": "esflorar",
    "esflore": "esflorar",
    "esflorei": "esflorar",
    "esfloreis": "esflorar",
    "esflorem": "esflorar",
    "esfloremo": "esflorar",
    "esfloremos": "esflorar",
    "esflores": "esflorar",
    "esfloro": "esflorar",
    "esflorou": "esflorar",
    "esflorá": "esflorar",
    "esflorámo": "esflorar",
    "esflorámos": "esflorar",
    "esfloráramo": "esflorar",
    "esfloráramos": "esflorar",
    "esflorárei": "esflorar",
    "esfloráreis": "esflorar",
    "esflorásseis": "esflorar",
    "esflorássemos": "esflorar",
    "esflorávamo": "esflorar",
    "esflorávamos": "esflorar",
    "esflorávei": "esflorar",
    "esfloráveis": "esflorar",
    "esfogueteada": "esfoguetear",
    "esfogueteadas": "esfoguetear",
    "esfogueteado": "esfoguetear",
    "esfogueteados": "esfoguetear",
    "esfogueteai": "esfoguetear",
    "esfogueteais": "esfoguetear",
    "esfogueteamo": "esfoguetear",
    "esfogueteamos": "esfoguetear",
    "esfogueteando": "esfoguetear",
    "esfogueteara": "esfoguetear",
    "esfoguetearam": "esfoguetear",
    "esfoguetearas": "esfoguetear",
    "esfoguetearde": "esfoguetear",
    "esfogueteardes": "esfoguetear",
    "esfogueteare": "esfoguetear",
    "esfoguetearei": "esfoguetear",
    "esfogueteareis": "esfoguetear",
    "esfoguetearem": "esfoguetear",
    "esfoguetearemos": "esfoguetear",
    "esfogueteares": "esfoguetear",
    "esfoguetearia": "esfoguetear",
    "esfogueteariam": "esfoguetear",
    "esfoguetearias": "esfoguetear",
    "esfoguetearmo": "esfoguetear",
    "esfoguetearmos": "esfoguetear",
    "esfogueteará": "esfoguetear",
    "esfoguetearás": "esfoguetear",
    "esfoguetearão": "esfoguetear",
    "esfoguetearíamos": "esfoguetear",
    "esfoguetearíeis": "esfoguetear",
    "esfogueteasse": "esfoguetear",
    "esfogueteassem": "esfoguetear",
    "esfogueteasses": "esfoguetear",
    "esfogueteaste": "esfoguetear",
    "esfogueteastes": "esfoguetear",
    "esfogueteava": "esfoguetear",
    "esfogueteavam": "esfoguetear",
    "esfogueteavas": "esfoguetear",
    "esfogueteei": "esfoguetear",
    "esfogueteeis": "esfoguetear",
    "esfogueteemo": "esfoguetear",
    "esfogueteemos": "esfoguetear",
    "esfogueteia": "esfoguetear",
    "esfogueteiam": "esfoguetear",
    "esfogueteias": "esfoguetear",
    "esfogueteie": "esfoguetear",
    "esfogueteiem": "esfoguetear",
    "esfogueteies": "esfoguetear",
    "esfogueteio": "esfoguetear",
    "esfogueteou": "esfoguetear",
    "esfogueteá": "esfoguetear",
    "esfogueteámo": "esfoguetear",
    "esfogueteámos": "esfoguetear",
    "esfogueteáramo": "esfoguetear",
    "esfogueteáramos": "esfoguetear",
    "esfogueteárei": "esfoguetear",
    "esfogueteáreis": "esfoguetear",
    "esfogueteásseis": "esfoguetear",
    "esfogueteássemos": "esfoguetear",
    "esfogueteávamo": "esfoguetear",
    "esfogueteávamos": "esfoguetear",
    "esfogueteávei": "esfoguetear",
    "esfogueteáveis": "esfoguetear",
    "esfoice": "esfoiçar",
    "esfoicei": "esfoiçar",
    "esfoiceis": "esfoiçar",
    "esfoicem": "esfoiçar",
    "esfoicemo": "esfoiçar",
    "esfoicemos": "esfoiçar",
    "esfoices": "esfoiçar",
    "esfoiça": "esfoiçar",
    "esfoiçada": "esfoiçar",
    "esfoiçadas": "esfoiçar",
    "esfoiçado": "esfoiçar",
    "esfoiçados": "esfoiçar",
    "esfoiçai": "esfoiçar",
    "esfoiçais": "esfoiçar",
    "esfoiçam": "esfoiçar",
    "esfoiçamo": "esfoiçar",
    "esfoiçamos": "esfoiçar",
    "esfoiçando": "esfoiçar",
    "esfoiçara": "esfoiçar",
    "esfoiçaram": "esfoiçar",
    "esfoiçaras": "esfoiçar",
    "esfoiçarde": "esfoiçar",
    "esfoiçardes": "esfoiçar",
    "esfoiçare": "esfoiçar",
    "esfoiçarei": "esfoiçar",
    "esfoiçareis": "esfoiçar",
    "esfoiçarem": "esfoiçar",
    "esfoiçaremos": "esfoiçar",
    "esfoiçares": "esfoiçar",
    "esfoiçaria": "esfoiçar",
    "esfoiçariam": "esfoiçar",
    "esfoiçarias": "esfoiçar",
    "esfoiçarmo": "esfoiçar",
    "esfoiçarmos": "esfoiçar",
    "esfoiçará": "esfoiçar",
    "esfoiçarás": "esfoiçar",
    "esfoiçarão": "esfoiçar",
    "esfoiçaríamos": "esfoiçar",
    "esfoiçaríeis": "esfoiçar",
    "esfoiças": "esfoiçar",
    "esfoiçasse": "esfoiçar",
    "esfoiçassem": "esfoiçar",
    "esfoiçasses": "esfoiçar",
    "esfoiçaste": "esfoiçar",
    "esfoiçastes": "esfoiçar",
    "esfoiçava": "esfoiçar",
    "esfoiçavam": "esfoiçar",
    "esfoiçavas": "esfoiçar",
    "esfoiço": "esfoiçar",
    "esfoiçou": "esfoiçar",
    "esfoiçá": "esfoiçar",
    "esfoiçámo": "esfoiçar",
    "esfoiçámos": "esfoiçar",
    "esfoiçáramo": "esfoiçar",
    "esfoiçáramos": "esfoiçar",
    "esfoiçárei": "esfoiçar",
    "esfoiçáreis": "esfoiçar",
    "esfoiçásseis": "esfoiçar",
    "esfoiçássemos": "esfoiçar",
    "esfoiçávamo": "esfoiçar",
    "esfoiçávamos": "esfoiçar",
    "esfoiçávei": "esfoiçar",
    "esfoiçáveis": "esfoiçar",
    "esfola": "esfolar",
    "esfolada": "esfolar",
    "esfoladas": "esfolar",
    "esfoladelas": "esfoladela",
    "esfolado": "esfolar",
    "esfoladoiros": "esfoladoiro",
    "esfoladora": "esfolador",
    "esfoladoras": "esfolador",
    "esfoladores": "esfolador",
    "esfolados": "esfolar",
    "esfoladouros": "esfoladouro",
    "esfoladuras": "esfoladura",
    "esfolai": "esfolar",
    "esfolais": "esfolar",
    "esfolam": "esfolar",
    "esfolamentos": "esfolamento",
    "esfolamo": "esfolar",
    "esfolamos": "esfolar",
    "esfolando": "esfolar",
    "esfolara": "esfolar",
    "esfolaram": "esfolar",
    "esfolaras": "esfolar",
    "esfolarde": "esfolar",
    "esfolardes": "esfolar",
    "esfolare": "esfolar",
    "esfolarei": "esfolar",
    "esfolareis": "esfolar",
    "esfolarem": "esfolar",
    "esfolaremos": "esfolar",
    "esfolares": "esfolar",
    "esfolaria": "esfolar",
    "esfolariam": "esfolar",
    "esfolarias": "esfolar",
    "esfolarmo": "esfolar",
    "esfolarmos": "esfolar",
    "esfolará": "esfolar",
    "esfolarás": "esfolar",
    "esfolarão": "esfolar",
    "esfolaríamos": "esfolar",
    "esfolaríeis": "esfolar",
    "esfolas": "esfolar",
    "esfolasse": "esfolar",
    "esfolassem": "esfolar",
    "esfolasses": "esfolar",
    "esfolaste": "esfolar",
    "esfolastes": "esfolar",
    "esfolava": "esfolar",
    "esfolavam": "esfolar",
    "esfolavas": "esfolar",
    "esfole": "esfolar",
    "esfolega": "esfolegar",
    "esfolegada": "esfolegar",
    "esfolegadas": "esfolegar",
    "esfolegado": "esfolegar",
    "esfolegados": "esfolegar",
    "esfolegai": "esfolegar",
    "esfolegais": "esfolegar",
    "esfolegam": "esfolegar",
    "esfolegamo": "esfolegar",
    "esfolegamos": "esfolegar",
    "esfolegando": "esfolegar",
    "esfolegara": "esfolegar",
    "esfolegaram": "esfolegar",
    "esfolegaras": "esfolegar",
    "esfolegardes": "esfolegar",
    "esfolegarei": "esfolegar",
    "esfolegareis": "esfolegar",
    "esfolegarem": "esfolegar",
    "esfolegaremos": "esfolegar",
    "esfolegares": "esfolegar",
    "esfolegaria": "esfolegar",
    "esfolegariam": "esfolegar",
    "esfolegarias": "esfolegar",
    "esfolegarmo": "esfolegar",
    "esfolegarmos": "esfolegar",
    "esfolegará": "esfolegar",
    "esfolegarás": "esfolegar",
    "esfolegarão": "esfolegar",
    "esfolegaríamos": "esfolegar",
    "esfolegaríeis": "esfolegar",
    "esfolegas": "esfolegar",
    "esfolegasse": "esfolegar",
    "esfolegassem": "esfolegar",
    "esfolegasses": "esfolegar",
    "esfolegaste": "esfolegar",
    "esfolegastes": "esfolegar",
    "esfolegava": "esfolegar",
    "esfolegavam": "esfolegar",
    "esfolegavas": "esfolegar",
    "esfolego": "esfolegar",
    "esfolegou": "esfolegar",
    "esfolegue": "esfolegar",
    "esfoleguei": "esfolegar",
    "esfolegueis": "esfolegar",
    "esfoleguem": "esfolegar",
    "esfoleguemo": "esfolegar",
    "esfoleguemos": "esfolegar",
    "esfolegues": "esfolegar",
    "esfolegámo": "esfolegar",
    "esfolegámos": "esfolegar",
    "esfolegáramo": "esfolegar",
    "esfolegáramos": "esfolegar",
    "esfolegáreis": "esfolegar",
    "esfolegásseis": "esfolegar",
    "esfolegássemos": "esfolegar",
    "esfolegávamo": "esfolegar",
    "esfolegávamos": "esfolegar",
    "esfolegáveis": "esfolegar",
    "esfolei": "esfolar",
    "esfoleis": "esfolar",
    "esfolem": "esfolar",
    "esfolemo": "esfolar",
    "esfolemos": "esfolar",
    "esfoles": "esfolar",
    "esfolha": "esfolhar",
    "esfolhace": "esfolhaçar",
    "esfolhacei": "esfolhaçar",
    "esfolhaceis": "esfolhaçar",
    "esfolhacem": "esfolhaçar",
    "esfolhacemo": "esfolhaçar",
    "esfolhacemos": "esfolhaçar",
    "esfolhaces": "esfolhaçar",
    "esfolhada": "esfolhar",
    "esfolhadas": "esfolhar",
    "esfolhado": "esfolhar",
    "esfolhadora": "esfolhador",
    "esfolhadoras": "esfolhador",
    "esfolhadores": "esfolhador",
    "esfolhados": "esfolhar",
    "esfolhai": "esfolhar",
    "esfolhais": "esfolhar",
    "esfolham": "esfolhar",
    "esfolhamo": "esfolhar",
    "esfolhamos": "esfolhar",
    "esfolhando": "esfolhar",
    "esfolhara": "esfolhar",
    "esfolharam": "esfolhar",
    "esfolharas": "esfolhar",
    "esfolharde": "esfolhar",
    "esfolhardes": "esfolhar",
    "esfolhare": "esfolhar",
    "esfolharei": "esfolhar",
    "esfolhareis": "esfolhar",
    "esfolharem": "esfolhar",
    "esfolharemos": "esfolhar",
    "esfolhares": "esfolhar",
    "esfolharia": "esfolhar",
    "esfolhariam": "esfolhar",
    "esfolharias": "esfolhar",
    "esfolharmo": "esfolhar",
    "esfolharmos": "esfolhar",
    "esfolhará": "esfolhar",
    "esfolharás": "esfolhar",
    "esfolharão": "esfolhar",
    "esfolharíamos": "esfolhar",
    "esfolharíeis": "esfolhar",
    "esfolhas": "esfolhar",
    "esfolhasse": "esfolhar",
    "esfolhassem": "esfolhar",
    "esfolhasses": "esfolhar",
    "esfolhaste": "esfolhar",
    "esfolhastes": "esfolhar",
    "esfolhava": "esfolhar",
    "esfolhavam": "esfolhar",
    "esfolhavas": "esfolhar",
    "esfolhaça": "esfolhaçar",
    "esfolhaçada": "esfolhaçar",
    "esfolhaçadas": "esfolhaçar",
    "esfolhaçado": "esfolhaçar",
    "esfolhaçados": "esfolhaçar",
    "esfolhaçai": "esfolhaçar",
    "esfolhaçais": "esfolhaçar",
    "esfolhaçam": "esfolhaçar",
    "esfolhaçamo": "esfolhaçar",
    "esfolhaçamos": "esfolhaçar",
    "esfolhaçando": "esfolhaçar",
    "esfolhaçara": "esfolhaçar",
    "esfolhaçaram": "esfolhaçar",
    "esfolhaçaras": "esfolhaçar",
    "esfolhaçarde": "esfolhaçar",
    "esfolhaçardes": "esfolhaçar",
    "esfolhaçare": "esfolhaçar",
    "esfolhaçarei": "esfolhaçar",
    "esfolhaçareis": "esfolhaçar",
    "esfolhaçarem": "esfolhaçar",
    "esfolhaçaremos": "esfolhaçar",
    "esfolhaçares": "esfolhaçar",
    "esfolhaçaria": "esfolhaçar",
    "esfolhaçariam": "esfolhaçar",
    "esfolhaçarias": "esfolhaçar",
    "esfolhaçarmo": "esfolhaçar",
    "esfolhaçarmos": "esfolhaçar",
    "esfolhaçará": "esfolhaçar",
    "esfolhaçarás": "esfolhaçar",
    "esfolhaçarão": "esfolhaçar",
    "esfolhaçaríamos": "esfolhaçar",
    "esfolhaçaríeis": "esfolhaçar",
    "esfolhaças": "esfolhaçar",
    "esfolhaçasse": "esfolhaçar",
    "esfolhaçassem": "esfolhaçar",
    "esfolhaçasses": "esfolhaçar",
    "esfolhaçaste": "esfolhaçar",
    "esfolhaçastes": "esfolhaçar",
    "esfolhaçava": "esfolhaçar",
    "esfolhaçavam": "esfolhaçar",
    "esfolhaçavas": "esfolhaçar",
    "esfolhaço": "esfolhaçar",
    "esfolhaçou": "esfolhaçar",
    "esfolhaçá": "esfolhaçar",
    "esfolhaçámo": "esfolhaçar",
    "esfolhaçámos": "esfolhaçar",
    "esfolhaçáramo": "esfolhaçar",
    "esfolhaçáramos": "esfolhaçar",
    "esfolhaçárei": "esfolhaçar",
    "esfolhaçáreis": "esfolhaçar",
    "esfolhaçásseis": "esfolhaçar",
    "esfolhaçássemos": "esfolhaçar",
    "esfolhaçávamo": "esfolhaçar",
    "esfolhaçávamos": "esfolhaçar",
    "esfolhaçávei": "esfolhaçar",
    "esfolhaçáveis": "esfolhaçar",
    "esfolhe": "esfolhar",
    "esfolheada": "esfolhear",
    "esfolheadas": "esfolhear",
    "esfolheado": "esfolhear",
    "esfolheados": "esfolhear",
    "esfolheai": "esfolhear",
    "esfolheais": "esfolhear",
    "esfolheamo": "esfolhear",
    "esfolheamos": "esfolhear",
    "esfolheando": "esfolhear",
    "esfolheara": "esfolhear",
    "esfolhearam": "esfolhear",
    "esfolhearas": "esfolhear",
    "esfolhearde": "esfolhear",
    "esfolheardes": "esfolhear",
    "esfolheare": "esfolhear",
    "esfolhearei": "esfolhear",
    "esfolheareis": "esfolhear",
    "esfolhearem": "esfolhear",
    "esfolhearemos": "esfolhear",
    "esfolheares": "esfolhear",
    "esfolhearia": "esfolhear",
    "esfolheariam": "esfolhear",
    "esfolhearias": "esfolhear",
    "esfolhearmo": "esfolhear",
    "esfolhearmos": "esfolhear",
    "esfolheará": "esfolhear",
    "esfolhearás": "esfolhear",
    "esfolhearão": "esfolhear",
    "esfolhearíamos": "esfolhear",
    "esfolhearíeis": "esfolhear",
    "esfolheasse": "esfolhear",
    "esfolheassem": "esfolhear",
    "esfolheasses": "esfolhear",
    "esfolheaste": "esfolhear",
    "esfolheastes": "esfolhear",
    "esfolheava": "esfolhear",
    "esfolheavam": "esfolhear",
    "esfolheavas": "esfolhear",
    "esfolheei": "esfolhear",
    "esfolheeis": "esfolhear",
    "esfolheemo": "esfolhear",
    "esfolheemos": "esfolhear",
    "esfolhei": "esfolhar",
    "esfolheia": "esfolhear",
    "esfolheiam": "esfolhear",
    "esfolheias": "esfolhear",
    "esfolheie": "esfolhear",
    "esfolheiem": "esfolhear",
    "esfolheies": "esfolhear",
    "esfolheio": "esfolhear",
    "esfolheis": "esfolhar",
    "esfolhem": "esfolhar",
    "esfolhemo": "esfolhar",
    "esfolhemos": "esfolhar",
    "esfolheou": "esfolhear",
    "esfolhes": "esfolhar",
    "esfolheá": "esfolhear",
    "esfolheámo": "esfolhear",
    "esfolheámos": "esfolhear",
    "esfolheáramo": "esfolhear",
    "esfolheáramos": "esfolhear",
    "esfolheárei": "esfolhear",
    "esfolheáreis": "esfolhear",
    "esfolheásseis": "esfolhear",
    "esfolheássemos": "esfolhear",
    "esfolheávamo": "esfolhear",
    "esfolheávamos": "esfolhear",
    "esfolheávei": "esfolhear",
    "esfolheáveis": "esfolhear",
    "esfolho": "esfolhar",
    "esfolhosa": "esfolhoso",
    "esfolhosas": "esfolhoso",
    "esfolhosos": "esfolhoso",
    "esfolhou": "esfolhar",
    "esfolhá": "esfolhar",
    "esfolhámo": "esfolhar",
    "esfolhámos": "esfolhar",
    "esfolháramo": "esfolhar",
    "esfolháramos": "esfolhar",
    "esfolhárei": "esfolhar",
    "esfolháreis": "esfolhar",
    "esfolhásseis": "esfolhar",
    "esfolhássemos": "esfolhar",
    "esfolhávamo": "esfolhar",
    "esfolhávamos": "esfolhar",
    "esfolhávei": "esfolhar",
    "esfolháveis": "esfolhar",
    "esfolia": "esfoliar",
    "esfoliada": "esfoliar",
    "esfoliadas": "esfoliar",
    "esfoliado": "esfoliar",
    "esfoliados": "esfoliar",
    "esfoliai": "esfoliar",
    "esfoliais": "esfoliar",
    "esfoliam": "esfoliar",
    "esfoliamo": "esfoliar",
    "esfoliamos": "esfoliar",
    "esfoliando": "esfoliar",
    "esfoliara": "esfoliar",
    "esfoliaram": "esfoliar",
    "esfoliaras": "esfoliar",
    "esfoliarde": "esfoliar",
    "esfoliardes": "esfoliar",
    "esfoliare": "esfoliar",
    "esfoliarei": "esfoliar",
    "esfoliareis": "esfoliar",
    "esfoliarem": "esfoliar",
    "esfoliaremos": "esfoliar",
    "esfoliares": "esfoliar",
    "esfoliaria": "esfoliar",
    "esfoliariam": "esfoliar",
    "esfoliarias": "esfoliar",
    "esfoliarmo": "esfoliar",
    "esfoliarmos": "esfoliar",
    "esfoliará": "esfoliar",
    "esfoliarás": "esfoliar",
    "esfoliarão": "esfoliar",
    "esfoliaríamos": "esfoliar",
    "esfoliaríeis": "esfoliar",
    "esfolias": "esfoliar",
    "esfoliasse": "esfoliar",
    "esfoliassem": "esfoliar",
    "esfoliasses": "esfoliar",
    "esfoliaste": "esfoliar",
    "esfoliastes": "esfoliar",
    "esfoliativa": "esfoliativo",
    "esfoliativas": "esfoliativo",
    "esfoliativos": "esfoliativo",
    "esfoliava": "esfoliar",
    "esfoliavam": "esfoliar",
    "esfoliavas": "esfoliar",
    "esfoliações": "esfoliação",
    "esfolie": "esfoliar",
    "esfoliei": "esfoliar",
    "esfolieis": "esfoliar",
    "esfoliem": "esfoliar",
    "esfoliemo": "esfoliar",
    "esfoliemos": "esfoliar",
    "esfolies": "esfoliar",
    "esfolio": "esfoliar",
    "esfoliou": "esfoliar",
    "esfoliá": "esfoliar",
    "esfoliámo": "esfoliar",
    "esfoliámos": "esfoliar",
    "esfoliáramo": "esfoliar",
    "esfoliáramos": "esfoliar",
    "esfoliárei": "esfoliar",
    "esfoliáreis": "esfoliar",
    "esfoliásseis": "esfoliar",
    "esfoliássemos": "esfoliar",
    "esfoliávamo": "esfoliar",
    "esfoliávamos": "esfoliar",
    "esfoliávei": "esfoliar",
    "esfoliáveis": "esfoliar",
    "esfolo": "esfolar",
    "esfolou": "esfolar",
    "esfolá": "esfolar",
    "esfolámo": "esfolar",
    "esfolámos": "esfolar",
    "esfoláramo": "esfolar",
    "esfoláramos": "esfolar",
    "esfolárei": "esfolar",
    "esfoláreis": "esfolar",
    "esfolásseis": "esfolar",
    "esfolássemos": "esfolar",
    "esfolávamo": "esfolar",
    "esfolávamos": "esfolar",
    "esfolávei": "esfolar",
    "esfoláveis": "esfolar",
    "esfomeada": "esfomear",
    "esfomeadas": "esfomear",
    "esfomeado": "esfomear",
    "esfomeados": "esfomear",
    "esfomeadíssima": "esfomeado",
    "esfomeadíssimas": "esfomeado",
    "esfomeadíssimo": "esfomeado",
    "esfomeadíssimos": "esfomeado",
    "esfomeai": "esfomear",
    "esfomeais": "esfomear",
    "esfomeamo": "esfomear",
    "esfomeamos": "esfomear",
    "esfomeando": "esfomear",
    "esfomeara": "esfomear",
    "esfomearam": "esfomear",
    "esfomearas": "esfomear",
    "esfomeardes": "esfomear",
    "esfomearei": "esfomear",
    "esfomeareis": "esfomear",
    "esfomearem": "esfomear",
    "esfomearemos": "esfomear",
    "esfomeares": "esfomear",
    "esfomearia": "esfomear",
    "esfomeariam": "esfomear",
    "esfomearias": "esfomear",
    "esfomearmo": "esfomear",
    "esfomearmos": "esfomear",
    "esfomeará": "esfomear",
    "esfomearás": "esfomear",
    "esfomearão": "esfomear",
    "esfomearíamos": "esfomear",
    "esfomearíeis": "esfomear",
    "esfomeasse": "esfomear",
    "esfomeassem": "esfomear",
    "esfomeasses": "esfomear",
    "esfomeaste": "esfomear",
    "esfomeastes": "esfomear",
    "esfomeava": "esfomear",
    "esfomeavam": "esfomear",
    "esfomeavas": "esfomear",
    "esfomeei": "esfomear",
    "esfomeeis": "esfomear",
    "esfomeemo": "esfomear",
    "esfomeemos": "esfomear",
    "esfomeia": "esfomear",
    "esfomeiam": "esfomear",
    "esfomeias": "esfomear",
    "esfomeie": "esfomear",
    "esfomeiem": "esfomear",
    "esfomeies": "esfomear",
    "esfomeio": "esfomear",
    "esfomeou": "esfomear",
    "esfomeámo": "esfomear",
    "esfomeámos": "esfomear",
    "esfomeáramo": "esfomear",
    "esfomeáramos": "esfomear",
    "esfomeáreis": "esfomear",
    "esfomeásseis": "esfomear",
    "esfomeássemos": "esfomear",
    "esfomeávamo": "esfomear",
    "esfomeávamos": "esfomear",
    "esfomeáveis": "esfomear",
    "esfondílios": "esfondílio",
    "esforce": "esforçar",
    "esforcei": "esforçar",
    "esforceis": "esforçar",
    "esforcem": "esforçar",
    "esforcemo": "esforçar",
    "esforcemos": "esforçar",
    "esforces": "esforçar",
    "esforrica": "esforricar",
    "esforricada": "esforricar",
    "esforricadas": "esforricar",
    "esforricado": "esforricar",
    "esforricados": "esforricar",
    "esforricai": "esforricar",
    "esforricais": "esforricar",
    "esforricam": "esforricar",
    "esforricamo": "esforricar",
    "esforricamos": "esforricar",
    "esforricando": "esforricar",
    "esforricara": "esforricar",
    "esforricaram": "esforricar",
    "esforricaras": "esforricar",
    "esforricarde": "esforricar",
    "esforricardes": "esforricar",
    "esforricare": "esforricar",
    "esforricarei": "esforricar",
    "esforricareis": "esforricar",
    "esforricarem": "esforricar",
    "esforricaremos": "esforricar",
    "esforricares": "esforricar",
    "esforricaria": "esforricar",
    "esforricariam": "esforricar",
    "esforricarias": "esforricar",
    "esforricarmo": "esforricar",
    "esforricarmos": "esforricar",
    "esforricará": "esforricar",
    "esforricarás": "esforricar",
    "esforricarão": "esforricar",
    "esforricaríamos": "esforricar",
    "esforricaríeis": "esforricar",
    "esforricas": "esforricar",
    "esforricasse": "esforricar",
    "esforricassem": "esforricar",
    "esforricasses": "esforricar",
    "esforricaste": "esforricar",
    "esforricastes": "esforricar",
    "esforricava": "esforricar",
    "esforricavam": "esforricar",
    "esforricavas": "esforricar",
    "esforrico": "esforricar",
    "esforricou": "esforricar",
    "esforricá": "esforricar",
    "esforricámo": "esforricar",
    "esforricámos": "esforricar",
    "esforricáramo": "esforricar",
    "esforricáramos": "esforricar",
    "esforricárei": "esforricar",
    "esforricáreis": "esforricar",
    "esforricásseis": "esforricar",
    "esforricássemos": "esforricar",
    "esforricávamo": "esforricar",
    "esforricávamos": "esforricar",
    "esforricávei": "esforricar",
    "esforricáveis": "esforricar",
    "esforrique": "esforricar",
    "esforriquei": "esforricar",
    "esforriqueis": "esforricar",
    "esforriquem": "esforricar",
    "esforriquemo": "esforricar",
    "esforriquemos": "esforricar",
    "esforriques": "esforricar",
    "esforça": "esforçar",
    "esforçada": "esforçar",
    "esforçadas": "esforçar",
    "esforçado": "esforçar",
    "esforçadora": "esforçador",
    "esforçadoras": "esforçador",
    "esforçadores": "esforçador",
    "esforçados": "esforçar",
    "esforçai": "esforçar",
    "esforçais": "esforçar",
    "esforçam": "esforçar",
    "esforçamo": "esforçar",
    "esforçamos": "esforçar",
    "esforçando": "esforçar",
    "esforçara": "esforçar",
    "esforçaram": "esforçar",
    "esforçaras": "esforçar",
    "esforçarde": "esforçar",
    "esforçardes": "esforçar",
    "esforçare": "esforçar",
    "esforçarei": "esforçar",
    "esforçareis": "esforçar",
    "esforçarem": "esforçar",
    "esforçaremos": "esforçar",
    "esforçares": "esforçar",
    "esforçaria": "esforçar",
    "esforçariam": "esforçar",
    "esforçarias": "esforçar",
    "esforçarmo": "esforçar",
    "esforçarmos": "esforçar",
    "esforçará": "esforçar",
    "esforçarás": "esforçar",
    "esforçarão": "esforçar",
    "esforçaríamos": "esforçar",
    "esforçaríeis": "esforçar",
    "esforças": "esforçar",
    "esforçasse": "esforçar",
    "esforçassem": "esforçar",
    "esforçasses": "esforçar",
    "esforçaste": "esforçar",
    "esforçastes": "esforçar",
    "esforçava": "esforçar",
    "esforçavam": "esforçar",
    "esforçavas": "esforçar",
    "esforço": "esforçar",
    "esforços": "esforço",
    "esforçou": "esforçar",
    "esforçozinho": "esforço",
    "esforçozinhos": "esforço",
    "esforçozito": "esforço",
    "esforçozitos": "esforço",
    "esforçá": "esforçar",
    "esforçámo": "esforçar",
    "esforçámos": "esforçar",
    "esforçáramo": "esforçar",
    "esforçáramos": "esforçar",
    "esforçárei": "esforçar",
    "esforçáreis": "esforçar",
    "esforçásseis": "esforçar",
    "esforçássemos": "esforçar",
    "esforçávamo": "esforçar",
    "esforçávamos": "esforçar",
    "esforçávei": "esforçar",
    "esforçáveis": "esforçar",
    "esfossa": "esfossar",
    "esfossada": "esfossar",
    "esfossadas": "esfossar",
    "esfossado": "esfossar",
    "esfossadora": "esfossador",
    "esfossadoras": "esfossador",
    "esfossadores": "esfossador",
    "esfossados": "esfossar",
    "esfossai": "esfossar",
    "esfossais": "esfossar",
    "esfossam": "esfossar",
    "esfossamo": "esfossar",
    "esfossamos": "esfossar",
    "esfossando": "esfossar",
    "esfossara": "esfossar",
    "esfossaram": "esfossar",
    "esfossaras": "esfossar",
    "esfossarde": "esfossar",
    "esfossardes": "esfossar",
    "esfossare": "esfossar",
    "esfossarei": "esfossar",
    "esfossareis": "esfossar",
    "esfossarem": "esfossar",
    "esfossaremos": "esfossar",
    "esfossares": "esfossar",
    "esfossaria": "esfossar",
    "esfossariam": "esfossar",
    "esfossarias": "esfossar",
    "esfossarmo": "esfossar",
    "esfossarmos": "esfossar",
    "esfossará": "esfossar",
    "esfossarás": "esfossar",
    "esfossarão": "esfossar",
    "esfossaríamos": "esfossar",
    "esfossaríeis": "esfossar",
    "esfossas": "esfossar",
    "esfossasse": "esfossar",
    "esfossassem": "esfossar",
    "esfossasses": "esfossar",
    "esfossaste": "esfossar",
    "esfossastes": "esfossar",
    "esfossava": "esfossar",
    "esfossavam": "esfossar",
    "esfossavas": "esfossar",
    "esfosse": "esfossar",
    "esfossei": "esfossar",
    "esfosseis": "esfossar",
    "esfossem": "esfossar",
    "esfossemo": "esfossar",
    "esfossemos": "esfossar",
    "esfosses": "esfossar",
    "esfossiliza": "esfossilizar",
    "esfossilizada": "esfossilizar",
    "esfossilizadas": "esfossilizar",
    "esfossilizado": "esfossilizar",
    "esfossilizados": "esfossilizar",
    "esfossilizai": "esfossilizar",
    "esfossilizais": "esfossilizar",
    "esfossilizam": "esfossilizar",
    "esfossilizamo": "esfossilizar",
    "esfossilizamos": "esfossilizar",
    "esfossilizando": "esfossilizar",
    "esfossilizara": "esfossilizar",
    "esfossilizaram": "esfossilizar",
    "esfossilizaras": "esfossilizar",
    "esfossilizarde": "esfossilizar",
    "esfossilizardes": "esfossilizar",
    "esfossilizare": "esfossilizar",
    "esfossilizarei": "esfossilizar",
    "esfossilizareis": "esfossilizar",
    "esfossilizarem": "esfossilizar",
    "esfossilizaremos": "esfossilizar",
    "esfossilizares": "esfossilizar",
    "esfossilizaria": "esfossilizar",
    "esfossilizariam": "esfossilizar",
    "esfossilizarias": "esfossilizar",
    "esfossilizarmo": "esfossilizar",
    "esfossilizarmos": "esfossilizar",
    "esfossilizará": "esfossilizar",
    "esfossilizarás": "esfossilizar",
    "esfossilizarão": "esfossilizar",
    "esfossilizaríamos": "esfossilizar",
    "esfossilizaríeis": "esfossilizar",
    "esfossilizas": "esfossilizar",
    "esfossilizasse": "esfossilizar",
    "esfossilizassem": "esfossilizar",
    "esfossilizasses": "esfossilizar",
    "esfossilizaste": "esfossilizar",
    "esfossilizastes": "esfossilizar",
    "esfossilizava": "esfossilizar",
    "esfossilizavam": "esfossilizar",
    "esfossilizavas": "esfossilizar",
    "esfossilize": "esfossilizar",
    "esfossilizei": "esfossilizar",
    "esfossilizeis": "esfossilizar",
    "esfossilizem": "esfossilizar",
    "esfossilizemo": "esfossilizar",
    "esfossilizemos": "esfossilizar",
    "esfossilizes": "esfossilizar",
    "esfossilizo": "esfossilizar",
    "esfossilizou": "esfossilizar",
    "esfossilizá": "esfossilizar",
    "esfossilizámo": "esfossilizar",
    "esfossilizámos": "esfossilizar",
    "esfossilizáramo": "esfossilizar",
    "esfossilizáramos": "esfossilizar",
    "esfossilizárei": "esfossilizar",
    "esfossilizáreis": "esfossilizar",
    "esfossilizásseis": "esfossilizar",
    "esfossilizássemos": "esfossilizar",
    "esfossilizávamo": "esfossilizar",
    "esfossilizávamos": "esfossilizar",
    "esfossilizávei": "esfossilizar",
    "esfossilizáveis": "esfossilizar",
    "esfosso": "esfossar",
    "esfossou": "esfossar",
    "esfossá": "esfossar",
    "esfossámo": "esfossar",
    "esfossámos": "esfossar",
    "esfossáramo": "esfossar",
    "esfossáramos": "esfossar",
    "esfossárei": "esfossar",
    "esfossáreis": "esfossar",
    "esfossásseis": "esfossar",
    "esfossássemos": "esfossar",
    "esfossávamo": "esfossar",
    "esfossávamos": "esfossar",
    "esfossávei": "esfossar",
    "esfossáveis": "esfossar",
    "esfouce": "esfouçar",
    "esfoucei": "esfouçar",
    "esfouceis": "esfouçar",
    "esfoucem": "esfouçar",
    "esfoucemo": "esfouçar",
    "esfoucemos": "esfouçar",
    "esfouces": "esfouçar",
    "esfouça": "esfouçar",
    "esfouçada": "esfouçar",
    "esfouçadas": "esfouçar",
    "esfouçado": "esfouçar",
    "esfouçados": "esfouçar",
    "esfouçai": "esfouçar",
    "esfouçais": "esfouçar",
    "esfouçam": "esfouçar",
    "esfouçamo": "esfouçar",
    "esfouçamos": "esfouçar",
    "esfouçando": "esfouçar",
    "esfouçara": "esfouçar",
    "esfouçaram": "esfouçar",
    "esfouçaras": "esfouçar",
    "esfouçarde": "esfouçar",
    "esfouçardes": "esfouçar",
    "esfouçare": "esfouçar",
    "esfouçarei": "esfouçar",
    "esfouçareis": "esfouçar",
    "esfouçarem": "esfouçar",
    "esfouçaremos": "esfouçar",
    "esfouçares": "esfouçar",
    "esfouçaria": "esfouçar",
    "esfouçariam": "esfouçar",
    "esfouçarias": "esfouçar",
    "esfouçarmo": "esfouçar",
    "esfouçarmos": "esfouçar",
    "esfouçará": "esfouçar",
    "esfouçarás": "esfouçar",
    "esfouçarão": "esfouçar",
    "esfouçaríamos": "esfouçar",
    "esfouçaríeis": "esfouçar",
    "esfouças": "esfouçar",
    "esfouçasse": "esfouçar",
    "esfouçassem": "esfouçar",
    "esfouçasses": "esfouçar",
    "esfouçaste": "esfouçar",
    "esfouçastes": "esfouçar",
    "esfouçava": "esfouçar",
    "esfouçavam": "esfouçar",
    "esfouçavas": "esfouçar",
    "esfouço": "esfouçar",
    "esfouçou": "esfouçar",
    "esfouçá": "esfouçar",
    "esfouçámo": "esfouçar",
    "esfouçámos": "esfouçar",
    "esfouçáramo": "esfouçar",
    "esfouçáramos": "esfouçar",
    "esfouçárei": "esfouçar",
    "esfouçáreis": "esfouçar",
    "esfouçásseis": "esfouçar",
    "esfouçássemos": "esfouçar",
    "esfouçávamo": "esfouçar",
    "esfouçávamos": "esfouçar",
    "esfouçávei": "esfouçar",
    "esfouçáveis": "esfouçar",
    "esfralda": "esfraldar",
    "esfraldada": "esfraldar",
    "esfraldadas": "esfraldar",
    "esfraldado": "esfraldar",
    "esfraldados": "esfraldar",
    "esfraldai": "esfraldar",
    "esfraldais": "esfraldar",
    "esfraldam": "esfraldar",
    "esfraldamo": "esfraldar",
    "esfraldamos": "esfraldar",
    "esfraldando": "esfraldar",
    "esfraldara": "esfraldar",
    "esfraldaram": "esfraldar",
    "esfraldaras": "esfraldar",
    "esfraldarde": "esfraldar",
    "esfraldardes": "esfraldar",
    "esfraldare": "esfraldar",
    "esfraldarei": "esfraldar",
    "esfraldareis": "esfraldar",
    "esfraldarem": "esfraldar",
    "esfraldaremos": "esfraldar",
    "esfraldares": "esfraldar",
    "esfraldaria": "esfraldar",
    "esfraldariam": "esfraldar",
    "esfraldarias": "esfraldar",
    "esfraldarmo": "esfraldar",
    "esfraldarmos": "esfraldar",
    "esfraldará": "esfraldar",
    "esfraldarás": "esfraldar",
    "esfraldarão": "esfraldar",
    "esfraldaríamos": "esfraldar",
    "esfraldaríeis": "esfraldar",
    "esfraldas": "esfraldar",
    "esfraldasse": "esfraldar",
    "esfraldassem": "esfraldar",
    "esfraldasses": "esfraldar",
    "esfraldaste": "esfraldar",
    "esfraldastes": "esfraldar",
    "esfraldava": "esfraldar",
    "esfraldavam": "esfraldar",
    "esfraldavas": "esfraldar",
    "esfralde": "esfraldar",
    "esfraldei": "esfraldar",
    "esfraldeis": "esfraldar",
    "esfraldem": "esfraldar",
    "esfraldemo": "esfraldar",
    "esfraldemos": "esfraldar",
    "esfraldes": "esfraldar",
    "esfraldo": "esfraldar",
    "esfraldou": "esfraldar",
    "esfraldá": "esfraldar",
    "esfraldámo": "esfraldar",
    "esfraldámos": "esfraldar",
    "esfraldáramo": "esfraldar",
    "esfraldáramos": "esfraldar",
    "esfraldárei": "esfraldar",
    "esfraldáreis": "esfraldar",
    "esfraldásseis": "esfraldar",
    "esfraldássemos": "esfraldar",
    "esfraldávamo": "esfraldar",
    "esfraldávamos": "esfraldar",
    "esfraldávei": "esfraldar",
    "esfraldáveis": "esfraldar",
    "esfrance": "esfrançar",
    "esfrancei": "esfrançar",
    "esfranceis": "esfrançar",
    "esfrancem": "esfrançar",
    "esfrancemo": "esfrançar",
    "esfrancemos": "esfrançar",
    "esfrances": "esfrançar",
    "esfrangalha": "esfrangalhar",
    "esfrangalhada": "esfrangalhar",
    "esfrangalhadas": "esfrangalhar",
    "esfrangalhado": "esfrangalhar",
    "esfrangalhados": "esfrangalhar",
    "esfrangalhai": "esfrangalhar",
    "esfrangalhais": "esfrangalhar",
    "esfrangalham": "esfrangalhar",
    "esfrangalhamo": "esfrangalhar",
    "esfrangalhamos": "esfrangalhar",
    "esfrangalhando": "esfrangalhar",
    "esfrangalhara": "esfrangalhar",
    "esfrangalharam": "esfrangalhar",
    "esfrangalharas": "esfrangalhar",
    "esfrangalharde": "esfrangalhar",
    "esfrangalhardes": "esfrangalhar",
    "esfrangalhare": "esfrangalhar",
    "esfrangalharei": "esfrangalhar",
    "esfrangalhareis": "esfrangalhar",
    "esfrangalharem": "esfrangalhar",
    "esfrangalharemos": "esfrangalhar",
    "esfrangalhares": "esfrangalhar",
    "esfrangalharia": "esfrangalhar",
    "esfrangalhariam": "esfrangalhar",
    "esfrangalharias": "esfrangalhar",
    "esfrangalharmo": "esfrangalhar",
    "esfrangalharmos": "esfrangalhar",
    "esfrangalhará": "esfrangalhar",
    "esfrangalharás": "esfrangalhar",
    "esfrangalharão": "esfrangalhar",
    "esfrangalharíamos": "esfrangalhar",
    "esfrangalharíeis": "esfrangalhar",
    "esfrangalhas": "esfrangalhar",
    "esfrangalhasse": "esfrangalhar",
    "esfrangalhassem": "esfrangalhar",
    "esfrangalhasses": "esfrangalhar",
    "esfrangalhaste": "esfrangalhar",
    "esfrangalhastes": "esfrangalhar",
    "esfrangalhava": "esfrangalhar",
    "esfrangalhavam": "esfrangalhar",
    "esfrangalhavas": "esfrangalhar",
    "esfrangalhe": "esfrangalhar",
    "esfrangalhei": "esfrangalhar",
    "esfrangalheis": "esfrangalhar",
    "esfrangalhem": "esfrangalhar",
    "esfrangalhemo": "esfrangalhar",
    "esfrangalhemos": "esfrangalhar",
    "esfrangalhes": "esfrangalhar",
    "esfrangalho": "esfrangalhar",
    "esfrangalhou": "esfrangalhar",
    "esfrangalhá": "esfrangalhar",
    "esfrangalhámo": "esfrangalhar",
    "esfrangalhámos": "esfrangalhar",
    "esfrangalháramo": "esfrangalhar",
    "esfrangalháramos": "esfrangalhar",
    "esfrangalhárei": "esfrangalhar",
    "esfrangalháreis": "esfrangalhar",
    "esfrangalhásseis": "esfrangalhar",
    "esfrangalhássemos": "esfrangalhar",
    "esfrangalhávamo": "esfrangalhar",
    "esfrangalhávamos": "esfrangalhar",
    "esfrangalhávei": "esfrangalhar",
    "esfrangalháveis": "esfrangalhar",
    "esfrança": "esfrançar",
    "esfrançada": "esfrançar",
    "esfrançadas": "esfrançar",
    "esfrançado": "esfrançar",
    "esfrançados": "esfrançar",
    "esfrançai": "esfrançar",
    "esfrançais": "esfrançar",
    "esfrançam": "esfrançar",
    "esfrançamo": "esfrançar",
    "esfrançamos": "esfrançar",
    "esfrançando": "esfrançar",
    "esfrançara": "esfrançar",
    "esfrançaram": "esfrançar",
    "esfrançaras": "esfrançar",
    "esfrançarde": "esfrançar",
    "esfrançardes": "esfrançar",
    "esfrançare": "esfrançar",
    "esfrançarei": "esfrançar",
    "esfrançareis": "esfrançar",
    "esfrançarem": "esfrançar",
    "esfrançaremos": "esfrançar",
    "esfrançares": "esfrançar",
    "esfrançaria": "esfrançar",
    "esfrançariam": "esfrançar",
    "esfrançarias": "esfrançar",
    "esfrançarmo": "esfrançar",
    "esfrançarmos": "esfrançar",
    "esfrançará": "esfrançar",
    "esfrançarás": "esfrançar",
    "esfrançarão": "esfrançar",
    "esfrançaríamos": "esfrançar",
    "esfrançaríeis": "esfrançar",
    "esfranças": "esfrançar",
    "esfrançasse": "esfrançar",
    "esfrançassem": "esfrançar",
    "esfrançasses": "esfrançar",
    "esfrançaste": "esfrançar",
    "esfrançastes": "esfrançar",
    "esfrançava": "esfrançar",
    "esfrançavam": "esfrançar",
    "esfrançavas": "esfrançar",
    "esfranço": "esfrançar",
    "esfrançou": "esfrançar",
    "esfrançá": "esfrançar",
    "esfrançámo": "esfrançar",
    "esfrançámos": "esfrançar",
    "esfrançáramo": "esfrançar",
    "esfrançáramos": "esfrançar",
    "esfrançárei": "esfrançar",
    "esfrançáreis": "esfrançar",
    "esfrançásseis": "esfrançar",
    "esfrançássemos": "esfrançar",
    "esfrançávamo": "esfrançar",
    "esfrançávamos": "esfrançar",
    "esfrançávei": "esfrançar",
    "esfrançáveis": "esfrançar",
    "esfrasgistas": "esfrasgista",
    "esfrasgísticas": "esfrasgística",
    "esfrega": "esfregar",
    "esfregada": "esfregar",
    "esfregadas": "esfregar",
    "esfregadeiras": "esfregadeira",
    "esfregadelas": "esfregadela",
    "esfregado": "esfregar",
    "esfregadora": "esfregador",
    "esfregadoras": "esfregador",
    "esfregadores": "esfregador",
    "esfregados": "esfregar",
    "esfregaduras": "esfregadura",
    "esfregai": "esfregar",
    "esfregais": "esfregar",
    "esfregalhos": "esfregalho",
    "esfregam": "esfregar",
    "esfregamentos": "esfregamento",
    "esfregamo": "esfregar",
    "esfregamos": "esfregar",
    "esfregando": "esfregar",
    "esfregara": "esfregar",
    "esfregaram": "esfregar",
    "esfregaras": "esfregar",
    "esfregarde": "esfregar",
    "esfregardes": "esfregar",
    "esfregare": "esfregar",
    "esfregarei": "esfregar",
    "esfregareis": "esfregar",
    "esfregarem": "esfregar",
    "esfregaremos": "esfregar",
    "esfregares": "esfregar",
    "esfregaria": "esfregar",
    "esfregariam": "esfregar",
    "esfregarias": "esfregar",
    "esfregarmo": "esfregar",
    "esfregarmos": "esfregar",
    "esfregará": "esfregar",
    "esfregarás": "esfregar",
    "esfregarão": "esfregar",
    "esfregaríamos": "esfregar",
    "esfregaríeis": "esfregar",
    "esfregas": "esfregar",
    "esfregasse": "esfregar",
    "esfregassem": "esfregar",
    "esfregasses": "esfregar",
    "esfregaste": "esfregar",
    "esfregastes": "esfregar",
    "esfregava": "esfregar",
    "esfregavam": "esfregar",
    "esfregavas": "esfregar",
    "esfregaços": "esfregaço",
    "esfregações": "esfregação",
    "esfrego": "esfregar",
    "esfregonas": "esfregona",
    "esfregou": "esfregar",
    "esfregue": "esfregar",
    "esfreguei": "esfregar",
    "esfregueis": "esfregar",
    "esfreguem": "esfregar",
    "esfreguemo": "esfregar",
    "esfreguemos": "esfregar",
    "esfregues": "esfregar",
    "esfregá": "esfregar",
    "esfregámo": "esfregar",
    "esfregámos": "esfregar",
    "esfregáramo": "esfregar",
    "esfregáramos": "esfregar",
    "esfregárei": "esfregar",
    "esfregáreis": "esfregar",
    "esfregásseis": "esfregar",
    "esfregássemos": "esfregar",
    "esfregávamo": "esfregar",
    "esfregávamos": "esfregar",
    "esfregávei": "esfregar",
    "esfregáveis": "esfregar",
    "esfregãozinho": "esfregão",
    "esfregãozito": "esfregão",
    "esfregões": "esfregão",
    "esfregõezinhos": "esfregão",
    "esfregõezitos": "esfregão",
    "esfria": "esfriar",
    "esfriada": "esfriar",
    "esfriadas": "esfriar",
    "esfriado": "esfriar",
    "esfriadoiros": "esfriadoiro",
    "esfriadora": "esfriador",
    "esfriadoras": "esfriador",
    "esfriadores": "esfriador",
    "esfriados": "esfriar",
    "esfriadouros": "esfriadouro",
    "esfriai": "esfriar",
    "esfriais": "esfriar",
    "esfriam": "esfriar",
    "esfriamentos": "esfriamento",
    "esfriamo": "esfriar",
    "esfriamos": "esfriar",
    "esfriando": "esfriar",
    "esfriantes": "esfriante",
    "esfriara": "esfriar",
    "esfriaram": "esfriar",
    "esfriaras": "esfriar",
    "esfriarde": "esfriar",
    "esfriardes": "esfriar",
    "esfriare": "esfriar",
    "esfriarei": "esfriar",
    "esfriareis": "esfriar",
    "esfriarem": "esfriar",
    "esfriaremos": "esfriar",
    "esfriares": "esfriar",
    "esfriaria": "esfriar",
    "esfriariam": "esfriar",
    "esfriarias": "esfriar",
    "esfriarmo": "esfriar",
    "esfriarmos": "esfriar",
    "esfriará": "esfriar",
    "esfriarás": "esfriar",
    "esfriarão": "esfriar",
    "esfriaríamos": "esfriar",
    "esfriaríeis": "esfriar",
    "esfrias": "esfriar",
    "esfriasse": "esfriar",
    "esfriassem": "esfriar",
    "esfriasses": "esfriar",
    "esfriaste": "esfriar",
    "esfriastes": "esfriar",
    "esfriava": "esfriar",
    "esfriavam": "esfriar",
    "esfriavas": "esfriar",
    "esfrie": "esfriar",
    "esfriei": "esfriar",
    "esfrieis": "esfriar",
    "esfriem": "esfriar",
    "esfriemo": "esfriar",
    "esfriemos": "esfriar",
    "esfries": "esfriar",
    "esfrio": "esfriar",
    "esfriou": "esfriar",
    "esfriá": "esfriar",
    "esfriámo": "esfriar",
    "esfriámos": "esfriar",
    "esfriáramo": "esfriar",
    "esfriáramos": "esfriar",
    "esfriárei": "esfriar",
    "esfriáreis": "esfriar",
    "esfriásseis": "esfriar",
    "esfriássemos": "esfriar",
    "esfriávamo": "esfriar",
    "esfriávamos": "esfriar",
    "esfriávei": "esfriar",
    "esfriáveis": "esfriar",
    "esfrola": "esfrolar",
    "esfrolada": "esfrolar",
    "esfroladas": "esfrolar",
    "esfrolado": "esfrolar",
    "esfrolados": "esfrolar",
    "esfrolai": "esfrolar",
    "esfrolais": "esfrolar",
    "esfrolam": "esfrolar",
    "esfrolamo": "esfrolar",
    "esfrolamos": "esfrolar",
    "esfrolando": "esfrolar",
    "esfrolara": "esfrolar",
    "esfrolaram": "esfrolar",
    "esfrolaras": "esfrolar",
    "esfrolarde": "esfrolar",
    "esfrolardes": "esfrolar",
    "esfrolare": "esfrolar",
    "esfrolarei": "esfrolar",
    "esfrolareis": "esfrolar",
    "esfrolarem": "esfrolar",
    "esfrolaremos": "esfrolar",
    "esfrolares": "esfrolar",
    "esfrolaria": "esfrolar",
    "esfrolariam": "esfrolar",
    "esfrolarias": "esfrolar",
    "esfrolarmo": "esfrolar",
    "esfrolarmos": "esfrolar",
    "esfrolará": "esfrolar",
    "esfrolarás": "esfrolar",
    "esfrolarão": "esfrolar",
    "esfrolaríamos": "esfrolar",
    "esfrolaríeis": "esfrolar",
    "esfrolas": "esfrolar",
    "esfrolasse": "esfrolar",
    "esfrolassem": "esfrolar",
    "esfrolasses": "esfrolar",
    "esfrolaste": "esfrolar",
    "esfrolastes": "esfrolar",
    "esfrolava": "esfrolar",
    "esfrolavam": "esfrolar",
    "esfrolavas": "esfrolar",
    "esfrole": "esfrolar",
    "esfrolei": "esfrolar",
    "esfroleis": "esfrolar",
    "esfrolem": "esfrolar",
    "esfrolemo": "esfrolar",
    "esfrolemos": "esfrolar",
    "esfroles": "esfrolar",
    "esfrolo": "esfrolar",
    "esfrolou": "esfrolar",
    "esfrolá": "esfrolar",
    "esfrolámo": "esfrolar",
    "esfrolámos": "esfrolar",
    "esfroláramo": "esfrolar",
    "esfroláramos": "esfrolar",
    "esfrolárei": "esfrolar",
    "esfroláreis": "esfrolar",
    "esfrolásseis": "esfrolar",
    "esfrolássemos": "esfrolar",
    "esfrolávamo": "esfrolar",
    "esfrolávamos": "esfrolar",
    "esfrolávei": "esfrolar",
    "esfroláveis": "esfrolar",
    "esfugenta": "esfugentar",
    "esfugentada": "esfugentar",
    "esfugentadas": "esfugentar",
    "esfugentado": "esfugentar",
    "esfugentados": "esfugentar",
    "esfugentai": "esfugentar",
    "esfugentais": "esfugentar",
    "esfugentam": "esfugentar",
    "esfugentamo": "esfugentar",
    "esfugentamos": "esfugentar",
    "esfugentando": "esfugentar",
    "esfugentara": "esfugentar",
    "esfugentaram": "esfugentar",
    "esfugentaras": "esfugentar",
    "esfugentarde": "esfugentar",
    "esfugentardes": "esfugentar",
    "esfugentare": "esfugentar",
    "esfugentarei": "esfugentar",
    "esfugentareis": "esfugentar",
    "esfugentarem": "esfugentar",
    "esfugentaremos": "esfugentar",
    "esfugentares": "esfugentar",
    "esfugentaria": "esfugentar",
    "esfugentariam": "esfugentar",
    "esfugentarias": "esfugentar",
    "esfugentarmo": "esfugentar",
    "esfugentarmos": "esfugentar",
    "esfugentará": "esfugentar",
    "esfugentarás": "esfugentar",
    "esfugentarão": "esfugentar",
    "esfugentaríamos": "esfugentar",
    "esfugentaríeis": "esfugentar",
    "esfugentas": "esfugentar",
    "esfugentasse": "esfugentar",
    "esfugentassem": "esfugentar",
    "esfugentasses": "esfugentar",
    "esfugentaste": "esfugentar",
    "esfugentastes": "esfugentar",
    "esfugentava": "esfugentar",
    "esfugentavam": "esfugentar",
    "esfugentavas": "esfugentar",
    "esfugente": "esfugentar",
    "esfugentei": "esfugentar",
    "esfugenteis": "esfugentar",
    "esfugentem": "esfugentar",
    "esfugentemo": "esfugentar",
    "esfugentemos": "esfugentar",
    "esfugentes": "esfugentar",
    "esfugento": "esfugentar",
    "esfugentou": "esfugentar",
    "esfugentá": "esfugentar",
    "esfugentámo": "esfugentar",
    "esfugentámos": "esfugentar",
    "esfugentáramo": "esfugentar",
    "esfugentáramos": "esfugentar",
    "esfugentárei": "esfugentar",
    "esfugentáreis": "esfugentar",
    "esfugentásseis": "esfugentar",
    "esfugentássemos": "esfugentar",
    "esfugentávamo": "esfugentar",
    "esfugentávamos": "esfugentar",
    "esfugentávei": "esfugentar",
    "esfugentáveis": "esfugentar",
    "esfulinha": "esfulinhar",
    "esfulinhada": "esfulinhar",
    "esfulinhadas": "esfulinhar",
    "esfulinhado": "esfulinhar",
    "esfulinhados": "esfulinhar",
    "esfulinhai": "esfulinhar",
    "esfulinhais": "esfulinhar",
    "esfulinham": "esfulinhar",
    "esfulinhamo": "esfulinhar",
    "esfulinhamos": "esfulinhar",
    "esfulinhando": "esfulinhar",
    "esfulinhara": "esfulinhar",
    "esfulinharam": "esfulinhar",
    "esfulinharas": "esfulinhar",
    "esfulinharde": "esfulinhar",
    "esfulinhardes": "esfulinhar",
    "esfulinhare": "esfulinhar",
    "esfulinharei": "esfulinhar",
    "esfulinhareis": "esfulinhar",
    "esfulinharem": "esfulinhar",
    "esfulinharemos": "esfulinhar",
    "esfulinhares": "esfulinhar",
    "esfulinharia": "esfulinhar",
    "esfulinhariam": "esfulinhar",
    "esfulinharias": "esfulinhar",
    "esfulinharmo": "esfulinhar",
    "esfulinharmos": "esfulinhar",
    "esfulinhará": "esfulinhar",
    "esfulinharás": "esfulinhar",
    "esfulinharão": "esfulinhar",
    "esfulinharíamos": "esfulinhar",
    "esfulinharíeis": "esfulinhar",
    "esfulinhas": "esfulinhar",
    "esfulinhasse": "esfulinhar",
    "esfulinhassem": "esfulinhar",
    "esfulinhasses": "esfulinhar",
    "esfulinhaste": "esfulinhar",
    "esfulinhastes": "esfulinhar",
    "esfulinhava": "esfulinhar",
    "esfulinhavam": "esfulinhar",
    "esfulinhavas": "esfulinhar",
    "esfulinhe": "esfulinhar",
    "esfulinhei": "esfulinhar",
    "esfulinheis": "esfulinhar",
    "esfulinhem": "esfulinhar",
    "esfulinhemo": "esfulinhar",
    "esfulinhemos": "esfulinhar",
    "esfulinhes": "esfulinhar",
    "esfulinho": "esfulinhar",
    "esfulinhou": "esfulinhar",
    "esfulinhá": "esfulinhar",
    "esfulinhámo": "esfulinhar",
    "esfulinhámos": "esfulinhar",
    "esfulinháramo": "esfulinhar",
    "esfulinháramos": "esfulinhar",
    "esfulinhárei": "esfulinhar",
    "esfulinháreis": "esfulinhar",
    "esfulinhásseis": "esfulinhar",
    "esfulinhássemos": "esfulinhar",
    "esfulinhávamo": "esfulinhar",
    "esfulinhávamos": "esfulinhar",
    "esfulinhávei": "esfulinhar",
    "esfulinháveis": "esfulinhar",
    "esfuma": "esfumar",
    "esfumace": "esfumaçar",
    "esfumacei": "esfumaçar",
    "esfumaceis": "esfumaçar",
    "esfumacem": "esfumaçar",
    "esfumacemo": "esfumaçar",
    "esfumacemos": "esfumaçar",
    "esfumaces": "esfumaçar",
    "esfumada": "esfumar",
    "esfumadas": "esfumar",
    "esfumado": "esfumar",
    "esfumadores": "esfumador",
    "esfumados": "esfumar",
    "esfumai": "esfumar",
    "esfumais": "esfumar",
    "esfumam": "esfumar",
    "esfumamo": "esfumar",
    "esfumamos": "esfumar",
    "esfumando": "esfumar",
    "esfumara": "esfumarar",
    "esfumarada": "esfumarar",
    "esfumaradas": "esfumarar",
    "esfumarado": "esfumarar",
    "esfumarados": "esfumarar",
    "esfumarai": "esfumarar",
    "esfumarais": "esfumarar",
    "esfumaram": "esfumarar",
    "esfumaramo": "esfumarar",
    "esfumaramos": "esfumarar",
    "esfumarando": "esfumarar",
    "esfumarara": "esfumarar",
    "esfumararam": "esfumarar",
    "esfumararas": "esfumarar",
    "esfumararde": "esfumarar",
    "esfumarardes": "esfumarar",
    "esfumarare": "esfumarar",
    "esfumararei": "esfumarar",
    "esfumarareis": "esfumarar",
    "esfumararem": "esfumarar",
    "esfumararemos": "esfumarar",
    "esfumarares": "esfumarar",
    "esfumararia": "esfumarar",
    "esfumarariam": "esfumarar",
    "esfumararias": "esfumarar",
    "esfumararmo": "esfumarar",
    "esfumararmos": "esfumarar",
    "esfumarará": "esfumarar",
    "esfumararás": "esfumarar",
    "esfumararão": "esfumarar",
    "esfumararíamos": "esfumarar",
    "esfumararíeis": "esfumarar",
    "esfumaras": "esfumarar",
    "esfumarasse": "esfumarar",
    "esfumarassem": "esfumarar",
    "esfumarasses": "esfumarar",
    "esfumaraste": "esfumarar",
    "esfumarastes": "esfumarar",
    "esfumarava": "esfumarar",
    "esfumaravam": "esfumarar",
    "esfumaravas": "esfumarar",
    "esfumarde": "esfumar",
    "esfumardes": "esfumar",
    "esfumare": "esfumarar",
    "esfumarei": "esfumarar",
    "esfumareis": "esfumarar",
    "esfumarem": "esfumarar",
    "esfumaremo": "esfumarar",
    "esfumaremos": "esfumarar",
    "esfumares": "esfumarar",
    "esfumaria": "esfumar",
    "esfumariam": "esfumar",
    "esfumarias": "esfumar",
    "esfumarmo": "esfumar",
    "esfumarmos": "esfumar",
    "esfumaro": "esfumarar",
    "esfumarou": "esfumarar",
    "esfumará": "esfumarar",
    "esfumarámo": "esfumarar",
    "esfumarámos": "esfumarar",
    "esfumaráramo": "esfumarar",
    "esfumaráramos": "esfumarar",
    "esfumarárei": "esfumarar",
    "esfumaráreis": "esfumarar",
    "esfumarás": "esfumar",
    "esfumarásseis": "esfumarar",
    "esfumarássemos": "esfumarar",
    "esfumarávamo": "esfumarar",
    "esfumarávamos": "esfumarar",
    "esfumarávei": "esfumarar",
    "esfumaráveis": "esfumarar",
    "esfumarão": "esfumar",
    "esfumaríamos": "esfumar",
    "esfumaríeis": "esfumar",
    "esfumas": "esfumar",
    "esfumasse": "esfumar",
    "esfumassem": "esfumar",
    "esfumasses": "esfumar",
    "esfumaste": "esfumar",
    "esfumastes": "esfumar",
    "esfumava": "esfumar",
    "esfumavam": "esfumar",
    "esfumavas": "esfumar",
    "esfumaça": "esfumaçar",
    "esfumaçada": "esfumaçar",
    "esfumaçadas": "esfumaçar",
    "esfumaçado": "esfumaçar",
    "esfumaçados": "esfumaçar",
    "esfumaçai": "esfumaçar",
    "esfumaçais": "esfumaçar",
    "esfumaçam": "esfumaçar",
    "esfumaçamo": "esfumaçar",
    "esfumaçamos": "esfumaçar",
    "esfumaçando": "esfumaçar",
    "esfumaçara": "esfumaçar",
    "esfumaçaram": "esfumaçar",
    "esfumaçaras": "esfumaçar",
    "esfumaçardes": "esfumaçar",
    "esfumaçarei": "esfumaçar",
    "esfumaçareis": "esfumaçar",
    "esfumaçarem": "esfumaçar",
    "esfumaçaremos": "esfumaçar",
    "esfumaçares": "esfumaçar",
    "esfumaçaria": "esfumaçar",
    "esfumaçariam": "esfumaçar",
    "esfumaçarias": "esfumaçar",
    "esfumaçarmo": "esfumaçar",
    "esfumaçarmos": "esfumaçar",
    "esfumaçará": "esfumaçar",
    "esfumaçarás": "esfumaçar",
    "esfumaçarão": "esfumaçar",
    "esfumaçaríamos": "esfumaçar",
    "esfumaçaríeis": "esfumaçar",
    "esfumaças": "esfumaçar",
    "esfumaçasse": "esfumaçar",
    "esfumaçassem": "esfumaçar",
    "esfumaçasses": "esfumaçar",
    "esfumaçaste": "esfumaçar",
    "esfumaçastes": "esfumaçar",
    "esfumaçava": "esfumaçar",
    "esfumaçavam": "esfumaçar",
    "esfumaçavas": "esfumaçar",
    "esfumaço": "esfumaçar",
    "esfumaçou": "esfumaçar",
    "esfumaçámo": "esfumaçar",
    "esfumaçámos": "esfumaçar",
    "esfumaçáramo": "esfumaçar",
    "esfumaçáramos": "esfumaçar",
    "esfumaçáreis": "esfumaçar",
    "esfumaçásseis": "esfumaçar",
    "esfumaçássemos": "esfumaçar",
    "esfumaçávamo": "esfumaçar",
    "esfumaçávamos": "esfumaçar",
    "esfumaçáveis": "esfumaçar",
    "esfumações": "esfumação",
    "esfume": "esfumar",
    "esfumeada": "esfumear",
    "esfumeadas": "esfumear",
    "esfumeado": "esfumear",
    "esfumeados": "esfumear",
    "esfumeai": "esfumear",
    "esfumeais": "esfumear",
    "esfumeamo": "esfumear",
    "esfumeamos": "esfumear",
    "esfumeando": "esfumear",
    "esfumeara": "esfumear",
    "esfumearam": "esfumear",
    "esfumearas": "esfumear",
    "esfumearde": "esfumear",
    "esfumeardes": "esfumear",
    "esfumeare": "esfumear",
    "esfumearei": "esfumear",
    "esfumeareis": "esfumear",
    "esfumearem": "esfumear",
    "esfumearemos": "esfumear",
    "esfumeares": "esfumear",
    "esfumearia": "esfumear",
    "esfumeariam": "esfumear",
    "esfumearias": "esfumear",
    "esfumearmo": "esfumear",
    "esfumearmos": "esfumear",
    "esfumeará": "esfumear",
    "esfumearás": "esfumear",
    "esfumearão": "esfumear",
    "esfumearíamos": "esfumear",
    "esfumearíeis": "esfumear",
    "esfumeasse": "esfumear",
    "esfumeassem": "esfumear",
    "esfumeasses": "esfumear",
    "esfumeaste": "esfumear",
    "esfumeastes": "esfumear",
    "esfumeava": "esfumear",
    "esfumeavam": "esfumear",
    "esfumeavas": "esfumear",
    "esfumeei": "esfumear",
    "esfumeeis": "esfumear",
    "esfumeemo": "esfumear",
    "esfumeemos": "esfumear",
    "esfumei": "esfumar",
    "esfumeia": "esfumear",
    "esfumeiam": "esfumear",
    "esfumeias": "esfumear",
    "esfumeie": "esfumear",
    "esfumeiem": "esfumear",
    "esfumeies": "esfumear",
    "esfumeio": "esfumear",
    "esfumeis": "esfumar",
    "esfumem": "esfumar",
    "esfumemo": "esfumar",
    "esfumemos": "esfumar",
    "esfumeou": "esfumear",
    "esfumes": "esfumar",
    "esfumeá": "esfumear",
    "esfumeámo": "esfumear",
    "esfumeámos": "esfumear",
    "esfumeáramo": "esfumear",
    "esfumeáramos": "esfumear",
    "esfumeárei": "esfumear",
    "esfumeáreis": "esfumear",
    "esfumeásseis": "esfumear",
    "esfumeássemos": "esfumear",
    "esfumeávamo": "esfumear",
    "esfumeávamos": "esfumear",
    "esfumeávei": "esfumear",
    "esfumeáveis": "esfumear",
    "esfumilha": "esfumilhar",
    "esfumilhada": "esfumilhar",
    "esfumilhadas": "esfumilhar",
    "esfumilhado": "esfumilhar",
    "esfumilhados": "esfumilhar",
    "esfumilhai": "esfumilhar",
    "esfumilhais": "esfumilhar",
    "esfumilham": "esfumilhar",
    "esfumilhamo": "esfumilhar",
    "esfumilhamos": "esfumilhar",
    "esfumilhando": "esfumilhar",
    "esfumilhara": "esfumilhar",
    "esfumilharam": "esfumilhar",
    "esfumilharas": "esfumilhar",
    "esfumilharde": "esfumilhar",
    "esfumilhardes": "esfumilhar",
    "esfumilhare": "esfumilhar",
    "esfumilharei": "esfumilhar",
    "esfumilhareis": "esfumilhar",
    "esfumilharem": "esfumilhar",
    "esfumilharemos": "esfumilhar",
    "esfumilhares": "esfumilhar",
    "esfumilharia": "esfumilhar",
    "esfumilhariam": "esfumilhar",
    "esfumilharias": "esfumilhar",
    "esfumilharmo": "esfumilhar",
    "esfumilharmos": "esfumilhar",
    "esfumilhará": "esfumilhar",
    "esfumilharás": "esfumilhar",
    "esfumilharão": "esfumilhar",
    "esfumilharíamos": "esfumilhar",
    "esfumilharíeis": "esfumilhar",
    "esfumilhas": "esfumilhar",
    "esfumilhasse": "esfumilhar",
    "esfumilhassem": "esfumilhar",
    "esfumilhasses": "esfumilhar",
    "esfumilhaste": "esfumilhar",
    "esfumilhastes": "esfumilhar",
    "esfumilhava": "esfumilhar",
    "esfumilhavam": "esfumilhar",
    "esfumilhavas": "esfumilhar",
    "esfumilhe": "esfumilhar",
    "esfumilhei": "esfumilhar",
    "esfumilheis": "esfumilhar",
    "esfumilhem": "esfumilhar",
    "esfumilhemo": "esfumilhar",
    "esfumilhemos": "esfumilhar",
    "esfumilhes": "esfumilhar",
    "esfumilho": "esfumilhar",
    "esfumilhou": "esfumilhar",
    "esfumilhá": "esfumilhar",
    "esfumilhámo": "esfumilhar",
    "esfumilhámos": "esfumilhar",
    "esfumilháramo": "esfumilhar",
    "esfumilháramos": "esfumilhar",
    "esfumilhárei": "esfumilhar",
    "esfumilháreis": "esfumilhar",
    "esfumilhásseis": "esfumilhar",
    "esfumilhássemos": "esfumilhar",
    "esfumilhávamo": "esfumilhar",
    "esfumilhávamos": "esfumilhar",
    "esfumilhávei": "esfumilhar",
    "esfumilháveis": "esfumilhar",
    "esfuminha": "esfuminhar",
    "esfuminhada": "esfuminhar",
    "esfuminhadas": "esfuminhar",
    "esfuminhado": "esfuminhar",
    "esfuminhados": "esfuminhar",
    "esfuminhai": "esfuminhar",
    "esfuminhais": "esfuminhar",
    "esfuminham": "esfuminhar",
    "esfuminhamo": "esfuminhar",
    "esfuminhamos": "esfuminhar",
    "esfuminhando": "esfuminhar",
    "esfuminhara": "esfuminhar",
    "esfuminharam": "esfuminhar",
    "esfuminharas": "esfuminhar",
    "esfuminharde": "esfuminhar",
    "esfuminhardes": "esfuminhar",
    "esfuminhare": "esfuminhar",
    "esfuminharei": "esfuminhar",
    "esfuminhareis": "esfuminhar",
    "esfuminharem": "esfuminhar",
    "esfuminharemos": "esfuminhar",
    "esfuminhares": "esfuminhar",
    "esfuminharia": "esfuminhar",
    "esfuminhariam": "esfuminhar",
    "esfuminharias": "esfuminhar",
    "esfuminharmo": "esfuminhar",
    "esfuminharmos": "esfuminhar",
    "esfuminhará": "esfuminhar",
    "esfuminharás": "esfuminhar",
    "esfuminharão": "esfuminhar",
    "esfuminharíamos": "esfuminhar",
    "esfuminharíeis": "esfuminhar",
    "esfuminhas": "esfuminhar",
    "esfuminhasse": "esfuminhar",
    "esfuminhassem": "esfuminhar",
    "esfuminhasses": "esfuminhar",
    "esfuminhaste": "esfuminhar",
    "esfuminhastes": "esfuminhar",
    "esfuminhava": "esfuminhar",
    "esfuminhavam": "esfuminhar",
    "esfuminhavas": "esfuminhar",
    "esfuminhe": "esfuminhar",
    "esfuminhei": "esfuminhar",
    "esfuminheis": "esfuminhar",
    "esfuminhem": "esfuminhar",
    "esfuminhemo": "esfuminhar",
    "esfuminhemos": "esfuminhar",
    "esfuminhes": "esfuminhar",
    "esfuminho": "esfuminhar",
    "esfuminhos": "esfuminho",
    "esfuminhou": "esfuminhar",
    "esfuminhá": "esfuminhar",
    "esfuminhámo": "esfuminhar",
    "esfuminhámos": "esfuminhar",
    "esfuminháramo": "esfuminhar",
    "esfuminháramos": "esfuminhar",
    "esfuminhárei": "esfuminhar",
    "esfuminháreis": "esfuminhar",
    "esfuminhásseis": "esfuminhar",
    "esfuminhássemos": "esfuminhar",
    "esfuminhávamo": "esfuminhar",
    "esfuminhávamos": "esfuminhar",
    "esfuminhávei": "esfuminhar",
    "esfuminháveis": "esfuminhar",
    "esfumo": "esfumar",
    "esfumou": "esfumar",
    "esfumá": "esfumar",
    "esfumámo": "esfumar",
    "esfumámos": "esfumar",
    "esfumáramo": "esfumar",
    "esfumáramos": "esfumar",
    "esfumárei": "esfumar",
    "esfumáreis": "esfumar",
    "esfumásseis": "esfumar",
    "esfumássemos": "esfumar",
    "esfumávamo": "esfumar",
    "esfumávamos": "esfumar",
    "esfumávei": "esfumar",
    "esfumáveis": "esfumar",
    "esfuraca": "esfuracar",
    "esfuracada": "esfuracar",
    "esfuracadas": "esfuracar",
    "esfuracado": "esfuracar",
    "esfuracados": "esfuracar",
    "esfuracai": "esfuracar",
    "esfuracais": "esfuracar",
    "esfuracam": "esfuracar",
    "esfuracamo": "esfuracar",
    "esfuracamos": "esfuracar",
    "esfuracando": "esfuracar",
    "esfuracara": "esfuracar",
    "esfuracaram": "esfuracar",
    "esfuracaras": "esfuracar",
    "esfuracarde": "esfuracar",
    "esfuracardes": "esfuracar",
    "esfuracare": "esfuracar",
    "esfuracarei": "esfuracar",
    "esfuracareis": "esfuracar",
    "esfuracarem": "esfuracar",
    "esfuracaremos": "esfuracar",
    "esfuracares": "esfuracar",
    "esfuracaria": "esfuracar",
    "esfuracariam": "esfuracar",
    "esfuracarias": "esfuracar",
    "esfuracarmo": "esfuracar",
    "esfuracarmos": "esfuracar",
    "esfuracará": "esfuracar",
    "esfuracarás": "esfuracar",
    "esfuracarão": "esfuracar",
    "esfuracaríamos": "esfuracar",
    "esfuracaríeis": "esfuracar",
    "esfuracas": "esfuracar",
    "esfuracasse": "esfuracar",
    "esfuracassem": "esfuracar",
    "esfuracasses": "esfuracar",
    "esfuracaste": "esfuracar",
    "esfuracastes": "esfuracar",
    "esfuracava": "esfuracar",
    "esfuracavam": "esfuracar",
    "esfuracavas": "esfuracar",
    "esfuraco": "esfuracar",
    "esfuracou": "esfuracar",
    "esfuracá": "esfuracar",
    "esfuracámo": "esfuracar",
    "esfuracámos": "esfuracar",
    "esfuracáramo": "esfuracar",
    "esfuracáramos": "esfuracar",
    "esfuracárei": "esfuracar",
    "esfuracáreis": "esfuracar",
    "esfuracásseis": "esfuracar",
    "esfuracássemos": "esfuracar",
    "esfuracávamo": "esfuracar",
    "esfuracávamos": "esfuracar",
    "esfuracávei": "esfuracar",
    "esfuracáveis": "esfuracar",
    "esfuranca": "esfurancar",
    "esfurancada": "esfurancar",
    "esfurancadas": "esfurancar",
    "esfurancado": "esfurancar",
    "esfurancados": "esfurancar",
    "esfurancai": "esfurancar",
    "esfurancais": "esfurancar",
    "esfurancam": "esfurancar",
    "esfurancamo": "esfurancar",
    "esfurancamos": "esfurancar",
    "esfurancando": "esfurancar",
    "esfurancara": "esfurancar",
    "esfurancaram": "esfurancar",
    "esfurancaras": "esfurancar",
    "esfurancarde": "esfurancar",
    "esfurancardes": "esfurancar",
    "esfurancare": "esfurancar",
    "esfurancarei": "esfurancar",
    "esfurancareis": "esfurancar",
    "esfurancarem": "esfurancar",
    "esfurancaremos": "esfurancar",
    "esfurancares": "esfurancar",
    "esfurancaria": "esfurancar",
    "esfurancariam": "esfurancar",
    "esfurancarias": "esfurancar",
    "esfurancarmo": "esfurancar",
    "esfurancarmos": "esfurancar",
    "esfurancará": "esfurancar",
    "esfurancarás": "esfurancar",
    "esfurancarão": "esfurancar",
    "esfurancaríamos": "esfurancar",
    "esfurancaríeis": "esfurancar",
    "esfurancas": "esfurancar",
    "esfurancasse": "esfurancar",
    "esfurancassem": "esfurancar",
    "esfurancasses": "esfurancar",
    "esfurancaste": "esfurancar",
    "esfurancastes": "esfurancar",
    "esfurancava": "esfurancar",
    "esfurancavam": "esfurancar",
    "esfurancavas": "esfurancar",
    "esfuranco": "esfurancar",
    "esfurancou": "esfurancar",
    "esfurancá": "esfurancar",
    "esfurancámo": "esfurancar",
    "esfurancámos": "esfurancar",
    "esfurancáramo": "esfurancar",
    "esfurancáramos": "esfurancar",
    "esfurancárei": "esfurancar",
    "esfurancáreis": "esfurancar",
    "esfurancásseis": "esfurancar",
    "esfurancássemos": "esfurancar",
    "esfurancávamo": "esfurancar",
    "esfurancávamos": "esfurancar",
    "esfurancávei": "esfurancar",
    "esfurancáveis": "esfurancar",
    "esfuranque": "esfurancar",
    "esfuranquei": "esfurancar",
    "esfuranqueis": "esfurancar",
    "esfuranquem": "esfurancar",
    "esfuranquemo": "esfurancar",
    "esfuranquemos": "esfurancar",
    "esfuranques": "esfurancar",
    "esfuraque": "esfuracar",
    "esfuraquei": "esfuracar",
    "esfuraqueis": "esfuracar",
    "esfuraquem": "esfuracar",
    "esfuraquemo": "esfuracar",
    "esfuraquemos": "esfuracar",
    "esfuraques": "esfuracar",
    "esfuzia": "esfuziar",
    "esfuziada": "esfuziar",
    "esfuziadas": "esfuziar",
    "esfuziado": "esfuziar",
    "esfuziados": "esfuziar",
    "esfuziai": "esfuziar",
    "esfuziais": "esfuziar",
    "esfuziam": "esfuziar",
    "esfuziamo": "esfuziar",
    "esfuziamos": "esfuziar",
    "esfuziando": "esfuziar",
    "esfuziantes": "esfuziante",
    "esfuziara": "esfuziar",
    "esfuziaram": "esfuziar",
    "esfuziaras": "esfuziar",
    "esfuziardes": "esfuziar",
    "esfuziarei": "esfuziar",
    "esfuziareis": "esfuziar",
    "esfuziarem": "esfuziar",
    "esfuziaremos": "esfuziar",
    "esfuziares": "esfuziar",
    "esfuziaria": "esfuziar",
    "esfuziariam": "esfuziar",
    "esfuziarias": "esfuziar",
    "esfuziarmo": "esfuziar",
    "esfuziarmos": "esfuziar",
    "esfuziará": "esfuziar",
    "esfuziarás": "esfuziar",
    "esfuziarão": "esfuziar",
    "esfuziaríamos": "esfuziar",
    "esfuziaríeis": "esfuziar",
    "esfuzias": "esfuziar",
    "esfuziasse": "esfuziar",
    "esfuziassem": "esfuziar",
    "esfuziasses": "esfuziar",
    "esfuziaste": "esfuziar",
    "esfuziastes": "esfuziar",
    "esfuziava": "esfuziar",
    "esfuziavam": "esfuziar",
    "esfuziavas": "esfuziar",
    "esfuzie": "esfuziar",
    "esfuziei": "esfuziar",
    "esfuzieis": "esfuziar",
    "esfuziem": "esfuziar",
    "esfuziemo": "esfuziar",
    "esfuziemos": "esfuziar",
    "esfuzies": "esfuziar",
    "esfuzila": "esfuzilar",
    "esfuzilada": "esfuzilar",
    "esfuziladas": "esfuzilar",
    "esfuzilado": "esfuzilar",
    "esfuzilados": "esfuzilar",
    "esfuzilai": "esfuzilar",
    "esfuzilais": "esfuzilar",
    "esfuzilam": "esfuzilar",
    "esfuzilamo": "esfuzilar",
    "esfuzilamos": "esfuzilar",
    "esfuzilando": "esfuzilar",
    "esfuzilara": "esfuzilar",
    "esfuzilaram": "esfuzilar",
    "esfuzilaras": "esfuzilar",
    "esfuzilardes": "esfuzilar",
    "esfuzilarei": "esfuzilar",
    "esfuzilareis": "esfuzilar",
    "esfuzilarem": "esfuzilar",
    "esfuzilaremos": "esfuzilar",
    "esfuzilares": "esfuzilar",
    "esfuzilaria": "esfuzilar",
    "esfuzilariam": "esfuzilar",
    "esfuzilarias": "esfuzilar",
    "esfuzilarmo": "esfuzilar",
    "esfuzilarmos": "esfuzilar",
    "esfuzilará": "esfuzilar",
    "esfuzilarás": "esfuzilar",
    "esfuzilarão": "esfuzilar",
    "esfuzilaríamos": "esfuzilar",
    "esfuzilaríeis": "esfuzilar",
    "esfuzilas": "esfuzilar",
    "esfuzilasse": "esfuzilar",
    "esfuzilassem": "esfuzilar",
    "esfuzilasses": "esfuzilar",
    "esfuzilaste": "esfuzilar",
    "esfuzilastes": "esfuzilar",
    "esfuzilava": "esfuzilar",
    "esfuzilavam": "esfuzilar",
    "esfuzilavas": "esfuzilar",
    "esfuzile": "esfuzilar",
    "esfuzilei": "esfuzilar",
    "esfuzileis": "esfuzilar",
    "esfuzilem": "esfuzilar",
    "esfuzilemo": "esfuzilar",
    "esfuzilemos": "esfuzilar",
    "esfuziles": "esfuzilar",
    "esfuzilo": "esfuzilar",
    "esfuzilou": "esfuzilar",
    "esfuzilámo": "esfuzilar",
    "esfuzilámos": "esfuzilar",
    "esfuziláramo": "esfuzilar",
    "esfuziláramos": "esfuzilar",
    "esfuziláreis": "esfuzilar",
    "esfuzilásseis": "esfuzilar",
    "esfuzilássemos": "esfuzilar",
    "esfuzilávamo": "esfuzilar",
    "esfuzilávamos": "esfuzilar",
    "esfuziláveis": "esfuzilar",
    "esfuzio": "esfuziar",
    "esfuziotes": "esfuziote",
    "esfuziou": "esfuziar",
    "esfuziámo": "esfuziar",
    "esfuziámos": "esfuziar",
    "esfuziáramo": "esfuziar",
    "esfuziáramos": "esfuziar",
    "esfuziáreis": "esfuziar",
    "esfuziásseis": "esfuziar",
    "esfuziássemos": "esfuziar",
    "esfuziávamo": "esfuziar",
    "esfuziávamos": "esfuziar",
    "esfuziáveis": "esfuziar",
    "esfácelos": "esfácelo",
    "esférica": "esférico",
    "esféricas": "esférico",
    "esféricos": "esférico",
    "esférulas": "esférula",
    "esfíncteres": "esfíncter",
    "esfíngica": "esfíngico",
    "esfíngicas": "esfíngico",
    "esfíngicos": "esfíngico",
    "esfíngidas": "esfíngida",
    "esgace": "esgaçar",
    "esgacei": "esgaçar",
    "esgaceis": "esgaçar",
    "esgacem": "esgaçar",
    "esgacemo": "esgaçar",
    "esgacemos": "esgaçar",
    "esgaces": "esgaçar",
    "esgadanha": "esgadanhar",
    "esgadanhada": "esgadanhar",
    "esgadanhadas": "esgadanhar",
    "esgadanhado": "esgadanhar",
    "esgadanhados": "esgadanhar",
    "esgadanhai": "esgadanhar",
    "esgadanhais": "esgadanhar",
    "esgadanham": "esgadanhar",
    "esgadanhamo": "esgadanhar",
    "esgadanhamos": "esgadanhar",
    "esgadanhando": "esgadanhar",
    "esgadanhara": "esgadanhar",
    "esgadanharam": "esgadanhar",
    "esgadanharas": "esgadanhar",
    "esgadanharde": "esgadanhar",
    "esgadanhardes": "esgadanhar",
    "esgadanhare": "esgadanhar",
    "esgadanharei": "esgadanhar",
    "esgadanhareis": "esgadanhar",
    "esgadanharem": "esgadanhar",
    "esgadanharemos": "esgadanhar",
    "esgadanhares": "esgadanhar",
    "esgadanharia": "esgadanhar",
    "esgadanhariam": "esgadanhar",
    "esgadanharias": "esgadanhar",
    "esgadanharmo": "esgadanhar",
    "esgadanharmos": "esgadanhar",
    "esgadanhará": "esgadanhar",
    "esgadanharás": "esgadanhar",
    "esgadanharão": "esgadanhar",
    "esgadanharíamos": "esgadanhar",
    "esgadanharíeis": "esgadanhar",
    "esgadanhas": "esgadanhar",
    "esgadanhasse": "esgadanhar",
    "esgadanhassem": "esgadanhar",
    "esgadanhasses": "esgadanhar",
    "esgadanhaste": "esgadanhar",
    "esgadanhastes": "esgadanhar",
    "esgadanhava": "esgadanhar",
    "esgadanhavam": "esgadanhar",
    "esgadanhavas": "esgadanhar",
    "esgadanhe": "esgadanhar",
    "esgadanhei": "esgadanhar",
    "esgadanheis": "esgadanhar",
    "esgadanhem": "esgadanhar",
    "esgadanhemo": "esgadanhar",
    "esgadanhemos": "esgadanhar",
    "esgadanhes": "esgadanhar",
    "esgadanho": "esgadanhar",
    "esgadanhou": "esgadanhar",
    "esgadanhá": "esgadanhar",
    "esgadanhámo": "esgadanhar",
    "esgadanhámos": "esgadanhar",
    "esgadanháramo": "esgadanhar",
    "esgadanháramos": "esgadanhar",
    "esgadanhárei": "esgadanhar",
    "esgadanháreis": "esgadanhar",
    "esgadanhásseis": "esgadanhar",
    "esgadanhássemos": "esgadanhar",
    "esgadanhávamo": "esgadanhar",
    "esgadanhávamos": "esgadanhar",
    "esgadanhávei": "esgadanhar",
    "esgadanháveis": "esgadanhar",
    "esgadelha": "esgadelhar",
    "esgadelhada": "esgadelhar",
    "esgadelhadas": "esgadelhar",
    "esgadelhado": "esgadelhar",
    "esgadelhados": "esgadelhar",
    "esgadelhai": "esgadelhar",
    "esgadelhais": "esgadelhar",
    "esgadelham": "esgadelhar",
    "esgadelhamo": "esgadelhar",
    "esgadelhamos": "esgadelhar",
    "esgadelhando": "esgadelhar",
    "esgadelhara": "esgadelhar",
    "esgadelharam": "esgadelhar",
    "esgadelharas": "esgadelhar",
    "esgadelharde": "esgadelhar",
    "esgadelhardes": "esgadelhar",
    "esgadelhare": "esgadelhar",
    "esgadelharei": "esgadelhar",
    "esgadelhareis": "esgadelhar",
    "esgadelharem": "esgadelhar",
    "esgadelharemos": "esgadelhar",
    "esgadelhares": "esgadelhar",
    "esgadelharia": "esgadelhar",
    "esgadelhariam": "esgadelhar",
    "esgadelharias": "esgadelhar",
    "esgadelharmo": "esgadelhar",
    "esgadelharmos": "esgadelhar",
    "esgadelhará": "esgadelhar",
    "esgadelharás": "esgadelhar",
    "esgadelharão": "esgadelhar",
    "esgadelharíamos": "esgadelhar",
    "esgadelharíeis": "esgadelhar",
    "esgadelhas": "esgadelhar",
    "esgadelhasse": "esgadelhar",
    "esgadelhassem": "esgadelhar",
    "esgadelhasses": "esgadelhar",
    "esgadelhaste": "esgadelhar",
    "esgadelhastes": "esgadelhar",
    "esgadelhava": "esgadelhar",
    "esgadelhavam": "esgadelhar",
    "esgadelhavas": "esgadelhar",
    "esgadelhe": "esgadelhar",
    "esgadelhei": "esgadelhar",
    "esgadelheis": "esgadelhar",
    "esgadelhem": "esgadelhar",
    "esgadelhemo": "esgadelhar",
    "esgadelhemos": "esgadelhar",
    "esgadelhes": "esgadelhar",
    "esgadelho": "esgadelhar",
    "esgadelhou": "esgadelhar",
    "esgadelhá": "esgadelhar",
    "esgadelhámo": "esgadelhar",
    "esgadelhámos": "esgadelhar",
    "esgadelháramo": "esgadelhar",
    "esgadelháramos": "esgadelhar",
    "esgadelhárei": "esgadelhar",
    "esgadelháreis": "esgadelhar",
    "esgadelhásseis": "esgadelhar",
    "esgadelhássemos": "esgadelhar",
    "esgadelhávamo": "esgadelhar",
    "esgadelhávamos": "esgadelhar",
    "esgadelhávei": "esgadelhar",
    "esgadelháveis": "esgadelhar",
    "esgaiva": "esgaivar",
    "esgaivada": "esgaivar",
    "esgaivadas": "esgaivar",
    "esgaivado": "esgaivar",
    "esgaivados": "esgaivar",
    "esgaivai": "esgaivar",
    "esgaivais": "esgaivar",
    "esgaivam": "esgaivar",
    "esgaivamo": "esgaivar",
    "esgaivamos": "esgaivar",
    "esgaivando": "esgaivar",
    "esgaivara": "esgaivar",
    "esgaivaram": "esgaivar",
    "esgaivaras": "esgaivar",
    "esgaivarde": "esgaivar",
    "esgaivardes": "esgaivar",
    "esgaivare": "esgaivar",
    "esgaivarei": "esgaivar",
    "esgaivareis": "esgaivar",
    "esgaivarem": "esgaivar",
    "esgaivaremos": "esgaivar",
    "esgaivares": "esgaivar",
    "esgaivaria": "esgaivar",
    "esgaivariam": "esgaivar",
    "esgaivarias": "esgaivar",
    "esgaivarmo": "esgaivar",
    "esgaivarmos": "esgaivar",
    "esgaivará": "esgaivar",
    "esgaivarás": "esgaivar",
    "esgaivarão": "esgaivar",
    "esgaivaríamos": "esgaivar",
    "esgaivaríeis": "esgaivar",
    "esgaivas": "esgaivar",
    "esgaivasse": "esgaivar",
    "esgaivassem": "esgaivar",
    "esgaivasses": "esgaivar",
    "esgaivaste": "esgaivar",
    "esgaivastes": "esgaivar",
    "esgaivava": "esgaivar",
    "esgaivavam": "esgaivar",
    "esgaivavas": "esgaivar",
    "esgaive": "esgaivar",
    "esgaivei": "esgaivar",
    "esgaiveis": "esgaivar",
    "esgaivem": "esgaivar",
    "esgaivemo": "esgaivar",
    "esgaivemos": "esgaivar",
    "esgaives": "esgaivar",
    "esgaivo": "esgaivar",
    "esgaivotada": "esgaivotado",
    "esgaivotadas": "esgaivotado",
    "esgaivotados": "esgaivotado",
    "esgaivou": "esgaivar",
    "esgaivá": "esgaivar",
    "esgaivámo": "esgaivar",
    "esgaivámos": "esgaivar",
    "esgaiváramo": "esgaivar",
    "esgaiváramos": "esgaivar",
    "esgaivárei": "esgaivar",
    "esgaiváreis": "esgaivar",
    "esgaivásseis": "esgaivar",
    "esgaivássemos": "esgaivar",
    "esgaivávamo": "esgaivar",
    "esgaivávamos": "esgaivar",
    "esgaivávei": "esgaivar",
    "esgaiváveis": "esgaivar",
    "esgalga": "esgalgar",
    "esgalgada": "esgalgar",
    "esgalgadas": "esgalgar",
    "esgalgado": "esgalgar",
    "esgalgados": "esgalgar",
    "esgalgadíssima": "esgalgado",
    "esgalgadíssimas": "esgalgado",
    "esgalgadíssimo": "esgalgado",
    "esgalgadíssimos": "esgalgado",
    "esgalgai": "esgalgar",
    "esgalgais": "esgalgar",
    "esgalgam": "esgalgar",
    "esgalgamo": "esgalgar",
    "esgalgamos": "esgalgar",
    "esgalgando": "esgalgar",
    "esgalgara": "esgalgar",
    "esgalgaram": "esgalgar",
    "esgalgaras": "esgalgar",
    "esgalgarde": "esgalgar",
    "esgalgardes": "esgalgar",
    "esgalgare": "esgalgar",
    "esgalgarei": "esgalgar",
    "esgalgareis": "esgalgar",
    "esgalgarem": "esgalgar",
    "esgalgaremos": "esgalgar",
    "esgalgares": "esgalgar",
    "esgalgaria": "esgalgar",
    "esgalgariam": "esgalgar",
    "esgalgarias": "esgalgar",
    "esgalgarmo": "esgalgar",
    "esgalgarmos": "esgalgar",
    "esgalgará": "esgalgar",
    "esgalgarás": "esgalgar",
    "esgalgarão": "esgalgar",
    "esgalgaríamos": "esgalgar",
    "esgalgaríeis": "esgalgar",
    "esgalgas": "esgalgar",
    "esgalgasse": "esgalgar",
    "esgalgassem": "esgalgar",
    "esgalgasses": "esgalgar",
    "esgalgaste": "esgalgar",
    "esgalgastes": "esgalgar",
    "esgalgava": "esgalgar",
    "esgalgavam": "esgalgar",
    "esgalgavas": "esgalgar",
    "esgalgo": "esgalgar",
    "esgalgou": "esgalgar",
    "esgalgue": "esgalgar",
    "esgalguei": "esgalgar",
    "esgalgueis": "esgalgar",
    "esgalguem": "esgalgar",
    "esgalguemo": "esgalgar",
    "esgalguemos": "esgalgar",
    "esgalgues": "esgalgar",
    "esgalgá": "esgalgar",
    "esgalgámo": "esgalgar",
    "esgalgámos": "esgalgar",
    "esgalgáramo": "esgalgar",
    "esgalgáramos": "esgalgar",
    "esgalgárei": "esgalgar",
    "esgalgáreis": "esgalgar",
    "esgalgásseis": "esgalgar",
    "esgalgássemos": "esgalgar",
    "esgalgávamo": "esgalgar",
    "esgalgávamos": "esgalgar",
    "esgalgávei": "esgalgar",
    "esgalgáveis": "esgalgar",
    "esgalha": "esgalhar",
    "esgalhada": "esgalhar",
    "esgalhadas": "esgalhar",
    "esgalhado": "esgalhar",
    "esgalhados": "esgalhar",
    "esgalhai": "esgalhar",
    "esgalhais": "esgalhar",
    "esgalham": "esgalhar",
    "esgalhamo": "esgalhar",
    "esgalhamos": "esgalhar",
    "esgalhando": "esgalhar",
    "esgalhara": "esgalhar",
    "esgalharam": "esgalhar",
    "esgalharas": "esgalhar",
    "esgalharde": "esgalhar",
    "esgalhardes": "esgalhar",
    "esgalhare": "esgalhar",
    "esgalharei": "esgalhar",
    "esgalhareis": "esgalhar",
    "esgalharem": "esgalhar",
    "esgalharemos": "esgalhar",
    "esgalhares": "esgalhar",
    "esgalharia": "esgalhar",
    "esgalhariam": "esgalhar",
    "esgalharias": "esgalhar",
    "esgalharmo": "esgalhar",
    "esgalharmos": "esgalhar",
    "esgalhará": "esgalhar",
    "esgalharás": "esgalhar",
    "esgalharão": "esgalhar",
    "esgalharíamos": "esgalhar",
    "esgalharíeis": "esgalhar",
    "esgalhas": "esgalhar",
    "esgalhasse": "esgalhar",
    "esgalhassem": "esgalhar",
    "esgalhasses": "esgalhar",
    "esgalhaste": "esgalhar",
    "esgalhastes": "esgalhar",
    "esgalhava": "esgalhar",
    "esgalhavam": "esgalhar",
    "esgalhavas": "esgalhar",
    "esgalhe": "esgalhar",
    "esgalhei": "esgalhar",
    "esgalheira": "esgalheiro",
    "esgalheiras": "esgalheiro",
    "esgalheiros": "esgalheiro",
    "esgalheis": "esgalhar",
    "esgalhem": "esgalhar",
    "esgalhemo": "esgalhar",
    "esgalhemos": "esgalhar",
    "esgalhes": "esgalhar",
    "esgalho": "esgalhar",
    "esgalhofada": "esgalhofado",
    "esgalhofadas": "esgalhofado",
    "esgalhofados": "esgalhofado",
    "esgalhos": "esgalho",
    "esgalhou": "esgalhar",
    "esgalhá": "esgalhar",
    "esgalhámo": "esgalhar",
    "esgalhámos": "esgalhar",
    "esgalháramo": "esgalhar",
    "esgalháramos": "esgalhar",
    "esgalhárei": "esgalhar",
    "esgalháreis": "esgalhar",
    "esgalhásseis": "esgalhar",
    "esgalhássemos": "esgalhar",
    "esgalhávamo": "esgalhar",
    "esgalhávamos": "esgalhar",
    "esgalhávei": "esgalhar",
    "esgalháveis": "esgalhar",
    "esgana": "esganar",
    "esganada": "esganar",
    "esganadas": "esganar",
    "esganado": "esganar",
    "esganadora": "esganador",
    "esganadoras": "esganador",
    "esganadores": "esganador",
    "esganados": "esganar",
    "esganaduras": "esganadura",
    "esganai": "esganar",
    "esganais": "esganar",
    "esganam": "esganar",
    "esganamo": "esganar",
    "esganamos": "esganar",
    "esganando": "esganar",
    "esganara": "esganar",
    "esganaram": "esganar",
    "esganaras": "esganar",
    "esganarde": "esganar",
    "esganardes": "esganar",
    "esganare": "esganar",
    "esganarei": "esganar",
    "esganareis": "esganar",
    "esganarelos": "esganarelo",
    "esganarem": "esganar",
    "esganaremos": "esganar",
    "esganares": "esganar",
    "esganaria": "esganar",
    "esganariam": "esganar",
    "esganarias": "esganar",
    "esganarmo": "esganar",
    "esganarmos": "esganar",
    "esganará": "esganar",
    "esganarás": "esganar",
    "esganarão": "esganar",
    "esganaríamos": "esganar",
    "esganaríeis": "esganar",
    "esganas": "esganar",
    "esganasse": "esganar",
    "esganassem": "esganar",
    "esganasses": "esganar",
    "esganaste": "esganar",
    "esganastes": "esganar",
    "esganava": "esganar",
    "esganavam": "esganar",
    "esganavas": "esganar",
    "esganações": "esganação",
    "esgane": "esganar",
    "esganei": "esganar",
    "esganeis": "esganar",
    "esganem": "esganar",
    "esganemo": "esganar",
    "esganemos": "esganar",
    "esganes": "esganar",
    "esganice": "esganiçar",
    "esganicei": "esganiçar",
    "esganiceis": "esganiçar",
    "esganicem": "esganiçar",
    "esganicemo": "esganiçar",
    "esganicemos": "esganiçar",
    "esganices": "esganiçar",
    "esganifada": "esganifado",
    "esganifadas": "esganifado",
    "esganifados": "esganifado",
    "esganinhos": "esganinho",
    "esganiça": "esganiçar",
    "esganiçada": "esganiçar",
    "esganiçadas": "esganiçar",
    "esganiçado": "esganiçar",
    "esganiçados": "esganiçar",
    "esganiçai": "esganiçar",
    "esganiçais": "esganiçar",
    "esganiçam": "esganiçar",
    "esganiçamo": "esganiçar",
    "esganiçamos": "esganiçar",
    "esganiçando": "esganiçar",
    "esganiçara": "esganiçar",
    "esganiçaram": "esganiçar",
    "esganiçaras": "esganiçar",
    "esganiçarde": "esganiçar",
    "esganiçardes": "esganiçar",
    "esganiçare": "esganiçar",
    "esganiçarei": "esganiçar",
    "esganiçareis": "esganiçar",
    "esganiçarem": "esganiçar",
    "esganiçaremos": "esganiçar",
    "esganiçares": "esganiçar",
    "esganiçaria": "esganiçar",
    "esganiçariam": "esganiçar",
    "esganiçarias": "esganiçar",
    "esganiçarmo": "esganiçar",
    "esganiçarmos": "esganiçar",
    "esganiçará": "esganiçar",
    "esganiçarás": "esganiçar",
    "esganiçarão": "esganiçar",
    "esganiçaríamos": "esganiçar",
    "esganiçaríeis": "esganiçar",
    "esganiças": "esganiçar",
    "esganiçasse": "esganiçar",
    "esganiçassem": "esganiçar",
    "esganiçasses": "esganiçar",
    "esganiçaste": "esganiçar",
    "esganiçastes": "esganiçar",
    "esganiçava": "esganiçar",
    "esganiçavam": "esganiçar",
    "esganiçavas": "esganiçar",
    "esganiço": "esganiçar",
    "esganiçou": "esganiçar",
    "esganiçá": "esganiçar",
    "esganiçámo": "esganiçar",
    "esganiçámos": "esganiçar",
    "esganiçáramo": "esganiçar",
    "esganiçáramos": "esganiçar",
    "esganiçárei": "esganiçar",
    "esganiçáreis": "esganiçar",
    "esganiçásseis": "esganiçar",
    "esganiçássemos": "esganiçar",
    "esganiçávamo": "esganiçar",
    "esganiçávamos": "esganiçar",
    "esganiçávei": "esganiçar",
    "esganiçáveis": "esganiçar",
    "esgano": "esganar",
    "esganou": "esganar",
    "esganá": "esganar",
    "esganámo": "esganar",
    "esganámos": "esganar",
    "esganáramo": "esganar",
    "esganáramos": "esganar",
    "esganárei": "esganar",
    "esganáreis": "esganar",
    "esganásseis": "esganar",
    "esganássemos": "esganar",
    "esganávamo": "esganar",
    "esganávamos": "esganar",
    "esganávei": "esganar",
    "esganáveis": "esganar",
    "esgarabulha": "esgarabulhar",
    "esgarabulhada": "esgarabulhar",
    "esgarabulhadas": "esgarabulhar",
    "esgarabulhado": "esgarabulhar",
    "esgarabulhados": "esgarabulhar",
    "esgarabulhai": "esgarabulhar",
    "esgarabulhais": "esgarabulhar",
    "esgarabulham": "esgarabulhar",
    "esgarabulhamo": "esgarabulhar",
    "esgarabulhamos": "esgarabulhar",
    "esgarabulhando": "esgarabulhar",
    "esgarabulhara": "esgarabulhar",
    "esgarabulharam": "esgarabulhar",
    "esgarabulharas": "esgarabulhar",
    "esgarabulhardes": "esgarabulhar",
    "esgarabulharei": "esgarabulhar",
    "esgarabulhareis": "esgarabulhar",
    "esgarabulharem": "esgarabulhar",
    "esgarabulharemos": "esgarabulhar",
    "esgarabulhares": "esgarabulhar",
    "esgarabulharia": "esgarabulhar",
    "esgarabulhariam": "esgarabulhar",
    "esgarabulharias": "esgarabulhar",
    "esgarabulharmo": "esgarabulhar",
    "esgarabulharmos": "esgarabulhar",
    "esgarabulhará": "esgarabulhar",
    "esgarabulharás": "esgarabulhar",
    "esgarabulharão": "esgarabulhar",
    "esgarabulharíamos": "esgarabulhar",
    "esgarabulharíeis": "esgarabulhar",
    "esgarabulhas": "esgarabulhar",
    "esgarabulhasse": "esgarabulhar",
    "esgarabulhassem": "esgarabulhar",
    "esgarabulhasses": "esgarabulhar",
    "esgarabulhaste": "esgarabulhar",
    "esgarabulhastes": "esgarabulhar",
    "esgarabulhava": "esgarabulhar",
    "esgarabulhavam": "esgarabulhar",
    "esgarabulhavas": "esgarabulhar",
    "esgarabulhe": "esgarabulhar",
    "esgarabulhei": "esgarabulhar",
    "esgarabulheis": "esgarabulhar",
    "esgarabulhem": "esgarabulhar",
    "esgarabulhemo": "esgarabulhar",
    "esgarabulhemos": "esgarabulhar",
    "esgarabulhes": "esgarabulhar",
    "esgarabulho": "esgarabulhar",
    "esgarabulhona": "esgarabulhão",
    "esgarabulhonas": "esgarabulhão",
    "esgarabulhou": "esgarabulhar",
    "esgarabulhámo": "esgarabulhar",
    "esgarabulhámos": "esgarabulhar",
    "esgarabulháramo": "esgarabulhar",
    "esgarabulháramos": "esgarabulhar",
    "esgarabulháreis": "esgarabulhar",
    "esgarabulhásseis": "esgarabulhar",
    "esgarabulhássemos": "esgarabulhar",
    "esgarabulhávamo": "esgarabulhar",
    "esgarabulhávamos": "esgarabulhar",
    "esgarabulháveis": "esgarabulhar",
    "esgarabulhões": "esgarabulhão",
    "esgarafuncha": "esgarafunchar",
    "esgarafunchada": "esgarafunchar",
    "esgarafunchadas": "esgarafunchar",
    "esgarafunchado": "esgarafunchar",
    "esgarafunchados": "esgarafunchar",
    "esgarafunchai": "esgarafunchar",
    "esgarafunchais": "esgarafunchar",
    "esgarafuncham": "esgarafunchar",
    "esgarafunchamo": "esgarafunchar",
    "esgarafunchamos": "esgarafunchar",
    "esgarafunchando": "esgarafunchar",
    "esgarafunchara": "esgarafunchar",
    "esgarafuncharam": "esgarafunchar",
    "esgarafuncharas": "esgarafunchar",
    "esgarafuncharde": "esgarafunchar",
    "esgarafunchardes": "esgarafunchar",
    "esgarafunchare": "esgarafunchar",
    "esgarafuncharei": "esgarafunchar",
    "esgarafunchareis": "esgarafunchar",
    "esgarafuncharem": "esgarafunchar",
    "esgarafuncharemos": "esgarafunchar",
    "esgarafunchares": "esgarafunchar",
    "esgarafuncharia": "esgarafunchar",
    "esgarafunchariam": "esgarafunchar",
    "esgarafuncharias": "esgarafunchar",
    "esgarafuncharmo": "esgarafunchar",
    "esgarafuncharmos": "esgarafunchar",
    "esgarafunchará": "esgarafunchar",
    "esgarafuncharás": "esgarafunchar",
    "esgarafuncharão": "esgarafunchar",
    "esgarafuncharíamos": "esgarafunchar",
    "esgarafuncharíeis": "esgarafunchar",
    "esgarafunchas": "esgarafunchar",
    "esgarafunchasse": "esgarafunchar",
    "esgarafunchassem": "esgarafunchar",
    "esgarafunchasses": "esgarafunchar",
    "esgarafunchaste": "esgarafunchar",
    "esgarafunchastes": "esgarafunchar",
    "esgarafunchava": "esgarafunchar",
    "esgarafunchavam": "esgarafunchar",
    "esgarafunchavas": "esgarafunchar",
    "esgarafunche": "esgarafunchar",
    "esgarafunchei": "esgarafunchar",
    "esgarafuncheis": "esgarafunchar",
    "esgarafunchem": "esgarafunchar",
    "esgarafunchemo": "esgarafunchar",
    "esgarafunchemos": "esgarafunchar",
    "esgarafunches": "esgarafunchar",
    "esgarafuncho": "esgarafunchar",
    "esgarafunchou": "esgarafunchar",
    "esgarafunchá": "esgarafunchar",
    "esgarafunchámo": "esgarafunchar",
    "esgarafunchámos": "esgarafunchar",
    "esgarafuncháramo": "esgarafunchar",
    "esgarafuncháramos": "esgarafunchar",
    "esgarafunchárei": "esgarafunchar",
    "esgarafuncháreis": "esgarafunchar",
    "esgarafunchásseis": "esgarafunchar",
    "esgarafunchássemos": "esgarafunchar",
    "esgarafunchávamo": "esgarafunchar",
    "esgarafunchávamos": "esgarafunchar",
    "esgarafunchávei": "esgarafunchar",
    "esgarafuncháveis": "esgarafunchar",
    "esgaratuja": "esgaratujar",
    "esgaratujada": "esgaratujar",
    "esgaratujadas": "esgaratujar",
    "esgaratujado": "esgaratujar",
    "esgaratujados": "esgaratujar",
    "esgaratujai": "esgaratujar",
    "esgaratujais": "esgaratujar",
    "esgaratujam": "esgaratujar",
    "esgaratujamo": "esgaratujar",
    "esgaratujamos": "esgaratujar",
    "esgaratujando": "esgaratujar",
    "esgaratujara": "esgaratujar",
    "esgaratujaram": "esgaratujar",
    "esgaratujaras": "esgaratujar",
    "esgaratujarde": "esgaratujar",
    "esgaratujardes": "esgaratujar",
    "esgaratujare": "esgaratujar",
    "esgaratujarei": "esgaratujar",
    "esgaratujareis": "esgaratujar",
    "esgaratujarem": "esgaratujar",
    "esgaratujaremos": "esgaratujar",
    "esgaratujares": "esgaratujar",
    "esgaratujaria": "esgaratujar",
    "esgaratujariam": "esgaratujar",
    "esgaratujarias": "esgaratujar",
    "esgaratujarmo": "esgaratujar",
    "esgaratujarmos": "esgaratujar",
    "esgaratujará": "esgaratujar",
    "esgaratujarás": "esgaratujar",
    "esgaratujarão": "esgaratujar",
    "esgaratujaríamos": "esgaratujar",
    "esgaratujaríeis": "esgaratujar",
    "esgaratujas": "esgaratujar",
    "esgaratujasse": "esgaratujar",
    "esgaratujassem": "esgaratujar",
    "esgaratujasses": "esgaratujar",
    "esgaratujaste": "esgaratujar",
    "esgaratujastes": "esgaratujar",
    "esgaratujava": "esgaratujar",
    "esgaratujavam": "esgaratujar",
    "esgaratujavas": "esgaratujar",
    "esgaratuje": "esgaratujar",
    "esgaratujei": "esgaratujar",
    "esgaratujeis": "esgaratujar",
    "esgaratujem": "esgaratujar",
    "esgaratujemo": "esgaratujar",
    "esgaratujemos": "esgaratujar",
    "esgaratujes": "esgaratujar",
    "esgaratujo": "esgaratujar",
    "esgaratujou": "esgaratujar",
    "esgaratujá": "esgaratujar",
    "esgaratujámo": "esgaratujar",
    "esgaratujámos": "esgaratujar",
    "esgaratujáramo": "esgaratujar",
    "esgaratujáramos": "esgaratujar",
    "esgaratujárei": "esgaratujar",
    "esgaratujáreis": "esgaratujar",
    "esgaratujásseis": "esgaratujar",
    "esgaratujássemos": "esgaratujar",
    "esgaratujávamo": "esgaratujar",
    "esgaratujávamos": "esgaratujar",
    "esgaratujávei": "esgaratujar",
    "esgaratujáveis": "esgaratujar",
    "esgaravana": "esgaravanar",
    "esgaravanada": "esgaravanar",
    "esgaravanadas": "esgaravanar",
    "esgaravanado": "esgaravanar",
    "esgaravanados": "esgaravanar",
    "esgaravanai": "esgaravanar",
    "esgaravanais": "esgaravanar",
    "esgaravanam": "esgaravanar",
    "esgaravanamo": "esgaravanar",
    "esgaravanamos": "esgaravanar",
    "esgaravanando": "esgaravanar",
    "esgaravanara": "esgaravanar",
    "esgaravanaram": "esgaravanar",
    "esgaravanaras": "esgaravanar",
    "esgaravanarde": "esgaravanar",
    "esgaravanardes": "esgaravanar",
    "esgaravanare": "esgaravanar",
    "esgaravanarei": "esgaravanar",
    "esgaravanareis": "esgaravanar",
    "esgaravanarem": "esgaravanar",
    "esgaravanaremos": "esgaravanar",
    "esgaravanares": "esgaravanar",
    "esgaravanaria": "esgaravanar",
    "esgaravanariam": "esgaravanar",
    "esgaravanarias": "esgaravanar",
    "esgaravanarmo": "esgaravanar",
    "esgaravanarmos": "esgaravanar",
    "esgaravanará": "esgaravanar",
    "esgaravanarás": "esgaravanar",
    "esgaravanarão": "esgaravanar",
    "esgaravanaríamos": "esgaravanar",
    "esgaravanaríeis": "esgaravanar",
    "esgaravanas": "esgaravanar",
    "esgaravanasse": "esgaravanar",
    "esgaravanassem": "esgaravanar",
    "esgaravanasses": "esgaravanar",
    "esgaravanaste": "esgaravanar",
    "esgaravanastes": "esgaravanar",
    "esgaravanava": "esgaravanar",
    "esgaravanavam": "esgaravanar",
    "esgaravanavas": "esgaravanar",
    "esgaravane": "esgaravanar",
    "esgaravanei": "esgaravanar",
    "esgaravaneis": "esgaravanar",
    "esgaravanem": "esgaravanar",
    "esgaravanemo": "esgaravanar",
    "esgaravanemos": "esgaravanar",
    "esgaravanes": "esgaravanar",
    "esgaravano": "esgaravanar",
    "esgaravanou": "esgaravanar",
    "esgaravaná": "esgaravanar",
    "esgaravanámo": "esgaravanar",
    "esgaravanámos": "esgaravanar",
    "esgaravanáramo": "esgaravanar",
    "esgaravanáramos": "esgaravanar",
    "esgaravanárei": "esgaravanar",
    "esgaravanáreis": "esgaravanar",
    "esgaravanásseis": "esgaravanar",
    "esgaravanássemos": "esgaravanar",
    "esgaravanávamo": "esgaravanar",
    "esgaravanávamos": "esgaravanar",
    "esgaravanávei": "esgaravanar",
    "esgaravanáveis": "esgaravanar",
    "esgaravata": "esgaravatar",
    "esgaravatada": "esgaravatar",
    "esgaravatadas": "esgaravatar",
    "esgaravatado": "esgaravatar",
    "esgaravatadora": "esgaravatador",
    "esgaravatadoras": "esgaravatador",
    "esgaravatadores": "esgaravatador",
    "esgaravatados": "esgaravatar",
    "esgaravatai": "esgaravatar",
    "esgaravatais": "esgaravatar",
    "esgaravatam": "esgaravatar",
    "esgaravatamentos": "esgaravatamento",
    "esgaravatamo": "esgaravatar",
    "esgaravatamos": "esgaravatar",
    "esgaravatando": "esgaravatar",
    "esgaravatara": "esgaravatar",
    "esgaravataram": "esgaravatar",
    "esgaravataras": "esgaravatar",
    "esgaravatarde": "esgaravatar",
    "esgaravatardes": "esgaravatar",
    "esgaravatare": "esgaravatar",
    "esgaravatarei": "esgaravatar",
    "esgaravatareis": "esgaravatar",
    "esgaravatarem": "esgaravatar",
    "esgaravataremos": "esgaravatar",
    "esgaravatares": "esgaravatar",
    "esgaravataria": "esgaravatar",
    "esgaravatariam": "esgaravatar",
    "esgaravatarias": "esgaravatar",
    "esgaravatarmo": "esgaravatar",
    "esgaravatarmos": "esgaravatar",
    "esgaravatará": "esgaravatar",
    "esgaravatarás": "esgaravatar",
    "esgaravatarão": "esgaravatar",
    "esgaravataríamos": "esgaravatar",
    "esgaravataríeis": "esgaravatar",
    "esgaravatas": "esgaravatar",
    "esgaravatasse": "esgaravatar",
    "esgaravatassem": "esgaravatar",
    "esgaravatasses": "esgaravatar",
    "esgaravataste": "esgaravatar",
    "esgaravatastes": "esgaravatar",
    "esgaravatava": "esgaravatar",
    "esgaravatavam": "esgaravatar",
    "esgaravatavas": "esgaravatar",
    "esgaravate": "esgaravatar",
    "esgaravatei": "esgaravatar",
    "esgaravateis": "esgaravatar",
    "esgaravatem": "esgaravatar",
    "esgaravatemo": "esgaravatar",
    "esgaravatemos": "esgaravatar",
    "esgaravates": "esgaravatar",
    "esgaravatis": "esgaravatil",
    "esgaravato": "esgaravatar",
    "esgaravatou": "esgaravatar",
    "esgaravatá": "esgaravatar",
    "esgaravatámo": "esgaravatar",
    "esgaravatámos": "esgaravatar",
    "esgaravatáramo": "esgaravatar",
    "esgaravatáramos": "esgaravatar",
    "esgaravatárei": "esgaravatar",
    "esgaravatáreis": "esgaravatar",
    "esgaravatásseis": "esgaravatar",
    "esgaravatássemos": "esgaravatar",
    "esgaravatávamo": "esgaravatar",
    "esgaravatávamos": "esgaravatar",
    "esgaravatávei": "esgaravatar",
    "esgaravatáveis": "esgaravatar",
    "esgarce": "esgarçar",
    "esgarcei": "esgarçar",
    "esgarceis": "esgarçar",
    "esgarcem": "esgarçar",
    "esgarcemo": "esgarçar",
    "esgarcemos": "esgarçar",
    "esgarces": "esgarçar",
    "esgardunha": "esgardunhar",
    "esgardunhada": "esgardunhar",
    "esgardunhadas": "esgardunhar",
    "esgardunhado": "esgardunhar",
    "esgardunhados": "esgardunhar",
    "esgardunhai": "esgardunhar",
    "esgardunhais": "esgardunhar",
    "esgardunham": "esgardunhar",
    "esgardunhamo": "esgardunhar",
    "esgardunhamos": "esgardunhar",
    "esgardunhando": "esgardunhar",
    "esgardunhara": "esgardunhar",
    "esgardunharam": "esgardunhar",
    "esgardunharas": "esgardunhar",
    "esgardunharde": "esgardunhar",
    "esgardunhardes": "esgardunhar",
    "esgardunhare": "esgardunhar",
    "esgardunharei": "esgardunhar",
    "esgardunhareis": "esgardunhar",
    "esgardunharem": "esgardunhar",
    "esgardunharemos": "esgardunhar",
    "esgardunhares": "esgardunhar",
    "esgardunharia": "esgardunhar",
    "esgardunhariam": "esgardunhar",
    "esgardunharias": "esgardunhar",
    "esgardunharmo": "esgardunhar",
    "esgardunharmos": "esgardunhar",
    "esgardunhará": "esgardunhar",
    "esgardunharás": "esgardunhar",
    "esgardunharão": "esgardunhar",
    "esgardunharíamos": "esgardunhar",
    "esgardunharíeis": "esgardunhar",
    "esgardunhas": "esgardunhar",
    "esgardunhasse": "esgardunhar",
    "esgardunhassem": "esgardunhar",
    "esgardunhasses": "esgardunhar",
    "esgardunhaste": "esgardunhar",
    "esgardunhastes": "esgardunhar",
    "esgardunhava": "esgardunhar",
    "esgardunhavam": "esgardunhar",
    "esgardunhavas": "esgardunhar",
    "esgardunhe": "esgardunhar",
    "esgardunhei": "esgardunhar",
    "esgardunheis": "esgardunhar",
    "esgardunhem": "esgardunhar",
    "esgardunhemo": "esgardunhar",
    "esgardunhemos": "esgardunhar",
    "esgardunhes": "esgardunhar",
    "esgardunho": "esgardunhar",
    "esgardunhou": "esgardunhar",
    "esgardunhá": "esgardunhar",
    "esgardunhámo": "esgardunhar",
    "esgardunhámos": "esgardunhar",
    "esgardunháramo": "esgardunhar",
    "esgardunháramos": "esgardunhar",
    "esgardunhárei": "esgardunhar",
    "esgardunháreis": "esgardunhar",
    "esgardunhásseis": "esgardunhar",
    "esgardunhássemos": "esgardunhar",
    "esgardunhávamo": "esgardunhar",
    "esgardunhávamos": "esgardunhar",
    "esgardunhávei": "esgardunhar",
    "esgardunháveis": "esgardunhar",
    "esgares": "esgar",
    "esgargala": "esgargalar",
    "esgargalada": "esgargalar",
    "esgargaladas": "esgargalar",
    "esgargalado": "esgargalar",
    "esgargalados": "esgargalar",
    "esgargalai": "esgargalar",
    "esgargalais": "esgargalar",
    "esgargalam": "esgargalar",
    "esgargalamo": "esgargalar",
    "esgargalamos": "esgargalar",
    "esgargalando": "esgargalar",
    "esgargalara": "esgargalar",
    "esgargalaram": "esgargalar",
    "esgargalaras": "esgargalar",
    "esgargalarde": "esgargalar",
    "esgargalardes": "esgargalar",
    "esgargalare": "esgargalar",
    "esgargalarei": "esgargalar",
    "esgargalareis": "esgargalar",
    "esgargalarem": "esgargalar",
    "esgargalaremos": "esgargalar",
    "esgargalares": "esgargalar",
    "esgargalaria": "esgargalar",
    "esgargalariam": "esgargalar",
    "esgargalarias": "esgargalar",
    "esgargalarmo": "esgargalar",
    "esgargalarmos": "esgargalar",
    "esgargalará": "esgargalar",
    "esgargalarás": "esgargalar",
    "esgargalarão": "esgargalar",
    "esgargalaríamos": "esgargalar",
    "esgargalaríeis": "esgargalar",
    "esgargalas": "esgargalar",
    "esgargalasse": "esgargalar",
    "esgargalassem": "esgargalar",
    "esgargalasses": "esgargalar",
    "esgargalaste": "esgargalar",
    "esgargalastes": "esgargalar",
    "esgargalava": "esgargalar",
    "esgargalavam": "esgargalar",
    "esgargalavas": "esgargalar",
    "esgargale": "esgargalar",
    "esgargalei": "esgargalar",
    "esgargaleis": "esgargalar",
    "esgargalem": "esgargalar",
    "esgargalemo": "esgargalar",
    "esgargalemos": "esgargalar",
    "esgargales": "esgargalar",
    "esgargalha": "esgargalhar",
    "esgargalhada": "esgargalhar",
    "esgargalhadas": "esgargalhar",
    "esgargalhado": "esgargalhar",
    "esgargalhados": "esgargalhar",
    "esgargalhai": "esgargalhar",
    "esgargalhais": "esgargalhar",
    "esgargalham": "esgargalhar",
    "esgargalhamo": "esgargalhar",
    "esgargalhamos": "esgargalhar",
    "esgargalhando": "esgargalhar",
    "esgargalhara": "esgargalhar",
    "esgargalharam": "esgargalhar",
    "esgargalharas": "esgargalhar",
    "esgargalharde": "esgargalhar",
    "esgargalhardes": "esgargalhar",
    "esgargalhare": "esgargalhar",
    "esgargalharei": "esgargalhar",
    "esgargalhareis": "esgargalhar",
    "esgargalharem": "esgargalhar",
    "esgargalharemos": "esgargalhar",
    "esgargalhares": "esgargalhar",
    "esgargalharia": "esgargalhar",
    "esgargalhariam": "esgargalhar",
    "esgargalharias": "esgargalhar",
    "esgargalharmo": "esgargalhar",
    "esgargalharmos": "esgargalhar",
    "esgargalhará": "esgargalhar",
    "esgargalharás": "esgargalhar",
    "esgargalharão": "esgargalhar",
    "esgargalharíamos": "esgargalhar",
    "esgargalharíeis": "esgargalhar",
    "esgargalhas": "esgargalhar",
    "esgargalhasse": "esgargalhar",
    "esgargalhassem": "esgargalhar",
    "esgargalhasses": "esgargalhar",
    "esgargalhaste": "esgargalhar",
    "esgargalhastes": "esgargalhar",
    "esgargalhava": "esgargalhar",
    "esgargalhavam": "esgargalhar",
    "esgargalhavas": "esgargalhar",
    "esgargalhe": "esgargalhar",
    "esgargalhei": "esgargalhar",
    "esgargalheis": "esgargalhar",
    "esgargalhem": "esgargalhar",
    "esgargalhemo": "esgargalhar",
    "esgargalhemos": "esgargalhar",
    "esgargalhes": "esgargalhar",
    "esgargalho": "esgargalhar",
    "esgargalhou": "esgargalhar",
    "esgargalhá": "esgargalhar",
    "esgargalhámo": "esgargalhar",
    "esgargalhámos": "esgargalhar",
    "esgargalháramo": "esgargalhar",
    "esgargalháramos": "esgargalhar",
    "esgargalhárei": "esgargalhar",
    "esgargalháreis": "esgargalhar",
    "esgargalhásseis": "esgargalhar",
    "esgargalhássemos": "esgargalhar",
    "esgargalhávamo": "esgargalhar",
    "esgargalhávamos": "esgargalhar",
    "esgargalhávei": "esgargalhar",
    "esgargalháveis": "esgargalhar",
    "esgargalo": "esgargalar",
    "esgargalou": "esgargalar",
    "esgargalá": "esgargalar",
    "esgargalámo": "esgargalar",
    "esgargalámos": "esgargalar",
    "esgargaláramo": "esgargalar",
    "esgargaláramos": "esgargalar",
    "esgargalárei": "esgargalar",
    "esgargaláreis": "esgargalar",
    "esgargalásseis": "esgargalar",
    "esgargalássemos": "esgargalar",
    "esgargalávamo": "esgargalar",
    "esgargalávamos": "esgargalar",
    "esgargalávei": "esgargalar",
    "esgargaláveis": "esgargalar",
    "esgarra": "esgarrar",
    "esgarrada": "esgarrar",
    "esgarradas": "esgarrar",
    "esgarrado": "esgarrar",
    "esgarrados": "esgarrar",
    "esgarrai": "esgarrar",
    "esgarrais": "esgarrar",
    "esgarram": "esgarrar",
    "esgarramo": "esgarrar",
    "esgarramos": "esgarrar",
    "esgarrancha": "esgarranchar",
    "esgarranchada": "esgarranchar",
    "esgarranchadas": "esgarranchar",
    "esgarranchado": "esgarranchar",
    "esgarranchados": "esgarranchar",
    "esgarranchai": "esgarranchar",
    "esgarranchais": "esgarranchar",
    "esgarrancham": "esgarranchar",
    "esgarranchamo": "esgarranchar",
    "esgarranchamos": "esgarranchar",
    "esgarranchando": "esgarranchar",
    "esgarranchara": "esgarranchar",
    "esgarrancharam": "esgarranchar",
    "esgarrancharas": "esgarranchar",
    "esgarrancharde": "esgarranchar",
    "esgarranchardes": "esgarranchar",
    "esgarranchare": "esgarranchar",
    "esgarrancharei": "esgarranchar",
    "esgarranchareis": "esgarranchar",
    "esgarrancharem": "esgarranchar",
    "esgarrancharemos": "esgarranchar",
    "esgarranchares": "esgarranchar",
    "esgarrancharia": "esgarranchar",
    "esgarranchariam": "esgarranchar",
    "esgarrancharias": "esgarranchar",
    "esgarrancharmo": "esgarranchar",
    "esgarrancharmos": "esgarranchar",
    "esgarranchará": "esgarranchar",
    "esgarrancharás": "esgarranchar",
    "esgarrancharão": "esgarranchar",
    "esgarrancharíamos": "esgarranchar",
    "esgarrancharíeis": "esgarranchar",
    "esgarranchas": "esgarranchar",
    "esgarranchasse": "esgarranchar",
    "esgarranchassem": "esgarranchar",
    "esgarranchasses": "esgarranchar",
    "esgarranchaste": "esgarranchar",
    "esgarranchastes": "esgarranchar",
    "esgarranchava": "esgarranchar",
    "esgarranchavam": "esgarranchar",
    "esgarranchavas": "esgarranchar",
    "esgarranche": "esgarranchar",
    "esgarranchei": "esgarranchar",
    "esgarrancheis": "esgarranchar",
    "esgarranchem": "esgarranchar",
    "esgarranchemo": "esgarranchar",
    "esgarranchemos": "esgarranchar",
    "esgarranches": "esgarranchar",
    "esgarrancho": "esgarranchar",
    "esgarranchou": "esgarranchar",
    "esgarranchá": "esgarranchar",
    "esgarranchámo": "esgarranchar",
    "esgarranchámos": "esgarranchar",
    "esgarrancháramo": "esgarranchar",
    "esgarrancháramos": "esgarranchar",
    "esgarranchárei": "esgarranchar",
    "esgarrancháreis": "esgarranchar",
    "esgarranchásseis": "esgarranchar",
    "esgarranchássemos": "esgarranchar",
    "esgarranchávamo": "esgarranchar",
    "esgarranchávamos": "esgarranchar",
    "esgarranchávei": "esgarranchar",
    "esgarrancháveis": "esgarranchar",
    "esgarrando": "esgarrar",
    "esgarrara": "esgarrar",
    "esgarraram": "esgarrar",
    "esgarraras": "esgarrar",
    "esgarrarde": "esgarrar",
    "esgarrardes": "esgarrar",
    "esgarrare": "esgarrar",
    "esgarrarei": "esgarrar",
    "esgarrareis": "esgarrar",
    "esgarrarem": "esgarrar",
    "esgarraremos": "esgarrar",
    "esgarrares": "esgarrar",
    "esgarraria": "esgarrar",
    "esgarrariam": "esgarrar",
    "esgarrarias": "esgarrar",
    "esgarrarmo": "esgarrar",
    "esgarrarmos": "esgarrar",
    "esgarrará": "esgarrar",
    "esgarrarás": "esgarrar",
    "esgarrarão": "esgarrar",
    "esgarraríamos": "esgarrar",
    "esgarraríeis": "esgarrar",
    "esgarras": "esgarrar",
    "esgarrasse": "esgarrar",
    "esgarrassem": "esgarrar",
    "esgarrasses": "esgarrar",
    "esgarraste": "esgarrar",
    "esgarrastes": "esgarrar",
    "esgarrava": "esgarrar",
    "esgarravam": "esgarrar",
    "esgarravas": "esgarrar",
    "esgarre": "esgarrar",
    "esgarrei": "esgarrar",
    "esgarreis": "esgarrar",
    "esgarrem": "esgarrar",
    "esgarremo": "esgarrar",
    "esgarremos": "esgarrar",
    "esgarres": "esgarrar",
    "esgarro": "esgarrar",
    "esgarrou": "esgarrar",
    "esgarrá": "esgarrar",
    "esgarrámo": "esgarrar",
    "esgarrámos": "esgarrar",
    "esgarráramo": "esgarrar",
    "esgarráramos": "esgarrar",
    "esgarrárei": "esgarrar",
    "esgarráreis": "esgarrar",
    "esgarrásseis": "esgarrar",
    "esgarrássemos": "esgarrar",
    "esgarrávamo": "esgarrar",
    "esgarrávamos": "esgarrar",
    "esgarrávei": "esgarrar",
    "esgarráveis": "esgarrar",
    "esgarrões": "esgarrão",
    "esgarça": "esgarçar",
    "esgarçada": "esgarçar",
    "esgarçadas": "esgarçar",
    "esgarçado": "esgarçar",
    "esgarçados": "esgarçar",
    "esgarçaduras": "esgarçadura",
    "esgarçai": "esgarçar",
    "esgarçais": "esgarçar",
    "esgarçam": "esgarçar",
    "esgarçamo": "esgarçar",
    "esgarçamos": "esgarçar",
    "esgarçando": "esgarçar",
    "esgarçara": "esgarçar",
    "esgarçaram": "esgarçar",
    "esgarçaras": "esgarçar",
    "esgarçarde": "esgarçar",
    "esgarçardes": "esgarçar",
    "esgarçare": "esgarçar",
    "esgarçarei": "esgarçar",
    "esgarçareis": "esgarçar",
    "esgarçarem": "esgarçar",
    "esgarçaremos": "esgarçar",
    "esgarçares": "esgarçar",
    "esgarçaria": "esgarçar",
    "esgarçariam": "esgarçar",
    "esgarçarias": "esgarçar",
    "esgarçarmo": "esgarçar",
    "esgarçarmos": "esgarçar",
    "esgarçará": "esgarçar",
    "esgarçarás": "esgarçar",
    "esgarçarão": "esgarçar",
    "esgarçaríamos": "esgarçar",
    "esgarçaríeis": "esgarçar",
    "esgarças": "esgarçar",
    "esgarçasse": "esgarçar",
    "esgarçassem": "esgarçar",
    "esgarçasses": "esgarçar",
    "esgarçaste": "esgarçar",
    "esgarçastes": "esgarçar",
    "esgarçava": "esgarçar",
    "esgarçavam": "esgarçar",
    "esgarçavas": "esgarçar",
    "esgarço": "esgarçar",
    "esgarçou": "esgarçar",
    "esgarçá": "esgarçar",
    "esgarçámo": "esgarçar",
    "esgarçámos": "esgarçar",
    "esgarçáramo": "esgarçar",
    "esgarçáramos": "esgarçar",
    "esgarçárei": "esgarçar",
    "esgarçáreis": "esgarçar",
    "esgarçásseis": "esgarçar",
    "esgarçássemos": "esgarçar",
    "esgarçávamo": "esgarçar",
    "esgarçávamos": "esgarçar",
    "esgarçávei": "esgarçar",
    "esgarçáveis": "esgarçar",
    "esgatanha": "esgatanhar",
    "esgatanhada": "esgatanhar",
    "esgatanhadas": "esgatanhar",
    "esgatanhado": "esgatanhar",
    "esgatanhados": "esgatanhar",
    "esgatanhai": "esgatanhar",
    "esgatanhais": "esgatanhar",
    "esgatanham": "esgatanhar",
    "esgatanhamo": "esgatanhar",
    "esgatanhamos": "esgatanhar",
    "esgatanhando": "esgatanhar",
    "esgatanhara": "esgatanhar",
    "esgatanharam": "esgatanhar",
    "esgatanharas": "esgatanhar",
    "esgatanharde": "esgatanhar",
    "esgatanhardes": "esgatanhar",
    "esgatanhare": "esgatanhar",
    "esgatanharei": "esgatanhar",
    "esgatanhareis": "esgatanhar",
    "esgatanharem": "esgatanhar",
    "esgatanharemos": "esgatanhar",
    "esgatanhares": "esgatanhar",
    "esgatanharia": "esgatanhar",
    "esgatanhariam": "esgatanhar",
    "esgatanharias": "esgatanhar",
    "esgatanharmo": "esgatanhar",
    "esgatanharmos": "esgatanhar",
    "esgatanhará": "esgatanhar",
    "esgatanharás": "esgatanhar",
    "esgatanharão": "esgatanhar",
    "esgatanharíamos": "esgatanhar",
    "esgatanharíeis": "esgatanhar",
    "esgatanhas": "esgatanhar",
    "esgatanhasse": "esgatanhar",
    "esgatanhassem": "esgatanhar",
    "esgatanhasses": "esgatanhar",
    "esgatanhaste": "esgatanhar",
    "esgatanhastes": "esgatanhar",
    "esgatanhava": "esgatanhar",
    "esgatanhavam": "esgatanhar",
    "esgatanhavas": "esgatanhar",
    "esgatanhe": "esgatanhar",
    "esgatanhei": "esgatanhar",
    "esgatanheis": "esgatanhar",
    "esgatanhem": "esgatanhar",
    "esgatanhemo": "esgatanhar",
    "esgatanhemos": "esgatanhar",
    "esgatanhes": "esgatanhar",
    "esgatanho": "esgatanhar",
    "esgatanhou": "esgatanhar",
    "esgatanhá": "esgatanhar",
    "esgatanhámo": "esgatanhar",
    "esgatanhámos": "esgatanhar",
    "esgatanháramo": "esgatanhar",
    "esgatanháramos": "esgatanhar",
    "esgatanhárei": "esgatanhar",
    "esgatanháreis": "esgatanhar",
    "esgatanhásseis": "esgatanhar",
    "esgatanhássemos": "esgatanhar",
    "esgatanhávamo": "esgatanhar",
    "esgatanhávamos": "esgatanhar",
    "esgatanhávei": "esgatanhar",
    "esgatanháveis": "esgatanhar",
    "esgazeada": "esgazear",
    "esgazeadas": "esgazear",
    "esgazeado": "esgazear",
    "esgazeados": "esgazear",
    "esgazeai": "esgazear",
    "esgazeais": "esgazear",
    "esgazeamo": "esgazear",
    "esgazeamos": "esgazear",
    "esgazeando": "esgazear",
    "esgazeara": "esgazear",
    "esgazearam": "esgazear",
    "esgazearas": "esgazear",
    "esgazearde": "esgazear",
    "esgazeardes": "esgazear",
    "esgazeare": "esgazear",
    "esgazearei": "esgazear",
    "esgazeareis": "esgazear",
    "esgazearem": "esgazear",
    "esgazearemos": "esgazear",
    "esgazeares": "esgazear",
    "esgazearia": "esgazear",
    "esgazeariam": "esgazear",
    "esgazearias": "esgazear",
    "esgazearmo": "esgazear",
    "esgazearmos": "esgazear",
    "esgazeará": "esgazear",
    "esgazearás": "esgazear",
    "esgazearão": "esgazear",
    "esgazearíamos": "esgazear",
    "esgazearíeis": "esgazear",
    "esgazeasse": "esgazear",
    "esgazeassem": "esgazear",
    "esgazeasses": "esgazear",
    "esgazeaste": "esgazear",
    "esgazeastes": "esgazear",
    "esgazeava": "esgazear",
    "esgazeavam": "esgazear",
    "esgazeavas": "esgazear",
    "esgazeei": "esgazear",
    "esgazeeis": "esgazear",
    "esgazeemo": "esgazear",
    "esgazeemos": "esgazear",
    "esgazeia": "esgazear",
    "esgazeiam": "esgazear",
    "esgazeias": "esgazear",
    "esgazeie": "esgazear",
    "esgazeiem": "esgazear",
    "esgazeies": "esgazear",
    "esgazeio": "esgazear",
    "esgazeou": "esgazear",
    "esgazeá": "esgazear",
    "esgazeámo": "esgazear",
    "esgazeámos": "esgazear",
    "esgazeáramo": "esgazear",
    "esgazeáramos": "esgazear",
    "esgazeárei": "esgazear",
    "esgazeáreis": "esgazear",
    "esgazeásseis": "esgazear",
    "esgazeássemos": "esgazear",
    "esgazeávamo": "esgazear",
    "esgazeávamos": "esgazear",
    "esgazeávei": "esgazear",
    "esgazeáveis": "esgazear",
    "esgaça": "esgaçar",
    "esgaçada": "esgaçar",
    "esgaçadas": "esgaçar",
    "esgaçado": "esgaçar",
    "esgaçados": "esgaçar",
    "esgaçai": "esgaçar",
    "esgaçais": "esgaçar",
    "esgaçam": "esgaçar",
    "esgaçamo": "esgaçar",
    "esgaçamos": "esgaçar",
    "esgaçando": "esgaçar",
    "esgaçara": "esgaçar",
    "esgaçaram": "esgaçar",
    "esgaçaras": "esgaçar",
    "esgaçarde": "esgaçar",
    "esgaçardes": "esgaçar",
    "esgaçare": "esgaçar",
    "esgaçarei": "esgaçar",
    "esgaçareis": "esgaçar",
    "esgaçarem": "esgaçar",
    "esgaçaremos": "esgaçar",
    "esgaçares": "esgaçar",
    "esgaçaria": "esgaçar",
    "esgaçariam": "esgaçar",
    "esgaçarias": "esgaçar",
    "esgaçarmo": "esgaçar",
    "esgaçarmos": "esgaçar",
    "esgaçará": "esgaçar",
    "esgaçarás": "esgaçar",
    "esgaçarão": "esgaçar",
    "esgaçaríamos": "esgaçar",
    "esgaçaríeis": "esgaçar",
    "esgaças": "esgaçar",
    "esgaçasse": "esgaçar",
    "esgaçassem": "esgaçar",
    "esgaçasses": "esgaçar",
    "esgaçaste": "esgaçar",
    "esgaçastes": "esgaçar",
    "esgaçava": "esgaçar",
    "esgaçavam": "esgaçar",
    "esgaçavas": "esgaçar",
    "esgaço": "esgaçar",
    "esgaçou": "esgaçar",
    "esgaçá": "esgaçar",
    "esgaçámo": "esgaçar",
    "esgaçámos": "esgaçar",
    "esgaçáramo": "esgaçar",
    "esgaçáramos": "esgaçar",
    "esgaçárei": "esgaçar",
    "esgaçáreis": "esgaçar",
    "esgaçásseis": "esgaçar",
    "esgaçássemos": "esgaçar",
    "esgaçávamo": "esgaçar",
    "esgaçávamos": "esgaçar",
    "esgaçávei": "esgaçar",
    "esgaçáveis": "esgaçar",
    "esgoela": "esgoelar",
    "esgoelada": "esgoelar",
    "esgoeladas": "esgoelar",
    "esgoelado": "esgoelar",
    "esgoelados": "esgoelar",
    "esgoelai": "esgoelar",
    "esgoelais": "esgoelar",
    "esgoelam": "esgoelar",
    "esgoelamentos": "esgoelamento",
    "esgoelamo": "esgoelar",
    "esgoelamos": "esgoelar",
    "esgoelando": "esgoelar",
    "esgoelara": "esgoelar",
    "esgoelaram": "esgoelar",
    "esgoelaras": "esgoelar",
    "esgoelarde": "esgoelar",
    "esgoelardes": "esgoelar",
    "esgoelare": "esgoelar",
    "esgoelarei": "esgoelar",
    "esgoelareis": "esgoelar",
    "esgoelarem": "esgoelar",
    "esgoelaremos": "esgoelar",
    "esgoelares": "esgoelar",
    "esgoelaria": "esgoelar",
    "esgoelariam": "esgoelar",
    "esgoelarias": "esgoelar",
    "esgoelarmo": "esgoelar",
    "esgoelarmos": "esgoelar",
    "esgoelará": "esgoelar",
    "esgoelarás": "esgoelar",
    "esgoelarão": "esgoelar",
    "esgoelaríamos": "esgoelar",
    "esgoelaríeis": "esgoelar",
    "esgoelas": "esgoelar",
    "esgoelasse": "esgoelar",
    "esgoelassem": "esgoelar",
    "esgoelasses": "esgoelar",
    "esgoelaste": "esgoelar",
    "esgoelastes": "esgoelar",
    "esgoelava": "esgoelar",
    "esgoelavam": "esgoelar",
    "esgoelavas": "esgoelar",
    "esgoele": "esgoelar",
    "esgoelei": "esgoelar",
    "esgoeleis": "esgoelar",
    "esgoelem": "esgoelar",
    "esgoelemo": "esgoelar",
    "esgoelemos": "esgoelar",
    "esgoeles": "esgoelar",
    "esgoelo": "esgoelar",
    "esgoelou": "esgoelar",
    "esgoelá": "esgoelar",
    "esgoelámo": "esgoelar",
    "esgoelámos": "esgoelar",
    "esgoeláramo": "esgoelar",
    "esgoeláramos": "esgoelar",
    "esgoelárei": "esgoelar",
    "esgoeláreis": "esgoelar",
    "esgoelásseis": "esgoelar",
    "esgoelássemos": "esgoelar",
    "esgoelávamo": "esgoelar",
    "esgoelávamos": "esgoelar",
    "esgoelávei": "esgoelar",
    "esgoeláveis": "esgoelar",
    "esgorja": "esgorjar",
    "esgorjada": "esgorjar",
    "esgorjadas": "esgorjar",
    "esgorjado": "esgorjar",
    "esgorjados": "esgorjar",
    "esgorjai": "esgorjar",
    "esgorjais": "esgorjar",
    "esgorjam": "esgorjar",
    "esgorjamo": "esgorjar",
    "esgorjamos": "esgorjar",
    "esgorjando": "esgorjar",
    "esgorjara": "esgorjar",
    "esgorjaram": "esgorjar",
    "esgorjaras": "esgorjar",
    "esgorjardes": "esgorjar",
    "esgorjarei": "esgorjar",
    "esgorjareis": "esgorjar",
    "esgorjarem": "esgorjar",
    "esgorjaremos": "esgorjar",
    "esgorjares": "esgorjar",
    "esgorjaria": "esgorjar",
    "esgorjariam": "esgorjar",
    "esgorjarias": "esgorjar",
    "esgorjarmo": "esgorjar",
    "esgorjarmos": "esgorjar",
    "esgorjará": "esgorjar",
    "esgorjarás": "esgorjar",
    "esgorjarão": "esgorjar",
    "esgorjaríamos": "esgorjar",
    "esgorjaríeis": "esgorjar",
    "esgorjas": "esgorjar",
    "esgorjasse": "esgorjar",
    "esgorjassem": "esgorjar",
    "esgorjasses": "esgorjar",
    "esgorjaste": "esgorjar",
    "esgorjastes": "esgorjar",
    "esgorjava": "esgorjar",
    "esgorjavam": "esgorjar",
    "esgorjavas": "esgorjar",
    "esgorje": "esgorjar",
    "esgorjei": "esgorjar",
    "esgorjeis": "esgorjar",
    "esgorjem": "esgorjar",
    "esgorjemo": "esgorjar",
    "esgorjemos": "esgorjar",
    "esgorjes": "esgorjar",
    "esgorjo": "esgorjar",
    "esgorjou": "esgorjar",
    "esgorjámo": "esgorjar",
    "esgorjámos": "esgorjar",
    "esgorjáramo": "esgorjar",
    "esgorjáramos": "esgorjar",
    "esgorjáreis": "esgorjar",
    "esgorjásseis": "esgorjar",
    "esgorjássemos": "esgorjar",
    "esgorjávamo": "esgorjar",
    "esgorjávamos": "esgorjar",
    "esgorjáveis": "esgorjar",
    "esgota": "esgotar",
    "esgotada": "esgotar",
    "esgotadas": "esgotar",
    "esgotado": "esgotar",
    "esgotadoiros": "esgotadoiro",
    "esgotadora": "esgotador",
    "esgotadoras": "esgotador",
    "esgotadores": "esgotador",
    "esgotados": "esgotar",
    "esgotadouros": "esgotadouro",
    "esgotaduras": "esgotadura",
    "esgotadíssima": "esgotado",
    "esgotadíssimas": "esgotado",
    "esgotadíssimo": "esgotado",
    "esgotadíssimos": "esgotado",
    "esgotai": "esgotar",
    "esgotais": "esgotar",
    "esgotam": "esgotar",
    "esgotamentos": "esgotamento",
    "esgotamo": "esgotar",
    "esgotamos": "esgotar",
    "esgotando": "esgotar",
    "esgotantes": "esgotante",
    "esgotara": "esgotar",
    "esgotaram": "esgotar",
    "esgotaras": "esgotar",
    "esgotarde": "esgotar",
    "esgotardes": "esgotar",
    "esgotare": "esgotar",
    "esgotarei": "esgotar",
    "esgotareis": "esgotar",
    "esgotarem": "esgotar",
    "esgotaremos": "esgotar",
    "esgotares": "esgotar",
    "esgotaria": "esgotar",
    "esgotariam": "esgotar",
    "esgotarias": "esgotar",
    "esgotarmo": "esgotar",
    "esgotarmos": "esgotar",
    "esgotará": "esgotar",
    "esgotarás": "esgotar",
    "esgotarão": "esgotar",
    "esgotaríamos": "esgotar",
    "esgotaríeis": "esgotar",
    "esgotas": "esgotar",
    "esgotasse": "esgotar",
    "esgotassem": "esgotar",
    "esgotasses": "esgotar",
    "esgotaste": "esgotar",
    "esgotastes": "esgotar",
    "esgotava": "esgotar",
    "esgotavam": "esgotar",
    "esgotavas": "esgotar",
    "esgote": "esgotar",
    "esgotei": "esgotar",
    "esgoteiros": "esgoteiro",
    "esgoteis": "esgotar",
    "esgotem": "esgotar",
    "esgotemo": "esgotar",
    "esgotemos": "esgotar",
    "esgotes": "esgotar",
    "esgoto": "esgotar",
    "esgotos": "esgoto",
    "esgotou": "esgotar",
    "esgotá": "esgotar",
    "esgotámo": "esgotar",
    "esgotámos": "esgotar",
    "esgotáramo": "esgotar",
    "esgotáramos": "esgotar",
    "esgotárei": "esgotar",
    "esgotáreis": "esgotar",
    "esgotásseis": "esgotar",
    "esgotássemos": "esgotar",
    "esgotávamo": "esgotar",
    "esgotávamos": "esgotar",
    "esgotávei": "esgotar",
    "esgotáveis": "esgotável",
    "esgrafia": "esgrafiar",
    "esgrafiada": "esgrafiar",
    "esgrafiadas": "esgrafiar",
    "esgrafiado": "esgrafiar",
    "esgrafiados": "esgrafiar",
    "esgrafiai": "esgrafiar",
    "esgrafiais": "esgrafiar",
    "esgrafiam": "esgrafiar",
    "esgrafiamo": "esgrafiar",
    "esgrafiamos": "esgrafiar",
    "esgrafiando": "esgrafiar",
    "esgrafiara": "esgrafiar",
    "esgrafiaram": "esgrafiar",
    "esgrafiaras": "esgrafiar",
    "esgrafiarde": "esgrafiar",
    "esgrafiardes": "esgrafiar",
    "esgrafiare": "esgrafiar",
    "esgrafiarei": "esgrafiar",
    "esgrafiareis": "esgrafiar",
    "esgrafiarem": "esgrafiar",
    "esgrafiaremos": "esgrafiar",
    "esgrafiares": "esgrafiar",
    "esgrafiaria": "esgrafiar",
    "esgrafiariam": "esgrafiar",
    "esgrafiarias": "esgrafiar",
    "esgrafiarmo": "esgrafiar",
    "esgrafiarmos": "esgrafiar",
    "esgrafiará": "esgrafiar",
    "esgrafiarás": "esgrafiar",
    "esgrafiarão": "esgrafiar",
    "esgrafiaríamos": "esgrafiar",
    "esgrafiaríeis": "esgrafiar",
    "esgrafias": "esgrafiar",
    "esgrafiasse": "esgrafiar",
    "esgrafiassem": "esgrafiar",
    "esgrafiasses": "esgrafiar",
    "esgrafiaste": "esgrafiar",
    "esgrafiastes": "esgrafiar",
    "esgrafiava": "esgrafiar",
    "esgrafiavam": "esgrafiar",
    "esgrafiavas": "esgrafiar",
    "esgrafie": "esgrafiar",
    "esgrafiei": "esgrafiar",
    "esgrafieis": "esgrafiar",
    "esgrafiem": "esgrafiar",
    "esgrafiemo": "esgrafiar",
    "esgrafiemos": "esgrafiar",
    "esgrafies": "esgrafiar",
    "esgrafio": "esgrafiar",
    "esgrafiou": "esgrafiar",
    "esgrafita": "esgrafitar",
    "esgrafitada": "esgrafitar",
    "esgrafitadas": "esgrafitar",
    "esgrafitado": "esgrafitar",
    "esgrafitados": "esgrafitar",
    "esgrafitai": "esgrafitar",
    "esgrafitais": "esgrafitar",
    "esgrafitam": "esgrafitar",
    "esgrafitamo": "esgrafitar",
    "esgrafitamos": "esgrafitar",
    "esgrafitando": "esgrafitar",
    "esgrafitara": "esgrafitar",
    "esgrafitaram": "esgrafitar",
    "esgrafitaras": "esgrafitar",
    "esgrafitarde": "esgrafitar",
    "esgrafitardes": "esgrafitar",
    "esgrafitare": "esgrafitar",
    "esgrafitarei": "esgrafitar",
    "esgrafitareis": "esgrafitar",
    "esgrafitarem": "esgrafitar",
    "esgrafitaremos": "esgrafitar",
    "esgrafitares": "esgrafitar",
    "esgrafitaria": "esgrafitar",
    "esgrafitariam": "esgrafitar",
    "esgrafitarias": "esgrafitar",
    "esgrafitarmo": "esgrafitar",
    "esgrafitarmos": "esgrafitar",
    "esgrafitará": "esgrafitar",
    "esgrafitarás": "esgrafitar",
    "esgrafitarão": "esgrafitar",
    "esgrafitaríamos": "esgrafitar",
    "esgrafitaríeis": "esgrafitar",
    "esgrafitas": "esgrafitar",
    "esgrafitasse": "esgrafitar",
    "esgrafitassem": "esgrafitar",
    "esgrafitasses": "esgrafitar",
    "esgrafitaste": "esgrafitar",
    "esgrafitastes": "esgrafitar",
    "esgrafitava": "esgrafitar",
    "esgrafitavam": "esgrafitar",
    "esgrafitavas": "esgrafitar",
    "esgrafite": "esgrafitar",
    "esgrafitei": "esgrafitar",
    "esgrafiteis": "esgrafitar",
    "esgrafitem": "esgrafitar",
    "esgrafitemo": "esgrafitar",
    "esgrafitemos": "esgrafitar",
    "esgrafites": "esgrafitar",
    "esgrafito": "esgrafitar",
    "esgrafitos": "esgrafito",
    "esgrafitou": "esgrafitar",
    "esgrafitá": "esgrafitar",
    "esgrafitámo": "esgrafitar",
    "esgrafitámos": "esgrafitar",
    "esgrafitáramo": "esgrafitar",
    "esgrafitáramos": "esgrafitar",
    "esgrafitárei": "esgrafitar",
    "esgrafitáreis": "esgrafitar",
    "esgrafitásseis": "esgrafitar",
    "esgrafitássemos": "esgrafitar",
    "esgrafitávamo": "esgrafitar",
    "esgrafitávamos": "esgrafitar",
    "esgrafitávei": "esgrafitar",
    "esgrafitáveis": "esgrafitar",
    "esgrafiá": "esgrafiar",
    "esgrafiámo": "esgrafiar",
    "esgrafiámos": "esgrafiar",
    "esgrafiáramo": "esgrafiar",
    "esgrafiáramos": "esgrafiar",
    "esgrafiárei": "esgrafiar",
    "esgrafiáreis": "esgrafiar",
    "esgrafiásseis": "esgrafiar",
    "esgrafiássemos": "esgrafiar",
    "esgrafiávamo": "esgrafiar",
    "esgrafiávamos": "esgrafiar",
    "esgrafiávei": "esgrafiar",
    "esgrafiáveis": "esgrafiar",
    "esgraminha": "esgraminhar",
    "esgraminhada": "esgraminhar",
    "esgraminhadas": "esgraminhar",
    "esgraminhado": "esgraminhar",
    "esgraminhadora": "esgraminhador",
    "esgraminhadoras": "esgraminhador",
    "esgraminhadores": "esgraminhador",
    "esgraminhados": "esgraminhar",
    "esgraminhai": "esgraminhar",
    "esgraminhais": "esgraminhar",
    "esgraminham": "esgraminhar",
    "esgraminhamo": "esgraminhar",
    "esgraminhamos": "esgraminhar",
    "esgraminhando": "esgraminhar",
    "esgraminhara": "esgraminhar",
    "esgraminharam": "esgraminhar",
    "esgraminharas": "esgraminhar",
    "esgraminharde": "esgraminhar",
    "esgraminhardes": "esgraminhar",
    "esgraminhare": "esgraminhar",
    "esgraminharei": "esgraminhar",
    "esgraminhareis": "esgraminhar",
    "esgraminharem": "esgraminhar",
    "esgraminharemos": "esgraminhar",
    "esgraminhares": "esgraminhar",
    "esgraminharia": "esgraminhar",
    "esgraminhariam": "esgraminhar",
    "esgraminharias": "esgraminhar",
    "esgraminharmo": "esgraminhar",
    "esgraminharmos": "esgraminhar",
    "esgraminhará": "esgraminhar",
    "esgraminharás": "esgraminhar",
    "esgraminharão": "esgraminhar",
    "esgraminharíamos": "esgraminhar",
    "esgraminharíeis": "esgraminhar",
    "esgraminhas": "esgraminhar",
    "esgraminhasse": "esgraminhar",
    "esgraminhassem": "esgraminhar",
    "esgraminhasses": "esgraminhar",
    "esgraminhaste": "esgraminhar",
    "esgraminhastes": "esgraminhar",
    "esgraminhava": "esgraminhar",
    "esgraminhavam": "esgraminhar",
    "esgraminhavas": "esgraminhar",
    "esgraminhe": "esgraminhar",
    "esgraminhei": "esgraminhar",
    "esgraminheis": "esgraminhar",
    "esgraminhem": "esgraminhar",
    "esgraminhemo": "esgraminhar",
    "esgraminhemos": "esgraminhar",
    "esgraminhes": "esgraminhar",
    "esgraminho": "esgraminhar",
    "esgraminhou": "esgraminhar",
    "esgraminhá": "esgraminhar",
    "esgraminhámo": "esgraminhar",
    "esgraminhámos": "esgraminhar",
    "esgraminháramo": "esgraminhar",
    "esgraminháramos": "esgraminhar",
    "esgraminhárei": "esgraminhar",
    "esgraminháreis": "esgraminhar",
    "esgraminhásseis": "esgraminhar",
    "esgraminhássemos": "esgraminhar",
    "esgraminhávamo": "esgraminhar",
    "esgraminhávamos": "esgraminhar",
    "esgraminhávei": "esgraminhar",
    "esgraminháveis": "esgraminhar",
    "esgravanadas": "esgravanada",
    "esgravata": "esgravatar",
    "esgravatada": "esgravatar",
    "esgravatadas": "esgravatar",
    "esgravatado": "esgravatar",
    "esgravatadores": "esgravatador",
    "esgravatados": "esgravatar",
    "esgravatai": "esgravatar",
    "esgravatais": "esgravatar",
    "esgravatam": "esgravatar",
    "esgravatamo": "esgravatar",
    "esgravatamos": "esgravatar",
    "esgravatando": "esgravatar",
    "esgravatara": "esgravatar",
    "esgravataram": "esgravatar",
    "esgravataras": "esgravatar",
    "esgravatarde": "esgravatar",
    "esgravatardes": "esgravatar",
    "esgravatare": "esgravatar",
    "esgravatarei": "esgravatar",
    "esgravatareis": "esgravatar",
    "esgravatarem": "esgravatar",
    "esgravataremos": "esgravatar",
    "esgravatares": "esgravatar",
    "esgravataria": "esgravatar",
    "esgravatariam": "esgravatar",
    "esgravatarias": "esgravatar",
    "esgravatarmo": "esgravatar",
    "esgravatarmos": "esgravatar",
    "esgravatará": "esgravatar",
    "esgravatarás": "esgravatar",
    "esgravatarão": "esgravatar",
    "esgravataríamos": "esgravatar",
    "esgravataríeis": "esgravatar",
    "esgravatas": "esgravatar",
    "esgravatasse": "esgravatar",
    "esgravatassem": "esgravatar",
    "esgravatasses": "esgravatar",
    "esgravataste": "esgravatar",
    "esgravatastes": "esgravatar",
    "esgravatava": "esgravatar",
    "esgravatavam": "esgravatar",
    "esgravatavas": "esgravatar",
    "esgravate": "esgravatar",
    "esgravatei": "esgravatar",
    "esgravateis": "esgravatar",
    "esgravatem": "esgravatar",
    "esgravatemo": "esgravatar",
    "esgravatemos": "esgravatar",
    "esgravates": "esgravatar",
    "esgravato": "esgravatar",
    "esgravatou": "esgravatar",
    "esgravatá": "esgravatar",
    "esgravatámo": "esgravatar",
    "esgravatámos": "esgravatar",
    "esgravatáramo": "esgravatar",
    "esgravatáramos": "esgravatar",
    "esgravatárei": "esgravatar",
    "esgravatáreis": "esgravatar",
    "esgravatásseis": "esgravatar",
    "esgravatássemos": "esgravatar",
    "esgravatávamo": "esgravatar",
    "esgravatávamos": "esgravatar",
    "esgravatávei": "esgravatar",
    "esgravatáveis": "esgravatar",
    "esgravelha": "esgravelhar",
    "esgravelhada": "esgravelhar",
    "esgravelhadas": "esgravelhar",
    "esgravelhado": "esgravelhar",
    "esgravelhados": "esgravelhar",
    "esgravelhai": "esgravelhar",
    "esgravelhais": "esgravelhar",
    "esgravelham": "esgravelhar",
    "esgravelhamo": "esgravelhar",
    "esgravelhamos": "esgravelhar",
    "esgravelhando": "esgravelhar",
    "esgravelhara": "esgravelhar",
    "esgravelharam": "esgravelhar",
    "esgravelharas": "esgravelhar",
    "esgravelharde": "esgravelhar",
    "esgravelhardes": "esgravelhar",
    "esgravelhare": "esgravelhar",
    "esgravelharei": "esgravelhar",
    "esgravelhareis": "esgravelhar",
    "esgravelharem": "esgravelhar",
    "esgravelharemos": "esgravelhar",
    "esgravelhares": "esgravelhar",
    "esgravelharia": "esgravelhar",
    "esgravelhariam": "esgravelhar",
    "esgravelharias": "esgravelhar",
    "esgravelharmo": "esgravelhar",
    "esgravelharmos": "esgravelhar",
    "esgravelhará": "esgravelhar",
    "esgravelharás": "esgravelhar",
    "esgravelharão": "esgravelhar",
    "esgravelharíamos": "esgravelhar",
    "esgravelharíeis": "esgravelhar",
    "esgravelhas": "esgravelhar",
    "esgravelhasse": "esgravelhar",
    "esgravelhassem": "esgravelhar",
    "esgravelhasses": "esgravelhar",
    "esgravelhaste": "esgravelhar",
    "esgravelhastes": "esgravelhar",
    "esgravelhava": "esgravelhar",
    "esgravelhavam": "esgravelhar",
    "esgravelhavas": "esgravelhar",
    "esgravelhe": "esgravelhar",
    "esgravelhei": "esgravelhar",
    "esgravelheis": "esgravelhar",
    "esgravelhem": "esgravelhar",
    "esgravelhemo": "esgravelhar",
    "esgravelhemos": "esgravelhar",
    "esgravelhes": "esgravelhar",
    "esgravelho": "esgravelhar",
    "esgravelhos": "esgravelho",
    "esgravelhou": "esgravelhar",
    "esgravelhá": "esgravelhar",
    "esgravelhámo": "esgravelhar",
    "esgravelhámos": "esgravelhar",
    "esgravelháramo": "esgravelhar",
    "esgravelháramos": "esgravelhar",
    "esgravelhárei": "esgravelhar",
    "esgravelháreis": "esgravelhar",
    "esgravelhásseis": "esgravelhar",
    "esgravelhássemos": "esgravelhar",
    "esgravelhávamo": "esgravelhar",
    "esgravelhávamos": "esgravelhar",
    "esgravelhávei": "esgravelhar",
    "esgravelháveis": "esgravelhar",
    "esgrila": "esgrilar",
    "esgrilada": "esgrilar",
    "esgriladas": "esgrilar",
    "esgrilado": "esgrilar",
    "esgrilados": "esgrilar",
    "esgrilai": "esgrilar",
    "esgrilais": "esgrilar",
    "esgrilam": "esgrilar",
    "esgrilamo": "esgrilar",
    "esgrilamos": "esgrilar",
    "esgrilando": "esgrilar",
    "esgrilara": "esgrilar",
    "esgrilaram": "esgrilar",
    "esgrilaras": "esgrilar",
    "esgrilarde": "esgrilar",
    "esgrilardes": "esgrilar",
    "esgrilare": "esgrilar",
    "esgrilarei": "esgrilar",
    "esgrilareis": "esgrilar",
    "esgrilarem": "esgrilar",
    "esgrilaremos": "esgrilar",
    "esgrilares": "esgrilar",
    "esgrilaria": "esgrilar",
    "esgrilariam": "esgrilar",
    "esgrilarias": "esgrilar",
    "esgrilarmo": "esgrilar",
    "esgrilarmos": "esgrilar",
    "esgrilará": "esgrilar",
    "esgrilarás": "esgrilar",
    "esgrilarão": "esgrilar",
    "esgrilaríamos": "esgrilar",
    "esgrilaríeis": "esgrilar",
    "esgrilas": "esgrilar",
    "esgrilasse": "esgrilar",
    "esgrilassem": "esgrilar",
    "esgrilasses": "esgrilar",
    "esgrilaste": "esgrilar",
    "esgrilastes": "esgrilar",
    "esgrilava": "esgrilar",
    "esgrilavam": "esgrilar",
    "esgrilavas": "esgrilar",
    "esgrile": "esgrilar",
    "esgrilei": "esgrilar",
    "esgrileis": "esgrilar",
    "esgrilem": "esgrilar",
    "esgrilemo": "esgrilar",
    "esgrilemos": "esgrilar",
    "esgriles": "esgrilar",
    "esgrilo": "esgrilar",
    "esgrilou": "esgrilar",
    "esgrilá": "esgrilar",
    "esgrilámo": "esgrilar",
    "esgrilámos": "esgrilar",
    "esgriláramo": "esgrilar",
    "esgriláramos": "esgrilar",
    "esgrilárei": "esgrilar",
    "esgriláreis": "esgrilar",
    "esgrilásseis": "esgrilar",
    "esgrilássemos": "esgrilar",
    "esgrilávamo": "esgrilar",
    "esgrilávamos": "esgrilar",
    "esgrilávei": "esgrilar",
    "esgriláveis": "esgrilar",
    "esgrima": "esgrimir",
    "esgrimais": "esgrimir",
    "esgrimam": "esgrimir",
    "esgrimamo": "esgrimir",
    "esgrimamos": "esgrimir",
    "esgrimas": "esgrimir",
    "esgrime": "esgrimir",
    "esgrimem": "esgrimir",
    "esgrimes": "esgrimir",
    "esgrimi": "esgrimir",
    "esgrimia": "esgrimir",
    "esgrimiam": "esgrimir",
    "esgrimias": "esgrimir",
    "esgrimida": "esgrimir",
    "esgrimidas": "esgrimir",
    "esgrimido": "esgrimir",
    "esgrimidora": "esgrimidor",
    "esgrimidoras": "esgrimidor",
    "esgrimidores": "esgrimidor",
    "esgrimidos": "esgrimir",
    "esgrimiduras": "esgrimidura",
    "esgrimimo": "esgrimir",
    "esgrimimos": "esgrimir",
    "esgrimindo": "esgrimir",
    "esgrimira": "esgrimir",
    "esgrimiram": "esgrimir",
    "esgrimiras": "esgrimir",
    "esgrimirdes": "esgrimir",
    "esgrimirei": "esgrimir",
    "esgrimireis": "esgrimir",
    "esgrimirem": "esgrimir",
    "esgrimiremos": "esgrimir",
    "esgrimires": "esgrimir",
    "esgrimiria": "esgrimir",
    "esgrimiriam": "esgrimir",
    "esgrimirias": "esgrimir",
    "esgrimirmo": "esgrimir",
    "esgrimirmos": "esgrimir",
    "esgrimirá": "esgrimir",
    "esgrimirás": "esgrimir",
    "esgrimirão": "esgrimir",
    "esgrimiríamos": "esgrimir",
    "esgrimiríeis": "esgrimir",
    "esgrimis": "esgrimir",
    "esgrimisse": "esgrimir",
    "esgrimissem": "esgrimir",
    "esgrimisses": "esgrimir",
    "esgrimistas": "esgrimista",
    "esgrimiste": "esgrimir",
    "esgrimistes": "esgrimir",
    "esgrimiu": "esgrimir",
    "esgrimo": "esgrimir",
    "esgrimíamo": "esgrimir",
    "esgrimíamos": "esgrimir",
    "esgrimíeis": "esgrimir",
    "esgrimíramo": "esgrimir",
    "esgrimíramos": "esgrimir",
    "esgrimíreis": "esgrimir",
    "esgrimísseis": "esgrimir",
    "esgrimíssemos": "esgrimir",
    "esgrouvia": "esgrouviar",
    "esgrouviada": "esgrouviar",
    "esgrouviadas": "esgrouviar",
    "esgrouviado": "esgrouviar",
    "esgrouviados": "esgrouviar",
    "esgrouviai": "esgrouviar",
    "esgrouviais": "esgrouviar",
    "esgrouviam": "esgrouviar",
    "esgrouviamo": "esgrouviar",
    "esgrouviamos": "esgrouviar",
    "esgrouviando": "esgrouviar",
    "esgrouviara": "esgrouviar",
    "esgrouviaram": "esgrouviar",
    "esgrouviaras": "esgrouviar",
    "esgrouviarde": "esgrouviar",
    "esgrouviardes": "esgrouviar",
    "esgrouviare": "esgrouviar",
    "esgrouviarei": "esgrouviar",
    "esgrouviareis": "esgrouviar",
    "esgrouviarem": "esgrouviar",
    "esgrouviaremos": "esgrouviar",
    "esgrouviares": "esgrouviar",
    "esgrouviaria": "esgrouviar",
    "esgrouviariam": "esgrouviar",
    "esgrouviarias": "esgrouviar",
    "esgrouviarmo": "esgrouviar",
    "esgrouviarmos": "esgrouviar",
    "esgrouviará": "esgrouviar",
    "esgrouviarás": "esgrouviar",
    "esgrouviarão": "esgrouviar",
    "esgrouviaríamos": "esgrouviar",
    "esgrouviaríeis": "esgrouviar",
    "esgrouvias": "esgrouviar",
    "esgrouviasse": "esgrouviar",
    "esgrouviassem": "esgrouviar",
    "esgrouviasses": "esgrouviar",
    "esgrouviaste": "esgrouviar",
    "esgrouviastes": "esgrouviar",
    "esgrouviava": "esgrouviar",
    "esgrouviavam": "esgrouviar",
    "esgrouviavas": "esgrouviar",
    "esgrouvie": "esgrouviar",
    "esgrouviei": "esgrouviar",
    "esgrouvieis": "esgrouviar",
    "esgrouviem": "esgrouviar",
    "esgrouviemo": "esgrouviar",
    "esgrouviemos": "esgrouviar",
    "esgrouvies": "esgrouviar",
    "esgrouvinha": "esgrouvinhar",
    "esgrouvinhada": "esgrouvinhar",
    "esgrouvinhadas": "esgrouvinhar",
    "esgrouvinhado": "esgrouvinhar",
    "esgrouvinhados": "esgrouvinhar",
    "esgrouvinhai": "esgrouvinhar",
    "esgrouvinhais": "esgrouvinhar",
    "esgrouvinham": "esgrouvinhar",
    "esgrouvinhamo": "esgrouvinhar",
    "esgrouvinhamos": "esgrouvinhar",
    "esgrouvinhando": "esgrouvinhar",
    "esgrouvinhara": "esgrouvinhar",
    "esgrouvinharam": "esgrouvinhar",
    "esgrouvinharas": "esgrouvinhar",
    "esgrouvinharde": "esgrouvinhar",
    "esgrouvinhardes": "esgrouvinhar",
    "esgrouvinhare": "esgrouvinhar",
    "esgrouvinharei": "esgrouvinhar",
    "esgrouvinhareis": "esgrouvinhar",
    "esgrouvinharem": "esgrouvinhar",
    "esgrouvinharemos": "esgrouvinhar",
    "esgrouvinhares": "esgrouvinhar",
    "esgrouvinharia": "esgrouvinhar",
    "esgrouvinhariam": "esgrouvinhar",
    "esgrouvinharias": "esgrouvinhar",
    "esgrouvinharmo": "esgrouvinhar",
    "esgrouvinharmos": "esgrouvinhar",
    "esgrouvinhará": "esgrouvinhar",
    "esgrouvinharás": "esgrouvinhar",
    "esgrouvinharão": "esgrouvinhar",
    "esgrouvinharíamos": "esgrouvinhar",
    "esgrouvinharíeis": "esgrouvinhar",
    "esgrouvinhas": "esgrouvinhar",
    "esgrouvinhasse": "esgrouvinhar",
    "esgrouvinhassem": "esgrouvinhar",
    "esgrouvinhasses": "esgrouvinhar",
    "esgrouvinhaste": "esgrouvinhar",
    "esgrouvinhastes": "esgrouvinhar",
    "esgrouvinhava": "esgrouvinhar",
    "esgrouvinhavam": "esgrouvinhar",
    "esgrouvinhavas": "esgrouvinhar",
    "esgrouvinhe": "esgrouvinhar",
    "esgrouvinhei": "esgrouvinhar",
    "esgrouvinheis": "esgrouvinhar",
    "esgrouvinhem": "esgrouvinhar",
    "esgrouvinhemo": "esgrouvinhar",
    "esgrouvinhemos": "esgrouvinhar",
    "esgrouvinhes": "esgrouvinhar",
    "esgrouvinho": "esgrouvinhar",
    "esgrouvinhou": "esgrouvinhar",
    "esgrouvinhá": "esgrouvinhar",
    "esgrouvinhámo": "esgrouvinhar",
    "esgrouvinhámos": "esgrouvinhar",
    "esgrouvinháramo": "esgrouvinhar",
    "esgrouvinháramos": "esgrouvinhar",
    "esgrouvinhárei": "esgrouvinhar",
    "esgrouvinháreis": "esgrouvinhar",
    "esgrouvinhásseis": "esgrouvinhar",
    "esgrouvinhássemos": "esgrouvinhar",
    "esgrouvinhávamo": "esgrouvinhar",
    "esgrouvinhávamos": "esgrouvinhar",
    "esgrouvinhávei": "esgrouvinhar",
    "esgrouvinháveis": "esgrouvinhar",
    "esgrouvio": "esgrouviar",
    "esgrouviou": "esgrouviar",
    "esgrouviá": "esgrouviar",
    "esgrouviámo": "esgrouviar",
    "esgrouviámos": "esgrouviar",
    "esgrouviáramo": "esgrouviar",
    "esgrouviáramos": "esgrouviar",
    "esgrouviárei": "esgrouviar",
    "esgrouviáreis": "esgrouviar",
    "esgrouviásseis": "esgrouviar",
    "esgrouviássemos": "esgrouviar",
    "esgrouviávamo": "esgrouviar",
    "esgrouviávamos": "esgrouviar",
    "esgrouviávei": "esgrouviar",
    "esgrouviáveis": "esgrouviar",
    "esguarda": "esguardar",
    "esguardada": "esguardar",
    "esguardadas": "esguardar",
    "esguardado": "esguardar",
    "esguardados": "esguardar",
    "esguardai": "esguardar",
    "esguardais": "esguardar",
    "esguardam": "esguardar",
    "esguardamo": "esguardar",
    "esguardamos": "esguardar",
    "esguardando": "esguardar",
    "esguardara": "esguardar",
    "esguardaram": "esguardar",
    "esguardaras": "esguardar",
    "esguardarde": "esguardar",
    "esguardardes": "esguardar",
    "esguardare": "esguardar",
    "esguardarei": "esguardar",
    "esguardareis": "esguardar",
    "esguardarem": "esguardar",
    "esguardaremos": "esguardar",
    "esguardares": "esguardar",
    "esguardaria": "esguardar",
    "esguardariam": "esguardar",
    "esguardarias": "esguardar",
    "esguardarmo": "esguardar",
    "esguardarmos": "esguardar",
    "esguardará": "esguardar",
    "esguardarás": "esguardar",
    "esguardarão": "esguardar",
    "esguardaríamos": "esguardar",
    "esguardaríeis": "esguardar",
    "esguardas": "esguardar",
    "esguardasse": "esguardar",
    "esguardassem": "esguardar",
    "esguardasses": "esguardar",
    "esguardaste": "esguardar",
    "esguardastes": "esguardar",
    "esguardava": "esguardar",
    "esguardavam": "esguardar",
    "esguardavas": "esguardar",
    "esguarde": "esguardar",
    "esguardei": "esguardar",
    "esguardeis": "esguardar",
    "esguardem": "esguardar",
    "esguardemo": "esguardar",
    "esguardemos": "esguardar",
    "esguardes": "esguardar",
    "esguardo": "esguardar",
    "esguardos": "esguardo",
    "esguardou": "esguardar",
    "esguardá": "esguardar",
    "esguardámo": "esguardar",
    "esguardámos": "esguardar",
    "esguardáramo": "esguardar",
    "esguardáramos": "esguardar",
    "esguardárei": "esguardar",
    "esguardáreis": "esguardar",
    "esguardásseis": "esguardar",
    "esguardássemos": "esguardar",
    "esguardávamo": "esguardar",
    "esguardávamos": "esguardar",
    "esguardávei": "esguardar",
    "esguardáveis": "esguardar",
    "esguedelha": "esguedelhar",
    "esguedelhada": "esguedelhar",
    "esguedelhadas": "esguedelhar",
    "esguedelhado": "esguedelhar",
    "esguedelhados": "esguedelhar",
    "esguedelhai": "esguedelhar",
    "esguedelhais": "esguedelhar",
    "esguedelham": "esguedelhar",
    "esguedelhamo": "esguedelhar",
    "esguedelhamos": "esguedelhar",
    "esguedelhando": "esguedelhar",
    "esguedelhara": "esguedelhar",
    "esguedelharam": "esguedelhar",
    "esguedelharas": "esguedelhar",
    "esguedelharde": "esguedelhar",
    "esguedelhardes": "esguedelhar",
    "esguedelhare": "esguedelhar",
    "esguedelharei": "esguedelhar",
    "esguedelhareis": "esguedelhar",
    "esguedelharem": "esguedelhar",
    "esguedelharemos": "esguedelhar",
    "esguedelhares": "esguedelhar",
    "esguedelharia": "esguedelhar",
    "esguedelhariam": "esguedelhar",
    "esguedelharias": "esguedelhar",
    "esguedelharmo": "esguedelhar",
    "esguedelharmos": "esguedelhar",
    "esguedelhará": "esguedelhar",
    "esguedelharás": "esguedelhar",
    "esguedelharão": "esguedelhar",
    "esguedelharíamos": "esguedelhar",
    "esguedelharíeis": "esguedelhar",
    "esguedelhas": "esguedelhar",
    "esguedelhasse": "esguedelhar",
    "esguedelhassem": "esguedelhar",
    "esguedelhasses": "esguedelhar",
    "esguedelhaste": "esguedelhar",
    "esguedelhastes": "esguedelhar",
    "esguedelhava": "esguedelhar",
    "esguedelhavam": "esguedelhar",
    "esguedelhavas": "esguedelhar",
    "esguedelhe": "esguedelhar",
    "esguedelhei": "esguedelhar",
    "esguedelheis": "esguedelhar",
    "esguedelhem": "esguedelhar",
    "esguedelhemo": "esguedelhar",
    "esguedelhemos": "esguedelhar",
    "esguedelhes": "esguedelhar",
    "esguedelho": "esguedelhar",
    "esguedelhou": "esguedelhar",
    "esguedelhá": "esguedelhar",
    "esguedelhámo": "esguedelhar",
    "esguedelhámos": "esguedelhar",
    "esguedelháramo": "esguedelhar",
    "esguedelháramos": "esguedelhar",
    "esguedelhárei": "esguedelhar",
    "esguedelháreis": "esguedelhar",
    "esguedelhásseis": "esguedelhar",
    "esguedelhássemos": "esguedelhar",
    "esguedelhávamo": "esguedelhar",
    "esguedelhávamos": "esguedelhar",
    "esguedelhávei": "esguedelhar",
    "esguedelháveis": "esguedelhar",
    "esgueira": "esgueirar",
    "esgueirada": "esgueirar",
    "esgueiradas": "esgueirar",
    "esgueirado": "esgueirar",
    "esgueirados": "esgueirar",
    "esgueirai": "esgueirar",
    "esgueirais": "esgueirar",
    "esgueiram": "esgueirar",
    "esgueiramo": "esgueirar",
    "esgueiramos": "esgueirar",
    "esgueirando": "esgueirar",
    "esgueirara": "esgueirar",
    "esgueiraram": "esgueirar",
    "esgueiraras": "esgueirar",
    "esgueirarde": "esgueirar",
    "esgueirardes": "esgueirar",
    "esgueirare": "esgueirar",
    "esgueirarei": "esgueirar",
    "esgueirareis": "esgueirar",
    "esgueirarem": "esgueirar",
    "esgueiraremos": "esgueirar",
    "esgueirares": "esgueirar",
    "esgueiraria": "esgueirar",
    "esgueirariam": "esgueirar",
    "esgueirarias": "esgueirar",
    "esgueirarmo": "esgueirar",
    "esgueirarmos": "esgueirar",
    "esgueirará": "esgueirar",
    "esgueirarás": "esgueirar",
    "esgueirarão": "esgueirar",
    "esgueiraríamos": "esgueirar",
    "esgueiraríeis": "esgueirar",
    "esgueiras": "esgueirar",
    "esgueirasse": "esgueirar",
    "esgueirassem": "esgueirar",
    "esgueirasses": "esgueirar",
    "esgueiraste": "esgueirar",
    "esgueirastes": "esgueirar",
    "esgueirava": "esgueirar",
    "esgueiravam": "esgueirar",
    "esgueiravas": "esgueirar",
    "esgueire": "esgueirar",
    "esgueirei": "esgueirar",
    "esgueireis": "esgueirar",
    "esgueirem": "esgueirar",
    "esgueiremo": "esgueirar",
    "esgueiremos": "esgueirar",
    "esgueires": "esgueirar",
    "esgueiriça": "esgueiriço",
    "esgueiriças": "esgueiriço",
    "esgueiriços": "esgueiriço",
    "esgueiro": "esgueirar",
    "esgueirou": "esgueirar",
    "esgueirá": "esgueirar",
    "esgueirámo": "esgueirar",
    "esgueirámos": "esgueirar",
    "esgueiráramo": "esgueirar",
    "esgueiráramos": "esgueirar",
    "esgueirárei": "esgueirar",
    "esgueiráreis": "esgueirar",
    "esgueirásseis": "esgueirar",
    "esgueirássemos": "esgueirar",
    "esgueirávamo": "esgueirar",
    "esgueirávamos": "esgueirar",
    "esgueirávei": "esgueirar",
    "esgueiráveis": "esgueirar",
    "esguelha": "esguelhar",
    "esguelhada": "esguelhar",
    "esguelhadas": "esguelhar",
    "esguelhado": "esguelhar",
    "esguelhados": "esguelhar",
    "esguelhai": "esguelhar",
    "esguelhais": "esguelhar",
    "esguelham": "esguelhar",
    "esguelhamo": "esguelhar",
    "esguelhamos": "esguelhar",
    "esguelhando": "esguelhar",
    "esguelhara": "esguelhar",
    "esguelharam": "esguelhar",
    "esguelharas": "esguelhar",
    "esguelharde": "esguelhar",
    "esguelhardes": "esguelhar",
    "esguelhare": "esguelhar",
    "esguelharei": "esguelhar",
    "esguelhareis": "esguelhar",
    "esguelharem": "esguelhar",
    "esguelharemos": "esguelhar",
    "esguelhares": "esguelhar",
    "esguelharia": "esguelhar",
    "esguelhariam": "esguelhar",
    "esguelharias": "esguelhar",
    "esguelharmo": "esguelhar",
    "esguelharmos": "esguelhar",
    "esguelhará": "esguelhar",
    "esguelharás": "esguelhar",
    "esguelharão": "esguelhar",
    "esguelharíamos": "esguelhar",
    "esguelharíeis": "esguelhar",
    "esguelhas": "esguelhar",
    "esguelhasse": "esguelhar",
    "esguelhassem": "esguelhar",
    "esguelhasses": "esguelhar",
    "esguelhaste": "esguelhar",
    "esguelhastes": "esguelhar",
    "esguelhava": "esguelhar",
    "esguelhavam": "esguelhar",
    "esguelhavas": "esguelhar",
    "esguelhe": "esguelhar",
    "esguelhei": "esguelhar",
    "esguelheis": "esguelhar",
    "esguelhem": "esguelhar",
    "esguelhemo": "esguelhar",
    "esguelhemos": "esguelhar",
    "esguelhes": "esguelhar",
    "esguelho": "esguelhar",
    "esguelhou": "esguelhar",
    "esguelhá": "esguelhar",
    "esguelhámo": "esguelhar",
    "esguelhámos": "esguelhar",
    "esguelháramo": "esguelhar",
    "esguelháramos": "esguelhar",
    "esguelhárei": "esguelhar",
    "esguelháreis": "esguelhar",
    "esguelhásseis": "esguelhar",
    "esguelhássemos": "esguelhar",
    "esguelhávamo": "esguelhar",
    "esguelhávamos": "esguelhar",
    "esguelhávei": "esguelhar",
    "esguelháveis": "esguelhar",
    "esguelhões": "esguelhão",
    "esguia": "esguio",
    "esguiada": "esguiar",
    "esguiadas": "esguiar",
    "esguiado": "esguiar",
    "esguiados": "esguiar",
    "esguiai": "esguiar",
    "esguiais": "esguiar",
    "esguiam": "esguiar",
    "esguiamo": "esguiar",
    "esguiamos": "esguiar",
    "esguiando": "esguiar",
    "esguiara": "esguiar",
    "esguiaram": "esguiar",
    "esguiaras": "esguiar",
    "esguiarde": "esguiar",
    "esguiardes": "esguiar",
    "esguiare": "esguiar",
    "esguiarei": "esguiar",
    "esguiareis": "esguiar",
    "esguiarem": "esguiar",
    "esguiaremos": "esguiar",
    "esguiares": "esguiar",
    "esguiaria": "esguiar",
    "esguiariam": "esguiar",
    "esguiarias": "esguiar",
    "esguiarmo": "esguiar",
    "esguiarmos": "esguiar",
    "esguiará": "esguiar",
    "esguiarás": "esguiar",
    "esguiarão": "esguiar",
    "esguiaríamos": "esguiar",
    "esguiaríeis": "esguiar",
    "esguias": "esguio",
    "esguiasse": "esguiar",
    "esguiassem": "esguiar",
    "esguiasses": "esguiar",
    "esguiaste": "esguiar",
    "esguiastes": "esguiar",
    "esguiava": "esguiar",
    "esguiavam": "esguiar",
    "esguiavas": "esguiar",
    "esguichada": "esguichado",
    "esguichadas": "esguichado",
    "esguichadelas": "esguichadela",
    "esguichados": "esguichado",
    "esguiches": "esguiche",
    "esguichos": "esguicho",
    "esguie": "esguiar",
    "esguiei": "esguiar",
    "esguieis": "esguiar",
    "esguiem": "esguiar",
    "esguiemo": "esguiar",
    "esguiemos": "esguiar",
    "esguies": "esguiar",
    "esguiezes": "esguiez",
    "esguincha": "esguinchar",
    "esguinchada": "esguinchar",
    "esguinchadas": "esguinchar",
    "esguinchado": "esguinchar",
    "esguinchados": "esguinchar",
    "esguinchai": "esguinchar",
    "esguinchais": "esguinchar",
    "esguincham": "esguinchar",
    "esguinchamo": "esguinchar",
    "esguinchamos": "esguinchar",
    "esguinchando": "esguinchar",
    "esguinchara": "esguinchar",
    "esguincharam": "esguinchar",
    "esguincharas": "esguinchar",
    "esguincharde": "esguinchar",
    "esguinchardes": "esguinchar",
    "esguinchare": "esguinchar",
    "esguincharei": "esguinchar",
    "esguinchareis": "esguinchar",
    "esguincharem": "esguinchar",
    "esguincharemos": "esguinchar",
    "esguinchares": "esguinchar",
    "esguincharia": "esguinchar",
    "esguinchariam": "esguinchar",
    "esguincharias": "esguinchar",
    "esguincharmo": "esguinchar",
    "esguincharmos": "esguinchar",
    "esguinchará": "esguinchar",
    "esguincharás": "esguinchar",
    "esguincharão": "esguinchar",
    "esguincharíamos": "esguinchar",
    "esguincharíeis": "esguinchar",
    "esguinchas": "esguinchar",
    "esguinchasse": "esguinchar",
    "esguinchassem": "esguinchar",
    "esguinchasses": "esguinchar",
    "esguinchaste": "esguinchar",
    "esguinchastes": "esguinchar",
    "esguinchava": "esguinchar",
    "esguinchavam": "esguinchar",
    "esguinchavas": "esguinchar",
    "esguinche": "esguinchar",
    "esguinchei": "esguinchar",
    "esguincheis": "esguinchar",
    "esguinchem": "esguinchar",
    "esguinchemo": "esguinchar",
    "esguinchemos": "esguinchar",
    "esguinches": "esguinchar",
    "esguincho": "esguinchar",
    "esguinchou": "esguinchar",
    "esguinchá": "esguinchar",
    "esguinchámo": "esguinchar",
    "esguinchámos": "esguinchar",
    "esguincháramo": "esguinchar",
    "esguincháramos": "esguinchar",
    "esguinchárei": "esguinchar",
    "esguincháreis": "esguinchar",
    "esguinchásseis": "esguinchar",
    "esguinchássemos": "esguinchar",
    "esguinchávamo": "esguinchar",
    "esguinchávamos": "esguinchar",
    "esguinchávei": "esguinchar",
    "esguincháveis": "esguinchar",
    "esguio": "esguiar",
    "esguios": "esguio",
    "esguiou": "esguiar",
    "esguiá": "esguiar",
    "esguiámo": "esguiar",
    "esguiámos": "esguiar",
    "esguiáramo": "esguiar",
    "esguiáramos": "esguiar",
    "esguiárei": "esguiar",
    "esguiáreis": "esguiar",
    "esguiásseis": "esguiar",
    "esguiássemos": "esguiar",
    "esguiávamo": "esguiar",
    "esguiávamos": "esguiar",
    "esguiávei": "esguiar",
    "esguiáveis": "esguiar",
    "esguiões": "esguião",
    "esgunchos": "esguncho",
    "eslabões": "eslabão",
    "esladroa": "esladroar",
    "esladroada": "esladroar",
    "esladroadas": "esladroar",
    "esladroado": "esladroar",
    "esladroados": "esladroar",
    "esladroai": "esladroar",
    "esladroais": "esladroar",
    "esladroam": "esladroar",
    "esladroamentos": "esladroamento",
    "esladroamo": "esladroar",
    "esladroamos": "esladroar",
    "esladroando": "esladroar",
    "esladroara": "esladroar",
    "esladroaram": "esladroar",
    "esladroaras": "esladroar",
    "esladroarde": "esladroar",
    "esladroardes": "esladroar",
    "esladroare": "esladroar",
    "esladroarei": "esladroar",
    "esladroareis": "esladroar",
    "esladroarem": "esladroar",
    "esladroaremos": "esladroar",
    "esladroares": "esladroar",
    "esladroaria": "esladroar",
    "esladroariam": "esladroar",
    "esladroarias": "esladroar",
    "esladroarmo": "esladroar",
    "esladroarmos": "esladroar",
    "esladroará": "esladroar",
    "esladroarás": "esladroar",
    "esladroarão": "esladroar",
    "esladroaríamos": "esladroar",
    "esladroaríeis": "esladroar",
    "esladroas": "esladroar",
    "esladroasse": "esladroar",
    "esladroassem": "esladroar",
    "esladroasses": "esladroar",
    "esladroaste": "esladroar",
    "esladroastes": "esladroar",
    "esladroava": "esladroar",
    "esladroavam": "esladroar",
    "esladroavas": "esladroar",
    "esladroe": "esladroar",
    "esladroei": "esladroar",
    "esladroeis": "esladroar",
    "esladroem": "esladroar",
    "esladroemo": "esladroar",
    "esladroemos": "esladroar",
    "esladroes": "esladroar",
    "esladroo": "esladroar",
    "esladroou": "esladroar",
    "esladroá": "esladroar",
    "esladroámo": "esladroar",
    "esladroámos": "esladroar",
    "esladroáramo": "esladroar",
    "esladroáramos": "esladroar",
    "esladroárei": "esladroar",
    "esladroáreis": "esladroar",
    "esladroásseis": "esladroar",
    "esladroássemos": "esladroar",
    "esladroávamo": "esladroar",
    "esladroávamos": "esladroar",
    "esladroávei": "esladroar",
    "esladroáveis": "esladroar",
    "eslagarta": "eslagartar",
    "eslagartada": "eslagartar",
    "eslagartadas": "eslagartar",
    "eslagartado": "eslagartar",
    "eslagartadora": "eslagartador",
    "eslagartadoras": "eslagartador",
    "eslagartadores": "eslagartador",
    "eslagartados": "eslagartar",
    "eslagartai": "eslagartar",
    "eslagartais": "eslagartar",
    "eslagartam": "eslagartar",
    "eslagartamo": "eslagartar",
    "eslagartamos": "eslagartar",
    "eslagartando": "eslagartar",
    "eslagartara": "eslagartar",
    "eslagartaram": "eslagartar",
    "eslagartaras": "eslagartar",
    "eslagartarde": "eslagartar",
    "eslagartardes": "eslagartar",
    "eslagartare": "eslagartar",
    "eslagartarei": "eslagartar",
    "eslagartareis": "eslagartar",
    "eslagartarem": "eslagartar",
    "eslagartaremos": "eslagartar",
    "eslagartares": "eslagartar",
    "eslagartaria": "eslagartar",
    "eslagartariam": "eslagartar",
    "eslagartarias": "eslagartar",
    "eslagartarmo": "eslagartar",
    "eslagartarmos": "eslagartar",
    "eslagartará": "eslagartar",
    "eslagartarás": "eslagartar",
    "eslagartarão": "eslagartar",
    "eslagartaríamos": "eslagartar",
    "eslagartaríeis": "eslagartar",
    "eslagartas": "eslagartar",
    "eslagartasse": "eslagartar",
    "eslagartassem": "eslagartar",
    "eslagartasses": "eslagartar",
    "eslagartaste": "eslagartar",
    "eslagartastes": "eslagartar",
    "eslagartava": "eslagartar",
    "eslagartavam": "eslagartar",
    "eslagartavas": "eslagartar",
    "eslagarte": "eslagartar",
    "eslagartei": "eslagartar",
    "eslagarteis": "eslagartar",
    "eslagartem": "eslagartar",
    "eslagartemo": "eslagartar",
    "eslagartemos": "eslagartar",
    "eslagartes": "eslagartar",
    "eslagarto": "eslagartar",
    "eslagartou": "eslagartar",
    "eslagartá": "eslagartar",
    "eslagartámo": "eslagartar",
    "eslagartámos": "eslagartar",
    "eslagartáramo": "eslagartar",
    "eslagartáramos": "eslagartar",
    "eslagartárei": "eslagartar",
    "eslagartáreis": "eslagartar",
    "eslagartásseis": "eslagartar",
    "eslagartássemos": "eslagartar",
    "eslagartávamo": "eslagartar",
    "eslagartávamos": "eslagartar",
    "eslagartávei": "eslagartar",
    "eslagartáveis": "eslagartar",
    "eslarada": "eslarado",
    "eslaradas": "eslarado",
    "eslarados": "eslarado",
    "eslava": "eslavo",
    "eslavas": "eslavo",
    "eslavica": "eslavico",
    "eslavicas": "eslavico",
    "eslavicos": "eslavico",
    "eslavismos": "eslavismo",
    "eslavos": "eslavo",
    "eslavónica": "eslavónico",
    "eslavónicas": "eslavónico",
    "eslavónicos": "eslavónico",
    "eslazeirada": "eslazeirado",
    "eslazeiradas": "eslazeirado",
    "eslazeirados": "eslazeirado",
    "eslinga": "eslingar",
    "eslingada": "eslingar",
    "eslingadas": "eslingar",
    "eslingado": "eslingar",
    "eslingados": "eslingar",
    "eslingai": "eslingar",
    "eslingais": "eslingar",
    "eslingam": "eslingar",
    "eslingamo": "eslingar",
    "eslingamos": "eslingar",
    "eslingando": "eslingar",
    "eslingara": "eslingar",
    "eslingaram": "eslingar",
    "eslingaras": "eslingar",
    "eslingarde": "eslingar",
    "eslingardes": "eslingar",
    "eslingare": "eslingar",
    "eslingarei": "eslingar",
    "eslingareis": "eslingar",
    "eslingarem": "eslingar",
    "eslingaremos": "eslingar",
    "eslingares": "eslingar",
    "eslingaria": "eslingar",
    "eslingariam": "eslingar",
    "eslingarias": "eslingar",
    "eslingarmo": "eslingar",
    "eslingarmos": "eslingar",
    "eslingará": "eslingar",
    "eslingarás": "eslingar",
    "eslingarão": "eslingar",
    "eslingaríamos": "eslingar",
    "eslingaríeis": "eslingar",
    "eslingas": "eslingar",
    "eslingasse": "eslingar",
    "eslingassem": "eslingar",
    "eslingasses": "eslingar",
    "eslingaste": "eslingar",
    "eslingastes": "eslingar",
    "eslingava": "eslingar",
    "eslingavam": "eslingar",
    "eslingavas": "eslingar",
    "eslingo": "eslingar",
    "eslingou": "eslingar",
    "eslingue": "eslingar",
    "eslinguei": "eslingar",
    "eslingueis": "eslingar",
    "eslinguem": "eslingar",
    "eslinguemo": "eslingar",
    "eslinguemos": "eslingar",
    "eslingues": "eslingar",
    "eslingá": "eslingar",
    "eslingámo": "eslingar",
    "eslingámos": "eslingar",
    "eslingáramo": "eslingar",
    "eslingáramos": "eslingar",
    "eslingárei": "eslingar",
    "eslingáreis": "eslingar",
    "eslingásseis": "eslingar",
    "eslingássemos": "eslingar",
    "eslingávamo": "eslingar",
    "eslingávamos": "eslingar",
    "eslingávei": "eslingar",
    "eslingáveis": "eslingar",
    "eslovaca": "eslovaco",
    "eslovacas": "eslovaco",
    "eslovacos": "eslovaco",
    "eslovena": "esloveno",
    "eslovenas": "esloveno",
    "eslovenos": "esloveno",
    "eslovénia": "eslovénio",
    "eslovénias": "eslovénio",
    "eslovénica": "eslovénico",
    "eslovénicas": "eslovénico",
    "eslovénicos": "eslovénico",
    "eslovénios": "eslovénio",
    "eslávica": "eslávico",
    "eslávicas": "eslávico",
    "eslávicos": "eslávico",
    "esma": "esmar",
    "esmada": "esmar",
    "esmadas": "esmar",
    "esmado": "esmar",
    "esmados": "esmar",
    "esmadriga": "esmadrigar",
    "esmadrigada": "esmadrigar",
    "esmadrigadas": "esmadrigar",
    "esmadrigado": "esmadrigar",
    "esmadrigados": "esmadrigar",
    "esmadrigai": "esmadrigar",
    "esmadrigais": "esmadrigar",
    "esmadrigam": "esmadrigar",
    "esmadrigamo": "esmadrigar",
    "esmadrigamos": "esmadrigar",
    "esmadrigando": "esmadrigar",
    "esmadrigara": "esmadrigar",
    "esmadrigaram": "esmadrigar",
    "esmadrigaras": "esmadrigar",
    "esmadrigarde": "esmadrigar",
    "esmadrigardes": "esmadrigar",
    "esmadrigare": "esmadrigar",
    "esmadrigarei": "esmadrigar",
    "esmadrigareis": "esmadrigar",
    "esmadrigarem": "esmadrigar",
    "esmadrigaremos": "esmadrigar",
    "esmadrigares": "esmadrigar",
    "esmadrigaria": "esmadrigar",
    "esmadrigariam": "esmadrigar",
    "esmadrigarias": "esmadrigar",
    "esmadrigarmo": "esmadrigar",
    "esmadrigarmos": "esmadrigar",
    "esmadrigará": "esmadrigar",
    "esmadrigarás": "esmadrigar",
    "esmadrigarão": "esmadrigar",
    "esmadrigaríamos": "esmadrigar",
    "esmadrigaríeis": "esmadrigar",
    "esmadrigas": "esmadrigar",
    "esmadrigasse": "esmadrigar",
    "esmadrigassem": "esmadrigar",
    "esmadrigasses": "esmadrigar",
    "esmadrigaste": "esmadrigar",
    "esmadrigastes": "esmadrigar",
    "esmadrigava": "esmadrigar",
    "esmadrigavam": "esmadrigar",
    "esmadrigavas": "esmadrigar",
    "esmadrigo": "esmadrigar",
    "esmadrigou": "esmadrigar",
    "esmadrigue": "esmadrigar",
    "esmadriguei": "esmadrigar",
    "esmadrigueis": "esmadrigar",
    "esmadriguem": "esmadrigar",
    "esmadriguemo": "esmadrigar",
    "esmadriguemos": "esmadrigar",
    "esmadrigues": "esmadrigar",
    "esmadrigá": "esmadrigar",
    "esmadrigámo": "esmadrigar",
    "esmadrigámos": "esmadrigar",
    "esmadrigáramo": "esmadrigar",
    "esmadrigáramos": "esmadrigar",
    "esmadrigárei": "esmadrigar",
    "esmadrigáreis": "esmadrigar",
    "esmadrigásseis": "esmadrigar",
    "esmadrigássemos": "esmadrigar",
    "esmadrigávamo": "esmadrigar",
    "esmadrigávamos": "esmadrigar",
    "esmadrigávei": "esmadrigar",
    "esmadrigáveis": "esmadrigar",
    "esmaece": "esmaecer",
    "esmaecei": "esmaecer",
    "esmaeceis": "esmaecer",
    "esmaecem": "esmaecer",
    "esmaecemo": "esmaecer",
    "esmaecemos": "esmaecer",
    "esmaecendo": "esmaecer",
    "esmaecera": "esmaecer",
    "esmaeceram": "esmaecer",
    "esmaeceras": "esmaecer",
    "esmaecerdes": "esmaecer",
    "esmaecerei": "esmaecer",
    "esmaecereis": "esmaecer",
    "esmaecerem": "esmaecer",
    "esmaeceremos": "esmaecer",
    "esmaeceres": "esmaecer",
    "esmaeceria": "esmaecer",
    "esmaeceriam": "esmaecer",
    "esmaecerias": "esmaecer",
    "esmaecermo": "esmaecer",
    "esmaecermos": "esmaecer",
    "esmaecerá": "esmaecer",
    "esmaecerás": "esmaecer",
    "esmaecerão": "esmaecer",
    "esmaeceríamos": "esmaecer",
    "esmaeceríeis": "esmaecer",
    "esmaeces": "esmaecer",
    "esmaecesse": "esmaecer",
    "esmaecessem": "esmaecer",
    "esmaecesses": "esmaecer",
    "esmaeceste": "esmaecer",
    "esmaecestes": "esmaecer",
    "esmaeceu": "esmaecer",
    "esmaeci": "esmaecer",
    "esmaecia": "esmaecer",
    "esmaeciam": "esmaecer",
    "esmaecias": "esmaecer",
    "esmaecida": "esmaecido",
    "esmaecidas": "esmaecido",
    "esmaecido": "esmaecer",
    "esmaecidos": "esmaecido",
    "esmaecimentos": "esmaecimento",
    "esmaecêramo": "esmaecer",
    "esmaecêramos": "esmaecer",
    "esmaecêreis": "esmaecer",
    "esmaecêsseis": "esmaecer",
    "esmaecêssemos": "esmaecer",
    "esmaecíamo": "esmaecer",
    "esmaecíamos": "esmaecer",
    "esmaecíeis": "esmaecer",
    "esmaeça": "esmaecer",
    "esmaeçais": "esmaecer",
    "esmaeçam": "esmaecer",
    "esmaeçamo": "esmaecer",
    "esmaeçamos": "esmaecer",
    "esmaeças": "esmaecer",
    "esmaeço": "esmaecer",
    "esmaga": "esmagar",
    "esmagacha": "esmagachar",
    "esmagachada": "esmagachar",
    "esmagachadas": "esmagachar",
    "esmagachado": "esmagachar",
    "esmagachados": "esmagachar",
    "esmagachai": "esmagachar",
    "esmagachais": "esmagachar",
    "esmagacham": "esmagachar",
    "esmagachamo": "esmagachar",
    "esmagachamos": "esmagachar",
    "esmagachando": "esmagachar",
    "esmagachara": "esmagachar",
    "esmagacharam": "esmagachar",
    "esmagacharas": "esmagachar",
    "esmagacharde": "esmagachar",
    "esmagachardes": "esmagachar",
    "esmagachare": "esmagachar",
    "esmagacharei": "esmagachar",
    "esmagachareis": "esmagachar",
    "esmagacharem": "esmagachar",
    "esmagacharemos": "esmagachar",
    "esmagachares": "esmagachar",
    "esmagacharia": "esmagachar",
    "esmagachariam": "esmagachar",
    "esmagacharias": "esmagachar",
    "esmagacharmo": "esmagachar",
    "esmagacharmos": "esmagachar",
    "esmagachará": "esmagachar",
    "esmagacharás": "esmagachar",
    "esmagacharão": "esmagachar",
    "esmagacharíamos": "esmagachar",
    "esmagacharíeis": "esmagachar",
    "esmagachas": "esmagachar",
    "esmagachasse": "esmagachar",
    "esmagachassem": "esmagachar",
    "esmagachasses": "esmagachar",
    "esmagachaste": "esmagachar",
    "esmagachastes": "esmagachar",
    "esmagachava": "esmagachar",
    "esmagachavam": "esmagachar",
    "esmagachavas": "esmagachar",
    "esmagache": "esmagachar",
    "esmagachei": "esmagachar",
    "esmagacheis": "esmagachar",
    "esmagachem": "esmagachar",
    "esmagachemo": "esmagachar",
    "esmagachemos": "esmagachar",
    "esmagaches": "esmagachar",
    "esmagacho": "esmagachar",
    "esmagachou": "esmagachar",
    "esmagachá": "esmagachar",
    "esmagachámo": "esmagachar",
    "esmagachámos": "esmagachar",
    "esmagacháramo": "esmagachar",
    "esmagacháramos": "esmagachar",
    "esmagachárei": "esmagachar",
    "esmagacháreis": "esmagachar",
    "esmagachásseis": "esmagachar",
    "esmagachássemos": "esmagachar",
    "esmagachávamo": "esmagachar",
    "esmagachávamos": "esmagachar",
    "esmagachávei": "esmagachar",
    "esmagacháveis": "esmagachar",
    "esmagada": "esmagar",
    "esmagadas": "esmagar",
    "esmagadelas": "esmagadela",
    "esmagado": "esmagar",
    "esmagadora": "esmagador",
    "esmagadoras": "esmagador",
    "esmagadores": "esmagador",
    "esmagados": "esmagar",
    "esmagaduras": "esmagadura",
    "esmagai": "esmagar",
    "esmagais": "esmagar",
    "esmagam": "esmagar",
    "esmagamentos": "esmagamento",
    "esmagamo": "esmagar",
    "esmagamos": "esmagar",
    "esmagando": "esmagar",
    "esmagara": "esmagar",
    "esmagaram": "esmagar",
    "esmagaras": "esmagar",
    "esmagarde": "esmagar",
    "esmagardes": "esmagar",
    "esmagare": "esmagar",
    "esmagarei": "esmagar",
    "esmagareis": "esmagar",
    "esmagarem": "esmagar",
    "esmagaremos": "esmagar",
    "esmagares": "esmagar",
    "esmagaria": "esmagar",
    "esmagariam": "esmagar",
    "esmagarias": "esmagar",
    "esmagarmo": "esmagar",
    "esmagarmos": "esmagar",
    "esmagará": "esmagar",
    "esmagarás": "esmagar",
    "esmagarão": "esmagar",
    "esmagaríamos": "esmagar",
    "esmagaríeis": "esmagar",
    "esmagas": "esmagar",
    "esmagasse": "esmagar",
    "esmagassem": "esmagar",
    "esmagasses": "esmagar",
    "esmagaste": "esmagar",
    "esmagastes": "esmagar",
    "esmagava": "esmagar",
    "esmagavam": "esmagar",
    "esmagavas": "esmagar",
    "esmagações": "esmagação",
    "esmago": "esmagar",
    "esmagou": "esmagar",
    "esmagruiçada": "esmagruiçado",
    "esmagruiçadas": "esmagruiçado",
    "esmagruiçados": "esmagruiçado",
    "esmague": "esmagar",
    "esmaguei": "esmagar",
    "esmagueis": "esmagar",
    "esmaguem": "esmagar",
    "esmaguemo": "esmagar",
    "esmaguemos": "esmagar",
    "esmagues": "esmagar",
    "esmagá": "esmagar",
    "esmagámo": "esmagar",
    "esmagámos": "esmagar",
    "esmagáramo": "esmagar",
    "esmagáramos": "esmagar",
    "esmagárei": "esmagar",
    "esmagáreis": "esmagar",
    "esmagásseis": "esmagar",
    "esmagássemos": "esmagar",
    "esmagávamo": "esmagar",
    "esmagávamos": "esmagar",
    "esmagávei": "esmagar",
    "esmagáveis": "esmagável",
    "esmai": "esmar",
    "esmaia": "esmaiar",
    "esmaiada": "esmaiar",
    "esmaiadas": "esmaiar",
    "esmaiado": "esmaiar",
    "esmaiados": "esmaiar",
    "esmaiai": "esmaiar",
    "esmaiais": "esmaiar",
    "esmaiam": "esmaiar",
    "esmaiamo": "esmaiar",
    "esmaiamos": "esmaiar",
    "esmaiando": "esmaiar",
    "esmaiara": "esmaiar",
    "esmaiaram": "esmaiar",
    "esmaiaras": "esmaiar",
    "esmaiardes": "esmaiar",
    "esmaiarei": "esmaiar",
    "esmaiareis": "esmaiar",
    "esmaiarem": "esmaiar",
    "esmaiaremos": "esmaiar",
    "esmaiares": "esmaiar",
    "esmaiaria": "esmaiar",
    "esmaiariam": "esmaiar",
    "esmaiarias": "esmaiar",
    "esmaiarmo": "esmaiar",
    "esmaiarmos": "esmaiar",
    "esmaiará": "esmaiar",
    "esmaiarás": "esmaiar",
    "esmaiarão": "esmaiar",
    "esmaiaríamos": "esmaiar",
    "esmaiaríeis": "esmaiar",
    "esmaias": "esmaiar",
    "esmaiasse": "esmaiar",
    "esmaiassem": "esmaiar",
    "esmaiasses": "esmaiar",
    "esmaiaste": "esmaiar",
    "esmaiastes": "esmaiar",
    "esmaiava": "esmaiar",
    "esmaiavam": "esmaiar",
    "esmaiavas": "esmaiar",
    "esmaie": "esmaiar",
    "esmaiei": "esmaiar",
    "esmaieis": "esmaiar",
    "esmaiem": "esmaiar",
    "esmaiemo": "esmaiar",
    "esmaiemos": "esmaiar",
    "esmaies": "esmaiar",
    "esmaio": "esmaiar",
    "esmaiou": "esmaiar",
    "esmais": "esmar",
    "esmaiámo": "esmaiar",
    "esmaiámos": "esmaiar",
    "esmaiáramo": "esmaiar",
    "esmaiáramos": "esmaiar",
    "esmaiáreis": "esmaiar",
    "esmaiásseis": "esmaiar",
    "esmaiássemos": "esmaiar",
    "esmaiávamo": "esmaiar",
    "esmaiávamos": "esmaiar",
    "esmaiáveis": "esmaiar",
    "esmaleitada": "esmaleitado",
    "esmaleitadas": "esmaleitado",
    "esmaleitados": "esmaleitado",
    "esmalta": "esmaltar",
    "esmaltada": "esmaltar",
    "esmaltadas": "esmaltar",
    "esmaltado": "esmaltar",
    "esmaltadora": "esmaltador",
    "esmaltadoras": "esmaltador",
    "esmaltadores": "esmaltador",
    "esmaltados": "esmaltar",
    "esmaltagens": "esmaltagem",
    "esmaltai": "esmaltar",
    "esmaltais": "esmaltar",
    "esmaltam": "esmaltar",
    "esmaltamo": "esmaltar",
    "esmaltamos": "esmaltar",
    "esmaltando": "esmaltar",
    "esmaltara": "esmaltar",
    "esmaltaram": "esmaltar",
    "esmaltaras": "esmaltar",
    "esmaltarde": "esmaltar",
    "esmaltardes": "esmaltar",
    "esmaltare": "esmaltar",
    "esmaltarei": "esmaltar",
    "esmaltareis": "esmaltar",
    "esmaltarem": "esmaltar",
    "esmaltaremos": "esmaltar",
    "esmaltares": "esmaltar",
    "esmaltaria": "esmaltar",
    "esmaltariam": "esmaltar",
    "esmaltarias": "esmaltar",
    "esmaltarmo": "esmaltar",
    "esmaltarmos": "esmaltar",
    "esmaltará": "esmaltar",
    "esmaltarás": "esmaltar",
    "esmaltarão": "esmaltar",
    "esmaltaríamos": "esmaltar",
    "esmaltaríeis": "esmaltar",
    "esmaltas": "esmaltar",
    "esmaltasse": "esmaltar",
    "esmaltassem": "esmaltar",
    "esmaltasses": "esmaltar",
    "esmaltaste": "esmaltar",
    "esmaltastes": "esmaltar",
    "esmaltava": "esmaltar",
    "esmaltavam": "esmaltar",
    "esmaltavas": "esmaltar",
    "esmaltações": "esmaltação",
    "esmalte": "esmaltar",
    "esmaltei": "esmaltar",
    "esmalteis": "esmaltar",
    "esmaltem": "esmaltar",
    "esmaltemo": "esmaltar",
    "esmaltemos": "esmaltar",
    "esmaltes": "esmalte",
    "esmaltinas": "esmaltina",
    "esmaltites": "esmaltite",
    "esmalto": "esmaltar",
    "esmaltou": "esmaltar",
    "esmaltá": "esmaltar",
    "esmaltámo": "esmaltar",
    "esmaltámos": "esmaltar",
    "esmaltáramo": "esmaltar",
    "esmaltáramos": "esmaltar",
    "esmaltárei": "esmaltar",
    "esmaltáreis": "esmaltar",
    "esmaltásseis": "esmaltar",
    "esmaltássemos": "esmaltar",
    "esmaltávamo": "esmaltar",
    "esmaltávamos": "esmaltar",
    "esmaltávei": "esmaltar",
    "esmaltáveis": "esmaltável",
    "esmam": "esmar",
    "esmamalhadas": "esmamalhada",
    "esmamaçadas": "esmamaçada",
    "esmamo": "esmar",
    "esmamona": "esmamonar",
    "esmamonada": "esmamonar",
    "esmamonadas": "esmamonar",
    "esmamonado": "esmamonar",
    "esmamonados": "esmamonar",
    "esmamonai": "esmamonar",
    "esmamonais": "esmamonar",
    "esmamonam": "esmamonar",
    "esmamonamo": "esmamonar",
    "esmamonamos": "esmamonar",
    "esmamonando": "esmamonar",
    "esmamonara": "esmamonar",
    "esmamonaram": "esmamonar",
    "esmamonaras": "esmamonar",
    "esmamonarde": "esmamonar",
    "esmamonardes": "esmamonar",
    "esmamonare": "esmamonar",
    "esmamonarei": "esmamonar",
    "esmamonareis": "esmamonar",
    "esmamonarem": "esmamonar",
    "esmamonaremos": "esmamonar",
    "esmamonares": "esmamonar",
    "esmamonaria": "esmamonar",
    "esmamonariam": "esmamonar",
    "esmamonarias": "esmamonar",
    "esmamonarmo": "esmamonar",
    "esmamonarmos": "esmamonar",
    "esmamonará": "esmamonar",
    "esmamonarás": "esmamonar",
    "esmamonarão": "esmamonar",
    "esmamonaríamos": "esmamonar",
    "esmamonaríeis": "esmamonar",
    "esmamonas": "esmamonar",
    "esmamonasse": "esmamonar",
    "esmamonassem": "esmamonar",
    "esmamonasses": "esmamonar",
    "esmamonaste": "esmamonar",
    "esmamonastes": "esmamonar",
    "esmamonava": "esmamonar",
    "esmamonavam": "esmamonar",
    "esmamonavas": "esmamonar",
    "esmamone": "esmamonar",
    "esmamonei": "esmamonar",
    "esmamoneis": "esmamonar",
    "esmamonem": "esmamonar",
    "esmamonemo": "esmamonar",
    "esmamonemos": "esmamonar",
    "esmamones": "esmamonar",
    "esmamono": "esmamonar",
    "esmamonou": "esmamonar",
    "esmamoná": "esmamonar",
    "esmamonámo": "esmamonar",
    "esmamonámos": "esmamonar",
    "esmamonáramo": "esmamonar",
    "esmamonáramos": "esmamonar",
    "esmamonárei": "esmamonar",
    "esmamonáreis": "esmamonar",
    "esmamonásseis": "esmamonar",
    "esmamonássemos": "esmamonar",
    "esmamonávamo": "esmamonar",
    "esmamonávamos": "esmamonar",
    "esmamonávei": "esmamonar",
    "esmamonáveis": "esmamonar",
    "esmamos": "esmar",
    "esmando": "esmar",
    "esmania": "esmaniar",
    "esmaniada": "esmaniar",
    "esmaniadas": "esmaniar",
    "esmaniado": "esmaniar",
    "esmaniados": "esmaniar",
    "esmaniai": "esmaniar",
    "esmaniais": "esmaniar",
    "esmaniam": "esmaniar",
    "esmaniamo": "esmaniar",
    "esmaniamos": "esmaniar",
    "esmaniando": "esmaniar",
    "esmaniara": "esmaniar",
    "esmaniaram": "esmaniar",
    "esmaniaras": "esmaniar",
    "esmaniardes": "esmaniar",
    "esmaniarei": "esmaniar",
    "esmaniareis": "esmaniar",
    "esmaniarem": "esmaniar",
    "esmaniaremos": "esmaniar",
    "esmaniares": "esmaniar",
    "esmaniaria": "esmaniar",
    "esmaniariam": "esmaniar",
    "esmaniarias": "esmaniar",
    "esmaniarmo": "esmaniar",
    "esmaniarmos": "esmaniar",
    "esmaniará": "esmaniar",
    "esmaniarás": "esmaniar",
    "esmaniarão": "esmaniar",
    "esmaniaríamos": "esmaniar",
    "esmaniaríeis": "esmaniar",
    "esmanias": "esmaniar",
    "esmaniasse": "esmaniar",
    "esmaniassem": "esmaniar",
    "esmaniasses": "esmaniar",
    "esmaniaste": "esmaniar",
    "esmaniastes": "esmaniar",
    "esmaniava": "esmaniar",
    "esmaniavam": "esmaniar",
    "esmaniavas": "esmaniar",
    "esmanie": "esmaniar",
    "esmaniei": "esmaniar",
    "esmanieis": "esmaniar",
    "esmaniem": "esmaniar",
    "esmaniemo": "esmaniar",
    "esmaniemos": "esmaniar",
    "esmanies": "esmaniar",
    "esmanio": "esmaniar",
    "esmaniou": "esmaniar",
    "esmaniámo": "esmaniar",
    "esmaniámos": "esmaniar",
    "esmaniáramo": "esmaniar",
    "esmaniáramos": "esmaniar",
    "esmaniáreis": "esmaniar",
    "esmaniásseis": "esmaniar",
    "esmaniássemos": "esmaniar",
    "esmaniávamo": "esmaniar",
    "esmaniávamos": "esmaniar",
    "esmaniáveis": "esmaniar",
    "esmanja": "esmanjar",
    "esmanjada": "esmanjar",
    "esmanjadas": "esmanjar",
    "esmanjado": "esmanjar",
    "esmanjados": "esmanjar",
    "esmanjai": "esmanjar",
    "esmanjais": "esmanjar",
    "esmanjam": "esmanjar",
    "esmanjamo": "esmanjar",
    "esmanjamos": "esmanjar",
    "esmanjando": "esmanjar",
    "esmanjara": "esmanjar",
    "esmanjaram": "esmanjar",
    "esmanjaras": "esmanjar",
    "esmanjarde": "esmanjar",
    "esmanjardes": "esmanjar",
    "esmanjare": "esmanjar",
    "esmanjarei": "esmanjar",
    "esmanjareis": "esmanjar",
    "esmanjarem": "esmanjar",
    "esmanjaremos": "esmanjar",
    "esmanjares": "esmanjar",
    "esmanjaria": "esmanjar",
    "esmanjariam": "esmanjar",
    "esmanjarias": "esmanjar",
    "esmanjarmo": "esmanjar",
    "esmanjarmos": "esmanjar",
    "esmanjará": "esmanjar",
    "esmanjarás": "esmanjar",
    "esmanjarão": "esmanjar",
    "esmanjaríamos": "esmanjar",
    "esmanjaríeis": "esmanjar",
    "esmanjas": "esmanjar",
    "esmanjasse": "esmanjar",
    "esmanjassem": "esmanjar",
    "esmanjasses": "esmanjar",
    "esmanjaste": "esmanjar",
    "esmanjastes": "esmanjar",
    "esmanjava": "esmanjar",
    "esmanjavam": "esmanjar",
    "esmanjavas": "esmanjar",
    "esmanje": "esmanjar",
    "esmanjei": "esmanjar",
    "esmanjeis": "esmanjar",
    "esmanjem": "esmanjar",
    "esmanjemo": "esmanjar",
    "esmanjemos": "esmanjar",
    "esmanjes": "esmanjar",
    "esmanjo": "esmanjar",
    "esmanjou": "esmanjar",
    "esmanjá": "esmanjar",
    "esmanjámo": "esmanjar",
    "esmanjámos": "esmanjar",
    "esmanjáramo": "esmanjar",
    "esmanjáramos": "esmanjar",
    "esmanjárei": "esmanjar",
    "esmanjáreis": "esmanjar",
    "esmanjásseis": "esmanjar",
    "esmanjássemos": "esmanjar",
    "esmanjávamo": "esmanjar",
    "esmanjávamos": "esmanjar",
    "esmanjávei": "esmanjar",
    "esmanjáveis": "esmanjar",
    "esmara": "esmar",
    "esmaram": "esmar",
    "esmaras": "esmar",
    "esmarde": "esmar",
    "esmardes": "esmar",
    "esmare": "esmar",
    "esmarei": "esmar",
    "esmareis": "esmar",
    "esmarelida": "esmarelido",
    "esmarelidas": "esmarelido",
    "esmarelidos": "esmarelido",
    "esmarem": "esmar",
    "esmaremos": "esmar",
    "esmares": "esmar",
    "esmaria": "esmar",
    "esmariam": "esmar",
    "esmarias": "esmar",
    "esmarmo": "esmar",
    "esmarmos": "esmar",
    "esmarra": "esmarrir",
    "esmarrais": "esmarrir",
    "esmarram": "esmarrir",
    "esmarramo": "esmarrir",
    "esmarramos": "esmarrir",
    "esmarras": "esmarrir",
    "esmarre": "esmarrir",
    "esmarrem": "esmarrir",
    "esmarres": "esmarrir",
    "esmarri": "esmarrir",
    "esmarria": "esmarrir",
    "esmarriam": "esmarrir",
    "esmarrias": "esmarrir",
    "esmarrida": "esmarrir",
    "esmarridas": "esmarrir",
    "esmarrido": "esmarrir",
    "esmarridos": "esmarrir",
    "esmarrimo": "esmarrir",
    "esmarrimos": "esmarrir",
    "esmarrindo": "esmarrir",
    "esmarrira": "esmarrir",
    "esmarriram": "esmarrir",
    "esmarriras": "esmarrir",
    "esmarrirdes": "esmarrir",
    "esmarrirei": "esmarrir",
    "esmarrireis": "esmarrir",
    "esmarrirem": "esmarrir",
    "esmarriremos": "esmarrir",
    "esmarrires": "esmarrir",
    "esmarriria": "esmarrir",
    "esmarririam": "esmarrir",
    "esmarririas": "esmarrir",
    "esmarrirmo": "esmarrir",
    "esmarrirmos": "esmarrir",
    "esmarrirá": "esmarrir",
    "esmarrirás": "esmarrir",
    "esmarrirão": "esmarrir",
    "esmarriríamos": "esmarrir",
    "esmarriríeis": "esmarrir",
    "esmarris": "esmarrir",
    "esmarrisse": "esmarrir",
    "esmarrissem": "esmarrir",
    "esmarrisses": "esmarrir",
    "esmarriste": "esmarrir",
    "esmarristes": "esmarrir",
    "esmarriu": "esmarrir",
    "esmarro": "esmarrir",
    "esmarroa": "esmarroar",
    "esmarroada": "esmarroar",
    "esmarroadas": "esmarroar",
    "esmarroado": "esmarroar",
    "esmarroados": "esmarroar",
    "esmarroai": "esmarroar",
    "esmarroais": "esmarroar",
    "esmarroam": "esmarroar",
    "esmarroamo": "esmarroar",
    "esmarroamos": "esmarroar",
    "esmarroando": "esmarroar",
    "esmarroara": "esmarroar",
    "esmarroaram": "esmarroar",
    "esmarroaras": "esmarroar",
    "esmarroarde": "esmarroar",
    "esmarroardes": "esmarroar",
    "esmarroare": "esmarroar",
    "esmarroarei": "esmarroar",
    "esmarroareis": "esmarroar",
    "esmarroarem": "esmarroar",
    "esmarroaremos": "esmarroar",
    "esmarroares": "esmarroar",
    "esmarroaria": "esmarroar",
    "esmarroariam": "esmarroar",
    "esmarroarias": "esmarroar",
    "esmarroarmo": "esmarroar",
    "esmarroarmos": "esmarroar",
    "esmarroará": "esmarroar",
    "esmarroarás": "esmarroar",
    "esmarroarão": "esmarroar",
    "esmarroaríamos": "esmarroar",
    "esmarroaríeis": "esmarroar",
    "esmarroas": "esmarroar",
    "esmarroasse": "esmarroar",
    "esmarroassem": "esmarroar",
    "esmarroasses": "esmarroar",
    "esmarroaste": "esmarroar",
    "esmarroastes": "esmarroar",
    "esmarroava": "esmarroar",
    "esmarroavam": "esmarroar",
    "esmarroavas": "esmarroar",
    "esmarroe": "esmarroar",
    "esmarroei": "esmarroar",
    "esmarroeis": "esmarroar",
    "esmarroem": "esmarroar",
    "esmarroemo": "esmarroar",
    "esmarroemos": "esmarroar",
    "esmarroes": "esmarroar",
    "esmarroo": "esmarroar",
    "esmarroou": "esmarroar",
    "esmarroá": "esmarroar",
    "esmarroámo": "esmarroar",
    "esmarroámos": "esmarroar",
    "esmarroáramo": "esmarroar",
    "esmarroáramos": "esmarroar",
    "esmarroárei": "esmarroar",
    "esmarroáreis": "esmarroar",
    "esmarroásseis": "esmarroar",
    "esmarroássemos": "esmarroar",
    "esmarroávamo": "esmarroar",
    "esmarroávamos": "esmarroar",
    "esmarroávei": "esmarroar",
    "esmarroáveis": "esmarroar",
    "esmarríamo": "esmarrir",
    "esmarríamos": "esmarrir",
    "esmarríeis": "esmarrir",
    "esmarríramo": "esmarrir",
    "esmarríramos": "esmarrir",
    "esmarríreis": "esmarrir",
    "esmarrísseis": "esmarrir",
    "esmarríssemos": "esmarrir",
    "esmará": "esmar",
    "esmarás": "esmar",
    "esmarão": "esmar",
    "esmaríamos": "esmar",
    "esmaríeis": "esmar",
    "esmas": "esmar",
    "esmasse": "esmar",
    "esmassem": "esmar",
    "esmasses": "esmar",
    "esmaste": "esmar",
    "esmastes": "esmar",
    "esmava": "esmar",
    "esmavam": "esmar",
    "esmavas": "esmar",
    "esme": "esmar",
    "esmeada": "esmear",
    "esmeadas": "esmear",
    "esmeado": "esmear",
    "esmeados": "esmear",
    "esmeai": "esmear",
    "esmeais": "esmear",
    "esmeamo": "esmear",
    "esmeamos": "esmear",
    "esmeando": "esmear",
    "esmeara": "esmear",
    "esmearam": "esmear",
    "esmearas": "esmear",
    "esmearde": "esmear",
    "esmeardes": "esmear",
    "esmeare": "esmear",
    "esmearei": "esmear",
    "esmeareis": "esmear",
    "esmearem": "esmear",
    "esmearemos": "esmear",
    "esmeares": "esmear",
    "esmearia": "esmear",
    "esmeariam": "esmear",
    "esmearias": "esmear",
    "esmearmo": "esmear",
    "esmearmos": "esmear",
    "esmeará": "esmear",
    "esmearás": "esmear",
    "esmearão": "esmear",
    "esmearíamos": "esmear",
    "esmearíeis": "esmear",
    "esmeasse": "esmear",
    "esmeassem": "esmear",
    "esmeasses": "esmear",
    "esmeaste": "esmear",
    "esmeastes": "esmear",
    "esmeava": "esmear",
    "esmeavam": "esmear",
    "esmeavas": "esmear",
    "esmecha": "esmechar",
    "esmechada": "esmechar",
    "esmechadas": "esmechar",
    "esmechado": "esmechar",
    "esmechados": "esmechar",
    "esmechai": "esmechar",
    "esmechais": "esmechar",
    "esmecham": "esmechar",
    "esmechamo": "esmechar",
    "esmechamos": "esmechar",
    "esmechando": "esmechar",
    "esmechara": "esmechar",
    "esmecharam": "esmechar",
    "esmecharas": "esmechar",
    "esmecharde": "esmechar",
    "esmechardes": "esmechar",
    "esmechare": "esmechar",
    "esmecharei": "esmechar",
    "esmechareis": "esmechar",
    "esmecharem": "esmechar",
    "esmecharemos": "esmechar",
    "esmechares": "esmechar",
    "esmecharia": "esmechar",
    "esmechariam": "esmechar",
    "esmecharias": "esmechar",
    "esmecharmo": "esmechar",
    "esmecharmos": "esmechar",
    "esmechará": "esmechar",
    "esmecharás": "esmechar",
    "esmecharão": "esmechar",
    "esmecharíamos": "esmechar",
    "esmecharíeis": "esmechar",
    "esmechas": "esmechar",
    "esmechasse": "esmechar",
    "esmechassem": "esmechar",
    "esmechasses": "esmechar",
    "esmechaste": "esmechar",
    "esmechastes": "esmechar",
    "esmechava": "esmechar",
    "esmechavam": "esmechar",
    "esmechavas": "esmechar",
    "esmeche": "esmechar",
    "esmechei": "esmechar",
    "esmecheis": "esmechar",
    "esmechem": "esmechar",
    "esmechemo": "esmechar",
    "esmechemos": "esmechar",
    "esmeches": "esmechar",
    "esmecho": "esmechar",
    "esmechou": "esmechar",
    "esmechá": "esmechar",
    "esmechámo": "esmechar",
    "esmechámos": "esmechar",
    "esmecháramo": "esmechar",
    "esmecháramos": "esmechar",
    "esmechárei": "esmechar",
    "esmecháreis": "esmechar",
    "esmechásseis": "esmechar",
    "esmechássemos": "esmechar",
    "esmechávamo": "esmechar",
    "esmechávamos": "esmechar",
    "esmechávei": "esmechar",
    "esmecháveis": "esmechar",
    "esmeei": "esmear",
    "esmeeis": "esmear",
    "esmeemo": "esmear",
    "esmeemos": "esmear",
    "esmegmas": "esmegma",
    "esmegmática": "esmegmático",
    "esmegmáticas": "esmegmático",
    "esmegmáticos": "esmegmático",
    "esmei": "esmar",
    "esmeia": "esmear",
    "esmeiam": "esmear",
    "esmeias": "esmear",
    "esmeie": "esmear",
    "esmeiem": "esmear",
    "esmeies": "esmear",
    "esmeio": "esmear",
    "esmeis": "esmar",
    "esmem": "esmar",
    "esmemo": "esmar",
    "esmemos": "esmar",
    "esmeou": "esmear",
    "esmera": "esmerar",
    "esmerada": "esmerar",
    "esmeradas": "esmerar",
    "esmerado": "esmerar",
    "esmerados": "esmerar",
    "esmeradíssima": "esmerado",
    "esmeradíssimas": "esmerado",
    "esmeradíssimo": "esmerado",
    "esmeradíssimos": "esmerado",
    "esmerai": "esmerar",
    "esmerais": "esmerar",
    "esmeraldas": "esmeralda",
    "esmeraldeada": "esmeraldear",
    "esmeraldeadas": "esmeraldear",
    "esmeraldeado": "esmeraldear",
    "esmeraldeados": "esmeraldear",
    "esmeraldeai": "esmeraldear",
    "esmeraldeais": "esmeraldear",
    "esmeraldeamo": "esmeraldear",
    "esmeraldeamos": "esmeraldear",
    "esmeraldeando": "esmeraldear",
    "esmeraldeara": "esmeraldear",
    "esmeraldearam": "esmeraldear",
    "esmeraldearas": "esmeraldear",
    "esmeraldearde": "esmeraldear",
    "esmeraldeardes": "esmeraldear",
    "esmeraldeare": "esmeraldear",
    "esmeraldearei": "esmeraldear",
    "esmeraldeareis": "esmeraldear",
    "esmeraldearem": "esmeraldear",
    "esmeraldearemos": "esmeraldear",
    "esmeraldeares": "esmeraldear",
    "esmeraldearia": "esmeraldear",
    "esmeraldeariam": "esmeraldear",
    "esmeraldearias": "esmeraldear",
    "esmeraldearmo": "esmeraldear",
    "esmeraldearmos": "esmeraldear",
    "esmeraldeará": "esmeraldear",
    "esmeraldearás": "esmeraldear",
    "esmeraldearão": "esmeraldear",
    "esmeraldearíamos": "esmeraldear",
    "esmeraldearíeis": "esmeraldear",
    "esmeraldeasse": "esmeraldear",
    "esmeraldeassem": "esmeraldear",
    "esmeraldeasses": "esmeraldear",
    "esmeraldeaste": "esmeraldear",
    "esmeraldeastes": "esmeraldear",
    "esmeraldeava": "esmeraldear",
    "esmeraldeavam": "esmeraldear",
    "esmeraldeavas": "esmeraldear",
    "esmeraldeei": "esmeraldear",
    "esmeraldeeis": "esmeraldear",
    "esmeraldeemo": "esmeraldear",
    "esmeraldeemos": "esmeraldear",
    "esmeraldeia": "esmeraldear",
    "esmeraldeiam": "esmeraldear",
    "esmeraldeias": "esmeraldear",
    "esmeraldeie": "esmeraldear",
    "esmeraldeiem": "esmeraldear",
    "esmeraldeies": "esmeraldear",
    "esmeraldeio": "esmeraldear",
    "esmeraldeou": "esmeraldear",
    "esmeraldeá": "esmeraldear",
    "esmeraldeámo": "esmeraldear",
    "esmeraldeámos": "esmeraldear",
    "esmeraldeáramo": "esmeraldear",
    "esmeraldeáramos": "esmeraldear",
    "esmeraldeárei": "esmeraldear",
    "esmeraldeáreis": "esmeraldear",
    "esmeraldeásseis": "esmeraldear",
    "esmeraldeássemos": "esmeraldear",
    "esmeraldeávamo": "esmeraldear",
    "esmeraldeávamos": "esmeraldear",
    "esmeraldeávei": "esmeraldear",
    "esmeraldeáveis": "esmeraldear",
    "esmeraldina": "esmeraldino",
    "esmeraldinas": "esmeraldino",
    "esmeraldinos": "esmeraldino",
    "esmeraldites": "esmeraldite",
    "esmeram": "esmerar",
    "esmeramo": "esmerar",
    "esmeramos": "esmerar",
    "esmerando": "esmerar",
    "esmerara": "esmerar",
    "esmeraram": "esmerar",
    "esmeraras": "esmerar",
    "esmerarde": "esmerar",
    "esmerardes": "esmerar",
    "esmerare": "esmerar",
    "esmerarei": "esmerar",
    "esmerareis": "esmerar",
    "esmerarem": "esmerar",
    "esmeraremos": "esmerar",
    "esmerares": "esmerar",
    "esmeraria": "esmerar",
    "esmerariam": "esmerar",
    "esmerarias": "esmerar",
    "esmerarmo": "esmerar",
    "esmerarmos": "esmerar",
    "esmerará": "esmerar",
    "esmerarás": "esmerar",
    "esmerarão": "esmerar",
    "esmeraríamos": "esmerar",
    "esmeraríeis": "esmerar",
    "esmeras": "esmerar",
    "esmerasse": "esmerar",
    "esmerassem": "esmerar",
    "esmerasses": "esmerar",
    "esmeraste": "esmerar",
    "esmerastes": "esmerar",
    "esmerava": "esmerar",
    "esmeravam": "esmerar",
    "esmeravas": "esmerar",
    "esmere": "esmerar",
    "esmerei": "esmerar",
    "esmereis": "esmerar",
    "esmerem": "esmerar",
    "esmeremo": "esmerar",
    "esmeremos": "esmerar",
    "esmeres": "esmerar",
    "esmerila": "esmerilar",
    "esmerilada": "esmerilar",
    "esmeriladas": "esmerilar",
    "esmeriladeiras": "esmeriladeira",
    "esmerilado": "esmerilar",
    "esmeriladora": "esmerilador",
    "esmeriladoras": "esmerilador",
    "esmeriladores": "esmerilador",
    "esmerilados": "esmerilar",
    "esmerilagens": "esmerilagem",
    "esmerilai": "esmerilar",
    "esmerilais": "esmerilar",
    "esmerilam": "esmerilar",
    "esmerilamentos": "esmerilamento",
    "esmerilamo": "esmerilar",
    "esmerilamos": "esmerilar",
    "esmerilando": "esmerilar",
    "esmerilara": "esmerilar",
    "esmerilaram": "esmerilar",
    "esmerilaras": "esmerilar",
    "esmerilarde": "esmerilar",
    "esmerilardes": "esmerilar",
    "esmerilare": "esmerilar",
    "esmerilarei": "esmerilar",
    "esmerilareis": "esmerilar",
    "esmerilarem": "esmerilar",
    "esmerilaremos": "esmerilar",
    "esmerilares": "esmerilar",
    "esmerilaria": "esmerilar",
    "esmerilariam": "esmerilar",
    "esmerilarias": "esmerilar",
    "esmerilarmo": "esmerilar",
    "esmerilarmos": "esmerilar",
    "esmerilará": "esmerilar",
    "esmerilarás": "esmerilar",
    "esmerilarão": "esmerilar",
    "esmerilaríamos": "esmerilar",
    "esmerilaríeis": "esmerilar",
    "esmerilas": "esmerilar",
    "esmerilasse": "esmerilar",
    "esmerilassem": "esmerilar",
    "esmerilasses": "esmerilar",
    "esmerilaste": "esmerilar",
    "esmerilastes": "esmerilar",
    "esmerilava": "esmerilar",
    "esmerilavam": "esmerilar",
    "esmerilavas": "esmerilar",
    "esmerilações": "esmerilação",
    "esmerile": "esmerilar",
    "esmerilei": "esmerilar",
    "esmerileis": "esmerilar",
    "esmerilem": "esmerilar",
    "esmerilemo": "esmerilar",
    "esmerilemos": "esmerilar",
    "esmeriles": "esmerilar",
    "esmerilha": "esmerilhar",
    "esmerilhada": "esmerilhar",
    "esmerilhadas": "esmerilhar",
    "esmerilhado": "esmerilhar",
    "esmerilhadora": "esmerilhador",
    "esmerilhadoras": "esmerilhador",
    "esmerilhadores": "esmerilhador",
    "esmerilhados": "esmerilhar",
    "esmerilhai": "esmerilhar",
    "esmerilhais": "esmerilhar",
    "esmerilham": "esmerilhar",
    "esmerilhamo": "esmerilhar",
    "esmerilhamos": "esmerilhar",
    "esmerilhando": "esmerilhar",
    "esmerilhara": "esmerilhar",
    "esmerilharam": "esmerilhar",
    "esmerilharas": "esmerilhar",
    "esmerilharde": "esmerilhar",
    "esmerilhardes": "esmerilhar",
    "esmerilhare": "esmerilhar",
    "esmerilharei": "esmerilhar",
    "esmerilhareis": "esmerilhar",
    "esmerilharem": "esmerilhar",
    "esmerilharemos": "esmerilhar",
    "esmerilhares": "esmerilhar",
    "esmerilharia": "esmerilhar",
    "esmerilhariam": "esmerilhar",
    "esmerilharias": "esmerilhar",
    "esmerilharmo": "esmerilhar",
    "esmerilharmos": "esmerilhar",
    "esmerilhará": "esmerilhar",
    "esmerilharás": "esmerilhar",
    "esmerilharão": "esmerilhar",
    "esmerilharíamos": "esmerilhar",
    "esmerilharíeis": "esmerilhar",
    "esmerilhas": "esmerilhar",
    "esmerilhasse": "esmerilhar",
    "esmerilhassem": "esmerilhar",
    "esmerilhasses": "esmerilhar",
    "esmerilhaste": "esmerilhar",
    "esmerilhastes": "esmerilhar",
    "esmerilhava": "esmerilhar",
    "esmerilhavam": "esmerilhar",
    "esmerilhavas": "esmerilhar",
    "esmerilhações": "esmerilhação",
    "esmerilhe": "esmerilhar",
    "esmerilhei": "esmerilhar",
    "esmerilheis": "esmerilhar",
    "esmerilhem": "esmerilhar",
    "esmerilhemo": "esmerilhar",
    "esmerilhemos": "esmerilhar",
    "esmerilhes": "esmerilhar",
    "esmerilho": "esmerilhar",
    "esmerilhou": "esmerilhar",
    "esmerilhá": "esmerilhar",
    "esmerilhámo": "esmerilhar",
    "esmerilhámos": "esmerilhar",
    "esmerilháramo": "esmerilhar",
    "esmerilháramos": "esmerilhar",
    "esmerilhárei": "esmerilhar",
    "esmerilháreis": "esmerilhar",
    "esmerilhásseis": "esmerilhar",
    "esmerilhássemos": "esmerilhar",
    "esmerilhávamo": "esmerilhar",
    "esmerilhávamos": "esmerilhar",
    "esmerilhávei": "esmerilhar",
    "esmerilháveis": "esmerilhar",
    "esmerilhões": "esmerilhão",
    "esmerilo": "esmerilar",
    "esmerilou": "esmerilar",
    "esmerilá": "esmerilar",
    "esmerilámo": "esmerilar",
    "esmerilámos": "esmerilar",
    "esmeriláramo": "esmerilar",
    "esmeriláramos": "esmerilar",
    "esmerilárei": "esmerilar",
    "esmeriláreis": "esmerilar",
    "esmerilásseis": "esmerilar",
    "esmerilássemos": "esmerilar",
    "esmerilávamo": "esmerilar",
    "esmerilávamos": "esmerilar",
    "esmerilávei": "esmerilar",
    "esmeriláveis": "esmerilar",
    "esmeris": "esmeril",
    "esmero": "esmerar",
    "esmeros": "esmero",
    "esmerou": "esmerar",
    "esmerá": "esmerar",
    "esmerámo": "esmerar",
    "esmerámos": "esmerar",
    "esmeráramo": "esmerar",
    "esmeráramos": "esmerar",
    "esmerárei": "esmerar",
    "esmeráreis": "esmerar",
    "esmerásseis": "esmerar",
    "esmerássemos": "esmerar",
    "esmerávamo": "esmerar",
    "esmerávamos": "esmerar",
    "esmerávei": "esmerar",
    "esmeráveis": "esmerar",
    "esmes": "esmar",
    "esmeá": "esmear",
    "esmeámo": "esmear",
    "esmeámos": "esmear",
    "esmeáramo": "esmear",
    "esmeáramos": "esmear",
    "esmeárei": "esmear",
    "esmeáreis": "esmear",
    "esmeásseis": "esmear",
    "esmeássemos": "esmear",
    "esmeávamo": "esmear",
    "esmeávamos": "esmear",
    "esmeávei": "esmear",
    "esmeáveis": "esmear",
    "esmifra": "esmifrar",
    "esmifrada": "esmifrar",
    "esmifradas": "esmifrar",
    "esmifrado": "esmifrar",
    "esmifrados": "esmifrar",
    "esmifrai": "esmifrar",
    "esmifrais": "esmifrar",
    "esmifram": "esmifrar",
    "esmiframo": "esmifrar",
    "esmiframos": "esmifrar",
    "esmifrando": "esmifrar",
    "esmifrara": "esmifrar",
    "esmifraram": "esmifrar",
    "esmifraras": "esmifrar",
    "esmifrarde": "esmifrar",
    "esmifrardes": "esmifrar",
    "esmifrare": "esmifrar",
    "esmifrarei": "esmifrar",
    "esmifrareis": "esmifrar",
    "esmifrarem": "esmifrar",
    "esmifraremos": "esmifrar",
    "esmifrares": "esmifrar",
    "esmifraria": "esmifrar",
    "esmifrariam": "esmifrar",
    "esmifrarias": "esmifrar",
    "esmifrarmo": "esmifrar",
    "esmifrarmos": "esmifrar",
    "esmifrará": "esmifrar",
    "esmifrarás": "esmifrar",
    "esmifrarão": "esmifrar",
    "esmifraríamos": "esmifrar",
    "esmifraríeis": "esmifrar",
    "esmifras": "esmifrar",
    "esmifrasse": "esmifrar",
    "esmifrassem": "esmifrar",
    "esmifrasses": "esmifrar",
    "esmifraste": "esmifrar",
    "esmifrastes": "esmifrar",
    "esmifrava": "esmifrar",
    "esmifravam": "esmifrar",
    "esmifravas": "esmifrar",
    "esmifre": "esmifrar",
    "esmifrei": "esmifrar",
    "esmifreis": "esmifrar",
    "esmifrem": "esmifrar",
    "esmifremo": "esmifrar",
    "esmifremos": "esmifrar",
    "esmifres": "esmifrar",
    "esmifro": "esmifrar",
    "esmifrou": "esmifrar",
    "esmifrá": "esmifrar",
    "esmifrámo": "esmifrar",
    "esmifrámos": "esmifrar",
    "esmifráramo": "esmifrar",
    "esmifráramos": "esmifrar",
    "esmifrárei": "esmifrar",
    "esmifráreis": "esmifrar",
    "esmifrásseis": "esmifrar",
    "esmifrássemos": "esmifrar",
    "esmifrávamo": "esmifrar",
    "esmifrávamos": "esmifrar",
    "esmifrávei": "esmifrar",
    "esmifráveis": "esmifrar",
    "esmigalha": "esmigalhar",
    "esmigalhada": "esmigalhar",
    "esmigalhadas": "esmigalhar",
    "esmigalhado": "esmigalhar",
    "esmigalhados": "esmigalhar",
    "esmigalhai": "esmigalhar",
    "esmigalhais": "esmigalhar",
    "esmigalham": "esmigalhar",
    "esmigalhamentos": "esmigalhamento",
    "esmigalhamo": "esmigalhar",
    "esmigalhamos": "esmigalhar",
    "esmigalhando": "esmigalhar",
    "esmigalhara": "esmigalhar",
    "esmigalharam": "esmigalhar",
    "esmigalharas": "esmigalhar",
    "esmigalharde": "esmigalhar",
    "esmigalhardes": "esmigalhar",
    "esmigalhare": "esmigalhar",
    "esmigalharei": "esmigalhar",
    "esmigalhareis": "esmigalhar",
    "esmigalharem": "esmigalhar",
    "esmigalharemos": "esmigalhar",
    "esmigalhares": "esmigalhar",
    "esmigalharia": "esmigalhar",
    "esmigalhariam": "esmigalhar",
    "esmigalharias": "esmigalhar",
    "esmigalharmo": "esmigalhar",
    "esmigalharmos": "esmigalhar",
    "esmigalhará": "esmigalhar",
    "esmigalharás": "esmigalhar",
    "esmigalharão": "esmigalhar",
    "esmigalharíamos": "esmigalhar",
    "esmigalharíeis": "esmigalhar",
    "esmigalhas": "esmigalhar",
    "esmigalhasse": "esmigalhar",
    "esmigalhassem": "esmigalhar",
    "esmigalhasses": "esmigalhar",
    "esmigalhaste": "esmigalhar",
    "esmigalhastes": "esmigalhar",
    "esmigalhava": "esmigalhar",
    "esmigalhavam": "esmigalhar",
    "esmigalhavas": "esmigalhar",
    "esmigalhe": "esmigalhar",
    "esmigalhei": "esmigalhar",
    "esmigalheis": "esmigalhar",
    "esmigalhem": "esmigalhar",
    "esmigalhemo": "esmigalhar",
    "esmigalhemos": "esmigalhar",
    "esmigalhes": "esmigalhar",
    "esmigalho": "esmigalhar",
    "esmigalhou": "esmigalhar",
    "esmigalhá": "esmigalhar",
    "esmigalhámo": "esmigalhar",
    "esmigalhámos": "esmigalhar",
    "esmigalháramo": "esmigalhar",
    "esmigalháramos": "esmigalhar",
    "esmigalhárei": "esmigalhar",
    "esmigalháreis": "esmigalhar",
    "esmigalhásseis": "esmigalhar",
    "esmigalhássemos": "esmigalhar",
    "esmigalhávamo": "esmigalhar",
    "esmigalhávamos": "esmigalhar",
    "esmigalhávei": "esmigalhar",
    "esmigalháveis": "esmigalhar",
    "esmijace": "esmijaçar",
    "esmijacei": "esmijaçar",
    "esmijaceis": "esmijaçar",
    "esmijacem": "esmijaçar",
    "esmijacemo": "esmijaçar",
    "esmijacemos": "esmijaçar",
    "esmijaces": "esmijaçar",
    "esmijaça": "esmijaçar",
    "esmijaçada": "esmijaçar",
    "esmijaçadas": "esmijaçar",
    "esmijaçado": "esmijaçar",
    "esmijaçados": "esmijaçar",
    "esmijaçai": "esmijaçar",
    "esmijaçais": "esmijaçar",
    "esmijaçam": "esmijaçar",
    "esmijaçamo": "esmijaçar",
    "esmijaçamos": "esmijaçar",
    "esmijaçando": "esmijaçar",
    "esmijaçara": "esmijaçar",
    "esmijaçaram": "esmijaçar",
    "esmijaçaras": "esmijaçar",
    "esmijaçardes": "esmijaçar",
    "esmijaçarei": "esmijaçar",
    "esmijaçareis": "esmijaçar",
    "esmijaçarem": "esmijaçar",
    "esmijaçaremos": "esmijaçar",
    "esmijaçares": "esmijaçar",
    "esmijaçaria": "esmijaçar",
    "esmijaçariam": "esmijaçar",
    "esmijaçarias": "esmijaçar",
    "esmijaçarmo": "esmijaçar",
    "esmijaçarmos": "esmijaçar",
    "esmijaçará": "esmijaçar",
    "esmijaçarás": "esmijaçar",
    "esmijaçarão": "esmijaçar",
    "esmijaçaríamos": "esmijaçar",
    "esmijaçaríeis": "esmijaçar",
    "esmijaças": "esmijaçar",
    "esmijaçasse": "esmijaçar",
    "esmijaçassem": "esmijaçar",
    "esmijaçasses": "esmijaçar",
    "esmijaçaste": "esmijaçar",
    "esmijaçastes": "esmijaçar",
    "esmijaçava": "esmijaçar",
    "esmijaçavam": "esmijaçar",
    "esmijaçavas": "esmijaçar",
    "esmijaço": "esmijaçar",
    "esmijaçou": "esmijaçar",
    "esmijaçámo": "esmijaçar",
    "esmijaçámos": "esmijaçar",
    "esmijaçáramo": "esmijaçar",
    "esmijaçáramos": "esmijaçar",
    "esmijaçáreis": "esmijaçar",
    "esmijaçásseis": "esmijaçar",
    "esmijaçássemos": "esmijaçar",
    "esmijaçávamo": "esmijaçar",
    "esmijaçávamos": "esmijaçar",
    "esmijaçáveis": "esmijaçar",
    "esmilha": "esmilhar",
    "esmilhada": "esmilhar",
    "esmilhadas": "esmilhar",
    "esmilhado": "esmilhar",
    "esmilhados": "esmilhar",
    "esmilhai": "esmilhar",
    "esmilhais": "esmilhar",
    "esmilham": "esmilhar",
    "esmilhamo": "esmilhar",
    "esmilhamos": "esmilhar",
    "esmilhando": "esmilhar",
    "esmilhara": "esmilhar",
    "esmilharam": "esmilhar",
    "esmilharas": "esmilhar",
    "esmilharde": "esmilhar",
    "esmilhardes": "esmilhar",
    "esmilhare": "esmilhar",
    "esmilharei": "esmilhar",
    "esmilhareis": "esmilhar",
    "esmilharem": "esmilhar",
    "esmilharemos": "esmilhar",
    "esmilhares": "esmilhar",
    "esmilharia": "esmilhar",
    "esmilhariam": "esmilhar",
    "esmilharias": "esmilhar",
    "esmilharmo": "esmilhar",
    "esmilharmos": "esmilhar",
    "esmilhará": "esmilhar",
    "esmilharás": "esmilhar",
    "esmilharão": "esmilhar",
    "esmilharíamos": "esmilhar",
    "esmilharíeis": "esmilhar",
    "esmilhas": "esmilhar",
    "esmilhasse": "esmilhar",
    "esmilhassem": "esmilhar",
    "esmilhasses": "esmilhar",
    "esmilhaste": "esmilhar",
    "esmilhastes": "esmilhar",
    "esmilhava": "esmilhar",
    "esmilhavam": "esmilhar",
    "esmilhavas": "esmilhar",
    "esmilhe": "esmilhar",
    "esmilhei": "esmilhar",
    "esmilheis": "esmilhar",
    "esmilhem": "esmilhar",
    "esmilhemo": "esmilhar",
    "esmilhemos": "esmilhar",
    "esmilhes": "esmilhar",
    "esmilho": "esmilhar",
    "esmilhou": "esmilhar",
    "esmilhá": "esmilhar",
    "esmilhámo": "esmilhar",
    "esmilhámos": "esmilhar",
    "esmilháramo": "esmilhar",
    "esmilháramos": "esmilhar",
    "esmilhárei": "esmilhar",
    "esmilháreis": "esmilhar",
    "esmilhásseis": "esmilhar",
    "esmilhássemos": "esmilhar",
    "esmilhávamo": "esmilhar",
    "esmilhávamos": "esmilhar",
    "esmilhávei": "esmilhar",
    "esmilháveis": "esmilhar",
    "esmiláceas": "esmilácea",
    "esmiola": "esmiolar",
    "esmiolada": "esmiolar",
    "esmioladas": "esmiolar",
    "esmiolado": "esmiolar",
    "esmiolados": "esmiolar",
    "esmiolai": "esmiolar",
    "esmiolais": "esmiolar",
    "esmiolam": "esmiolar",
    "esmiolamo": "esmiolar",
    "esmiolamos": "esmiolar",
    "esmiolando": "esmiolar",
    "esmiolara": "esmiolar",
    "esmiolaram": "esmiolar",
    "esmiolaras": "esmiolar",
    "esmiolarde": "esmiolar",
    "esmiolardes": "esmiolar",
    "esmiolare": "esmiolar",
    "esmiolarei": "esmiolar",
    "esmiolareis": "esmiolar",
    "esmiolarem": "esmiolar",
    "esmiolaremos": "esmiolar",
    "esmiolares": "esmiolar",
    "esmiolaria": "esmiolar",
    "esmiolariam": "esmiolar",
    "esmiolarias": "esmiolar",
    "esmiolarmo": "esmiolar",
    "esmiolarmos": "esmiolar",
    "esmiolará": "esmiolar",
    "esmiolarás": "esmiolar",
    "esmiolarão": "esmiolar",
    "esmiolaríamos": "esmiolar",
    "esmiolaríeis": "esmiolar",
    "esmiolas": "esmiolar",
    "esmiolasse": "esmiolar",
    "esmiolassem": "esmiolar",
    "esmiolasses": "esmiolar",
    "esmiolaste": "esmiolar",
    "esmiolastes": "esmiolar",
    "esmiolava": "esmiolar",
    "esmiolavam": "esmiolar",
    "esmiolavas": "esmiolar",
    "esmiole": "esmiolar",
    "esmiolei": "esmiolar",
    "esmioleis": "esmiolar",
    "esmiolem": "esmiolar",
    "esmiolemo": "esmiolar",
    "esmiolemos": "esmiolar",
    "esmioles": "esmiolar",
    "esmiolo": "esmiolar",
    "esmiolou": "esmiolar",
    "esmiolá": "esmiolar",
    "esmiolámo": "esmiolar",
    "esmiolámos": "esmiolar",
    "esmioláramo": "esmiolar",
    "esmioláramos": "esmiolar",
    "esmiolárei": "esmiolar",
    "esmioláreis": "esmiolar",
    "esmiolásseis": "esmiolar",
    "esmiolássemos": "esmiolar",
    "esmiolávamo": "esmiolar",
    "esmiolávamos": "esmiolar",
    "esmiolávei": "esmiolar",
    "esmioláveis": "esmiolar",
    "esmirra": "esmirrar",
    "esmirrada": "esmirrar",
    "esmirradas": "esmirrar",
    "esmirrado": "esmirrar",
    "esmirrados": "esmirrar",
    "esmirrai": "esmirrar",
    "esmirrais": "esmirrar",
    "esmirram": "esmirrar",
    "esmirramo": "esmirrar",
    "esmirramos": "esmirrar",
    "esmirrando": "esmirrar",
    "esmirrara": "esmirrar",
    "esmirraram": "esmirrar",
    "esmirraras": "esmirrar",
    "esmirrarde": "esmirrar",
    "esmirrardes": "esmirrar",
    "esmirrare": "esmirrar",
    "esmirrarei": "esmirrar",
    "esmirrareis": "esmirrar",
    "esmirrarem": "esmirrar",
    "esmirraremos": "esmirrar",
    "esmirrares": "esmirrar",
    "esmirraria": "esmirrar",
    "esmirrariam": "esmirrar",
    "esmirrarias": "esmirrar",
    "esmirrarmo": "esmirrar",
    "esmirrarmos": "esmirrar",
    "esmirrará": "esmirrar",
    "esmirrarás": "esmirrar",
    "esmirrarão": "esmirrar",
    "esmirraríamos": "esmirrar",
    "esmirraríeis": "esmirrar",
    "esmirras": "esmirrar",
    "esmirrasse": "esmirrar",
    "esmirrassem": "esmirrar",
    "esmirrasses": "esmirrar",
    "esmirraste": "esmirrar",
    "esmirrastes": "esmirrar",
    "esmirrava": "esmirrar",
    "esmirravam": "esmirrar",
    "esmirravas": "esmirrar",
    "esmirre": "esmirrar",
    "esmirrei": "esmirrar",
    "esmirreis": "esmirrar",
    "esmirrem": "esmirrar",
    "esmirremo": "esmirrar",
    "esmirremos": "esmirrar",
    "esmirres": "esmirrar",
    "esmirro": "esmirrar",
    "esmirrou": "esmirrar",
    "esmirrá": "esmirrar",
    "esmirrámo": "esmirrar",
    "esmirrámos": "esmirrar",
    "esmirráramo": "esmirrar",
    "esmirráramos": "esmirrar",
    "esmirrárei": "esmirrar",
    "esmirráreis": "esmirrar",
    "esmirrásseis": "esmirrar",
    "esmirrássemos": "esmirrar",
    "esmirrávamo": "esmirrar",
    "esmirrávamos": "esmirrar",
    "esmirrávei": "esmirrar",
    "esmirráveis": "esmirrar",
    "esmiuce": "esmiuçar",
    "esmiucei": "esmiuçar",
    "esmiuceis": "esmiuçar",
    "esmiucem": "esmiuçar",
    "esmiucemo": "esmiuçar",
    "esmiucemos": "esmiuçar",
    "esmiuces": "esmiuçar",
    "esmiudada": "esmiudar",
    "esmiudadas": "esmiudar",
    "esmiudado": "esmiudar",
    "esmiudados": "esmiudar",
    "esmiudai": "esmiudar",
    "esmiudais": "esmiudar",
    "esmiudamo": "esmiudar",
    "esmiudamos": "esmiudar",
    "esmiudando": "esmiudar",
    "esmiudara": "esmiudar",
    "esmiudaram": "esmiudar",
    "esmiudaras": "esmiudar",
    "esmiudarde": "esmiudar",
    "esmiudardes": "esmiudar",
    "esmiudare": "esmiudar",
    "esmiudarei": "esmiudar",
    "esmiudareis": "esmiudar",
    "esmiudarem": "esmiudar",
    "esmiudaremos": "esmiudar",
    "esmiudares": "esmiudar",
    "esmiudaria": "esmiudar",
    "esmiudariam": "esmiudar",
    "esmiudarias": "esmiudar",
    "esmiudarmo": "esmiudar",
    "esmiudarmos": "esmiudar",
    "esmiudará": "esmiudar",
    "esmiudarás": "esmiudar",
    "esmiudarão": "esmiudar",
    "esmiudaríamos": "esmiudar",
    "esmiudaríeis": "esmiudar",
    "esmiudasse": "esmiudar",
    "esmiudassem": "esmiudar",
    "esmiudasses": "esmiudar",
    "esmiudaste": "esmiudar",
    "esmiudastes": "esmiudar",
    "esmiudava": "esmiudar",
    "esmiudavam": "esmiudar",
    "esmiudavas": "esmiudar",
    "esmiudei": "esmiudar",
    "esmiudeis": "esmiudar",
    "esmiudemo": "esmiudar",
    "esmiudemos": "esmiudar",
    "esmiudou": "esmiudar",
    "esmiudá": "esmiudar",
    "esmiudámo": "esmiudar",
    "esmiudámos": "esmiudar",
    "esmiudáramo": "esmiudar",
    "esmiudáramos": "esmiudar",
    "esmiudárei": "esmiudar",
    "esmiudáreis": "esmiudar",
    "esmiudásseis": "esmiudar",
    "esmiudássemos": "esmiudar",
    "esmiudávamo": "esmiudar",
    "esmiudávamos": "esmiudar",
    "esmiudávei": "esmiudar",
    "esmiudáveis": "esmiudar",
    "esmiunce": "esmiunçar",
    "esmiuncei": "esmiunçar",
    "esmiunceis": "esmiunçar",
    "esmiuncem": "esmiunçar",
    "esmiuncemo": "esmiunçar",
    "esmiuncemos": "esmiunçar",
    "esmiunces": "esmiunçar",
    "esmiunça": "esmiunçar",
    "esmiunçada": "esmiunçar",
    "esmiunçadas": "esmiunçar",
    "esmiunçado": "esmiunçar",
    "esmiunçados": "esmiunçar",
    "esmiunçai": "esmiunçar",
    "esmiunçais": "esmiunçar",
    "esmiunçam": "esmiunçar",
    "esmiunçamo": "esmiunçar",
    "esmiunçamos": "esmiunçar",
    "esmiunçando": "esmiunçar",
    "esmiunçara": "esmiunçar",
    "esmiunçaram": "esmiunçar",
    "esmiunçaras": "esmiunçar",
    "esmiunçarde": "esmiunçar",
    "esmiunçardes": "esmiunçar",
    "esmiunçare": "esmiunçar",
    "esmiunçarei": "esmiunçar",
    "esmiunçareis": "esmiunçar",
    "esmiunçarem": "esmiunçar",
    "esmiunçaremos": "esmiunçar",
    "esmiunçares": "esmiunçar",
    "esmiunçaria": "esmiunçar",
    "esmiunçariam": "esmiunçar",
    "esmiunçarias": "esmiunçar",
    "esmiunçarmo": "esmiunçar",
    "esmiunçarmos": "esmiunçar",
    "esmiunçará": "esmiunçar",
    "esmiunçarás": "esmiunçar",
    "esmiunçarão": "esmiunçar",
    "esmiunçaríamos": "esmiunçar",
    "esmiunçaríeis": "esmiunçar",
    "esmiunças": "esmiunçar",
    "esmiunçasse": "esmiunçar",
    "esmiunçassem": "esmiunçar",
    "esmiunçasses": "esmiunçar",
    "esmiunçaste": "esmiunçar",
    "esmiunçastes": "esmiunçar",
    "esmiunçava": "esmiunçar",
    "esmiunçavam": "esmiunçar",
    "esmiunçavas": "esmiunçar",
    "esmiunço": "esmiunçar",
    "esmiunçou": "esmiunçar",
    "esmiunçá": "esmiunçar",
    "esmiunçámo": "esmiunçar",
    "esmiunçámos": "esmiunçar",
    "esmiunçáramo": "esmiunçar",
    "esmiunçáramos": "esmiunçar",
    "esmiunçárei": "esmiunçar",
    "esmiunçáreis": "esmiunçar",
    "esmiunçásseis": "esmiunçar",
    "esmiunçássemos": "esmiunçar",
    "esmiunçávamo": "esmiunçar",
    "esmiunçávamos": "esmiunçar",
    "esmiunçávei": "esmiunçar",
    "esmiunçáveis": "esmiunçar",
    "esmiuçada": "esmiuçar",
    "esmiuçadas": "esmiuçar",
    "esmiuçado": "esmiuçar",
    "esmiuçadora": "esmiuçador",
    "esmiuçadoras": "esmiuçador",
    "esmiuçadores": "esmiuçador",
    "esmiuçados": "esmiuçar",
    "esmiuçai": "esmiuçar",
    "esmiuçais": "esmiuçar",
    "esmiuçamo": "esmiuçar",
    "esmiuçamos": "esmiuçar",
    "esmiuçando": "esmiuçar",
    "esmiuçara": "esmiuçar",
    "esmiuçaram": "esmiuçar",
    "esmiuçaras": "esmiuçar",
    "esmiuçarde": "esmiuçar",
    "esmiuçardes": "esmiuçar",
    "esmiuçare": "esmiuçar",
    "esmiuçarei": "esmiuçar",
    "esmiuçareis": "esmiuçar",
    "esmiuçarem": "esmiuçar",
    "esmiuçaremos": "esmiuçar",
    "esmiuçares": "esmiuçar",
    "esmiuçarmo": "esmiuçar",
    "esmiuçarmos": "esmiuçar",
    "esmiuçará": "esmiuçar",
    "esmiuçarás": "esmiuçar",
    "esmiuçarão": "esmiuçar",
    "esmiuçaríamos": "esmiuçar",
    "esmiuçaríeis": "esmiuçar",
    "esmiuçasse": "esmiuçar",
    "esmiuçassem": "esmiuçar",
    "esmiuçasses": "esmiuçar",
    "esmiuçaste": "esmiuçar",
    "esmiuçastes": "esmiuçar",
    "esmiuçava": "esmiuçar",
    "esmiuçavam": "esmiuçar",
    "esmiuçavas": "esmiuçar",
    "esmiuçou": "esmiuçar",
    "esmiuçá": "esmiuçar",
    "esmiuçámo": "esmiuçar",
    "esmiuçámos": "esmiuçar",
    "esmiuçáramo": "esmiuçar",
    "esmiuçáramos": "esmiuçar",
    "esmiuçárei": "esmiuçar",
    "esmiuçáreis": "esmiuçar",
    "esmiuçásseis": "esmiuçar",
    "esmiuçássemos": "esmiuçar",
    "esmiuçávamo": "esmiuçar",
    "esmiuçávamos": "esmiuçar",
    "esmiuçávei": "esmiuçar",
    "esmiuçáveis": "esmiuçável",
    "esmiúce": "esmiuçar",
    "esmiúcem": "esmiuçar",
    "esmiúces": "esmiuçar",
    "esmiúda": "esmiudar",
    "esmiúdam": "esmiudar",
    "esmiúdas": "esmiudar",
    "esmiúde": "esmiudar",
    "esmiúdem": "esmiudar",
    "esmiúdes": "esmiudar",
    "esmiúdo": "esmiudar",
    "esmiúça": "esmiuçar",
    "esmiúçam": "esmiuçar",
    "esmiúçaria": "esmiuçar",
    "esmiúçariam": "esmiuçar",
    "esmiúçarias": "esmiuçar",
    "esmiúças": "esmiuçar",
    "esmiúço": "esmiuçar",
    "esmo": "esmar",
    "esmoa": "esmoer",
    "esmoais": "esmoer",
    "esmoam": "esmoer",
    "esmoamo": "esmoer",
    "esmoamos": "esmoer",
    "esmoas": "esmoer",
    "esmoca": "esmocar",
    "esmocada": "esmocar",
    "esmocadas": "esmocar",
    "esmocadelas": "esmocadela",
    "esmocado": "esmocar",
    "esmocados": "esmocar",
    "esmocai": "esmocar",
    "esmocais": "esmocar",
    "esmocam": "esmocar",
    "esmocamo": "esmocar",
    "esmocamos": "esmocar",
    "esmocando": "esmocar",
    "esmocara": "esmocar",
    "esmocaram": "esmocar",
    "esmocaras": "esmocar",
    "esmocarde": "esmocar",
    "esmocardes": "esmocar",
    "esmocare": "esmocar",
    "esmocarei": "esmocar",
    "esmocareis": "esmocar",
    "esmocarem": "esmocar",
    "esmocaremos": "esmocar",
    "esmocares": "esmocar",
    "esmocaria": "esmocar",
    "esmocariam": "esmocar",
    "esmocarias": "esmocar",
    "esmocarmo": "esmocar",
    "esmocarmos": "esmocar",
    "esmocará": "esmocar",
    "esmocarás": "esmocar",
    "esmocarão": "esmocar",
    "esmocaríamos": "esmocar",
    "esmocaríeis": "esmocar",
    "esmocas": "esmocar",
    "esmocasse": "esmocar",
    "esmocassem": "esmocar",
    "esmocasses": "esmocar",
    "esmocaste": "esmocar",
    "esmocastes": "esmocar",
    "esmocava": "esmocar",
    "esmocavam": "esmocar",
    "esmocavas": "esmocar",
    "esmocha": "esmochar",
    "esmochada": "esmochar",
    "esmochadas": "esmochar",
    "esmochado": "esmochar",
    "esmochados": "esmochar",
    "esmochai": "esmochar",
    "esmochais": "esmochar",
    "esmocham": "esmochar",
    "esmochamo": "esmochar",
    "esmochamos": "esmochar",
    "esmochando": "esmochar",
    "esmochara": "esmochar",
    "esmocharam": "esmochar",
    "esmocharas": "esmochar",
    "esmocharde": "esmochar",
    "esmochardes": "esmochar",
    "esmochare": "esmochar",
    "esmocharei": "esmochar",
    "esmochareis": "esmochar",
    "esmocharem": "esmochar",
    "esmocharemos": "esmochar",
    "esmochares": "esmochar",
    "esmocharia": "esmochar",
    "esmochariam": "esmochar",
    "esmocharias": "esmochar",
    "esmocharmo": "esmochar",
    "esmocharmos": "esmochar",
    "esmochará": "esmochar",
    "esmocharás": "esmochar",
    "esmocharão": "esmochar",
    "esmocharíamos": "esmochar",
    "esmocharíeis": "esmochar",
    "esmochas": "esmochar",
    "esmochasse": "esmochar",
    "esmochassem": "esmochar",
    "esmochasses": "esmochar",
    "esmochaste": "esmochar",
    "esmochastes": "esmochar",
    "esmochava": "esmochar",
    "esmochavam": "esmochar",
    "esmochavas": "esmochar",
    "esmoche": "esmochar",
    "esmochei": "esmochar",
    "esmocheis": "esmochar",
    "esmochem": "esmochar",
    "esmochemo": "esmochar",
    "esmochemos": "esmochar",
    "esmoches": "esmochar",
    "esmocho": "esmochar",
    "esmochou": "esmochar",
    "esmochá": "esmochar",
    "esmochámo": "esmochar",
    "esmochámos": "esmochar",
    "esmocháramo": "esmochar",
    "esmocháramos": "esmochar",
    "esmochárei": "esmochar",
    "esmocháreis": "esmochar",
    "esmochásseis": "esmochar",
    "esmochássemos": "esmochar",
    "esmochávamo": "esmochar",
    "esmochávamos": "esmochar",
    "esmochávei": "esmochar",
    "esmocháveis": "esmochar",
    "esmoco": "esmocar",
    "esmocou": "esmocar",
    "esmocá": "esmocar",
    "esmocámo": "esmocar",
    "esmocámos": "esmocar",
    "esmocáramo": "esmocar",
    "esmocáramos": "esmocar",
    "esmocárei": "esmocar",
    "esmocáreis": "esmocar",
    "esmocásseis": "esmocar",
    "esmocássemos": "esmocar",
    "esmocávamo": "esmocar",
    "esmocávamos": "esmocar",
    "esmocávei": "esmocar",
    "esmocáveis": "esmocar",
    "esmoedora": "esmoedor",
    "esmoedoras": "esmoedor",
    "esmoedores": "esmoedor",
    "esmoei": "esmoer",
    "esmoeis": "esmoer",
    "esmoem": "esmoer",
    "esmoemo": "esmoer",
    "esmoemos": "esmoer",
    "esmoendo": "esmoer",
    "esmoera": "esmoer",
    "esmoeram": "esmoer",
    "esmoeras": "esmoer",
    "esmoerde": "esmoer",
    "esmoerdes": "esmoer",
    "esmoere": "esmoer",
    "esmoerei": "esmoer",
    "esmoereis": "esmoer",
    "esmoerem": "esmoer",
    "esmoeremos": "esmoer",
    "esmoeres": "esmoer",
    "esmoeria": "esmoer",
    "esmoeriam": "esmoer",
    "esmoerias": "esmoer",
    "esmoermo": "esmoer",
    "esmoermos": "esmoer",
    "esmoerá": "esmoer",
    "esmoerás": "esmoer",
    "esmoerão": "esmoer",
    "esmoeríamos": "esmoer",
    "esmoeríeis": "esmoer",
    "esmoesse": "esmoer",
    "esmoessem": "esmoer",
    "esmoesses": "esmoer",
    "esmoeste": "esmoer",
    "esmoestes": "esmoer",
    "esmoeu": "esmoer",
    "esmoita": "esmoitar",
    "esmoitada": "esmoitar",
    "esmoitadas": "esmoitar",
    "esmoitado": "esmoitar",
    "esmoitados": "esmoitar",
    "esmoitai": "esmoitar",
    "esmoitais": "esmoitar",
    "esmoitam": "esmoitar",
    "esmoitamo": "esmoitar",
    "esmoitamos": "esmoitar",
    "esmoitando": "esmoitar",
    "esmoitara": "esmoitar",
    "esmoitaram": "esmoitar",
    "esmoitaras": "esmoitar",
    "esmoitarde": "esmoitar",
    "esmoitardes": "esmoitar",
    "esmoitare": "esmoitar",
    "esmoitarei": "esmoitar",
    "esmoitareis": "esmoitar",
    "esmoitarem": "esmoitar",
    "esmoitaremos": "esmoitar",
    "esmoitares": "esmoitar",
    "esmoitaria": "esmoitar",
    "esmoitariam": "esmoitar",
    "esmoitarias": "esmoitar",
    "esmoitarmo": "esmoitar",
    "esmoitarmos": "esmoitar",
    "esmoitará": "esmoitar",
    "esmoitarás": "esmoitar",
    "esmoitarão": "esmoitar",
    "esmoitaríamos": "esmoitar",
    "esmoitaríeis": "esmoitar",
    "esmoitas": "esmoitar",
    "esmoitasse": "esmoitar",
    "esmoitassem": "esmoitar",
    "esmoitasses": "esmoitar",
    "esmoitaste": "esmoitar",
    "esmoitastes": "esmoitar",
    "esmoitava": "esmoitar",
    "esmoitavam": "esmoitar",
    "esmoitavas": "esmoitar",
    "esmoite": "esmoitar",
    "esmoitei": "esmoitar",
    "esmoiteis": "esmoitar",
    "esmoitem": "esmoitar",
    "esmoitemo": "esmoitar",
    "esmoitemos": "esmoitar",
    "esmoites": "esmoitar",
    "esmoito": "esmoitar",
    "esmoitou": "esmoitar",
    "esmoitá": "esmoitar",
    "esmoitámo": "esmoitar",
    "esmoitámos": "esmoitar",
    "esmoitáramo": "esmoitar",
    "esmoitáramos": "esmoitar",
    "esmoitárei": "esmoitar",
    "esmoitáreis": "esmoitar",
    "esmoitásseis": "esmoitar",
    "esmoitássemos": "esmoitar",
    "esmoitávamo": "esmoitar",
    "esmoitávamos": "esmoitar",
    "esmoitávei": "esmoitar",
    "esmoitáveis": "esmoitar",
    "esmola": "esmolar",
    "esmolada": "esmolar",
    "esmoladas": "esmolar",
    "esmolado": "esmolar",
    "esmoladora": "esmolador",
    "esmoladoras": "esmolador",
    "esmoladores": "esmolador",
    "esmolados": "esmolar",
    "esmolai": "esmolar",
    "esmolais": "esmolar",
    "esmolam": "esmolar",
    "esmolamo": "esmolar",
    "esmolamos": "esmolar",
    "esmolando": "esmolar",
    "esmolantes": "esmolante",
    "esmolara": "esmolar",
    "esmolaram": "esmolar",
    "esmolaras": "esmolar",
    "esmolarde": "esmolar",
    "esmolardes": "esmolar",
    "esmolare": "esmolar",
    "esmolarei": "esmolar",
    "esmolareis": "esmolar",
    "esmolarem": "esmolar",
    "esmolaremos": "esmolar",
    "esmolares": "esmolar",
    "esmolaria": "esmolar",
    "esmolariam": "esmolar",
    "esmolarias": "esmolaria",
    "esmolarmo": "esmolar",
    "esmolarmos": "esmolar",
    "esmolará": "esmolar",
    "esmolarás": "esmolar",
    "esmolarão": "esmolar",
    "esmolaríamos": "esmolar",
    "esmolaríeis": "esmolar",
    "esmolas": "esmolar",
    "esmolasse": "esmolar",
    "esmolassem": "esmolar",
    "esmolasses": "esmolar",
    "esmolaste": "esmolar",
    "esmolastes": "esmolar",
    "esmolava": "esmolar",
    "esmolavam": "esmolar",
    "esmolavas": "esmolar",
    "esmolazinha": "esmola",
    "esmolazinhas": "esmola",
    "esmolazita": "esmola",
    "esmolazitas": "esmola",
    "esmole": "esmolar",
    "esmoledora": "esmoledor",
    "esmoledoras": "esmoledor",
    "esmoledores": "esmoledor",
    "esmolei": "esmolar",
    "esmoleira": "esmoleiro",
    "esmoleiras": "esmoleiro",
    "esmoleiros": "esmoleiro",
    "esmoleis": "esmolar",
    "esmolem": "esmolar",
    "esmolemo": "esmolar",
    "esmolemos": "esmolar",
    "esmoleres": "esmoler",
    "esmoles": "esmolar",
    "esmolinha": "esmola",
    "esmolinhas": "esmola",
    "esmolita": "esmola",
    "esmolitas": "esmola",
    "esmolo": "esmolar",
    "esmolou": "esmolar",
    "esmolá": "esmolar",
    "esmolámo": "esmolar",
    "esmolámos": "esmolar",
    "esmoláramo": "esmolar",
    "esmoláramos": "esmolar",
    "esmolárei": "esmolar",
    "esmoláreis": "esmolar",
    "esmolásseis": "esmolar",
    "esmolássemos": "esmolar",
    "esmolávamo": "esmolar",
    "esmolávamos": "esmolar",
    "esmolávei": "esmolar",
    "esmoláveis": "esmolar",
    "esmonca": "esmoncar",
    "esmoncada": "esmoncar",
    "esmoncadas": "esmoncar",
    "esmoncadelas": "esmoncadela",
    "esmoncado": "esmoncar",
    "esmoncados": "esmoncar",
    "esmoncai": "esmoncar",
    "esmoncais": "esmoncar",
    "esmoncam": "esmoncar",
    "esmoncamo": "esmoncar",
    "esmoncamos": "esmoncar",
    "esmoncando": "esmoncar",
    "esmoncara": "esmoncar",
    "esmoncaram": "esmoncar",
    "esmoncaras": "esmoncar",
    "esmoncarde": "esmoncar",
    "esmoncardes": "esmoncar",
    "esmoncare": "esmoncar",
    "esmoncarei": "esmoncar",
    "esmoncareis": "esmoncar",
    "esmoncarem": "esmoncar",
    "esmoncaremos": "esmoncar",
    "esmoncares": "esmoncar",
    "esmoncaria": "esmoncar",
    "esmoncariam": "esmoncar",
    "esmoncarias": "esmoncar",
    "esmoncarmo": "esmoncar",
    "esmoncarmos": "esmoncar",
    "esmoncará": "esmoncar",
    "esmoncarás": "esmoncar",
    "esmoncarão": "esmoncar",
    "esmoncaríamos": "esmoncar",
    "esmoncaríeis": "esmoncar",
    "esmoncas": "esmoncar",
    "esmoncasse": "esmoncar",
    "esmoncassem": "esmoncar",
    "esmoncasses": "esmoncar",
    "esmoncaste": "esmoncar",
    "esmoncastes": "esmoncar",
    "esmoncava": "esmoncar",
    "esmoncavam": "esmoncar",
    "esmoncavas": "esmoncar",
    "esmonco": "esmoncar",
    "esmoncos": "esmonco",
    "esmoncou": "esmoncar",
    "esmoncá": "esmoncar",
    "esmoncámo": "esmoncar",
    "esmoncámos": "esmoncar",
    "esmoncáramo": "esmoncar",
    "esmoncáramos": "esmoncar",
    "esmoncárei": "esmoncar",
    "esmoncáreis": "esmoncar",
    "esmoncásseis": "esmoncar",
    "esmoncássemos": "esmoncar",
    "esmoncávamo": "esmoncar",
    "esmoncávamos": "esmoncar",
    "esmoncávei": "esmoncar",
    "esmoncáveis": "esmoncar",
    "esmonda": "esmondar",
    "esmondada": "esmondar",
    "esmondadas": "esmondar",
    "esmondado": "esmondar",
    "esmondados": "esmondar",
    "esmondai": "esmondar",
    "esmondais": "esmondar",
    "esmondam": "esmondar",
    "esmondamo": "esmondar",
    "esmondamos": "esmondar",
    "esmondando": "esmondar",
    "esmondara": "esmondar",
    "esmondaram": "esmondar",
    "esmondaras": "esmondar",
    "esmondarde": "esmondar",
    "esmondardes": "esmondar",
    "esmondare": "esmondar",
    "esmondarei": "esmondar",
    "esmondareis": "esmondar",
    "esmondarem": "esmondar",
    "esmondaremos": "esmondar",
    "esmondares": "esmondar",
    "esmondaria": "esmondar",
    "esmondariam": "esmondar",
    "esmondarias": "esmondar",
    "esmondarmo": "esmondar",
    "esmondarmos": "esmondar",
    "esmondará": "esmondar",
    "esmondarás": "esmondar",
    "esmondarão": "esmondar",
    "esmondaríamos": "esmondar",
    "esmondaríeis": "esmondar",
    "esmondas": "esmondar",
    "esmondasse": "esmondar",
    "esmondassem": "esmondar",
    "esmondasses": "esmondar",
    "esmondaste": "esmondar",
    "esmondastes": "esmondar",
    "esmondava": "esmondar",
    "esmondavam": "esmondar",
    "esmondavas": "esmondar",
    "esmonde": "esmondar",
    "esmondei": "esmondar",
    "esmondeis": "esmondar",
    "esmondem": "esmondar",
    "esmondemo": "esmondar",
    "esmondemos": "esmondar",
    "esmondes": "esmondar",
    "esmondo": "esmondar",
    "esmondou": "esmondar",
    "esmondá": "esmondar",
    "esmondámo": "esmondar",
    "esmondámos": "esmondar",
    "esmondáramo": "esmondar",
    "esmondáramos": "esmondar",
    "esmondárei": "esmondar",
    "esmondáreis": "esmondar",
    "esmondásseis": "esmondar",
    "esmondássemos": "esmondar",
    "esmondávamo": "esmondar",
    "esmondávamos": "esmondar",
    "esmondávei": "esmondar",
    "esmondáveis": "esmondar",
    "esmonque": "esmoncar",
    "esmonquei": "esmoncar",
    "esmonqueis": "esmoncar",
    "esmonquem": "esmoncar",
    "esmonquemo": "esmoncar",
    "esmonquemos": "esmoncar",
    "esmonques": "esmoncar",
    "esmoo": "esmoer",
    "esmoque": "esmocar",
    "esmoquei": "esmocar",
    "esmoqueis": "esmocar",
    "esmoquem": "esmocar",
    "esmoquemo": "esmocar",
    "esmoquemos": "esmocar",
    "esmoques": "esmocar",
    "esmordace": "esmordaçar",
    "esmordacei": "esmordaçar",
    "esmordaceis": "esmordaçar",
    "esmordacem": "esmordaçar",
    "esmordacemo": "esmordaçar",
    "esmordacemos": "esmordaçar",
    "esmordaces": "esmordaçar",
    "esmordaça": "esmordaçar",
    "esmordaçada": "esmordaçar",
    "esmordaçadas": "esmordaçar",
    "esmordaçado": "esmordaçar",
    "esmordaçados": "esmordaçar",
    "esmordaçai": "esmordaçar",
    "esmordaçais": "esmordaçar",
    "esmordaçam": "esmordaçar",
    "esmordaçamo": "esmordaçar",
    "esmordaçamos": "esmordaçar",
    "esmordaçando": "esmordaçar",
    "esmordaçara": "esmordaçar",
    "esmordaçaram": "esmordaçar",
    "esmordaçaras": "esmordaçar",
    "esmordaçarde": "esmordaçar",
    "esmordaçardes": "esmordaçar",
    "esmordaçare": "esmordaçar",
    "esmordaçarei": "esmordaçar",
    "esmordaçareis": "esmordaçar",
    "esmordaçarem": "esmordaçar",
    "esmordaçaremos": "esmordaçar",
    "esmordaçares": "esmordaçar",
    "esmordaçaria": "esmordaçar",
    "esmordaçariam": "esmordaçar",
    "esmordaçarias": "esmordaçar",
    "esmordaçarmo": "esmordaçar",
    "esmordaçarmos": "esmordaçar",
    "esmordaçará": "esmordaçar",
    "esmordaçarás": "esmordaçar",
    "esmordaçarão": "esmordaçar",
    "esmordaçaríamos": "esmordaçar",
    "esmordaçaríeis": "esmordaçar",
    "esmordaças": "esmordaçar",
    "esmordaçasse": "esmordaçar",
    "esmordaçassem": "esmordaçar",
    "esmordaçasses": "esmordaçar",
    "esmordaçaste": "esmordaçar",
    "esmordaçastes": "esmordaçar",
    "esmordaçava": "esmordaçar",
    "esmordaçavam": "esmordaçar",
    "esmordaçavas": "esmordaçar",
    "esmordaço": "esmordaçar",
    "esmordaçou": "esmordaçar",
    "esmordaçá": "esmordaçar",
    "esmordaçámo": "esmordaçar",
    "esmordaçámos": "esmordaçar",
    "esmordaçáramo": "esmordaçar",
    "esmordaçáramos": "esmordaçar",
    "esmordaçárei": "esmordaçar",
    "esmordaçáreis": "esmordaçar",
    "esmordaçásseis": "esmordaçar",
    "esmordaçássemos": "esmordaçar",
    "esmordaçávamo": "esmordaçar",
    "esmordaçávamos": "esmordaçar",
    "esmordaçávei": "esmordaçar",
    "esmordaçáveis": "esmordaçar",
    "esmordica": "esmordicar",
    "esmordicada": "esmordicar",
    "esmordicadas": "esmordicar",
    "esmordicado": "esmordicar",
    "esmordicados": "esmordicar",
    "esmordicai": "esmordicar",
    "esmordicais": "esmordicar",
    "esmordicam": "esmordicar",
    "esmordicamo": "esmordicar",
    "esmordicamos": "esmordicar",
    "esmordicando": "esmordicar",
    "esmordicara": "esmordicar",
    "esmordicaram": "esmordicar",
    "esmordicaras": "esmordicar",
    "esmordicarde": "esmordicar",
    "esmordicardes": "esmordicar",
    "esmordicare": "esmordicar",
    "esmordicarei": "esmordicar",
    "esmordicareis": "esmordicar",
    "esmordicarem": "esmordicar",
    "esmordicaremos": "esmordicar",
    "esmordicares": "esmordicar",
    "esmordicaria": "esmordicar",
    "esmordicariam": "esmordicar",
    "esmordicarias": "esmordicar",
    "esmordicarmo": "esmordicar",
    "esmordicarmos": "esmordicar",
    "esmordicará": "esmordicar",
    "esmordicarás": "esmordicar",
    "esmordicarão": "esmordicar",
    "esmordicaríamos": "esmordicar",
    "esmordicaríeis": "esmordicar",
    "esmordicas": "esmordicar",
    "esmordicasse": "esmordicar",
    "esmordicassem": "esmordicar",
    "esmordicasses": "esmordicar",
    "esmordicaste": "esmordicar",
    "esmordicastes": "esmordicar",
    "esmordicava": "esmordicar",
    "esmordicavam": "esmordicar",
    "esmordicavas": "esmordicar",
    "esmordico": "esmordicar",
    "esmordicou": "esmordicar",
    "esmordicá": "esmordicar",
    "esmordicámo": "esmordicar",
    "esmordicámos": "esmordicar",
    "esmordicáramo": "esmordicar",
    "esmordicáramos": "esmordicar",
    "esmordicárei": "esmordicar",
    "esmordicáreis": "esmordicar",
    "esmordicásseis": "esmordicar",
    "esmordicássemos": "esmordicar",
    "esmordicávamo": "esmordicar",
    "esmordicávamos": "esmordicar",
    "esmordicávei": "esmordicar",
    "esmordicáveis": "esmordicar",
    "esmordique": "esmordicar",
    "esmordiquei": "esmordicar",
    "esmordiqueis": "esmordicar",
    "esmordiquem": "esmordicar",
    "esmordiquemo": "esmordicar",
    "esmordiquemos": "esmordicar",
    "esmordiques": "esmordicar",
    "esmorece": "esmorecer",
    "esmorecei": "esmorecer",
    "esmoreceis": "esmorecer",
    "esmorecem": "esmorecer",
    "esmorecemo": "esmorecer",
    "esmorecemos": "esmorecer",
    "esmorecendo": "esmorecer",
    "esmorecera": "esmorecer",
    "esmoreceram": "esmorecer",
    "esmoreceras": "esmorecer",
    "esmorecerdes": "esmorecer",
    "esmorecerei": "esmorecer",
    "esmorecereis": "esmorecer",
    "esmorecerem": "esmorecer",
    "esmoreceremos": "esmorecer",
    "esmoreceres": "esmorecer",
    "esmoreceria": "esmorecer",
    "esmoreceriam": "esmorecer",
    "esmorecerias": "esmorecer",
    "esmorecermo": "esmorecer",
    "esmorecermos": "esmorecer",
    "esmorecerá": "esmorecer",
    "esmorecerás": "esmorecer",
    "esmorecerão": "esmorecer",
    "esmoreceríamos": "esmorecer",
    "esmoreceríeis": "esmorecer",
    "esmoreces": "esmorecer",
    "esmorecesse": "esmorecer",
    "esmorecessem": "esmorecer",
    "esmorecesses": "esmorecer",
    "esmoreceste": "esmorecer",
    "esmorecestes": "esmorecer",
    "esmoreceu": "esmorecer",
    "esmoreci": "esmorecer",
    "esmorecia": "esmorecer",
    "esmoreciam": "esmorecer",
    "esmorecias": "esmorecer",
    "esmorecida": "esmorecido",
    "esmorecidas": "esmorecido",
    "esmorecido": "esmorecer",
    "esmorecidos": "esmorecido",
    "esmorecidíssima": "esmorecido",
    "esmorecidíssimas": "esmorecido",
    "esmorecidíssimo": "esmorecido",
    "esmorecidíssimos": "esmorecido",
    "esmorecimentos": "esmorecimento",
    "esmorecêramo": "esmorecer",
    "esmorecêramos": "esmorecer",
    "esmorecêreis": "esmorecer",
    "esmorecêsseis": "esmorecer",
    "esmorecêssemos": "esmorecer",
    "esmorecíamo": "esmorecer",
    "esmorecíamos": "esmorecer",
    "esmorecíeis": "esmorecer",
    "esmoreça": "esmorecer",
    "esmoreçais": "esmorecer",
    "esmoreçam": "esmorecer",
    "esmoreçamo": "esmorecer",
    "esmoreçamos": "esmorecer",
    "esmoreças": "esmorecer",
    "esmoreço": "esmorecer",
    "esmorida": "esmorido",
    "esmoridas": "esmorido",
    "esmoridos": "esmorido",
    "esmorona": "esmoronar",
    "esmoronada": "esmoronar",
    "esmoronadas": "esmoronar",
    "esmoronado": "esmoronar",
    "esmoronados": "esmoronar",
    "esmoronai": "esmoronar",
    "esmoronais": "esmoronar",
    "esmoronam": "esmoronar",
    "esmoronamo": "esmoronar",
    "esmoronamos": "esmoronar",
    "esmoronando": "esmoronar",
    "esmoronara": "esmoronar",
    "esmoronaram": "esmoronar",
    "esmoronaras": "esmoronar",
    "esmoronarde": "esmoronar",
    "esmoronardes": "esmoronar",
    "esmoronare": "esmoronar",
    "esmoronarei": "esmoronar",
    "esmoronareis": "esmoronar",
    "esmoronarem": "esmoronar",
    "esmoronaremos": "esmoronar",
    "esmoronares": "esmoronar",
    "esmoronaria": "esmoronar",
    "esmoronariam": "esmoronar",
    "esmoronarias": "esmoronar",
    "esmoronarmo": "esmoronar",
    "esmoronarmos": "esmoronar",
    "esmoronará": "esmoronar",
    "esmoronarás": "esmoronar",
    "esmoronarão": "esmoronar",
    "esmoronaríamos": "esmoronar",
    "esmoronaríeis": "esmoronar",
    "esmoronas": "esmoronar",
    "esmoronasse": "esmoronar",
    "esmoronassem": "esmoronar",
    "esmoronasses": "esmoronar",
    "esmoronaste": "esmoronar",
    "esmoronastes": "esmoronar",
    "esmoronava": "esmoronar",
    "esmoronavam": "esmoronar",
    "esmoronavas": "esmoronar",
    "esmorone": "esmoronar",
    "esmoronei": "esmoronar",
    "esmoroneis": "esmoronar",
    "esmoronem": "esmoronar",
    "esmoronemo": "esmoronar",
    "esmoronemos": "esmoronar",
    "esmorones": "esmoronar",
    "esmorono": "esmoronar",
    "esmoronou": "esmoronar",
    "esmoroná": "esmoronar",
    "esmoronámo": "esmoronar",
    "esmoronámos": "esmoronar",
    "esmoronáramo": "esmoronar",
    "esmoronáramos": "esmoronar",
    "esmoronárei": "esmoronar",
    "esmoronáreis": "esmoronar",
    "esmoronásseis": "esmoronar",
    "esmoronássemos": "esmoronar",
    "esmoronávamo": "esmoronar",
    "esmoronávamos": "esmoronar",
    "esmoronávei": "esmoronar",
    "esmoronáveis": "esmoronar",
    "esmorrace": "esmorraçar",
    "esmorracei": "esmorraçar",
    "esmorraceis": "esmorraçar",
    "esmorracem": "esmorraçar",
    "esmorracemo": "esmorraçar",
    "esmorracemos": "esmorraçar",
    "esmorraces": "esmorraçar",
    "esmorraça": "esmorraçar",
    "esmorraçada": "esmorraçar",
    "esmorraçadas": "esmorraçar",
    "esmorraçado": "esmorraçar",
    "esmorraçados": "esmorraçar",
    "esmorraçai": "esmorraçar",
    "esmorraçais": "esmorraçar",
    "esmorraçam": "esmorraçar",
    "esmorraçamo": "esmorraçar",
    "esmorraçamos": "esmorraçar",
    "esmorraçando": "esmorraçar",
    "esmorraçara": "esmorraçar",
    "esmorraçaram": "esmorraçar",
    "esmorraçaras": "esmorraçar",
    "esmorraçarde": "esmorraçar",
    "esmorraçardes": "esmorraçar",
    "esmorraçare": "esmorraçar",
    "esmorraçarei": "esmorraçar",
    "esmorraçareis": "esmorraçar",
    "esmorraçarem": "esmorraçar",
    "esmorraçaremos": "esmorraçar",
    "esmorraçares": "esmorraçar",
    "esmorraçaria": "esmorraçar",
    "esmorraçariam": "esmorraçar",
    "esmorraçarias": "esmorraçar",
    "esmorraçarmo": "esmorraçar",
    "esmorraçarmos": "esmorraçar",
    "esmorraçará": "esmorraçar",
    "esmorraçarás": "esmorraçar",
    "esmorraçarão": "esmorraçar",
    "esmorraçaríamos": "esmorraçar",
    "esmorraçaríeis": "esmorraçar",
    "esmorraças": "esmorraçar",
    "esmorraçasse": "esmorraçar",
    "esmorraçassem": "esmorraçar",
    "esmorraçasses": "esmorraçar",
    "esmorraçaste": "esmorraçar",
    "esmorraçastes": "esmorraçar",
    "esmorraçava": "esmorraçar",
    "esmorraçavam": "esmorraçar",
    "esmorraçavas": "esmorraçar",
    "esmorraço": "esmorraçar",
    "esmorraçou": "esmorraçar",
    "esmorraçá": "esmorraçar",
    "esmorraçámo": "esmorraçar",
    "esmorraçámos": "esmorraçar",
    "esmorraçáramo": "esmorraçar",
    "esmorraçáramos": "esmorraçar",
    "esmorraçárei": "esmorraçar",
    "esmorraçáreis": "esmorraçar",
    "esmorraçásseis": "esmorraçar",
    "esmorraçássemos": "esmorraçar",
    "esmorraçávamo": "esmorraçar",
    "esmorraçávamos": "esmorraçar",
    "esmorraçávei": "esmorraçar",
    "esmorraçáveis": "esmorraçar",
    "esmos": "esmo",
    "esmossa": "esmossar",
    "esmossada": "esmossar",
    "esmossadas": "esmossar",
    "esmossado": "esmossar",
    "esmossados": "esmossar",
    "esmossai": "esmossar",
    "esmossais": "esmossar",
    "esmossam": "esmossar",
    "esmossamo": "esmossar",
    "esmossamos": "esmossar",
    "esmossando": "esmossar",
    "esmossara": "esmossar",
    "esmossaram": "esmossar",
    "esmossaras": "esmossar",
    "esmossarde": "esmossar",
    "esmossardes": "esmossar",
    "esmossare": "esmossar",
    "esmossarei": "esmossar",
    "esmossareis": "esmossar",
    "esmossarem": "esmossar",
    "esmossaremos": "esmossar",
    "esmossares": "esmossar",
    "esmossaria": "esmossar",
    "esmossariam": "esmossar",
    "esmossarias": "esmossar",
    "esmossarmo": "esmossar",
    "esmossarmos": "esmossar",
    "esmossará": "esmossar",
    "esmossarás": "esmossar",
    "esmossarão": "esmossar",
    "esmossaríamos": "esmossar",
    "esmossaríeis": "esmossar",
    "esmossas": "esmossar",
    "esmossasse": "esmossar",
    "esmossassem": "esmossar",
    "esmossasses": "esmossar",
    "esmossaste": "esmossar",
    "esmossastes": "esmossar",
    "esmossava": "esmossar",
    "esmossavam": "esmossar",
    "esmossavas": "esmossar",
    "esmosse": "esmossar",
    "esmossei": "esmossar",
    "esmosseis": "esmossar",
    "esmossem": "esmossar",
    "esmossemo": "esmossar",
    "esmossemos": "esmossar",
    "esmosses": "esmossar",
    "esmosso": "esmossar",
    "esmossou": "esmossar",
    "esmossá": "esmossar",
    "esmossámo": "esmossar",
    "esmossámos": "esmossar",
    "esmossáramo": "esmossar",
    "esmossáramos": "esmossar",
    "esmossárei": "esmossar",
    "esmossáreis": "esmossar",
    "esmossásseis": "esmossar",
    "esmossássemos": "esmossar",
    "esmossávamo": "esmossar",
    "esmossávamos": "esmossar",
    "esmossávei": "esmossar",
    "esmossáveis": "esmossar",
    "esmou": "esmar",
    "esmouca": "esmoucar",
    "esmoucada": "esmoucar",
    "esmoucadas": "esmoucar",
    "esmoucadelas": "esmoucadela",
    "esmoucado": "esmoucar",
    "esmoucados": "esmoucar",
    "esmoucai": "esmoucar",
    "esmoucais": "esmoucar",
    "esmoucam": "esmoucar",
    "esmoucamo": "esmoucar",
    "esmoucamos": "esmoucar",
    "esmoucando": "esmoucar",
    "esmoucara": "esmoucar",
    "esmoucaram": "esmoucar",
    "esmoucaras": "esmoucar",
    "esmoucarde": "esmoucar",
    "esmoucardes": "esmoucar",
    "esmoucare": "esmoucar",
    "esmoucarei": "esmoucar",
    "esmoucareis": "esmoucar",
    "esmoucarem": "esmoucar",
    "esmoucaremos": "esmoucar",
    "esmoucares": "esmoucar",
    "esmoucaria": "esmoucar",
    "esmoucariam": "esmoucar",
    "esmoucarias": "esmoucar",
    "esmoucarmo": "esmoucar",
    "esmoucarmos": "esmoucar",
    "esmoucará": "esmoucar",
    "esmoucarás": "esmoucar",
    "esmoucarão": "esmoucar",
    "esmoucaríamos": "esmoucar",
    "esmoucaríeis": "esmoucar",
    "esmoucas": "esmoucar",
    "esmoucasse": "esmoucar",
    "esmoucassem": "esmoucar",
    "esmoucasses": "esmoucar",
    "esmoucaste": "esmoucar",
    "esmoucastes": "esmoucar",
    "esmoucava": "esmoucar",
    "esmoucavam": "esmoucar",
    "esmoucavas": "esmoucar",
    "esmouco": "esmoucar",
    "esmoucou": "esmoucar",
    "esmoucá": "esmoucar",
    "esmoucámo": "esmoucar",
    "esmoucámos": "esmoucar",
    "esmoucáramo": "esmoucar",
    "esmoucáramos": "esmoucar",
    "esmoucárei": "esmoucar",
    "esmoucáreis": "esmoucar",
    "esmoucásseis": "esmoucar",
    "esmoucássemos": "esmoucar",
    "esmoucávamo": "esmoucar",
    "esmoucávamos": "esmoucar",
    "esmoucávei": "esmoucar",
    "esmoucáveis": "esmoucar",
    "esmouque": "esmoucar",
    "esmouquei": "esmoucar",
    "esmouqueis": "esmoucar",
    "esmouquem": "esmoucar",
    "esmouquemo": "esmoucar",
    "esmouquemos": "esmoucar",
    "esmouques": "esmoucar",
    "esmouta": "esmoutar",
    "esmoutada": "esmoutar",
    "esmoutadas": "esmoutar",
    "esmoutado": "esmoutar",
    "esmoutados": "esmoutar",
    "esmoutai": "esmoutar",
    "esmoutais": "esmoutar",
    "esmoutam": "esmoutar",
    "esmoutamo": "esmoutar",
    "esmoutamos": "esmoutar",
    "esmoutando": "esmoutar",
    "esmoutara": "esmoutar",
    "esmoutaram": "esmoutar",
    "esmoutaras": "esmoutar",
    "esmoutarde": "esmoutar",
    "esmoutardes": "esmoutar",
    "esmoutare": "esmoutar",
    "esmoutarei": "esmoutar",
    "esmoutareis": "esmoutar",
    "esmoutarem": "esmoutar",
    "esmoutaremos": "esmoutar",
    "esmoutares": "esmoutar",
    "esmoutaria": "esmoutar",
    "esmoutariam": "esmoutar",
    "esmoutarias": "esmoutar",
    "esmoutarmo": "esmoutar",
    "esmoutarmos": "esmoutar",
    "esmoutará": "esmoutar",
    "esmoutarás": "esmoutar",
    "esmoutarão": "esmoutar",
    "esmoutaríamos": "esmoutar",
    "esmoutaríeis": "esmoutar",
    "esmoutas": "esmoutar",
    "esmoutasse": "esmoutar",
    "esmoutassem": "esmoutar",
    "esmoutasses": "esmoutar",
    "esmoutaste": "esmoutar",
    "esmoutastes": "esmoutar",
    "esmoutava": "esmoutar",
    "esmoutavam": "esmoutar",
    "esmoutavas": "esmoutar",
    "esmoute": "esmoutar",
    "esmoutei": "esmoutar",
    "esmouteis": "esmoutar",
    "esmoutem": "esmoutar",
    "esmoutemo": "esmoutar",
    "esmoutemos": "esmoutar",
    "esmoutes": "esmoutar",
    "esmouto": "esmoutar",
    "esmoutou": "esmoutar",
    "esmoutá": "esmoutar",
    "esmoutámo": "esmoutar",
    "esmoutámos": "esmoutar",
    "esmoutáramo": "esmoutar",
    "esmoutáramos": "esmoutar",
    "esmoutárei": "esmoutar",
    "esmoutáreis": "esmoutar",
    "esmoutásseis": "esmoutar",
    "esmoutássemos": "esmoutar",
    "esmoutávamo": "esmoutar",
    "esmoutávamos": "esmoutar",
    "esmoutávei": "esmoutar",
    "esmoutáveis": "esmoutar",
    "esmoçadelas": "esmoçadela",
    "esmoê": "esmoer",
    "esmoêramo": "esmoer",
    "esmoêramos": "esmoer",
    "esmoêrei": "esmoer",
    "esmoêreis": "esmoer",
    "esmoêsseis": "esmoer",
    "esmoêssemos": "esmoer",
    "esmoí": "esmoer",
    "esmoía": "esmoer",
    "esmoíam": "esmoer",
    "esmoíamo": "esmoer",
    "esmoíamos": "esmoer",
    "esmoías": "esmoer",
    "esmoída": "esmoer",
    "esmoídas": "esmoer",
    "esmoído": "esmoer",
    "esmoídos": "esmoer",
    "esmoíei": "esmoer",
    "esmoíeis": "esmoer",
    "esmurra": "esmurrar",
    "esmurrace": "esmurraçar",
    "esmurracei": "esmurraçar",
    "esmurraceis": "esmurraçar",
    "esmurracem": "esmurraçar",
    "esmurracemo": "esmurraçar",
    "esmurracemos": "esmurraçar",
    "esmurraces": "esmurraçar",
    "esmurrada": "esmurrar",
    "esmurradas": "esmurrar",
    "esmurrado": "esmurrar",
    "esmurrados": "esmurrar",
    "esmurrai": "esmurrar",
    "esmurrais": "esmurrar",
    "esmurram": "esmurrar",
    "esmurramo": "esmurrar",
    "esmurramos": "esmurrar",
    "esmurrando": "esmurrar",
    "esmurrara": "esmurrar",
    "esmurraram": "esmurrar",
    "esmurraras": "esmurrar",
    "esmurrarde": "esmurrar",
    "esmurrardes": "esmurrar",
    "esmurrare": "esmurrar",
    "esmurrarei": "esmurrar",
    "esmurrareis": "esmurrar",
    "esmurrarem": "esmurrar",
    "esmurraremos": "esmurrar",
    "esmurrares": "esmurrar",
    "esmurraria": "esmurrar",
    "esmurrariam": "esmurrar",
    "esmurrarias": "esmurrar",
    "esmurrarmo": "esmurrar",
    "esmurrarmos": "esmurrar",
    "esmurrará": "esmurrar",
    "esmurrarás": "esmurrar",
    "esmurrarão": "esmurrar",
    "esmurraríamos": "esmurrar",
    "esmurraríeis": "esmurrar",
    "esmurras": "esmurrar",
    "esmurrasse": "esmurrar",
    "esmurrassem": "esmurrar",
    "esmurrasses": "esmurrar",
    "esmurraste": "esmurrar",
    "esmurrastes": "esmurrar",
    "esmurrava": "esmurrar",
    "esmurravam": "esmurrar",
    "esmurravas": "esmurrar",
    "esmurraça": "esmurraçar",
    "esmurraçada": "esmurraçar",
    "esmurraçadas": "esmurraçar",
    "esmurraçado": "esmurraçar",
    "esmurraçadora": "esmurraçador",
    "esmurraçadoras": "esmurraçador",
    "esmurraçadores": "esmurraçador",
    "esmurraçados": "esmurraçar",
    "esmurraçai": "esmurraçar",
    "esmurraçais": "esmurraçar",
    "esmurraçam": "esmurraçar",
    "esmurraçamo": "esmurraçar",
    "esmurraçamos": "esmurraçar",
    "esmurraçando": "esmurraçar",
    "esmurraçara": "esmurraçar",
    "esmurraçaram": "esmurraçar",
    "esmurraçaras": "esmurraçar",
    "esmurraçarde": "esmurraçar",
    "esmurraçardes": "esmurraçar",
    "esmurraçare": "esmurraçar",
    "esmurraçarei": "esmurraçar",
    "esmurraçareis": "esmurraçar",
    "esmurraçarem": "esmurraçar",
    "esmurraçaremos": "esmurraçar",
    "esmurraçares": "esmurraçar",
    "esmurraçaria": "esmurraçar",
    "esmurraçariam": "esmurraçar",
    "esmurraçarias": "esmurraçar",
    "esmurraçarmo": "esmurraçar",
    "esmurraçarmos": "esmurraçar",
    "esmurraçará": "esmurraçar",
    "esmurraçarás": "esmurraçar",
    "esmurraçarão": "esmurraçar",
    "esmurraçaríamos": "esmurraçar",
    "esmurraçaríeis": "esmurraçar",
    "esmurraças": "esmurraçar",
    "esmurraçasse": "esmurraçar",
    "esmurraçassem": "esmurraçar",
    "esmurraçasses": "esmurraçar",
    "esmurraçaste": "esmurraçar",
    "esmurraçastes": "esmurraçar",
    "esmurraçava": "esmurraçar",
    "esmurraçavam": "esmurraçar",
    "esmurraçavas": "esmurraçar",
    "esmurraço": "esmurraçar",
    "esmurraçou": "esmurraçar",
    "esmurraçá": "esmurraçar",
    "esmurraçámo": "esmurraçar",
    "esmurraçámos": "esmurraçar",
    "esmurraçáramo": "esmurraçar",
    "esmurraçáramos": "esmurraçar",
    "esmurraçárei": "esmurraçar",
    "esmurraçáreis": "esmurraçar",
    "esmurraçásseis": "esmurraçar",
    "esmurraçássemos": "esmurraçar",
    "esmurraçávamo": "esmurraçar",
    "esmurraçávamos": "esmurraçar",
    "esmurraçávei": "esmurraçar",
    "esmurraçáveis": "esmurraçar",
    "esmurre": "esmurrar",
    "esmurrei": "esmurrar",
    "esmurreis": "esmurrar",
    "esmurrem": "esmurrar",
    "esmurremo": "esmurrar",
    "esmurremos": "esmurrar",
    "esmurres": "esmurrar",
    "esmurro": "esmurrar",
    "esmurrou": "esmurrar",
    "esmurrá": "esmurrar",
    "esmurrámo": "esmurrar",
    "esmurrámos": "esmurrar",
    "esmurráramo": "esmurrar",
    "esmurráramos": "esmurrar",
    "esmurrárei": "esmurrar",
    "esmurráreis": "esmurrar",
    "esmurrásseis": "esmurrar",
    "esmurrássemos": "esmurrar",
    "esmurrávamo": "esmurrar",
    "esmurrávamos": "esmurrar",
    "esmurrávei": "esmurrar",
    "esmurráveis": "esmurrar",
    "esmá": "esmar",
    "esmámo": "esmar",
    "esmámos": "esmar",
    "esmáramo": "esmar",
    "esmáramos": "esmar",
    "esmárei": "esmar",
    "esmáreis": "esmar",
    "esmásseis": "esmar",
    "esmássemos": "esmar",
    "esmávamo": "esmar",
    "esmávamos": "esmar",
    "esmávei": "esmar",
    "esmáveis": "esmar",
    "esméctica": "esméctico",
    "esmécticas": "esméctico",
    "esmécticos": "esméctico",
    "esmói": "esmoer",
    "esmóis": "esmoer",
    "esnoca": "esnocar",
    "esnocada": "esnocar",
    "esnocadas": "esnocar",
    "esnocado": "esnocar",
    "esnocados": "esnocar",
    "esnocai": "esnocar",
    "esnocais": "esnocar",
    "esnocam": "esnocar",
    "esnocamo": "esnocar",
    "esnocamos": "esnocar",
    "esnocando": "esnocar",
    "esnocara": "esnocar",
    "esnocaram": "esnocar",
    "esnocaras": "esnocar",
    "esnocarde": "esnocar",
    "esnocardes": "esnocar",
    "esnocare": "esnocar",
    "esnocarei": "esnocar",
    "esnocareis": "esnocar",
    "esnocarem": "esnocar",
    "esnocaremos": "esnocar",
    "esnocares": "esnocar",
    "esnocaria": "esnocar",
    "esnocariam": "esnocar",
    "esnocarias": "esnocar",
    "esnocarmo": "esnocar",
    "esnocarmos": "esnocar",
    "esnocará": "esnocar",
    "esnocarás": "esnocar",
    "esnocarão": "esnocar",
    "esnocaríamos": "esnocar",
    "esnocaríeis": "esnocar",
    "esnocas": "esnocar",
    "esnocasse": "esnocar",
    "esnocassem": "esnocar",
    "esnocasses": "esnocar",
    "esnocaste": "esnocar",
    "esnocastes": "esnocar",
    "esnocava": "esnocar",
    "esnocavam": "esnocar",
    "esnocavas": "esnocar",
    "esnoco": "esnocar",
    "esnocou": "esnocar",
    "esnocá": "esnocar",
    "esnocámo": "esnocar",
    "esnocámos": "esnocar",
    "esnocáramo": "esnocar",
    "esnocáramos": "esnocar",
    "esnocárei": "esnocar",
    "esnocáreis": "esnocar",
    "esnocásseis": "esnocar",
    "esnocássemos": "esnocar",
    "esnocávamo": "esnocar",
    "esnocávamos": "esnocar",
    "esnocávei": "esnocar",
    "esnocáveis": "esnocar",
    "esnogas": "esnoga",
    "esnoque": "esnocar",
    "esnoquei": "esnocar",
    "esnoqueis": "esnocar",
    "esnoquem": "esnocar",
    "esnoquemo": "esnocar",
    "esnoquemos": "esnocar",
    "esnoques": "esnocar",
    "esocídea": "esocídeo",
    "esocídeas": "esocídeo",
    "esocídeos": "esocídeo",
    "esoderma": "esodermo",
    "esodermas": "esodermo",
    "esodermes": "esoderme",
    "esodermos": "esodermo",
    "esodérmica": "esodérmico",
    "esodérmicas": "esodérmico",
    "esodérmicos": "esodérmico",
    "esofagias": "esofagia",
    "esofagismos": "esofagismo",
    "esofagites": "esofagite",
    "esofagoscopias": "esofagoscopia",
    "esofagoscópica": "esofagoscópico",
    "esofagoscópicas": "esofagoscópico",
    "esofagoscópicos": "esofagoscópico",
    "esofagostómica": "esofagostómico",
    "esofagostómicas": "esofagostómico",
    "esofagostómicos": "esofagostómico",
    "esofagotomias": "esofagotomia",
    "esofagotómica": "esofagotómico",
    "esofagotómicas": "esofagotómico",
    "esofagotómicos": "esofagotómico",
    "esoforias": "esoforia",
    "esofágica": "esofágico",
    "esofágicas": "esofágico",
    "esofágicos": "esofágico",
    "esofórica": "esofórico",
    "esofóricas": "esofórico",
    "esofóricos": "esofórico",
    "esoterismos": "esoterismo",
    "esotérica": "esotérico",
    "esotéricas": "esotérico",
    "esotéricos": "esotérico",
    "espace": "espaçar",
    "espaceada": "espacear",
    "espaceadas": "espacear",
    "espaceado": "espacear",
    "espaceados": "espacear",
    "espaceai": "espacear",
    "espaceais": "espacear",
    "espaceamo": "espacear",
    "espaceamos": "espacear",
    "espaceando": "espacear",
    "espaceara": "espacear",
    "espacearam": "espacear",
    "espacearas": "espacear",
    "espacearde": "espacear",
    "espaceardes": "espacear",
    "espaceare": "espacear",
    "espacearei": "espacear",
    "espaceareis": "espacear",
    "espacearem": "espacear",
    "espacearemos": "espacear",
    "espaceares": "espacear",
    "espacearia": "espacear",
    "espaceariam": "espacear",
    "espacearias": "espacear",
    "espacearmo": "espacear",
    "espacearmos": "espacear",
    "espaceará": "espacear",
    "espacearás": "espacear",
    "espacearão": "espacear",
    "espacearíamos": "espacear",
    "espacearíeis": "espacear",
    "espaceasse": "espacear",
    "espaceassem": "espacear",
    "espaceasses": "espacear",
    "espaceaste": "espacear",
    "espaceastes": "espacear",
    "espaceava": "espacear",
    "espaceavam": "espacear",
    "espaceavas": "espacear",
    "espaceei": "espacear",
    "espaceeis": "espacear",
    "espaceemo": "espacear",
    "espaceemos": "espacear",
    "espacei": "espaçar",
    "espaceia": "espacear",
    "espaceiam": "espacear",
    "espaceias": "espacear",
    "espaceie": "espacear",
    "espaceiem": "espacear",
    "espaceies": "espacear",
    "espaceio": "espacear",
    "espaceis": "espaçar",
    "espaceja": "espacejar",
    "espacejada": "espacejar",
    "espacejadas": "espacejar",
    "espacejado": "espacejar",
    "espacejados": "espacejar",
    "espacejai": "espacejar",
    "espacejais": "espacejar",
    "espacejam": "espacejar",
    "espacejamo": "espacejar",
    "espacejamos": "espacejar",
    "espacejando": "espacejar",
    "espacejara": "espacejar",
    "espacejaram": "espacejar",
    "espacejaras": "espacejar",
    "espacejarde": "espacejar",
    "espacejardes": "espacejar",
    "espacejare": "espacejar",
    "espacejarei": "espacejar",
    "espacejareis": "espacejar",
    "espacejarem": "espacejar",
    "espacejaremos": "espacejar",
    "espacejares": "espacejar",
    "espacejaria": "espacejar",
    "espacejariam": "espacejar",
    "espacejarias": "espacejar",
    "espacejarmo": "espacejar",
    "espacejarmos": "espacejar",
    "espacejará": "espacejar",
    "espacejarás": "espacejar",
    "espacejarão": "espacejar",
    "espacejaríamos": "espacejar",
    "espacejaríeis": "espacejar",
    "espacejas": "espacejar",
    "espacejasse": "espacejar",
    "espacejassem": "espacejar",
    "espacejasses": "espacejar",
    "espacejaste": "espacejar",
    "espacejastes": "espacejar",
    "espacejava": "espacejar",
    "espacejavam": "espacejar",
    "espacejavas": "espacejar",
    "espaceje": "espacejar",
    "espacejei": "espacejar",
    "espacejeis": "espacejar",
    "espacejem": "espacejar",
    "espacejemo": "espacejar",
    "espacejemos": "espacejar",
    "espacejes": "espacejar",
    "espacejo": "espacejar",
    "espacejou": "espacejar",
    "espacejá": "espacejar",
    "espacejámo": "espacejar",
    "espacejámos": "espacejar",
    "espacejáramo": "espacejar",
    "espacejáramos": "espacejar",
    "espacejárei": "espacejar",
    "espacejáreis": "espacejar",
    "espacejásseis": "espacejar",
    "espacejássemos": "espacejar",
    "espacejávamo": "espacejar",
    "espacejávamos": "espacejar",
    "espacejávei": "espacejar",
    "espacejáveis": "espacejar",
    "espacem": "espaçar",
    "espacemo": "espaçar",
    "espacemos": "espaçar",
    "espaceou": "espacear",
    "espaces": "espaçar",
    "espaceá": "espacear",
    "espaceámo": "espacear",
    "espaceámos": "espacear",
    "espaceáramo": "espacear",
    "espaceáramos": "espacear",
    "espaceárei": "espacear",
    "espaceáreis": "espacear",
    "espaceásseis": "espacear",
    "espaceássemos": "espacear",
    "espaceávamo": "espacear",
    "espaceávamos": "espacear",
    "espaceávei": "espacear",
    "espaceáveis": "espacear",
    "espaciais": "espacial",
    "espacinho": "espaço",
    "espacinhos": "espaço",
    "espacito": "espaço",
    "espacitos": "espaço",
    "espada": "espadar",
    "espadachins": "espadachim",
    "espadada": "espadar",
    "espadadas": "espadar",
    "espadado": "espadar",
    "espadados": "espadar",
    "espadaga": "espadagar",
    "espadagada": "espadagar",
    "espadagadas": "espadagar",
    "espadagado": "espadagar",
    "espadagados": "espadagar",
    "espadagai": "espadagar",
    "espadagais": "espadagar",
    "espadagam": "espadagar",
    "espadagamo": "espadagar",
    "espadagamos": "espadagar",
    "espadagando": "espadagar",
    "espadagara": "espadagar",
    "espadagaram": "espadagar",
    "espadagaras": "espadagar",
    "espadagarde": "espadagar",
    "espadagardes": "espadagar",
    "espadagare": "espadagar",
    "espadagarei": "espadagar",
    "espadagareis": "espadagar",
    "espadagarem": "espadagar",
    "espadagaremos": "espadagar",
    "espadagares": "espadagar",
    "espadagaria": "espadagar",
    "espadagariam": "espadagar",
    "espadagarias": "espadagar",
    "espadagarmo": "espadagar",
    "espadagarmos": "espadagar",
    "espadagará": "espadagar",
    "espadagarás": "espadagar",
    "espadagarão": "espadagar",
    "espadagaríamos": "espadagar",
    "espadagaríeis": "espadagar",
    "espadagas": "espadagar",
    "espadagasse": "espadagar",
    "espadagassem": "espadagar",
    "espadagasses": "espadagar",
    "espadagaste": "espadagar",
    "espadagastes": "espadagar",
    "espadagava": "espadagar",
    "espadagavam": "espadagar",
    "espadagavas": "espadagar",
    "espadago": "espadagar",
    "espadagou": "espadagar",
    "espadague": "espadagar",
    "espadaguei": "espadagar",
    "espadagueis": "espadagar",
    "espadaguem": "espadagar",
    "espadaguemo": "espadagar",
    "espadaguemos": "espadagar",
    "espadagues": "espadagar",
    "espadagá": "espadagar",
    "espadagámo": "espadagar",
    "espadagámos": "espadagar",
    "espadagáramo": "espadagar",
    "espadagáramos": "espadagar",
    "espadagárei": "espadagar",
    "espadagáreis": "espadagar",
    "espadagásseis": "espadagar",
    "espadagássemos": "espadagar",
    "espadagávamo": "espadagar",
    "espadagávamos": "espadagar",
    "espadagávei": "espadagar",
    "espadagáveis": "espadagar",
    "espadagões": "espadagão",
    "espadai": "espadar",
    "espadais": "espadar",
    "espadam": "espadar",
    "espadamo": "espadar",
    "espadamos": "espadar",
    "espadana": "espadanar",
    "espadanada": "espadanar",
    "espadanadas": "espadanar",
    "espadanado": "espadanar",
    "espadanados": "espadanar",
    "espadanai": "espadanar",
    "espadanais": "espadanar",
    "espadanam": "espadanar",
    "espadanamo": "espadanar",
    "espadanamos": "espadanar",
    "espadanando": "espadanar",
    "espadanara": "espadanar",
    "espadanaram": "espadanar",
    "espadanaras": "espadanar",
    "espadanarde": "espadanar",
    "espadanardes": "espadanar",
    "espadanare": "espadanar",
    "espadanarei": "espadanar",
    "espadanareis": "espadanar",
    "espadanarem": "espadanar",
    "espadanaremos": "espadanar",
    "espadanares": "espadanar",
    "espadanaria": "espadanar",
    "espadanariam": "espadanar",
    "espadanarias": "espadanar",
    "espadanarmo": "espadanar",
    "espadanarmos": "espadanar",
    "espadanará": "espadanar",
    "espadanarás": "espadanar",
    "espadanarão": "espadanar",
    "espadanaríamos": "espadanar",
    "espadanaríeis": "espadanar",
    "espadanas": "espadanar",
    "espadanasse": "espadanar",
    "espadanassem": "espadanar",
    "espadanasses": "espadanar",
    "espadanaste": "espadanar",
    "espadanastes": "espadanar",
    "espadanava": "espadanar",
    "espadanavam": "espadanar",
    "espadanavas": "espadanar",
    "espadando": "espadar",
    "espadane": "espadanar",
    "espadanei": "espadanar",
    "espadaneis": "espadanar",
    "espadanem": "espadanar",
    "espadanemo": "espadanar",
    "espadanemos": "espadanar",
    "espadanes": "espadanar",
    "espadano": "espadanar",
    "espadanou": "espadanar",
    "espadaná": "espadanar",
    "espadanámo": "espadanar",
    "espadanámos": "espadanar",
    "espadanáramo": "espadanar",
    "espadanáramos": "espadanar",
    "espadanárei": "espadanar",
    "espadanáreis": "espadanar",
    "espadanásseis": "espadanar",
    "espadanássemos": "espadanar",
    "espadanávamo": "espadanar",
    "espadanávamos": "espadanar",
    "espadanávei": "espadanar",
    "espadanáveis": "espadanar",
    "espadara": "espadar",
    "espadaram": "espadar",
    "espadaras": "espadar",
    "espadarde": "espadar",
    "espadardes": "espadar",
    "espadare": "espadar",
    "espadarei": "espadar",
    "espadareis": "espadar",
    "espadarem": "espadar",
    "espadaremos": "espadar",
    "espadares": "espadar",
    "espadaria": "espadar",
    "espadariam": "espadar",
    "espadarias": "espadar",
    "espadarmo": "espadar",
    "espadarmos": "espadar",
    "espadarrões": "espadarrão",
    "espadartes": "espadarte",
    "espadará": "espadar",
    "espadarás": "espadar",
    "espadarão": "espadar",
    "espadaríamos": "espadar",
    "espadaríeis": "espadar",
    "espadas": "espadar",
    "espadasse": "espadar",
    "espadassem": "espadar",
    "espadasses": "espadar",
    "espadaste": "espadar",
    "espadastes": "espadar",
    "espadava": "espadar",
    "espadavam": "espadar",
    "espadavas": "espadar",
    "espadaúda": "espadaúdo",
    "espadaúdas": "espadaúdo",
    "espadaúdos": "espadaúdo",
    "espade": "espadar",
    "espadei": "espadar",
    "espadeira": "espadeiro",
    "espadeirada": "espadeirar",
    "espadeiradas": "espadeirar",
    "espadeirado": "espadeirar",
    "espadeirados": "espadeirar",
    "espadeirai": "espadeirar",
    "espadeirais": "espadeirar",
    "espadeiram": "espadeirar",
    "espadeiramo": "espadeirar",
    "espadeiramos": "espadeirar",
    "espadeirando": "espadeirar",
    "espadeirara": "espadeirar",
    "espadeiraram": "espadeirar",
    "espadeiraras": "espadeirar",
    "espadeirarde": "espadeirar",
    "espadeirardes": "espadeirar",
    "espadeirare": "espadeirar",
    "espadeirarei": "espadeirar",
    "espadeirareis": "espadeirar",
    "espadeirarem": "espadeirar",
    "espadeiraremos": "espadeirar",
    "espadeirares": "espadeirar",
    "espadeiraria": "espadeirar",
    "espadeirariam": "espadeirar",
    "espadeirarias": "espadeirar",
    "espadeirarmo": "espadeirar",
    "espadeirarmos": "espadeirar",
    "espadeirará": "espadeirar",
    "espadeirarás": "espadeirar",
    "espadeirarão": "espadeirar",
    "espadeiraríamos": "espadeirar",
    "espadeiraríeis": "espadeirar",
    "espadeiras": "espadeiro",
    "espadeirasse": "espadeirar",
    "espadeirassem": "espadeirar",
    "espadeirasses": "espadeirar",
    "espadeiraste": "espadeirar",
    "espadeirastes": "espadeirar",
    "espadeirava": "espadeirar",
    "espadeiravam": "espadeirar",
    "espadeiravas": "espadeirar",
    "espadeire": "espadeirar",
    "espadeirei": "espadeirar",
    "espadeireis": "espadeirar",
    "espadeirem": "espadeirar",
    "espadeiremo": "espadeirar",
    "espadeiremos": "espadeirar",
    "espadeires": "espadeirar",
    "espadeiro": "espadeirar",
    "espadeiros": "espadeiro",
    "espadeirou": "espadeirar",
    "espadeirá": "espadeirar",
    "espadeirámo": "espadeirar",
    "espadeirámos": "espadeirar",
    "espadeiráramo": "espadeirar",
    "espadeiráramos": "espadeirar",
    "espadeirárei": "espadeirar",
    "espadeiráreis": "espadeirar",
    "espadeirásseis": "espadeirar",
    "espadeirássemos": "espadeirar",
    "espadeirávamo": "espadeirar",
    "espadeirávamos": "espadeirar",
    "espadeirávei": "espadeirar",
    "espadeiráveis": "espadeirar",
    "espadeirões": "espadeirão",
    "espadeis": "espadar",
    "espadela": "espadelar",
    "espadelada": "espadelar",
    "espadeladas": "espadelar",
    "espadeladeiras": "espadeladeira",
    "espadelado": "espadelar",
    "espadeladoiros": "espadeladoiro",
    "espadeladora": "espadelador",
    "espadeladoras": "espadelador",
    "espadeladores": "espadelador",
    "espadelados": "espadelar",
    "espadeladouros": "espadeladouro",
    "espadelagens": "espadelagem",
    "espadelai": "espadelar",
    "espadelais": "espadelar",
    "espadelam": "espadelar",
    "espadelamo": "espadelar",
    "espadelamos": "espadelar",
    "espadelando": "espadelar",
    "espadelara": "espadelar",
    "espadelaram": "espadelar",
    "espadelaras": "espadelar",
    "espadelarde": "espadelar",
    "espadelardes": "espadelar",
    "espadelare": "espadelar",
    "espadelarei": "espadelar",
    "espadelareis": "espadelar",
    "espadelarem": "espadelar",
    "espadelaremos": "espadelar",
    "espadelares": "espadelar",
    "espadelaria": "espadelar",
    "espadelariam": "espadelar",
    "espadelarias": "espadelar",
    "espadelarmo": "espadelar",
    "espadelarmos": "espadelar",
    "espadelará": "espadelar",
    "espadelarás": "espadelar",
    "espadelarão": "espadelar",
    "espadelaríamos": "espadelar",
    "espadelaríeis": "espadelar",
    "espadelas": "espadelar",
    "espadelasse": "espadelar",
    "espadelassem": "espadelar",
    "espadelasses": "espadelar",
    "espadelaste": "espadelar",
    "espadelastes": "espadelar",
    "espadelava": "espadelar",
    "espadelavam": "espadelar",
    "espadelavas": "espadelar",
    "espadele": "espadelar",
    "espadelei": "espadelar",
    "espadeleiros": "espadeleiro",
    "espadeleis": "espadelar",
    "espadelem": "espadelar",
    "espadelemo": "espadelar",
    "espadelemos": "espadelar",
    "espadeles": "espadelar",
    "espadelo": "espadelar",
    "espadelou": "espadelar",
    "espadelá": "espadelar",
    "espadelámo": "espadelar",
    "espadelámos": "espadelar",
    "espadeláramo": "espadelar",
    "espadeláramos": "espadelar",
    "espadelárei": "espadelar",
    "espadeláreis": "espadelar",
    "espadelásseis": "espadelar",
    "espadelássemos": "espadelar",
    "espadelávamo": "espadelar",
    "espadelávamos": "espadelar",
    "espadelávei": "espadelar",
    "espadeláveis": "espadelar",
    "espadem": "espadar",
    "espademo": "espadar",
    "espademos": "espadar",
    "espades": "espadar",
    "espadices": "espadice",
    "espadilhas": "espadilha",
    "espadilheiros": "espadilheiro",
    "espadins": "espadim",
    "espado": "espadar",
    "espadou": "espadar",
    "espadua": "espaduar",
    "espaduada": "espaduar",
    "espaduadas": "espaduar",
    "espaduado": "espaduar",
    "espaduados": "espaduar",
    "espaduai": "espaduar",
    "espaduais": "espaduar",
    "espaduam": "espaduar",
    "espaduamo": "espaduar",
    "espaduamos": "espaduar",
    "espaduando": "espaduar",
    "espaduara": "espaduar",
    "espaduaram": "espaduar",
    "espaduaras": "espaduar",
    "espaduarde": "espaduar",
    "espaduardes": "espaduar",
    "espaduare": "espaduar",
    "espaduarei": "espaduar",
    "espaduareis": "espaduar",
    "espaduarem": "espaduar",
    "espaduaremos": "espaduar",
    "espaduares": "espaduar",
    "espaduaria": "espaduar",
    "espaduariam": "espaduar",
    "espaduarias": "espaduar",
    "espaduarmo": "espaduar",
    "espaduarmos": "espaduar",
    "espaduará": "espaduar",
    "espaduarás": "espaduar",
    "espaduarão": "espaduar",
    "espaduaríamos": "espaduar",
    "espaduaríeis": "espaduar",
    "espaduas": "espaduar",
    "espaduasse": "espaduar",
    "espaduassem": "espaduar",
    "espaduasses": "espaduar",
    "espaduaste": "espaduar",
    "espaduastes": "espaduar",
    "espaduava": "espaduar",
    "espaduavam": "espaduar",
    "espaduavas": "espaduar",
    "espadue": "espaduar",
    "espaduei": "espaduar",
    "espadueis": "espaduar",
    "espaduem": "espaduar",
    "espaduemo": "espaduar",
    "espaduemos": "espaduar",
    "espadues": "espaduar",
    "espaduo": "espaduar",
    "espaduou": "espaduar",
    "espaduá": "espaduar",
    "espaduámo": "espaduar",
    "espaduámos": "espaduar",
    "espaduáramo": "espaduar",
    "espaduáramos": "espaduar",
    "espaduárei": "espaduar",
    "espaduáreis": "espaduar",
    "espaduásseis": "espaduar",
    "espaduássemos": "espaduar",
    "espaduávamo": "espaduar",
    "espaduávamos": "espaduar",
    "espaduávei": "espaduar",
    "espaduáveis": "espaduar",
    "espadá": "espadar",
    "espadámo": "espadar",
    "espadámos": "espadar",
    "espadáramo": "espadar",
    "espadáramos": "espadar",
    "espadárei": "espadar",
    "espadáreis": "espadar",
    "espadásseis": "espadar",
    "espadássemos": "espadar",
    "espadávamo": "espadar",
    "espadávamos": "espadar",
    "espadávei": "espadar",
    "espadáveis": "espadar",
    "espadânea": "espadâneo",
    "espadâneas": "espadâneo",
    "espadâneos": "espadâneo",
    "espadícia": "espadício",
    "espadícias": "espadício",
    "espadícios": "espadício",
    "espadões": "espadão",
    "espaguetis": "espagueti",
    "espagírias": "espagíria",
    "espairece": "espairecer",
    "espairecei": "espairecer",
    "espaireceis": "espairecer",
    "espairecem": "espairecer",
    "espairecemo": "espairecer",
    "espairecemos": "espairecer",
    "espairecendo": "espairecer",
    "espairecera": "espairecer",
    "espaireceram": "espairecer",
    "espaireceras": "espairecer",
    "espairecerdes": "espairecer",
    "espairecerei": "espairecer",
    "espairecereis": "espairecer",
    "espairecerem": "espairecer",
    "espaireceremos": "espairecer",
    "espaireceres": "espairecer",
    "espaireceria": "espairecer",
    "espaireceriam": "espairecer",
    "espairecerias": "espairecer",
    "espairecermo": "espairecer",
    "espairecermos": "espairecer",
    "espairecerá": "espairecer",
    "espairecerás": "espairecer",
    "espairecerão": "espairecer",
    "espaireceríamos": "espairecer",
    "espaireceríeis": "espairecer",
    "espaireces": "espairecer",
    "espairecesse": "espairecer",
    "espairecessem": "espairecer",
    "espairecesses": "espairecer",
    "espaireceste": "espairecer",
    "espairecestes": "espairecer",
    "espaireceu": "espairecer",
    "espaireci": "espairecer",
    "espairecia": "espairecer",
    "espaireciam": "espairecer",
    "espairecias": "espairecer",
    "espairecida": "espairecer",
    "espairecidas": "espairecer",
    "espairecido": "espairecer",
    "espairecidos": "espairecer",
    "espairecimentos": "espairecimento",
    "espairecêramo": "espairecer",
    "espairecêramos": "espairecer",
    "espairecêreis": "espairecer",
    "espairecêsseis": "espairecer",
    "espairecêssemos": "espairecer",
    "espairecíamo": "espairecer",
    "espairecíamos": "espairecer",
    "espairecíeis": "espairecer",
    "espaireça": "espairecer",
    "espaireçais": "espairecer",
    "espaireçam": "espairecer",
    "espaireçamo": "espairecer",
    "espaireçamos": "espairecer",
    "espaireças": "espairecer",
    "espaireço": "espairecer",
    "espaldares": "espaldar",
    "espaldas": "espalda",
    "espaldeada": "espaldear",
    "espaldeadas": "espaldear",
    "espaldeado": "espaldear",
    "espaldeados": "espaldear",
    "espaldeai": "espaldear",
    "espaldeais": "espaldear",
    "espaldeamo": "espaldear",
    "espaldeamos": "espaldear",
    "espaldeando": "espaldear",
    "espaldeara": "espaldear",
    "espaldearam": "espaldear",
    "espaldearas": "espaldear",
    "espaldearde": "espaldear",
    "espaldeardes": "espaldear",
    "espaldeare": "espaldear",
    "espaldearei": "espaldear",
    "espaldeareis": "espaldear",
    "espaldearem": "espaldear",
    "espaldearemos": "espaldear",
    "espaldeares": "espaldear",
    "espaldearia": "espaldear",
    "espaldeariam": "espaldear",
    "espaldearias": "espaldear",
    "espaldearmo": "espaldear",
    "espaldearmos": "espaldear",
    "espaldeará": "espaldear",
    "espaldearás": "espaldear",
    "espaldearão": "espaldear",
    "espaldearíamos": "espaldear",
    "espaldearíeis": "espaldear",
    "espaldeasse": "espaldear",
    "espaldeassem": "espaldear",
    "espaldeasses": "espaldear",
    "espaldeaste": "espaldear",
    "espaldeastes": "espaldear",
    "espaldeava": "espaldear",
    "espaldeavam": "espaldear",
    "espaldeavas": "espaldear",
    "espaldeei": "espaldear",
    "espaldeeis": "espaldear",
    "espaldeemo": "espaldear",
    "espaldeemos": "espaldear",
    "espaldeia": "espaldear",
    "espaldeiam": "espaldear",
    "espaldeias": "espaldear",
    "espaldeie": "espaldear",
    "espaldeiem": "espaldear",
    "espaldeies": "espaldear",
    "espaldeio": "espaldear",
    "espaldeira": "espaldeirar",
    "espaldeirada": "espaldeirar",
    "espaldeiradas": "espaldeirar",
    "espaldeirado": "espaldeirar",
    "espaldeirados": "espaldeirar",
    "espaldeirai": "espaldeirar",
    "espaldeirais": "espaldeirar",
    "espaldeiram": "espaldeirar",
    "espaldeiramo": "espaldeirar",
    "espaldeiramos": "espaldeirar",
    "espaldeirando": "espaldeirar",
    "espaldeirara": "espaldeirar",
    "espaldeiraram": "espaldeirar",
    "espaldeiraras": "espaldeirar",
    "espaldeirarde": "espaldeirar",
    "espaldeirardes": "espaldeirar",
    "espaldeirare": "espaldeirar",
    "espaldeirarei": "espaldeirar",
    "espaldeirareis": "espaldeirar",
    "espaldeirarem": "espaldeirar",
    "espaldeiraremos": "espaldeirar",
    "espaldeirares": "espaldeirar",
    "espaldeiraria": "espaldeirar",
    "espaldeirariam": "espaldeirar",
    "espaldeirarias": "espaldeirar",
    "espaldeirarmo": "espaldeirar",
    "espaldeirarmos": "espaldeirar",
    "espaldeirará": "espaldeirar",
    "espaldeirarás": "espaldeirar",
    "espaldeirarão": "espaldeirar",
    "espaldeiraríamos": "espaldeirar",
    "espaldeiraríeis": "espaldeirar",
    "espaldeiras": "espaldeirar",
    "espaldeirasse": "espaldeirar",
    "espaldeirassem": "espaldeirar",
    "espaldeirasses": "espaldeirar",
    "espaldeiraste": "espaldeirar",
    "espaldeirastes": "espaldeirar",
    "espaldeirava": "espaldeirar",
    "espaldeiravam": "espaldeirar",
    "espaldeiravas": "espaldeirar",
    "espaldeire": "espaldeirar",
    "espaldeirei": "espaldeirar",
    "espaldeireis": "espaldeirar",
    "espaldeirem": "espaldeirar",
    "espaldeiremo": "espaldeirar",
    "espaldeiremos": "espaldeirar",
    "espaldeires": "espaldeirar",
    "espaldeiro": "espaldeirar",
    "espaldeirou": "espaldeirar",
    "espaldeirá": "espaldeirar",
    "espaldeirámo": "espaldeirar",
    "espaldeirámos": "espaldeirar",
    "espaldeiráramo": "espaldeirar",
    "espaldeiráramos": "espaldeirar",
    "espaldeirárei": "espaldeirar",
    "espaldeiráreis": "espaldeirar",
    "espaldeirásseis": "espaldeirar",
    "espaldeirássemos": "espaldeirar",
    "espaldeirávamo": "espaldeirar",
    "espaldeirávamos": "espaldeirar",
    "espaldeirávei": "espaldeirar",
    "espaldeiráveis": "espaldeirar",
    "espaldeou": "espaldear",
    "espaldetas": "espaldeta",
    "espaldeá": "espaldear",
    "espaldeámo": "espaldear",
    "espaldeámos": "espaldear",
    "espaldeáramo": "espaldear",
    "espaldeáramos": "espaldear",
    "espaldeárei": "espaldear",
    "espaldeáreis": "espaldear",
    "espaldeásseis": "espaldear",
    "espaldeássemos": "espaldear",
    "espaldeávamo": "espaldear",
    "espaldeávamos": "espaldear",
    "espaldeávei": "espaldear",
    "espaldeáveis": "espaldear",
    "espaldões": "espaldão",
    "espalha": "espalhar",
    "espalhada": "espalhar",
    "espalhadas": "espalhar",
    "espalhadeiras": "espalhadeira",
    "espalhado": "espalhar",
    "espalhadoiras": "espalhadoira",
    "espalhadora": "espalhador",
    "espalhadoras": "espalhador",
    "espalhadores": "espalhador",
    "espalhados": "espalhar",
    "espalhadouras": "espalhadoura",
    "espalhafata": "espalhafatar",
    "espalhafatada": "espalhafatar",
    "espalhafatadas": "espalhafatar",
    "espalhafatado": "espalhafatar",
    "espalhafatados": "espalhafatar",
    "espalhafatai": "espalhafatar",
    "espalhafatais": "espalhafatar",
    "espalhafatam": "espalhafatar",
    "espalhafatamo": "espalhafatar",
    "espalhafatamos": "espalhafatar",
    "espalhafatando": "espalhafatar",
    "espalhafatara": "espalhafatar",
    "espalhafataram": "espalhafatar",
    "espalhafataras": "espalhafatar",
    "espalhafatarde": "espalhafatar",
    "espalhafatardes": "espalhafatar",
    "espalhafatare": "espalhafatar",
    "espalhafatarei": "espalhafatar",
    "espalhafatareis": "espalhafatar",
    "espalhafatarem": "espalhafatar",
    "espalhafataremos": "espalhafatar",
    "espalhafatares": "espalhafatar",
    "espalhafataria": "espalhafatar",
    "espalhafatariam": "espalhafatar",
    "espalhafatarias": "espalhafatar",
    "espalhafatarmo": "espalhafatar",
    "espalhafatarmos": "espalhafatar",
    "espalhafatará": "espalhafatar",
    "espalhafatarás": "espalhafatar",
    "espalhafatarão": "espalhafatar",
    "espalhafataríamos": "espalhafatar",
    "espalhafataríeis": "espalhafatar",
    "espalhafatas": "espalhafatar",
    "espalhafatasse": "espalhafatar",
    "espalhafatassem": "espalhafatar",
    "espalhafatasses": "espalhafatar",
    "espalhafataste": "espalhafatar",
    "espalhafatastes": "espalhafatar",
    "espalhafatava": "espalhafatar",
    "espalhafatavam": "espalhafatar",
    "espalhafatavas": "espalhafatar",
    "espalhafate": "espalhafatar",
    "espalhafatei": "espalhafatar",
    "espalhafateis": "espalhafatar",
    "espalhafatem": "espalhafatar",
    "espalhafatemo": "espalhafatar",
    "espalhafatemos": "espalhafatar",
    "espalhafates": "espalhafatar",
    "espalhafato": "espalhafatar",
    "espalhafatona": "espalhafatão",
    "espalhafatonas": "espalhafatão",
    "espalhafatos": "espalhafato",
    "espalhafatosa": "espalhafatoso",
    "espalhafatosas": "espalhafatoso",
    "espalhafatosos": "espalhafatoso",
    "espalhafatou": "espalhafatar",
    "espalhafatá": "espalhafatar",
    "espalhafatámo": "espalhafatar",
    "espalhafatámos": "espalhafatar",
    "espalhafatáramo": "espalhafatar",
    "espalhafatáramos": "espalhafatar",
    "espalhafatárei": "espalhafatar",
    "espalhafatáreis": "espalhafatar",
    "espalhafatásseis": "espalhafatar",
    "espalhafatássemos": "espalhafatar",
    "espalhafatávamo": "espalhafatar",
    "espalhafatávamos": "espalhafatar",
    "espalhafatávei": "espalhafatar",
    "espalhafatáveis": "espalhafatar",
    "espalhafatões": "espalhafatão",
    "espalhaga": "espalhagar",
    "espalhagada": "espalhagar",
    "espalhagadas": "espalhagar",
    "espalhagado": "espalhagar",
    "espalhagados": "espalhagar",
    "espalhagai": "espalhagar",
    "espalhagais": "espalhagar",
    "espalhagam": "espalhagar",
    "espalhagamo": "espalhagar",
    "espalhagamos": "espalhagar",
    "espalhagando": "espalhagar",
    "espalhagara": "espalhagar",
    "espalhagaram": "espalhagar",
    "espalhagaras": "espalhagar",
    "espalhagarde": "espalhagar",
    "espalhagardes": "espalhagar",
    "espalhagare": "espalhagar",
    "espalhagarei": "espalhagar",
    "espalhagareis": "espalhagar",
    "espalhagarem": "espalhagar",
    "espalhagaremos": "espalhagar",
    "espalhagares": "espalhagar",
    "espalhagaria": "espalhagar",
    "espalhagariam": "espalhagar",
    "espalhagarias": "espalhagar",
    "espalhagarmo": "espalhagar",
    "espalhagarmos": "espalhagar",
    "espalhagará": "espalhagar",
    "espalhagarás": "espalhagar",
    "espalhagarão": "espalhagar",
    "espalhagaríamos": "espalhagar",
    "espalhagaríeis": "espalhagar",
    "espalhagas": "espalhagar",
    "espalhagasse": "espalhagar",
    "espalhagassem": "espalhagar",
    "espalhagasses": "espalhagar",
    "espalhagaste": "espalhagar",
    "espalhagastes": "espalhagar",
    "espalhagava": "espalhagar",
    "espalhagavam": "espalhagar",
    "espalhagavas": "espalhagar",
    "espalhago": "espalhagar",
    "espalhagou": "espalhagar",
    "espalhague": "espalhagar",
    "espalhaguei": "espalhagar",
    "espalhagueis": "espalhagar",
    "espalhaguem": "espalhagar",
    "espalhaguemo": "espalhagar",
    "espalhaguemos": "espalhagar",
    "espalhagues": "espalhagar",
    "espalhagá": "espalhagar",
    "espalhagámo": "espalhagar",
    "espalhagámos": "espalhagar",
    "espalhagáramo": "espalhagar",
    "espalhagáramos": "espalhagar",
    "espalhagárei": "espalhagar",
    "espalhagáreis": "espalhagar",
    "espalhagásseis": "espalhagar",
    "espalhagássemos": "espalhagar",
    "espalhagávamo": "espalhagar",
    "espalhagávamos": "espalhagar",
    "espalhagávei": "espalhagar",
    "espalhagáveis": "espalhagar",
    "espalhai": "espalhar",
    "espalhais": "espalhar",
    "espalham": "espalhar",
    "espalhamentos": "espalhamento",
    "espalhamo": "espalhar",
    "espalhamos": "espalhar",
    "espalhando": "espalhar",
    "espalhanços": "espalhanço",
    "espalhara": "espalhar",
    "espalharam": "espalhar",
    "espalharas": "espalhar",
    "espalharde": "espalhar",
    "espalhardes": "espalhar",
    "espalhare": "espalhar",
    "espalharei": "espalhar",
    "espalhareis": "espalhar",
    "espalharem": "espalhar",
    "espalharemos": "espalhar",
    "espalhares": "espalhar",
    "espalharia": "espalhar",
    "espalhariam": "espalhar",
    "espalharias": "espalhar",
    "espalharmo": "espalhar",
    "espalharmos": "espalhar",
    "espalhará": "espalhar",
    "espalharás": "espalhar",
    "espalharão": "espalhar",
    "espalharíamos": "espalhar",
    "espalharíeis": "espalhar",
    "espalhas": "espalhar",
    "espalhasse": "espalhar",
    "espalhassem": "espalhar",
    "espalhasses": "espalhar",
    "espalhaste": "espalhar",
    "espalhastes": "espalhar",
    "espalhava": "espalhar",
    "espalhavam": "espalhar",
    "espalhavas": "espalhar",
    "espalhe": "espalhar",
    "espalhei": "espalhar",
    "espalheis": "espalhar",
    "espalhem": "espalhar",
    "espalhemo": "espalhar",
    "espalhemos": "espalhar",
    "espalhes": "espalhar",
    "espalho": "espalhar",
    "espalhos": "espalho",
    "espalhou": "espalhar",
    "espalhá": "espalhar",
    "espalhámo": "espalhar",
    "espalhámos": "espalhar",
    "espalháramo": "espalhar",
    "espalháramos": "espalhar",
    "espalhárei": "espalhar",
    "espalháreis": "espalhar",
    "espalhásseis": "espalhar",
    "espalhássemos": "espalhar",
    "espalhávamo": "espalhar",
    "espalhávamos": "espalhar",
    "espalhávei": "espalhar",
    "espalháveis": "espalhável",
    "espalma": "espalmar",
    "espalmada": "espalmar",
    "espalmadas": "espalmar",
    "espalmado": "espalmar",
    "espalmadora": "espalmador",
    "espalmadoras": "espalmador",
    "espalmadores": "espalmador",
    "espalmados": "espalmar",
    "espalmaduras": "espalmadura",
    "espalmai": "espalmar",
    "espalmais": "espalmar",
    "espalmam": "espalmar",
    "espalmamentos": "espalmamento",
    "espalmamo": "espalmar",
    "espalmamos": "espalmar",
    "espalmando": "espalmar",
    "espalmara": "espalmar",
    "espalmaram": "espalmar",
    "espalmaras": "espalmar",
    "espalmarde": "espalmar",
    "espalmardes": "espalmar",
    "espalmare": "espalmar",
    "espalmarei": "espalmar",
    "espalmareis": "espalmar",
    "espalmarem": "espalmar",
    "espalmaremos": "espalmar",
    "espalmares": "espalmar",
    "espalmaria": "espalmar",
    "espalmariam": "espalmar",
    "espalmarias": "espalmar",
    "espalmarmo": "espalmar",
    "espalmarmos": "espalmar",
    "espalmará": "espalmar",
    "espalmarás": "espalmar",
    "espalmarão": "espalmar",
    "espalmaríamos": "espalmar",
    "espalmaríeis": "espalmar",
    "espalmas": "espalmar",
    "espalmasse": "espalmar",
    "espalmassem": "espalmar",
    "espalmasses": "espalmar",
    "espalmaste": "espalmar",
    "espalmastes": "espalmar",
    "espalmava": "espalmar",
    "espalmavam": "espalmar",
    "espalmavas": "espalmar",
    "espalme": "espalmar",
    "espalmei": "espalmar",
    "espalmeis": "espalmar",
    "espalmem": "espalmar",
    "espalmemo": "espalmar",
    "espalmemos": "espalmar",
    "espalmes": "espalmar",
    "espalmo": "espalmar",
    "espalmou": "espalmar",
    "espalmá": "espalmar",
    "espalmámo": "espalmar",
    "espalmámos": "espalmar",
    "espalmáramo": "espalmar",
    "espalmáramos": "espalmar",
    "espalmárei": "espalmar",
    "espalmáreis": "espalmar",
    "espalmásseis": "espalmar",
    "espalmássemos": "espalmar",
    "espalmávamo": "espalmar",
    "espalmávamos": "espalmar",
    "espalmávei": "espalmar",
    "espalmáveis": "espalmar",
    "espampanantes": "espampanante",
    "espana": "espanar",
    "espanada": "espanar",
    "espanadas": "espanar",
    "espanadelas": "espanadela",
    "espanado": "espanar",
    "espanadora": "espanador",
    "espanadoras": "espanador",
    "espanadores": "espanador",
    "espanados": "espanar",
    "espanai": "espanar",
    "espanais": "espanar",
    "espanam": "espanar",
    "espanamentos": "espanamento",
    "espanamo": "espanar",
    "espanamos": "espanar",
    "espanando": "espanar",
    "espanara": "espanar",
    "espanaram": "espanar",
    "espanaras": "espanar",
    "espanarde": "espanar",
    "espanardes": "espanar",
    "espanare": "espanar",
    "espanarei": "espanar",
    "espanareis": "espanar",
    "espanarem": "espanar",
    "espanaremos": "espanar",
    "espanares": "espanar",
    "espanaria": "espanar",
    "espanariam": "espanar",
    "espanarias": "espanar",
    "espanarmo": "espanar",
    "espanarmos": "espanar",
    "espanará": "espanar",
    "espanarás": "espanar",
    "espanarão": "espanar",
    "espanaríamos": "espanar",
    "espanaríeis": "espanar",
    "espanas": "espanar",
    "espanasca": "espanascar",
    "espanascada": "espanascar",
    "espanascadas": "espanascar",
    "espanascado": "espanascar",
    "espanascados": "espanascar",
    "espanascai": "espanascar",
    "espanascais": "espanascar",
    "espanascam": "espanascar",
    "espanascamo": "espanascar",
    "espanascamos": "espanascar",
    "espanascando": "espanascar",
    "espanascara": "espanascar",
    "espanascaram": "espanascar",
    "espanascaras": "espanascar",
    "espanascarde": "espanascar",
    "espanascardes": "espanascar",
    "espanascare": "espanascar",
    "espanascarei": "espanascar",
    "espanascareis": "espanascar",
    "espanascarem": "espanascar",
    "espanascaremos": "espanascar",
    "espanascares": "espanascar",
    "espanascaria": "espanascar",
    "espanascariam": "espanascar",
    "espanascarias": "espanascar",
    "espanascarmo": "espanascar",
    "espanascarmos": "espanascar",
    "espanascará": "espanascar",
    "espanascarás": "espanascar",
    "espanascarão": "espanascar",
    "espanascaríamos": "espanascar",
    "espanascaríeis": "espanascar",
    "espanascas": "espanascar",
    "espanascasse": "espanascar",
    "espanascassem": "espanascar",
    "espanascasses": "espanascar",
    "espanascaste": "espanascar",
    "espanascastes": "espanascar",
    "espanascava": "espanascar",
    "espanascavam": "espanascar",
    "espanascavas": "espanascar",
    "espanasco": "espanascar",
    "espanascou": "espanascar",
    "espanascá": "espanascar",
    "espanascámo": "espanascar",
    "espanascámos": "espanascar",
    "espanascáramo": "espanascar",
    "espanascáramos": "espanascar",
    "espanascárei": "espanascar",
    "espanascáreis": "espanascar",
    "espanascásseis": "espanascar",
    "espanascássemos": "espanascar",
    "espanascávamo": "espanascar",
    "espanascávamos": "espanascar",
    "espanascávei": "espanascar",
    "espanascáveis": "espanascar",
    "espanasque": "espanascar",
    "espanasquei": "espanascar",
    "espanasqueis": "espanascar",
    "espanasquem": "espanascar",
    "espanasquemo": "espanascar",
    "espanasquemos": "espanascar",
    "espanasques": "espanascar",
    "espanasse": "espanar",
    "espanassem": "espanar",
    "espanasses": "espanar",
    "espanaste": "espanar",
    "espanastes": "espanar",
    "espanava": "espanar",
    "espanavam": "espanar",
    "espanavas": "espanar",
    "espanações": "espanação",
    "espanca": "espancar",
    "espancada": "espancar",
    "espancadas": "espancar",
    "espancado": "espancar",
    "espancadora": "espancador",
    "espancadoras": "espancador",
    "espancadores": "espancador",
    "espancados": "espancar",
    "espancai": "espancar",
    "espancais": "espancar",
    "espancam": "espancar",
    "espancamentos": "espancamento",
    "espancamo": "espancar",
    "espancamos": "espancar",
    "espancando": "espancar",
    "espancara": "espancar",
    "espancaram": "espancar",
    "espancaras": "espancar",
    "espancarde": "espancar",
    "espancardes": "espancar",
    "espancare": "espancar",
    "espancarei": "espancar",
    "espancareis": "espancar",
    "espancarem": "espancar",
    "espancaremos": "espancar",
    "espancares": "espancar",
    "espancaria": "espancar",
    "espancariam": "espancar",
    "espancarias": "espancar",
    "espancarmo": "espancar",
    "espancarmos": "espancar",
    "espancará": "espancar",
    "espancarás": "espancar",
    "espancarão": "espancar",
    "espancaríamos": "espancar",
    "espancaríeis": "espancar",
    "espancas": "espancar",
    "espancasse": "espancar",
    "espancassem": "espancar",
    "espancasses": "espancar",
    "espancaste": "espancar",
    "espancastes": "espancar",
    "espancava": "espancar",
    "espancavam": "espancar",
    "espancavas": "espancar",
    "espanco": "espancar",
    "espancou": "espancar",
    "espancá": "espancar",
    "espancámo": "espancar",
    "espancámos": "espancar",
    "espancáramo": "espancar",
    "espancáramos": "espancar",
    "espancárei": "espancar",
    "espancáreis": "espancar",
    "espancásseis": "espancar",
    "espancássemos": "espancar",
    "espancávamo": "espancar",
    "espancávamos": "espancar",
    "espancávei": "espancar",
    "espancáveis": "espancar",
    "espane": "espanar",
    "espanei": "espanar",
    "espaneis": "espanar",
    "espaneja": "espanejar",
    "espanejada": "espanejar",
    "espanejadas": "espanejar",
    "espanejado": "espanejar",
    "espanejadora": "espanejador",
    "espanejadoras": "espanejador",
    "espanejadores": "espanejador",
    "espanejados": "espanejar",
    "espanejai": "espanejar",
    "espanejais": "espanejar",
    "espanejam": "espanejar",
    "espanejamo": "espanejar",
    "espanejamos": "espanejar",
    "espanejando": "espanejar",
    "espanejara": "espanejar",
    "espanejaram": "espanejar",
    "espanejaras": "espanejar",
    "espanejarde": "espanejar",
    "espanejardes": "espanejar",
    "espanejare": "espanejar",
    "espanejarei": "espanejar",
    "espanejareis": "espanejar",
    "espanejarem": "espanejar",
    "espanejaremos": "espanejar",
    "espanejares": "espanejar",
    "espanejaria": "espanejar",
    "espanejariam": "espanejar",
    "espanejarias": "espanejar",
    "espanejarmo": "espanejar",
    "espanejarmos": "espanejar",
    "espanejará": "espanejar",
    "espanejarás": "espanejar",
    "espanejarão": "espanejar",
    "espanejaríamos": "espanejar",
    "espanejaríeis": "espanejar",
    "espanejas": "espanejar",
    "espanejasse": "espanejar",
    "espanejassem": "espanejar",
    "espanejasses": "espanejar",
    "espanejaste": "espanejar",
    "espanejastes": "espanejar",
    "espanejava": "espanejar",
    "espanejavam": "espanejar",
    "espanejavas": "espanejar",
    "espaneje": "espanejar",
    "espanejei": "espanejar",
    "espanejeis": "espanejar",
    "espanejem": "espanejar",
    "espanejemo": "espanejar",
    "espanejemos": "espanejar",
    "espanejes": "espanejar",
    "espanejo": "espanejar",
    "espanejou": "espanejar",
    "espanejá": "espanejar",
    "espanejámo": "espanejar",
    "espanejámos": "espanejar",
    "espanejáramo": "espanejar",
    "espanejáramos": "espanejar",
    "espanejárei": "espanejar",
    "espanejáreis": "espanejar",
    "espanejásseis": "espanejar",
    "espanejássemos": "espanejar",
    "espanejávamo": "espanejar",
    "espanejávamos": "espanejar",
    "espanejávei": "espanejar",
    "espanejáveis": "espanejar",
    "espanem": "espanar",
    "espanemo": "espanar",
    "espanemos": "espanar",
    "espanes": "espanar",
    "espanhola": "espanholar",
    "espanholada": "espanholar",
    "espanholadas": "espanholar",
    "espanholado": "espanholar",
    "espanholados": "espanholar",
    "espanholai": "espanholar",
    "espanholais": "espanholar",
    "espanholam": "espanholar",
    "espanholamo": "espanholar",
    "espanholamos": "espanholar",
    "espanholando": "espanholar",
    "espanholara": "espanholar",
    "espanholaram": "espanholar",
    "espanholaras": "espanholar",
    "espanholarde": "espanholar",
    "espanholardes": "espanholar",
    "espanholare": "espanholar",
    "espanholarei": "espanholar",
    "espanholareis": "espanholar",
    "espanholarem": "espanholar",
    "espanholaremos": "espanholar",
    "espanholares": "espanholar",
    "espanholaria": "espanholar",
    "espanholariam": "espanholar",
    "espanholarias": "espanholar",
    "espanholarmo": "espanholar",
    "espanholarmos": "espanholar",
    "espanholará": "espanholar",
    "espanholarás": "espanholar",
    "espanholarão": "espanholar",
    "espanholaríamos": "espanholar",
    "espanholaríeis": "espanholar",
    "espanholas": "espanholar",
    "espanholasse": "espanholar",
    "espanholassem": "espanholar",
    "espanholasses": "espanholar",
    "espanholaste": "espanholar",
    "espanholastes": "espanholar",
    "espanholava": "espanholar",
    "espanholavam": "espanholar",
    "espanholavas": "espanholar",
    "espanhole": "espanholar",
    "espanholei": "espanholar",
    "espanholeis": "espanholar",
    "espanholem": "espanholar",
    "espanholemo": "espanholar",
    "espanholemos": "espanholar",
    "espanholes": "espanholar",
    "espanholismos": "espanholismo",
    "espanholiza": "espanholizar",
    "espanholizada": "espanholizar",
    "espanholizadas": "espanholizar",
    "espanholizado": "espanholizar",
    "espanholizados": "espanholizar",
    "espanholizai": "espanholizar",
    "espanholizais": "espanholizar",
    "espanholizam": "espanholizar",
    "espanholizamo": "espanholizar",
    "espanholizamos": "espanholizar",
    "espanholizando": "espanholizar",
    "espanholizara": "espanholizar",
    "espanholizaram": "espanholizar",
    "espanholizaras": "espanholizar",
    "espanholizarde": "espanholizar",
    "espanholizardes": "espanholizar",
    "espanholizare": "espanholizar",
    "espanholizarei": "espanholizar",
    "espanholizareis": "espanholizar",
    "espanholizarem": "espanholizar",
    "espanholizaremos": "espanholizar",
    "espanholizares": "espanholizar",
    "espanholizaria": "espanholizar",
    "espanholizariam": "espanholizar",
    "espanholizarias": "espanholizar",
    "espanholizarmo": "espanholizar",
    "espanholizarmos": "espanholizar",
    "espanholizará": "espanholizar",
    "espanholizarás": "espanholizar",
    "espanholizarão": "espanholizar",
    "espanholizaríamos": "espanholizar",
    "espanholizaríeis": "espanholizar",
    "espanholizas": "espanholizar",
    "espanholizasse": "espanholizar",
    "espanholizassem": "espanholizar",
    "espanholizasses": "espanholizar",
    "espanholizaste": "espanholizar",
    "espanholizastes": "espanholizar",
    "espanholizava": "espanholizar",
    "espanholizavam": "espanholizar",
    "espanholizavas": "espanholizar",
    "espanholize": "espanholizar",
    "espanholizei": "espanholizar",
    "espanholizeis": "espanholizar",
    "espanholizem": "espanholizar",
    "espanholizemo": "espanholizar",
    "espanholizemos": "espanholizar",
    "espanholizes": "espanholizar",
    "espanholizo": "espanholizar",
    "espanholizou": "espanholizar",
    "espanholizá": "espanholizar",
    "espanholizámo": "espanholizar",
    "espanholizámos": "espanholizar",
    "espanholizáramo": "espanholizar",
    "espanholizáramos": "espanholizar",
    "espanholizárei": "espanholizar",
    "espanholizáreis": "espanholizar",
    "espanholizásseis": "espanholizar",
    "espanholizássemos": "espanholizar",
    "espanholizávamo": "espanholizar",
    "espanholizávamos": "espanholizar",
    "espanholizávei": "espanholizar",
    "espanholizáveis": "espanholizável",
    "espanholo": "espanholar",
    "espanholou": "espanholar",
    "espanholá": "espanholar",
    "espanholámo": "espanholar",
    "espanholámos": "espanholar",
    "espanholáramo": "espanholar",
    "espanholáramos": "espanholar",
    "espanholárei": "espanholar",
    "espanholáreis": "espanholar",
    "espanholásseis": "espanholar",
    "espanholássemos": "espanholar",
    "espanholávamo": "espanholar",
    "espanholávamos": "espanholar",
    "espanholávei": "espanholar",
    "espanholáveis": "espanholar",
    "espanhóis": "espanhol",
    "espano": "espanar",
    "espanou": "espanar",
    "espanque": "espancar",
    "espanqueada": "espanquear",
    "espanqueadas": "espanquear",
    "espanqueado": "espanquear",
    "espanqueados": "espanquear",
    "espanqueai": "espanquear",
    "espanqueais": "espanquear",
    "espanqueamo": "espanquear",
    "espanqueamos": "espanquear",
    "espanqueando": "espanquear",
    "espanqueara": "espanquear",
    "espanquearam": "espanquear",
    "espanquearas": "espanquear",
    "espanquearde": "espanquear",
    "espanqueardes": "espanquear",
    "espanqueare": "espanquear",
    "espanquearei": "espanquear",
    "espanqueareis": "espanquear",
    "espanquearem": "espanquear",
    "espanquearemos": "espanquear",
    "espanqueares": "espanquear",
    "espanquearia": "espanquear",
    "espanqueariam": "espanquear",
    "espanquearias": "espanquear",
    "espanquearmo": "espanquear",
    "espanquearmos": "espanquear",
    "espanqueará": "espanquear",
    "espanquearás": "espanquear",
    "espanquearão": "espanquear",
    "espanquearíamos": "espanquear",
    "espanquearíeis": "espanquear",
    "espanqueasse": "espanquear",
    "espanqueassem": "espanquear",
    "espanqueasses": "espanquear",
    "espanqueaste": "espanquear",
    "espanqueastes": "espanquear",
    "espanqueava": "espanquear",
    "espanqueavam": "espanquear",
    "espanqueavas": "espanquear",
    "espanqueei": "espanquear",
    "espanqueeis": "espanquear",
    "espanqueemo": "espanquear",
    "espanqueemos": "espanquear",
    "espanquei": "espancar",
    "espanqueia": "espanquear",
    "espanqueiam": "espanquear",
    "espanqueias": "espanquear",
    "espanqueie": "espanquear",
    "espanqueiem": "espanquear",
    "espanqueies": "espanquear",
    "espanqueio": "espanquear",
    "espanqueis": "espancar",
    "espanquem": "espancar",
    "espanquemo": "espancar",
    "espanquemos": "espancar",
    "espanqueou": "espanquear",
    "espanques": "espancar",
    "espanqueá": "espanquear",
    "espanqueámo": "espanquear",
    "espanqueámos": "espanquear",
    "espanqueáramo": "espanquear",
    "espanqueáramos": "espanquear",
    "espanqueárei": "espanquear",
    "espanqueáreis": "espanquear",
    "espanqueásseis": "espanquear",
    "espanqueássemos": "espanquear",
    "espanqueávamo": "espanquear",
    "espanqueávamos": "espanquear",
    "espanqueávei": "espanquear",
    "espanqueáveis": "espanquear",
    "espanta": "espantar",
    "espantada": "espantar",
    "espantadas": "espantar",
    "espantadiça": "espantadiço",
    "espantadiças": "espantadiço",
    "espantadiços": "espantadiço",
    "espantado": "espantar",
    "espantadora": "espantador",
    "espantadoras": "espantador",
    "espantadores": "espantador",
    "espantados": "espantar",
    "espantadíssima": "espantado",
    "espantadíssimas": "espantado",
    "espantadíssimo": "espantado",
    "espantadíssimos": "espantado",
    "espantai": "espantar",
    "espantais": "espantar",
    "espantalhos": "espantalho",
    "espantam": "espantar",
    "espantamo": "espantar",
    "espantamos": "espantar",
    "espantando": "espantar",
    "espantara": "espantar",
    "espantaram": "espantar",
    "espantaras": "espantar",
    "espantarde": "espantar",
    "espantardes": "espantar",
    "espantare": "espantar",
    "espantarei": "espantar",
    "espantareis": "espantar",
    "espantarem": "espantar",
    "espantaremos": "espantar",
    "espantares": "espantar",
    "espantaria": "espantar",
    "espantariam": "espantar",
    "espantarias": "espantar",
    "espantarmo": "espantar",
    "espantarmos": "espantar",
    "espantará": "espantar",
    "espantarás": "espantar",
    "espantarão": "espantar",
    "espantaríamos": "espantar",
    "espantaríeis": "espantar",
    "espantas": "espantar",
    "espantasse": "espantar",
    "espantassem": "espantar",
    "espantasses": "espantar",
    "espantaste": "espantar",
    "espantastes": "espantar",
    "espantava": "espantar",
    "espantavam": "espantar",
    "espantavas": "espantar",
    "espante": "espantar",
    "espantei": "espantar",
    "espanteis": "espantar",
    "espantem": "espantar",
    "espantemo": "espantar",
    "espantemos": "espantar",
    "espantes": "espantar",
    "espanto": "espantar",
    "espantos": "espanto",
    "espantosa": "espantoso",
    "espantosas": "espantoso",
    "espantosos": "espantoso",
    "espantou": "espantar",
    "espantá": "espantar",
    "espantámo": "espantar",
    "espantámos": "espantar",
    "espantáramo": "espantar",
    "espantáramos": "espantar",
    "espantárei": "espantar",
    "espantáreis": "espantar",
    "espantásseis": "espantar",
    "espantássemos": "espantar",
    "espantávamo": "espantar",
    "espantávamos": "espantar",
    "espantávei": "espantar",
    "espantáveis": "espantável",
    "espaná": "espanar",
    "espanámo": "espanar",
    "espanámos": "espanar",
    "espanáramo": "espanar",
    "espanáramos": "espanar",
    "espanárei": "espanar",
    "espanáreis": "espanar",
    "espanásseis": "espanar",
    "espanássemos": "espanar",
    "espanávamo": "espanar",
    "espanávamos": "espanar",
    "espanávei": "espanar",
    "espanáveis": "espanar",
    "espanéfica": "espanéfico",
    "espanéficas": "espanéfico",
    "espanéficos": "espanéfico",
    "espapace": "espapaçar",
    "espapacei": "espapaçar",
    "espapaceis": "espapaçar",
    "espapacem": "espapaçar",
    "espapacemo": "espapaçar",
    "espapacemos": "espapaçar",
    "espapaces": "espapaçar",
    "espapada": "espapado",
    "espapadas": "espapado",
    "espapados": "espapado",
    "espaparrada": "espaparrado",
    "espaparradas": "espaparrado",
    "espaparrados": "espaparrado",
    "espapaça": "espapaçar",
    "espapaçada": "espapaçar",
    "espapaçadas": "espapaçar",
    "espapaçado": "espapaçar",
    "espapaçados": "espapaçar",
    "espapaçadíssima": "espapaçado",
    "espapaçadíssimas": "espapaçado",
    "espapaçadíssimo": "espapaçado",
    "espapaçadíssimos": "espapaçado",
    "espapaçai": "espapaçar",
    "espapaçais": "espapaçar",
    "espapaçam": "espapaçar",
    "espapaçamo": "espapaçar",
    "espapaçamos": "espapaçar",
    "espapaçando": "espapaçar",
    "espapaçara": "espapaçar",
    "espapaçaram": "espapaçar",
    "espapaçaras": "espapaçar",
    "espapaçarde": "espapaçar",
    "espapaçardes": "espapaçar",
    "espapaçare": "espapaçar",
    "espapaçarei": "espapaçar",
    "espapaçareis": "espapaçar",
    "espapaçarem": "espapaçar",
    "espapaçaremos": "espapaçar",
    "espapaçares": "espapaçar",
    "espapaçaria": "espapaçar",
    "espapaçariam": "espapaçar",
    "espapaçarias": "espapaçar",
    "espapaçarmo": "espapaçar",
    "espapaçarmos": "espapaçar",
    "espapaçará": "espapaçar",
    "espapaçarás": "espapaçar",
    "espapaçarão": "espapaçar",
    "espapaçaríamos": "espapaçar",
    "espapaçaríeis": "espapaçar",
    "espapaças": "espapaçar",
    "espapaçasse": "espapaçar",
    "espapaçassem": "espapaçar",
    "espapaçasses": "espapaçar",
    "espapaçaste": "espapaçar",
    "espapaçastes": "espapaçar",
    "espapaçava": "espapaçar",
    "espapaçavam": "espapaçar",
    "espapaçavas": "espapaçar",
    "espapaço": "espapaçar",
    "espapaçou": "espapaçar",
    "espapaçá": "espapaçar",
    "espapaçámo": "espapaçar",
    "espapaçámos": "espapaçar",
    "espapaçáramo": "espapaçar",
    "espapaçáramos": "espapaçar",
    "espapaçárei": "espapaçar",
    "espapaçáreis": "espapaçar",
    "espapaçásseis": "espapaçar",
    "espapaçássemos": "espapaçar",
    "espapaçávamo": "espapaçar",
    "espapaçávamos": "espapaçar",
    "espapaçávei": "espapaçar",
    "espapaçáveis": "espapaçar",
    "esparadrapos": "esparadrapo",
    "esparaveis": "esparavel",
    "esparavelas": "esparavela",
    "esparavonada": "esparavonado",
    "esparavonadas": "esparavonado",
    "esparavonados": "esparavonado",
    "esparavões": "esparavão",
    "esparcelada": "esparcelado",
    "esparceladas": "esparcelado",
    "esparcelados": "esparcelado",
    "esparcetas": "esparceta",
    "esparcetos": "esparceto",
    "esparelas": "esparela",
    "espargais": "espargal",
    "esparganeáceas": "esparganeácea",
    "esparganiácea": "esparganiáceo",
    "esparganiáceas": "esparganiáceo",
    "esparganiáceos": "esparganiáceo",
    "esparge": "espargir",
    "espargem": "espargir",
    "esparges": "espargir",
    "espargi": "espargir",
    "espargia": "espargir",
    "espargiam": "espargir",
    "espargias": "espargir",
    "espargida": "espargir",
    "espargidas": "espargir",
    "espargido": "espargir",
    "espargidos": "espargir",
    "espargimentos": "espargimento",
    "espargimo": "espargir",
    "espargimos": "espargir",
    "espargindo": "espargir",
    "espargira": "espargir",
    "espargiram": "espargir",
    "espargiras": "espargir",
    "espargirde": "espargir",
    "espargirdes": "espargir",
    "espargire": "espargir",
    "espargirei": "espargir",
    "espargireis": "espargir",
    "espargirem": "espargir",
    "espargiremos": "espargir",
    "espargires": "espargir",
    "espargiria": "espargir",
    "espargiriam": "espargir",
    "espargirias": "espargir",
    "espargirmo": "espargir",
    "espargirmos": "espargir",
    "espargirá": "espargir",
    "espargirás": "espargir",
    "espargirão": "espargir",
    "espargiríamos": "espargir",
    "espargiríeis": "espargir",
    "espargis": "espargir",
    "espargisse": "espargir",
    "espargissem": "espargir",
    "espargisses": "espargir",
    "espargiste": "espargir",
    "espargistes": "espargir",
    "espargiu": "espargir",
    "espargos": "espargo",
    "espargueiras": "espargueira",
    "esparguetes": "esparguete",
    "espargutas": "esparguta",
    "espargíamo": "espargir",
    "espargíamos": "espargir",
    "espargíei": "espargir",
    "espargíeis": "espargir",
    "espargíramo": "espargir",
    "espargíramos": "espargir",
    "espargírei": "espargir",
    "espargíreis": "espargir",
    "espargísseis": "espargir",
    "espargíssemos": "espargir",
    "esparja": "espargir",
    "esparjais": "espargir",
    "esparjam": "espargir",
    "esparjamo": "espargir",
    "esparjamos": "espargir",
    "esparjas": "espargir",
    "esparjo": "espargir",
    "esparra": "esparrar",
    "esparrada": "esparrar",
    "esparradas": "esparrar",
    "esparrado": "esparrar",
    "esparrados": "esparrar",
    "esparrai": "esparrar",
    "esparrais": "esparrar",
    "esparralha": "esparralhar",
    "esparralhada": "esparralhar",
    "esparralhadas": "esparralhar",
    "esparralhado": "esparralhar",
    "esparralhados": "esparralhar",
    "esparralhai": "esparralhar",
    "esparralhais": "esparralhar",
    "esparralham": "esparralhar",
    "esparralhamo": "esparralhar",
    "esparralhamos": "esparralhar",
    "esparralhando": "esparralhar",
    "esparralhara": "esparralhar",
    "esparralharam": "esparralhar",
    "esparralharas": "esparralhar",
    "esparralharde": "esparralhar",
    "esparralhardes": "esparralhar",
    "esparralhare": "esparralhar",
    "esparralharei": "esparralhar",
    "esparralhareis": "esparralhar",
    "esparralharem": "esparralhar",
    "esparralharemos": "esparralhar",
    "esparralhares": "esparralhar",
    "esparralharia": "esparralhar",
    "esparralhariam": "esparralhar",
    "esparralharias": "esparralhar",
    "esparralharmo": "esparralhar",
    "esparralharmos": "esparralhar",
    "esparralhará": "esparralhar",
    "esparralharás": "esparralhar",
    "esparralharão": "esparralhar",
    "esparralharíamos": "esparralhar",
    "esparralharíeis": "esparralhar",
    "esparralhas": "esparralhar",
    "esparralhasse": "esparralhar",
    "esparralhassem": "esparralhar",
    "esparralhasses": "esparralhar",
    "esparralhaste": "esparralhar",
    "esparralhastes": "esparralhar",
    "esparralhava": "esparralhar",
    "esparralhavam": "esparralhar",
    "esparralhavas": "esparralhar",
    "esparralhe": "esparralhar",
    "esparralhei": "esparralhar",
    "esparralheis": "esparralhar",
    "esparralhem": "esparralhar",
    "esparralhemo": "esparralhar",
    "esparralhemos": "esparralhar",
    "esparralhes": "esparralhar",
    "esparralho": "esparralhar",
    "esparralhou": "esparralhar",
    "esparralhá": "esparralhar",
    "esparralhámo": "esparralhar",
    "esparralhámos": "esparralhar",
    "esparralháramo": "esparralhar",
    "esparralháramos": "esparralhar",
    "esparralhárei": "esparralhar",
    "esparralháreis": "esparralhar",
    "esparralhásseis": "esparralhar",
    "esparralhássemos": "esparralhar",
    "esparralhávamo": "esparralhar",
    "esparralhávamos": "esparralhar",
    "esparralhávei": "esparralhar",
    "esparralháveis": "esparralhar",
    "esparram": "esparrar",
    "esparrama": "esparramar",
    "esparramada": "esparramar",
    "esparramadas": "esparramar",
    "esparramado": "esparramar",
    "esparramados": "esparramar",
    "esparramai": "esparramar",
    "esparramais": "esparramar",
    "esparramam": "esparramar",
    "esparramamo": "esparramar",
    "esparramamos": "esparramar",
    "esparramando": "esparramar",
    "esparramara": "esparramar",
    "esparramaram": "esparramar",
    "esparramaras": "esparramar",
    "esparramarde": "esparramar",
    "esparramardes": "esparramar",
    "esparramare": "esparramar",
    "esparramarei": "esparramar",
    "esparramareis": "esparramar",
    "esparramarem": "esparramar",
    "esparramaremos": "esparramar",
    "esparramares": "esparramar",
    "esparramaria": "esparramar",
    "esparramariam": "esparramar",
    "esparramarias": "esparramar",
    "esparramarmo": "esparramar",
    "esparramarmos": "esparramar",
    "esparramará": "esparramar",
    "esparramarás": "esparramar",
    "esparramarão": "esparramar",
    "esparramaríamos": "esparramar",
    "esparramaríeis": "esparramar",
    "esparramas": "esparramar",
    "esparramasse": "esparramar",
    "esparramassem": "esparramar",
    "esparramasses": "esparramar",
    "esparramaste": "esparramar",
    "esparramastes": "esparramar",
    "esparramava": "esparramar",
    "esparramavam": "esparramar",
    "esparramavas": "esparramar",
    "esparramações": "esparramação",
    "esparrame": "esparramar",
    "esparramei": "esparramar",
    "esparrameis": "esparramar",
    "esparramem": "esparramar",
    "esparramemo": "esparramar",
    "esparramemos": "esparramar",
    "esparrames": "esparramar",
    "esparramo": "esparrar",
    "esparramos": "esparrar",
    "esparramou": "esparramar",
    "esparramá": "esparramar",
    "esparramámo": "esparramar",
    "esparramámos": "esparramar",
    "esparramáramo": "esparramar",
    "esparramáramos": "esparramar",
    "esparramárei": "esparramar",
    "esparramáreis": "esparramar",
    "esparramásseis": "esparramar",
    "esparramássemos": "esparramar",
    "esparramávamo": "esparramar",
    "esparramávamos": "esparramar",
    "esparramávei": "esparramar",
    "esparramáveis": "esparramar",
    "esparrando": "esparrar",
    "esparrara": "esparrar",
    "esparraram": "esparrar",
    "esparraras": "esparrar",
    "esparrarde": "esparrar",
    "esparrardes": "esparrar",
    "esparrare": "esparrar",
    "esparrarei": "esparrar",
    "esparrareis": "esparrar",
    "esparrarem": "esparrar",
    "esparraremos": "esparrar",
    "esparrares": "esparrar",
    "esparraria": "esparrar",
    "esparrariam": "esparrar",
    "esparrarias": "esparrar",
    "esparrarmo": "esparrar",
    "esparrarmos": "esparrar",
    "esparrará": "esparrar",
    "esparrarás": "esparrar",
    "esparrarão": "esparrar",
    "esparraríamos": "esparrar",
    "esparraríeis": "esparrar",
    "esparras": "esparrar",
    "esparrasse": "esparrar",
    "esparrassem": "esparrar",
    "esparrasses": "esparrar",
    "esparraste": "esparrar",
    "esparrastes": "esparrar",
    "esparrava": "esparrar",
    "esparravam": "esparrar",
    "esparravas": "esparrar",
    "esparre": "esparrar",
    "esparrega": "esparregar",
    "esparregada": "esparregar",
    "esparregadas": "esparregar",
    "esparregado": "esparregar",
    "esparregados": "esparregar",
    "esparregai": "esparregar",
    "esparregais": "esparregar",
    "esparregam": "esparregar",
    "esparregamo": "esparregar",
    "esparregamos": "esparregar",
    "esparregando": "esparregar",
    "esparregara": "esparregar",
    "esparregaram": "esparregar",
    "esparregaras": "esparregar",
    "esparregarde": "esparregar",
    "esparregardes": "esparregar",
    "esparregare": "esparregar",
    "esparregarei": "esparregar",
    "esparregareis": "esparregar",
    "esparregarem": "esparregar",
    "esparregaremos": "esparregar",
    "esparregares": "esparregar",
    "esparregaria": "esparregar",
    "esparregariam": "esparregar",
    "esparregarias": "esparregar",
    "esparregarmo": "esparregar",
    "esparregarmos": "esparregar",
    "esparregará": "esparregar",
    "esparregarás": "esparregar",
    "esparregarão": "esparregar",
    "esparregaríamos": "esparregar",
    "esparregaríeis": "esparregar",
    "esparregas": "esparregar",
    "esparregasse": "esparregar",
    "esparregassem": "esparregar",
    "esparregasses": "esparregar",
    "esparregaste": "esparregar",
    "esparregastes": "esparregar",
    "esparregava": "esparregar",
    "esparregavam": "esparregar",
    "esparregavas": "esparregar",
    "esparrego": "esparregar",
    "esparregou": "esparregar",
    "esparregue": "esparregar",
    "esparreguei": "esparregar",
    "esparregueis": "esparregar",
    "esparreguem": "esparregar",
    "esparreguemo": "esparregar",
    "esparreguemos": "esparregar",
    "esparregues": "esparregar",
    "esparregá": "esparregar",
    "esparregámo": "esparregar",
    "esparregámos": "esparregar",
    "esparregáramo": "esparregar",
    "esparregáramos": "esparregar",
    "esparregárei": "esparregar",
    "esparregáreis": "esparregar",
    "esparregásseis": "esparregar",
    "esparregássemos": "esparregar",
    "esparregávamo": "esparregar",
    "esparregávamos": "esparregar",
    "esparregávei": "esparregar",
    "esparregáveis": "esparregar",
    "esparrei": "esparrar",
    "esparreis": "esparrar",
    "esparrelas": "esparrela",
    "esparrem": "esparrar",
    "esparremo": "esparrar",
    "esparremos": "esparrar",
    "esparres": "esparrar",
    "esparrinha": "esparrinhar",
    "esparrinhada": "esparrinhar",
    "esparrinhadas": "esparrinhar",
    "esparrinhado": "esparrinhar",
    "esparrinhados": "esparrinhar",
    "esparrinhai": "esparrinhar",
    "esparrinhais": "esparrinhar",
    "esparrinham": "esparrinhar",
    "esparrinhamo": "esparrinhar",
    "esparrinhamos": "esparrinhar",
    "esparrinhando": "esparrinhar",
    "esparrinhara": "esparrinhar",
    "esparrinharam": "esparrinhar",
    "esparrinharas": "esparrinhar",
    "esparrinharde": "esparrinhar",
    "esparrinhardes": "esparrinhar",
    "esparrinhare": "esparrinhar",
    "esparrinharei": "esparrinhar",
    "esparrinhareis": "esparrinhar",
    "esparrinharem": "esparrinhar",
    "esparrinharemos": "esparrinhar",
    "esparrinhares": "esparrinhar",
    "esparrinharia": "esparrinhar",
    "esparrinhariam": "esparrinhar",
    "esparrinharias": "esparrinhar",
    "esparrinharmo": "esparrinhar",
    "esparrinharmos": "esparrinhar",
    "esparrinhará": "esparrinhar",
    "esparrinharás": "esparrinhar",
    "esparrinharão": "esparrinhar",
    "esparrinharíamos": "esparrinhar",
    "esparrinharíeis": "esparrinhar",
    "esparrinhas": "esparrinhar",
    "esparrinhasse": "esparrinhar",
    "esparrinhassem": "esparrinhar",
    "esparrinhasses": "esparrinhar",
    "esparrinhaste": "esparrinhar",
    "esparrinhastes": "esparrinhar",
    "esparrinhava": "esparrinhar",
    "esparrinhavam": "esparrinhar",
    "esparrinhavas": "esparrinhar",
    "esparrinhe": "esparrinhar",
    "esparrinhei": "esparrinhar",
    "esparrinheis": "esparrinhar",
    "esparrinhem": "esparrinhar",
    "esparrinhemo": "esparrinhar",
    "esparrinhemos": "esparrinhar",
    "esparrinhes": "esparrinhar",
    "esparrinho": "esparrinhar",
    "esparrinhou": "esparrinhar",
    "esparrinhá": "esparrinhar",
    "esparrinhámo": "esparrinhar",
    "esparrinhámos": "esparrinhar",
    "esparrinháramo": "esparrinhar",
    "esparrinháramos": "esparrinhar",
    "esparrinhárei": "esparrinhar",
    "esparrinháreis": "esparrinhar",
    "esparrinhásseis": "esparrinhar",
    "esparrinhássemos": "esparrinhar",
    "esparrinhávamo": "esparrinhar",
    "esparrinhávamos": "esparrinhar",
    "esparrinhávei": "esparrinhar",
    "esparrinháveis": "esparrinhar",
    "esparro": "esparrar",
    "esparrou": "esparrar",
    "esparrá": "esparrar",
    "esparrámo": "esparrar",
    "esparrámos": "esparrar",
    "esparráramo": "esparrar",
    "esparráramos": "esparrar",
    "esparrárei": "esparrar",
    "esparráreis": "esparrar",
    "esparrásseis": "esparrar",
    "esparrássemos": "esparrar",
    "esparrávamo": "esparrar",
    "esparrávamos": "esparrar",
    "esparrávei": "esparrar",
    "esparráveis": "esparrar",
    "esparsa": "esparso",
    "esparsas": "esparso",
    "esparsos": "esparso",
    "esparta": "espartir",
    "espartais": "espartir",
    "espartam": "espartir",
    "espartamo": "espartir",
    "espartamos": "espartir",
    "espartana": "espartano",
    "espartanas": "espartano",
    "espartanidades": "espartanidade",
    "espartanos": "espartano",
    "espartarias": "espartaria",
    "espartas": "espartir",
    "esparte": "espartir",
    "esparteiras": "esparteira",
    "esparteiros": "esparteiro",
    "esparteja": "espartejar",
    "espartejada": "espartejar",
    "espartejadas": "espartejar",
    "espartejado": "espartejar",
    "espartejados": "espartejar",
    "espartejai": "espartejar",
    "espartejais": "espartejar",
    "espartejam": "espartejar",
    "espartejamo": "espartejar",
    "espartejamos": "espartejar",
    "espartejando": "espartejar",
    "espartejara": "espartejar",
    "espartejaram": "espartejar",
    "espartejaras": "espartejar",
    "espartejarde": "espartejar",
    "espartejardes": "espartejar",
    "espartejare": "espartejar",
    "espartejarei": "espartejar",
    "espartejareis": "espartejar",
    "espartejarem": "espartejar",
    "espartejaremos": "espartejar",
    "espartejares": "espartejar",
    "espartejaria": "espartejar",
    "espartejariam": "espartejar",
    "espartejarias": "espartejar",
    "espartejarmo": "espartejar",
    "espartejarmos": "espartejar",
    "espartejará": "espartejar",
    "espartejarás": "espartejar",
    "espartejarão": "espartejar",
    "espartejaríamos": "espartejar",
    "espartejaríeis": "espartejar",
    "espartejas": "espartejar",
    "espartejasse": "espartejar",
    "espartejassem": "espartejar",
    "espartejasses": "espartejar",
    "espartejaste": "espartejar",
    "espartejastes": "espartejar",
    "espartejava": "espartejar",
    "espartejavam": "espartejar",
    "espartejavas": "espartejar",
    "esparteje": "espartejar",
    "espartejei": "espartejar",
    "espartejeis": "espartejar",
    "espartejem": "espartejar",
    "espartejemo": "espartejar",
    "espartejemos": "espartejar",
    "espartejes": "espartejar",
    "espartejo": "espartejar",
    "espartejou": "espartejar",
    "espartejá": "espartejar",
    "espartejámo": "espartejar",
    "espartejámos": "espartejar",
    "espartejáramo": "espartejar",
    "espartejáramos": "espartejar",
    "espartejárei": "espartejar",
    "espartejáreis": "espartejar",
    "espartejásseis": "espartejar",
    "espartejássemos": "espartejar",
    "espartejávamo": "espartejar",
    "espartejávamos": "espartejar",
    "espartejávei": "espartejar",
    "espartejáveis": "espartejar",
    "espartem": "espartir",
    "espartenhas": "espartenha",
    "espartes": "espartir",
    "esparteínas": "esparteína",
    "esparti": "espartir",
    "espartia": "espartir",
    "espartiam": "espartir",
    "espartias": "espartir",
    "espartida": "espartir",
    "espartidas": "espartir",
    "espartido": "espartir",
    "espartidos": "espartir",
    "espartilha": "espartilhar",
    "espartilhada": "espartilhar",
    "espartilhadas": "espartilhar",
    "espartilhado": "espartilhar",
    "espartilhados": "espartilhar",
    "espartilhai": "espartilhar",
    "espartilhais": "espartilhar",
    "espartilham": "espartilhar",
    "espartilhamentos": "espartilhamento",
    "espartilhamo": "espartilhar",
    "espartilhamos": "espartilhar",
    "espartilhando": "espartilhar",
    "espartilhara": "espartilhar",
    "espartilharam": "espartilhar",
    "espartilharas": "espartilhar",
    "espartilharde": "espartilhar",
    "espartilhardes": "espartilhar",
    "espartilhare": "espartilhar",
    "espartilharei": "espartilhar",
    "espartilhareis": "espartilhar",
    "espartilharem": "espartilhar",
    "espartilharemos": "espartilhar",
    "espartilhares": "espartilhar",
    "espartilharia": "espartilhar",
    "espartilhariam": "espartilhar",
    "espartilharias": "espartilhar",
    "espartilharmo": "espartilhar",
    "espartilharmos": "espartilhar",
    "espartilhará": "espartilhar",
    "espartilharás": "espartilhar",
    "espartilharão": "espartilhar",
    "espartilharíamos": "espartilhar",
    "espartilharíeis": "espartilhar",
    "espartilhas": "espartilhar",
    "espartilhasse": "espartilhar",
    "espartilhassem": "espartilhar",
    "espartilhasses": "espartilhar",
    "espartilhaste": "espartilhar",
    "espartilhastes": "espartilhar",
    "espartilhava": "espartilhar",
    "espartilhavam": "espartilhar",
    "espartilhavas": "espartilhar",
    "espartilhe": "espartilhar",
    "espartilhei": "espartilhar",
    "espartilheiros": "espartilheiro",
    "espartilheis": "espartilhar",
    "espartilhem": "espartilhar",
    "espartilhemo": "espartilhar",
    "espartilhemos": "espartilhar",
    "espartilhes": "espartilhar",
    "espartilho": "espartilhar",
    "espartilhos": "espartilho",
    "espartilhou": "espartilhar",
    "espartilhá": "espartilhar",
    "espartilhámo": "espartilhar",
    "espartilhámos": "espartilhar",
    "espartilháramo": "espartilhar",
    "espartilháramos": "espartilhar",
    "espartilhárei": "espartilhar",
    "espartilháreis": "espartilhar",
    "espartilhásseis": "espartilhar",
    "espartilhássemos": "espartilhar",
    "espartilhávamo": "espartilhar",
    "espartilhávamos": "espartilhar",
    "espartilhávei": "espartilhar",
    "espartilháveis": "espartilhar",
    "espartimo": "espartir",
    "espartimos": "espartir",
    "espartindo": "espartir",
    "espartira": "espartir",
    "espartiram": "espartir",
    "espartiras": "espartir",
    "espartirde": "espartir",
    "espartirdes": "espartir",
    "espartire": "espartir",
    "espartirei": "espartir",
    "espartireis": "espartir",
    "espartirem": "espartir",
    "espartiremos": "espartir",
    "espartires": "espartir",
    "espartiria": "espartir",
    "espartiriam": "espartir",
    "espartirias": "espartir",
    "espartirmo": "espartir",
    "espartirmos": "espartir",
    "espartirá": "espartir",
    "espartirás": "espartir",
    "espartirão": "espartir",
    "espartiríamos": "espartir",
    "espartiríeis": "espartir",
    "espartis": "espartir",
    "espartisse": "espartir",
    "espartissem": "espartir",
    "espartisses": "espartir",
    "espartiste": "espartir",
    "espartistes": "espartir",
    "espartiu": "espartir",
    "esparto": "espartir",
    "espartos": "esparto",
    "espartíamo": "espartir",
    "espartíamos": "espartir",
    "espartíei": "espartir",
    "espartíeis": "espartir",
    "espartíramo": "espartir",
    "espartíramos": "espartir",
    "espartírei": "espartir",
    "espartíreis": "espartir",
    "espartísseis": "espartir",
    "espartíssemos": "espartir",
    "espartões": "espartão",
    "esparva": "esparvar",
    "esparvada": "esparvar",
    "esparvadas": "esparvar",
    "esparvado": "esparvar",
    "esparvados": "esparvar",
    "esparvai": "esparvar",
    "esparvais": "esparvar",
    "esparvam": "esparvar",
    "esparvamo": "esparvar",
    "esparvamos": "esparvar",
    "esparvando": "esparvar",
    "esparvara": "esparvar",
    "esparvaram": "esparvar",
    "esparvaras": "esparvar",
    "esparvarde": "esparvar",
    "esparvardes": "esparvar",
    "esparvare": "esparvar",
    "esparvarei": "esparvar",
    "esparvareis": "esparvar",
    "esparvarem": "esparvar",
    "esparvaremos": "esparvar",
    "esparvares": "esparvar",
    "esparvaria": "esparvar",
    "esparvariam": "esparvar",
    "esparvarias": "esparvar",
    "esparvarmo": "esparvar",
    "esparvarmos": "esparvar",
    "esparvará": "esparvar",
    "esparvarás": "esparvar",
    "esparvarão": "esparvar",
    "esparvaríamos": "esparvar",
    "esparvaríeis": "esparvar",
    "esparvas": "esparvar",
    "esparvasse": "esparvar",
    "esparvassem": "esparvar",
    "esparvasses": "esparvar",
    "esparvaste": "esparvar",
    "esparvastes": "esparvar",
    "esparvava": "esparvar",
    "esparvavam": "esparvar",
    "esparvavas": "esparvar",
    "esparve": "esparvar",
    "esparvei": "esparvar",
    "esparveis": "esparvar",
    "esparvem": "esparvar",
    "esparvemo": "esparvar",
    "esparvemos": "esparvar",
    "esparves": "esparvar",
    "esparvo": "esparvar",
    "esparvonada": "esparvonado",
    "esparvonadas": "esparvonado",
    "esparvonados": "esparvonado",
    "esparvou": "esparvar",
    "esparvá": "esparvar",
    "esparvámo": "esparvar",
    "esparvámos": "esparvar",
    "esparváramo": "esparvar",
    "esparváramos": "esparvar",
    "esparvárei": "esparvar",
    "esparváreis": "esparvar",
    "esparvásseis": "esparvar",
    "esparvássemos": "esparvar",
    "esparvávamo": "esparvar",
    "esparvávamos": "esparvar",
    "esparvávei": "esparvar",
    "esparváveis": "esparvar",
    "esparvões": "esparvão",
    "esparza": "esparzir",
    "esparzais": "esparzir",
    "esparzam": "esparzir",
    "esparzamo": "esparzir",
    "esparzamos": "esparzir",
    "esparzas": "esparzir",
    "esparze": "esparzir",
    "esparzem": "esparzir",
    "esparzes": "esparzir",
    "esparzetas": "esparzeta",
    "esparzi": "esparzir",
    "esparzia": "esparzir",
    "esparziam": "esparzir",
    "esparzias": "esparzir",
    "esparzida": "esparzir",
    "esparzidas": "esparzir",
    "esparzido": "esparzir",
    "esparzidos": "esparzir",
    "esparzimo": "esparzir",
    "esparzimos": "esparzir",
    "esparzindo": "esparzir",
    "esparzira": "esparzir",
    "esparziram": "esparzir",
    "esparziras": "esparzir",
    "esparzirde": "esparzir",
    "esparzirdes": "esparzir",
    "esparzire": "esparzir",
    "esparzirei": "esparzir",
    "esparzireis": "esparzir",
    "esparzirem": "esparzir",
    "esparziremos": "esparzir",
    "esparzires": "esparzir",
    "esparziria": "esparzir",
    "esparziriam": "esparzir",
    "esparzirias": "esparzir",
    "esparzirmo": "esparzir",
    "esparzirmos": "esparzir",
    "esparzirá": "esparzir",
    "esparzirás": "esparzir",
    "esparzirão": "esparzir",
    "esparziríamos": "esparzir",
    "esparziríeis": "esparzir",
    "esparzis": "esparzir",
    "esparzisse": "esparzir",
    "esparzissem": "esparzir",
    "esparzisses": "esparzir",
    "esparziste": "esparzir",
    "esparzistes": "esparzir",
    "esparziu": "esparzir",
    "esparzo": "esparzir",
    "esparzíamo": "esparzir",
    "esparzíamos": "esparzir",
    "esparzíei": "esparzir",
    "esparzíeis": "esparzir",
    "esparzíramo": "esparzir",
    "esparzíramos": "esparzir",
    "esparzírei": "esparzir",
    "esparzíreis": "esparzir",
    "esparzísseis": "esparzir",
    "esparzíssemos": "esparzir",
    "esparídea": "esparídeo",
    "esparídeas": "esparídeo",
    "esparídeos": "esparídeo",
    "espasma": "espasmar",
    "espasmada": "espasmar",
    "espasmadas": "espasmar",
    "espasmado": "espasmar",
    "espasmados": "espasmar",
    "espasmai": "espasmar",
    "espasmais": "espasmar",
    "espasmam": "espasmar",
    "espasmamo": "espasmar",
    "espasmamos": "espasmar",
    "espasmando": "espasmar",
    "espasmara": "espasmar",
    "espasmaram": "espasmar",
    "espasmaras": "espasmar",
    "espasmarde": "espasmar",
    "espasmardes": "espasmar",
    "espasmare": "espasmar",
    "espasmarei": "espasmar",
    "espasmareis": "espasmar",
    "espasmarem": "espasmar",
    "espasmaremos": "espasmar",
    "espasmares": "espasmar",
    "espasmaria": "espasmar",
    "espasmariam": "espasmar",
    "espasmarias": "espasmar",
    "espasmarmo": "espasmar",
    "espasmarmos": "espasmar",
    "espasmará": "espasmar",
    "espasmarás": "espasmar",
    "espasmarão": "espasmar",
    "espasmaríamos": "espasmar",
    "espasmaríeis": "espasmar",
    "espasmas": "espasmar",
    "espasmasse": "espasmar",
    "espasmassem": "espasmar",
    "espasmasses": "espasmar",
    "espasmaste": "espasmar",
    "espasmastes": "espasmar",
    "espasmava": "espasmar",
    "espasmavam": "espasmar",
    "espasmavas": "espasmar",
    "espasme": "espasmar",
    "espasmei": "espasmar",
    "espasmeis": "espasmar",
    "espasmem": "espasmar",
    "espasmemo": "espasmar",
    "espasmemos": "espasmar",
    "espasmes": "espasmar",
    "espasmo": "espasmar",
    "espasmolítica": "espasmolítico",
    "espasmolíticas": "espasmolítico",
    "espasmolíticos": "espasmolítico",
    "espasmos": "espasmo",
    "espasmou": "espasmar",
    "espasmá": "espasmar",
    "espasmámo": "espasmar",
    "espasmámos": "espasmar",
    "espasmáramo": "espasmar",
    "espasmáramos": "espasmar",
    "espasmárei": "espasmar",
    "espasmáreis": "espasmar",
    "espasmásseis": "espasmar",
    "espasmássemos": "espasmar",
    "espasmávamo": "espasmar",
    "espasmávamos": "espasmar",
    "espasmávei": "espasmar",
    "espasmáveis": "espasmar",
    "espasmódica": "espasmódico",
    "espasmódicas": "espasmódico",
    "espasmódicos": "espasmódico",
    "espastácea": "espastáceo",
    "espastáceas": "espastáceo",
    "espastáceos": "espastáceo",
    "espatas": "espata",
    "espatelas": "espatela",
    "espatifa": "espatifar",
    "espatifada": "espatifar",
    "espatifadas": "espatifar",
    "espatifado": "espatifar",
    "espatifados": "espatifar",
    "espatifai": "espatifar",
    "espatifais": "espatifar",
    "espatifam": "espatifar",
    "espatifamo": "espatifar",
    "espatifamos": "espatifar",
    "espatifando": "espatifar",
    "espatifara": "espatifar",
    "espatifaram": "espatifar",
    "espatifaras": "espatifar",
    "espatifarde": "espatifar",
    "espatifardes": "espatifar",
    "espatifare": "espatifar",
    "espatifarei": "espatifar",
    "espatifareis": "espatifar",
    "espatifarem": "espatifar",
    "espatifaremos": "espatifar",
    "espatifares": "espatifar",
    "espatifaria": "espatifar",
    "espatifariam": "espatifar",
    "espatifarias": "espatifar",
    "espatifarmo": "espatifar",
    "espatifarmos": "espatifar",
    "espatifará": "espatifar",
    "espatifarás": "espatifar",
    "espatifarão": "espatifar",
    "espatifaríamos": "espatifar",
    "espatifaríeis": "espatifar",
    "espatifas": "espatifar",
    "espatifasse": "espatifar",
    "espatifassem": "espatifar",
    "espatifasses": "espatifar",
    "espatifaste": "espatifar",
    "espatifastes": "espatifar",
    "espatifava": "espatifar",
    "espatifavam": "espatifar",
    "espatifavas": "espatifar",
    "espatife": "espatifar",
    "espatifei": "espatifar",
    "espatifeis": "espatifar",
    "espatifem": "espatifar",
    "espatifemo": "espatifar",
    "espatifemos": "espatifar",
    "espatifes": "espatifar",
    "espatifo": "espatifar",
    "espatifou": "espatifar",
    "espatifá": "espatifar",
    "espatifámo": "espatifar",
    "espatifámos": "espatifar",
    "espatifáramo": "espatifar",
    "espatifáramos": "espatifar",
    "espatifárei": "espatifar",
    "espatifáreis": "espatifar",
    "espatifásseis": "espatifar",
    "espatifássemos": "espatifar",
    "espatifávamo": "espatifar",
    "espatifávamos": "espatifar",
    "espatifávei": "espatifar",
    "espatifáveis": "espatifar",
    "espatilha": "espatilhar",
    "espatilhada": "espatilhar",
    "espatilhadas": "espatilhar",
    "espatilhado": "espatilhar",
    "espatilhados": "espatilhar",
    "espatilhai": "espatilhar",
    "espatilhais": "espatilhar",
    "espatilham": "espatilhar",
    "espatilhamo": "espatilhar",
    "espatilhamos": "espatilhar",
    "espatilhando": "espatilhar",
    "espatilhara": "espatilhar",
    "espatilharam": "espatilhar",
    "espatilharas": "espatilhar",
    "espatilharde": "espatilhar",
    "espatilhardes": "espatilhar",
    "espatilhare": "espatilhar",
    "espatilharei": "espatilhar",
    "espatilhareis": "espatilhar",
    "espatilharem": "espatilhar",
    "espatilharemos": "espatilhar",
    "espatilhares": "espatilhar",
    "espatilharia": "espatilhar",
    "espatilhariam": "espatilhar",
    "espatilharias": "espatilhar",
    "espatilharmo": "espatilhar",
    "espatilharmos": "espatilhar",
    "espatilhará": "espatilhar",
    "espatilharás": "espatilhar",
    "espatilharão": "espatilhar",
    "espatilharíamos": "espatilhar",
    "espatilharíeis": "espatilhar",
    "espatilhas": "espatilhar",
    "espatilhasse": "espatilhar",
    "espatilhassem": "espatilhar",
    "espatilhasses": "espatilhar",
    "espatilhaste": "espatilhar",
    "espatilhastes": "espatilhar",
    "espatilhava": "espatilhar",
    "espatilhavam": "espatilhar",
    "espatilhavas": "espatilhar",
    "espatilhe": "espatilhar",
    "espatilhei": "espatilhar",
    "espatilheis": "espatilhar",
    "espatilhem": "espatilhar",
    "espatilhemo": "espatilhar",
    "espatilhemos": "espatilhar",
    "espatilhes": "espatilhar",
    "espatilho": "espatilhar",
    "espatilhou": "espatilhar",
    "espatilhá": "espatilhar",
    "espatilhámo": "espatilhar",
    "espatilhámos": "espatilhar",
    "espatilháramo": "espatilhar",
    "espatilháramos": "espatilhar",
    "espatilhárei": "espatilhar",
    "espatilháreis": "espatilhar",
    "espatilhásseis": "espatilhar",
    "espatilhássemos": "espatilhar",
    "espatilhávamo": "espatilhar",
    "espatilhávamos": "espatilhar",
    "espatilhávei": "espatilhar",
    "espatilháveis": "espatilhar",
    "espatos": "espato",
    "espatulada": "espatulado",
    "espatuladas": "espatulado",
    "espatulados": "espatulado",
    "espatários": "espatário",
    "espaventa": "espaventar",
    "espaventada": "espaventar",
    "espaventadas": "espaventar",
    "espaventado": "espaventar",
    "espaventados": "espaventar",
    "espaventai": "espaventar",
    "espaventais": "espaventar",
    "espaventam": "espaventar",
    "espaventamo": "espaventar",
    "espaventamos": "espaventar",
    "espaventando": "espaventar",
    "espaventara": "espaventar",
    "espaventaram": "espaventar",
    "espaventaras": "espaventar",
    "espaventarde": "espaventar",
    "espaventardes": "espaventar",
    "espaventare": "espaventar",
    "espaventarei": "espaventar",
    "espaventareis": "espaventar",
    "espaventarem": "espaventar",
    "espaventaremos": "espaventar",
    "espaventares": "espaventar",
    "espaventaria": "espaventar",
    "espaventariam": "espaventar",
    "espaventarias": "espaventar",
    "espaventarmo": "espaventar",
    "espaventarmos": "espaventar",
    "espaventará": "espaventar",
    "espaventarás": "espaventar",
    "espaventarão": "espaventar",
    "espaventaríamos": "espaventar",
    "espaventaríeis": "espaventar",
    "espaventas": "espaventar",
    "espaventasse": "espaventar",
    "espaventassem": "espaventar",
    "espaventasses": "espaventar",
    "espaventaste": "espaventar",
    "espaventastes": "espaventar",
    "espaventava": "espaventar",
    "espaventavam": "espaventar",
    "espaventavas": "espaventar",
    "espavente": "espaventar",
    "espaventei": "espaventar",
    "espaventeis": "espaventar",
    "espaventem": "espaventar",
    "espaventemo": "espaventar",
    "espaventemos": "espaventar",
    "espaventes": "espaventar",
    "espavento": "espaventar",
    "espaventos": "espavento",
    "espaventosa": "espaventoso",
    "espaventosas": "espaventoso",
    "espaventosos": "espaventoso",
    "espaventou": "espaventar",
    "espaventá": "espaventar",
    "espaventámo": "espaventar",
    "espaventámos": "espaventar",
    "espaventáramo": "espaventar",
    "espaventáramos": "espaventar",
    "espaventárei": "espaventar",
    "espaventáreis": "espaventar",
    "espaventásseis": "espaventar",
    "espaventássemos": "espaventar",
    "espaventávamo": "espaventar",
    "espaventávamos": "espaventar",
    "espaventávei": "espaventar",
    "espaventáveis": "espaventar",
    "espavora": "espavorir",
    "espavorais": "espavorir",
    "espavoram": "espavorir",
    "espavoramo": "espavorir",
    "espavoramos": "espavorir",
    "espavoras": "espavorir",
    "espavore": "espavorir",
    "espavorece": "espavorecer",
    "espavorecei": "espavorecer",
    "espavoreceis": "espavorecer",
    "espavorecem": "espavorecer",
    "espavorecemo": "espavorecer",
    "espavorecemos": "espavorecer",
    "espavorecendo": "espavorecer",
    "espavorecera": "espavorecer",
    "espavoreceram": "espavorecer",
    "espavoreceras": "espavorecer",
    "espavorecerde": "espavorecer",
    "espavorecerdes": "espavorecer",
    "espavorecere": "espavorecer",
    "espavorecerei": "espavorecer",
    "espavorecereis": "espavorecer",
    "espavorecerem": "espavorecer",
    "espavoreceremos": "espavorecer",
    "espavoreceres": "espavorecer",
    "espavoreceria": "espavorecer",
    "espavoreceriam": "espavorecer",
    "espavorecerias": "espavorecer",
    "espavorecermo": "espavorecer",
    "espavorecermos": "espavorecer",
    "espavorecerá": "espavorecer",
    "espavorecerás": "espavorecer",
    "espavorecerão": "espavorecer",
    "espavoreceríamos": "espavorecer",
    "espavoreceríeis": "espavorecer",
    "espavoreces": "espavorecer",
    "espavorecesse": "espavorecer",
    "espavorecessem": "espavorecer",
    "espavorecesses": "espavorecer",
    "espavoreceste": "espavorecer",
    "espavorecestes": "espavorecer",
    "espavoreceu": "espavorecer",
    "espavoreci": "espavorecer",
    "espavorecia": "espavorecer",
    "espavoreciam": "espavorecer",
    "espavorecias": "espavorecer",
    "espavorecida": "espavorecer",
    "espavorecidas": "espavorecer",
    "espavorecido": "espavorecer",
    "espavorecidos": "espavorecer",
    "espavorecê": "espavorecer",
    "espavorecêramo": "espavorecer",
    "espavorecêramos": "espavorecer",
    "espavorecêrei": "espavorecer",
    "espavorecêreis": "espavorecer",
    "espavorecêsseis": "espavorecer",
    "espavorecêssemos": "espavorecer",
    "espavorecíamo": "espavorecer",
    "espavorecíamos": "espavorecer",
    "espavorecíei": "espavorecer",
    "espavorecíeis": "espavorecer",
    "espavorem": "espavorir",
    "espavores": "espavorir",
    "espavoreça": "espavorecer",
    "espavoreçais": "espavorecer",
    "espavoreçam": "espavorecer",
    "espavoreçamo": "espavorecer",
    "espavoreçamos": "espavorecer",
    "espavoreças": "espavorecer",
    "espavoreço": "espavorecer",
    "espavori": "espavorir",
    "espavoria": "espavorir",
    "espavoriam": "espavorir",
    "espavorias": "espavorir",
    "espavorida": "espavorir",
    "espavoridas": "espavorir",
    "espavorido": "espavorir",
    "espavoridos": "espavorir",
    "espavorimo": "espavorir",
    "espavorimos": "espavorir",
    "espavorindo": "espavorir",
    "espavorira": "espavorir",
    "espavoriram": "espavorir",
    "espavoriras": "espavorir",
    "espavorirde": "espavorir",
    "espavorirdes": "espavorir",
    "espavorire": "espavorir",
    "espavorirei": "espavorir",
    "espavorireis": "espavorir",
    "espavorirem": "espavorir",
    "espavoriremos": "espavorir",
    "espavorires": "espavorir",
    "espavoriria": "espavorir",
    "espavoririam": "espavorir",
    "espavoririas": "espavorir",
    "espavorirmo": "espavorir",
    "espavorirmos": "espavorir",
    "espavorirá": "espavorir",
    "espavorirás": "espavorir",
    "espavorirão": "espavorir",
    "espavoriríamos": "espavorir",
    "espavoriríeis": "espavorir",
    "espavoris": "espavorir",
    "espavorisse": "espavorir",
    "espavorissem": "espavorir",
    "espavorisses": "espavorir",
    "espavoriste": "espavorir",
    "espavoristes": "espavorir",
    "espavoriu": "espavorir",
    "espavoriza": "espavorizar",
    "espavorizada": "espavorizar",
    "espavorizadas": "espavorizar",
    "espavorizado": "espavorizar",
    "espavorizados": "espavorizar",
    "espavorizai": "espavorizar",
    "espavorizais": "espavorizar",
    "espavorizam": "espavorizar",
    "espavorizamo": "espavorizar",
    "espavorizamos": "espavorizar",
    "espavorizando": "espavorizar",
    "espavorizara": "espavorizar",
    "espavorizaram": "espavorizar",
    "espavorizaras": "espavorizar",
    "espavorizarde": "espavorizar",
    "espavorizardes": "espavorizar",
    "espavorizare": "espavorizar",
    "espavorizarei": "espavorizar",
    "espavorizareis": "espavorizar",
    "espavorizarem": "espavorizar",
    "espavorizaremos": "espavorizar",
    "espavorizares": "espavorizar",
    "espavorizaria": "espavorizar",
    "espavorizariam": "espavorizar",
    "espavorizarias": "espavorizar",
    "espavorizarmo": "espavorizar",
    "espavorizarmos": "espavorizar",
    "espavorizará": "espavorizar",
    "espavorizarás": "espavorizar",
    "espavorizarão": "espavorizar",
    "espavorizaríamos": "espavorizar",
    "espavorizaríeis": "espavorizar",
    "espavorizas": "espavorizar",
    "espavorizasse": "espavorizar",
    "espavorizassem": "espavorizar",
    "espavorizasses": "espavorizar",
    "espavorizaste": "espavorizar",
    "espavorizastes": "espavorizar",
    "espavorizava": "espavorizar",
    "espavorizavam": "espavorizar",
    "espavorizavas": "espavorizar",
    "espavorize": "espavorizar",
    "espavorizei": "espavorizar",
    "espavorizeis": "espavorizar",
    "espavorizem": "espavorizar",
    "espavorizemo": "espavorizar",
    "espavorizemos": "espavorizar",
    "espavorizes": "espavorizar",
    "espavorizo": "espavorizar",
    "espavorizou": "espavorizar",
    "espavorizá": "espavorizar",
    "espavorizámo": "espavorizar",
    "espavorizámos": "espavorizar",
    "espavorizáramo": "espavorizar",
    "espavorizáramos": "espavorizar",
    "espavorizárei": "espavorizar",
    "espavorizáreis": "espavorizar",
    "espavorizásseis": "espavorizar",
    "espavorizássemos": "espavorizar",
    "espavorizávamo": "espavorizar",
    "espavorizávamos": "espavorizar",
    "espavorizávei": "espavorizar",
    "espavorizáveis": "espavorizar",
    "espavoro": "espavorir",
    "espavoríamo": "espavorir",
    "espavoríamos": "espavorir",
    "espavoríei": "espavorir",
    "espavoríeis": "espavorir",
    "espavoríramo": "espavorir",
    "espavoríramos": "espavorir",
    "espavorírei": "espavorir",
    "espavoríreis": "espavorir",
    "espavorísseis": "espavorir",
    "espavoríssemos": "espavorir",
    "espaça": "espaçar",
    "espaçada": "espaçar",
    "espaçadas": "espaçar",
    "espaçado": "espaçar",
    "espaçados": "espaçar",
    "espaçai": "espaçar",
    "espaçais": "espaçar",
    "espaçam": "espaçar",
    "espaçamentos": "espaçamento",
    "espaçamo": "espaçar",
    "espaçamos": "espaçar",
    "espaçando": "espaçar",
    "espaçara": "espaçar",
    "espaçaram": "espaçar",
    "espaçaras": "espaçar",
    "espaçarde": "espaçar",
    "espaçardes": "espaçar",
    "espaçare": "espaçar",
    "espaçarei": "espaçar",
    "espaçareis": "espaçar",
    "espaçarem": "espaçar",
    "espaçaremos": "espaçar",
    "espaçares": "espaçar",
    "espaçaria": "espaçar",
    "espaçariam": "espaçar",
    "espaçarias": "espaçar",
    "espaçarmo": "espaçar",
    "espaçarmos": "espaçar",
    "espaçará": "espaçar",
    "espaçarás": "espaçar",
    "espaçarão": "espaçar",
    "espaçaríamos": "espaçar",
    "espaçaríeis": "espaçar",
    "espaças": "espaçar",
    "espaçasse": "espaçar",
    "espaçassem": "espaçar",
    "espaçasses": "espaçar",
    "espaçaste": "espaçar",
    "espaçastes": "espaçar",
    "espaçava": "espaçar",
    "espaçavam": "espaçar",
    "espaçavas": "espaçar",
    "espaço": "espaçar",
    "espaçonaves": "espaçonave",
    "espaços": "espaço",
    "espaçosa": "espaçoso",
    "espaçosas": "espaçoso",
    "espaçosos": "espaçoso",
    "espaçou": "espaçar",
    "espaçozinho": "espaço",
    "espaçozinhos": "espaço",
    "espaçozito": "espaço",
    "espaçozitos": "espaço",
    "espaçá": "espaçar",
    "espaçámo": "espaçar",
    "espaçámos": "espaçar",
    "espaçáramo": "espaçar",
    "espaçáramos": "espaçar",
    "espaçárei": "espaçar",
    "espaçáreis": "espaçar",
    "espaçásseis": "espaçar",
    "espaçássemos": "espaçar",
    "espaçávamo": "espaçar",
    "espaçávamos": "espaçar",
    "espaçávei": "espaçar",
    "espaçáveis": "espaçar",
    "espação": "espaço",
    "espações": "espaço",
    "especa": "especar",
    "especada": "especar",
    "especadas": "especar",
    "especado": "especar",
    "especados": "especar",
    "especai": "especar",
    "especais": "especar",
    "especam": "especar",
    "especamo": "especar",
    "especamos": "especar",
    "especando": "especar",
    "especara": "especar",
    "especaram": "especar",
    "especaras": "especar",
    "especarde": "especar",
    "especardes": "especar",
    "especare": "especar",
    "especarei": "especar",
    "especareis": "especar",
    "especarem": "especar",
    "especaremos": "especar",
    "especares": "especar",
    "especaria": "especar",
    "especariam": "especar",
    "especarias": "especar",
    "especarmo": "especar",
    "especarmos": "especar",
    "especará": "especar",
    "especarás": "especar",
    "especarão": "especar",
    "especaríamos": "especar",
    "especaríeis": "especar",
    "especas": "especar",
    "especasse": "especar",
    "especassem": "especar",
    "especasses": "especar",
    "especaste": "especar",
    "especastes": "especar",
    "especava": "especar",
    "especavam": "especar",
    "especavas": "especar",
    "espece": "espeçar",
    "especei": "espeçar",
    "especeis": "espeçar",
    "especem": "espeçar",
    "especemo": "espeçar",
    "especemos": "espeçar",
    "especes": "espeçar",
    "especiais": "especial",
    "especialidades": "especialidade",
    "especialistas": "especialista",
    "especializa": "especializar",
    "especializada": "especializar",
    "especializadas": "especializar",
    "especializado": "especializar",
    "especializados": "especializar",
    "especializadíssima": "especializado",
    "especializadíssimas": "especializado",
    "especializadíssimo": "especializado",
    "especializadíssimos": "especializado",
    "especializai": "especializar",
    "especializais": "especializar",
    "especializam": "especializar",
    "especializamo": "especializar",
    "especializamos": "especializar",
    "especializando": "especializar",
    "especializara": "especializar",
    "especializaram": "especializar",
    "especializaras": "especializar",
    "especializarde": "especializar",
    "especializardes": "especializar",
    "especializare": "especializar",
    "especializarei": "especializar",
    "especializareis": "especializar",
    "especializarem": "especializar",
    "especializaremos": "especializar",
    "especializares": "especializar",
    "especializaria": "especializar",
    "especializariam": "especializar",
    "especializarias": "especializar",
    "especializarmo": "especializar",
    "especializarmos": "especializar",
    "especializará": "especializar",
    "especializarás": "especializar",
    "especializarão": "especializar",
    "especializaríamos": "especializar",
    "especializaríeis": "especializar",
    "especializas": "especializar",
    "especializasse": "especializar",
    "especializassem": "especializar",
    "especializasses": "especializar",
    "especializaste": "especializar",
    "especializastes": "especializar",
    "especializava": "especializar",
    "especializavam": "especializar",
    "especializavas": "especializar",
    "especializações": "especialização",
    "especialize": "especializar",
    "especializei": "especializar",
    "especializeis": "especializar",
    "especializem": "especializar",
    "especializemo": "especializar",
    "especializemos": "especializar",
    "especializes": "especializar",
    "especializo": "especializar",
    "especializou": "especializar",
    "especializá": "especializar",
    "especializámo": "especializar",
    "especializámos": "especializar",
    "especializáramo": "especializar",
    "especializáramos": "especializar",
    "especializárei": "especializar",
    "especializáreis": "especializar",
    "especializásseis": "especializar",
    "especializássemos": "especializar",
    "especializávamo": "especializar",
    "especializávamos": "especializar",
    "especializávei": "especializar",
    "especializáveis": "especializar",
    "especiarias": "especiaria",
    "especiações": "especiação",
    "especieiros": "especieiro",
    "especifica": "especificar",
    "especificada": "especificar",
    "especificadas": "especificar",
    "especificado": "especificar",
    "especificadora": "especificador",
    "especificadoras": "especificador",
    "especificadores": "especificador",
    "especificados": "especificar",
    "especificai": "especificar",
    "especificais": "especificar",
    "especificam": "especificar",
    "especificamo": "especificar",
    "especificamos": "especificar",
    "especificando": "especificar",
    "especificara": "especificar",
    "especificaram": "especificar",
    "especificaras": "especificar",
    "especificarde": "especificar",
    "especificardes": "especificar",
    "especificare": "especificar",
    "especificarei": "especificar",
    "especificareis": "especificar",
    "especificarem": "especificar",
    "especificaremos": "especificar",
    "especificares": "especificar",
    "especificaria": "especificar",
    "especificariam": "especificar",
    "especificarias": "especificar",
    "especificarmo": "especificar",
    "especificarmos": "especificar",
    "especificará": "especificar",
    "especificarás": "especificar",
    "especificarão": "especificar",
    "especificaríamos": "especificar",
    "especificaríeis": "especificar",
    "especificas": "especificar",
    "especificasse": "especificar",
    "especificassem": "especificar",
    "especificasses": "especificar",
    "especificaste": "especificar",
    "especificastes": "especificar",
    "especificativa": "especificativo",
    "especificativas": "especificativo",
    "especificativos": "especificativo",
    "especificava": "especificar",
    "especificavam": "especificar",
    "especificavas": "especificar",
    "especificações": "especificação",
    "especificidades": "especificidade",
    "especifico": "especificar",
    "especificou": "especificar",
    "especificá": "especificar",
    "especificámo": "especificar",
    "especificámos": "especificar",
    "especificáramo": "especificar",
    "especificáramos": "especificar",
    "especificárei": "especificar",
    "especificáreis": "especificar",
    "especificásseis": "especificar",
    "especificássemos": "especificar",
    "especificávamo": "especificar",
    "especificávamos": "especificar",
    "especificávei": "especificar",
    "especificáveis": "especificável",
    "especifique": "especificar",
    "especifiquei": "especificar",
    "especifiqueis": "especificar",
    "especifiquem": "especificar",
    "especifiquemo": "especificar",
    "especifiquemos": "especificar",
    "especifiques": "especificar",
    "especiones": "especione",
    "especiosa": "especioso",
    "especiosas": "especioso",
    "especiosidades": "especiosidade",
    "especiosos": "especioso",
    "especo": "especar",
    "especou": "especar",
    "especta": "espectar",
    "espectaculares": "espectacular",
    "espectaculosa": "espectaculoso",
    "espectaculosas": "espectaculoso",
    "espectaculosidades": "espectaculosidade",
    "espectaculosos": "espectaculoso",
    "espectaculozinho": "espectáculo",
    "espectaculozinhos": "espectáculo",
    "espectaculozito": "espectáculo",
    "espectaculozitos": "espectáculo",
    "espectada": "espectar",
    "espectadas": "espectar",
    "espectado": "espectar",
    "espectadora": "espectador",
    "espectadoras": "espectador",
    "espectadores": "espectador",
    "espectados": "espectar",
    "espectai": "espectar",
    "espectais": "espectar",
    "espectam": "espectar",
    "espectamo": "espectar",
    "espectamos": "espectar",
    "espectando": "espectar",
    "espectara": "espectar",
    "espectaram": "espectar",
    "espectaras": "espectar",
    "espectarde": "espectar",
    "espectardes": "espectar",
    "espectare": "espectar",
    "espectarei": "espectar",
    "espectareis": "espectar",
    "espectarem": "espectar",
    "espectaremos": "espectar",
    "espectares": "espectar",
    "espectaria": "espectar",
    "espectariam": "espectar",
    "espectarias": "espectar",
    "espectarmo": "espectar",
    "espectarmos": "espectar",
    "espectará": "espectar",
    "espectarás": "espectar",
    "espectarão": "espectar",
    "espectaríamos": "espectar",
    "espectaríeis": "espectar",
    "espectas": "espectar",
    "espectasse": "espectar",
    "espectassem": "espectar",
    "espectasses": "espectar",
    "espectaste": "espectar",
    "espectastes": "espectar",
    "espectava": "espectar",
    "espectavam": "espectar",
    "espectavas": "espectar",
    "especte": "espectar",
    "espectei": "espectar",
    "especteis": "espectar",
    "espectem": "espectar",
    "espectemo": "espectar",
    "espectemos": "espectar",
    "espectes": "espectar",
    "especto": "espectar",
    "espectou": "espectar",
    "espectrais": "espectral",
    "espectrofotometrias": "espectrofotometria",
    "espectrofotométrica": "espectrofotométrico",
    "espectrofotométricas": "espectrofotométrico",
    "espectrofotométricos": "espectrofotométrico",
    "espectrofotómetros": "espectrofotómetro",
    "espectrografias": "espectrografia",
    "espectrogramas": "espectrograma",
    "espectrográfica": "espectrográfico",
    "espectrográficas": "espectrográfico",
    "espectrográficos": "espectrográfico",
    "espectrometrias": "espectrometria",
    "espectrométrica": "espectrométrico",
    "espectrométricas": "espectrométrico",
    "espectrométricos": "espectrométrico",
    "espectros": "espectro",
    "espectroscopias": "espectroscopia",
    "espectroscopistas": "espectroscopista",
    "espectroscópica": "espectroscópico",
    "espectroscópicas": "espectroscópico",
    "espectroscópicos": "espectroscópico",
    "espectroscópios": "espectroscópio",
    "espectrozinho": "espectro",
    "espectrozinhos": "espectro",
    "espectrozito": "espectro",
    "espectrozitos": "espectro",
    "espectrógrafos": "espectrógrafo",
    "espectrómetros": "espectrómetro",
    "espectá": "espectar",
    "espectáculos": "espectáculo",
    "espectámo": "espectar",
    "espectámos": "espectar",
    "espectáramo": "espectar",
    "espectáramos": "espectar",
    "espectárei": "espectar",
    "espectáreis": "espectar",
    "espectásseis": "espectar",
    "espectássemos": "espectar",
    "espectávamo": "espectar",
    "espectávamos": "espectar",
    "espectávei": "espectar",
    "espectáveis": "espectável",
    "especula": "especular",
    "especulada": "especular",
    "especuladas": "especular",
    "especulado": "especular",
    "especuladora": "especulador",
    "especuladoras": "especulador",
    "especuladores": "especulador",
    "especulados": "especular",
    "especulai": "especular",
    "especulais": "especular",
    "especulam": "especular",
    "especulamo": "especular",
    "especulamos": "especular",
    "especulando": "especular",
    "especulara": "especular",
    "especularam": "especular",
    "especularas": "especular",
    "especularde": "especular",
    "especulardes": "especular",
    "especulare": "especular",
    "especularei": "especular",
    "especulareis": "especular",
    "especularem": "especular",
    "especularemos": "especular",
    "especulares": "especular",
    "especularia": "especular",
    "especulariam": "especular",
    "especularias": "especular",
    "especularmo": "especular",
    "especularmos": "especular",
    "especulará": "especular",
    "especularás": "especular",
    "especularão": "especular",
    "especularíamos": "especular",
    "especularíeis": "especular",
    "especulas": "especular",
    "especulasse": "especular",
    "especulassem": "especular",
    "especulasses": "especular",
    "especulaste": "especular",
    "especulastes": "especular",
    "especulativa": "especulativo",
    "especulativas": "especulativo",
    "especulativos": "especulativo",
    "especulava": "especular",
    "especulavam": "especular",
    "especulavas": "especular",
    "especulações": "especulação",
    "especule": "especular",
    "especulei": "especular",
    "especuleis": "especular",
    "especulem": "especular",
    "especulemo": "especular",
    "especulemos": "especular",
    "especules": "especular",
    "especulo": "especular",
    "especulou": "especular",
    "especulá": "especular",
    "especulámo": "especular",
    "especulámos": "especular",
    "especuláramo": "especular",
    "especuláramos": "especular",
    "especulárei": "especular",
    "especuláreis": "especular",
    "especulásseis": "especular",
    "especulássemos": "especular",
    "especulávamo": "especular",
    "especulávamos": "especular",
    "especulávei": "especular",
    "especuláveis": "especular",
    "especá": "especar",
    "especámo": "especar",
    "especámos": "especar",
    "especáramo": "especar",
    "especáramos": "especar",
    "especárei": "especar",
    "especáreis": "especar",
    "especásseis": "especar",
    "especássemos": "especar",
    "especávamo": "especar",
    "especávamos": "especar",
    "especávei": "especar",
    "especáveis": "especar",
    "específica": "específico",
    "específicas": "específico",
    "específicos": "específico",
    "espeda": "espedir",
    "espedace": "espedaçar",
    "espedacei": "espedaçar",
    "espedaceis": "espedaçar",
    "espedacem": "espedaçar",
    "espedacemo": "espedaçar",
    "espedacemos": "espedaçar",
    "espedaces": "espedaçar",
    "espedais": "espedir",
    "espedam": "espedir",
    "espedamo": "espedir",
    "espedamos": "espedir",
    "espedas": "espedir",
    "espedaça": "espedaçar",
    "espedaçada": "espedaçar",
    "espedaçadas": "espedaçar",
    "espedaçado": "espedaçar",
    "espedaçados": "espedaçar",
    "espedaçai": "espedaçar",
    "espedaçais": "espedaçar",
    "espedaçam": "espedaçar",
    "espedaçamo": "espedaçar",
    "espedaçamos": "espedaçar",
    "espedaçando": "espedaçar",
    "espedaçara": "espedaçar",
    "espedaçaram": "espedaçar",
    "espedaçaras": "espedaçar",
    "espedaçarde": "espedaçar",
    "espedaçardes": "espedaçar",
    "espedaçare": "espedaçar",
    "espedaçarei": "espedaçar",
    "espedaçareis": "espedaçar",
    "espedaçarem": "espedaçar",
    "espedaçaremos": "espedaçar",
    "espedaçares": "espedaçar",
    "espedaçaria": "espedaçar",
    "espedaçariam": "espedaçar",
    "espedaçarias": "espedaçar",
    "espedaçarmo": "espedaçar",
    "espedaçarmos": "espedaçar",
    "espedaçará": "espedaçar",
    "espedaçarás": "espedaçar",
    "espedaçarão": "espedaçar",
    "espedaçaríamos": "espedaçar",
    "espedaçaríeis": "espedaçar",
    "espedaças": "espedaçar",
    "espedaçasse": "espedaçar",
    "espedaçassem": "espedaçar",
    "espedaçasses": "espedaçar",
    "espedaçaste": "espedaçar",
    "espedaçastes": "espedaçar",
    "espedaçava": "espedaçar",
    "espedaçavam": "espedaçar",
    "espedaçavas": "espedaçar",
    "espedaço": "espedaçar",
    "espedaçou": "espedaçar",
    "espedaçá": "espedaçar",
    "espedaçámo": "espedaçar",
    "espedaçámos": "espedaçar",
    "espedaçáramo": "espedaçar",
    "espedaçáramos": "espedaçar",
    "espedaçárei": "espedaçar",
    "espedaçáreis": "espedaçar",
    "espedaçásseis": "espedaçar",
    "espedaçássemos": "espedaçar",
    "espedaçávamo": "espedaçar",
    "espedaçávamos": "espedaçar",
    "espedaçávei": "espedaçar",
    "espedaçáveis": "espedaçar",
    "espede": "espedir",
    "espedem": "espedir",
    "espedes": "espedir",
    "espedi": "espedir",
    "espedia": "espedir",
    "espediam": "espedir",
    "espedias": "espedir",
    "espedida": "espedir",
    "espedidas": "espedir",
    "espedido": "espedir",
    "espedidos": "espedir",
    "espedimo": "espedir",
    "espedimos": "espedir",
    "espedindo": "espedir",
    "espedira": "espedir",
    "espediram": "espedir",
    "espediras": "espedir",
    "espedirde": "espedir",
    "espedirdes": "espedir",
    "espedire": "espedir",
    "espedirei": "espedir",
    "espedireis": "espedir",
    "espedirem": "espedir",
    "espediremos": "espedir",
    "espedires": "espedir",
    "espediria": "espedir",
    "espediriam": "espedir",
    "espedirias": "espedir",
    "espedirmo": "espedir",
    "espedirmos": "espedir",
    "espedirá": "espedir",
    "espedirás": "espedir",
    "espedirão": "espedir",
    "espediríamos": "espedir",
    "espediríeis": "espedir",
    "espedis": "espedir",
    "espedisse": "espedir",
    "espedissem": "espedir",
    "espedisses": "espedir",
    "espediste": "espedir",
    "espedistes": "espedir",
    "espediu": "espedir",
    "espedo": "espedir",
    "espedrega": "espedregar",
    "espedregada": "espedregar",
    "espedregadas": "espedregar",
    "espedregado": "espedregar",
    "espedregados": "espedregar",
    "espedregai": "espedregar",
    "espedregais": "espedregar",
    "espedregam": "espedregar",
    "espedregamo": "espedregar",
    "espedregamos": "espedregar",
    "espedregando": "espedregar",
    "espedregara": "espedregar",
    "espedregaram": "espedregar",
    "espedregaras": "espedregar",
    "espedregarde": "espedregar",
    "espedregardes": "espedregar",
    "espedregare": "espedregar",
    "espedregarei": "espedregar",
    "espedregareis": "espedregar",
    "espedregarem": "espedregar",
    "espedregaremos": "espedregar",
    "espedregares": "espedregar",
    "espedregaria": "espedregar",
    "espedregariam": "espedregar",
    "espedregarias": "espedregar",
    "espedregarmo": "espedregar",
    "espedregarmos": "espedregar",
    "espedregará": "espedregar",
    "espedregarás": "espedregar",
    "espedregarão": "espedregar",
    "espedregaríamos": "espedregar",
    "espedregaríeis": "espedregar",
    "espedregas": "espedregar",
    "espedregasse": "espedregar",
    "espedregassem": "espedregar",
    "espedregasses": "espedregar",
    "espedregaste": "espedregar",
    "espedregastes": "espedregar",
    "espedregava": "espedregar",
    "espedregavam": "espedregar",
    "espedregavas": "espedregar",
    "espedrego": "espedregar",
    "espedregou": "espedregar",
    "espedregue": "espedregar",
    "espedreguei": "espedregar",
    "espedregueis": "espedregar",
    "espedreguem": "espedregar",
    "espedreguemo": "espedregar",
    "espedreguemos": "espedregar",
    "espedregues": "espedregar",
    "espedregá": "espedregar",
    "espedregámo": "espedregar",
    "espedregámos": "espedregar",
    "espedregáramo": "espedregar",
    "espedregáramos": "espedregar",
    "espedregárei": "espedregar",
    "espedregáreis": "espedregar",
    "espedregásseis": "espedregar",
    "espedregássemos": "espedregar",
    "espedregávamo": "espedregar",
    "espedregávamos": "espedregar",
    "espedregávei": "espedregar",
    "espedregáveis": "espedregar",
    "espedíamo": "espedir",
    "espedíamos": "espedir",
    "espedíei": "espedir",
    "espedíeis": "espedir",
    "espedíramo": "espedir",
    "espedíramos": "espedir",
    "espedírei": "espedir",
    "espedíreis": "espedir",
    "espedísseis": "espedir",
    "espedíssemos": "espedir",
    "espeleologias": "espeleologia",
    "espeleológica": "espeleológico",
    "espeleológicas": "espeleológico",
    "espeleológicos": "espeleológico",
    "espeleóloga": "espeleólogo",
    "espeleólogas": "espeleólogo",
    "espeleólogos": "espeleólogo",
    "espelha": "espelhar",
    "espelhada": "espelhar",
    "espelhadas": "espelhar",
    "espelhado": "espelhar",
    "espelhados": "espelhar",
    "espelhai": "espelhar",
    "espelhais": "espelhar",
    "espelham": "espelhar",
    "espelhamentos": "espelhamento",
    "espelhamo": "espelhar",
    "espelhamos": "espelhar",
    "espelhando": "espelhar",
    "espelhantes": "espelhante",
    "espelhara": "espelhar",
    "espelharam": "espelhar",
    "espelharas": "espelhar",
    "espelharde": "espelhar",
    "espelhardes": "espelhar",
    "espelhare": "espelhar",
    "espelharei": "espelhar",
    "espelhareis": "espelhar",
    "espelharem": "espelhar",
    "espelharemos": "espelhar",
    "espelhares": "espelhar",
    "espelharia": "espelhar",
    "espelhariam": "espelhar",
    "espelharias": "espelharia",
    "espelharmo": "espelhar",
    "espelharmos": "espelhar",
    "espelhará": "espelhar",
    "espelharás": "espelhar",
    "espelharão": "espelhar",
    "espelharíamos": "espelhar",
    "espelharíeis": "espelhar",
    "espelhas": "espelhar",
    "espelhasse": "espelhar",
    "espelhassem": "espelhar",
    "espelhasses": "espelhar",
    "espelhaste": "espelhar",
    "espelhastes": "espelhar",
    "espelhava": "espelhar",
    "espelhavam": "espelhar",
    "espelhavas": "espelhar",
    "espelhações": "espelhação",
    "espelhe": "espelhar",
    "espelhei": "espelhar",
    "espelheiros": "espelheiro",
    "espelheis": "espelhar",
    "espelhem": "espelhar",
    "espelhemo": "espelhar",
    "espelhemos": "espelhar",
    "espelhenta": "espelhento",
    "espelhentas": "espelhento",
    "espelhentos": "espelhento",
    "espelhes": "espelhar",
    "espelhinho": "espelho",
    "espelhinhos": "espelho",
    "espelhins": "espelhim",
    "espelhito": "espelho",
    "espelhitos": "espelho",
    "espelho": "espelhar",
    "espelhos": "espelho",
    "espelhou": "espelhar",
    "espelhá": "espelhar",
    "espelhámo": "espelhar",
    "espelhámos": "espelhar",
    "espelháramo": "espelhar",
    "espelháramos": "espelhar",
    "espelhárei": "espelhar",
    "espelháreis": "espelhar",
    "espelhásseis": "espelhar",
    "espelhássemos": "espelhar",
    "espelhávamo": "espelhar",
    "espelhávamos": "espelhar",
    "espelhávei": "espelhar",
    "espelháveis": "espelhar",
    "espeltas": "espelta",
    "espeluncas": "espelunca",
    "espendas": "espenda",
    "espeneja": "espenejar",
    "espenejada": "espenejar",
    "espenejadas": "espenejar",
    "espenejado": "espenejar",
    "espenejados": "espenejar",
    "espenejai": "espenejar",
    "espenejais": "espenejar",
    "espenejam": "espenejar",
    "espenejamo": "espenejar",
    "espenejamos": "espenejar",
    "espenejando": "espenejar",
    "espenejara": "espenejar",
    "espenejaram": "espenejar",
    "espenejaras": "espenejar",
    "espenejarde": "espenejar",
    "espenejardes": "espenejar",
    "espenejare": "espenejar",
    "espenejarei": "espenejar",
    "espenejareis": "espenejar",
    "espenejarem": "espenejar",
    "espenejaremos": "espenejar",
    "espenejares": "espenejar",
    "espenejaria": "espenejar",
    "espenejariam": "espenejar",
    "espenejarias": "espenejar",
    "espenejarmo": "espenejar",
    "espenejarmos": "espenejar",
    "espenejará": "espenejar",
    "espenejarás": "espenejar",
    "espenejarão": "espenejar",
    "espenejaríamos": "espenejar",
    "espenejaríeis": "espenejar",
    "espenejas": "espenejar",
    "espenejasse": "espenejar",
    "espenejassem": "espenejar",
    "espenejasses": "espenejar",
    "espenejaste": "espenejar",
    "espenejastes": "espenejar",
    "espenejava": "espenejar",
    "espenejavam": "espenejar",
    "espenejavas": "espenejar",
    "espeneje": "espenejar",
    "espenejei": "espenejar",
    "espenejeis": "espenejar",
    "espenejem": "espenejar",
    "espenejemo": "espenejar",
    "espenejemos": "espenejar",
    "espenejes": "espenejar",
    "espenejo": "espenejar",
    "espenejou": "espenejar",
    "espenejá": "espenejar",
    "espenejámo": "espenejar",
    "espenejámos": "espenejar",
    "espenejáramo": "espenejar",
    "espenejáramos": "espenejar",
    "espenejárei": "espenejar",
    "espenejáreis": "espenejar",
    "espenejásseis": "espenejar",
    "espenejássemos": "espenejar",
    "espenejávamo": "espenejar",
    "espenejávamos": "espenejar",
    "espenejávei": "espenejar",
    "espenejáveis": "espenejar",
    "espenica": "espenicar",
    "espenicada": "espenicar",
    "espenicadas": "espenicar",
    "espenicado": "espenicar",
    "espenicados": "espenicar",
    "espenicai": "espenicar",
    "espenicais": "espenicar",
    "espenicam": "espenicar",
    "espenicamo": "espenicar",
    "espenicamos": "espenicar",
    "espenicando": "espenicar",
    "espenicara": "espenicar",
    "espenicaram": "espenicar",
    "espenicaras": "espenicar",
    "espenicarde": "espenicar",
    "espenicardes": "espenicar",
    "espenicare": "espenicar",
    "espenicarei": "espenicar",
    "espenicareis": "espenicar",
    "espenicarem": "espenicar",
    "espenicaremos": "espenicar",
    "espenicares": "espenicar",
    "espenicaria": "espenicar",
    "espenicariam": "espenicar",
    "espenicarias": "espenicar",
    "espenicarmo": "espenicar",
    "espenicarmos": "espenicar",
    "espenicará": "espenicar",
    "espenicarás": "espenicar",
    "espenicarão": "espenicar",
    "espenicaríamos": "espenicar",
    "espenicaríeis": "espenicar",
    "espenicas": "espenicar",
    "espenicasse": "espenicar",
    "espenicassem": "espenicar",
    "espenicasses": "espenicar",
    "espenicaste": "espenicar",
    "espenicastes": "espenicar",
    "espenicava": "espenicar",
    "espenicavam": "espenicar",
    "espenicavas": "espenicar",
    "espenico": "espenicar",
    "espenicou": "espenicar",
    "espenicá": "espenicar",
    "espenicámo": "espenicar",
    "espenicámos": "espenicar",
    "espenicáramo": "espenicar",
    "espenicáramos": "espenicar",
    "espenicárei": "espenicar",
    "espenicáreis": "espenicar",
    "espenicásseis": "espenicar",
    "espenicássemos": "espenicar",
    "espenicávamo": "espenicar",
    "espenicávamos": "espenicar",
    "espenicávei": "espenicar",
    "espenicáveis": "espenicar",
    "espenifra": "espenifrar",
    "espenifrada": "espenifrar",
    "espenifradas": "espenifrar",
    "espenifrado": "espenifrar",
    "espenifrados": "espenifrar",
    "espenifrai": "espenifrar",
    "espenifrais": "espenifrar",
    "espenifram": "espenifrar",
    "espeniframo": "espenifrar",
    "espeniframos": "espenifrar",
    "espenifrando": "espenifrar",
    "espenifrara": "espenifrar",
    "espenifraram": "espenifrar",
    "espenifraras": "espenifrar",
    "espenifrardes": "espenifrar",
    "espenifrarei": "espenifrar",
    "espenifrareis": "espenifrar",
    "espenifrarem": "espenifrar",
    "espenifraremos": "espenifrar",
    "espenifrares": "espenifrar",
    "espenifraria": "espenifrar",
    "espenifrariam": "espenifrar",
    "espenifrarias": "espenifrar",
    "espenifrarmo": "espenifrar",
    "espenifrarmos": "espenifrar",
    "espenifrará": "espenifrar",
    "espenifrarás": "espenifrar",
    "espenifrarão": "espenifrar",
    "espenifraríamos": "espenifrar",
    "espenifraríeis": "espenifrar",
    "espenifras": "espenifrar",
    "espenifrasse": "espenifrar",
    "espenifrassem": "espenifrar",
    "espenifrasses": "espenifrar",
    "espenifraste": "espenifrar",
    "espenifrastes": "espenifrar",
    "espenifrava": "espenifrar",
    "espenifravam": "espenifrar",
    "espenifravas": "espenifrar",
    "espenifre": "espenifrar",
    "espenifrei": "espenifrar",
    "espenifreis": "espenifrar",
    "espenifrem": "espenifrar",
    "espenifremo": "espenifrar",
    "espenifremos": "espenifrar",
    "espenifres": "espenifrar",
    "espenifro": "espenifrar",
    "espenifrou": "espenifrar",
    "espenifrámo": "espenifrar",
    "espenifrámos": "espenifrar",
    "espenifráramo": "espenifrar",
    "espenifráramos": "espenifrar",
    "espenifráreis": "espenifrar",
    "espenifrásseis": "espenifrar",
    "espenifrássemos": "espenifrar",
    "espenifrávamo": "espenifrar",
    "espenifrávamos": "espenifrar",
    "espenifráveis": "espenifrar",
    "espenique": "espenicar",
    "espeniquei": "espenicar",
    "espeniqueis": "espenicar",
    "espeniquem": "espenicar",
    "espeniquemo": "espenicar",
    "espeniquemos": "espenicar",
    "espeniques": "espenicar",
    "espenuja": "espenujar",
    "espenujada": "espenujar",
    "espenujadas": "espenujar",
    "espenujado": "espenujar",
    "espenujados": "espenujar",
    "espenujai": "espenujar",
    "espenujais": "espenujar",
    "espenujam": "espenujar",
    "espenujamo": "espenujar",
    "espenujamos": "espenujar",
    "espenujando": "espenujar",
    "espenujara": "espenujar",
    "espenujaram": "espenujar",
    "espenujaras": "espenujar",
    "espenujarde": "espenujar",
    "espenujardes": "espenujar",
    "espenujare": "espenujar",
    "espenujarei": "espenujar",
    "espenujareis": "espenujar",
    "espenujarem": "espenujar",
    "espenujaremos": "espenujar",
    "espenujares": "espenujar",
    "espenujaria": "espenujar",
    "espenujariam": "espenujar",
    "espenujarias": "espenujar",
    "espenujarmo": "espenujar",
    "espenujarmos": "espenujar",
    "espenujará": "espenujar",
    "espenujarás": "espenujar",
    "espenujarão": "espenujar",
    "espenujaríamos": "espenujar",
    "espenujaríeis": "espenujar",
    "espenujas": "espenujar",
    "espenujasse": "espenujar",
    "espenujassem": "espenujar",
    "espenujasses": "espenujar",
    "espenujaste": "espenujar",
    "espenujastes": "espenujar",
    "espenujava": "espenujar",
    "espenujavam": "espenujar",
    "espenujavas": "espenujar",
    "espenuje": "espenujar",
    "espenujei": "espenujar",
    "espenujeis": "espenujar",
    "espenujem": "espenujar",
    "espenujemo": "espenujar",
    "espenujemos": "espenujar",
    "espenujes": "espenujar",
    "espenujo": "espenujar",
    "espenujou": "espenujar",
    "espenujá": "espenujar",
    "espenujámo": "espenujar",
    "espenujámos": "espenujar",
    "espenujáramo": "espenujar",
    "espenujáramos": "espenujar",
    "espenujárei": "espenujar",
    "espenujáreis": "espenujar",
    "espenujásseis": "espenujar",
    "espenujássemos": "espenujar",
    "espenujávamo": "espenujar",
    "espenujávamos": "espenujar",
    "espenujávei": "espenujar",
    "espenujáveis": "espenujar",
    "espenífres": "espenífre",
    "espeque": "especar",
    "espequei": "especar",
    "espequeis": "especar",
    "espequem": "especar",
    "espequemo": "especar",
    "espequemos": "especar",
    "espeques": "espeque",
    "espera": "esperar",
    "esperada": "esperar",
    "esperadas": "esperar",
    "esperado": "esperar",
    "esperadoiros": "esperadoiro",
    "esperadora": "esperador",
    "esperadoras": "esperador",
    "esperadores": "esperador",
    "esperados": "esperar",
    "esperadouros": "esperadouro",
    "esperai": "esperar",
    "esperais": "esperar",
    "esperam": "esperar",
    "esperamo": "esperar",
    "esperamos": "esperar",
    "esperance": "esperançar",
    "esperancei": "esperançar",
    "esperanceis": "esperançar",
    "esperancem": "esperançar",
    "esperancemo": "esperançar",
    "esperancemos": "esperançar",
    "esperances": "esperançar",
    "esperando": "esperar",
    "esperantistas": "esperantista",
    "esperantos": "esperanto",
    "esperança": "esperançar",
    "esperançada": "esperançar",
    "esperançadas": "esperançar",
    "esperançado": "esperançar",
    "esperançados": "esperançar",
    "esperançai": "esperançar",
    "esperançais": "esperançar",
    "esperançam": "esperançar",
    "esperançamo": "esperançar",
    "esperançamos": "esperançar",
    "esperançando": "esperançar",
    "esperançara": "esperançar",
    "esperançaram": "esperançar",
    "esperançaras": "esperançar",
    "esperançarde": "esperançar",
    "esperançardes": "esperançar",
    "esperançare": "esperançar",
    "esperançarei": "esperançar",
    "esperançareis": "esperançar",
    "esperançarem": "esperançar",
    "esperançaremos": "esperançar",
    "esperançares": "esperançar",
    "esperançaria": "esperançar",
    "esperançariam": "esperançar",
    "esperançarias": "esperançar",
    "esperançarmo": "esperançar",
    "esperançarmos": "esperançar",
    "esperançará": "esperançar",
    "esperançarás": "esperançar",
    "esperançarão": "esperançar",
    "esperançaríamos": "esperançar",
    "esperançaríeis": "esperançar",
    "esperanças": "esperançar",
    "esperançasse": "esperançar",
    "esperançassem": "esperançar",
    "esperançasses": "esperançar",
    "esperançaste": "esperançar",
    "esperançastes": "esperançar",
    "esperançava": "esperançar",
    "esperançavam": "esperançar",
    "esperançavas": "esperançar",
    "esperanço": "esperançar",
    "esperançosa": "esperançoso",
    "esperançosas": "esperançoso",
    "esperançosos": "esperançoso",
    "esperançou": "esperançar",
    "esperançá": "esperançar",
    "esperançámo": "esperançar",
    "esperançámos": "esperançar",
    "esperançáramo": "esperançar",
    "esperançáramos": "esperançar",
    "esperançárei": "esperançar",
    "esperançáreis": "esperançar",
    "esperançásseis": "esperançar",
    "esperançássemos": "esperançar",
    "esperançávamo": "esperançar",
    "esperançávamos": "esperançar",
    "esperançávei": "esperançar",
    "esperançáveis": "esperançar",
    "esperara": "esperar",
    "esperaram": "esperar",
    "esperaras": "esperar",
    "esperarde": "esperar",
    "esperardes": "esperar",
    "esperare": "esperar",
    "esperarei": "esperar",
    "esperareis": "esperar",
    "esperarem": "esperar",
    "esperaremos": "esperar",
    "esperares": "esperar",
    "esperaria": "esperar",
    "esperariam": "esperar",
    "esperarias": "esperar",
    "esperarmo": "esperar",
    "esperarmos": "esperar",
    "esperará": "esperar",
    "esperarás": "esperar",
    "esperarão": "esperar",
    "esperaríamos": "esperar",
    "esperaríeis": "esperar",
    "esperas": "esperar",
    "esperasse": "esperar",
    "esperassem": "esperar",
    "esperasses": "esperar",
    "esperaste": "esperar",
    "esperastes": "esperar",
    "esperava": "esperar",
    "esperavam": "esperar",
    "esperavas": "esperar",
    "esperazinha": "espera",
    "esperazinhas": "espera",
    "esperazita": "espera",
    "esperazitas": "espera",
    "esperdice": "esperdiçar",
    "esperdicei": "esperdiçar",
    "esperdiceis": "esperdiçar",
    "esperdicem": "esperdiçar",
    "esperdicemo": "esperdiçar",
    "esperdicemos": "esperdiçar",
    "esperdices": "esperdiçar",
    "esperdiça": "esperdiçar",
    "esperdiçada": "esperdiçar",
    "esperdiçadas": "esperdiçar",
    "esperdiçado": "esperdiçar",
    "esperdiçadora": "esperdiçador",
    "esperdiçadoras": "esperdiçador",
    "esperdiçadores": "esperdiçador",
    "esperdiçados": "esperdiçar",
    "esperdiçai": "esperdiçar",
    "esperdiçais": "esperdiçar",
    "esperdiçam": "esperdiçar",
    "esperdiçamo": "esperdiçar",
    "esperdiçamos": "esperdiçar",
    "esperdiçando": "esperdiçar",
    "esperdiçara": "esperdiçar",
    "esperdiçaram": "esperdiçar",
    "esperdiçaras": "esperdiçar",
    "esperdiçarde": "esperdiçar",
    "esperdiçardes": "esperdiçar",
    "esperdiçare": "esperdiçar",
    "esperdiçarei": "esperdiçar",
    "esperdiçareis": "esperdiçar",
    "esperdiçarem": "esperdiçar",
    "esperdiçaremos": "esperdiçar",
    "esperdiçares": "esperdiçar",
    "esperdiçaria": "esperdiçar",
    "esperdiçariam": "esperdiçar",
    "esperdiçarias": "esperdiçar",
    "esperdiçarmo": "esperdiçar",
    "esperdiçarmos": "esperdiçar",
    "esperdiçará": "esperdiçar",
    "esperdiçarás": "esperdiçar",
    "esperdiçarão": "esperdiçar",
    "esperdiçaríamos": "esperdiçar",
    "esperdiçaríeis": "esperdiçar",
    "esperdiças": "esperdiçar",
    "esperdiçasse": "esperdiçar",
    "esperdiçassem": "esperdiçar",
    "esperdiçasses": "esperdiçar",
    "esperdiçaste": "esperdiçar",
    "esperdiçastes": "esperdiçar",
    "esperdiçava": "esperdiçar",
    "esperdiçavam": "esperdiçar",
    "esperdiçavas": "esperdiçar",
    "esperdiço": "esperdiçar",
    "esperdiçou": "esperdiçar",
    "esperdiçá": "esperdiçar",
    "esperdiçámo": "esperdiçar",
    "esperdiçámos": "esperdiçar",
    "esperdiçáramo": "esperdiçar",
    "esperdiçáramos": "esperdiçar",
    "esperdiçárei": "esperdiçar",
    "esperdiçáreis": "esperdiçar",
    "esperdiçásseis": "esperdiçar",
    "esperdiçássemos": "esperdiçar",
    "esperdiçávamo": "esperdiçar",
    "esperdiçávamos": "esperdiçar",
    "esperdiçávei": "esperdiçar",
    "esperdiçáveis": "esperdiçar",
    "esperdícios": "esperdício",
    "espere": "esperar",
    "esperei": "esperar",
    "espereis": "esperar",
    "esperem": "esperar",
    "esperemo": "esperar",
    "esperemos": "esperar",
    "esperes": "esperar",
    "esperiegas": "esperiega",
    "espermacetes": "espermacete",
    "espermas": "esperma",
    "espermatecas": "espermateca",
    "espermatiza": "espermatizar",
    "espermatizada": "espermatizar",
    "espermatizadas": "espermatizar",
    "espermatizado": "espermatizar",
    "espermatizados": "espermatizar",
    "espermatizai": "espermatizar",
    "espermatizais": "espermatizar",
    "espermatizam": "espermatizar",
    "espermatizamo": "espermatizar",
    "espermatizamos": "espermatizar",
    "espermatizando": "espermatizar",
    "espermatizara": "espermatizar",
    "espermatizaram": "espermatizar",
    "espermatizaras": "espermatizar",
    "espermatizarde": "espermatizar",
    "espermatizardes": "espermatizar",
    "espermatizare": "espermatizar",
    "espermatizarei": "espermatizar",
    "espermatizareis": "espermatizar",
    "espermatizarem": "espermatizar",
    "espermatizaremos": "espermatizar",
    "espermatizares": "espermatizar",
    "espermatizaria": "espermatizar",
    "espermatizariam": "espermatizar",
    "espermatizarias": "espermatizar",
    "espermatizarmo": "espermatizar",
    "espermatizarmos": "espermatizar",
    "espermatizará": "espermatizar",
    "espermatizarás": "espermatizar",
    "espermatizarão": "espermatizar",
    "espermatizaríamos": "espermatizar",
    "espermatizaríeis": "espermatizar",
    "espermatizas": "espermatizar",
    "espermatizasse": "espermatizar",
    "espermatizassem": "espermatizar",
    "espermatizasses": "espermatizar",
    "espermatizaste": "espermatizar",
    "espermatizastes": "espermatizar",
    "espermatizava": "espermatizar",
    "espermatizavam": "espermatizar",
    "espermatizavas": "espermatizar",
    "espermatize": "espermatizar",
    "espermatizei": "espermatizar",
    "espermatizeis": "espermatizar",
    "espermatizem": "espermatizar",
    "espermatizemo": "espermatizar",
    "espermatizemos": "espermatizar",
    "espermatizes": "espermatizar",
    "espermatizo": "espermatizar",
    "espermatizou": "espermatizar",
    "espermatizá": "espermatizar",
    "espermatizámo": "espermatizar",
    "espermatizámos": "espermatizar",
    "espermatizáramo": "espermatizar",
    "espermatizáramos": "espermatizar",
    "espermatizárei": "espermatizar",
    "espermatizáreis": "espermatizar",
    "espermatizásseis": "espermatizar",
    "espermatizássemos": "espermatizar",
    "espermatizávamo": "espermatizar",
    "espermatizávamos": "espermatizar",
    "espermatizávei": "espermatizar",
    "espermatizáveis": "espermatizar",
    "espermatoblastos": "espermatoblasto",
    "espermatoblástica": "espermatoblástico",
    "espermatoblásticas": "espermatoblástico",
    "espermatoblásticos": "espermatoblástico",
    "espermatoceles": "espermatocele",
    "espermatogenésica": "espermatogenésico",
    "espermatogenésicas": "espermatogenésico",
    "espermatogenésicos": "espermatogenésico",
    "espermatogéneses": "espermatogénese",
    "espermatogénica": "espermatogénico",
    "espermatogénicas": "espermatogénico",
    "espermatogénicos": "espermatogénico",
    "espermatogónica": "espermatogónico",
    "espermatogónicas": "espermatogónico",
    "espermatogónicos": "espermatogónico",
    "espermatogónios": "espermatogónio",
    "espermatorreias": "espermatorreia",
    "espermatorreica": "espermatorreico",
    "espermatorreicas": "espermatorreico",
    "espermatorreicos": "espermatorreico",
    "espermatotecas": "espermatoteca",
    "espermatozoária": "espermatozoário",
    "espermatozoárias": "espermatozoário",
    "espermatozoários": "espermatozoário",
    "espermatozóides": "espermatozóide",
    "espermatídios": "espermatídio",
    "espermatócitos": "espermatócito",
    "espermatófitas": "espermatófita",
    "espermatófitos": "espermatófito",
    "espermatóforos": "espermatóforo",
    "espermatótica": "espermatótico",
    "espermatóticas": "espermatótico",
    "espermatóticos": "espermatótico",
    "espermicidas": "espermicida",
    "espermácios": "espermácio",
    "espermáfitas": "espermáfita",
    "espermática": "espermático",
    "espermáticas": "espermático",
    "espermáticos": "espermático",
    "esperneada": "espernear",
    "esperneadas": "espernear",
    "esperneado": "espernear",
    "esperneados": "espernear",
    "esperneai": "espernear",
    "esperneais": "espernear",
    "esperneamo": "espernear",
    "esperneamos": "espernear",
    "esperneando": "espernear",
    "esperneara": "espernear",
    "espernearam": "espernear",
    "espernearas": "espernear",
    "espernearde": "espernear",
    "esperneardes": "espernear",
    "esperneare": "espernear",
    "espernearei": "espernear",
    "esperneareis": "espernear",
    "espernearem": "espernear",
    "espernearemos": "espernear",
    "esperneares": "espernear",
    "espernearia": "espernear",
    "esperneariam": "espernear",
    "espernearias": "espernear",
    "espernearmo": "espernear",
    "espernearmos": "espernear",
    "esperneará": "espernear",
    "espernearás": "espernear",
    "espernearão": "espernear",
    "espernearíamos": "espernear",
    "espernearíeis": "espernear",
    "esperneasse": "espernear",
    "esperneassem": "espernear",
    "esperneasses": "espernear",
    "esperneaste": "espernear",
    "esperneastes": "espernear",
    "esperneava": "espernear",
    "esperneavam": "espernear",
    "esperneavas": "espernear",
    "esperneei": "espernear",
    "esperneeis": "espernear",
    "esperneemo": "espernear",
    "esperneemos": "espernear",
    "espernega": "espernegar",
    "espernegada": "espernegar",
    "espernegadas": "espernegar",
    "espernegado": "espernegar",
    "espernegados": "espernegar",
    "espernegai": "espernegar",
    "espernegais": "espernegar",
    "espernegam": "espernegar",
    "espernegamo": "espernegar",
    "espernegamos": "espernegar",
    "espernegando": "espernegar",
    "espernegara": "espernegar",
    "espernegaram": "espernegar",
    "espernegaras": "espernegar",
    "espernegarde": "espernegar",
    "espernegardes": "espernegar",
    "espernegare": "espernegar",
    "espernegarei": "espernegar",
    "espernegareis": "espernegar",
    "espernegarem": "espernegar",
    "espernegaremos": "espernegar",
    "espernegares": "espernegar",
    "espernegaria": "espernegar",
    "espernegariam": "espernegar",
    "espernegarias": "espernegar",
    "espernegarmo": "espernegar",
    "espernegarmos": "espernegar",
    "espernegará": "espernegar",
    "espernegarás": "espernegar",
    "espernegarão": "espernegar",
    "espernegaríamos": "espernegar",
    "espernegaríeis": "espernegar",
    "espernegas": "espernegar",
    "espernegasse": "espernegar",
    "espernegassem": "espernegar",
    "espernegasses": "espernegar",
    "espernegaste": "espernegar",
    "espernegastes": "espernegar",
    "espernegava": "espernegar",
    "espernegavam": "espernegar",
    "espernegavas": "espernegar",
    "espernego": "espernegar",
    "espernegou": "espernegar",
    "espernegue": "espernegar",
    "esperneguei": "espernegar",
    "espernegueis": "espernegar",
    "esperneguem": "espernegar",
    "esperneguemo": "espernegar",
    "esperneguemos": "espernegar",
    "espernegues": "espernegar",
    "espernegá": "espernegar",
    "espernegámo": "espernegar",
    "espernegámos": "espernegar",
    "espernegáramo": "espernegar",
    "espernegáramos": "espernegar",
    "espernegárei": "espernegar",
    "espernegáreis": "espernegar",
    "espernegásseis": "espernegar",
    "espernegássemos": "espernegar",
    "espernegávamo": "espernegar",
    "espernegávamos": "espernegar",
    "espernegávei": "espernegar",
    "espernegáveis": "espernegar",
    "esperneia": "espernear",
    "esperneiam": "espernear",
    "esperneias": "espernear",
    "esperneie": "espernear",
    "esperneiem": "espernear",
    "esperneies": "espernear",
    "esperneio": "espernear",
    "esperneou": "espernear",
    "esperneá": "espernear",
    "esperneámo": "espernear",
    "esperneámos": "espernear",
    "esperneáramo": "espernear",
    "esperneáramos": "espernear",
    "esperneárei": "espernear",
    "esperneáreis": "espernear",
    "esperneásseis": "espernear",
    "esperneássemos": "espernear",
    "esperneávamo": "espernear",
    "esperneávamos": "espernear",
    "esperneávei": "espernear",
    "esperneáveis": "espernear",
    "espero": "esperar",
    "esperou": "esperar",
    "esperta": "esperto",
    "espertada": "espertar",
    "espertadas": "espertar",
    "espertado": "espertar",
    "espertadora": "espertador",
    "espertadoras": "espertador",
    "espertadores": "espertador",
    "espertados": "espertar",
    "espertai": "espertar",
    "espertais": "espertar",
    "espertalhona": "espertalhão",
    "espertalhonas": "espertalhão",
    "espertalhões": "espertalhão",
    "espertam": "espertar",
    "espertamentos": "espertamento",
    "espertamo": "espertar",
    "espertamos": "espertar",
    "espertando": "espertar",
    "espertara": "espertar",
    "espertaram": "espertar",
    "espertaras": "espertar",
    "espertarde": "espertar",
    "espertardes": "espertar",
    "espertare": "espertar",
    "espertarei": "espertar",
    "espertareis": "espertar",
    "espertarem": "espertar",
    "espertaremos": "espertar",
    "espertares": "espertar",
    "espertaria": "espertar",
    "espertariam": "espertar",
    "espertarias": "espertar",
    "espertarmo": "espertar",
    "espertarmos": "espertar",
    "espertará": "espertar",
    "espertarás": "espertar",
    "espertarão": "espertar",
    "espertaríamos": "espertar",
    "espertaríeis": "espertar",
    "espertas": "esperto",
    "espertasse": "espertar",
    "espertassem": "espertar",
    "espertasses": "espertar",
    "espertaste": "espertar",
    "espertastes": "espertar",
    "espertava": "espertar",
    "espertavam": "espertar",
    "espertavas": "espertar",
    "espertazinha": "esperto",
    "espertazinhas": "esperto",
    "espertazita": "esperto",
    "espertazitas": "esperto",
    "espertaça": "esperto",
    "espertaças": "esperto",
    "espertaço": "esperto",
    "espertaços": "esperto",
    "esperte": "espertar",
    "espertei": "espertar",
    "esperteis": "espertar",
    "espertem": "espertar",
    "espertemo": "espertar",
    "espertemos": "espertar",
    "espertes": "espertar",
    "espertezas": "esperteza",
    "espertina": "espertinar",
    "espertinada": "espertinar",
    "espertinadas": "espertinar",
    "espertinado": "espertinar",
    "espertinados": "espertinar",
    "espertinai": "espertinar",
    "espertinais": "espertinar",
    "espertinam": "espertinar",
    "espertinamo": "espertinar",
    "espertinamos": "espertinar",
    "espertinando": "espertinar",
    "espertinara": "espertinar",
    "espertinaram": "espertinar",
    "espertinaras": "espertinar",
    "espertinarde": "espertinar",
    "espertinardes": "espertinar",
    "espertinare": "espertinar",
    "espertinarei": "espertinar",
    "espertinareis": "espertinar",
    "espertinarem": "espertinar",
    "espertinaremos": "espertinar",
    "espertinares": "espertinar",
    "espertinaria": "espertinar",
    "espertinariam": "espertinar",
    "espertinarias": "espertinar",
    "espertinarmo": "espertinar",
    "espertinarmos": "espertinar",
    "espertinará": "espertinar",
    "espertinarás": "espertinar",
    "espertinarão": "espertinar",
    "espertinaríamos": "espertinar",
    "espertinaríeis": "espertinar",
    "espertinas": "espertinar",
    "espertinasse": "espertinar",
    "espertinassem": "espertinar",
    "espertinasses": "espertinar",
    "espertinaste": "espertinar",
    "espertinastes": "espertinar",
    "espertinava": "espertinar",
    "espertinavam": "espertinar",
    "espertinavas": "espertinar",
    "espertine": "espertinar",
    "espertinei": "espertinar",
    "espertineis": "espertinar",
    "espertinem": "espertinar",
    "espertinemo": "espertinar",
    "espertinemos": "espertinar",
    "espertines": "espertinar",
    "espertinha": "esperto",
    "espertinhas": "esperto",
    "espertinho": "esperto",
    "espertinhos": "esperto",
    "espertino": "espertinar",
    "espertinou": "espertinar",
    "espertiná": "espertinar",
    "espertinámo": "espertinar",
    "espertinámos": "espertinar",
    "espertináramo": "espertinar",
    "espertináramos": "espertinar",
    "espertinárei": "espertinar",
    "espertináreis": "espertinar",
    "espertinásseis": "espertinar",
    "espertinássemos": "espertinar",
    "espertinávamo": "espertinar",
    "espertinávamos": "espertinar",
    "espertinávei": "espertinar",
    "espertináveis": "espertinar",
    "espertita": "esperto",
    "espertitas": "esperto",
    "espertito": "esperto",
    "espertitos": "esperto",
    "esperto": "espertar",
    "espertona": "esperto",
    "espertonas": "esperto",
    "espertos": "esperto",
    "espertou": "espertar",
    "espertozinho": "esperto",
    "espertozinhos": "esperto",
    "espertozito": "esperto",
    "espertozitos": "esperto",
    "espertá": "espertar",
    "espertámo": "espertar",
    "espertámos": "espertar",
    "espertáramo": "espertar",
    "espertáramos": "espertar",
    "espertárei": "espertar",
    "espertáreis": "espertar",
    "espertásseis": "espertar",
    "espertássemos": "espertar",
    "espertávamo": "espertar",
    "espertávamos": "espertar",
    "espertávei": "espertar",
    "espertáveis": "espertar",
    "espertão": "esperto",
    "espertíssima": "esperto",
    "espertíssimas": "esperto",
    "espertíssimo": "esperto",
    "espertíssimos": "esperto",
    "espertões": "esperto",
    "esperá": "esperar",
    "esperámo": "esperar",
    "esperámos": "esperar",
    "esperáramo": "esperar",
    "esperáramos": "esperar",
    "esperárei": "esperar",
    "esperáreis": "esperar",
    "esperásseis": "esperar",
    "esperássemos": "esperar",
    "esperávamo": "esperar",
    "esperávamos": "esperar",
    "esperávei": "esperar",
    "esperáveis": "esperável",
    "espescoce": "espescoçar",
    "espescocei": "espescoçar",
    "espescoceis": "espescoçar",
    "espescocem": "espescoçar",
    "espescocemo": "espescoçar",
    "espescocemos": "espescoçar",
    "espescoces": "espescoçar",
    "espescoça": "espescoçar",
    "espescoçada": "espescoçar",
    "espescoçadas": "espescoçar",
    "espescoçado": "espescoçar",
    "espescoçados": "espescoçar",
    "espescoçai": "espescoçar",
    "espescoçais": "espescoçar",
    "espescoçam": "espescoçar",
    "espescoçamo": "espescoçar",
    "espescoçamos": "espescoçar",
    "espescoçando": "espescoçar",
    "espescoçara": "espescoçar",
    "espescoçaram": "espescoçar",
    "espescoçaras": "espescoçar",
    "espescoçarde": "espescoçar",
    "espescoçardes": "espescoçar",
    "espescoçare": "espescoçar",
    "espescoçarei": "espescoçar",
    "espescoçareis": "espescoçar",
    "espescoçarem": "espescoçar",
    "espescoçaremos": "espescoçar",
    "espescoçares": "espescoçar",
    "espescoçaria": "espescoçar",
    "espescoçariam": "espescoçar",
    "espescoçarias": "espescoçar",
    "espescoçarmo": "espescoçar",
    "espescoçarmos": "espescoçar",
    "espescoçará": "espescoçar",
    "espescoçarás": "espescoçar",
    "espescoçarão": "espescoçar",
    "espescoçaríamos": "espescoçar",
    "espescoçaríeis": "espescoçar",
    "espescoças": "espescoçar",
    "espescoçasse": "espescoçar",
    "espescoçassem": "espescoçar",
    "espescoçasses": "espescoçar",
    "espescoçaste": "espescoçar",
    "espescoçastes": "espescoçar",
    "espescoçava": "espescoçar",
    "espescoçavam": "espescoçar",
    "espescoçavas": "espescoçar",
    "espescoço": "espescoçar",
    "espescoçou": "espescoçar",
    "espescoçá": "espescoçar",
    "espescoçámo": "espescoçar",
    "espescoçámos": "espescoçar",
    "espescoçáramo": "espescoçar",
    "espescoçáramos": "espescoçar",
    "espescoçárei": "espescoçar",
    "espescoçáreis": "espescoçar",
    "espescoçásseis": "espescoçar",
    "espescoçássemos": "espescoçar",
    "espescoçávamo": "espescoçar",
    "espescoçávamos": "espescoçar",
    "espescoçávei": "espescoçar",
    "espescoçáveis": "espescoçar",
    "espessa": "espesso",
    "espessada": "espessar",
    "espessadas": "espessar",
    "espessado": "espessar",
    "espessados": "espessar",
    "espessai": "espessar",
    "espessais": "espessar",
    "espessam": "espessar",
    "espessamentos": "espessamento",
    "espessamo": "espessar",
    "espessamos": "espessar",
    "espessando": "espessar",
    "espessara": "espessar",
    "espessaram": "espessar",
    "espessaras": "espessar",
    "espessarde": "espessar",
    "espessardes": "espessar",
    "espessare": "espessar",
    "espessarei": "espessar",
    "espessareis": "espessar",
    "espessarem": "espessar",
    "espessaremos": "espessar",
    "espessares": "espessar",
    "espessaria": "espessar",
    "espessariam": "espessar",
    "espessarias": "espessar",
    "espessarmo": "espessar",
    "espessarmos": "espessar",
    "espessará": "espessar",
    "espessarás": "espessar",
    "espessarão": "espessar",
    "espessaríamos": "espessar",
    "espessaríeis": "espessar",
    "espessas": "espesso",
    "espessasse": "espessar",
    "espessassem": "espessar",
    "espessasses": "espessar",
    "espessaste": "espessar",
    "espessastes": "espessar",
    "espessava": "espessar",
    "espessavam": "espessar",
    "espessavas": "espessar",
    "espesse": "espessar",
    "espessei": "espessar",
    "espesseis": "espessar",
    "espessem": "espessar",
    "espessemo": "espessar",
    "espessemos": "espessar",
    "espesses": "espessar",
    "espessidões": "espessidão",
    "espesso": "espessar",
    "espessos": "espesso",
    "espessou": "espessar",
    "espessuras": "espessura",
    "espessá": "espessar",
    "espessámo": "espessar",
    "espessámos": "espessar",
    "espessáramo": "espessar",
    "espessáramos": "espessar",
    "espessárei": "espessar",
    "espessáreis": "espessar",
    "espessásseis": "espessar",
    "espessássemos": "espessar",
    "espessávamo": "espessar",
    "espessávamos": "espessar",
    "espessávei": "espessar",
    "espessáveis": "espessar",
    "espessíssima": "espesso",
    "espessíssimas": "espesso",
    "espessíssimo": "espesso",
    "espessíssimos": "espesso",
    "espeta": "espetar",
    "espetada": "espetar",
    "espetadas": "espetar",
    "espetadazinha": "espetada",
    "espetadazinhas": "espetada",
    "espetadazita": "espetada",
    "espetadazitas": "espetada",
    "espetadelas": "espetadela",
    "espetadinha": "espetada",
    "espetadinhas": "espetada",
    "espetadita": "espetada",
    "espetaditas": "espetada",
    "espetado": "espetar",
    "espetados": "espetar",
    "espetai": "espetar",
    "espetais": "espetar",
    "espetam": "espetar",
    "espetamo": "espetar",
    "espetamos": "espetar",
    "espetando": "espetar",
    "espetanços": "espetanço",
    "espetara": "espetar",
    "espetaram": "espetar",
    "espetaras": "espetar",
    "espetarde": "espetar",
    "espetardes": "espetar",
    "espetare": "espetar",
    "espetarei": "espetar",
    "espetareis": "espetar",
    "espetarem": "espetar",
    "espetaremos": "espetar",
    "espetares": "espetar",
    "espetaria": "espetar",
    "espetariam": "espetar",
    "espetarias": "espetar",
    "espetarmo": "espetar",
    "espetarmos": "espetar",
    "espetarrada": "espetarrado",
    "espetarradas": "espetarrado",
    "espetarrados": "espetarrado",
    "espetará": "espetar",
    "espetarás": "espetar",
    "espetarão": "espetar",
    "espetaríamos": "espetar",
    "espetaríeis": "espetar",
    "espetas": "espetar",
    "espetasse": "espetar",
    "espetassem": "espetar",
    "espetasses": "espetar",
    "espetaste": "espetar",
    "espetastes": "espetar",
    "espetava": "espetar",
    "espetavam": "espetar",
    "espetavas": "espetar",
    "espete": "espetar",
    "espetei": "espetar",
    "espeteiras": "espeteira",
    "espeteis": "espetar",
    "espetem": "espetar",
    "espetemo": "espetar",
    "espetemos": "espetar",
    "espetes": "espetar",
    "espetinho": "espeto",
    "espetinhos": "espeto",
    "espetito": "espeto",
    "espetitos": "espeto",
    "espeto": "espetar",
    "espetos": "espeto",
    "espetou": "espetar",
    "espetá": "espetar",
    "espetámo": "espetar",
    "espetámos": "espetar",
    "espetáramo": "espetar",
    "espetáramos": "espetar",
    "espetárei": "espetar",
    "espetáreis": "espetar",
    "espetásseis": "espetar",
    "espetássemos": "espetar",
    "espetávamo": "espetar",
    "espetávamos": "espetar",
    "espetávei": "espetar",
    "espetáveis": "espetável",
    "espetões": "espetão",
    "espevita": "espevitar",
    "espevitada": "espevitar",
    "espevitadas": "espevitar",
    "espevitadeiras": "espevitadeira",
    "espevitado": "espevitar",
    "espevitadora": "espevitador",
    "espevitadoras": "espevitador",
    "espevitadores": "espevitador",
    "espevitados": "espevitar",
    "espevitadíssima": "espevitado",
    "espevitadíssimas": "espevitado",
    "espevitadíssimo": "espevitado",
    "espevitadíssimos": "espevitado",
    "espevitai": "espevitar",
    "espevitais": "espevitar",
    "espevitam": "espevitar",
    "espevitamentos": "espevitamento",
    "espevitamo": "espevitar",
    "espevitamos": "espevitar",
    "espevitando": "espevitar",
    "espevitara": "espevitar",
    "espevitaram": "espevitar",
    "espevitaras": "espevitar",
    "espevitarde": "espevitar",
    "espevitardes": "espevitar",
    "espevitare": "espevitar",
    "espevitarei": "espevitar",
    "espevitareis": "espevitar",
    "espevitarem": "espevitar",
    "espevitaremos": "espevitar",
    "espevitares": "espevitar",
    "espevitaria": "espevitar",
    "espevitariam": "espevitar",
    "espevitarias": "espevitar",
    "espevitarmo": "espevitar",
    "espevitarmos": "espevitar",
    "espevitará": "espevitar",
    "espevitarás": "espevitar",
    "espevitarão": "espevitar",
    "espevitaríamos": "espevitar",
    "espevitaríeis": "espevitar",
    "espevitas": "espevitar",
    "espevitasse": "espevitar",
    "espevitassem": "espevitar",
    "espevitasses": "espevitar",
    "espevitaste": "espevitar",
    "espevitastes": "espevitar",
    "espevitava": "espevitar",
    "espevitavam": "espevitar",
    "espevitavas": "espevitar",
    "espevite": "espevitar",
    "espevitei": "espevitar",
    "espeviteis": "espevitar",
    "espevitem": "espevitar",
    "espevitemo": "espevitar",
    "espevitemos": "espevitar",
    "espevites": "espevitar",
    "espevito": "espevitar",
    "espevitou": "espevitar",
    "espevitá": "espevitar",
    "espevitámo": "espevitar",
    "espevitámos": "espevitar",
    "espevitáramo": "espevitar",
    "espevitáramos": "espevitar",
    "espevitárei": "espevitar",
    "espevitáreis": "espevitar",
    "espevitásseis": "espevitar",
    "espevitássemos": "espevitar",
    "espevitávamo": "espevitar",
    "espevitávamos": "espevitar",
    "espevitávei": "espevitar",
    "espevitáveis": "espevitável",
    "espezinha": "espezinhar",
    "espezinhada": "espezinhar",
    "espezinhadas": "espezinhar",
    "espezinhado": "espezinhar",
    "espezinhados": "espezinhar",
    "espezinhai": "espezinhar",
    "espezinhais": "espezinhar",
    "espezinham": "espezinhar",
    "espezinhamo": "espezinhar",
    "espezinhamos": "espezinhar",
    "espezinhando": "espezinhar",
    "espezinhara": "espezinhar",
    "espezinharam": "espezinhar",
    "espezinharas": "espezinhar",
    "espezinharde": "espezinhar",
    "espezinhardes": "espezinhar",
    "espezinhare": "espezinhar",
    "espezinharei": "espezinhar",
    "espezinhareis": "espezinhar",
    "espezinharem": "espezinhar",
    "espezinharemos": "espezinhar",
    "espezinhares": "espezinhar",
    "espezinharia": "espezinhar",
    "espezinhariam": "espezinhar",
    "espezinharias": "espezinhar",
    "espezinharmo": "espezinhar",
    "espezinharmos": "espezinhar",
    "espezinhará": "espezinhar",
    "espezinharás": "espezinhar",
    "espezinharão": "espezinhar",
    "espezinharíamos": "espezinhar",
    "espezinharíeis": "espezinhar",
    "espezinhas": "espezinhar",
    "espezinhasse": "espezinhar",
    "espezinhassem": "espezinhar",
    "espezinhasses": "espezinhar",
    "espezinhaste": "espezinhar",
    "espezinhastes": "espezinhar",
    "espezinhava": "espezinhar",
    "espezinhavam": "espezinhar",
    "espezinhavas": "espezinhar",
    "espezinhe": "espezinhar",
    "espezinhei": "espezinhar",
    "espezinheis": "espezinhar",
    "espezinhem": "espezinhar",
    "espezinhemo": "espezinhar",
    "espezinhemos": "espezinhar",
    "espezinhes": "espezinhar",
    "espezinho": "espezinhar",
    "espezinhou": "espezinhar",
    "espezinhá": "espezinhar",
    "espezinhámo": "espezinhar",
    "espezinhámos": "espezinhar",
    "espezinháramo": "espezinhar",
    "espezinháramos": "espezinhar",
    "espezinhárei": "espezinhar",
    "espezinháreis": "espezinhar",
    "espezinhásseis": "espezinhar",
    "espezinhássemos": "espezinhar",
    "espezinhávamo": "espezinhar",
    "espezinhávamos": "espezinhar",
    "espezinhávei": "espezinhar",
    "espezinháveis": "espezinhar",
    "espeça": "espeçar",
    "espeçada": "espeçar",
    "espeçadas": "espeçar",
    "espeçado": "espeçar",
    "espeçados": "espeçar",
    "espeçai": "espeçar",
    "espeçais": "espeçar",
    "espeçam": "espeçar",
    "espeçamo": "espeçar",
    "espeçamos": "espeçar",
    "espeçando": "espeçar",
    "espeçara": "espeçar",
    "espeçaram": "espeçar",
    "espeçaras": "espeçar",
    "espeçarde": "espeçar",
    "espeçardes": "espeçar",
    "espeçare": "espeçar",
    "espeçarei": "espeçar",
    "espeçareis": "espeçar",
    "espeçarem": "espeçar",
    "espeçaremos": "espeçar",
    "espeçares": "espeçar",
    "espeçaria": "espeçar",
    "espeçariam": "espeçar",
    "espeçarias": "espeçar",
    "espeçarmo": "espeçar",
    "espeçarmos": "espeçar",
    "espeçará": "espeçar",
    "espeçarás": "espeçar",
    "espeçarão": "espeçar",
    "espeçaríamos": "espeçar",
    "espeçaríeis": "espeçar",
    "espeças": "espeçar",
    "espeçasse": "espeçar",
    "espeçassem": "espeçar",
    "espeçasses": "espeçar",
    "espeçaste": "espeçar",
    "espeçastes": "espeçar",
    "espeçava": "espeçar",
    "espeçavam": "espeçar",
    "espeçavas": "espeçar",
    "espeço": "espeçar",
    "espeçou": "espeçar",
    "espeçá": "espeçar",
    "espeçámo": "espeçar",
    "espeçámos": "espeçar",
    "espeçáramo": "espeçar",
    "espeçáramos": "espeçar",
    "espeçárei": "espeçar",
    "espeçáreis": "espeçar",
    "espeçásseis": "espeçar",
    "espeçássemos": "espeçar",
    "espeçávamo": "espeçar",
    "espeçávamos": "espeçar",
    "espeçávei": "espeçar",
    "espeçáveis": "espeçar",
    "espia": "espiar",
    "espiada": "espiar",
    "espiadas": "espiar",
    "espiado": "espiar",
    "espiados": "espiar",
    "espiai": "espiar",
    "espiais": "espiar",
    "espiam": "espiar",
    "espiamo": "espiar",
    "espiamos": "espiar",
    "espiando": "espiar",
    "espiara": "espiar",
    "espiaram": "espiar",
    "espiaras": "espiar",
    "espiarde": "espiar",
    "espiardes": "espiar",
    "espiare": "espiar",
    "espiarei": "espiar",
    "espiareis": "espiar",
    "espiarem": "espiar",
    "espiaremos": "espiar",
    "espiares": "espiar",
    "espiaria": "espiar",
    "espiariam": "espiar",
    "espiarias": "espiar",
    "espiarmo": "espiar",
    "espiarmos": "espiar",
    "espiará": "espiar",
    "espiarás": "espiar",
    "espiarão": "espiar",
    "espiaríamos": "espiar",
    "espiaríeis": "espiar",
    "espias": "espiar",
    "espiasse": "espiar",
    "espiassem": "espiar",
    "espiasses": "espiar",
    "espiaste": "espiar",
    "espiastes": "espiar",
    "espiava": "espiar",
    "espiavam": "espiar",
    "espiavas": "espiar",
    "espicace": "espicaçar",
    "espicacei": "espicaçar",
    "espicaceis": "espicaçar",
    "espicacem": "espicaçar",
    "espicacemo": "espicaçar",
    "espicacemos": "espicaçar",
    "espicaces": "espicaçar",
    "espicaça": "espicaçar",
    "espicaçada": "espicaçar",
    "espicaçadas": "espicaçar",
    "espicaçadelas": "espicaçadela",
    "espicaçado": "espicaçar",
    "espicaçados": "espicaçar",
    "espicaçai": "espicaçar",
    "espicaçais": "espicaçar",
    "espicaçam": "espicaçar",
    "espicaçamo": "espicaçar",
    "espicaçamos": "espicaçar",
    "espicaçando": "espicaçar",
    "espicaçara": "espicaçar",
    "espicaçaram": "espicaçar",
    "espicaçaras": "espicaçar",
    "espicaçarde": "espicaçar",
    "espicaçardes": "espicaçar",
    "espicaçare": "espicaçar",
    "espicaçarei": "espicaçar",
    "espicaçareis": "espicaçar",
    "espicaçarem": "espicaçar",
    "espicaçaremos": "espicaçar",
    "espicaçares": "espicaçar",
    "espicaçaria": "espicaçar",
    "espicaçariam": "espicaçar",
    "espicaçarias": "espicaçar",
    "espicaçarmo": "espicaçar",
    "espicaçarmos": "espicaçar",
    "espicaçará": "espicaçar",
    "espicaçarás": "espicaçar",
    "espicaçarão": "espicaçar",
    "espicaçaríamos": "espicaçar",
    "espicaçaríeis": "espicaçar",
    "espicaças": "espicaçar",
    "espicaçasse": "espicaçar",
    "espicaçassem": "espicaçar",
    "espicaçasses": "espicaçar",
    "espicaçaste": "espicaçar",
    "espicaçastes": "espicaçar",
    "espicaçava": "espicaçar",
    "espicaçavam": "espicaçar",
    "espicaçavas": "espicaçar",
    "espicaço": "espicaçar",
    "espicaçou": "espicaçar",
    "espicaçá": "espicaçar",
    "espicaçámo": "espicaçar",
    "espicaçámos": "espicaçar",
    "espicaçáramo": "espicaçar",
    "espicaçáramos": "espicaçar",
    "espicaçárei": "espicaçar",
    "espicaçáreis": "espicaçar",
    "espicaçásseis": "espicaçar",
    "espicaçássemos": "espicaçar",
    "espicaçávamo": "espicaçar",
    "espicaçávamos": "espicaçar",
    "espicaçávei": "espicaçar",
    "espicaçáveis": "espicaçável",
    "espicha": "espichar",
    "espichada": "espichar",
    "espichadas": "espichar",
    "espichadeiras": "espichadeira",
    "espichadelas": "espichadela",
    "espichado": "espichar",
    "espichados": "espichar",
    "espichai": "espichar",
    "espichais": "espichar",
    "espicham": "espichar",
    "espichamo": "espichar",
    "espichamos": "espichar",
    "espichando": "espichar",
    "espichara": "espichar",
    "espicharam": "espichar",
    "espicharas": "espichar",
    "espicharde": "espichar",
    "espichardes": "espichar",
    "espichare": "espichar",
    "espicharei": "espichar",
    "espichareis": "espichar",
    "espicharem": "espichar",
    "espicharemos": "espichar",
    "espichares": "espichar",
    "espicharia": "espichar",
    "espichariam": "espichar",
    "espicharias": "espichar",
    "espicharmo": "espichar",
    "espicharmos": "espichar",
    "espichará": "espichar",
    "espicharás": "espichar",
    "espicharão": "espichar",
    "espicharíamos": "espichar",
    "espicharíeis": "espichar",
    "espichas": "espichar",
    "espichasse": "espichar",
    "espichassem": "espichar",
    "espichasses": "espichar",
    "espichaste": "espichar",
    "espichastes": "espichar",
    "espichava": "espichar",
    "espichavam": "espichar",
    "espichavas": "espichar",
    "espiche": "espichar",
    "espichei": "espichar",
    "espicheis": "espichel",
    "espichelitos": "espichelito",
    "espichem": "espichar",
    "espichemo": "espichar",
    "espichemos": "espichar",
    "espiches": "espiche",
    "espicho": "espichar",
    "espichos": "espicho",
    "espichou": "espichar",
    "espichá": "espichar",
    "espichámo": "espichar",
    "espichámos": "espichar",
    "espicháramo": "espichar",
    "espicháramos": "espichar",
    "espichárei": "espichar",
    "espicháreis": "espichar",
    "espichásseis": "espichar",
    "espichássemos": "espichar",
    "espichávamo": "espichar",
    "espichávamos": "espichar",
    "espichávei": "espichar",
    "espicháveis": "espichar",
    "espiciflora": "espicifloro",
    "espicifloras": "espicifloro",
    "espicifloros": "espicifloro",
    "espiciformes": "espiciforme",
    "espicilégios": "espicilégio",
    "espiclondrífica": "espiclondrífico",
    "espiclondríficas": "espiclondrífico",
    "espiclondríficos": "espiclondrífico",
    "espie": "espiar",
    "espiei": "espiar",
    "espieis": "espiar",
    "espiem": "espiar",
    "espiemo": "espiar",
    "espiemos": "espiar",
    "espies": "espiar",
    "espiga": "espigar",
    "espigada": "espigar",
    "espigadas": "espigar",
    "espigado": "espigar",
    "espigados": "espigar",
    "espigadotes": "espigadote",
    "espigai": "espigar",
    "espigais": "espigar",
    "espigam": "espigar",
    "espigamas": "espigama",
    "espigamentos": "espigamento",
    "espigamo": "espigar",
    "espigamos": "espigar",
    "espigando": "espigar",
    "espigara": "espigar",
    "espigaram": "espigar",
    "espigaras": "espigar",
    "espigardes": "espigar",
    "espigarei": "espigar",
    "espigareis": "espigar",
    "espigarem": "espigar",
    "espigaremos": "espigar",
    "espigares": "espigar",
    "espigaria": "espigar",
    "espigariam": "espigar",
    "espigarias": "espigar",
    "espigarmo": "espigar",
    "espigarmos": "espigar",
    "espigará": "espigar",
    "espigarás": "espigar",
    "espigarão": "espigar",
    "espigaríamos": "espigar",
    "espigaríeis": "espigar",
    "espigas": "espigar",
    "espigasse": "espigar",
    "espigassem": "espigar",
    "espigasses": "espigar",
    "espigaste": "espigar",
    "espigastes": "espigar",
    "espigava": "espigar",
    "espigavam": "espigar",
    "espigavas": "espigar",
    "espigo": "espigar",
    "espigos": "espigo",
    "espigosa": "espigoso",
    "espigosas": "espigoso",
    "espigosos": "espigoso",
    "espigou": "espigar",
    "espigue": "espigar",
    "espiguei": "espigar",
    "espigueiros": "espigueiro",
    "espigueis": "espigar",
    "espiguem": "espigar",
    "espiguemo": "espigar",
    "espiguemos": "espigar",
    "espigues": "espigar",
    "espiguetas": "espigueta",
    "espiguilha": "espiguilhar",
    "espiguilhada": "espiguilhar",
    "espiguilhadas": "espiguilhar",
    "espiguilhado": "espiguilhar",
    "espiguilhados": "espiguilhar",
    "espiguilhai": "espiguilhar",
    "espiguilhais": "espiguilhar",
    "espiguilham": "espiguilhar",
    "espiguilhamo": "espiguilhar",
    "espiguilhamos": "espiguilhar",
    "espiguilhando": "espiguilhar",
    "espiguilhara": "espiguilhar",
    "espiguilharam": "espiguilhar",
    "espiguilharas": "espiguilhar",
    "espiguilharde": "espiguilhar",
    "espiguilhardes": "espiguilhar",
    "espiguilhare": "espiguilhar",
    "espiguilharei": "espiguilhar",
    "espiguilhareis": "espiguilhar",
    "espiguilharem": "espiguilhar",
    "espiguilharemos": "espiguilhar",
    "espiguilhares": "espiguilhar",
    "espiguilharia": "espiguilhar",
    "espiguilhariam": "espiguilhar",
    "espiguilharias": "espiguilhar",
    "espiguilharmo": "espiguilhar",
    "espiguilharmos": "espiguilhar",
    "espiguilhará": "espiguilhar",
    "espiguilharás": "espiguilhar",
    "espiguilharão": "espiguilhar",
    "espiguilharíamos": "espiguilhar",
    "espiguilharíeis": "espiguilhar",
    "espiguilhas": "espiguilhar",
    "espiguilhasse": "espiguilhar",
    "espiguilhassem": "espiguilhar",
    "espiguilhasses": "espiguilhar",
    "espiguilhaste": "espiguilhar",
    "espiguilhastes": "espiguilhar",
    "espiguilhava": "espiguilhar",
    "espiguilhavam": "espiguilhar",
    "espiguilhavas": "espiguilhar",
    "espiguilhe": "espiguilhar",
    "espiguilhei": "espiguilhar",
    "espiguilheis": "espiguilhar",
    "espiguilhem": "espiguilhar",
    "espiguilhemo": "espiguilhar",
    "espiguilhemos": "espiguilhar",
    "espiguilhes": "espiguilhar",
    "espiguilho": "espiguilhar",
    "espiguilhou": "espiguilhar",
    "espiguilhá": "espiguilhar",
    "espiguilhámo": "espiguilhar",
    "espiguilhámos": "espiguilhar",
    "espiguilháramo": "espiguilhar",
    "espiguilháramos": "espiguilhar",
    "espiguilhárei": "espiguilhar",
    "espiguilháreis": "espiguilhar",
    "espiguilhásseis": "espiguilhar",
    "espiguilhássemos": "espiguilhar",
    "espiguilhávamo": "espiguilhar",
    "espiguilhávamos": "espiguilhar",
    "espiguilhávei": "espiguilhar",
    "espiguilháveis": "espiguilhar",
    "espigámo": "espigar",
    "espigámos": "espigar",
    "espigáramo": "espigar",
    "espigáramos": "espigar",
    "espigáreis": "espigar",
    "espigásseis": "espigar",
    "espigássemos": "espigar",
    "espigávamo": "espigar",
    "espigávamos": "espigar",
    "espigáveis": "espigar",
    "espigões": "espigão",
    "espilra": "espilrar",
    "espilrada": "espilrar",
    "espilradas": "espilrar",
    "espilrado": "espilrar",
    "espilrados": "espilrar",
    "espilrai": "espilrar",
    "espilrais": "espilrar",
    "espilram": "espilrar",
    "espilramo": "espilrar",
    "espilramos": "espilrar",
    "espilrando": "espilrar",
    "espilrara": "espilrar",
    "espilraram": "espilrar",
    "espilraras": "espilrar",
    "espilrardes": "espilrar",
    "espilrarei": "espilrar",
    "espilrareis": "espilrar",
    "espilrarem": "espilrar",
    "espilraremos": "espilrar",
    "espilrares": "espilrar",
    "espilraria": "espilrar",
    "espilrariam": "espilrar",
    "espilrarias": "espilrar",
    "espilrarmo": "espilrar",
    "espilrarmos": "espilrar",
    "espilrará": "espilrar",
    "espilrarás": "espilrar",
    "espilrarão": "espilrar",
    "espilraríamos": "espilrar",
    "espilraríeis": "espilrar",
    "espilras": "espilrar",
    "espilrasse": "espilrar",
    "espilrassem": "espilrar",
    "espilrasses": "espilrar",
    "espilraste": "espilrar",
    "espilrastes": "espilrar",
    "espilrava": "espilrar",
    "espilravam": "espilrar",
    "espilravas": "espilrar",
    "espilre": "espilrar",
    "espilrei": "espilrar",
    "espilreis": "espilrar",
    "espilrem": "espilrar",
    "espilremo": "espilrar",
    "espilremos": "espilrar",
    "espilres": "espilrar",
    "espilro": "espilrar",
    "espilrou": "espilrar",
    "espilrámo": "espilrar",
    "espilrámos": "espilrar",
    "espilráramo": "espilrar",
    "espilráramos": "espilrar",
    "espilráreis": "espilrar",
    "espilrásseis": "espilrar",
    "espilrássemos": "espilrar",
    "espilrávamo": "espilrar",
    "espilrávamos": "espilrar",
    "espilráveis": "espilrar",
    "espinacídeos": "espinacídeo",
    "espinafres": "espinafre",
    "espinais": "espinal",
    "espinalgias": "espinalgia",
    "espince": "espinçar",
    "espincei": "espinçar",
    "espinceis": "espinçar",
    "espincem": "espinçar",
    "espincemo": "espinçar",
    "espincemos": "espinçar",
    "espinces": "espinçar",
    "espineis": "espinel",
    "espinelas": "espinela",
    "espinelídeos": "espinelídeo",
    "espinescentes": "espinescente",
    "espinetas": "espineta",
    "espingardadas": "espingardada",
    "espingardarias": "espingardaria",
    "espingardas": "espingarda",
    "espingardeada": "espingardear",
    "espingardeadas": "espingardear",
    "espingardeado": "espingardear",
    "espingardeados": "espingardear",
    "espingardeai": "espingardear",
    "espingardeais": "espingardear",
    "espingardeamentos": "espingardeamento",
    "espingardeamo": "espingardear",
    "espingardeamos": "espingardear",
    "espingardeando": "espingardear",
    "espingardeara": "espingardear",
    "espingardearam": "espingardear",
    "espingardearas": "espingardear",
    "espingardearde": "espingardear",
    "espingardeardes": "espingardear",
    "espingardeare": "espingardear",
    "espingardearei": "espingardear",
    "espingardeareis": "espingardear",
    "espingardearem": "espingardear",
    "espingardearemos": "espingardear",
    "espingardeares": "espingardear",
    "espingardearia": "espingardear",
    "espingardeariam": "espingardear",
    "espingardearias": "espingardear",
    "espingardearmo": "espingardear",
    "espingardearmos": "espingardear",
    "espingardeará": "espingardear",
    "espingardearás": "espingardear",
    "espingardearão": "espingardear",
    "espingardearíamos": "espingardear",
    "espingardearíeis": "espingardear",
    "espingardeasse": "espingardear",
    "espingardeassem": "espingardear",
    "espingardeasses": "espingardear",
    "espingardeaste": "espingardear",
    "espingardeastes": "espingardear",
    "espingardeava": "espingardear",
    "espingardeavam": "espingardear",
    "espingardeavas": "espingardear",
    "espingardeei": "espingardear",
    "espingardeeis": "espingardear",
    "espingardeemo": "espingardear",
    "espingardeemos": "espingardear",
    "espingardeia": "espingardear",
    "espingardeiam": "espingardear",
    "espingardeias": "espingardear",
    "espingardeie": "espingardear",
    "espingardeiem": "espingardear",
    "espingardeies": "espingardear",
    "espingardeio": "espingardear",
    "espingardeiras": "espingardeira",
    "espingardeiros": "espingardeiro",
    "espingardeou": "espingardear",
    "espingardeá": "espingardear",
    "espingardeámo": "espingardear",
    "espingardeámos": "espingardear",
    "espingardeáramo": "espingardear",
    "espingardeáramos": "espingardear",
    "espingardeárei": "espingardear",
    "espingardeáreis": "espingardear",
    "espingardeásseis": "espingardear",
    "espingardeássemos": "espingardear",
    "espingardeávamo": "espingardear",
    "espingardeávamos": "espingardear",
    "espingardeávei": "espingardear",
    "espingardeáveis": "espingardear",
    "espingardões": "espingardão",
    "espinha": "espinhar",
    "espinhada": "espinhar",
    "espinhadas": "espinhar",
    "espinhado": "espinhar",
    "espinhados": "espinhar",
    "espinhai": "espinhar",
    "espinhais": "espinhar",
    "espinham": "espinhar",
    "espinhamo": "espinhar",
    "espinhamos": "espinhar",
    "espinhando": "espinhar",
    "espinhara": "espinhar",
    "espinharam": "espinhar",
    "espinharas": "espinhar",
    "espinharde": "espinhar",
    "espinhardes": "espinhar",
    "espinhare": "espinhar",
    "espinharei": "espinhar",
    "espinhareis": "espinhar",
    "espinharem": "espinhar",
    "espinharemos": "espinhar",
    "espinhares": "espinhar",
    "espinharia": "espinhar",
    "espinhariam": "espinhar",
    "espinharias": "espinhar",
    "espinharmo": "espinhar",
    "espinharmos": "espinhar",
    "espinhará": "espinhar",
    "espinharás": "espinhar",
    "espinharão": "espinhar",
    "espinharíamos": "espinhar",
    "espinharíeis": "espinhar",
    "espinhas": "espinhar",
    "espinhasse": "espinhar",
    "espinhassem": "espinhar",
    "espinhasses": "espinhar",
    "espinhaste": "espinhar",
    "espinhastes": "espinhar",
    "espinhava": "espinhar",
    "espinhavam": "espinhar",
    "espinhavas": "espinhar",
    "espinhaços": "espinhaço",
    "espinhe": "espinhar",
    "espinhei": "espinhar",
    "espinheirais": "espinheiral",
    "espinheiras": "espinheira",
    "espinheiros": "espinheiro",
    "espinheis": "espinhel",
    "espinhelas": "espinhela",
    "espinhem": "espinhar",
    "espinhemo": "espinhar",
    "espinhemos": "espinhar",
    "espinhenses": "espinhense",
    "espinhenta": "espinhento",
    "espinhentas": "espinhento",
    "espinhentos": "espinhento",
    "espinhes": "espinhar",
    "espinho": "espinhar",
    "espinhos": "espinho",
    "espinhosa": "espinhoso",
    "espinhosas": "espinhoso",
    "espinhosos": "espinhoso",
    "espinhou": "espinhar",
    "espinhá": "espinhar",
    "espinhámo": "espinhar",
    "espinhámos": "espinhar",
    "espinháramo": "espinhar",
    "espinháramos": "espinhar",
    "espinhárei": "espinhar",
    "espinháreis": "espinhar",
    "espinhásseis": "espinhar",
    "espinhássemos": "espinhar",
    "espinhávamo": "espinhar",
    "espinhávamos": "espinhar",
    "espinhávei": "espinhar",
    "espinháveis": "espinhar",
    "espiniformes": "espiniforme",
    "espinosismos": "espinosismo",
    "espinosistas": "espinosista",
    "espinoteada": "espinotear",
    "espinoteadas": "espinotear",
    "espinoteado": "espinotear",
    "espinoteados": "espinotear",
    "espinoteai": "espinotear",
    "espinoteais": "espinotear",
    "espinoteamo": "espinotear",
    "espinoteamos": "espinotear",
    "espinoteando": "espinotear",
    "espinoteara": "espinotear",
    "espinotearam": "espinotear",
    "espinotearas": "espinotear",
    "espinoteardes": "espinotear",
    "espinotearei": "espinotear",
    "espinoteareis": "espinotear",
    "espinotearem": "espinotear",
    "espinotearemos": "espinotear",
    "espinoteares": "espinotear",
    "espinotearia": "espinotear",
    "espinoteariam": "espinotear",
    "espinotearias": "espinotear",
    "espinotearmo": "espinotear",
    "espinotearmos": "espinotear",
    "espinoteará": "espinotear",
    "espinotearás": "espinotear",
    "espinotearão": "espinotear",
    "espinotearíamos": "espinotear",
    "espinotearíeis": "espinotear",
    "espinoteasse": "espinotear",
    "espinoteassem": "espinotear",
    "espinoteasses": "espinotear",
    "espinoteaste": "espinotear",
    "espinoteastes": "espinotear",
    "espinoteava": "espinotear",
    "espinoteavam": "espinotear",
    "espinoteavas": "espinotear",
    "espinoteei": "espinotear",
    "espinoteeis": "espinotear",
    "espinoteemo": "espinotear",
    "espinoteemos": "espinotear",
    "espinoteia": "espinotear",
    "espinoteiam": "espinotear",
    "espinoteias": "espinotear",
    "espinoteie": "espinotear",
    "espinoteiem": "espinotear",
    "espinoteies": "espinotear",
    "espinoteio": "espinotear",
    "espinoteios": "espinoteio",
    "espinoteou": "espinotear",
    "espinoteámo": "espinotear",
    "espinoteámos": "espinotear",
    "espinoteáramo": "espinotear",
    "espinoteáramos": "espinotear",
    "espinoteáreis": "espinotear",
    "espinoteásseis": "espinotear",
    "espinoteássemos": "espinotear",
    "espinoteávamo": "espinotear",
    "espinoteávamos": "espinotear",
    "espinoteáveis": "espinotear",
    "espintariscópios": "espintariscópio",
    "espinteroscópios": "espinteroscópio",
    "espinácidas": "espinácida",
    "espinça": "espinçar",
    "espinçada": "espinçar",
    "espinçadas": "espinçar",
    "espinçado": "espinçar",
    "espinçados": "espinçar",
    "espinçai": "espinçar",
    "espinçais": "espinçar",
    "espinçam": "espinçar",
    "espinçamo": "espinçar",
    "espinçamos": "espinçar",
    "espinçando": "espinçar",
    "espinçara": "espinçar",
    "espinçaram": "espinçar",
    "espinçaras": "espinçar",
    "espinçarde": "espinçar",
    "espinçardes": "espinçar",
    "espinçare": "espinçar",
    "espinçarei": "espinçar",
    "espinçareis": "espinçar",
    "espinçarem": "espinçar",
    "espinçaremos": "espinçar",
    "espinçares": "espinçar",
    "espinçaria": "espinçar",
    "espinçariam": "espinçar",
    "espinçarias": "espinçar",
    "espinçarmo": "espinçar",
    "espinçarmos": "espinçar",
    "espinçará": "espinçar",
    "espinçarás": "espinçar",
    "espinçarão": "espinçar",
    "espinçaríamos": "espinçar",
    "espinçaríeis": "espinçar",
    "espinças": "espinçar",
    "espinçasse": "espinçar",
    "espinçassem": "espinçar",
    "espinçasses": "espinçar",
    "espinçaste": "espinçar",
    "espinçastes": "espinçar",
    "espinçava": "espinçar",
    "espinçavam": "espinçar",
    "espinçavas": "espinçar",
    "espinço": "espinçar",
    "espinçou": "espinçar",
    "espinçá": "espinçar",
    "espinçámo": "espinçar",
    "espinçámos": "espinçar",
    "espinçáramo": "espinçar",
    "espinçáramos": "espinçar",
    "espinçárei": "espinçar",
    "espinçáreis": "espinçar",
    "espinçásseis": "espinçar",
    "espinçássemos": "espinçar",
    "espinçávamo": "espinçar",
    "espinçávamos": "espinçar",
    "espinçávei": "espinçar",
    "espinçáveis": "espinçar",
    "espinélidas": "espinélida",
    "espio": "espiar",
    "espiolha": "espiolhar",
    "espiolhada": "espiolhar",
    "espiolhadas": "espiolhar",
    "espiolhado": "espiolhar",
    "espiolhados": "espiolhar",
    "espiolhai": "espiolhar",
    "espiolhais": "espiolhar",
    "espiolham": "espiolhar",
    "espiolhamo": "espiolhar",
    "espiolhamos": "espiolhar",
    "espiolhando": "espiolhar",
    "espiolhara": "espiolhar",
    "espiolharam": "espiolhar",
    "espiolharas": "espiolhar",
    "espiolharde": "espiolhar",
    "espiolhardes": "espiolhar",
    "espiolhare": "espiolhar",
    "espiolharei": "espiolhar",
    "espiolhareis": "espiolhar",
    "espiolharem": "espiolhar",
    "espiolharemos": "espiolhar",
    "espiolhares": "espiolhar",
    "espiolharia": "espiolhar",
    "espiolhariam": "espiolhar",
    "espiolharias": "espiolhar",
    "espiolharmo": "espiolhar",
    "espiolharmos": "espiolhar",
    "espiolhará": "espiolhar",
    "espiolharás": "espiolhar",
    "espiolharão": "espiolhar",
    "espiolharíamos": "espiolhar",
    "espiolharíeis": "espiolhar",
    "espiolhas": "espiolhar",
    "espiolhasse": "espiolhar",
    "espiolhassem": "espiolhar",
    "espiolhasses": "espiolhar",
    "espiolhaste": "espiolhar",
    "espiolhastes": "espiolhar",
    "espiolhava": "espiolhar",
    "espiolhavam": "espiolhar",
    "espiolhavas": "espiolhar",
    "espiolhe": "espiolhar",
    "espiolhei": "espiolhar",
    "espiolheis": "espiolhar",
    "espiolhem": "espiolhar",
    "espiolhemo": "espiolhar",
    "espiolhemos": "espiolhar",
    "espiolhes": "espiolhar",
    "espiolho": "espiolhar",
    "espiolhou": "espiolhar",
    "espiolhá": "espiolhar",
    "espiolhámo": "espiolhar",
    "espiolhámos": "espiolhar",
    "espiolháramo": "espiolhar",
    "espiolháramos": "espiolhar",
    "espiolhárei": "espiolhar",
    "espiolháreis": "espiolhar",
    "espiolhásseis": "espiolhar",
    "espiolhássemos": "espiolhar",
    "espiolhávamo": "espiolhar",
    "espiolhávamos": "espiolhar",
    "espiolhávei": "espiolhar",
    "espiolháveis": "espiolhar",
    "espiona": "espionar",
    "espionada": "espionar",
    "espionadas": "espionar",
    "espionado": "espionar",
    "espionados": "espionar",
    "espionagens": "espionagem",
    "espionai": "espionar",
    "espionais": "espionar",
    "espionam": "espionar",
    "espionamo": "espionar",
    "espionamos": "espionar",
    "espionando": "espionar",
    "espionara": "espionar",
    "espionaram": "espionar",
    "espionaras": "espionar",
    "espionarde": "espionar",
    "espionardes": "espionar",
    "espionare": "espionar",
    "espionarei": "espionar",
    "espionareis": "espionar",
    "espionarem": "espionar",
    "espionaremos": "espionar",
    "espionares": "espionar",
    "espionaria": "espionar",
    "espionariam": "espionar",
    "espionarias": "espionar",
    "espionarmo": "espionar",
    "espionarmos": "espionar",
    "espionará": "espionar",
    "espionarás": "espionar",
    "espionarão": "espionar",
    "espionaríamos": "espionar",
    "espionaríeis": "espionar",
    "espionas": "espionar",
    "espionasse": "espionar",
    "espionassem": "espionar",
    "espionasses": "espionar",
    "espionaste": "espionar",
    "espionastes": "espionar",
    "espionava": "espionar",
    "espionavam": "espionar",
    "espionavas": "espionar",
    "espione": "espionar",
    "espionei": "espionar",
    "espioneis": "espionar",
    "espionem": "espionar",
    "espionemo": "espionar",
    "espionemos": "espionar",
    "espiones": "espionar",
    "espiono": "espionar",
    "espionou": "espionar",
    "espioná": "espionar",
    "espionámo": "espionar",
    "espionámos": "espionar",
    "espionáramo": "espionar",
    "espionáramos": "espionar",
    "espionárei": "espionar",
    "espionáreis": "espionar",
    "espionásseis": "espionar",
    "espionássemos": "espionar",
    "espionávamo": "espionar",
    "espionávamos": "espionar",
    "espionávei": "espionar",
    "espionáveis": "espionar",
    "espiou": "espiar",
    "espipa": "espipar",
    "espipada": "espipar",
    "espipadas": "espipar",
    "espipado": "espipar",
    "espipados": "espipar",
    "espipai": "espipar",
    "espipais": "espipar",
    "espipam": "espipar",
    "espipamo": "espipar",
    "espipamos": "espipar",
    "espipando": "espipar",
    "espipara": "espipar",
    "espiparam": "espipar",
    "espiparas": "espipar",
    "espiparde": "espipar",
    "espipardes": "espipar",
    "espipare": "espipar",
    "espiparei": "espipar",
    "espipareis": "espipar",
    "espiparem": "espipar",
    "espiparemos": "espipar",
    "espipares": "espipar",
    "espiparia": "espipar",
    "espipariam": "espipar",
    "espiparias": "espipar",
    "espiparmo": "espipar",
    "espiparmos": "espipar",
    "espipará": "espipar",
    "espiparás": "espipar",
    "espiparão": "espipar",
    "espiparíamos": "espipar",
    "espiparíeis": "espipar",
    "espipas": "espipar",
    "espipasse": "espipar",
    "espipassem": "espipar",
    "espipasses": "espipar",
    "espipaste": "espipar",
    "espipastes": "espipar",
    "espipava": "espipar",
    "espipavam": "espipar",
    "espipavas": "espipar",
    "espipe": "espipar",
    "espipei": "espipar",
    "espipeis": "espipar",
    "espipem": "espipar",
    "espipemo": "espipar",
    "espipemos": "espipar",
    "espipes": "espipar",
    "espipo": "espipar",
    "espipou": "espipar",
    "espipá": "espipar",
    "espipámo": "espipar",
    "espipámos": "espipar",
    "espipáramo": "espipar",
    "espipáramos": "espipar",
    "espipárei": "espipar",
    "espipáreis": "espipar",
    "espipásseis": "espipar",
    "espipássemos": "espipar",
    "espipávamo": "espipar",
    "espipávamos": "espipar",
    "espipávei": "espipar",
    "espipáveis": "espipar",
    "espiqueada": "espiqueado",
    "espiqueadas": "espiqueado",
    "espiqueados": "espiqueado",
    "espiques": "espique",
    "espira": "espirar",
    "espirada": "espirar",
    "espiradas": "espirar",
    "espirado": "espirar",
    "espirados": "espirar",
    "espirai": "espirar",
    "espirais": "espirar",
    "espirala": "espiralar",
    "espiralada": "espiralar",
    "espiraladas": "espiralar",
    "espiralado": "espiralar",
    "espiralados": "espiralar",
    "espiralai": "espiralar",
    "espiralais": "espiralar",
    "espiralam": "espiralar",
    "espiralamo": "espiralar",
    "espiralamos": "espiralar",
    "espiralando": "espiralar",
    "espiralara": "espiralar",
    "espiralaram": "espiralar",
    "espiralaras": "espiralar",
    "espiralarde": "espiralar",
    "espiralardes": "espiralar",
    "espiralare": "espiralar",
    "espiralarei": "espiralar",
    "espiralareis": "espiralar",
    "espiralarem": "espiralar",
    "espiralaremos": "espiralar",
    "espiralares": "espiralar",
    "espiralaria": "espiralar",
    "espiralariam": "espiralar",
    "espiralarias": "espiralar",
    "espiralarmo": "espiralar",
    "espiralarmos": "espiralar",
    "espiralará": "espiralar",
    "espiralarás": "espiralar",
    "espiralarão": "espiralar",
    "espiralaríamos": "espiralar",
    "espiralaríeis": "espiralar",
    "espiralas": "espiralar",
    "espiralasse": "espiralar",
    "espiralassem": "espiralar",
    "espiralasses": "espiralar",
    "espiralaste": "espiralar",
    "espiralastes": "espiralar",
    "espiralava": "espiralar",
    "espiralavam": "espiralar",
    "espiralavas": "espiralar",
    "espirale": "espiralar",
    "espiralei": "espiralar",
    "espiraleis": "espiralar",
    "espiralem": "espiralar",
    "espiralemo": "espiralar",
    "espiralemos": "espiralar",
    "espirales": "espiralar",
    "espiralo": "espiralar",
    "espiralou": "espiralar",
    "espiralá": "espiralar",
    "espiralámo": "espiralar",
    "espiralámos": "espiralar",
    "espiraláramo": "espiralar",
    "espiraláramos": "espiralar",
    "espiralárei": "espiralar",
    "espiraláreis": "espiralar",
    "espiralásseis": "espiralar",
    "espiralássemos": "espiralar",
    "espiralávamo": "espiralar",
    "espiralávamos": "espiralar",
    "espiralávei": "espiralar",
    "espiraláveis": "espiralar",
    "espiram": "espirar",
    "espiramo": "espirar",
    "espiramos": "espirar",
    "espirando": "espirar",
    "espirantes": "espirante",
    "espirara": "espirar",
    "espiraram": "espirar",
    "espiraras": "espirar",
    "espirardes": "espirar",
    "espirarei": "espirar",
    "espirareis": "espirar",
    "espirarem": "espirar",
    "espiraremos": "espirar",
    "espirares": "espirar",
    "espiraria": "espirar",
    "espirariam": "espirar",
    "espirarias": "espirar",
    "espirarmo": "espirar",
    "espirarmos": "espirar",
    "espirará": "espirar",
    "espirarás": "espirar",
    "espirarão": "espirar",
    "espiraríamos": "espirar",
    "espiraríeis": "espirar",
    "espiras": "espirar",
    "espirasse": "espirar",
    "espirassem": "espirar",
    "espirasses": "espirar",
    "espiraste": "espirar",
    "espirastes": "espirar",
    "espirava": "espirar",
    "espiravam": "espirar",
    "espiravas": "espirar",
    "espirações": "espiração",
    "espire": "espirar",
    "espirei": "espirar",
    "espireis": "espirar",
    "espirem": "espirar",
    "espiremas": "espirema",
    "espiremo": "espirar",
    "espiremos": "espirar",
    "espires": "espirar",
    "espirita": "espiritar",
    "espiritada": "espiritar",
    "espiritadas": "espiritar",
    "espiritado": "espiritar",
    "espiritados": "espiritar",
    "espiritai": "espiritar",
    "espiritais": "espiritar",
    "espiritam": "espiritar",
    "espiritamo": "espiritar",
    "espiritamos": "espiritar",
    "espiritando": "espiritar",
    "espiritara": "espiritar",
    "espiritaram": "espiritar",
    "espiritaras": "espiritar",
    "espiritarde": "espiritar",
    "espiritardes": "espiritar",
    "espiritare": "espiritar",
    "espiritarei": "espiritar",
    "espiritareis": "espiritar",
    "espiritarem": "espiritar",
    "espiritaremos": "espiritar",
    "espiritares": "espiritar",
    "espiritaria": "espiritar",
    "espiritariam": "espiritar",
    "espiritarias": "espiritar",
    "espiritarmo": "espiritar",
    "espiritarmos": "espiritar",
    "espiritará": "espiritar",
    "espiritarás": "espiritar",
    "espiritarão": "espiritar",
    "espiritaríamos": "espiritar",
    "espiritaríeis": "espiritar",
    "espiritas": "espiritar",
    "espiritasse": "espiritar",
    "espiritassem": "espiritar",
    "espiritasses": "espiritar",
    "espiritaste": "espiritar",
    "espiritastes": "espiritar",
    "espiritava": "espiritar",
    "espiritavam": "espiritar",
    "espiritavas": "espiritar",
    "espirite": "espiritar",
    "espiritei": "espiritar",
    "espiriteis": "espiritar",
    "espiritem": "espiritar",
    "espiritemo": "espiritar",
    "espiritemos": "espiritar",
    "espirites": "espiritar",
    "espiritismos": "espiritismo",
    "espiritistas": "espiritista",
    "espiritiza": "espiritizar",
    "espiritizada": "espiritizar",
    "espiritizadas": "espiritizar",
    "espiritizado": "espiritizar",
    "espiritizados": "espiritizar",
    "espiritizai": "espiritizar",
    "espiritizais": "espiritizar",
    "espiritizam": "espiritizar",
    "espiritizamo": "espiritizar",
    "espiritizamos": "espiritizar",
    "espiritizando": "espiritizar",
    "espiritizara": "espiritizar",
    "espiritizaram": "espiritizar",
    "espiritizaras": "espiritizar",
    "espiritizarde": "espiritizar",
    "espiritizardes": "espiritizar",
    "espiritizare": "espiritizar",
    "espiritizarei": "espiritizar",
    "espiritizareis": "espiritizar",
    "espiritizarem": "espiritizar",
    "espiritizaremos": "espiritizar",
    "espiritizares": "espiritizar",
    "espiritizaria": "espiritizar",
    "espiritizariam": "espiritizar",
    "espiritizarias": "espiritizar",
    "espiritizarmo": "espiritizar",
    "espiritizarmos": "espiritizar",
    "espiritizará": "espiritizar",
    "espiritizarás": "espiritizar",
    "espiritizarão": "espiritizar",
    "espiritizaríamos": "espiritizar",
    "espiritizaríeis": "espiritizar",
    "espiritizas": "espiritizar",
    "espiritizasse": "espiritizar",
    "espiritizassem": "espiritizar",
    "espiritizasses": "espiritizar",
    "espiritizaste": "espiritizar",
    "espiritizastes": "espiritizar",
    "espiritizava": "espiritizar",
    "espiritizavam": "espiritizar",
    "espiritizavas": "espiritizar",
    "espiritize": "espiritizar",
    "espiritizei": "espiritizar",
    "espiritizeis": "espiritizar",
    "espiritizem": "espiritizar",
    "espiritizemo": "espiritizar",
    "espiritizemos": "espiritizar",
    "espiritizes": "espiritizar",
    "espiritizo": "espiritizar",
    "espiritizou": "espiritizar",
    "espiritizá": "espiritizar",
    "espiritizámo": "espiritizar",
    "espiritizámos": "espiritizar",
    "espiritizáramo": "espiritizar",
    "espiritizáramos": "espiritizar",
    "espiritizárei": "espiritizar",
    "espiritizáreis": "espiritizar",
    "espiritizásseis": "espiritizar",
    "espiritizássemos": "espiritizar",
    "espiritizávamo": "espiritizar",
    "espiritizávamos": "espiritizar",
    "espiritizávei": "espiritizar",
    "espiritizáveis": "espiritizar",
    "espirito": "espiritar",
    "espiritou": "espiritar",
    "espirituais": "espiritual",
    "espiritualeira": "espiritualeiro",
    "espiritualeiras": "espiritualeiro",
    "espiritualeiros": "espiritualeiro",
    "espiritualidades": "espiritualidade",
    "espiritualismos": "espiritualismo",
    "espiritualistas": "espiritualista",
    "espiritualiza": "espiritualizar",
    "espiritualizada": "espiritualizar",
    "espiritualizadas": "espiritualizar",
    "espiritualizado": "espiritualizar",
    "espiritualizados": "espiritualizar",
    "espiritualizai": "espiritualizar",
    "espiritualizais": "espiritualizar",
    "espiritualizam": "espiritualizar",
    "espiritualizamo": "espiritualizar",
    "espiritualizamos": "espiritualizar",
    "espiritualizando": "espiritualizar",
    "espiritualizara": "espiritualizar",
    "espiritualizaram": "espiritualizar",
    "espiritualizaras": "espiritualizar",
    "espiritualizarde": "espiritualizar",
    "espiritualizardes": "espiritualizar",
    "espiritualizare": "espiritualizar",
    "espiritualizarei": "espiritualizar",
    "espiritualizareis": "espiritualizar",
    "espiritualizarem": "espiritualizar",
    "espiritualizaremos": "espiritualizar",
    "espiritualizares": "espiritualizar",
    "espiritualizaria": "espiritualizar",
    "espiritualizariam": "espiritualizar",
    "espiritualizarias": "espiritualizar",
    "espiritualizarmo": "espiritualizar",
    "espiritualizarmos": "espiritualizar",
    "espiritualizará": "espiritualizar",
    "espiritualizarás": "espiritualizar",
    "espiritualizarão": "espiritualizar",
    "espiritualizaríamos": "espiritualizar",
    "espiritualizaríeis": "espiritualizar",
    "espiritualizas": "espiritualizar",
    "espiritualizasse": "espiritualizar",
    "espiritualizassem": "espiritualizar",
    "espiritualizasses": "espiritualizar",
    "espiritualizaste": "espiritualizar",
    "espiritualizastes": "espiritualizar",
    "espiritualizava": "espiritualizar",
    "espiritualizavam": "espiritualizar",
    "espiritualizavas": "espiritualizar",
    "espiritualizações": "espiritualização",
    "espiritualize": "espiritualizar",
    "espiritualizei": "espiritualizar",
    "espiritualizeis": "espiritualizar",
    "espiritualizem": "espiritualizar",
    "espiritualizemo": "espiritualizar",
    "espiritualizemos": "espiritualizar",
    "espiritualizes": "espiritualizar",
    "espiritualizo": "espiritualizar",
    "espiritualizou": "espiritualizar",
    "espiritualizá": "espiritualizar",
    "espiritualizámo": "espiritualizar",
    "espiritualizámos": "espiritualizar",
    "espiritualizáramo": "espiritualizar",
    "espiritualizáramos": "espiritualizar",
    "espiritualizárei": "espiritualizar",
    "espiritualizáreis": "espiritualizar",
    "espiritualizásseis": "espiritualizar",
    "espiritualizássemos": "espiritualizar",
    "espiritualizávamo": "espiritualizar",
    "espiritualizávamos": "espiritualizar",
    "espiritualizávei": "espiritualizar",
    "espiritualizáveis": "espiritualizar",
    "espirituosa": "espirituoso",
    "espirituosas": "espirituoso",
    "espirituosidades": "espirituosidade",
    "espirituosos": "espirituoso",
    "espiritá": "espiritar",
    "espiritámo": "espiritar",
    "espiritámos": "espiritar",
    "espiritáramo": "espiritar",
    "espiritáramos": "espiritar",
    "espiritárei": "espiritar",
    "espiritáreis": "espiritar",
    "espiritásseis": "espiritar",
    "espiritássemos": "espiritar",
    "espiritávamo": "espiritar",
    "espiritávamos": "espiritar",
    "espiritávei": "espiritar",
    "espiritáveis": "espiritar",
    "espiro": "espirar",
    "espirogiras": "espirogira",
    "espirométrica": "espirométrico",
    "espirométricas": "espirométrico",
    "espirométricos": "espirométrico",
    "espiroquetas": "espiroqueta",
    "espiroquetoses": "espiroquetose",
    "espiroquética": "espiroquético",
    "espiroquéticas": "espiroquético",
    "espiroquéticos": "espiroquético",
    "espirou": "espirar",
    "espirra": "espirrar",
    "espirrada": "espirrar",
    "espirradas": "espirrar",
    "espirradeiras": "espirradeira",
    "espirrado": "espirrar",
    "espirradora": "espirrador",
    "espirradoras": "espirrador",
    "espirradores": "espirrador",
    "espirrados": "espirrar",
    "espirrai": "espirrar",
    "espirrais": "espirrar",
    "espirram": "espirrar",
    "espirramo": "espirrar",
    "espirramos": "espirrar",
    "espirrando": "espirrar",
    "espirrantes": "espirrante",
    "espirrara": "espirrar",
    "espirraram": "espirrar",
    "espirraras": "espirrar",
    "espirrardes": "espirrar",
    "espirrarei": "espirrar",
    "espirrareis": "espirrar",
    "espirrarem": "espirrar",
    "espirraremos": "espirrar",
    "espirrares": "espirrar",
    "espirraria": "espirrar",
    "espirrariam": "espirrar",
    "espirrarias": "espirrar",
    "espirrarmo": "espirrar",
    "espirrarmos": "espirrar",
    "espirrará": "espirrar",
    "espirrarás": "espirrar",
    "espirrarão": "espirrar",
    "espirraríamos": "espirrar",
    "espirraríeis": "espirrar",
    "espirras": "espirrar",
    "espirrasse": "espirrar",
    "espirrassem": "espirrar",
    "espirrasses": "espirrar",
    "espirraste": "espirrar",
    "espirrastes": "espirrar",
    "espirrava": "espirrar",
    "espirravam": "espirrar",
    "espirravas": "espirrar",
    "espirre": "espirrar",
    "espirrei": "espirrar",
    "espirreis": "espirrar",
    "espirrem": "espirrar",
    "espirremo": "espirrar",
    "espirremos": "espirrar",
    "espirres": "espirrar",
    "espirro": "espirrar",
    "espirros": "espirro",
    "espirrou": "espirrar",
    "espirrámo": "espirrar",
    "espirrámos": "espirrar",
    "espirráramo": "espirrar",
    "espirráramos": "espirrar",
    "espirráreis": "espirrar",
    "espirrásseis": "espirrar",
    "espirrássemos": "espirrar",
    "espirrávamo": "espirrar",
    "espirrávamos": "espirrar",
    "espirráveis": "espirrar",
    "espiráculos": "espiráculo",
    "espirámo": "espirar",
    "espirámos": "espirar",
    "espiráramo": "espirar",
    "espiráramos": "espirar",
    "espiráreis": "espirar",
    "espirásseis": "espirar",
    "espirássemos": "espirar",
    "espirávamo": "espirar",
    "espirávamos": "espirar",
    "espiráveis": "espirar",
    "espiróides": "espiróide",
    "espirómetros": "espirómetro",
    "espiá": "espiar",
    "espiámo": "espiar",
    "espiámos": "espiar",
    "espiáramo": "espiar",
    "espiáramos": "espiar",
    "espiárei": "espiar",
    "espiáreis": "espiar",
    "espiásseis": "espiar",
    "espiássemos": "espiar",
    "espiávamo": "espiar",
    "espiávamos": "espiar",
    "espiávei": "espiar",
    "espiáveis": "espiar",
    "espiã": "espião",
    "espiãs": "espião",
    "espiões": "espião",
    "esplanadas": "esplanada",
    "esplancnografias": "esplancnografia",
    "esplancnográfica": "esplancnográfico",
    "esplancnográficas": "esplancnográfico",
    "esplancnográficos": "esplancnográfico",
    "esplancnologias": "esplancnologia",
    "esplancnológica": "esplancnológico",
    "esplancnológicas": "esplancnológico",
    "esplancnológicos": "esplancnológico",
    "esplancnopleuras": "esplancnopleura",
    "esplancnoplêurica": "esplancnoplêurico",
    "esplancnoplêuricas": "esplancnoplêurico",
    "esplancnoplêuricos": "esplancnoplêurico",
    "esplancnóloga": "esplancnólogo",
    "esplancnólogas": "esplancnólogo",
    "esplancnólogos": "esplancnólogo",
    "esplanconógrafos": "esplanconógrafo",
    "esplenalgias": "esplenalgia",
    "esplenda": "esplender",
    "esplendais": "esplender",
    "esplendam": "esplender",
    "esplendamo": "esplender",
    "esplendamos": "esplender",
    "esplendas": "esplender",
    "esplende": "esplender",
    "esplendece": "esplendecer",
    "esplendecei": "esplendecer",
    "esplendeceis": "esplendecer",
    "esplendecem": "esplendecer",
    "esplendecemo": "esplendecer",
    "esplendecemos": "esplendecer",
    "esplendecendo": "esplendecer",
    "esplendecentes": "esplendecente",
    "esplendecera": "esplendecer",
    "esplendeceram": "esplendecer",
    "esplendeceras": "esplendecer",
    "esplendecerdes": "esplendecer",
    "esplendecerei": "esplendecer",
    "esplendecereis": "esplendecer",
    "esplendecerem": "esplendecer",
    "esplendeceremos": "esplendecer",
    "esplendeceres": "esplendecer",
    "esplendeceria": "esplendecer",
    "esplendeceriam": "esplendecer",
    "esplendecerias": "esplendecer",
    "esplendecermo": "esplendecer",
    "esplendecermos": "esplendecer",
    "esplendecerá": "esplendecer",
    "esplendecerás": "esplendecer",
    "esplendecerão": "esplendecer",
    "esplendeceríamos": "esplendecer",
    "esplendeceríeis": "esplendecer",
    "esplendeces": "esplendecer",
    "esplendecesse": "esplendecer",
    "esplendecessem": "esplendecer",
    "esplendecesses": "esplendecer",
    "esplendeceste": "esplendecer",
    "esplendecestes": "esplendecer",
    "esplendeceu": "esplendecer",
    "esplendeci": "esplendecer",
    "esplendecia": "esplendecer",
    "esplendeciam": "esplendecer",
    "esplendecias": "esplendecer",
    "esplendecida": "esplendecer",
    "esplendecidas": "esplendecer",
    "esplendecido": "esplendecer",
    "esplendecidos": "esplendecer",
    "esplendecências": "esplendecência",
    "esplendecêramo": "esplendecer",
    "esplendecêramos": "esplendecer",
    "esplendecêreis": "esplendecer",
    "esplendecêsseis": "esplendecer",
    "esplendecêssemos": "esplendecer",
    "esplendecíamo": "esplendecer",
    "esplendecíamos": "esplendecer",
    "esplendecíeis": "esplendecer",
    "esplendei": "esplender",
    "esplendeis": "esplender",
    "esplendem": "esplender",
    "esplendemo": "esplender",
    "esplendemos": "esplender",
    "esplendendo": "esplender",
    "esplendentes": "esplendente",
    "esplendera": "esplender",
    "esplenderam": "esplender",
    "esplenderas": "esplender",
    "esplenderdes": "esplender",
    "esplenderei": "esplender",
    "esplendereis": "esplender",
    "esplenderem": "esplender",
    "esplenderemos": "esplender",
    "esplenderes": "esplender",
    "esplenderia": "esplender",
    "esplenderiam": "esplender",
    "esplenderias": "esplender",
    "esplendermo": "esplender",
    "esplendermos": "esplender",
    "esplenderá": "esplender",
    "esplenderás": "esplender",
    "esplenderão": "esplender",
    "esplenderíamos": "esplender",
    "esplenderíeis": "esplender",
    "esplendes": "esplender",
    "esplendesse": "esplender",
    "esplendessem": "esplender",
    "esplendesses": "esplender",
    "esplendeste": "esplender",
    "esplendestes": "esplender",
    "esplendeu": "esplender",
    "esplendeça": "esplendecer",
    "esplendeçais": "esplendecer",
    "esplendeçam": "esplendecer",
    "esplendeçamo": "esplendecer",
    "esplendeçamos": "esplendecer",
    "esplendeças": "esplendecer",
    "esplendeço": "esplendecer",
    "esplendi": "esplender",
    "esplendia": "esplender",
    "esplendiam": "esplender",
    "esplendias": "esplender",
    "esplendida": "esplender",
    "esplendidas": "esplender",
    "esplendidezas": "esplendideza",
    "esplendido": "esplender",
    "esplendidos": "esplender",
    "esplendo": "esplender",
    "esplendores": "esplendor",
    "esplendorosa": "esplendoroso",
    "esplendorosas": "esplendoroso",
    "esplendorosos": "esplendoroso",
    "esplendências": "esplendência",
    "esplendêramo": "esplender",
    "esplendêramos": "esplender",
    "esplendêreis": "esplender",
    "esplendêsseis": "esplender",
    "esplendêssemos": "esplender",
    "esplendíamo": "esplender",
    "esplendíamos": "esplender",
    "esplendíeis": "esplender",
    "esplenectomias": "esplenectomia",
    "esplenectómica": "esplenectómico",
    "esplenectómicas": "esplenectómico",
    "esplenectómicos": "esplenectómico",
    "esplenites": "esplenite",
    "esplenoceles": "esplenocele",
    "esplenocélica": "esplenocélico",
    "esplenocélicas": "esplenocélico",
    "esplenocélicos": "esplenocélico",
    "esplenomegalias": "esplenomegalia",
    "esplenomegálica": "esplenomegálico",
    "esplenomegálicas": "esplenomegálico",
    "esplenomegálicos": "esplenomegálico",
    "esplenopatas": "esplenopata",
    "esplenopatias": "esplenopatia",
    "esplenopática": "esplenopático",
    "esplenopáticas": "esplenopático",
    "esplenopáticos": "esplenopático",
    "esplenotomias": "esplenotomia",
    "esplenotópica": "esplenotópico",
    "esplenotópicas": "esplenotópico",
    "esplenotópicos": "esplenotópico",
    "esplenálgica": "esplenálgico",
    "esplenálgicas": "esplenálgico",
    "esplenálgicos": "esplenálgico",
    "esplenética": "esplenético",
    "esplenéticas": "esplenético",
    "esplenéticos": "esplenético",
    "esplenítica": "esplenítico",
    "espleníticas": "esplenítico",
    "espleníticos": "esplenítico",
    "esplenôncias": "esplenôncia",
    "esplenôncica": "esplenôncico",
    "esplenôncicas": "esplenôncico",
    "esplenôncicos": "esplenôncico",
    "esplinhadoiros": "esplinhadoiro",
    "esplinhadouros": "esplinhadouro",
    "esplénica": "esplénico",
    "esplénicas": "esplénico",
    "esplénicos": "esplénico",
    "esplénios": "esplénio",
    "esplêndida": "esplêndido",
    "esplêndidas": "esplêndido",
    "esplêndidos": "esplêndido",
    "espoa": "espoar",
    "espoada": "espoar",
    "espoadas": "espoar",
    "espoado": "espoar",
    "espoadores": "espoador",
    "espoados": "espoar",
    "espoai": "espoar",
    "espoais": "espoar",
    "espoam": "espoar",
    "espoamo": "espoar",
    "espoamos": "espoar",
    "espoando": "espoar",
    "espoara": "espoar",
    "espoaram": "espoar",
    "espoaras": "espoar",
    "espoarde": "espoar",
    "espoardes": "espoar",
    "espoare": "espoar",
    "espoarei": "espoar",
    "espoareis": "espoar",
    "espoarem": "espoar",
    "espoaremos": "espoar",
    "espoares": "espoar",
    "espoaria": "espoar",
    "espoariam": "espoar",
    "espoarias": "espoar",
    "espoarmo": "espoar",
    "espoarmos": "espoar",
    "espoará": "espoar",
    "espoarás": "espoar",
    "espoarão": "espoar",
    "espoaríamos": "espoar",
    "espoaríeis": "espoar",
    "espoas": "espoar",
    "espoasse": "espoar",
    "espoassem": "espoar",
    "espoasses": "espoar",
    "espoaste": "espoar",
    "espoastes": "espoar",
    "espoava": "espoar",
    "espoavam": "espoar",
    "espoavas": "espoar",
    "espodites": "espodite",
    "espodumenas": "espodumena",
    "espoe": "espoar",
    "espoei": "espoar",
    "espoeis": "espoar",
    "espoem": "espoar",
    "espoemo": "espoar",
    "espoemos": "espoar",
    "espoes": "espoar",
    "espofilos": "espofilo",
    "espoja": "espojar",
    "espojada": "espojar",
    "espojadas": "espojar",
    "espojado": "espojar",
    "espojadoiros": "espojadoiro",
    "espojados": "espojar",
    "espojadouros": "espojadouro",
    "espojaduras": "espojadura",
    "espojai": "espojar",
    "espojais": "espojar",
    "espojam": "espojar",
    "espojamo": "espojar",
    "espojamos": "espojar",
    "espojando": "espojar",
    "espojara": "espojar",
    "espojaram": "espojar",
    "espojaras": "espojar",
    "espojarde": "espojar",
    "espojardes": "espojar",
    "espojare": "espojar",
    "espojarei": "espojar",
    "espojareis": "espojar",
    "espojarem": "espojar",
    "espojaremos": "espojar",
    "espojares": "espojar",
    "espojaria": "espojar",
    "espojariam": "espojar",
    "espojarias": "espojar",
    "espojarmo": "espojar",
    "espojarmos": "espojar",
    "espojará": "espojar",
    "espojarás": "espojar",
    "espojarão": "espojar",
    "espojaríamos": "espojar",
    "espojaríeis": "espojar",
    "espojas": "espojar",
    "espojasse": "espojar",
    "espojassem": "espojar",
    "espojasses": "espojar",
    "espojaste": "espojar",
    "espojastes": "espojar",
    "espojava": "espojar",
    "espojavam": "espojar",
    "espojavas": "espojar",
    "espoje": "espojar",
    "espojei": "espojar",
    "espojeiros": "espojeiro",
    "espojeis": "espojar",
    "espojem": "espojar",
    "espojemo": "espojar",
    "espojemos": "espojar",
    "espojes": "espojar",
    "espojinhos": "espojinho",
    "espojo": "espojar",
    "espojos": "espojo",
    "espojou": "espojar",
    "espojá": "espojar",
    "espojámo": "espojar",
    "espojámos": "espojar",
    "espojáramo": "espojar",
    "espojáramos": "espojar",
    "espojárei": "espojar",
    "espojáreis": "espojar",
    "espojásseis": "espojar",
    "espojássemos": "espojar",
    "espojávamo": "espojar",
    "espojávamos": "espojar",
    "espojávei": "espojar",
    "espojáveis": "espojar",
    "espoldra": "espoldrar",
    "espoldrada": "espoldrar",
    "espoldradas": "espoldrar",
    "espoldrado": "espoldrar",
    "espoldradora": "espoldrador",
    "espoldradoras": "espoldrador",
    "espoldradores": "espoldrador",
    "espoldrados": "espoldrar",
    "espoldrai": "espoldrar",
    "espoldrais": "espoldrar",
    "espoldram": "espoldrar",
    "espoldramo": "espoldrar",
    "espoldramos": "espoldrar",
    "espoldrando": "espoldrar",
    "espoldrara": "espoldrar",
    "espoldraram": "espoldrar",
    "espoldraras": "espoldrar",
    "espoldrarde": "espoldrar",
    "espoldrardes": "espoldrar",
    "espoldrare": "espoldrar",
    "espoldrarei": "espoldrar",
    "espoldrareis": "espoldrar",
    "espoldrarem": "espoldrar",
    "espoldraremos": "espoldrar",
    "espoldrares": "espoldrar",
    "espoldraria": "espoldrar",
    "espoldrariam": "espoldrar",
    "espoldrarias": "espoldrar",
    "espoldrarmo": "espoldrar",
    "espoldrarmos": "espoldrar",
    "espoldrará": "espoldrar",
    "espoldrarás": "espoldrar",
    "espoldrarão": "espoldrar",
    "espoldraríamos": "espoldrar",
    "espoldraríeis": "espoldrar",
    "espoldras": "espoldrar",
    "espoldrasse": "espoldrar",
    "espoldrassem": "espoldrar",
    "espoldrasses": "espoldrar",
    "espoldraste": "espoldrar",
    "espoldrastes": "espoldrar",
    "espoldrava": "espoldrar",
    "espoldravam": "espoldrar",
    "espoldravas": "espoldrar",
    "espoldre": "espoldrar",
    "espoldrei": "espoldrar",
    "espoldreis": "espoldrar",
    "espoldrem": "espoldrar",
    "espoldremo": "espoldrar",
    "espoldremos": "espoldrar",
    "espoldres": "espoldrar",
    "espoldro": "espoldrar",
    "espoldrou": "espoldrar",
    "espoldrá": "espoldrar",
    "espoldrámo": "espoldrar",
    "espoldrámos": "espoldrar",
    "espoldráramo": "espoldrar",
    "espoldráramos": "espoldrar",
    "espoldrárei": "espoldrar",
    "espoldráreis": "espoldrar",
    "espoldrásseis": "espoldrar",
    "espoldrássemos": "espoldrar",
    "espoldrávamo": "espoldrar",
    "espoldrávamos": "espoldrar",
    "espoldrávei": "espoldrar",
    "espoldráveis": "espoldrar",
    "espoleta": "espoletar",
    "espoletada": "espoletar",
    "espoletadas": "espoletar",
    "espoletado": "espoletar",
    "espoletados": "espoletar",
    "espoletai": "espoletar",
    "espoletais": "espoletar",
    "espoletam": "espoletar",
    "espoletamo": "espoletar",
    "espoletamos": "espoletar",
    "espoletando": "espoletar",
    "espoletara": "espoletar",
    "espoletaram": "espoletar",
    "espoletaras": "espoletar",
    "espoletarde": "espoletar",
    "espoletardes": "espoletar",
    "espoletare": "espoletar",
    "espoletarei": "espoletar",
    "espoletareis": "espoletar",
    "espoletarem": "espoletar",
    "espoletaremos": "espoletar",
    "espoletares": "espoletar",
    "espoletaria": "espoletar",
    "espoletariam": "espoletar",
    "espoletarias": "espoletar",
    "espoletarmo": "espoletar",
    "espoletarmos": "espoletar",
    "espoletará": "espoletar",
    "espoletarás": "espoletar",
    "espoletarão": "espoletar",
    "espoletaríamos": "espoletar",
    "espoletaríeis": "espoletar",
    "espoletas": "espoletar",
    "espoletasse": "espoletar",
    "espoletassem": "espoletar",
    "espoletasses": "espoletar",
    "espoletaste": "espoletar",
    "espoletastes": "espoletar",
    "espoletava": "espoletar",
    "espoletavam": "espoletar",
    "espoletavas": "espoletar",
    "espolete": "espoletar",
    "espoletei": "espoletar",
    "espoleteis": "espoletar",
    "espoletem": "espoletar",
    "espoletemo": "espoletar",
    "espoletemos": "espoletar",
    "espoletes": "espoletar",
    "espoleto": "espoletar",
    "espoletou": "espoletar",
    "espoletá": "espoletar",
    "espoletámo": "espoletar",
    "espoletámos": "espoletar",
    "espoletáramo": "espoletar",
    "espoletáramos": "espoletar",
    "espoletárei": "espoletar",
    "espoletáreis": "espoletar",
    "espoletásseis": "espoletar",
    "espoletássemos": "espoletar",
    "espoletávamo": "espoletar",
    "espoletávamos": "espoletar",
    "espoletávei": "espoletar",
    "espoletáveis": "espoletar",
    "espolia": "espoliar",
    "espoliada": "espoliar",
    "espoliadas": "espoliar",
    "espoliado": "espoliar",
    "espoliadora": "espoliador",
    "espoliadoras": "espoliador",
    "espoliadores": "espoliador",
    "espoliados": "espoliar",
    "espoliai": "espoliar",
    "espoliais": "espoliar",
    "espoliam": "espoliar",
    "espoliamo": "espoliar",
    "espoliamos": "espoliar",
    "espoliando": "espoliar",
    "espoliantes": "espoliante",
    "espoliara": "espoliar",
    "espoliaram": "espoliar",
    "espoliaras": "espoliar",
    "espoliarde": "espoliar",
    "espoliardes": "espoliar",
    "espoliare": "espoliar",
    "espoliarei": "espoliar",
    "espoliareis": "espoliar",
    "espoliarem": "espoliar",
    "espoliaremos": "espoliar",
    "espoliares": "espoliar",
    "espoliaria": "espoliar",
    "espoliariam": "espoliar",
    "espoliarias": "espoliar",
    "espoliarmo": "espoliar",
    "espoliarmos": "espoliar",
    "espoliará": "espoliar",
    "espoliarás": "espoliar",
    "espoliarão": "espoliar",
    "espoliaríamos": "espoliar",
    "espoliaríeis": "espoliar",
    "espolias": "espoliar",
    "espoliasse": "espoliar",
    "espoliassem": "espoliar",
    "espoliasses": "espoliar",
    "espoliaste": "espoliar",
    "espoliastes": "espoliar",
    "espoliativa": "espoliativo",
    "espoliativas": "espoliativo",
    "espoliativos": "espoliativo",
    "espoliava": "espoliar",
    "espoliavam": "espoliar",
    "espoliavas": "espoliar",
    "espoliações": "espoliação",
    "espolie": "espoliar",
    "espoliei": "espoliar",
    "espolieis": "espoliar",
    "espoliem": "espoliar",
    "espoliemo": "espoliar",
    "espoliemos": "espoliar",
    "espolies": "espoliar",
    "espolina": "espolinar",
    "espolinada": "espolinar",
    "espolinadas": "espolinar",
    "espolinado": "espolinar",
    "espolinados": "espolinar",
    "espolinai": "espolinar",
    "espolinais": "espolinar",
    "espolinam": "espolinar",
    "espolinamo": "espolinar",
    "espolinamos": "espolinar",
    "espolinando": "espolinar",
    "espolinara": "espolinar",
    "espolinaram": "espolinar",
    "espolinaras": "espolinar",
    "espolinarde": "espolinar",
    "espolinardes": "espolinar",
    "espolinare": "espolinar",
    "espolinarei": "espolinar",
    "espolinareis": "espolinar",
    "espolinarem": "espolinar",
    "espolinaremos": "espolinar",
    "espolinares": "espolinar",
    "espolinaria": "espolinar",
    "espolinariam": "espolinar",
    "espolinarias": "espolinar",
    "espolinarmo": "espolinar",
    "espolinarmos": "espolinar",
    "espolinará": "espolinar",
    "espolinarás": "espolinar",
    "espolinarão": "espolinar",
    "espolinaríamos": "espolinar",
    "espolinaríeis": "espolinar",
    "espolinas": "espolinar",
    "espolinasse": "espolinar",
    "espolinassem": "espolinar",
    "espolinasses": "espolinar",
    "espolinaste": "espolinar",
    "espolinastes": "espolinar",
    "espolinava": "espolinar",
    "espolinavam": "espolinar",
    "espolinavas": "espolinar",
    "espoline": "espolinar",
    "espolinei": "espolinar",
    "espolineis": "espolinar",
    "espolinem": "espolinar",
    "espolinemo": "espolinar",
    "espolinemos": "espolinar",
    "espolines": "espolinar",
    "espolinha": "espolinhar",
    "espolinhada": "espolinhar",
    "espolinhadas": "espolinhar",
    "espolinhado": "espolinhar",
    "espolinhados": "espolinhar",
    "espolinhai": "espolinhar",
    "espolinhais": "espolinhar",
    "espolinham": "espolinhar",
    "espolinhamo": "espolinhar",
    "espolinhamos": "espolinhar",
    "espolinhando": "espolinhar",
    "espolinhara": "espolinhar",
    "espolinharam": "espolinhar",
    "espolinharas": "espolinhar",
    "espolinharde": "espolinhar",
    "espolinhardes": "espolinhar",
    "espolinhare": "espolinhar",
    "espolinharei": "espolinhar",
    "espolinhareis": "espolinhar",
    "espolinharem": "espolinhar",
    "espolinharemos": "espolinhar",
    "espolinhares": "espolinhar",
    "espolinharia": "espolinhar",
    "espolinhariam": "espolinhar",
    "espolinharias": "espolinhar",
    "espolinharmo": "espolinhar",
    "espolinharmos": "espolinhar",
    "espolinhará": "espolinhar",
    "espolinharás": "espolinhar",
    "espolinharão": "espolinhar",
    "espolinharíamos": "espolinhar",
    "espolinharíeis": "espolinhar",
    "espolinhas": "espolinhar",
    "espolinhasse": "espolinhar",
    "espolinhassem": "espolinhar",
    "espolinhasses": "espolinhar",
    "espolinhaste": "espolinhar",
    "espolinhastes": "espolinhar",
    "espolinhava": "espolinhar",
    "espolinhavam": "espolinhar",
    "espolinhavas": "espolinhar",
    "espolinhe": "espolinhar",
    "espolinhei": "espolinhar",
    "espolinheis": "espolinhar",
    "espolinhem": "espolinhar",
    "espolinhemo": "espolinhar",
    "espolinhemos": "espolinhar",
    "espolinhes": "espolinhar",
    "espolinho": "espolinhar",
    "espolinhou": "espolinhar",
    "espolinhá": "espolinhar",
    "espolinhámo": "espolinhar",
    "espolinhámos": "espolinhar",
    "espolinháramo": "espolinhar",
    "espolinháramos": "espolinhar",
    "espolinhárei": "espolinhar",
    "espolinháreis": "espolinhar",
    "espolinhásseis": "espolinhar",
    "espolinhássemos": "espolinhar",
    "espolinhávamo": "espolinhar",
    "espolinhávamos": "espolinhar",
    "espolinhávei": "espolinhar",
    "espolinháveis": "espolinhar",
    "espolino": "espolinar",
    "espolinou": "espolinar",
    "espolins": "espolim",
    "espoliná": "espolinar",
    "espolinámo": "espolinar",
    "espolinámos": "espolinar",
    "espolináramo": "espolinar",
    "espolináramos": "espolinar",
    "espolinárei": "espolinar",
    "espolináreis": "espolinar",
    "espolinásseis": "espolinar",
    "espolinássemos": "espolinar",
    "espolinávamo": "espolinar",
    "espolinávamos": "espolinar",
    "espolinávei": "espolinar",
    "espolináveis": "espolinar",
    "espolio": "espoliar",
    "espoliou": "espoliar",
    "espoliá": "espoliar",
    "espoliámo": "espoliar",
    "espoliámos": "espoliar",
    "espoliáramo": "espoliar",
    "espoliáramos": "espoliar",
    "espoliárei": "espoliar",
    "espoliáreis": "espoliar",
    "espoliária": "espoliário",
    "espoliárias": "espoliário",
    "espoliários": "espoliário",
    "espoliásseis": "espoliar",
    "espoliássemos": "espoliar",
    "espoliávamo": "espoliar",
    "espoliávamos": "espoliar",
    "espoliávei": "espoliar",
    "espoliáveis": "espoliável",
    "espolpa": "espolpar",
    "espolpada": "espolpar",
    "espolpadas": "espolpar",
    "espolpado": "espolpar",
    "espolpados": "espolpar",
    "espolpai": "espolpar",
    "espolpais": "espolpar",
    "espolpam": "espolpar",
    "espolpamo": "espolpar",
    "espolpamos": "espolpar",
    "espolpando": "espolpar",
    "espolpara": "espolpar",
    "espolparam": "espolpar",
    "espolparas": "espolpar",
    "espolparde": "espolpar",
    "espolpardes": "espolpar",
    "espolpare": "espolpar",
    "espolparei": "espolpar",
    "espolpareis": "espolpar",
    "espolparem": "espolpar",
    "espolparemos": "espolpar",
    "espolpares": "espolpar",
    "espolparia": "espolpar",
    "espolpariam": "espolpar",
    "espolparias": "espolpar",
    "espolparmo": "espolpar",
    "espolparmos": "espolpar",
    "espolpará": "espolpar",
    "espolparás": "espolpar",
    "espolparão": "espolpar",
    "espolparíamos": "espolpar",
    "espolparíeis": "espolpar",
    "espolpas": "espolpar",
    "espolpasse": "espolpar",
    "espolpassem": "espolpar",
    "espolpasses": "espolpar",
    "espolpaste": "espolpar",
    "espolpastes": "espolpar",
    "espolpava": "espolpar",
    "espolpavam": "espolpar",
    "espolpavas": "espolpar",
    "espolpe": "espolpar",
    "espolpei": "espolpar",
    "espolpeis": "espolpar",
    "espolpem": "espolpar",
    "espolpemo": "espolpar",
    "espolpemos": "espolpar",
    "espolpes": "espolpar",
    "espolpo": "espolpar",
    "espolpou": "espolpar",
    "espolpá": "espolpar",
    "espolpámo": "espolpar",
    "espolpámos": "espolpar",
    "espolpáramo": "espolpar",
    "espolpáramos": "espolpar",
    "espolpárei": "espolpar",
    "espolpáreis": "espolpar",
    "espolpásseis": "espolpar",
    "espolpássemos": "espolpar",
    "espolpávamo": "espolpar",
    "espolpávamos": "espolpar",
    "espolpávei": "espolpar",
    "espolpáveis": "espolpar",
    "espondaica": "espondaico",
    "espondaicas": "espondaico",
    "espondaicos": "espondaico",
    "espondeia": "espondeu",
    "espondeias": "espondeu",
    "espondeus": "espondeu",
    "espondilites": "espondilite",
    "espondiloses": "espondilose",
    "espondilítica": "espondilítico",
    "espondilíticas": "espondilítico",
    "espondilíticos": "espondilítico",
    "espondílica": "espondílico",
    "espondílicas": "espondílico",
    "espondílicos": "espondílico",
    "esponedilótica": "esponedilótico",
    "esponedilóticas": "esponedilótico",
    "esponedilóticos": "esponedilótico",
    "espongiformes": "espongiforme",
    "espongilídeos": "espongilídeo",
    "espongiária": "espongiário",
    "espongiárias": "espongiário",
    "espongiários": "espongiário",
    "espongíolos": "espongíolo",
    "esponja": "esponjar",
    "esponjada": "esponjar",
    "esponjadas": "esponjar",
    "esponjado": "esponjar",
    "esponjados": "esponjar",
    "esponjai": "esponjar",
    "esponjais": "esponjar",
    "esponjam": "esponjar",
    "esponjamo": "esponjar",
    "esponjamos": "esponjar",
    "esponjando": "esponjar",
    "esponjara": "esponjar",
    "esponjaram": "esponjar",
    "esponjaras": "esponjar",
    "esponjarde": "esponjar",
    "esponjardes": "esponjar",
    "esponjare": "esponjar",
    "esponjarei": "esponjar",
    "esponjareis": "esponjar",
    "esponjarem": "esponjar",
    "esponjaremos": "esponjar",
    "esponjares": "esponjar",
    "esponjaria": "esponjar",
    "esponjariam": "esponjar",
    "esponjarias": "esponjar",
    "esponjarmo": "esponjar",
    "esponjarmos": "esponjar",
    "esponjará": "esponjar",
    "esponjarás": "esponjar",
    "esponjarão": "esponjar",
    "esponjaríamos": "esponjar",
    "esponjaríeis": "esponjar",
    "esponjas": "esponjar",
    "esponjasse": "esponjar",
    "esponjassem": "esponjar",
    "esponjasses": "esponjar",
    "esponjaste": "esponjar",
    "esponjastes": "esponjar",
    "esponjava": "esponjar",
    "esponjavam": "esponjar",
    "esponjavas": "esponjar",
    "esponje": "esponjar",
    "esponjei": "esponjar",
    "esponjeiras": "esponjeira",
    "esponjeis": "esponjar",
    "esponjem": "esponjar",
    "esponjemo": "esponjar",
    "esponjemos": "esponjar",
    "esponjes": "esponjar",
    "esponjinha": "esponja",
    "esponjinhas": "esponja",
    "esponjita": "esponja",
    "esponjitas": "esponja",
    "esponjo": "esponjar",
    "esponjosa": "esponjoso",
    "esponjosas": "esponjoso",
    "esponjosidades": "esponjosidade",
    "esponjosos": "esponjoso",
    "esponjou": "esponjar",
    "esponjá": "esponjar",
    "esponjámo": "esponjar",
    "esponjámos": "esponjar",
    "esponjáramo": "esponjar",
    "esponjáramos": "esponjar",
    "esponjárei": "esponjar",
    "esponjáreis": "esponjar",
    "esponjásseis": "esponjar",
    "esponjássemos": "esponjar",
    "esponjávamo": "esponjar",
    "esponjávamos": "esponjar",
    "esponjávei": "esponjar",
    "esponjáveis": "esponjar",
    "esponsais": "esponsal",
    "esponsalícia": "esponsalício",
    "esponsalícias": "esponsalício",
    "esponsalícios": "esponsalício",
    "esponsória": "esponsório",
    "esponsórias": "esponsório",
    "esponsórios": "esponsório",
    "esponta": "espontar",
    "espontada": "espontar",
    "espontadas": "espontar",
    "espontado": "espontar",
    "espontados": "espontar",
    "espontai": "espontar",
    "espontais": "espontar",
    "espontam": "espontar",
    "espontamo": "espontar",
    "espontamos": "espontar",
    "espontando": "espontar",
    "espontaneidades": "espontaneidade",
    "espontara": "espontar",
    "espontaram": "espontar",
    "espontaras": "espontar",
    "espontarde": "espontar",
    "espontardes": "espontar",
    "espontare": "espontar",
    "espontarei": "espontar",
    "espontareis": "espontar",
    "espontarem": "espontar",
    "espontaremos": "espontar",
    "espontares": "espontar",
    "espontaria": "espontar",
    "espontariam": "espontar",
    "espontarias": "espontar",
    "espontarmo": "espontar",
    "espontarmos": "espontar",
    "espontará": "espontar",
    "espontarás": "espontar",
    "espontarão": "espontar",
    "espontaríamos": "espontar",
    "espontaríeis": "espontar",
    "espontas": "espontar",
    "espontasse": "espontar",
    "espontassem": "espontar",
    "espontasses": "espontar",
    "espontaste": "espontar",
    "espontastes": "espontar",
    "espontava": "espontar",
    "espontavam": "espontar",
    "espontavas": "espontar",
    "esponte": "espontar",
    "espontei": "espontar",
    "esponteira": "esponteirar",
    "esponteirada": "esponteirar",
    "esponteiradas": "esponteirar",
    "esponteirado": "esponteirar",
    "esponteirados": "esponteirar",
    "esponteirai": "esponteirar",
    "esponteirais": "esponteirar",
    "esponteiram": "esponteirar",
    "esponteiramo": "esponteirar",
    "esponteiramos": "esponteirar",
    "esponteirando": "esponteirar",
    "esponteirara": "esponteirar",
    "esponteiraram": "esponteirar",
    "esponteiraras": "esponteirar",
    "esponteirarde": "esponteirar",
    "esponteirardes": "esponteirar",
    "esponteirare": "esponteirar",
    "esponteirarei": "esponteirar",
    "esponteirareis": "esponteirar",
    "esponteirarem": "esponteirar",
    "esponteiraremos": "esponteirar",
    "esponteirares": "esponteirar",
    "esponteiraria": "esponteirar",
    "esponteirariam": "esponteirar",
    "esponteirarias": "esponteirar",
    "esponteirarmo": "esponteirar",
    "esponteirarmos": "esponteirar",
    "esponteirará": "esponteirar",
    "esponteirarás": "esponteirar",
    "esponteirarão": "esponteirar",
    "esponteiraríamos": "esponteirar",
    "esponteiraríeis": "esponteirar",
    "esponteiras": "esponteirar",
    "esponteirasse": "esponteirar",
    "esponteirassem": "esponteirar",
    "esponteirasses": "esponteirar",
    "esponteiraste": "esponteirar",
    "esponteirastes": "esponteirar",
    "esponteirava": "esponteirar",
    "esponteiravam": "esponteirar",
    "esponteiravas": "esponteirar",
    "esponteire": "esponteirar",
    "esponteirei": "esponteirar",
    "esponteireis": "esponteirar",
    "esponteirem": "esponteirar",
    "esponteiremo": "esponteirar",
    "esponteiremos": "esponteirar",
    "esponteires": "esponteirar",
    "esponteiro": "esponteirar",
    "esponteirou": "esponteirar",
    "esponteirá": "esponteirar",
    "esponteirámo": "esponteirar",
    "esponteirámos": "esponteirar",
    "esponteiráramo": "esponteirar",
    "esponteiráramos": "esponteirar",
    "esponteirárei": "esponteirar",
    "esponteiráreis": "esponteirar",
    "esponteirásseis": "esponteirar",
    "esponteirássemos": "esponteirar",
    "esponteirávamo": "esponteirar",
    "esponteirávamos": "esponteirar",
    "esponteirávei": "esponteirar",
    "esponteiráveis": "esponteirar",
    "esponteis": "espontar",
    "espontem": "espontar",
    "espontemo": "espontar",
    "espontemos": "espontar",
    "espontes": "espontar",
    "esponto": "espontar",
    "espontou": "espontar",
    "espontá": "espontar",
    "espontámo": "espontar",
    "espontámos": "espontar",
    "espontáramo": "espontar",
    "espontáramos": "espontar",
    "espontárei": "espontar",
    "espontáreis": "espontar",
    "espontásseis": "espontar",
    "espontássemos": "espontar",
    "espontávamo": "espontar",
    "espontávamos": "espontar",
    "espontávei": "espontar",
    "espontáveis": "espontar",
    "espontânea": "espontâneo",
    "espontâneas": "espontâneo",
    "espontâneos": "espontâneo",
    "espoo": "espoar",
    "espoou": "espoar",
    "espora": "esporar",
    "esporada": "esporar",
    "esporadas": "esporar",
    "esporadicidades": "esporadicidade",
    "esporado": "esporar",
    "esporados": "esporar",
    "esporai": "esporar",
    "esporais": "esporar",
    "esporam": "esporar",
    "esporamo": "esporar",
    "esporamos": "esporar",
    "esporando": "esporar",
    "esporara": "esporar",
    "esporaram": "esporar",
    "esporaras": "esporar",
    "esporarde": "esporar",
    "esporardes": "esporar",
    "esporare": "esporar",
    "esporarei": "esporar",
    "esporareis": "esporar",
    "esporarem": "esporar",
    "esporaremos": "esporar",
    "esporares": "esporar",
    "esporaria": "esporar",
    "esporariam": "esporar",
    "esporarias": "esporar",
    "esporarmo": "esporar",
    "esporarmos": "esporar",
    "esporará": "esporar",
    "esporarás": "esporar",
    "esporarão": "esporar",
    "esporaríamos": "esporar",
    "esporaríeis": "esporar",
    "esporas": "esporar",
    "esporasse": "esporar",
    "esporassem": "esporar",
    "esporasses": "esporar",
    "esporaste": "esporar",
    "esporastes": "esporar",
    "esporava": "esporar",
    "esporavam": "esporar",
    "esporavas": "esporar",
    "esporaúda": "esporaúdo",
    "esporaúdas": "esporaúdo",
    "esporaúdos": "esporaúdo",
    "espore": "esporar",
    "esporeada": "esporear",
    "esporeadas": "esporear",
    "esporeado": "esporear",
    "esporeados": "esporear",
    "esporeai": "esporear",
    "esporeais": "esporear",
    "esporeamo": "esporear",
    "esporeamos": "esporear",
    "esporeando": "esporear",
    "esporeara": "esporear",
    "esporearam": "esporear",
    "esporearas": "esporear",
    "esporearde": "esporear",
    "esporeardes": "esporear",
    "esporeare": "esporear",
    "esporearei": "esporear",
    "esporeareis": "esporear",
    "esporearem": "esporear",
    "esporearemos": "esporear",
    "esporeares": "esporear",
    "esporearia": "esporear",
    "esporeariam": "esporear",
    "esporearias": "esporear",
    "esporearmo": "esporear",
    "esporearmos": "esporear",
    "esporeará": "esporear",
    "esporearás": "esporear",
    "esporearão": "esporear",
    "esporearíamos": "esporear",
    "esporearíeis": "esporear",
    "esporeasse": "esporear",
    "esporeassem": "esporear",
    "esporeasses": "esporear",
    "esporeaste": "esporear",
    "esporeastes": "esporear",
    "esporeava": "esporear",
    "esporeavam": "esporear",
    "esporeavas": "esporear",
    "esporeei": "esporear",
    "esporeeis": "esporear",
    "esporeemo": "esporear",
    "esporeemos": "esporear",
    "esporei": "esporar",
    "esporeia": "esporear",
    "esporeiam": "esporear",
    "esporeias": "esporear",
    "esporeie": "esporear",
    "esporeiem": "esporear",
    "esporeies": "esporear",
    "esporeio": "esporear",
    "esporeiras": "esporeira",
    "esporeis": "esporar",
    "esporem": "esporar",
    "esporemo": "esporar",
    "esporemos": "esporar",
    "esporeou": "esporear",
    "espores": "esporar",
    "esporeá": "esporear",
    "esporeámo": "esporear",
    "esporeámos": "esporear",
    "esporeáramo": "esporear",
    "esporeáramos": "esporear",
    "esporeárei": "esporear",
    "esporeáreis": "esporear",
    "esporeásseis": "esporear",
    "esporeássemos": "esporear",
    "esporeávamo": "esporear",
    "esporeávamos": "esporear",
    "esporeávei": "esporear",
    "esporeáveis": "esporear",
    "esporins": "esporim",
    "esporo": "esporar",
    "esporoada": "esporoado",
    "esporoadas": "esporoado",
    "esporoados": "esporoado",
    "esporocistos": "esporocisto",
    "esporogonias": "esporogonia",
    "esporogónica": "esporogónico",
    "esporogónicas": "esporogónico",
    "esporogónicos": "esporogónico",
    "esporogónios": "esporogónio",
    "esporos": "esporo",
    "esporou": "esporar",
    "esporozoária": "esporozoário",
    "esporozoárias": "esporozoário",
    "esporozoários": "esporozoário",
    "esporozoítos": "esporozoíto",
    "esportas": "esporta",
    "esportelas": "esportela",
    "esportiva": "esportivo",
    "esportivas": "esportivo",
    "esportivos": "esportivo",
    "esportula": "esportular",
    "esportulada": "esportular",
    "esportuladas": "esportular",
    "esportulado": "esportular",
    "esportulados": "esportular",
    "esportulai": "esportular",
    "esportulais": "esportular",
    "esportulam": "esportular",
    "esportulamo": "esportular",
    "esportulamos": "esportular",
    "esportulando": "esportular",
    "esportulara": "esportular",
    "esportularam": "esportular",
    "esportularas": "esportular",
    "esportularde": "esportular",
    "esportulardes": "esportular",
    "esportulare": "esportular",
    "esportularei": "esportular",
    "esportulareis": "esportular",
    "esportularem": "esportular",
    "esportularemos": "esportular",
    "esportulares": "esportular",
    "esportularia": "esportular",
    "esportulariam": "esportular",
    "esportularias": "esportular",
    "esportularmo": "esportular",
    "esportularmos": "esportular",
    "esportulará": "esportular",
    "esportularás": "esportular",
    "esportularão": "esportular",
    "esportularíamos": "esportular",
    "esportularíeis": "esportular",
    "esportulas": "esportular",
    "esportulasse": "esportular",
    "esportulassem": "esportular",
    "esportulasses": "esportular",
    "esportulaste": "esportular",
    "esportulastes": "esportular",
    "esportulava": "esportular",
    "esportulavam": "esportular",
    "esportulavas": "esportular",
    "esportule": "esportular",
    "esportulei": "esportular",
    "esportuleis": "esportular",
    "esportulem": "esportular",
    "esportulemo": "esportular",
    "esportulemos": "esportular",
    "esportules": "esportular",
    "esportulo": "esportular",
    "esportulou": "esportular",
    "esportulá": "esportular",
    "esportulámo": "esportular",
    "esportulámos": "esportular",
    "esportuláramo": "esportular",
    "esportuláramos": "esportular",
    "esportulárei": "esportular",
    "esportuláreis": "esportular",
    "esportulásseis": "esportular",
    "esportulássemos": "esportular",
    "esportulávamo": "esportular",
    "esportulávamos": "esportular",
    "esportulávei": "esportular",
    "esportuláveis": "esportular",
    "esporulações": "esporulação",
    "esporá": "esporar",
    "esporádica": "esporádico",
    "esporádicas": "esporádico",
    "esporádicos": "esporádico",
    "esporámo": "esporar",
    "esporámos": "esporar",
    "esporáramo": "esporar",
    "esporáramos": "esporar",
    "esporárei": "esporar",
    "esporáreis": "esporar",
    "esporásseis": "esporar",
    "esporássemos": "esporar",
    "esporávamo": "esporar",
    "esporávamos": "esporar",
    "esporávei": "esporar",
    "esporáveis": "esporar",
    "esporângeos": "esporângeo",
    "esporífera": "esporífero",
    "esporíferas": "esporífero",
    "esporíferos": "esporífero",
    "esporófila": "esporófilo",
    "esporófilas": "esporófilo",
    "esporófilos": "esporófilo",
    "esporófita": "esporófito",
    "esporófitas": "esporófito",
    "esporófitos": "esporófito",
    "esporóita": "esporóito",
    "esporóitas": "esporóito",
    "esporóitos": "esporóito",
    "esporões": "esporão",
    "esposa": "esposo",
    "esposada": "esposar",
    "esposadas": "esposar",
    "esposado": "esposar",
    "esposados": "esposar",
    "esposai": "esposar",
    "esposais": "esposar",
    "esposam": "esposar",
    "esposamo": "esposar",
    "esposamos": "esposar",
    "esposando": "esposar",
    "esposara": "esposar",
    "esposaram": "esposar",
    "esposaras": "esposar",
    "esposarde": "esposar",
    "esposardes": "esposar",
    "esposare": "esposar",
    "esposarei": "esposar",
    "esposareis": "esposar",
    "esposarem": "esposar",
    "esposaremos": "esposar",
    "esposares": "esposar",
    "esposaria": "esposar",
    "esposariam": "esposar",
    "esposarias": "esposar",
    "esposarmo": "esposar",
    "esposarmos": "esposar",
    "esposará": "esposar",
    "esposarás": "esposar",
    "esposarão": "esposar",
    "esposaríamos": "esposar",
    "esposaríeis": "esposar",
    "esposas": "esposo",
    "esposasse": "esposar",
    "esposassem": "esposar",
    "esposasses": "esposar",
    "esposaste": "esposar",
    "esposastes": "esposar",
    "esposava": "esposar",
    "esposavam": "esposar",
    "esposavas": "esposar",
    "espose": "esposar",
    "esposei": "esposar",
    "esposeis": "esposar",
    "esposem": "esposar",
    "esposemo": "esposar",
    "esposemos": "esposar",
    "esposendenses": "esposendense",
    "esposes": "esposar",
    "esposo": "esposar",
    "esposos": "esposo",
    "esposou": "esposar",
    "esposteja": "espostejar",
    "espostejada": "espostejar",
    "espostejadas": "espostejar",
    "espostejado": "espostejar",
    "espostejados": "espostejar",
    "espostejai": "espostejar",
    "espostejais": "espostejar",
    "espostejam": "espostejar",
    "espostejamo": "espostejar",
    "espostejamos": "espostejar",
    "espostejando": "espostejar",
    "espostejara": "espostejar",
    "espostejaram": "espostejar",
    "espostejaras": "espostejar",
    "espostejarde": "espostejar",
    "espostejardes": "espostejar",
    "espostejare": "espostejar",
    "espostejarei": "espostejar",
    "espostejareis": "espostejar",
    "espostejarem": "espostejar",
    "espostejaremos": "espostejar",
    "espostejares": "espostejar",
    "espostejaria": "espostejar",
    "espostejariam": "espostejar",
    "espostejarias": "espostejar",
    "espostejarmo": "espostejar",
    "espostejarmos": "espostejar",
    "espostejará": "espostejar",
    "espostejarás": "espostejar",
    "espostejarão": "espostejar",
    "espostejaríamos": "espostejar",
    "espostejaríeis": "espostejar",
    "espostejas": "espostejar",
    "espostejasse": "espostejar",
    "espostejassem": "espostejar",
    "espostejasses": "espostejar",
    "espostejaste": "espostejar",
    "espostejastes": "espostejar",
    "espostejava": "espostejar",
    "espostejavam": "espostejar",
    "espostejavas": "espostejar",
    "esposteje": "espostejar",
    "espostejei": "espostejar",
    "espostejeis": "espostejar",
    "espostejem": "espostejar",
    "espostejemo": "espostejar",
    "espostejemos": "espostejar",
    "espostejes": "espostejar",
    "espostejo": "espostejar",
    "espostejou": "espostejar",
    "espostejá": "espostejar",
    "espostejámo": "espostejar",
    "espostejámos": "espostejar",
    "espostejáramo": "espostejar",
    "espostejáramos": "espostejar",
    "espostejárei": "espostejar",
    "espostejáreis": "espostejar",
    "espostejásseis": "espostejar",
    "espostejássemos": "espostejar",
    "espostejávamo": "espostejar",
    "espostejávamos": "espostejar",
    "espostejávei": "espostejar",
    "espostejáveis": "espostejar",
    "esposá": "esposar",
    "esposámo": "esposar",
    "esposámos": "esposar",
    "esposáramo": "esposar",
    "esposáramos": "esposar",
    "esposárei": "esposar",
    "esposáreis": "esposar",
    "esposásseis": "esposar",
    "esposássemos": "esposar",
    "esposávamo": "esposar",
    "esposávamos": "esposar",
    "esposávei": "esposar",
    "esposáveis": "esposar",
    "esposórios": "esposório",
    "espoá": "espoar",
    "espoámo": "espoar",
    "espoámos": "espoar",
    "espoáramo": "espoar",
    "espoáramos": "espoar",
    "espoárei": "espoar",
    "espoáreis": "espoar",
    "espoásseis": "espoar",
    "espoássemos": "espoar",
    "espoávamo": "espoar",
    "espoávamos": "espoar",
    "espoávei": "espoar",
    "espoáveis": "espoar",
    "espraia": "espraiar",
    "espraiada": "espraiar",
    "espraiadas": "espraiar",
    "espraiado": "espraiar",
    "espraiados": "espraiar",
    "espraiai": "espraiar",
    "espraiais": "espraiar",
    "espraiam": "espraiar",
    "espraiamentos": "espraiamento",
    "espraiamo": "espraiar",
    "espraiamos": "espraiar",
    "espraiando": "espraiar",
    "espraiara": "espraiar",
    "espraiaram": "espraiar",
    "espraiaras": "espraiar",
    "espraiarde": "espraiar",
    "espraiardes": "espraiar",
    "espraiare": "espraiar",
    "espraiarei": "espraiar",
    "espraiareis": "espraiar",
    "espraiarem": "espraiar",
    "espraiaremos": "espraiar",
    "espraiares": "espraiar",
    "espraiaria": "espraiar",
    "espraiariam": "espraiar",
    "espraiarias": "espraiar",
    "espraiarmo": "espraiar",
    "espraiarmos": "espraiar",
    "espraiará": "espraiar",
    "espraiarás": "espraiar",
    "espraiarão": "espraiar",
    "espraiaríamos": "espraiar",
    "espraiaríeis": "espraiar",
    "espraias": "espraiar",
    "espraiasse": "espraiar",
    "espraiassem": "espraiar",
    "espraiasses": "espraiar",
    "espraiaste": "espraiar",
    "espraiastes": "espraiar",
    "espraiava": "espraiar",
    "espraiavam": "espraiar",
    "espraiavas": "espraiar",
    "espraie": "espraiar",
    "espraiei": "espraiar",
    "espraieis": "espraiar",
    "espraiem": "espraiar",
    "espraiemo": "espraiar",
    "espraiemos": "espraiar",
    "espraies": "espraiar",
    "espraio": "espraiar",
    "espraiou": "espraiar",
    "espraiá": "espraiar",
    "espraiámo": "espraiar",
    "espraiámos": "espraiar",
    "espraiáramo": "espraiar",
    "espraiáramos": "espraiar",
    "espraiárei": "espraiar",
    "espraiáreis": "espraiar",
    "espraiásseis": "espraiar",
    "espraiássemos": "espraiar",
    "espraiávamo": "espraiar",
    "espraiávamos": "espraiar",
    "espraiávei": "espraiar",
    "espraiáveis": "espraiar",
    "espreguice": "espreguiçar",
    "espreguicei": "espreguiçar",
    "espreguiceis": "espreguiçar",
    "espreguicem": "espreguiçar",
    "espreguicemo": "espreguiçar",
    "espreguicemos": "espreguiçar",
    "espreguices": "espreguiçar",
    "espreguiça": "espreguiçar",
    "espreguiçada": "espreguiçar",
    "espreguiçadas": "espreguiçar",
    "espreguiçadeiras": "espreguiçadeira",
    "espreguiçadelas": "espreguiçadela",
    "espreguiçado": "espreguiçar",
    "espreguiçadoiros": "espreguiçadoiro",
    "espreguiçadora": "espreguiçador",
    "espreguiçadoras": "espreguiçador",
    "espreguiçadores": "espreguiçador",
    "espreguiçados": "espreguiçar",
    "espreguiçadouros": "espreguiçadouro",
    "espreguiçai": "espreguiçar",
    "espreguiçais": "espreguiçar",
    "espreguiçam": "espreguiçar",
    "espreguiçamentos": "espreguiçamento",
    "espreguiçamo": "espreguiçar",
    "espreguiçamos": "espreguiçar",
    "espreguiçando": "espreguiçar",
    "espreguiçara": "espreguiçar",
    "espreguiçaram": "espreguiçar",
    "espreguiçaras": "espreguiçar",
    "espreguiçarde": "espreguiçar",
    "espreguiçardes": "espreguiçar",
    "espreguiçare": "espreguiçar",
    "espreguiçarei": "espreguiçar",
    "espreguiçareis": "espreguiçar",
    "espreguiçarem": "espreguiçar",
    "espreguiçaremos": "espreguiçar",
    "espreguiçares": "espreguiçar",
    "espreguiçaria": "espreguiçar",
    "espreguiçariam": "espreguiçar",
    "espreguiçarias": "espreguiçar",
    "espreguiçarmo": "espreguiçar",
    "espreguiçarmos": "espreguiçar",
    "espreguiçará": "espreguiçar",
    "espreguiçarás": "espreguiçar",
    "espreguiçarão": "espreguiçar",
    "espreguiçaríamos": "espreguiçar",
    "espreguiçaríeis": "espreguiçar",
    "espreguiças": "espreguiçar",
    "espreguiçasse": "espreguiçar",
    "espreguiçassem": "espreguiçar",
    "espreguiçasses": "espreguiçar",
    "espreguiçaste": "espreguiçar",
    "espreguiçastes": "espreguiçar",
    "espreguiçava": "espreguiçar",
    "espreguiçavam": "espreguiçar",
    "espreguiçavas": "espreguiçar",
    "espreguiço": "espreguiçar",
    "espreguiçou": "espreguiçar",
    "espreguiçá": "espreguiçar",
    "espreguiçámo": "espreguiçar",
    "espreguiçámos": "espreguiçar",
    "espreguiçáramo": "espreguiçar",
    "espreguiçáramos": "espreguiçar",
    "espreguiçárei": "espreguiçar",
    "espreguiçáreis": "espreguiçar",
    "espreguiçásseis": "espreguiçar",
    "espreguiçássemos": "espreguiçar",
    "espreguiçávamo": "espreguiçar",
    "espreguiçávamos": "espreguiçar",
    "espreguiçávei": "espreguiçar",
    "espreguiçáveis": "espreguiçar",
    "espreita": "espreitar",
    "espreitada": "espreitar",
    "espreitadas": "espreitar",
    "espreitadeira": "espreitadeiro",
    "espreitadeiras": "espreitadeiro",
    "espreitadeiros": "espreitadeiro",
    "espreitadelas": "espreitadela",
    "espreitado": "espreitar",
    "espreitadora": "espreitador",
    "espreitadoras": "espreitador",
    "espreitadores": "espreitador",
    "espreitados": "espreitar",
    "espreitai": "espreitar",
    "espreitais": "espreitar",
    "espreitam": "espreitar",
    "espreitamo": "espreitar",
    "espreitamos": "espreitar",
    "espreitando": "espreitar",
    "espreitantes": "espreitante",
    "espreitanças": "espreitança",
    "espreitara": "espreitar",
    "espreitaram": "espreitar",
    "espreitaras": "espreitar",
    "espreitarde": "espreitar",
    "espreitardes": "espreitar",
    "espreitare": "espreitar",
    "espreitarei": "espreitar",
    "espreitareis": "espreitar",
    "espreitarem": "espreitar",
    "espreitaremos": "espreitar",
    "espreitares": "espreitar",
    "espreitaria": "espreitar",
    "espreitariam": "espreitar",
    "espreitarias": "espreitar",
    "espreitarmo": "espreitar",
    "espreitarmos": "espreitar",
    "espreitará": "espreitar",
    "espreitarás": "espreitar",
    "espreitarão": "espreitar",
    "espreitaríamos": "espreitar",
    "espreitaríeis": "espreitar",
    "espreitas": "espreitar",
    "espreitasse": "espreitar",
    "espreitassem": "espreitar",
    "espreitasses": "espreitar",
    "espreitaste": "espreitar",
    "espreitastes": "espreitar",
    "espreitava": "espreitar",
    "espreitavam": "espreitar",
    "espreitavas": "espreitar",
    "espreite": "espreitar",
    "espreitei": "espreitar",
    "espreiteis": "espreitar",
    "espreitem": "espreitar",
    "espreitemo": "espreitar",
    "espreitemos": "espreitar",
    "espreites": "espreitar",
    "espreito": "espreitar",
    "espreitou": "espreitar",
    "espreitá": "espreitar",
    "espreitámo": "espreitar",
    "espreitámos": "espreitar",
    "espreitáramo": "espreitar",
    "espreitáramos": "espreitar",
    "espreitárei": "espreitar",
    "espreitáreis": "espreitar",
    "espreitásseis": "espreitar",
    "espreitássemos": "espreitar",
    "espreitávamo": "espreitar",
    "espreitávamos": "espreitar",
    "espreitávei": "espreitar",
    "espreitáveis": "espreitar",
    "esprema": "espremer",
    "espremais": "espremer",
    "espremam": "espremer",
    "espremamo": "espremer",
    "espremamos": "espremer",
    "espremas": "espremer",
    "espreme": "espremer",
    "espremedelas": "espremedela",
    "espremediça": "espremediço",
    "espremediças": "espremediço",
    "espremediços": "espremediço",
    "espremedora": "espremedor",
    "espremedoras": "espremedor",
    "espremedores": "espremedor",
    "espremeduras": "espremedura",
    "espremei": "espremer",
    "espremeis": "espremer",
    "espremem": "espremer",
    "esprememo": "espremer",
    "esprememos": "espremer",
    "espremendo": "espremer",
    "espremera": "espremer",
    "espremeram": "espremer",
    "espremeras": "espremer",
    "espremerde": "espremer",
    "espremerdes": "espremer",
    "espremere": "espremer",
    "espremerei": "espremer",
    "espremereis": "espremer",
    "espremerem": "espremer",
    "espremeremos": "espremer",
    "espremeres": "espremer",
    "espremeria": "espremer",
    "espremeriam": "espremer",
    "espremerias": "espremer",
    "espremermo": "espremer",
    "espremermos": "espremer",
    "espremerá": "espremer",
    "espremerás": "espremer",
    "espremerão": "espremer",
    "espremeríamos": "espremer",
    "espremeríeis": "espremer",
    "espremes": "espremer",
    "espremesse": "espremer",
    "espremessem": "espremer",
    "espremesses": "espremer",
    "espremeste": "espremer",
    "espremestes": "espremer",
    "espremeu": "espremer",
    "espremi": "espremer",
    "espremia": "espremer",
    "espremiam": "espremer",
    "espremias": "espremer",
    "espremida": "espremido",
    "espremidas": "espremido",
    "espremido": "espremer",
    "espremidos": "espremido",
    "espremidíssima": "espremido",
    "espremidíssimas": "espremido",
    "espremidíssimo": "espremido",
    "espremidíssimos": "espremido",
    "espremo": "espremer",
    "espremê": "espremer",
    "espremêramo": "espremer",
    "espremêramos": "espremer",
    "espremêrei": "espremer",
    "espremêreis": "espremer",
    "espremêsseis": "espremer",
    "espremêssemos": "espremer",
    "espremíamo": "espremer",
    "espremíamos": "espremer",
    "espremíei": "espremer",
    "espremíeis": "espremer",
    "espremíveis": "espremível",
    "espriegas": "espriega",
    "espua": "espuir",
    "espuais": "espuir",
    "espuam": "espuir",
    "espuamo": "espuir",
    "espuamos": "espuir",
    "espuas": "espuir",
    "espuem": "espuir",
    "espui": "espuir",
    "espuindo": "espuir",
    "espuirde": "espuir",
    "espuirdes": "espuir",
    "espuirei": "espuir",
    "espuireis": "espuir",
    "espuiremos": "espuir",
    "espuiria": "espuir",
    "espuiriam": "espuir",
    "espuirias": "espuir",
    "espuirmo": "espuir",
    "espuirmos": "espuir",
    "espuirá": "espuir",
    "espuirás": "espuir",
    "espuirão": "espuir",
    "espuiríamos": "espuir",
    "espuiríeis": "espuir",
    "espuis": "espuir",
    "espuiu": "espuir",
    "espuições": "espuição",
    "espulga": "espulgar",
    "espulgada": "espulgar",
    "espulgadas": "espulgar",
    "espulgado": "espulgar",
    "espulgados": "espulgar",
    "espulgai": "espulgar",
    "espulgais": "espulgar",
    "espulgam": "espulgar",
    "espulgamentos": "espulgamento",
    "espulgamo": "espulgar",
    "espulgamos": "espulgar",
    "espulgando": "espulgar",
    "espulgara": "espulgar",
    "espulgaram": "espulgar",
    "espulgaras": "espulgar",
    "espulgarde": "espulgar",
    "espulgardes": "espulgar",
    "espulgare": "espulgar",
    "espulgarei": "espulgar",
    "espulgareis": "espulgar",
    "espulgarem": "espulgar",
    "espulgaremos": "espulgar",
    "espulgares": "espulgar",
    "espulgaria": "espulgar",
    "espulgariam": "espulgar",
    "espulgarias": "espulgar",
    "espulgarmo": "espulgar",
    "espulgarmos": "espulgar",
    "espulgará": "espulgar",
    "espulgarás": "espulgar",
    "espulgarão": "espulgar",
    "espulgaríamos": "espulgar",
    "espulgaríeis": "espulgar",
    "espulgas": "espulgar",
    "espulgasse": "espulgar",
    "espulgassem": "espulgar",
    "espulgasses": "espulgar",
    "espulgaste": "espulgar",
    "espulgastes": "espulgar",
    "espulgava": "espulgar",
    "espulgavam": "espulgar",
    "espulgavas": "espulgar",
    "espulgações": "espulgação",
    "espulgo": "espulgar",
    "espulgou": "espulgar",
    "espulgue": "espulgar",
    "espulguei": "espulgar",
    "espulgueis": "espulgar",
    "espulguem": "espulgar",
    "espulguemo": "espulgar",
    "espulguemos": "espulgar",
    "espulgues": "espulgar",
    "espulgá": "espulgar",
    "espulgámo": "espulgar",
    "espulgámos": "espulgar",
    "espulgáramo": "espulgar",
    "espulgáramos": "espulgar",
    "espulgárei": "espulgar",
    "espulgáreis": "espulgar",
    "espulgásseis": "espulgar",
    "espulgássemos": "espulgar",
    "espulgávamo": "espulgar",
    "espulgávamos": "espulgar",
    "espulgávei": "espulgar",
    "espulgáveis": "espulgar",
    "espuma": "espumar",
    "espumace": "espumaçar",
    "espumacei": "espumaçar",
    "espumaceis": "espumaçar",
    "espumacem": "espumaçar",
    "espumacemo": "espumaçar",
    "espumacemos": "espumaçar",
    "espumaces": "espumaçar",
    "espumada": "espumar",
    "espumadas": "espumar",
    "espumadeiras": "espumadeira",
    "espumado": "espumar",
    "espumados": "espumar",
    "espumai": "espumar",
    "espumais": "espumar",
    "espumam": "espumar",
    "espumamo": "espumar",
    "espumamos": "espumar",
    "espumando": "espumar",
    "espumantes": "espumante",
    "espumara": "espumar",
    "espumaradas": "espumarada",
    "espumaram": "espumar",
    "espumaras": "espumar",
    "espumardes": "espumar",
    "espumarei": "espumar",
    "espumareis": "espumar",
    "espumarem": "espumar",
    "espumaremos": "espumar",
    "espumares": "espumar",
    "espumaria": "espumar",
    "espumariam": "espumar",
    "espumarias": "espumar",
    "espumarmo": "espumar",
    "espumarmos": "espumar",
    "espumará": "espumar",
    "espumarás": "espumar",
    "espumarão": "espumar",
    "espumaríamos": "espumar",
    "espumaríeis": "espumar",
    "espumas": "espumar",
    "espumasse": "espumar",
    "espumassem": "espumar",
    "espumasses": "espumar",
    "espumaste": "espumar",
    "espumastes": "espumar",
    "espumava": "espumar",
    "espumavam": "espumar",
    "espumavas": "espumar",
    "espumaça": "espumaçar",
    "espumaçada": "espumaçar",
    "espumaçadas": "espumaçar",
    "espumaçado": "espumaçar",
    "espumaçados": "espumaçar",
    "espumaçai": "espumaçar",
    "espumaçais": "espumaçar",
    "espumaçam": "espumaçar",
    "espumaçamo": "espumaçar",
    "espumaçamos": "espumaçar",
    "espumaçando": "espumaçar",
    "espumaçara": "espumaçar",
    "espumaçaram": "espumaçar",
    "espumaçaras": "espumaçar",
    "espumaçardes": "espumaçar",
    "espumaçarei": "espumaçar",
    "espumaçareis": "espumaçar",
    "espumaçarem": "espumaçar",
    "espumaçaremos": "espumaçar",
    "espumaçares": "espumaçar",
    "espumaçaria": "espumaçar",
    "espumaçariam": "espumaçar",
    "espumaçarias": "espumaçar",
    "espumaçarmo": "espumaçar",
    "espumaçarmos": "espumaçar",
    "espumaçará": "espumaçar",
    "espumaçarás": "espumaçar",
    "espumaçarão": "espumaçar",
    "espumaçaríamos": "espumaçar",
    "espumaçaríeis": "espumaçar",
    "espumaças": "espumaçar",
    "espumaçasse": "espumaçar",
    "espumaçassem": "espumaçar",
    "espumaçasses": "espumaçar",
    "espumaçaste": "espumaçar",
    "espumaçastes": "espumaçar",
    "espumaçava": "espumaçar",
    "espumaçavam": "espumaçar",
    "espumaçavas": "espumaçar",
    "espumaço": "espumaçar",
    "espumaçou": "espumaçar",
    "espumaçámo": "espumaçar",
    "espumaçámos": "espumaçar",
    "espumaçáramo": "espumaçar",
    "espumaçáramos": "espumaçar",
    "espumaçáreis": "espumaçar",
    "espumaçásseis": "espumaçar",
    "espumaçássemos": "espumaçar",
    "espumaçávamo": "espumaçar",
    "espumaçávamos": "espumaçar",
    "espumaçáveis": "espumaçar",
    "espume": "espumar",
    "espumei": "espumar",
    "espumeis": "espumar",
    "espumeja": "espumejar",
    "espumejada": "espumejar",
    "espumejadas": "espumejar",
    "espumejado": "espumejar",
    "espumejados": "espumejar",
    "espumejai": "espumejar",
    "espumejais": "espumejar",
    "espumejam": "espumejar",
    "espumejamo": "espumejar",
    "espumejamos": "espumejar",
    "espumejando": "espumejar",
    "espumejantes": "espumejante",
    "espumejara": "espumejar",
    "espumejaram": "espumejar",
    "espumejaras": "espumejar",
    "espumejardes": "espumejar",
    "espumejarei": "espumejar",
    "espumejareis": "espumejar",
    "espumejarem": "espumejar",
    "espumejaremos": "espumejar",
    "espumejares": "espumejar",
    "espumejaria": "espumejar",
    "espumejariam": "espumejar",
    "espumejarias": "espumejar",
    "espumejarmo": "espumejar",
    "espumejarmos": "espumejar",
    "espumejará": "espumejar",
    "espumejarás": "espumejar",
    "espumejarão": "espumejar",
    "espumejaríamos": "espumejar",
    "espumejaríeis": "espumejar",
    "espumejas": "espumejar",
    "espumejasse": "espumejar",
    "espumejassem": "espumejar",
    "espumejasses": "espumejar",
    "espumejaste": "espumejar",
    "espumejastes": "espumejar",
    "espumejava": "espumejar",
    "espumejavam": "espumejar",
    "espumejavas": "espumejar",
    "espumeje": "espumejar",
    "espumejei": "espumejar",
    "espumejeis": "espumejar",
    "espumejem": "espumejar",
    "espumejemo": "espumejar",
    "espumejemos": "espumejar",
    "espumejes": "espumejar",
    "espumejo": "espumejar",
    "espumejou": "espumejar",
    "espumejámo": "espumejar",
    "espumejámos": "espumejar",
    "espumejáramo": "espumejar",
    "espumejáramos": "espumejar",
    "espumejáreis": "espumejar",
    "espumejásseis": "espumejar",
    "espumejássemos": "espumejar",
    "espumejávamo": "espumejar",
    "espumejávamos": "espumejar",
    "espumejáveis": "espumejar",
    "espumem": "espumar",
    "espumemo": "espumar",
    "espumemos": "espumar",
    "espumes": "espumar",
    "espuminha": "espuma",
    "espuminhas": "espuma",
    "espumita": "espuma",
    "espumitas": "espuma",
    "espumo": "espumar",
    "espumosa": "espumoso",
    "espumosas": "espumoso",
    "espumosidades": "espumosidade",
    "espumosos": "espumoso",
    "espumou": "espumar",
    "espumámo": "espumar",
    "espumámos": "espumar",
    "espumáramo": "espumar",
    "espumáramos": "espumar",
    "espumáreis": "espumar",
    "espumásseis": "espumar",
    "espumássemos": "espumar",
    "espumávamo": "espumar",
    "espumávamos": "espumar",
    "espumáveis": "espumar",
    "espumífera": "espumífero",
    "espumíferas": "espumífero",
    "espumíferos": "espumífero",
    "espuo": "espuir",
    "espurcícias": "espurcícia",
    "espuriedades": "espuriedade",
    "esputa": "esputar",
    "esputada": "esputar",
    "esputadas": "esputar",
    "esputado": "esputar",
    "esputados": "esputar",
    "esputai": "esputar",
    "esputais": "esputar",
    "esputam": "esputar",
    "esputamo": "esputar",
    "esputamos": "esputar",
    "esputando": "esputar",
    "esputara": "esputar",
    "esputaram": "esputar",
    "esputaras": "esputar",
    "esputardes": "esputar",
    "esputarei": "esputar",
    "esputareis": "esputar",
    "esputarem": "esputar",
    "esputaremos": "esputar",
    "esputares": "esputar",
    "esputaria": "esputar",
    "esputariam": "esputar",
    "esputarias": "esputar",
    "esputarmo": "esputar",
    "esputarmos": "esputar",
    "esputará": "esputar",
    "esputarás": "esputar",
    "esputarão": "esputar",
    "esputaríamos": "esputar",
    "esputaríeis": "esputar",
    "esputas": "esputar",
    "esputasse": "esputar",
    "esputassem": "esputar",
    "esputasses": "esputar",
    "esputaste": "esputar",
    "esputastes": "esputar",
    "esputava": "esputar",
    "esputavam": "esputar",
    "esputavas": "esputar",
    "esputações": "esputação",
    "espute": "esputar",
    "esputei": "esputar",
    "esputeis": "esputar",
    "esputem": "esputar",
    "esputemo": "esputar",
    "esputemos": "esputar",
    "esputes": "esputar",
    "esputo": "esputar",
    "esputou": "esputar",
    "esputámo": "esputar",
    "esputámos": "esputar",
    "esputáramo": "esputar",
    "esputáramos": "esputar",
    "esputáreis": "esputar",
    "esputásseis": "esputar",
    "esputássemos": "esputar",
    "esputávamo": "esputar",
    "esputávamos": "esputar",
    "esputáveis": "esputar",
    "espuí": "espuir",
    "espuía": "espuir",
    "espuíam": "espuir",
    "espuíamo": "espuir",
    "espuíamos": "espuir",
    "espuías": "espuir",
    "espuída": "espuir",
    "espuídas": "espuir",
    "espuído": "espuir",
    "espuídos": "espuir",
    "espuíei": "espuir",
    "espuíeis": "espuir",
    "espuímo": "espuir",
    "espuímos": "espuir",
    "espuíra": "espuir",
    "espuíram": "espuir",
    "espuíramo": "espuir",
    "espuíramos": "espuir",
    "espuíras": "espuir",
    "espuíre": "espuir",
    "espuírei": "espuir",
    "espuíreis": "espuir",
    "espuírem": "espuir",
    "espuíres": "espuir",
    "espuís": "espuir",
    "espuísse": "espuir",
    "espuísseis": "espuir",
    "espuíssem": "espuir",
    "espuíssemos": "espuir",
    "espuísses": "espuir",
    "espuíste": "espuir",
    "espuístes": "espuir",
    "espáduas": "espádua",
    "espáridas": "espárida",
    "espátulas": "espátula",
    "espécies": "espécie",
    "espécimens": "espécimen",
    "espécimes": "espécime",
    "espéculos": "espéculo",
    "espículas": "espícula",
    "espículos": "espículo",
    "espínea": "espíneo",
    "espíneas": "espíneo",
    "espíneos": "espíneo",
    "espínulas": "espínula",
    "espíritas": "espírita",
    "espíritos": "espírito",
    "espólios": "espólio",
    "espórtulas": "espórtula",
    "espórulos": "espórulo",
    "espôndilos": "espôndilo",
    "espúmea": "espúmeo",
    "espúmeas": "espúmeo",
    "espúmeos": "espúmeo",
    "espúndias": "espúndia",
    "espúria": "espúrio",
    "espúrias": "espúrio",
    "espúrios": "espúrio",
    "esquadra": "esquadrar",
    "esquadrada": "esquadrar",
    "esquadradas": "esquadrar",
    "esquadrado": "esquadrar",
    "esquadrados": "esquadrar",
    "esquadrai": "esquadrar",
    "esquadrais": "esquadrar",
    "esquadram": "esquadrar",
    "esquadramo": "esquadrar",
    "esquadramos": "esquadrar",
    "esquadrando": "esquadrar",
    "esquadrara": "esquadrar",
    "esquadraram": "esquadrar",
    "esquadraras": "esquadrar",
    "esquadrarde": "esquadrar",
    "esquadrardes": "esquadrar",
    "esquadrare": "esquadrar",
    "esquadrarei": "esquadrar",
    "esquadrareis": "esquadrar",
    "esquadrarem": "esquadrar",
    "esquadraremos": "esquadrar",
    "esquadrares": "esquadrar",
    "esquadraria": "esquadrar",
    "esquadrariam": "esquadrar",
    "esquadrarias": "esquadrar",
    "esquadrarmo": "esquadrar",
    "esquadrarmos": "esquadrar",
    "esquadrará": "esquadrar",
    "esquadrarás": "esquadrar",
    "esquadrarão": "esquadrar",
    "esquadraríamos": "esquadrar",
    "esquadraríeis": "esquadrar",
    "esquadras": "esquadrar",
    "esquadrasse": "esquadrar",
    "esquadrassem": "esquadrar",
    "esquadrasses": "esquadrar",
    "esquadraste": "esquadrar",
    "esquadrastes": "esquadrar",
    "esquadrava": "esquadrar",
    "esquadravam": "esquadrar",
    "esquadravas": "esquadrar",
    "esquadre": "esquadrar",
    "esquadrei": "esquadrar",
    "esquadreis": "esquadrar",
    "esquadreja": "esquadrejar",
    "esquadrejada": "esquadrejar",
    "esquadrejadas": "esquadrejar",
    "esquadrejado": "esquadrejar",
    "esquadrejados": "esquadrejar",
    "esquadrejai": "esquadrejar",
    "esquadrejais": "esquadrejar",
    "esquadrejam": "esquadrejar",
    "esquadrejamentos": "esquadrejamento",
    "esquadrejamo": "esquadrejar",
    "esquadrejamos": "esquadrejar",
    "esquadrejando": "esquadrejar",
    "esquadrejara": "esquadrejar",
    "esquadrejaram": "esquadrejar",
    "esquadrejaras": "esquadrejar",
    "esquadrejarde": "esquadrejar",
    "esquadrejardes": "esquadrejar",
    "esquadrejare": "esquadrejar",
    "esquadrejarei": "esquadrejar",
    "esquadrejareis": "esquadrejar",
    "esquadrejarem": "esquadrejar",
    "esquadrejaremos": "esquadrejar",
    "esquadrejares": "esquadrejar",
    "esquadrejaria": "esquadrejar",
    "esquadrejariam": "esquadrejar",
    "esquadrejarias": "esquadrejar",
    "esquadrejarmo": "esquadrejar",
    "esquadrejarmos": "esquadrejar",
    "esquadrejará": "esquadrejar",
    "esquadrejarás": "esquadrejar",
    "esquadrejarão": "esquadrejar",
    "esquadrejaríamos": "esquadrejar",
    "esquadrejaríeis": "esquadrejar",
    "esquadrejas": "esquadrejar",
    "esquadrejasse": "esquadrejar",
    "esquadrejassem": "esquadrejar",
    "esquadrejasses": "esquadrejar",
    "esquadrejaste": "esquadrejar",
    "esquadrejastes": "esquadrejar",
    "esquadrejava": "esquadrejar",
    "esquadrejavam": "esquadrejar",
    "esquadrejavas": "esquadrejar",
    "esquadreje": "esquadrejar",
    "esquadrejei": "esquadrejar",
    "esquadrejeis": "esquadrejar",
    "esquadrejem": "esquadrejar",
    "esquadrejemo": "esquadrejar",
    "esquadrejemos": "esquadrejar",
    "esquadrejes": "esquadrejar",
    "esquadrejo": "esquadrejar",
    "esquadrejou": "esquadrejar",
    "esquadrejá": "esquadrejar",
    "esquadrejámo": "esquadrejar",
    "esquadrejámos": "esquadrejar",
    "esquadrejáramo": "esquadrejar",
    "esquadrejáramos": "esquadrejar",
    "esquadrejárei": "esquadrejar",
    "esquadrejáreis": "esquadrejar",
    "esquadrejásseis": "esquadrejar",
    "esquadrejássemos": "esquadrejar",
    "esquadrejávamo": "esquadrejar",
    "esquadrejávamos": "esquadrejar",
    "esquadrejávei": "esquadrejar",
    "esquadrejáveis": "esquadrejar",
    "esquadrem": "esquadrar",
    "esquadremo": "esquadrar",
    "esquadremos": "esquadrar",
    "esquadres": "esquadrar",
    "esquadria": "esquadriar",
    "esquadriada": "esquadriar",
    "esquadriadas": "esquadriar",
    "esquadriado": "esquadriar",
    "esquadriados": "esquadriar",
    "esquadriai": "esquadriar",
    "esquadriais": "esquadriar",
    "esquadriam": "esquadriar",
    "esquadriamo": "esquadriar",
    "esquadriamos": "esquadriar",
    "esquadriando": "esquadriar",
    "esquadriara": "esquadriar",
    "esquadriaram": "esquadriar",
    "esquadriaras": "esquadriar",
    "esquadriarde": "esquadriar",
    "esquadriardes": "esquadriar",
    "esquadriare": "esquadriar",
    "esquadriarei": "esquadriar",
    "esquadriareis": "esquadriar",
    "esquadriarem": "esquadriar",
    "esquadriaremos": "esquadriar",
    "esquadriares": "esquadriar",
    "esquadriaria": "esquadriar",
    "esquadriariam": "esquadriar",
    "esquadriarias": "esquadriar",
    "esquadriarmo": "esquadriar",
    "esquadriarmos": "esquadriar",
    "esquadriará": "esquadriar",
    "esquadriarás": "esquadriar",
    "esquadriarão": "esquadriar",
    "esquadriaríamos": "esquadriar",
    "esquadriaríeis": "esquadriar",
    "esquadrias": "esquadriar",
    "esquadriasse": "esquadriar",
    "esquadriassem": "esquadriar",
    "esquadriasses": "esquadriar",
    "esquadriaste": "esquadriar",
    "esquadriastes": "esquadriar",
    "esquadriava": "esquadriar",
    "esquadriavam": "esquadriar",
    "esquadriavas": "esquadriar",
    "esquadrie": "esquadriar",
    "esquadriei": "esquadriar",
    "esquadrieis": "esquadriar",
    "esquadriem": "esquadriar",
    "esquadriemo": "esquadriar",
    "esquadriemos": "esquadriar",
    "esquadries": "esquadriar",
    "esquadrilha": "esquadrilhar",
    "esquadrilhada": "esquadrilhar",
    "esquadrilhadas": "esquadrilhar",
    "esquadrilhado": "esquadrilhar",
    "esquadrilhados": "esquadrilhar",
    "esquadrilhai": "esquadrilhar",
    "esquadrilhais": "esquadrilhar",
    "esquadrilham": "esquadrilhar",
    "esquadrilhamo": "esquadrilhar",
    "esquadrilhamos": "esquadrilhar",
    "esquadrilhando": "esquadrilhar",
    "esquadrilhara": "esquadrilhar",
    "esquadrilharam": "esquadrilhar",
    "esquadrilharas": "esquadrilhar",
    "esquadrilharde": "esquadrilhar",
    "esquadrilhardes": "esquadrilhar",
    "esquadrilhare": "esquadrilhar",
    "esquadrilharei": "esquadrilhar",
    "esquadrilhareis": "esquadrilhar",
    "esquadrilharem": "esquadrilhar",
    "esquadrilharemos": "esquadrilhar",
    "esquadrilhares": "esquadrilhar",
    "esquadrilharia": "esquadrilhar",
    "esquadrilhariam": "esquadrilhar",
    "esquadrilharias": "esquadrilhar",
    "esquadrilharmo": "esquadrilhar",
    "esquadrilharmos": "esquadrilhar",
    "esquadrilhará": "esquadrilhar",
    "esquadrilharás": "esquadrilhar",
    "esquadrilharão": "esquadrilhar",
    "esquadrilharíamos": "esquadrilhar",
    "esquadrilharíeis": "esquadrilhar",
    "esquadrilhas": "esquadrilhar",
    "esquadrilhasse": "esquadrilhar",
    "esquadrilhassem": "esquadrilhar",
    "esquadrilhasses": "esquadrilhar",
    "esquadrilhaste": "esquadrilhar",
    "esquadrilhastes": "esquadrilhar",
    "esquadrilhava": "esquadrilhar",
    "esquadrilhavam": "esquadrilhar",
    "esquadrilhavas": "esquadrilhar",
    "esquadrilhe": "esquadrilhar",
    "esquadrilhei": "esquadrilhar",
    "esquadrilheis": "esquadrilhar",
    "esquadrilhem": "esquadrilhar",
    "esquadrilhemo": "esquadrilhar",
    "esquadrilhemos": "esquadrilhar",
    "esquadrilhes": "esquadrilhar",
    "esquadrilho": "esquadrilhar",
    "esquadrilhou": "esquadrilhar",
    "esquadrilhá": "esquadrilhar",
    "esquadrilhámo": "esquadrilhar",
    "esquadrilhámos": "esquadrilhar",
    "esquadrilháramo": "esquadrilhar",
    "esquadrilháramos": "esquadrilhar",
    "esquadrilhárei": "esquadrilhar",
    "esquadrilháreis": "esquadrilhar",
    "esquadrilhásseis": "esquadrilhar",
    "esquadrilhássemos": "esquadrilhar",
    "esquadrilhávamo": "esquadrilhar",
    "esquadrilhávamos": "esquadrilhar",
    "esquadrilhávei": "esquadrilhar",
    "esquadrilháveis": "esquadrilhar",
    "esquadrinha": "esquadrinhar",
    "esquadrinhada": "esquadrinhar",
    "esquadrinhadas": "esquadrinhar",
    "esquadrinhado": "esquadrinhar",
    "esquadrinhadora": "esquadrinhador",
    "esquadrinhadoras": "esquadrinhador",
    "esquadrinhadores": "esquadrinhador",
    "esquadrinhados": "esquadrinhar",
    "esquadrinhaduras": "esquadrinhadura",
    "esquadrinhai": "esquadrinhar",
    "esquadrinhais": "esquadrinhar",
    "esquadrinham": "esquadrinhar",
    "esquadrinhamentos": "esquadrinhamento",
    "esquadrinhamo": "esquadrinhar",
    "esquadrinhamos": "esquadrinhar",
    "esquadrinhando": "esquadrinhar",
    "esquadrinhara": "esquadrinhar",
    "esquadrinharam": "esquadrinhar",
    "esquadrinharas": "esquadrinhar",
    "esquadrinharde": "esquadrinhar",
    "esquadrinhardes": "esquadrinhar",
    "esquadrinhare": "esquadrinhar",
    "esquadrinharei": "esquadrinhar",
    "esquadrinhareis": "esquadrinhar",
    "esquadrinharem": "esquadrinhar",
    "esquadrinharemos": "esquadrinhar",
    "esquadrinhares": "esquadrinhar",
    "esquadrinharia": "esquadrinhar",
    "esquadrinhariam": "esquadrinhar",
    "esquadrinharias": "esquadrinhar",
    "esquadrinharmo": "esquadrinhar",
    "esquadrinharmos": "esquadrinhar",
    "esquadrinhará": "esquadrinhar",
    "esquadrinharás": "esquadrinhar",
    "esquadrinharão": "esquadrinhar",
    "esquadrinharíamos": "esquadrinhar",
    "esquadrinharíeis": "esquadrinhar",
    "esquadrinhas": "esquadrinhar",
    "esquadrinhasse": "esquadrinhar",
    "esquadrinhassem": "esquadrinhar",
    "esquadrinhasses": "esquadrinhar",
    "esquadrinhaste": "esquadrinhar",
    "esquadrinhastes": "esquadrinhar",
    "esquadrinhava": "esquadrinhar",
    "esquadrinhavam": "esquadrinhar",
    "esquadrinhavas": "esquadrinhar",
    "esquadrinhe": "esquadrinhar",
    "esquadrinhei": "esquadrinhar",
    "esquadrinheis": "esquadrinhar",
    "esquadrinhem": "esquadrinhar",
    "esquadrinhemo": "esquadrinhar",
    "esquadrinhemos": "esquadrinhar",
    "esquadrinhes": "esquadrinhar",
    "esquadrinho": "esquadrinhar",
    "esquadrinhou": "esquadrinhar",
    "esquadrinhá": "esquadrinhar",
    "esquadrinhámo": "esquadrinhar",
    "esquadrinhámos": "esquadrinhar",
    "esquadrinháramo": "esquadrinhar",
    "esquadrinháramos": "esquadrinhar",
    "esquadrinhárei": "esquadrinhar",
    "esquadrinháreis": "esquadrinhar",
    "esquadrinhásseis": "esquadrinhar",
    "esquadrinhássemos": "esquadrinhar",
    "esquadrinhávamo": "esquadrinhar",
    "esquadrinhávamos": "esquadrinhar",
    "esquadrinhávei": "esquadrinhar",
    "esquadrinháveis": "esquadrinhar",
    "esquadrio": "esquadriar",
    "esquadriou": "esquadriar",
    "esquadriá": "esquadriar",
    "esquadriámo": "esquadriar",
    "esquadriámos": "esquadriar",
    "esquadriáramo": "esquadriar",
    "esquadriáramos": "esquadriar",
    "esquadriárei": "esquadriar",
    "esquadriáreis": "esquadriar",
    "esquadriásseis": "esquadriar",
    "esquadriássemos": "esquadriar",
    "esquadriávamo": "esquadriar",
    "esquadriávamos": "esquadriar",
    "esquadriávei": "esquadriar",
    "esquadriáveis": "esquadriar",
    "esquadro": "esquadrar",
    "esquadrona": "esquadronar",
    "esquadronada": "esquadronar",
    "esquadronadas": "esquadronar",
    "esquadronado": "esquadronar",
    "esquadronados": "esquadronar",
    "esquadronai": "esquadronar",
    "esquadronais": "esquadronar",
    "esquadronam": "esquadronar",
    "esquadronamo": "esquadronar",
    "esquadronamos": "esquadronar",
    "esquadronando": "esquadronar",
    "esquadronara": "esquadronar",
    "esquadronaram": "esquadronar",
    "esquadronaras": "esquadronar",
    "esquadronarde": "esquadronar",
    "esquadronardes": "esquadronar",
    "esquadronare": "esquadronar",
    "esquadronarei": "esquadronar",
    "esquadronareis": "esquadronar",
    "esquadronarem": "esquadronar",
    "esquadronaremos": "esquadronar",
    "esquadronares": "esquadronar",
    "esquadronaria": "esquadronar",
    "esquadronariam": "esquadronar",
    "esquadronarias": "esquadronar",
    "esquadronarmo": "esquadronar",
    "esquadronarmos": "esquadronar",
    "esquadronará": "esquadronar",
    "esquadronarás": "esquadronar",
    "esquadronarão": "esquadronar",
    "esquadronaríamos": "esquadronar",
    "esquadronaríeis": "esquadronar",
    "esquadronas": "esquadronar",
    "esquadronasse": "esquadronar",
    "esquadronassem": "esquadronar",
    "esquadronasses": "esquadronar",
    "esquadronaste": "esquadronar",
    "esquadronastes": "esquadronar",
    "esquadronava": "esquadronar",
    "esquadronavam": "esquadronar",
    "esquadronavas": "esquadronar",
    "esquadrone": "esquadronar",
    "esquadronei": "esquadronar",
    "esquadroneis": "esquadronar",
    "esquadronem": "esquadronar",
    "esquadronemo": "esquadronar",
    "esquadronemos": "esquadronar",
    "esquadrones": "esquadronar",
    "esquadrono": "esquadronar",
    "esquadronou": "esquadronar",
    "esquadroná": "esquadronar",
    "esquadronámo": "esquadronar",
    "esquadronámos": "esquadronar",
    "esquadronáramo": "esquadronar",
    "esquadronáramos": "esquadronar",
    "esquadronárei": "esquadronar",
    "esquadronáreis": "esquadronar",
    "esquadronásseis": "esquadronar",
    "esquadronássemos": "esquadronar",
    "esquadronávamo": "esquadronar",
    "esquadronávamos": "esquadronar",
    "esquadronávei": "esquadronar",
    "esquadronáveis": "esquadronar",
    "esquadros": "esquadro",
    "esquadrou": "esquadrar",
    "esquadrá": "esquadrar",
    "esquadrámo": "esquadrar",
    "esquadrámos": "esquadrar",
    "esquadráramo": "esquadrar",
    "esquadráramos": "esquadrar",
    "esquadrárei": "esquadrar",
    "esquadráreis": "esquadrar",
    "esquadrásseis": "esquadrar",
    "esquadrássemos": "esquadrar",
    "esquadrávamo": "esquadrar",
    "esquadrávamos": "esquadrar",
    "esquadrávei": "esquadrar",
    "esquadráveis": "esquadrar",
    "esquadrões": "esquadrão",
    "esqualores": "esqualor",
    "esqualos": "esqualo",
    "esqualídeos": "esqualídeo",
    "esquarrosa": "esquarroso",
    "esquarrosas": "esquarroso",
    "esquarrosos": "esquarroso",
    "esquarteja": "esquartejar",
    "esquartejada": "esquartejar",
    "esquartejadas": "esquartejar",
    "esquartejado": "esquartejar",
    "esquartejados": "esquartejar",
    "esquartejai": "esquartejar",
    "esquartejais": "esquartejar",
    "esquartejam": "esquartejar",
    "esquartejamentos": "esquartejamento",
    "esquartejamo": "esquartejar",
    "esquartejamos": "esquartejar",
    "esquartejando": "esquartejar",
    "esquartejara": "esquartejar",
    "esquartejaram": "esquartejar",
    "esquartejaras": "esquartejar",
    "esquartejarde": "esquartejar",
    "esquartejardes": "esquartejar",
    "esquartejare": "esquartejar",
    "esquartejarei": "esquartejar",
    "esquartejareis": "esquartejar",
    "esquartejarem": "esquartejar",
    "esquartejaremos": "esquartejar",
    "esquartejares": "esquartejar",
    "esquartejaria": "esquartejar",
    "esquartejariam": "esquartejar",
    "esquartejarias": "esquartejar",
    "esquartejarmo": "esquartejar",
    "esquartejarmos": "esquartejar",
    "esquartejará": "esquartejar",
    "esquartejarás": "esquartejar",
    "esquartejarão": "esquartejar",
    "esquartejaríamos": "esquartejar",
    "esquartejaríeis": "esquartejar",
    "esquartejas": "esquartejar",
    "esquartejasse": "esquartejar",
    "esquartejassem": "esquartejar",
    "esquartejasses": "esquartejar",
    "esquartejaste": "esquartejar",
    "esquartejastes": "esquartejar",
    "esquartejava": "esquartejar",
    "esquartejavam": "esquartejar",
    "esquartejavas": "esquartejar",
    "esquarteje": "esquartejar",
    "esquartejei": "esquartejar",
    "esquartejeis": "esquartejar",
    "esquartejem": "esquartejar",
    "esquartejemo": "esquartejar",
    "esquartejemos": "esquartejar",
    "esquartejes": "esquartejar",
    "esquartejo": "esquartejar",
    "esquartejou": "esquartejar",
    "esquartejá": "esquartejar",
    "esquartejámo": "esquartejar",
    "esquartejámos": "esquartejar",
    "esquartejáramo": "esquartejar",
    "esquartejáramos": "esquartejar",
    "esquartejárei": "esquartejar",
    "esquartejáreis": "esquartejar",
    "esquartejásseis": "esquartejar",
    "esquartejássemos": "esquartejar",
    "esquartejávamo": "esquartejar",
    "esquartejávamos": "esquartejar",
    "esquartejávei": "esquartejar",
    "esquartejáveis": "esquartejar",
    "esquartela": "esquartelar",
    "esquartelada": "esquartelar",
    "esquarteladas": "esquartelar",
    "esquartelado": "esquartelar",
    "esquartelados": "esquartelar",
    "esquarteladuras": "esquarteladura",
    "esquartelai": "esquartelar",
    "esquartelais": "esquartelar",
    "esquartelam": "esquartelar",
    "esquartelamo": "esquartelar",
    "esquartelamos": "esquartelar",
    "esquartelando": "esquartelar",
    "esquartelara": "esquartelar",
    "esquartelaram": "esquartelar",
    "esquartelaras": "esquartelar",
    "esquartelarde": "esquartelar",
    "esquartelardes": "esquartelar",
    "esquartelare": "esquartelar",
    "esquartelarei": "esquartelar",
    "esquartelareis": "esquartelar",
    "esquartelarem": "esquartelar",
    "esquartelaremos": "esquartelar",
    "esquartelares": "esquartelar",
    "esquartelaria": "esquartelar",
    "esquartelariam": "esquartelar",
    "esquartelarias": "esquartelar",
    "esquartelarmo": "esquartelar",
    "esquartelarmos": "esquartelar",
    "esquartelará": "esquartelar",
    "esquartelarás": "esquartelar",
    "esquartelarão": "esquartelar",
    "esquartelaríamos": "esquartelar",
    "esquartelaríeis": "esquartelar",
    "esquartelas": "esquartelar",
    "esquartelasse": "esquartelar",
    "esquartelassem": "esquartelar",
    "esquartelasses": "esquartelar",
    "esquartelaste": "esquartelar",
    "esquartelastes": "esquartelar",
    "esquartelava": "esquartelar",
    "esquartelavam": "esquartelar",
    "esquartelavas": "esquartelar",
    "esquartele": "esquartelar",
    "esquartelei": "esquartelar",
    "esquarteleis": "esquartelar",
    "esquartelem": "esquartelar",
    "esquartelemo": "esquartelar",
    "esquartelemos": "esquartelar",
    "esquarteles": "esquartelar",
    "esquartelo": "esquartelar",
    "esquartelou": "esquartelar",
    "esquartelá": "esquartelar",
    "esquartelámo": "esquartelar",
    "esquartelámos": "esquartelar",
    "esquarteláramo": "esquartelar",
    "esquarteláramos": "esquartelar",
    "esquartelárei": "esquartelar",
    "esquarteláreis": "esquartelar",
    "esquartelásseis": "esquartelar",
    "esquartelássemos": "esquartelar",
    "esquartelávamo": "esquartelar",
    "esquartelávamos": "esquartelar",
    "esquartelávei": "esquartelar",
    "esquarteláveis": "esquartelar",
    "esquartilha": "esquartilhar",
    "esquartilhada": "esquartilhar",
    "esquartilhadas": "esquartilhar",
    "esquartilhado": "esquartilhar",
    "esquartilhados": "esquartilhar",
    "esquartilhai": "esquartilhar",
    "esquartilhais": "esquartilhar",
    "esquartilham": "esquartilhar",
    "esquartilhamentos": "esquartilhamento",
    "esquartilhamo": "esquartilhar",
    "esquartilhamos": "esquartilhar",
    "esquartilhando": "esquartilhar",
    "esquartilhara": "esquartilhar",
    "esquartilharam": "esquartilhar",
    "esquartilharas": "esquartilhar",
    "esquartilharde": "esquartilhar",
    "esquartilhardes": "esquartilhar",
    "esquartilhare": "esquartilhar",
    "esquartilharei": "esquartilhar",
    "esquartilhareis": "esquartilhar",
    "esquartilharem": "esquartilhar",
    "esquartilharemos": "esquartilhar",
    "esquartilhares": "esquartilhar",
    "esquartilharia": "esquartilhar",
    "esquartilhariam": "esquartilhar",
    "esquartilharias": "esquartilhar",
    "esquartilharmo": "esquartilhar",
    "esquartilharmos": "esquartilhar",
    "esquartilhará": "esquartilhar",
    "esquartilharás": "esquartilhar",
    "esquartilharão": "esquartilhar",
    "esquartilharíamos": "esquartilhar",
    "esquartilharíeis": "esquartilhar",
    "esquartilhas": "esquartilhar",
    "esquartilhasse": "esquartilhar",
    "esquartilhassem": "esquartilhar",
    "esquartilhasses": "esquartilhar",
    "esquartilhaste": "esquartilhar",
    "esquartilhastes": "esquartilhar",
    "esquartilhava": "esquartilhar",
    "esquartilhavam": "esquartilhar",
    "esquartilhavas": "esquartilhar",
    "esquartilhe": "esquartilhar",
    "esquartilhei": "esquartilhar",
    "esquartilheis": "esquartilhar",
    "esquartilhem": "esquartilhar",
    "esquartilhemo": "esquartilhar",
    "esquartilhemos": "esquartilhar",
    "esquartilhes": "esquartilhar",
    "esquartilho": "esquartilhar",
    "esquartilhou": "esquartilhar",
    "esquartilhá": "esquartilhar",
    "esquartilhámo": "esquartilhar",
    "esquartilhámos": "esquartilhar",
    "esquartilháramo": "esquartilhar",
    "esquartilháramos": "esquartilhar",
    "esquartilhárei": "esquartilhar",
    "esquartilháreis": "esquartilhar",
    "esquartilhásseis": "esquartilhar",
    "esquartilhássemos": "esquartilhar",
    "esquartilhávamo": "esquartilhar",
    "esquartilhávamos": "esquartilhar",
    "esquartilhávei": "esquartilhar",
    "esquartilháveis": "esquartilhar",
    "esquece": "esquecer",
    "esquecediça": "esquecediço",
    "esquecediças": "esquecediço",
    "esquecediços": "esquecediço",
    "esquecedora": "esquecedor",
    "esquecedoras": "esquecedor",
    "esquecedores": "esquecedor",
    "esquecei": "esquecer",
    "esqueceis": "esquecer",
    "esquecem": "esquecer",
    "esquecemo": "esquecer",
    "esquecemos": "esquecer",
    "esquecendo": "esquecer",
    "esquecera": "esquecer",
    "esqueceram": "esquecer",
    "esqueceras": "esquecer",
    "esquecerde": "esquecer",
    "esquecerdes": "esquecer",
    "esquecere": "esquecer",
    "esquecerei": "esquecer",
    "esquecereis": "esquecer",
    "esquecerem": "esquecer",
    "esqueceremos": "esquecer",
    "esqueceres": "esquecer",
    "esqueceria": "esquecer",
    "esqueceriam": "esquecer",
    "esquecerias": "esquecer",
    "esquecermo": "esquecer",
    "esquecermos": "esquecer",
    "esquecerá": "esquecer",
    "esquecerás": "esquecer",
    "esquecerão": "esquecer",
    "esqueceríamos": "esquecer",
    "esqueceríeis": "esquecer",
    "esqueces": "esquecer",
    "esquecesse": "esquecer",
    "esquecessem": "esquecer",
    "esquecesses": "esquecer",
    "esqueceste": "esquecer",
    "esquecestes": "esquecer",
    "esqueceu": "esquecer",
    "esqueci": "esquecer",
    "esquecia": "esquecer",
    "esqueciam": "esquecer",
    "esquecias": "esquecer",
    "esquecida": "esquecido",
    "esquecidas": "esquecido",
    "esquecido": "esquecer",
    "esquecidos": "esquecido",
    "esquecimentos": "esquecimento",
    "esquecê": "esquecer",
    "esquecêramo": "esquecer",
    "esquecêramos": "esquecer",
    "esquecêrei": "esquecer",
    "esquecêreis": "esquecer",
    "esquecêsseis": "esquecer",
    "esquecêssemos": "esquecer",
    "esquecíamo": "esquecer",
    "esquecíamos": "esquecer",
    "esquecíei": "esquecer",
    "esquecíeis": "esquecer",
    "esqueletos": "esqueleto",
    "esquelética": "esquelético",
    "esqueléticas": "esquelético",
    "esqueléticos": "esquelético",
    "esquemas": "esquema",
    "esquematismos": "esquematismo",
    "esquematiza": "esquematizar",
    "esquematizada": "esquematizar",
    "esquematizadas": "esquematizar",
    "esquematizado": "esquematizar",
    "esquematizados": "esquematizar",
    "esquematizai": "esquematizar",
    "esquematizais": "esquematizar",
    "esquematizam": "esquematizar",
    "esquematizamo": "esquematizar",
    "esquematizamos": "esquematizar",
    "esquematizando": "esquematizar",
    "esquematizara": "esquematizar",
    "esquematizaram": "esquematizar",
    "esquematizaras": "esquematizar",
    "esquematizarde": "esquematizar",
    "esquematizardes": "esquematizar",
    "esquematizare": "esquematizar",
    "esquematizarei": "esquematizar",
    "esquematizareis": "esquematizar",
    "esquematizarem": "esquematizar",
    "esquematizaremos": "esquematizar",
    "esquematizares": "esquematizar",
    "esquematizaria": "esquematizar",
    "esquematizariam": "esquematizar",
    "esquematizarias": "esquematizar",
    "esquematizarmo": "esquematizar",
    "esquematizarmos": "esquematizar",
    "esquematizará": "esquematizar",
    "esquematizarás": "esquematizar",
    "esquematizarão": "esquematizar",
    "esquematizaríamos": "esquematizar",
    "esquematizaríeis": "esquematizar",
    "esquematizas": "esquematizar",
    "esquematizasse": "esquematizar",
    "esquematizassem": "esquematizar",
    "esquematizasses": "esquematizar",
    "esquematizaste": "esquematizar",
    "esquematizastes": "esquematizar",
    "esquematizava": "esquematizar",
    "esquematizavam": "esquematizar",
    "esquematizavas": "esquematizar",
    "esquematizações": "esquematização",
    "esquematize": "esquematizar",
    "esquematizei": "esquematizar",
    "esquematizeis": "esquematizar",
    "esquematizem": "esquematizar",
    "esquematizemo": "esquematizar",
    "esquematizemos": "esquematizar",
    "esquematizes": "esquematizar",
    "esquematizo": "esquematizar",
    "esquematizou": "esquematizar",
    "esquematizá": "esquematizar",
    "esquematizámo": "esquematizar",
    "esquematizámos": "esquematizar",
    "esquematizáramo": "esquematizar",
    "esquematizáramos": "esquematizar",
    "esquematizárei": "esquematizar",
    "esquematizáreis": "esquematizar",
    "esquematizásseis": "esquematizar",
    "esquematizássemos": "esquematizar",
    "esquematizávamo": "esquematizar",
    "esquematizávamos": "esquematizar",
    "esquematizávei": "esquematizar",
    "esquematizáveis": "esquematizável",
    "esquemática": "esquemático",
    "esquemáticas": "esquemático",
    "esquemáticos": "esquemático",
    "esquenta": "esquentar",
    "esquentada": "esquentar",
    "esquentadas": "esquentar",
    "esquentadiça": "esquentadiço",
    "esquentadiças": "esquentadiço",
    "esquentadiços": "esquentadiço",
    "esquentado": "esquentar",
    "esquentadores": "esquentador",
    "esquentados": "esquentar",
    "esquentai": "esquentar",
    "esquentais": "esquentar",
    "esquentam": "esquentar",
    "esquentamentos": "esquentamento",
    "esquentamo": "esquentar",
    "esquentamos": "esquentar",
    "esquentando": "esquentar",
    "esquentara": "esquentar",
    "esquentaram": "esquentar",
    "esquentaras": "esquentar",
    "esquentarde": "esquentar",
    "esquentardes": "esquentar",
    "esquentare": "esquentar",
    "esquentarei": "esquentar",
    "esquentareis": "esquentar",
    "esquentarem": "esquentar",
    "esquentaremos": "esquentar",
    "esquentares": "esquentar",
    "esquentaria": "esquentar",
    "esquentariam": "esquentar",
    "esquentarias": "esquentar",
    "esquentarmo": "esquentar",
    "esquentarmos": "esquentar",
    "esquentará": "esquentar",
    "esquentarás": "esquentar",
    "esquentarão": "esquentar",
    "esquentaríamos": "esquentar",
    "esquentaríeis": "esquentar",
    "esquentas": "esquentar",
    "esquentasse": "esquentar",
    "esquentassem": "esquentar",
    "esquentasses": "esquentar",
    "esquentaste": "esquentar",
    "esquentastes": "esquentar",
    "esquentava": "esquentar",
    "esquentavam": "esquentar",
    "esquentavas": "esquentar",
    "esquentações": "esquentação",
    "esquente": "esquentar",
    "esquentei": "esquentar",
    "esquenteis": "esquentar",
    "esquentem": "esquentar",
    "esquentemo": "esquentar",
    "esquentemos": "esquentar",
    "esquentes": "esquentar",
    "esquento": "esquentar",
    "esquentou": "esquentar",
    "esquentá": "esquentar",
    "esquentámo": "esquentar",
    "esquentámos": "esquentar",
    "esquentáramo": "esquentar",
    "esquentáramos": "esquentar",
    "esquentárei": "esquentar",
    "esquentáreis": "esquentar",
    "esquentásseis": "esquentar",
    "esquentássemos": "esquentar",
    "esquentávamo": "esquentar",
    "esquentávamos": "esquentar",
    "esquentávei": "esquentar",
    "esquentáveis": "esquentar",
    "esquerda": "esquerdo",
    "esquerdada": "esquerdar",
    "esquerdadas": "esquerdar",
    "esquerdado": "esquerdar",
    "esquerdados": "esquerdar",
    "esquerdai": "esquerdar",
    "esquerdais": "esquerdar",
    "esquerdalhadas": "esquerdalhada",
    "esquerdam": "esquerdar",
    "esquerdamo": "esquerdar",
    "esquerdamos": "esquerdar",
    "esquerdando": "esquerdar",
    "esquerdara": "esquerdar",
    "esquerdaram": "esquerdar",
    "esquerdaras": "esquerdar",
    "esquerdarde": "esquerdar",
    "esquerdardes": "esquerdar",
    "esquerdare": "esquerdar",
    "esquerdarei": "esquerdar",
    "esquerdareis": "esquerdar",
    "esquerdarem": "esquerdar",
    "esquerdaremos": "esquerdar",
    "esquerdares": "esquerdar",
    "esquerdaria": "esquerdar",
    "esquerdariam": "esquerdar",
    "esquerdarias": "esquerdar",
    "esquerdarmo": "esquerdar",
    "esquerdarmos": "esquerdar",
    "esquerdará": "esquerdar",
    "esquerdarás": "esquerdar",
    "esquerdarão": "esquerdar",
    "esquerdaríamos": "esquerdar",
    "esquerdaríeis": "esquerdar",
    "esquerdas": "esquerdo",
    "esquerdasse": "esquerdar",
    "esquerdassem": "esquerdar",
    "esquerdasses": "esquerdar",
    "esquerdaste": "esquerdar",
    "esquerdastes": "esquerdar",
    "esquerdava": "esquerdar",
    "esquerdavam": "esquerdar",
    "esquerdavas": "esquerdar",
    "esquerde": "esquerdar",
    "esquerdeada": "esquerdear",
    "esquerdeadas": "esquerdear",
    "esquerdeado": "esquerdear",
    "esquerdeados": "esquerdear",
    "esquerdeai": "esquerdear",
    "esquerdeais": "esquerdear",
    "esquerdeamo": "esquerdear",
    "esquerdeamos": "esquerdear",
    "esquerdeando": "esquerdear",
    "esquerdeara": "esquerdear",
    "esquerdearam": "esquerdear",
    "esquerdearas": "esquerdear",
    "esquerdearde": "esquerdear",
    "esquerdeardes": "esquerdear",
    "esquerdeare": "esquerdear",
    "esquerdearei": "esquerdear",
    "esquerdeareis": "esquerdear",
    "esquerdearem": "esquerdear",
    "esquerdearemos": "esquerdear",
    "esquerdeares": "esquerdear",
    "esquerdearia": "esquerdear",
    "esquerdeariam": "esquerdear",
    "esquerdearias": "esquerdear",
    "esquerdearmo": "esquerdear",
    "esquerdearmos": "esquerdear",
    "esquerdeará": "esquerdear",
    "esquerdearás": "esquerdear",
    "esquerdearão": "esquerdear",
    "esquerdearíamos": "esquerdear",
    "esquerdearíeis": "esquerdear",
    "esquerdeasse": "esquerdear",
    "esquerdeassem": "esquerdear",
    "esquerdeasses": "esquerdear",
    "esquerdeaste": "esquerdear",
    "esquerdeastes": "esquerdear",
    "esquerdeava": "esquerdear",
    "esquerdeavam": "esquerdear",
    "esquerdeavas": "esquerdear",
    "esquerdeei": "esquerdear",
    "esquerdeeis": "esquerdear",
    "esquerdeemo": "esquerdear",
    "esquerdeemos": "esquerdear",
    "esquerdei": "esquerdar",
    "esquerdeia": "esquerdear",
    "esquerdeiam": "esquerdear",
    "esquerdeias": "esquerdear",
    "esquerdeie": "esquerdear",
    "esquerdeiem": "esquerdear",
    "esquerdeies": "esquerdear",
    "esquerdeio": "esquerdear",
    "esquerdeis": "esquerdar",
    "esquerdem": "esquerdar",
    "esquerdemo": "esquerdar",
    "esquerdemos": "esquerdar",
    "esquerdeou": "esquerdear",
    "esquerdes": "esquerdar",
    "esquerdeá": "esquerdear",
    "esquerdeámo": "esquerdear",
    "esquerdeámos": "esquerdear",
    "esquerdeáramo": "esquerdear",
    "esquerdeáramos": "esquerdear",
    "esquerdeárei": "esquerdear",
    "esquerdeáreis": "esquerdear",
    "esquerdeásseis": "esquerdear",
    "esquerdeássemos": "esquerdear",
    "esquerdeávamo": "esquerdear",
    "esquerdeávamos": "esquerdear",
    "esquerdeávei": "esquerdear",
    "esquerdeáveis": "esquerdear",
    "esquerdina": "esquerdino",
    "esquerdinas": "esquerdino",
    "esquerdinos": "esquerdino",
    "esquerdismos": "esquerdismo",
    "esquerdistas": "esquerdista",
    "esquerdo": "esquerdar",
    "esquerdos": "esquerdo",
    "esquerdou": "esquerdar",
    "esquerdá": "esquerdar",
    "esquerdámo": "esquerdar",
    "esquerdámos": "esquerdar",
    "esquerdáramo": "esquerdar",
    "esquerdáramos": "esquerdar",
    "esquerdárei": "esquerdar",
    "esquerdáreis": "esquerdar",
    "esquerdásseis": "esquerdar",
    "esquerdássemos": "esquerdar",
    "esquerdávamo": "esquerdar",
    "esquerdávamos": "esquerdar",
    "esquerdávei": "esquerdar",
    "esquerdáveis": "esquerdar",
    "esqueça": "esquecer",
    "esqueçais": "esquecer",
    "esqueçam": "esquecer",
    "esqueçamo": "esquecer",
    "esqueçamos": "esquecer",
    "esqueças": "esquecer",
    "esqueço": "esquecer",
    "esquia": "esquiar",
    "esquiada": "esquiar",
    "esquiadas": "esquiar",
    "esquiado": "esquiar",
    "esquiadora": "esquiador",
    "esquiadoras": "esquiador",
    "esquiadores": "esquiador",
    "esquiados": "esquiar",
    "esquiai": "esquiar",
    "esquiais": "esquiar",
    "esquiam": "esquiar",
    "esquiamo": "esquiar",
    "esquiamos": "esquiar",
    "esquiando": "esquiar",
    "esquiara": "esquiar",
    "esquiaram": "esquiar",
    "esquiaras": "esquiar",
    "esquiardes": "esquiar",
    "esquiarei": "esquiar",
    "esquiareis": "esquiar",
    "esquiarem": "esquiar",
    "esquiaremos": "esquiar",
    "esquiares": "esquiar",
    "esquiaria": "esquiar",
    "esquiariam": "esquiar",
    "esquiarias": "esquiar",
    "esquiarmo": "esquiar",
    "esquiarmos": "esquiar",
    "esquiará": "esquiar",
    "esquiarás": "esquiar",
    "esquiarão": "esquiar",
    "esquiaríamos": "esquiar",
    "esquiaríeis": "esquiar",
    "esquias": "esquiar",
    "esquiasse": "esquiar",
    "esquiassem": "esquiar",
    "esquiasses": "esquiar",
    "esquiaste": "esquiar",
    "esquiastes": "esquiar",
    "esquiava": "esquiar",
    "esquiavam": "esquiar",
    "esquiavas": "esquiar",
    "esquice": "esquiçar",
    "esquicei": "esquiçar",
    "esquiceis": "esquiçar",
    "esquicem": "esquiçar",
    "esquicemo": "esquiçar",
    "esquicemos": "esquiçar",
    "esquices": "esquiçar",
    "esquidiana": "esquidiano",
    "esquidianas": "esquidiano",
    "esquidianos": "esquidiano",
    "esquie": "esquiar",
    "esquiei": "esquiar",
    "esquieis": "esquiar",
    "esquiem": "esquiar",
    "esquiemo": "esquiar",
    "esquiemos": "esquiar",
    "esquies": "esquiar",
    "esquifa": "esquifar",
    "esquifada": "esquifar",
    "esquifadas": "esquifar",
    "esquifado": "esquifar",
    "esquifados": "esquifar",
    "esquifai": "esquifar",
    "esquifais": "esquifar",
    "esquifam": "esquifar",
    "esquifamo": "esquifar",
    "esquifamos": "esquifar",
    "esquifando": "esquifar",
    "esquifara": "esquifar",
    "esquifaram": "esquifar",
    "esquifaras": "esquifar",
    "esquifardes": "esquifar",
    "esquifarei": "esquifar",
    "esquifareis": "esquifar",
    "esquifarem": "esquifar",
    "esquifaremos": "esquifar",
    "esquifares": "esquifar",
    "esquifaria": "esquifar",
    "esquifariam": "esquifar",
    "esquifarias": "esquifar",
    "esquifarmo": "esquifar",
    "esquifarmos": "esquifar",
    "esquifará": "esquifar",
    "esquifarás": "esquifar",
    "esquifarão": "esquifar",
    "esquifaríamos": "esquifar",
    "esquifaríeis": "esquifar",
    "esquifas": "esquifar",
    "esquifasse": "esquifar",
    "esquifassem": "esquifar",
    "esquifasses": "esquifar",
    "esquifaste": "esquifar",
    "esquifastes": "esquifar",
    "esquifava": "esquifar",
    "esquifavam": "esquifar",
    "esquifavas": "esquifar",
    "esquife": "esquifar",
    "esquifei": "esquifar",
    "esquifeis": "esquifar",
    "esquifem": "esquifar",
    "esquifemo": "esquifar",
    "esquifemos": "esquifar",
    "esquifes": "esquife",
    "esquifo": "esquifar",
    "esquifou": "esquifar",
    "esquifámo": "esquifar",
    "esquifámos": "esquifar",
    "esquifáramo": "esquifar",
    "esquifáramos": "esquifar",
    "esquifáreis": "esquifar",
    "esquifásseis": "esquifar",
    "esquifássemos": "esquifar",
    "esquifávamo": "esquifar",
    "esquifávamos": "esquifar",
    "esquifáveis": "esquifar",
    "esquila": "esquilar",
    "esquilada": "esquilar",
    "esquiladas": "esquilar",
    "esquilado": "esquilar",
    "esquilados": "esquilar",
    "esquilai": "esquilar",
    "esquilais": "esquilar",
    "esquilam": "esquilar",
    "esquilamo": "esquilar",
    "esquilamos": "esquilar",
    "esquilando": "esquilar",
    "esquilara": "esquilar",
    "esquilaram": "esquilar",
    "esquilaras": "esquilar",
    "esquilarde": "esquilar",
    "esquilardes": "esquilar",
    "esquilare": "esquilar",
    "esquilarei": "esquilar",
    "esquilareis": "esquilar",
    "esquilarem": "esquilar",
    "esquilaremos": "esquilar",
    "esquilares": "esquilar",
    "esquilaria": "esquilar",
    "esquilariam": "esquilar",
    "esquilarias": "esquilar",
    "esquilarmo": "esquilar",
    "esquilarmos": "esquilar",
    "esquilará": "esquilar",
    "esquilarás": "esquilar",
    "esquilarão": "esquilar",
    "esquilaríamos": "esquilar",
    "esquilaríeis": "esquilar",
    "esquilas": "esquilar",
    "esquilasse": "esquilar",
    "esquilassem": "esquilar",
    "esquilasses": "esquilar",
    "esquilaste": "esquilar",
    "esquilastes": "esquilar",
    "esquilava": "esquilar",
    "esquilavam": "esquilar",
    "esquilavas": "esquilar",
    "esquile": "esquilar",
    "esquilei": "esquilar",
    "esquileis": "esquilar",
    "esquilem": "esquilar",
    "esquilemo": "esquilar",
    "esquilemos": "esquilar",
    "esquiles": "esquilar",
    "esquilo": "esquilar",
    "esquilos": "esquilo",
    "esquilou": "esquilar",
    "esquilá": "esquilar",
    "esquilámo": "esquilar",
    "esquilámos": "esquilar",
    "esquiláramo": "esquilar",
    "esquiláramos": "esquilar",
    "esquilárei": "esquilar",
    "esquiláreis": "esquilar",
    "esquilásseis": "esquilar",
    "esquilássemos": "esquilar",
    "esquilávamo": "esquilar",
    "esquilávamos": "esquilar",
    "esquilávei": "esquilar",
    "esquiláveis": "esquilar",
    "esquimós": "esquimó",
    "esquina": "esquinar",
    "esquinada": "esquinar",
    "esquinadas": "esquinar",
    "esquinado": "esquinar",
    "esquinados": "esquinar",
    "esquinai": "esquinar",
    "esquinais": "esquinar",
    "esquinam": "esquinar",
    "esquinamo": "esquinar",
    "esquinamos": "esquinar",
    "esquinando": "esquinar",
    "esquinantes": "esquinante",
    "esquinara": "esquinar",
    "esquinaram": "esquinar",
    "esquinaras": "esquinar",
    "esquinarde": "esquinar",
    "esquinardes": "esquinar",
    "esquinare": "esquinar",
    "esquinarei": "esquinar",
    "esquinareis": "esquinar",
    "esquinarem": "esquinar",
    "esquinaremos": "esquinar",
    "esquinares": "esquinar",
    "esquinaria": "esquinar",
    "esquinariam": "esquinar",
    "esquinarias": "esquinar",
    "esquinarmo": "esquinar",
    "esquinarmos": "esquinar",
    "esquinará": "esquinar",
    "esquinarás": "esquinar",
    "esquinarão": "esquinar",
    "esquinaríamos": "esquinar",
    "esquinaríeis": "esquinar",
    "esquinas": "esquinar",
    "esquinasse": "esquinar",
    "esquinassem": "esquinar",
    "esquinasses": "esquinar",
    "esquinaste": "esquinar",
    "esquinastes": "esquinar",
    "esquinava": "esquinar",
    "esquinavam": "esquinar",
    "esquinavas": "esquinar",
    "esquine": "esquinar",
    "esquinei": "esquinar",
    "esquineis": "esquinar",
    "esquinem": "esquinar",
    "esquinemo": "esquinar",
    "esquinemos": "esquinar",
    "esquines": "esquinar",
    "esquino": "esquinar",
    "esquinotes": "esquinote",
    "esquinou": "esquinar",
    "esquiná": "esquinar",
    "esquinámo": "esquinar",
    "esquinámos": "esquinar",
    "esquináramo": "esquinar",
    "esquináramos": "esquinar",
    "esquinárei": "esquinar",
    "esquináreis": "esquinar",
    "esquinásseis": "esquinar",
    "esquinássemos": "esquinar",
    "esquinávamo": "esquinar",
    "esquinávamos": "esquinar",
    "esquinávei": "esquinar",
    "esquináveis": "esquinar",
    "esquinências": "esquinência",
    "esquio": "esquiar",
    "esquiou": "esquiar",
    "esquipa": "esquipar",
    "esquipada": "esquipar",
    "esquipadas": "esquipar",
    "esquipado": "esquipar",
    "esquipadora": "esquipador",
    "esquipadoras": "esquipador",
    "esquipadores": "esquipador",
    "esquipados": "esquipar",
    "esquipai": "esquipar",
    "esquipais": "esquipar",
    "esquipam": "esquipar",
    "esquipamentos": "esquipamento",
    "esquipamo": "esquipar",
    "esquipamos": "esquipar",
    "esquipando": "esquipar",
    "esquipara": "esquipar",
    "esquiparam": "esquipar",
    "esquiparas": "esquipar",
    "esquiparde": "esquipar",
    "esquipardes": "esquipar",
    "esquipare": "esquipar",
    "esquiparei": "esquipar",
    "esquipareis": "esquipar",
    "esquiparem": "esquipar",
    "esquiparemos": "esquipar",
    "esquipares": "esquipar",
    "esquiparia": "esquipar",
    "esquipariam": "esquipar",
    "esquiparias": "esquipar",
    "esquiparmo": "esquipar",
    "esquiparmos": "esquipar",
    "esquipará": "esquipar",
    "esquiparás": "esquipar",
    "esquiparão": "esquipar",
    "esquiparíamos": "esquipar",
    "esquiparíeis": "esquipar",
    "esquipas": "esquipar",
    "esquipasse": "esquipar",
    "esquipassem": "esquipar",
    "esquipasses": "esquipar",
    "esquipaste": "esquipar",
    "esquipastes": "esquipar",
    "esquipava": "esquipar",
    "esquipavam": "esquipar",
    "esquipavas": "esquipar",
    "esquipações": "esquipação",
    "esquipe": "esquipar",
    "esquipei": "esquipar",
    "esquipeis": "esquipar",
    "esquipem": "esquipar",
    "esquipemo": "esquipar",
    "esquipemos": "esquipar",
    "esquipes": "esquipar",
    "esquipo": "esquipar",
    "esquipou": "esquipar",
    "esquipá": "esquipar",
    "esquipámo": "esquipar",
    "esquipámos": "esquipar",
    "esquipáramo": "esquipar",
    "esquipáramos": "esquipar",
    "esquipárei": "esquipar",
    "esquipáreis": "esquipar",
    "esquipásseis": "esquipar",
    "esquipássemos": "esquipar",
    "esquipávamo": "esquipar",
    "esquipávamos": "esquipar",
    "esquipávei": "esquipar",
    "esquipáveis": "esquipar",
    "esquipões": "esquipão",
    "esquirola": "esquirolar",
    "esquirolada": "esquirolar",
    "esquiroladas": "esquirolar",
    "esquirolado": "esquirolar",
    "esquirolados": "esquirolar",
    "esquirolai": "esquirolar",
    "esquirolais": "esquirolar",
    "esquirolam": "esquirolar",
    "esquirolamo": "esquirolar",
    "esquirolamos": "esquirolar",
    "esquirolando": "esquirolar",
    "esquirolara": "esquirolar",
    "esquirolaram": "esquirolar",
    "esquirolaras": "esquirolar",
    "esquirolarde": "esquirolar",
    "esquirolardes": "esquirolar",
    "esquirolare": "esquirolar",
    "esquirolarei": "esquirolar",
    "esquirolareis": "esquirolar",
    "esquirolarem": "esquirolar",
    "esquirolaremos": "esquirolar",
    "esquirolares": "esquirolar",
    "esquirolaria": "esquirolar",
    "esquirolariam": "esquirolar",
    "esquirolarias": "esquirolar",
    "esquirolarmo": "esquirolar",
    "esquirolarmos": "esquirolar",
    "esquirolará": "esquirolar",
    "esquirolarás": "esquirolar",
    "esquirolarão": "esquirolar",
    "esquirolaríamos": "esquirolar",
    "esquirolaríeis": "esquirolar",
    "esquirolas": "esquirolar",
    "esquirolasse": "esquirolar",
    "esquirolassem": "esquirolar",
    "esquirolasses": "esquirolar",
    "esquirolaste": "esquirolar",
    "esquirolastes": "esquirolar",
    "esquirolava": "esquirolar",
    "esquirolavam": "esquirolar",
    "esquirolavas": "esquirolar",
    "esquirole": "esquirolar",
    "esquirolei": "esquirolar",
    "esquiroleis": "esquirolar",
    "esquirolem": "esquirolar",
    "esquirolemo": "esquirolar",
    "esquirolemos": "esquirolar",
    "esquiroles": "esquirolar",
    "esquirolo": "esquirolar",
    "esquirolosa": "esquiroloso",
    "esquirolosas": "esquiroloso",
    "esquirolosos": "esquiroloso",
    "esquirolou": "esquirolar",
    "esquirolá": "esquirolar",
    "esquirolámo": "esquirolar",
    "esquirolámos": "esquirolar",
    "esquiroláramo": "esquirolar",
    "esquiroláramos": "esquirolar",
    "esquirolárei": "esquirolar",
    "esquiroláreis": "esquirolar",
    "esquirolásseis": "esquirolar",
    "esquirolássemos": "esquirolar",
    "esquirolávamo": "esquirolar",
    "esquirolávamos": "esquirolar",
    "esquirolávei": "esquirolar",
    "esquiroláveis": "esquirolar",
    "esquis": "esqui",
    "esquisita": "esquisito",
    "esquisitas": "esquisito",
    "esquisitices": "esquisitice",
    "esquisitona": "esquisitão",
    "esquisitonas": "esquisitão",
    "esquisitos": "esquisito",
    "esquisitória": "esquisitório",
    "esquisitórias": "esquisitório",
    "esquisitórios": "esquisitório",
    "esquisitões": "esquisitão",
    "esquisocárpica": "esquisocárpico",
    "esquisocárpicas": "esquisocárpico",
    "esquisocárpicos": "esquisocárpico",
    "esquisofrénica": "esquisofrénico",
    "esquisofrénicas": "esquisofrénico",
    "esquisofrénicos": "esquisofrénico",
    "esquisofásica": "esquisofásico",
    "esquisofásicas": "esquisofásico",
    "esquisofásicos": "esquisofásico",
    "esquisográfica": "esquisográfico",
    "esquisográficas": "esquisográfico",
    "esquisográficos": "esquisográfico",
    "esquisogónica": "esquisogónico",
    "esquisogónicas": "esquisogónico",
    "esquisogónicos": "esquisogónico",
    "esquissa": "esquissar",
    "esquissada": "esquissar",
    "esquissadas": "esquissar",
    "esquissado": "esquissar",
    "esquissados": "esquissar",
    "esquissai": "esquissar",
    "esquissais": "esquissar",
    "esquissam": "esquissar",
    "esquissamo": "esquissar",
    "esquissamos": "esquissar",
    "esquissando": "esquissar",
    "esquissara": "esquissar",
    "esquissaram": "esquissar",
    "esquissaras": "esquissar",
    "esquissarde": "esquissar",
    "esquissardes": "esquissar",
    "esquissare": "esquissar",
    "esquissarei": "esquissar",
    "esquissareis": "esquissar",
    "esquissarem": "esquissar",
    "esquissaremos": "esquissar",
    "esquissares": "esquissar",
    "esquissaria": "esquissar",
    "esquissariam": "esquissar",
    "esquissarias": "esquissar",
    "esquissarmo": "esquissar",
    "esquissarmos": "esquissar",
    "esquissará": "esquissar",
    "esquissarás": "esquissar",
    "esquissarão": "esquissar",
    "esquissaríamos": "esquissar",
    "esquissaríeis": "esquissar",
    "esquissas": "esquissar",
    "esquissasse": "esquissar",
    "esquissassem": "esquissar",
    "esquissasses": "esquissar",
    "esquissaste": "esquissar",
    "esquissastes": "esquissar",
    "esquissava": "esquissar",
    "esquissavam": "esquissar",
    "esquissavas": "esquissar",
    "esquisse": "esquissar",
    "esquissei": "esquissar",
    "esquisseis": "esquissar",
    "esquissem": "esquissar",
    "esquissemo": "esquissar",
    "esquissemos": "esquissar",
    "esquisses": "esquissar",
    "esquisso": "esquissar",
    "esquissos": "esquisso",
    "esquissou": "esquissar",
    "esquissá": "esquissar",
    "esquissámo": "esquissar",
    "esquissámos": "esquissar",
    "esquissáramo": "esquissar",
    "esquissáramos": "esquissar",
    "esquissárei": "esquissar",
    "esquissáreis": "esquissar",
    "esquissásseis": "esquissar",
    "esquissássemos": "esquissar",
    "esquissávamo": "esquissar",
    "esquissávamos": "esquissar",
    "esquissávei": "esquissar",
    "esquissáveis": "esquissar",
    "esquistocárpica": "esquistocárpico",
    "esquistocárpicas": "esquistocárpico",
    "esquistocárpicos": "esquistocárpico",
    "esquistóides": "esquistóide",
    "esquisófitas": "esquisófita",
    "esquitocarpos": "esquitocarpo",
    "esquiva": "esquivo",
    "esquivada": "esquivar",
    "esquivadas": "esquivar",
    "esquivado": "esquivar",
    "esquivados": "esquivar",
    "esquivai": "esquivar",
    "esquivais": "esquivar",
    "esquivam": "esquivar",
    "esquivamentos": "esquivamento",
    "esquivamo": "esquivar",
    "esquivamos": "esquivar",
    "esquivando": "esquivar",
    "esquivanças": "esquivança",
    "esquivara": "esquivar",
    "esquivaram": "esquivar",
    "esquivaras": "esquivar",
    "esquivarde": "esquivar",
    "esquivardes": "esquivar",
    "esquivare": "esquivar",
    "esquivarei": "esquivar",
    "esquivareis": "esquivar",
    "esquivarem": "esquivar",
    "esquivaremos": "esquivar",
    "esquivares": "esquivar",
    "esquivaria": "esquivar",
    "esquivariam": "esquivar",
    "esquivarias": "esquivar",
    "esquivarmo": "esquivar",
    "esquivarmos": "esquivar",
    "esquivará": "esquivar",
    "esquivarás": "esquivar",
    "esquivarão": "esquivar",
    "esquivaríamos": "esquivar",
    "esquivaríeis": "esquivar",
    "esquivas": "esquivo",
    "esquivasse": "esquivar",
    "esquivassem": "esquivar",
    "esquivasses": "esquivar",
    "esquivaste": "esquivar",
    "esquivastes": "esquivar",
    "esquivava": "esquivar",
    "esquivavam": "esquivar",
    "esquivavas": "esquivar",
    "esquive": "esquivar",
    "esquivei": "esquivar",
    "esquiveis": "esquivar",
    "esquivem": "esquivar",
    "esquivemo": "esquivar",
    "esquivemos": "esquivar",
    "esquives": "esquivar",
    "esquivezas": "esquiveza",
    "esquivo": "esquivar",
    "esquivos": "esquivo",
    "esquivosa": "esquivoso",
    "esquivosas": "esquivoso",
    "esquivosos": "esquivoso",
    "esquivou": "esquivar",
    "esquivá": "esquivar",
    "esquivámo": "esquivar",
    "esquivámos": "esquivar",
    "esquiváramo": "esquivar",
    "esquiváramos": "esquivar",
    "esquivárei": "esquivar",
    "esquiváreis": "esquivar",
    "esquivásseis": "esquivar",
    "esquivássemos": "esquivar",
    "esquivávamo": "esquivar",
    "esquivávamos": "esquivar",
    "esquivávei": "esquivar",
    "esquiváveis": "esquivar",
    "esquixas": "esquixa",
    "esquizocarpos": "esquizocarpo",
    "esquizofasias": "esquizofasia",
    "esquizofrenias": "esquizofrenia",
    "esquizofrénica": "esquizofrénico",
    "esquizofrénicas": "esquizofrénico",
    "esquizofrénicos": "esquizofrénico",
    "esquizogonias": "esquizogonia",
    "esquizografias": "esquizografia",
    "esquizoidias": "esquizoidia",
    "esquizomaníaca": "esquizomaníaco",
    "esquizomaníacas": "esquizomaníaco",
    "esquizomaníacos": "esquizomaníaco",
    "esquizomicetes": "esquizomicete",
    "esquizontes": "esquizonte",
    "esquizotimias": "esquizotimia",
    "esquizotímica": "esquizotímico",
    "esquizotímicas": "esquizotímico",
    "esquizotímicos": "esquizotímico",
    "esquizóides": "esquizóide",
    "esquizôntica": "esquizôntico",
    "esquizônticas": "esquizôntico",
    "esquizônticos": "esquizôntico",
    "esquiámo": "esquiar",
    "esquiámos": "esquiar",
    "esquiáramo": "esquiar",
    "esquiáramos": "esquiar",
    "esquiáreis": "esquiar",
    "esquiásseis": "esquiar",
    "esquiássemos": "esquiar",
    "esquiávamo": "esquiar",
    "esquiávamos": "esquiar",
    "esquiáveis": "esquiar",
    "esquiça": "esquiçar",
    "esquiçada": "esquiçar",
    "esquiçadas": "esquiçar",
    "esquiçado": "esquiçar",
    "esquiçados": "esquiçar",
    "esquiçai": "esquiçar",
    "esquiçais": "esquiçar",
    "esquiçam": "esquiçar",
    "esquiçamo": "esquiçar",
    "esquiçamos": "esquiçar",
    "esquiçando": "esquiçar",
    "esquiçara": "esquiçar",
    "esquiçaram": "esquiçar",
    "esquiçaras": "esquiçar",
    "esquiçarde": "esquiçar",
    "esquiçardes": "esquiçar",
    "esquiçare": "esquiçar",
    "esquiçarei": "esquiçar",
    "esquiçareis": "esquiçar",
    "esquiçarem": "esquiçar",
    "esquiçaremos": "esquiçar",
    "esquiçares": "esquiçar",
    "esquiçaria": "esquiçar",
    "esquiçariam": "esquiçar",
    "esquiçarias": "esquiçar",
    "esquiçarmo": "esquiçar",
    "esquiçarmos": "esquiçar",
    "esquiçará": "esquiçar",
    "esquiçarás": "esquiçar",
    "esquiçarão": "esquiçar",
    "esquiçaríamos": "esquiçar",
    "esquiçaríeis": "esquiçar",
    "esquiças": "esquiçar",
    "esquiçasse": "esquiçar",
    "esquiçassem": "esquiçar",
    "esquiçasses": "esquiçar",
    "esquiçaste": "esquiçar",
    "esquiçastes": "esquiçar",
    "esquiçava": "esquiçar",
    "esquiçavam": "esquiçar",
    "esquiçavas": "esquiçar",
    "esquiço": "esquiçar",
    "esquiçou": "esquiçar",
    "esquiçá": "esquiçar",
    "esquiçámo": "esquiçar",
    "esquiçámos": "esquiçar",
    "esquiçáramo": "esquiçar",
    "esquiçáramos": "esquiçar",
    "esquiçárei": "esquiçar",
    "esquiçáreis": "esquiçar",
    "esquiçásseis": "esquiçar",
    "esquiçássemos": "esquiçar",
    "esquiçávamo": "esquiçar",
    "esquiçávamos": "esquiçar",
    "esquiçávei": "esquiçar",
    "esquiçáveis": "esquiçar",
    "esquálida": "esquálido",
    "esquálidas": "esquálido",
    "esquálidos": "esquálido",
    "esquírolas": "esquírola",
    "esquística": "esquístico",
    "esquísticas": "esquístico",
    "esquísticos": "esquístico",
    "essa": "esse",
    "essas": "esse",
    "essenciais": "essencial",
    "essencialidades": "essencialidade",
    "essencialismos": "essencialismo",
    "esses": "esse",
    "essotra": "essotro",
    "essotras": "essotro",
    "essotros": "essotro",
    "essénia": "essénio",
    "essénias": "essénio",
    "essénios": "essénio",
    "essências": "essência",
    "esta": "este",
    "estabalhoada": "estabalhoado",
    "estabalhoadas": "estabalhoado",
    "estabalhoados": "estabalhoado",
    "estabaredas": "estabareda",
    "estabelece": "estabelecer",
    "estabelecedora": "estabelecedor",
    "estabelecedoras": "estabelecedor",
    "estabelecedores": "estabelecedor",
    "estabelecei": "estabelecer",
    "estabeleceis": "estabelecer",
    "estabelecem": "estabelecer",
    "estabelecemo": "estabelecer",
    "estabelecemos": "estabelecer",
    "estabelecendo": "estabelecer",
    "estabelecera": "estabelecer",
    "estabeleceram": "estabelecer",
    "estabeleceras": "estabelecer",
    "estabelecerde": "estabelecer",
    "estabelecerdes": "estabelecer",
    "estabelecere": "estabelecer",
    "estabelecerei": "estabelecer",
    "estabelecereis": "estabelecer",
    "estabelecerem": "estabelecer",
    "estabeleceremos": "estabelecer",
    "estabeleceres": "estabelecer",
    "estabeleceria": "estabelecer",
    "estabeleceriam": "estabelecer",
    "estabelecerias": "estabelecer",
    "estabelecermo": "estabelecer",
    "estabelecermos": "estabelecer",
    "estabelecerá": "estabelecer",
    "estabelecerás": "estabelecer",
    "estabelecerão": "estabelecer",
    "estabeleceríamos": "estabelecer",
    "estabeleceríeis": "estabelecer",
    "estabeleces": "estabelecer",
    "estabelecesse": "estabelecer",
    "estabelecessem": "estabelecer",
    "estabelecesses": "estabelecer",
    "estabeleceste": "estabelecer",
    "estabelecestes": "estabelecer",
    "estabeleceu": "estabelecer",
    "estabeleci": "estabelecer",
    "estabelecia": "estabelecer",
    "estabeleciam": "estabelecer",
    "estabelecias": "estabelecer",
    "estabelecida": "estabelecido",
    "estabelecidas": "estabelecido",
    "estabelecido": "estabelecer",
    "estabelecidos": "estabelecido",
    "estabelecimentos": "estabelecimento",
    "estabelecê": "estabelecer",
    "estabelecêramo": "estabelecer",
    "estabelecêramos": "estabelecer",
    "estabelecêrei": "estabelecer",
    "estabelecêreis": "estabelecer",
    "estabelecêsseis": "estabelecer",
    "estabelecêssemos": "estabelecer",
    "estabelecíamo": "estabelecer",
    "estabelecíamos": "estabelecer",
    "estabelecíei": "estabelecer",
    "estabelecíeis": "estabelecer",
    "estabelecíveis": "estabelecível",
    "estabeleça": "estabelecer",
    "estabeleçais": "estabelecer",
    "estabeleçam": "estabelecer",
    "estabeleçamo": "estabelecer",
    "estabeleçamos": "estabelecer",
    "estabeleças": "estabelecer",
    "estabeleço": "estabelecer",
    "estabilidades": "estabilidade",
    "estabiliza": "estabilizar",
    "estabilizada": "estabilizar",
    "estabilizadas": "estabilizar",
    "estabilizado": "estabilizar",
    "estabilizadora": "estabilizador",
    "estabilizadoras": "estabilizador",
    "estabilizadores": "estabilizador",
    "estabilizados": "estabilizar",
    "estabilizai": "estabilizar",
    "estabilizais": "estabilizar",
    "estabilizam": "estabilizar",
    "estabilizamo": "estabilizar",
    "estabilizamos": "estabilizar",
    "estabilizando": "estabilizar",
    "estabilizara": "estabilizar",
    "estabilizaram": "estabilizar",
    "estabilizaras": "estabilizar",
    "estabilizarde": "estabilizar",
    "estabilizardes": "estabilizar",
    "estabilizare": "estabilizar",
    "estabilizarei": "estabilizar",
    "estabilizareis": "estabilizar",
    "estabilizarem": "estabilizar",
    "estabilizaremos": "estabilizar",
    "estabilizares": "estabilizar",
    "estabilizaria": "estabilizar",
    "estabilizariam": "estabilizar",
    "estabilizarias": "estabilizar",
    "estabilizarmo": "estabilizar",
    "estabilizarmos": "estabilizar",
    "estabilizará": "estabilizar",
    "estabilizarás": "estabilizar",
    "estabilizarão": "estabilizar",
    "estabilizaríamos": "estabilizar",
    "estabilizaríeis": "estabilizar",
    "estabilizas": "estabilizar",
    "estabilizasse": "estabilizar",
    "estabilizassem": "estabilizar",
    "estabilizasses": "estabilizar",
    "estabilizaste": "estabilizar",
    "estabilizastes": "estabilizar",
    "estabilizava": "estabilizar",
    "estabilizavam": "estabilizar",
    "estabilizavas": "estabilizar",
    "estabilizações": "estabilização",
    "estabilize": "estabilizar",
    "estabilizei": "estabilizar",
    "estabilizeis": "estabilizar",
    "estabilizem": "estabilizar",
    "estabilizemo": "estabilizar",
    "estabilizemos": "estabilizar",
    "estabilizes": "estabilizar",
    "estabilizo": "estabilizar",
    "estabilizou": "estabilizar",
    "estabilizá": "estabilizar",
    "estabilizámo": "estabilizar",
    "estabilizámos": "estabilizar",
    "estabilizáramo": "estabilizar",
    "estabilizáramos": "estabilizar",
    "estabilizárei": "estabilizar",
    "estabilizáreis": "estabilizar",
    "estabilizásseis": "estabilizar",
    "estabilizássemos": "estabilizar",
    "estabilizávamo": "estabilizar",
    "estabilizávamos": "estabilizar",
    "estabilizávei": "estabilizar",
    "estabilizáveis": "estabilizável",
    "estabula": "estabular",
    "estabulada": "estabular",
    "estabuladas": "estabular",
    "estabulado": "estabular",
    "estabulados": "estabular",
    "estabulai": "estabular",
    "estabulais": "estabular",
    "estabulam": "estabular",
    "estabulamo": "estabular",
    "estabulamos": "estabular",
    "estabulando": "estabular",
    "estabulara": "estabular",
    "estabularam": "estabular",
    "estabularas": "estabular",
    "estabularde": "estabular",
    "estabulardes": "estabular",
    "estabulare": "estabular",
    "estabularei": "estabular",
    "estabulareis": "estabular",
    "estabularem": "estabular",
    "estabularemos": "estabular",
    "estabulares": "estabular",
    "estabularia": "estabular",
    "estabulariam": "estabular",
    "estabularias": "estabular",
    "estabularmo": "estabular",
    "estabularmos": "estabular",
    "estabulará": "estabular",
    "estabularás": "estabular",
    "estabularão": "estabular",
    "estabularíamos": "estabular",
    "estabularíeis": "estabular",
    "estabulas": "estabular",
    "estabulasse": "estabular",
    "estabulassem": "estabular",
    "estabulasses": "estabular",
    "estabulaste": "estabular",
    "estabulastes": "estabular",
    "estabulava": "estabular",
    "estabulavam": "estabular",
    "estabulavas": "estabular",
    "estabulações": "estabulação",
    "estabule": "estabular",
    "estabulei": "estabular",
    "estabuleis": "estabular",
    "estabulem": "estabular",
    "estabulemo": "estabular",
    "estabulemos": "estabular",
    "estabules": "estabular",
    "estabulo": "estabular",
    "estabulou": "estabular",
    "estabulá": "estabular",
    "estabulámo": "estabular",
    "estabulámos": "estabular",
    "estabuláramo": "estabular",
    "estabuláramos": "estabular",
    "estabulárei": "estabular",
    "estabuláreis": "estabular",
    "estabulásseis": "estabular",
    "estabulássemos": "estabular",
    "estabulávamo": "estabular",
    "estabulávamos": "estabular",
    "estabulávei": "estabular",
    "estabuláveis": "estabular",
    "estaca": "estacar",
    "estacada": "estacar",
    "estacadas": "estacar",
    "estacado": "estacar",
    "estacados": "estacar",
    "estacai": "estacar",
    "estacais": "estacar",
    "estacam": "estacar",
    "estacamo": "estacar",
    "estacamos": "estacar",
    "estacando": "estacar",
    "estacara": "estacar",
    "estacaram": "estacar",
    "estacaras": "estacar",
    "estacarde": "estacar",
    "estacardes": "estacar",
    "estacare": "estacar",
    "estacarei": "estacar",
    "estacareis": "estacar",
    "estacarem": "estacar",
    "estacaremos": "estacar",
    "estacares": "estacar",
    "estacaria": "estacar",
    "estacariam": "estacar",
    "estacarias": "estacaria",
    "estacarmo": "estacar",
    "estacarmos": "estacar",
    "estacará": "estacar",
    "estacarás": "estacar",
    "estacarão": "estacar",
    "estacaríamos": "estacar",
    "estacaríeis": "estacar",
    "estacas": "estacar",
    "estacasse": "estacar",
    "estacassem": "estacar",
    "estacasses": "estacar",
    "estacaste": "estacar",
    "estacastes": "estacar",
    "estacava": "estacar",
    "estacavam": "estacar",
    "estacavas": "estacar",
    "estaciona": "estacionar",
    "estacionada": "estacionar",
    "estacionadas": "estacionar",
    "estacionado": "estacionar",
    "estacionados": "estacionar",
    "estacionai": "estacionar",
    "estacionais": "estacionar",
    "estacionam": "estacionar",
    "estacionamentos": "estacionamento",
    "estacionamo": "estacionar",
    "estacionamos": "estacionar",
    "estacionando": "estacionar",
    "estacionara": "estacionar",
    "estacionaram": "estacionar",
    "estacionaras": "estacionar",
    "estacionarde": "estacionar",
    "estacionardes": "estacionar",
    "estacionare": "estacionar",
    "estacionarei": "estacionar",
    "estacionareis": "estacionar",
    "estacionarem": "estacionar",
    "estacionaremos": "estacionar",
    "estacionares": "estacionar",
    "estacionaria": "estacionar",
    "estacionariam": "estacionar",
    "estacionarias": "estacionar",
    "estacionarmo": "estacionar",
    "estacionarmos": "estacionar",
    "estacionará": "estacionar",
    "estacionarás": "estacionar",
    "estacionarão": "estacionar",
    "estacionaríamos": "estacionar",
    "estacionaríeis": "estacionar",
    "estacionas": "estacionar",
    "estacionasse": "estacionar",
    "estacionassem": "estacionar",
    "estacionasses": "estacionar",
    "estacionaste": "estacionar",
    "estacionastes": "estacionar",
    "estacionava": "estacionar",
    "estacionavam": "estacionar",
    "estacionavas": "estacionar",
    "estacione": "estacionar",
    "estacionei": "estacionar",
    "estacioneis": "estacionar",
    "estacionem": "estacionar",
    "estacionemo": "estacionar",
    "estacionemos": "estacionar",
    "estaciones": "estacionar",
    "estaciono": "estacionar",
    "estacionou": "estacionar",
    "estacioná": "estacionar",
    "estacionámo": "estacionar",
    "estacionámos": "estacionar",
    "estacionáramo": "estacionar",
    "estacionáramos": "estacionar",
    "estacionárei": "estacionar",
    "estacionáreis": "estacionar",
    "estacionária": "estacionário",
    "estacionárias": "estacionário",
    "estacionários": "estacionário",
    "estacionásseis": "estacionar",
    "estacionássemos": "estacionar",
    "estacionávamo": "estacionar",
    "estacionávamos": "estacionar",
    "estacionávei": "estacionar",
    "estacionáveis": "estacionar",
    "estaco": "estacar",
    "estacoa": "estacoar",
    "estacoada": "estacoar",
    "estacoadas": "estacoar",
    "estacoadelas": "estacoadela",
    "estacoado": "estacoar",
    "estacoados": "estacoar",
    "estacoai": "estacoar",
    "estacoais": "estacoar",
    "estacoam": "estacoar",
    "estacoamo": "estacoar",
    "estacoamos": "estacoar",
    "estacoando": "estacoar",
    "estacoara": "estacoar",
    "estacoaram": "estacoar",
    "estacoaras": "estacoar",
    "estacoarde": "estacoar",
    "estacoardes": "estacoar",
    "estacoare": "estacoar",
    "estacoarei": "estacoar",
    "estacoareis": "estacoar",
    "estacoarem": "estacoar",
    "estacoaremos": "estacoar",
    "estacoares": "estacoar",
    "estacoaria": "estacoar",
    "estacoariam": "estacoar",
    "estacoarias": "estacoar",
    "estacoarmo": "estacoar",
    "estacoarmos": "estacoar",
    "estacoará": "estacoar",
    "estacoarás": "estacoar",
    "estacoarão": "estacoar",
    "estacoaríamos": "estacoar",
    "estacoaríeis": "estacoar",
    "estacoas": "estacoar",
    "estacoasse": "estacoar",
    "estacoassem": "estacoar",
    "estacoasses": "estacoar",
    "estacoaste": "estacoar",
    "estacoastes": "estacoar",
    "estacoava": "estacoar",
    "estacoavam": "estacoar",
    "estacoavas": "estacoar",
    "estacoe": "estacoar",
    "estacoei": "estacoar",
    "estacoeis": "estacoar",
    "estacoem": "estacoar",
    "estacoemo": "estacoar",
    "estacoemos": "estacoar",
    "estacoes": "estacoar",
    "estacoo": "estacoar",
    "estacoou": "estacoar",
    "estacou": "estacar",
    "estacoá": "estacoar",
    "estacoámo": "estacoar",
    "estacoámos": "estacoar",
    "estacoáramo": "estacoar",
    "estacoáramos": "estacoar",
    "estacoárei": "estacoar",
    "estacoáreis": "estacoar",
    "estacoásseis": "estacoar",
    "estacoássemos": "estacoar",
    "estacoávamo": "estacoar",
    "estacoávamos": "estacoar",
    "estacoávei": "estacoar",
    "estacoáveis": "estacoar",
    "estacá": "estacar",
    "estacámo": "estacar",
    "estacámos": "estacar",
    "estacáramo": "estacar",
    "estacáramos": "estacar",
    "estacárei": "estacar",
    "estacáreis": "estacar",
    "estacásseis": "estacar",
    "estacássemos": "estacar",
    "estacávamo": "estacar",
    "estacávamos": "estacar",
    "estacávei": "estacar",
    "estacáveis": "estacar",
    "estacões": "estacão",
    "estada": "estar",
    "estadas": "estar",
    "estadeada": "estadear",
    "estadeadas": "estadear",
    "estadeado": "estadear",
    "estadeadora": "estadeador",
    "estadeadoras": "estadeador",
    "estadeadores": "estadeador",
    "estadeados": "estadear",
    "estadeai": "estadear",
    "estadeais": "estadear",
    "estadeamo": "estadear",
    "estadeamos": "estadear",
    "estadeando": "estadear",
    "estadeara": "estadear",
    "estadearam": "estadear",
    "estadearas": "estadear",
    "estadearde": "estadear",
    "estadeardes": "estadear",
    "estadeare": "estadear",
    "estadearei": "estadear",
    "estadeareis": "estadear",
    "estadearem": "estadear",
    "estadearemos": "estadear",
    "estadeares": "estadear",
    "estadearia": "estadear",
    "estadeariam": "estadear",
    "estadearias": "estadear",
    "estadearmo": "estadear",
    "estadearmos": "estadear",
    "estadeará": "estadear",
    "estadearás": "estadear",
    "estadearão": "estadear",
    "estadearíamos": "estadear",
    "estadearíeis": "estadear",
    "estadeasse": "estadear",
    "estadeassem": "estadear",
    "estadeasses": "estadear",
    "estadeaste": "estadear",
    "estadeastes": "estadear",
    "estadeava": "estadear",
    "estadeavam": "estadear",
    "estadeavas": "estadear",
    "estadeações": "estadeação",
    "estadeei": "estadear",
    "estadeeis": "estadear",
    "estadeemo": "estadear",
    "estadeemos": "estadear",
    "estadeia": "estadear",
    "estadeiam": "estadear",
    "estadeias": "estadear",
    "estadeie": "estadear",
    "estadeiem": "estadear",
    "estadeies": "estadear",
    "estadeio": "estadear",
    "estadelas": "estadela",
    "estadeou": "estadear",
    "estadeá": "estadear",
    "estadeámo": "estadear",
    "estadeámos": "estadear",
    "estadeáramo": "estadear",
    "estadeáramos": "estadear",
    "estadeárei": "estadear",
    "estadeáreis": "estadear",
    "estadeásseis": "estadear",
    "estadeássemos": "estadear",
    "estadeávamo": "estadear",
    "estadeávamos": "estadear",
    "estadeávei": "estadear",
    "estadeáveis": "estadear",
    "estadias": "estadia",
    "estadismos": "estadismo",
    "estadistas": "estadista",
    "estado": "estar",
    "estados": "estar",
    "estaduais": "estadual",
    "estadualizações": "estadualização",
    "estadulhos": "estadulho",
    "estadística": "estadístico",
    "estadísticas": "estadístico",
    "estadísticos": "estadístico",
    "estadões": "estadão",
    "estafa": "estafar",
    "estafada": "estafar",
    "estafadas": "estafar",
    "estafadelas": "estafadela",
    "estafado": "estafar",
    "estafadora": "estafador",
    "estafadoras": "estafador",
    "estafadores": "estafador",
    "estafados": "estafar",
    "estafadíssima": "estafado",
    "estafadíssimas": "estafado",
    "estafadíssimo": "estafado",
    "estafadíssimos": "estafado",
    "estafai": "estafar",
    "estafais": "estafar",
    "estafam": "estafar",
    "estafamentos": "estafamento",
    "estafamo": "estafar",
    "estafamos": "estafar",
    "estafando": "estafar",
    "estafantes": "estafante",
    "estafara": "estafar",
    "estafaram": "estafar",
    "estafaras": "estafar",
    "estafarde": "estafar",
    "estafardes": "estafar",
    "estafare": "estafar",
    "estafarei": "estafar",
    "estafareis": "estafar",
    "estafarem": "estafar",
    "estafaremos": "estafar",
    "estafares": "estafar",
    "estafaria": "estafar",
    "estafariam": "estafar",
    "estafarias": "estafar",
    "estafarmo": "estafar",
    "estafarmos": "estafar",
    "estafará": "estafar",
    "estafarás": "estafar",
    "estafarão": "estafar",
    "estafaríamos": "estafar",
    "estafaríeis": "estafar",
    "estafas": "estafar",
    "estafasse": "estafar",
    "estafassem": "estafar",
    "estafasses": "estafar",
    "estafaste": "estafar",
    "estafastes": "estafar",
    "estafava": "estafar",
    "estafavam": "estafar",
    "estafavas": "estafar",
    "estafe": "estafar",
    "estafega": "estafegar",
    "estafegada": "estafegar",
    "estafegadas": "estafegar",
    "estafegado": "estafegar",
    "estafegados": "estafegar",
    "estafegai": "estafegar",
    "estafegais": "estafegar",
    "estafegam": "estafegar",
    "estafegamo": "estafegar",
    "estafegamos": "estafegar",
    "estafegando": "estafegar",
    "estafegara": "estafegar",
    "estafegaram": "estafegar",
    "estafegaras": "estafegar",
    "estafegarde": "estafegar",
    "estafegardes": "estafegar",
    "estafegare": "estafegar",
    "estafegarei": "estafegar",
    "estafegareis": "estafegar",
    "estafegarem": "estafegar",
    "estafegaremos": "estafegar",
    "estafegares": "estafegar",
    "estafegaria": "estafegar",
    "estafegariam": "estafegar",
    "estafegarias": "estafegar",
    "estafegarmo": "estafegar",
    "estafegarmos": "estafegar",
    "estafegará": "estafegar",
    "estafegarás": "estafegar",
    "estafegarão": "estafegar",
    "estafegaríamos": "estafegar",
    "estafegaríeis": "estafegar",
    "estafegas": "estafegar",
    "estafegasse": "estafegar",
    "estafegassem": "estafegar",
    "estafegasses": "estafegar",
    "estafegaste": "estafegar",
    "estafegastes": "estafegar",
    "estafegava": "estafegar",
    "estafegavam": "estafegar",
    "estafegavas": "estafegar",
    "estafego": "estafegar",
    "estafegou": "estafegar",
    "estafegue": "estafegar",
    "estafeguei": "estafegar",
    "estafegueis": "estafegar",
    "estafeguem": "estafegar",
    "estafeguemo": "estafegar",
    "estafeguemos": "estafegar",
    "estafegues": "estafegar",
    "estafegá": "estafegar",
    "estafegámo": "estafegar",
    "estafegámos": "estafegar",
    "estafegáramo": "estafegar",
    "estafegáramos": "estafegar",
    "estafegárei": "estafegar",
    "estafegáreis": "estafegar",
    "estafegásseis": "estafegar",
    "estafegássemos": "estafegar",
    "estafegávamo": "estafegar",
    "estafegávamos": "estafegar",
    "estafegávei": "estafegar",
    "estafegáveis": "estafegar",
    "estafei": "estafar",
    "estafeis": "estafar",
    "estafem": "estafar",
    "estafemo": "estafar",
    "estafemos": "estafar",
    "estafermos": "estafermo",
    "estafes": "estafe",
    "estafetamentos": "estafetamento",
    "estafetas": "estafeta",
    "estafeteiros": "estafeteiro",
    "estafilococos": "estafilococo",
    "estafo": "estafar",
    "estafou": "estafar",
    "estafá": "estafar",
    "estafámo": "estafar",
    "estafámos": "estafar",
    "estafáramo": "estafar",
    "estafáramos": "estafar",
    "estafárei": "estafar",
    "estafáreis": "estafar",
    "estafásseis": "estafar",
    "estafássemos": "estafar",
    "estafávamo": "estafar",
    "estafávamos": "estafar",
    "estafávei": "estafar",
    "estafáveis": "estafar",
    "estagia": "estagiar",
    "estagiada": "estagiar",
    "estagiadas": "estagiar",
    "estagiado": "estagiar",
    "estagiados": "estagiar",
    "estagiai": "estagiar",
    "estagiais": "estagiar",
    "estagiam": "estagiar",
    "estagiamo": "estagiar",
    "estagiamos": "estagiar",
    "estagiando": "estagiar",
    "estagiara": "estagiar",
    "estagiaram": "estagiar",
    "estagiaras": "estagiar",
    "estagiardes": "estagiar",
    "estagiarei": "estagiar",
    "estagiareis": "estagiar",
    "estagiarem": "estagiar",
    "estagiaremos": "estagiar",
    "estagiares": "estagiar",
    "estagiaria": "estagiar",
    "estagiariam": "estagiar",
    "estagiarias": "estagiar",
    "estagiarmo": "estagiar",
    "estagiarmos": "estagiar",
    "estagiará": "estagiar",
    "estagiarás": "estagiar",
    "estagiarão": "estagiar",
    "estagiaríamos": "estagiar",
    "estagiaríeis": "estagiar",
    "estagias": "estagiar",
    "estagiasse": "estagiar",
    "estagiassem": "estagiar",
    "estagiasses": "estagiar",
    "estagiaste": "estagiar",
    "estagiastes": "estagiar",
    "estagiava": "estagiar",
    "estagiavam": "estagiar",
    "estagiavas": "estagiar",
    "estagie": "estagiar",
    "estagiei": "estagiar",
    "estagieis": "estagiar",
    "estagiem": "estagiar",
    "estagiemo": "estagiar",
    "estagiemos": "estagiar",
    "estagies": "estagiar",
    "estagio": "estagiar",
    "estagiou": "estagiar",
    "estagiámo": "estagiar",
    "estagiámos": "estagiar",
    "estagiáramo": "estagiar",
    "estagiáramos": "estagiar",
    "estagiáreis": "estagiar",
    "estagiária": "estagiário",
    "estagiárias": "estagiário",
    "estagiários": "estagiário",
    "estagiásseis": "estagiar",
    "estagiássemos": "estagiar",
    "estagiávamo": "estagiar",
    "estagiávamos": "estagiar",
    "estagiáveis": "estagiar",
    "estagna": "estagnar",
    "estagnada": "estagnar",
    "estagnadas": "estagnar",
    "estagnado": "estagnar",
    "estagnadora": "estagnador",
    "estagnadoras": "estagnador",
    "estagnadores": "estagnador",
    "estagnados": "estagnar",
    "estagnai": "estagnar",
    "estagnais": "estagnar",
    "estagnam": "estagnar",
    "estagnamo": "estagnar",
    "estagnamos": "estagnar",
    "estagnando": "estagnar",
    "estagnantes": "estagnante",
    "estagnara": "estagnar",
    "estagnaram": "estagnar",
    "estagnaras": "estagnar",
    "estagnardes": "estagnar",
    "estagnarei": "estagnar",
    "estagnareis": "estagnar",
    "estagnarem": "estagnar",
    "estagnaremos": "estagnar",
    "estagnares": "estagnar",
    "estagnaria": "estagnar",
    "estagnariam": "estagnar",
    "estagnarias": "estagnar",
    "estagnarmo": "estagnar",
    "estagnarmos": "estagnar",
    "estagnará": "estagnar",
    "estagnarás": "estagnar",
    "estagnarão": "estagnar",
    "estagnaríamos": "estagnar",
    "estagnaríeis": "estagnar",
    "estagnas": "estagnar",
    "estagnasse": "estagnar",
    "estagnassem": "estagnar",
    "estagnasses": "estagnar",
    "estagnaste": "estagnar",
    "estagnastes": "estagnar",
    "estagnava": "estagnar",
    "estagnavam": "estagnar",
    "estagnavas": "estagnar",
    "estagnações": "estagnação",
    "estagne": "estagnar",
    "estagnei": "estagnar",
    "estagneis": "estagnar",
    "estagnem": "estagnar",
    "estagnemo": "estagnar",
    "estagnemos": "estagnar",
    "estagnes": "estagnar",
    "estagno": "estagnar",
    "estagnou": "estagnar",
    "estagnámo": "estagnar",
    "estagnámos": "estagnar",
    "estagnáramo": "estagnar",
    "estagnáramos": "estagnar",
    "estagnáreis": "estagnar",
    "estagnásseis": "estagnar",
    "estagnássemos": "estagnar",
    "estagnávamo": "estagnar",
    "estagnávamos": "estagnar",
    "estagnáveis": "estagnar",
    "estagnícolas": "estagnícola",
    "estais": "estar",
    "estala": "estalar",
    "estalactiformes": "estalactiforme",
    "estalactimétrica": "estalactimétrico",
    "estalactimétricas": "estalactimétrico",
    "estalactimétricos": "estalactimétrico",
    "estalactites": "estalactite",
    "estalactífera": "estalactífero",
    "estalactíferas": "estalactífero",
    "estalactíferos": "estalactífero",
    "estalactítica": "estalactítico",
    "estalactíticas": "estalactítico",
    "estalactíticos": "estalactítico",
    "estalada": "estalar",
    "estaladas": "estalar",
    "estaladiça": "estaladiço",
    "estaladiças": "estaladiço",
    "estaladiços": "estaladiço",
    "estalado": "estalar",
    "estalados": "estalar",
    "estaladuras": "estaladura",
    "estalagens": "estalagem",
    "estalagmites": "estalagmite",
    "estalagmometrias": "estalagmometria",
    "estalagmométrica": "estalagmométrico",
    "estalagmométricas": "estalagmométrico",
    "estalagmométricos": "estalagmométrico",
    "estalagmítica": "estalagmítico",
    "estalagmíticas": "estalagmítico",
    "estalagmíticos": "estalagmítico",
    "estalagmómetros": "estalagmómetro",
    "estalai": "estalar",
    "estalais": "estalar",
    "estalajadeira": "estalajadeiro",
    "estalajadeiras": "estalajadeiro",
    "estalajadeiros": "estalajadeiro",
    "estalam": "estalar",
    "estalamo": "estalar",
    "estalamos": "estalar",
    "estalando": "estalar",
    "estalantes": "estalante",
    "estalara": "estalar",
    "estalaram": "estalar",
    "estalaras": "estalar",
    "estalarde": "estalar",
    "estalardes": "estalar",
    "estalare": "estalar",
    "estalarei": "estalar",
    "estalareis": "estalar",
    "estalarem": "estalar",
    "estalaremos": "estalar",
    "estalares": "estalar",
    "estalaria": "estalar",
    "estalariam": "estalar",
    "estalarias": "estalaria",
    "estalarmo": "estalar",
    "estalarmos": "estalar",
    "estalará": "estalar",
    "estalarás": "estalar",
    "estalarão": "estalar",
    "estalaríamos": "estalar",
    "estalaríeis": "estalar",
    "estalas": "estalar",
    "estalasse": "estalar",
    "estalassem": "estalar",
    "estalasses": "estalar",
    "estalaste": "estalar",
    "estalastes": "estalar",
    "estalava": "estalar",
    "estalavam": "estalar",
    "estalavas": "estalar",
    "estale": "estalar",
    "estalecida": "estalecido",
    "estalecidas": "estalecido",
    "estalecidos": "estalecido",
    "estalei": "estalar",
    "estaleiros": "estaleiro",
    "estaleis": "estalar",
    "estaleja": "estalejar",
    "estalejada": "estalejar",
    "estalejadas": "estalejar",
    "estalejado": "estalejar",
    "estalejados": "estalejar",
    "estalejaduras": "estalejadura",
    "estalejai": "estalejar",
    "estalejais": "estalejar",
    "estalejam": "estalejar",
    "estalejamo": "estalejar",
    "estalejamos": "estalejar",
    "estalejando": "estalejar",
    "estalejara": "estalejar",
    "estalejaram": "estalejar",
    "estalejaras": "estalejar",
    "estalejardes": "estalejar",
    "estalejarei": "estalejar",
    "estalejareis": "estalejar",
    "estalejarem": "estalejar",
    "estalejaremos": "estalejar",
    "estalejares": "estalejar",
    "estalejaria": "estalejar",
    "estalejariam": "estalejar",
    "estalejarias": "estalejar",
    "estalejarmo": "estalejar",
    "estalejarmos": "estalejar",
    "estalejará": "estalejar",
    "estalejarás": "estalejar",
    "estalejarão": "estalejar",
    "estalejaríamos": "estalejar",
    "estalejaríeis": "estalejar",
    "estalejas": "estalejar",
    "estalejasse": "estalejar",
    "estalejassem": "estalejar",
    "estalejasses": "estalejar",
    "estalejaste": "estalejar",
    "estalejastes": "estalejar",
    "estalejava": "estalejar",
    "estalejavam": "estalejar",
    "estalejavas": "estalejar",
    "estaleje": "estalejar",
    "estalejei": "estalejar",
    "estalejeis": "estalejar",
    "estalejem": "estalejar",
    "estalejemo": "estalejar",
    "estalejemos": "estalejar",
    "estalejes": "estalejar",
    "estalejo": "estalejar",
    "estalejou": "estalejar",
    "estalejámo": "estalejar",
    "estalejámos": "estalejar",
    "estalejáramo": "estalejar",
    "estalejáramos": "estalejar",
    "estalejáreis": "estalejar",
    "estalejásseis": "estalejar",
    "estalejássemos": "estalejar",
    "estalejávamo": "estalejar",
    "estalejávamos": "estalejar",
    "estalejáveis": "estalejar",
    "estalem": "estalar",
    "estalemo": "estalar",
    "estalemos": "estalar",
    "estales": "estalar",
    "estalica": "estalicar",
    "estalicada": "estalicar",
    "estalicadas": "estalicar",
    "estalicado": "estalicar",
    "estalicados": "estalicar",
    "estalicais": "estalicar",
    "estalicam": "estalicar",
    "estalicamo": "estalicar",
    "estalicamos": "estalicar",
    "estalicando": "estalicar",
    "estalicara": "estalicar",
    "estalicaram": "estalicar",
    "estalicaras": "estalicar",
    "estalicardes": "estalicar",
    "estalicarei": "estalicar",
    "estalicareis": "estalicar",
    "estalicarem": "estalicar",
    "estalicaremos": "estalicar",
    "estalicares": "estalicar",
    "estalicaria": "estalicar",
    "estalicariam": "estalicar",
    "estalicarias": "estalicar",
    "estalicarmo": "estalicar",
    "estalicarmos": "estalicar",
    "estalicará": "estalicar",
    "estalicarás": "estalicar",
    "estalicarão": "estalicar",
    "estalicaríamos": "estalicar",
    "estalicaríeis": "estalicar",
    "estalicas": "estalicar",
    "estalicasse": "estalicar",
    "estalicassem": "estalicar",
    "estalicasses": "estalicar",
    "estalicaste": "estalicar",
    "estalicastes": "estalicar",
    "estalicava": "estalicar",
    "estalicavam": "estalicar",
    "estalicavas": "estalicar",
    "estalico": "estalicar",
    "estalicou": "estalicar",
    "estalicámo": "estalicar",
    "estalicámos": "estalicar",
    "estalicáramo": "estalicar",
    "estalicáramos": "estalicar",
    "estalicáreis": "estalicar",
    "estalicásseis": "estalicar",
    "estalicássemos": "estalicar",
    "estalicávamo": "estalicar",
    "estalicávamos": "estalicar",
    "estalicáveis": "estalicar",
    "estalida": "estalidar",
    "estalidada": "estalidar",
    "estalidadas": "estalidar",
    "estalidado": "estalidar",
    "estalidados": "estalidar",
    "estalidai": "estalidar",
    "estalidais": "estalidar",
    "estalidam": "estalidar",
    "estalidamo": "estalidar",
    "estalidamos": "estalidar",
    "estalidando": "estalidar",
    "estalidara": "estalidar",
    "estalidaram": "estalidar",
    "estalidaras": "estalidar",
    "estalidardes": "estalidar",
    "estalidarei": "estalidar",
    "estalidareis": "estalidar",
    "estalidarem": "estalidar",
    "estalidaremos": "estalidar",
    "estalidares": "estalidar",
    "estalidaria": "estalidar",
    "estalidariam": "estalidar",
    "estalidarias": "estalidar",
    "estalidarmo": "estalidar",
    "estalidarmos": "estalidar",
    "estalidará": "estalidar",
    "estalidarás": "estalidar",
    "estalidarão": "estalidar",
    "estalidaríamos": "estalidar",
    "estalidaríeis": "estalidar",
    "estalidas": "estalidar",
    "estalidasse": "estalidar",
    "estalidassem": "estalidar",
    "estalidasses": "estalidar",
    "estalidaste": "estalidar",
    "estalidastes": "estalidar",
    "estalidava": "estalidar",
    "estalidavam": "estalidar",
    "estalidavas": "estalidar",
    "estalide": "estalidar",
    "estalidei": "estalidar",
    "estalideis": "estalidar",
    "estalidem": "estalidar",
    "estalidemo": "estalidar",
    "estalidemos": "estalidar",
    "estalides": "estalidar",
    "estalido": "estalidar",
    "estalidos": "estalido",
    "estalidou": "estalidar",
    "estalidámo": "estalidar",
    "estalidámos": "estalidar",
    "estalidáramo": "estalidar",
    "estalidáramos": "estalidar",
    "estalidáreis": "estalidar",
    "estalidásseis": "estalidar",
    "estalidássemos": "estalidar",
    "estalidávamo": "estalidar",
    "estalidávamos": "estalidar",
    "estalidáveis": "estalidar",
    "estalinho": "estalo",
    "estalinhos": "estalo",
    "estalinismos": "estalinismo",
    "estalinistas": "estalinista",
    "estalinizações": "estalinização",
    "estalique": "estalicar",
    "estaliquei": "estalicar",
    "estaliqueis": "estalicar",
    "estaliquem": "estalicar",
    "estaliquemos": "estalicar",
    "estaliques": "estalicar",
    "estalito": "estalo",
    "estalitos": "estalo",
    "estalo": "estalar",
    "estalos": "estalo",
    "estalou": "estalar",
    "estalá": "estalar",
    "estalámo": "estalar",
    "estalámos": "estalar",
    "estaláramo": "estalar",
    "estaláramos": "estalar",
    "estalárei": "estalar",
    "estaláreis": "estalar",
    "estalásseis": "estalar",
    "estalássemos": "estalar",
    "estalávamo": "estalar",
    "estalávamos": "estalar",
    "estalávei": "estalar",
    "estaláveis": "estalar",
    "estalões": "estalão",
    "estambra": "estambrar",
    "estambrada": "estambrar",
    "estambradas": "estambrar",
    "estambrado": "estambrar",
    "estambrados": "estambrar",
    "estambrai": "estambrar",
    "estambrais": "estambrar",
    "estambram": "estambrar",
    "estambramo": "estambrar",
    "estambramos": "estambrar",
    "estambrando": "estambrar",
    "estambrara": "estambrar",
    "estambraram": "estambrar",
    "estambraras": "estambrar",
    "estambrarde": "estambrar",
    "estambrardes": "estambrar",
    "estambrare": "estambrar",
    "estambrarei": "estambrar",
    "estambrareis": "estambrar",
    "estambrarem": "estambrar",
    "estambraremos": "estambrar",
    "estambrares": "estambrar",
    "estambraria": "estambrar",
    "estambrariam": "estambrar",
    "estambrarias": "estambrar",
    "estambrarmo": "estambrar",
    "estambrarmos": "estambrar",
    "estambrará": "estambrar",
    "estambrarás": "estambrar",
    "estambrarão": "estambrar",
    "estambraríamos": "estambrar",
    "estambraríeis": "estambrar",
    "estambras": "estambrar",
    "estambrasse": "estambrar",
    "estambrassem": "estambrar",
    "estambrasses": "estambrar",
    "estambraste": "estambrar",
    "estambrastes": "estambrar",
    "estambrava": "estambrar",
    "estambravam": "estambrar",
    "estambravas": "estambrar",
    "estambre": "estambrar",
    "estambrei": "estambrar",
    "estambreira": "estambreiro",
    "estambreiras": "estambreiro",
    "estambreiros": "estambreiro",
    "estambreis": "estambrar",
    "estambrem": "estambrar",
    "estambremo": "estambrar",
    "estambremos": "estambrar",
    "estambres": "estambrar",
    "estambro": "estambrar",
    "estambrou": "estambrar",
    "estambrá": "estambrar",
    "estambrámo": "estambrar",
    "estambrámos": "estambrar",
    "estambráramo": "estambrar",
    "estambráramos": "estambrar",
    "estambrárei": "estambrar",
    "estambráreis": "estambrar",
    "estambrásseis": "estambrar",
    "estambrássemos": "estambrar",
    "estambrávamo": "estambrar",
    "estambrávamos": "estambrar",
    "estambrávei": "estambrar",
    "estambráveis": "estambrar",
    "estamenhas": "estamenha",
    "estamenheiros": "estamenheiro",
    "estamentos": "estamento",
    "estames": "estame",
    "estamina": "estaminar",
    "estaminada": "estaminar",
    "estaminadas": "estaminar",
    "estaminado": "estaminar",
    "estaminados": "estaminar",
    "estaminai": "estaminar",
    "estaminais": "estaminar",
    "estaminam": "estaminar",
    "estaminamo": "estaminar",
    "estaminamos": "estaminar",
    "estaminando": "estaminar",
    "estaminara": "estaminar",
    "estaminaram": "estaminar",
    "estaminaras": "estaminar",
    "estaminarde": "estaminar",
    "estaminardes": "estaminar",
    "estaminare": "estaminar",
    "estaminarei": "estaminar",
    "estaminareis": "estaminar",
    "estaminarem": "estaminar",
    "estaminaremos": "estaminar",
    "estaminares": "estaminar",
    "estaminaria": "estaminar",
    "estaminariam": "estaminar",
    "estaminarias": "estaminar",
    "estaminarmo": "estaminar",
    "estaminarmos": "estaminar",
    "estaminará": "estaminar",
    "estaminarás": "estaminar",
    "estaminarão": "estaminar",
    "estaminaríamos": "estaminar",
    "estaminaríeis": "estaminar",
    "estaminas": "estaminar",
    "estaminasse": "estaminar",
    "estaminassem": "estaminar",
    "estaminasses": "estaminar",
    "estaminaste": "estaminar",
    "estaminastes": "estaminar",
    "estaminava": "estaminar",
    "estaminavam": "estaminar",
    "estaminavas": "estaminar",
    "estamine": "estaminar",
    "estaminei": "estaminar",
    "estamineis": "estaminar",
    "estaminem": "estaminar",
    "estaminemo": "estaminar",
    "estaminemos": "estaminar",
    "estamines": "estaminar",
    "estamino": "estaminar",
    "estaminosa": "estaminoso",
    "estaminosas": "estaminoso",
    "estaminosos": "estaminoso",
    "estaminou": "estaminar",
    "estaminá": "estaminar",
    "estaminácea": "estamináceo",
    "estamináceas": "estamináceo",
    "estamináceos": "estamináceo",
    "estaminámo": "estaminar",
    "estaminámos": "estaminar",
    "estamináramo": "estaminar",
    "estamináramos": "estaminar",
    "estaminárei": "estaminar",
    "estamináreis": "estaminar",
    "estaminária": "estaminário",
    "estaminárias": "estaminário",
    "estaminários": "estaminário",
    "estaminásseis": "estaminar",
    "estaminássemos": "estaminar",
    "estaminávamo": "estaminar",
    "estaminávamos": "estaminar",
    "estaminávei": "estaminar",
    "estamináveis": "estaminar",
    "estaminífera": "estaminífero",
    "estaminíferas": "estaminífero",
    "estaminíferos": "estaminífero",
    "estaminódios": "estaminódio",
    "estaminóides": "estaminóide",
    "estamo": "estar",
    "estamos": "estar",
    "estampa": "estampar",
    "estampada": "estampar",
    "estampadas": "estampar",
    "estampado": "estampar",
    "estampadora": "estampador",
    "estampadoras": "estampador",
    "estampadores": "estampador",
    "estampados": "estampar",
    "estampagens": "estampagem",
    "estampai": "estampar",
    "estampais": "estampar",
    "estampam": "estampar",
    "estampamo": "estampar",
    "estampamos": "estampar",
    "estampando": "estampar",
    "estampara": "estampar",
    "estamparam": "estampar",
    "estamparas": "estampar",
    "estamparde": "estampar",
    "estampardes": "estampar",
    "estampare": "estampar",
    "estamparei": "estampar",
    "estampareis": "estampar",
    "estamparem": "estampar",
    "estamparemos": "estampar",
    "estampares": "estampar",
    "estamparia": "estampar",
    "estampariam": "estampar",
    "estamparias": "estamparia",
    "estamparmo": "estampar",
    "estamparmos": "estampar",
    "estampará": "estampar",
    "estamparás": "estampar",
    "estamparão": "estampar",
    "estamparíamos": "estampar",
    "estamparíeis": "estampar",
    "estampas": "estampar",
    "estampasse": "estampar",
    "estampassem": "estampar",
    "estampasses": "estampar",
    "estampaste": "estampar",
    "estampastes": "estampar",
    "estampatórios": "estampatório",
    "estampava": "estampar",
    "estampavam": "estampar",
    "estampavas": "estampar",
    "estampe": "estampar",
    "estampei": "estampar",
    "estampeiros": "estampeiro",
    "estampeis": "estampar",
    "estampem": "estampar",
    "estampemo": "estampar",
    "estampemos": "estampar",
    "estampes": "estampar",
    "estampidos": "estampido",
    "estampilha": "estampilhar",
    "estampilhada": "estampilhar",
    "estampilhadas": "estampilhar",
    "estampilhado": "estampilhar",
    "estampilhados": "estampilhar",
    "estampilhagens": "estampilhagem",
    "estampilhai": "estampilhar",
    "estampilhais": "estampilhar",
    "estampilham": "estampilhar",
    "estampilhamo": "estampilhar",
    "estampilhamos": "estampilhar",
    "estampilhando": "estampilhar",
    "estampilhara": "estampilhar",
    "estampilharam": "estampilhar",
    "estampilharas": "estampilhar",
    "estampilharde": "estampilhar",
    "estampilhardes": "estampilhar",
    "estampilhare": "estampilhar",
    "estampilharei": "estampilhar",
    "estampilhareis": "estampilhar",
    "estampilharem": "estampilhar",
    "estampilharemos": "estampilhar",
    "estampilhares": "estampilhar",
    "estampilharia": "estampilhar",
    "estampilhariam": "estampilhar",
    "estampilharias": "estampilhar",
    "estampilharmo": "estampilhar",
    "estampilharmos": "estampilhar",
    "estampilhará": "estampilhar",
    "estampilharás": "estampilhar",
    "estampilharão": "estampilhar",
    "estampilharíamos": "estampilhar",
    "estampilharíeis": "estampilhar",
    "estampilhas": "estampilhar",
    "estampilhasse": "estampilhar",
    "estampilhassem": "estampilhar",
    "estampilhasses": "estampilhar",
    "estampilhaste": "estampilhar",
    "estampilhastes": "estampilhar",
    "estampilhava": "estampilhar",
    "estampilhavam": "estampilhar",
    "estampilhavas": "estampilhar",
    "estampilhe": "estampilhar",
    "estampilhei": "estampilhar",
    "estampilheis": "estampilhar",
    "estampilhem": "estampilhar",
    "estampilhemo": "estampilhar",
    "estampilhemos": "estampilhar",
    "estampilhes": "estampilhar",
    "estampilho": "estampilhar",
    "estampilhou": "estampilhar",
    "estampilhá": "estampilhar",
    "estampilhámo": "estampilhar",
    "estampilhámos": "estampilhar",
    "estampilháramo": "estampilhar",
    "estampilháramos": "estampilhar",
    "estampilhárei": "estampilhar",
    "estampilháreis": "estampilhar",
    "estampilhásseis": "estampilhar",
    "estampilhássemos": "estampilhar",
    "estampilhávamo": "estampilhar",
    "estampilhávamos": "estampilhar",
    "estampilhávei": "estampilhar",
    "estampilháveis": "estampilhar",
    "estampo": "estampar",
    "estampou": "estampar",
    "estampá": "estampar",
    "estampámo": "estampar",
    "estampámos": "estampar",
    "estampáramo": "estampar",
    "estampáramos": "estampar",
    "estampárei": "estampar",
    "estampáreis": "estampar",
    "estampásseis": "estampar",
    "estampássemos": "estampar",
    "estampávamo": "estampar",
    "estampávamos": "estampar",
    "estampávei": "estampar",
    "estampáveis": "estampar",
    "estamínulas": "estamínula",
    "estanatos": "estanato",
    "estanca": "estancar",
    "estancada": "estancar",
    "estancadas": "estancar",
    "estancadeiras": "estancadeira",
    "estancado": "estancar",
    "estancados": "estancar",
    "estancai": "estancar",
    "estancais": "estancar",
    "estancam": "estancar",
    "estancamentos": "estancamento",
    "estancamo": "estancar",
    "estancamos": "estancar",
    "estancando": "estancar",
    "estancara": "estancar",
    "estancaram": "estancar",
    "estancaras": "estancar",
    "estancarde": "estancar",
    "estancardes": "estancar",
    "estancare": "estancar",
    "estancarei": "estancar",
    "estancareis": "estancar",
    "estancarem": "estancar",
    "estancaremos": "estancar",
    "estancares": "estancar",
    "estancaria": "estancar",
    "estancariam": "estancar",
    "estancarias": "estancar",
    "estancarmo": "estancar",
    "estancarmos": "estancar",
    "estancará": "estancar",
    "estancarás": "estancar",
    "estancarão": "estancar",
    "estancaríamos": "estancar",
    "estancaríeis": "estancar",
    "estancas": "estancar",
    "estancasse": "estancar",
    "estancassem": "estancar",
    "estancasses": "estancar",
    "estancaste": "estancar",
    "estancastes": "estancar",
    "estancava": "estancar",
    "estancavam": "estancar",
    "estancavas": "estancar",
    "estancações": "estancação",
    "estanceira": "estanceiro",
    "estanceiras": "estanceiro",
    "estanceiros": "estanceiro",
    "estancia": "estanciar",
    "estanciada": "estanciar",
    "estanciadas": "estanciar",
    "estanciado": "estanciar",
    "estanciados": "estanciar",
    "estanciai": "estanciar",
    "estanciais": "estanciar",
    "estanciam": "estanciar",
    "estanciamo": "estanciar",
    "estanciamos": "estanciar",
    "estanciando": "estanciar",
    "estanciara": "estanciar",
    "estanciaram": "estanciar",
    "estanciaras": "estanciar",
    "estanciardes": "estanciar",
    "estanciarei": "estanciar",
    "estanciareis": "estanciar",
    "estanciarem": "estanciar",
    "estanciaremos": "estanciar",
    "estanciares": "estanciar",
    "estanciaria": "estanciar",
    "estanciariam": "estanciar",
    "estanciarias": "estanciar",
    "estanciarmo": "estanciar",
    "estanciarmos": "estanciar",
    "estanciará": "estanciar",
    "estanciarás": "estanciar",
    "estanciarão": "estanciar",
    "estanciaríamos": "estanciar",
    "estanciaríeis": "estanciar",
    "estancias": "estanciar",
    "estanciasse": "estanciar",
    "estanciassem": "estanciar",
    "estanciasses": "estanciar",
    "estanciaste": "estanciar",
    "estanciastes": "estanciar",
    "estanciava": "estanciar",
    "estanciavam": "estanciar",
    "estanciavas": "estanciar",
    "estancie": "estanciar",
    "estanciei": "estanciar",
    "estancieira": "estancieiro",
    "estancieiras": "estancieiro",
    "estancieiros": "estancieiro",
    "estancieis": "estanciar",
    "estanciem": "estanciar",
    "estanciemo": "estanciar",
    "estanciemos": "estanciar",
    "estancies": "estanciar",
    "estancio": "estanciar",
    "estanciou": "estanciar",
    "estanciámo": "estanciar",
    "estanciámos": "estanciar",
    "estanciáramo": "estanciar",
    "estanciáramos": "estanciar",
    "estanciáreis": "estanciar",
    "estanciásseis": "estanciar",
    "estanciássemos": "estanciar",
    "estanciávamo": "estanciar",
    "estanciávamos": "estanciar",
    "estanciáveis": "estanciar",
    "estanco": "estancar",
    "estancos": "estanco",
    "estancou": "estancar",
    "estancá": "estancar",
    "estancámo": "estancar",
    "estancámos": "estancar",
    "estancáramo": "estancar",
    "estancáramos": "estancar",
    "estancárei": "estancar",
    "estancáreis": "estancar",
    "estancásseis": "estancar",
    "estancássemos": "estancar",
    "estancávamo": "estancar",
    "estancávamos": "estancar",
    "estancávei": "estancar",
    "estancáveis": "estancável",
    "estandardizações": "estandardização",
    "estandartes": "estandarte",
    "estando": "estar",
    "estanha": "estanhar",
    "estanhada": "estanhar",
    "estanhadas": "estanhar",
    "estanhado": "estanhar",
    "estanhadora": "estanhador",
    "estanhadoras": "estanhador",
    "estanhadores": "estanhador",
    "estanhados": "estanhar",
    "estanhagens": "estanhagem",
    "estanhai": "estanhar",
    "estanhais": "estanhar",
    "estanham": "estanhar",
    "estanhamo": "estanhar",
    "estanhamos": "estanhar",
    "estanhando": "estanhar",
    "estanhara": "estanhar",
    "estanharam": "estanhar",
    "estanharas": "estanhar",
    "estanharde": "estanhar",
    "estanhardes": "estanhar",
    "estanhare": "estanhar",
    "estanharei": "estanhar",
    "estanhareis": "estanhar",
    "estanharem": "estanhar",
    "estanharemos": "estanhar",
    "estanhares": "estanhar",
    "estanharia": "estanhar",
    "estanhariam": "estanhar",
    "estanharias": "estanhar",
    "estanharmo": "estanhar",
    "estanharmos": "estanhar",
    "estanhará": "estanhar",
    "estanharás": "estanhar",
    "estanharão": "estanhar",
    "estanharíamos": "estanhar",
    "estanharíeis": "estanhar",
    "estanhas": "estanhar",
    "estanhasse": "estanhar",
    "estanhassem": "estanhar",
    "estanhasses": "estanhar",
    "estanhaste": "estanhar",
    "estanhastes": "estanhar",
    "estanhava": "estanhar",
    "estanhavam": "estanhar",
    "estanhavas": "estanhar",
    "estanhe": "estanhar",
    "estanhei": "estanhar",
    "estanheiras": "estanheira",
    "estanheis": "estanhar",
    "estanhem": "estanhar",
    "estanhemo": "estanhar",
    "estanhemos": "estanhar",
    "estanhes": "estanhar",
    "estanho": "estanhar",
    "estanhos": "estanho",
    "estanhou": "estanhar",
    "estanhá": "estanhar",
    "estanhámo": "estanhar",
    "estanhámos": "estanhar",
    "estanháramo": "estanhar",
    "estanháramos": "estanhar",
    "estanhárei": "estanhar",
    "estanháreis": "estanhar",
    "estanhásseis": "estanhar",
    "estanhássemos": "estanhar",
    "estanhávamo": "estanhar",
    "estanhávamos": "estanhar",
    "estanhávei": "estanhar",
    "estanháveis": "estanhar",
    "estaninas": "estanina",
    "estanosa": "estanoso",
    "estanosas": "estanoso",
    "estanosos": "estanoso",
    "estanque": "estancar",
    "estanquei": "estancar",
    "estanqueira": "estanqueiro",
    "estanqueiras": "estanqueiro",
    "estanqueiros": "estanqueiro",
    "estanqueis": "estancar",
    "estanquem": "estancar",
    "estanquemo": "estancar",
    "estanquemos": "estancar",
    "estanques": "estanque",
    "estantes": "estante",
    "estanças": "estança",
    "estanífera": "estanífero",
    "estaníferas": "estanífero",
    "estaníferos": "estanífero",
    "estapafúrdia": "estapafúrdio",
    "estapafúrdias": "estapafúrdio",
    "estapafúrdica": "estapafúrdico",
    "estapafúrdicas": "estapafúrdico",
    "estapafúrdicos": "estapafúrdico",
    "estapafúrdios": "estapafúrdio",
    "estaque": "estacar",
    "estaqueada": "estaquear",
    "estaqueadas": "estaquear",
    "estaqueado": "estaquear",
    "estaqueados": "estaquear",
    "estaqueai": "estaquear",
    "estaqueais": "estaquear",
    "estaqueamentos": "estaqueamento",
    "estaqueamo": "estaquear",
    "estaqueamos": "estaquear",
    "estaqueando": "estaquear",
    "estaqueara": "estaquear",
    "estaquearam": "estaquear",
    "estaquearas": "estaquear",
    "estaquearde": "estaquear",
    "estaqueardes": "estaquear",
    "estaqueare": "estaquear",
    "estaquearei": "estaquear",
    "estaqueareis": "estaquear",
    "estaquearem": "estaquear",
    "estaquearemos": "estaquear",
    "estaqueares": "estaquear",
    "estaquearia": "estaquear",
    "estaqueariam": "estaquear",
    "estaquearias": "estaquear",
    "estaquearmo": "estaquear",
    "estaquearmos": "estaquear",
    "estaqueará": "estaquear",
    "estaquearás": "estaquear",
    "estaquearão": "estaquear",
    "estaquearíamos": "estaquear",
    "estaquearíeis": "estaquear",
    "estaqueasse": "estaquear",
    "estaqueassem": "estaquear",
    "estaqueasses": "estaquear",
    "estaqueaste": "estaquear",
    "estaqueastes": "estaquear",
    "estaqueava": "estaquear",
    "estaqueavam": "estaquear",
    "estaqueavas": "estaquear",
    "estaqueações": "estaqueação",
    "estaqueei": "estaquear",
    "estaqueeis": "estaquear",
    "estaqueemo": "estaquear",
    "estaqueemos": "estaquear",
    "estaquei": "estacar",
    "estaqueia": "estaquear",
    "estaqueiam": "estaquear",
    "estaqueias": "estaquear",
    "estaqueie": "estaquear",
    "estaqueiem": "estaquear",
    "estaqueies": "estaquear",
    "estaqueio": "estaquear",
    "estaqueis": "estacar",
    "estaquem": "estacar",
    "estaquemo": "estacar",
    "estaquemos": "estacar",
    "estaqueou": "estaquear",
    "estaques": "estacar",
    "estaqueá": "estaquear",
    "estaqueámo": "estaquear",
    "estaqueámos": "estaquear",
    "estaqueáramo": "estaquear",
    "estaqueáramos": "estaquear",
    "estaqueárei": "estaquear",
    "estaqueáreis": "estaquear",
    "estaqueásseis": "estaquear",
    "estaqueássemos": "estaquear",
    "estaqueávamo": "estaquear",
    "estaqueávamos": "estaquear",
    "estaqueávei": "estaquear",
    "estaqueáveis": "estaquear",
    "estaquias": "estaquia",
    "estaquilhas": "estaquilha",
    "estardalha": "estardalhar",
    "estardalhada": "estardalhar",
    "estardalhadas": "estardalhar",
    "estardalhado": "estardalhar",
    "estardalhados": "estardalhar",
    "estardalhai": "estardalhar",
    "estardalhais": "estardalhar",
    "estardalham": "estardalhar",
    "estardalhamo": "estardalhar",
    "estardalhamos": "estardalhar",
    "estardalhando": "estardalhar",
    "estardalhara": "estardalhar",
    "estardalharam": "estardalhar",
    "estardalharas": "estardalhar",
    "estardalhardes": "estardalhar",
    "estardalharei": "estardalhar",
    "estardalhareis": "estardalhar",
    "estardalharem": "estardalhar",
    "estardalharemos": "estardalhar",
    "estardalhares": "estardalhar",
    "estardalharia": "estardalhar",
    "estardalhariam": "estardalhar",
    "estardalharias": "estardalhar",
    "estardalharmo": "estardalhar",
    "estardalharmos": "estardalhar",
    "estardalhará": "estardalhar",
    "estardalharás": "estardalhar",
    "estardalharão": "estardalhar",
    "estardalharíamos": "estardalhar",
    "estardalharíeis": "estardalhar",
    "estardalhas": "estardalhar",
    "estardalhasse": "estardalhar",
    "estardalhassem": "estardalhar",
    "estardalhasses": "estardalhar",
    "estardalhaste": "estardalhar",
    "estardalhastes": "estardalhar",
    "estardalhava": "estardalhar",
    "estardalhavam": "estardalhar",
    "estardalhavas": "estardalhar",
    "estardalhaços": "estardalhaço",
    "estardalhe": "estardalhar",
    "estardalhei": "estardalhar",
    "estardalheis": "estardalhar",
    "estardalhem": "estardalhar",
    "estardalhemo": "estardalhar",
    "estardalhemos": "estardalhar",
    "estardalhes": "estardalhar",
    "estardalho": "estardalhar",
    "estardalhos": "estardalho",
    "estardalhou": "estardalhar",
    "estardalhámo": "estardalhar",
    "estardalhámos": "estardalhar",
    "estardalháramo": "estardalhar",
    "estardalháramos": "estardalhar",
    "estardalháreis": "estardalhar",
    "estardalhásseis": "estardalhar",
    "estardalhássemos": "estardalhar",
    "estardalhávamo": "estardalhar",
    "estardalhávamos": "estardalhar",
    "estardalháveis": "estardalhar",
    "estardes": "estar",
    "estardiotas": "estardiota",
    "estarei": "estar",
    "estareis": "estar",
    "estarem": "estar",
    "estaremos": "estar",
    "estares": "estar",
    "estaria": "estar",
    "estariam": "estar",
    "estarias": "estar",
    "estarmo": "estar",
    "estarmos": "estar",
    "estarnas": "estarna",
    "estarolas": "estarola",
    "estarrece": "estarrecer",
    "estarrecedora": "estarrecedor",
    "estarrecedoras": "estarrecedor",
    "estarrecedores": "estarrecedor",
    "estarrecei": "estarrecer",
    "estarreceis": "estarrecer",
    "estarrecem": "estarrecer",
    "estarrecemo": "estarrecer",
    "estarrecemos": "estarrecer",
    "estarrecendo": "estarrecer",
    "estarrecera": "estarrecer",
    "estarreceram": "estarrecer",
    "estarreceras": "estarrecer",
    "estarrecerde": "estarrecer",
    "estarrecerdes": "estarrecer",
    "estarrecere": "estarrecer",
    "estarrecerei": "estarrecer",
    "estarrecereis": "estarrecer",
    "estarrecerem": "estarrecer",
    "estarreceremos": "estarrecer",
    "estarreceres": "estarrecer",
    "estarreceria": "estarrecer",
    "estarreceriam": "estarrecer",
    "estarrecerias": "estarrecer",
    "estarrecermo": "estarrecer",
    "estarrecermos": "estarrecer",
    "estarrecerá": "estarrecer",
    "estarrecerás": "estarrecer",
    "estarrecerão": "estarrecer",
    "estarreceríamos": "estarrecer",
    "estarreceríeis": "estarrecer",
    "estarreces": "estarrecer",
    "estarrecesse": "estarrecer",
    "estarrecessem": "estarrecer",
    "estarrecesses": "estarrecer",
    "estarreceste": "estarrecer",
    "estarrecestes": "estarrecer",
    "estarreceu": "estarrecer",
    "estarreci": "estarrecer",
    "estarrecia": "estarrecer",
    "estarreciam": "estarrecer",
    "estarrecias": "estarrecer",
    "estarrecida": "estarrecido",
    "estarrecidas": "estarrecido",
    "estarrecido": "estarrecer",
    "estarrecidos": "estarrecido",
    "estarrecê": "estarrecer",
    "estarrecêramo": "estarrecer",
    "estarrecêramos": "estarrecer",
    "estarrecêrei": "estarrecer",
    "estarrecêreis": "estarrecer",
    "estarrecêsseis": "estarrecer",
    "estarrecêssemos": "estarrecer",
    "estarrecíamo": "estarrecer",
    "estarrecíamos": "estarrecer",
    "estarrecíei": "estarrecer",
    "estarrecíeis": "estarrecer",
    "estarreça": "estarrecer",
    "estarreçais": "estarrecer",
    "estarreçam": "estarrecer",
    "estarreçamo": "estarrecer",
    "estarreçamos": "estarrecer",
    "estarreças": "estarrecer",
    "estarreço": "estarrecer",
    "estarrinca": "estarrincar",
    "estarrincada": "estarrincar",
    "estarrincadas": "estarrincar",
    "estarrincado": "estarrincar",
    "estarrincados": "estarrincar",
    "estarrincai": "estarrincar",
    "estarrincais": "estarrincar",
    "estarrincam": "estarrincar",
    "estarrincamo": "estarrincar",
    "estarrincamos": "estarrincar",
    "estarrincando": "estarrincar",
    "estarrincara": "estarrincar",
    "estarrincaram": "estarrincar",
    "estarrincaras": "estarrincar",
    "estarrincarde": "estarrincar",
    "estarrincardes": "estarrincar",
    "estarrincare": "estarrincar",
    "estarrincarei": "estarrincar",
    "estarrincareis": "estarrincar",
    "estarrincarem": "estarrincar",
    "estarrincaremos": "estarrincar",
    "estarrincares": "estarrincar",
    "estarrincaria": "estarrincar",
    "estarrincariam": "estarrincar",
    "estarrincarias": "estarrincar",
    "estarrincarmo": "estarrincar",
    "estarrincarmos": "estarrincar",
    "estarrincará": "estarrincar",
    "estarrincarás": "estarrincar",
    "estarrincarão": "estarrincar",
    "estarrincaríamos": "estarrincar",
    "estarrincaríeis": "estarrincar",
    "estarrincas": "estarrincar",
    "estarrincasse": "estarrincar",
    "estarrincassem": "estarrincar",
    "estarrincasses": "estarrincar",
    "estarrincaste": "estarrincar",
    "estarrincastes": "estarrincar",
    "estarrincava": "estarrincar",
    "estarrincavam": "estarrincar",
    "estarrincavas": "estarrincar",
    "estarrinco": "estarrincar",
    "estarrincou": "estarrincar",
    "estarrincá": "estarrincar",
    "estarrincámo": "estarrincar",
    "estarrincámos": "estarrincar",
    "estarrincáramo": "estarrincar",
    "estarrincáramos": "estarrincar",
    "estarrincárei": "estarrincar",
    "estarrincáreis": "estarrincar",
    "estarrincásseis": "estarrincar",
    "estarrincássemos": "estarrincar",
    "estarrincávamo": "estarrincar",
    "estarrincávamos": "estarrincar",
    "estarrincávei": "estarrincar",
    "estarrincáveis": "estarrincar",
    "estarrinque": "estarrincar",
    "estarrinquei": "estarrincar",
    "estarrinqueis": "estarrincar",
    "estarrinquem": "estarrincar",
    "estarrinquemo": "estarrincar",
    "estarrinquemos": "estarrincar",
    "estarrinques": "estarrincar",
    "estará": "estar",
    "estarás": "estar",
    "estarão": "estar",
    "estaríamos": "estar",
    "estaríeis": "estar",
    "estas": "este",
    "estaseamentos": "estaseamento",
    "estases": "estase",
    "estasiada": "estasiado",
    "estasiadas": "estasiado",
    "estasiados": "estasiado",
    "estatais": "estatal",
    "estatela": "estatelar",
    "estatelada": "estatelar",
    "estateladas": "estatelar",
    "estatelado": "estatelar",
    "estatelados": "estatelar",
    "estatelai": "estatelar",
    "estatelais": "estatelar",
    "estatelam": "estatelar",
    "estatelamentos": "estatelamento",
    "estatelamo": "estatelar",
    "estatelamos": "estatelar",
    "estatelando": "estatelar",
    "estatelara": "estatelar",
    "estatelaram": "estatelar",
    "estatelaras": "estatelar",
    "estatelarde": "estatelar",
    "estatelardes": "estatelar",
    "estatelare": "estatelar",
    "estatelarei": "estatelar",
    "estatelareis": "estatelar",
    "estatelarem": "estatelar",
    "estatelaremos": "estatelar",
    "estatelares": "estatelar",
    "estatelaria": "estatelar",
    "estatelariam": "estatelar",
    "estatelarias": "estatelar",
    "estatelarmo": "estatelar",
    "estatelarmos": "estatelar",
    "estatelará": "estatelar",
    "estatelarás": "estatelar",
    "estatelarão": "estatelar",
    "estatelaríamos": "estatelar",
    "estatelaríeis": "estatelar",
    "estatelas": "estatelar",
    "estatelasse": "estatelar",
    "estatelassem": "estatelar",
    "estatelasses": "estatelar",
    "estatelaste": "estatelar",
    "estatelastes": "estatelar",
    "estatelava": "estatelar",
    "estatelavam": "estatelar",
    "estatelavas": "estatelar",
    "estatelações": "estatelação",
    "estatele": "estatelar",
    "estatelei": "estatelar",
    "estateleis": "estatelar",
    "estatelem": "estatelar",
    "estatelemo": "estatelar",
    "estatelemos": "estatelar",
    "estateles": "estatelar",
    "estatelo": "estatelar",
    "estatelou": "estatelar",
    "estatelá": "estatelar",
    "estatelámo": "estatelar",
    "estatelámos": "estatelar",
    "estateláramo": "estatelar",
    "estateláramos": "estatelar",
    "estatelárei": "estatelar",
    "estateláreis": "estatelar",
    "estatelásseis": "estatelar",
    "estatelássemos": "estatelar",
    "estatelávamo": "estatelar",
    "estatelávamos": "estatelar",
    "estatelávei": "estatelar",
    "estateláveis": "estatelar",
    "estatestesias": "estatestesia",
    "estatestésica": "estatestésico",
    "estatestésicas": "estatestésico",
    "estatestésicos": "estatestésico",
    "estaticistas": "estaticista",
    "estatismos": "estatismo",
    "estatistas": "estatista",
    "estativa": "estativo",
    "estativas": "estativo",
    "estativos": "estativo",
    "estatizada": "estatizado",
    "estatizadas": "estatizado",
    "estatizadora": "estatizador",
    "estatizadoras": "estatizador",
    "estatizadores": "estatizador",
    "estatizados": "estatizado",
    "estatizações": "estatização",
    "estatores": "estator",
    "estatoscópica": "estatoscópico",
    "estatoscópicas": "estatoscópico",
    "estatoscópicos": "estatoscópico",
    "estatoscópios": "estatoscópio",
    "estatua": "estatuir",
    "estatuados": "estatuado",
    "estatuais": "estatuir",
    "estatuam": "estatuir",
    "estatuamo": "estatuir",
    "estatuamos": "estatuir",
    "estatuarias": "estatuaria",
    "estatuas": "estatuir",
    "estatucionais": "estatucional",
    "estatuem": "estatuir",
    "estatuetas": "estatueta",
    "estatui": "estatuir",
    "estatuindo": "estatuir",
    "estatuirde": "estatuir",
    "estatuirdes": "estatuir",
    "estatuirei": "estatuir",
    "estatuireis": "estatuir",
    "estatuiremos": "estatuir",
    "estatuiria": "estatuir",
    "estatuiriam": "estatuir",
    "estatuirias": "estatuir",
    "estatuirmo": "estatuir",
    "estatuirmos": "estatuir",
    "estatuirá": "estatuir",
    "estatuirás": "estatuir",
    "estatuirão": "estatuir",
    "estatuiríamos": "estatuir",
    "estatuiríeis": "estatuir",
    "estatuis": "estatuir",
    "estatuiu": "estatuir",
    "estatuo": "estatuir",
    "estaturas": "estatura",
    "estatutiva": "estatutivo",
    "estatutivas": "estatutivo",
    "estatutivos": "estatutivo",
    "estatutos": "estatuto",
    "estatutária": "estatutário",
    "estatutárias": "estatutário",
    "estatutários": "estatutário",
    "estatuária": "estatuário",
    "estatuárias": "estatuário",
    "estatuários": "estatuário",
    "estatuí": "estatuir",
    "estatuía": "estatuir",
    "estatuíam": "estatuir",
    "estatuíamo": "estatuir",
    "estatuíamos": "estatuir",
    "estatuías": "estatuir",
    "estatuída": "estatuir",
    "estatuídas": "estatuir",
    "estatuído": "estatuir",
    "estatuídos": "estatuir",
    "estatuíei": "estatuir",
    "estatuíeis": "estatuir",
    "estatuímo": "estatuir",
    "estatuímos": "estatuir",
    "estatuíra": "estatuir",
    "estatuíram": "estatuir",
    "estatuíramo": "estatuir",
    "estatuíramos": "estatuir",
    "estatuíras": "estatuir",
    "estatuíre": "estatuir",
    "estatuírei": "estatuir",
    "estatuíreis": "estatuir",
    "estatuírem": "estatuir",
    "estatuíres": "estatuir",
    "estatuís": "estatuir",
    "estatuísse": "estatuir",
    "estatuísseis": "estatuir",
    "estatuíssem": "estatuir",
    "estatuíssemos": "estatuir",
    "estatuísses": "estatuir",
    "estatuíste": "estatuir",
    "estatuístes": "estatuir",
    "estatística": "estatístico",
    "estatísticas": "estatístico",
    "estatísticos": "estatístico",
    "estaurolatrias": "estaurolatria",
    "estaurolátrica": "estaurolátrico",
    "estaurolátricas": "estaurolátrico",
    "estaurolátricos": "estaurolátrico",
    "estaurólatras": "estaurólatra",
    "estaurólitos": "estaurólito",
    "estaus": "estau",
    "estava": "estar",
    "estavam": "estar",
    "estavanada": "estavanado",
    "estavanadas": "estavanado",
    "estavanados": "estavanado",
    "estavas": "estar",
    "estaza": "estazar",
    "estazada": "estazar",
    "estazadas": "estazar",
    "estazado": "estazar",
    "estazadora": "estazador",
    "estazadoras": "estazador",
    "estazadores": "estazador",
    "estazados": "estazar",
    "estazai": "estazar",
    "estazais": "estazar",
    "estazam": "estazar",
    "estazamentos": "estazamento",
    "estazamo": "estazar",
    "estazamos": "estazar",
    "estazando": "estazar",
    "estazara": "estazar",
    "estazaram": "estazar",
    "estazaras": "estazar",
    "estazarde": "estazar",
    "estazardes": "estazar",
    "estazare": "estazar",
    "estazarei": "estazar",
    "estazareis": "estazar",
    "estazarem": "estazar",
    "estazaremos": "estazar",
    "estazares": "estazar",
    "estazaria": "estazar",
    "estazariam": "estazar",
    "estazarias": "estazar",
    "estazarmo": "estazar",
    "estazarmos": "estazar",
    "estazará": "estazar",
    "estazarás": "estazar",
    "estazarão": "estazar",
    "estazaríamos": "estazar",
    "estazaríeis": "estazar",
    "estazas": "estazar",
    "estazasse": "estazar",
    "estazassem": "estazar",
    "estazasses": "estazar",
    "estazaste": "estazar",
    "estazastes": "estazar",
    "estazava": "estazar",
    "estazavam": "estazar",
    "estazavas": "estazar",
    "estaze": "estazar",
    "estazei": "estazar",
    "estazeis": "estazar",
    "estazem": "estazar",
    "estazemo": "estazar",
    "estazemos": "estazar",
    "estazes": "estazar",
    "estazo": "estazar",
    "estazou": "estazar",
    "estazá": "estazar",
    "estazámo": "estazar",
    "estazámos": "estazar",
    "estazáramo": "estazar",
    "estazáramos": "estazar",
    "estazárei": "estazar",
    "estazáreis": "estazar",
    "estazásseis": "estazar",
    "estazássemos": "estazar",
    "estazávamo": "estazar",
    "estazávamos": "estazar",
    "estazávei": "estazar",
    "estazáveis": "estazar",
    "estações": "estação",
    "esteada": "estear",
    "esteadas": "estear",
    "esteado": "estear",
    "esteados": "estear",
    "esteai": "estear",
    "esteais": "estear",
    "esteamentos": "esteamento",
    "esteamo": "estear",
    "esteamos": "estear",
    "esteando": "estear",
    "esteara": "estear",
    "estearam": "estear",
    "estearas": "estear",
    "estearde": "estear",
    "esteardes": "estear",
    "esteare": "estear",
    "estearei": "estear",
    "esteareis": "estear",
    "estearem": "estear",
    "estearemos": "estear",
    "esteares": "estear",
    "estearia": "estear",
    "esteariam": "estear",
    "estearias": "estear",
    "estearinas": "estearina",
    "estearmo": "estear",
    "estearmos": "estear",
    "esteará": "estear",
    "estearás": "estear",
    "estearão": "estear",
    "estearíamos": "estear",
    "estearíeis": "estear",
    "esteasse": "estear",
    "esteassem": "estear",
    "esteasses": "estear",
    "esteaste": "estear",
    "esteastes": "estear",
    "esteatitas": "esteatita",
    "esteatites": "esteatite",
    "esteatomas": "esteatoma",
    "esteatopigias": "esteatopigia",
    "esteatopigíaca": "esteatopigíaco",
    "esteatopigíacas": "esteatopigíaco",
    "esteatopigíacos": "esteatopigíaco",
    "esteatómica": "esteatómico",
    "esteatómicas": "esteatómico",
    "esteatómicos": "esteatómico",
    "esteava": "estear",
    "esteavam": "estear",
    "esteavas": "estear",
    "esteei": "estear",
    "esteeis": "estear",
    "esteemo": "estear",
    "esteemos": "estear",
    "estefaniana": "estefaniano",
    "estefanianas": "estefaniano",
    "estefanianos": "estefaniano",
    "estefanotes": "estefanote",
    "estefânias": "estefânia",
    "esteganografias": "esteganografia",
    "esteganográfica": "esteganográfico",
    "esteganográficas": "esteganográfico",
    "esteganográficos": "esteganográfico",
    "esteganógrafos": "esteganógrafo",
    "esteganópodes": "esteganópode",
    "esteia": "estear",
    "esteiam": "estear",
    "esteias": "estear",
    "esteie": "estear",
    "esteiem": "estear",
    "esteies": "estear",
    "esteio": "estear",
    "esteios": "esteio",
    "esteira": "esteirar",
    "esteirada": "esteirar",
    "esteiradas": "esteirar",
    "esteirado": "esteirar",
    "esteirados": "esteirar",
    "esteirai": "esteirar",
    "esteirais": "esteirar",
    "esteiram": "esteirar",
    "esteiramo": "esteirar",
    "esteiramos": "esteirar",
    "esteirando": "esteirar",
    "esteirara": "esteirar",
    "esteiraram": "esteirar",
    "esteiraras": "esteirar",
    "esteirarde": "esteirar",
    "esteirardes": "esteirar",
    "esteirare": "esteirar",
    "esteirarei": "esteirar",
    "esteirareis": "esteirar",
    "esteirarem": "esteirar",
    "esteiraremos": "esteirar",
    "esteirares": "esteirar",
    "esteiraria": "esteirar",
    "esteirariam": "esteirar",
    "esteirarias": "esteiraria",
    "esteirarmo": "esteirar",
    "esteirarmos": "esteirar",
    "esteirará": "esteirar",
    "esteirarás": "esteirar",
    "esteirarão": "esteirar",
    "esteiraríamos": "esteirar",
    "esteiraríeis": "esteirar",
    "esteiras": "esteirar",
    "esteirasse": "esteirar",
    "esteirassem": "esteirar",
    "esteirasses": "esteirar",
    "esteiraste": "esteirar",
    "esteirastes": "esteirar",
    "esteirava": "esteirar",
    "esteiravam": "esteirar",
    "esteiravas": "esteirar",
    "esteirações": "esteiração",
    "esteire": "esteirar",
    "esteirei": "esteirar",
    "esteireis": "esteirar",
    "esteirem": "esteirar",
    "esteiremo": "esteirar",
    "esteiremos": "esteirar",
    "esteires": "esteirar",
    "esteiro": "esteirar",
    "esteiros": "esteiro",
    "esteirou": "esteirar",
    "esteirá": "esteirar",
    "esteirámo": "esteirar",
    "esteirámos": "esteirar",
    "esteiráramo": "esteirar",
    "esteiráramos": "esteirar",
    "esteirárei": "esteirar",
    "esteiráreis": "esteirar",
    "esteirásseis": "esteirar",
    "esteirássemos": "esteirar",
    "esteirávamo": "esteirar",
    "esteirávamos": "esteirar",
    "esteirávei": "esteirar",
    "esteiráveis": "esteirar",
    "esteirões": "esteirão",
    "esteja": "estar",
    "estejai": "estar",
    "estejais": "estar",
    "estejam": "estar",
    "estejamo": "estar",
    "estejamos": "estar",
    "estejas": "estar",
    "estela": "estelar",
    "estelada": "estelar",
    "esteladas": "estelar",
    "estelado": "estelar",
    "estelados": "estelar",
    "estelai": "estelar",
    "estelais": "estelar",
    "estelam": "estelar",
    "estelamo": "estelar",
    "estelamos": "estelar",
    "estelando": "estelar",
    "estelantes": "estelante",
    "estelara": "estelar",
    "estelaram": "estelar",
    "estelaras": "estelar",
    "estelarde": "estelar",
    "estelardes": "estelar",
    "estelare": "estelar",
    "estelarei": "estelar",
    "estelareis": "estelar",
    "estelarem": "estelar",
    "estelaremos": "estelar",
    "estelares": "estelar",
    "estelaria": "estelar",
    "estelariam": "estelar",
    "estelarias": "estelar",
    "estelarmo": "estelar",
    "estelarmos": "estelar",
    "estelará": "estelar",
    "estelarás": "estelar",
    "estelarão": "estelar",
    "estelaríamos": "estelar",
    "estelaríeis": "estelar",
    "estelas": "estelar",
    "estelasse": "estelar",
    "estelassem": "estelar",
    "estelasses": "estelar",
    "estelaste": "estelar",
    "estelastes": "estelar",
    "estelava": "estelar",
    "estelavam": "estelar",
    "estelavas": "estelar",
    "estele": "estelar",
    "estelei": "estelar",
    "esteleis": "estelar",
    "estelem": "estelar",
    "estelemo": "estelar",
    "estelemos": "estelar",
    "estelerídea": "estelerídeo",
    "estelerídeas": "estelerídeo",
    "estelerídeos": "estelerídeo",
    "esteleróides": "esteleróide",
    "esteles": "estelar",
    "estelionatos": "estelionato",
    "estelionatária": "estelionatário",
    "estelionatárias": "estelionatário",
    "estelionatários": "estelionatário",
    "estelo": "estelar",
    "estelografias": "estelografia",
    "estelografistas": "estelografista",
    "estelográfica": "estelográfico",
    "estelográficas": "estelográfico",
    "estelográficos": "estelográfico",
    "estelos": "estelo",
    "estelou": "estelar",
    "estelá": "estelar",
    "estelámo": "estelar",
    "estelámos": "estelar",
    "esteláramo": "estelar",
    "esteláramos": "estelar",
    "estelárei": "estelar",
    "esteláreis": "estelar",
    "estelásseis": "estelar",
    "estelássemos": "estelar",
    "estelávamo": "estelar",
    "estelávamos": "estelar",
    "estelávei": "estelar",
    "esteláveis": "estelar",
    "estelífera": "estelífero",
    "estelíferas": "estelífero",
    "estelíferos": "estelífero",
    "estelógrafos": "estelógrafo",
    "estemas": "estema",
    "estemática": "estemático",
    "estemáticas": "estemático",
    "estemáticos": "estemático",
    "estenda": "estender",
    "estendais": "estender",
    "estendaliana": "estendaliano",
    "estendalianas": "estendaliano",
    "estendalianos": "estendaliano",
    "estendam": "estender",
    "estendamo": "estender",
    "estendamos": "estender",
    "estendas": "estender",
    "estende": "estender",
    "estendedoiros": "estendedoiro",
    "estendedora": "estendedor",
    "estendedoras": "estendedor",
    "estendedores": "estendedor",
    "estendedouros": "estendedouro",
    "estendeduras": "estendedura",
    "estendei": "estender",
    "estendeis": "estender",
    "estendem": "estender",
    "estendemo": "estender",
    "estendemos": "estender",
    "estendendo": "estender",
    "estendera": "estender",
    "estenderam": "estender",
    "estenderas": "estender",
    "estenderde": "estender",
    "estenderdes": "estender",
    "estendere": "estender",
    "estenderei": "estender",
    "estendereis": "estender",
    "estenderem": "estender",
    "estenderemos": "estender",
    "estenderes": "estender",
    "estenderetes": "estenderete",
    "estenderia": "estender",
    "estenderiam": "estender",
    "estenderias": "estender",
    "estendermo": "estender",
    "estendermos": "estender",
    "estenderá": "estender",
    "estenderás": "estender",
    "estenderão": "estender",
    "estenderíamos": "estender",
    "estenderíeis": "estender",
    "estendes": "estender",
    "estendesse": "estender",
    "estendessem": "estender",
    "estendesses": "estender",
    "estendeste": "estender",
    "estendestes": "estender",
    "estendeu": "estender",
    "estendi": "estender",
    "estendia": "estender",
    "estendiam": "estender",
    "estendias": "estender",
    "estendida": "estendido",
    "estendidas": "estendido",
    "estendido": "estender",
    "estendidos": "estendido",
    "estendo": "estender",
    "estendê": "estender",
    "estendêramo": "estender",
    "estendêramos": "estender",
    "estendêrei": "estender",
    "estendêreis": "estender",
    "estendêsseis": "estender",
    "estendêssemos": "estender",
    "estendíamo": "estender",
    "estendíamos": "estender",
    "estendíei": "estender",
    "estendíeis": "estender",
    "estendíveis": "estendível",
    "estenias": "estenia",
    "estenocefálica": "estenocefálico",
    "estenocefálicas": "estenocefálico",
    "estenocefálicos": "estenocefálico",
    "estenocéfala": "estenocéfalo",
    "estenocéfalas": "estenocéfalo",
    "estenocéfalos": "estenocéfalo",
    "estenodactilografias": "estenodactilografia",
    "estenodactilógrafa": "estenodactilógrafo",
    "estenodactilógrafas": "estenodactilógrafo",
    "estenodactilógrafos": "estenodactilógrafo",
    "estenografa": "estenografar",
    "estenografada": "estenografar",
    "estenografadas": "estenografar",
    "estenografado": "estenografar",
    "estenografados": "estenografar",
    "estenografai": "estenografar",
    "estenografais": "estenografar",
    "estenografam": "estenografar",
    "estenografamo": "estenografar",
    "estenografamos": "estenografar",
    "estenografando": "estenografar",
    "estenografara": "estenografar",
    "estenografaram": "estenografar",
    "estenografaras": "estenografar",
    "estenografarde": "estenografar",
    "estenografardes": "estenografar",
    "estenografare": "estenografar",
    "estenografarei": "estenografar",
    "estenografareis": "estenografar",
    "estenografarem": "estenografar",
    "estenografaremos": "estenografar",
    "estenografares": "estenografar",
    "estenografaria": "estenografar",
    "estenografariam": "estenografar",
    "estenografarias": "estenografar",
    "estenografarmo": "estenografar",
    "estenografarmos": "estenografar",
    "estenografará": "estenografar",
    "estenografarás": "estenografar",
    "estenografarão": "estenografar",
    "estenografaríamos": "estenografar",
    "estenografaríeis": "estenografar",
    "estenografas": "estenografar",
    "estenografasse": "estenografar",
    "estenografassem": "estenografar",
    "estenografasses": "estenografar",
    "estenografaste": "estenografar",
    "estenografastes": "estenografar",
    "estenografava": "estenografar",
    "estenografavam": "estenografar",
    "estenografavas": "estenografar",
    "estenografe": "estenografar",
    "estenografei": "estenografar",
    "estenografeis": "estenografar",
    "estenografem": "estenografar",
    "estenografemo": "estenografar",
    "estenografemos": "estenografar",
    "estenografes": "estenografar",
    "estenografias": "estenografia",
    "estenografo": "estenografar",
    "estenografou": "estenografar",
    "estenografá": "estenografar",
    "estenografámo": "estenografar",
    "estenografámos": "estenografar",
    "estenografáramo": "estenografar",
    "estenografáramos": "estenografar",
    "estenografárei": "estenografar",
    "estenografáreis": "estenografar",
    "estenografásseis": "estenografar",
    "estenografássemos": "estenografar",
    "estenografávamo": "estenografar",
    "estenografávamos": "estenografar",
    "estenografávei": "estenografar",
    "estenografáveis": "estenografar",
    "estenográfica": "estenográfico",
    "estenográficas": "estenográfico",
    "estenográficos": "estenográfico",
    "estenoses": "estenose",
    "estenoterma": "estenotermo",
    "estenotermas": "estenotermo",
    "estenotermos": "estenotermo",
    "estenotérmoca": "estenotérmoco",
    "estenotérmocas": "estenotérmoco",
    "estenotérmocos": "estenotérmoco",
    "estentora": "estentor",
    "estentoras": "estentor",
    "estentores": "estentor",
    "estentórea": "estentóreo",
    "estentóreas": "estentóreo",
    "estentóreos": "estentóreo",
    "estentórica": "estentórico",
    "estentóricas": "estentórico",
    "estentóricos": "estentórico",
    "estenógrafa": "estenógrafo",
    "estenógrafas": "estenógrafo",
    "estenógrafos": "estenógrafo",
    "esteou": "estear",
    "estepada": "estepado",
    "estepadas": "estepado",
    "estepados": "estepado",
    "estepes": "estepe",
    "estequiometrias": "estequiometria",
    "estequiométrica": "estequiométrico",
    "estequiométricas": "estequiométrico",
    "estequiométricos": "estequiométrico",
    "estequiómetros": "estequiómetro",
    "esterca": "estercar",
    "estercada": "estercar",
    "estercadas": "estercar",
    "estercado": "estercar",
    "estercadora": "estercador",
    "estercadoras": "estercador",
    "estercadores": "estercador",
    "estercados": "estercar",
    "estercaduras": "estercadura",
    "estercai": "estercar",
    "estercais": "estercar",
    "estercam": "estercar",
    "estercamo": "estercar",
    "estercamos": "estercar",
    "estercando": "estercar",
    "estercara": "estercar",
    "estercaram": "estercar",
    "estercaras": "estercar",
    "estercarde": "estercar",
    "estercardes": "estercar",
    "estercare": "estercar",
    "estercarei": "estercar",
    "estercareis": "estercar",
    "estercarem": "estercar",
    "estercaremos": "estercar",
    "estercares": "estercar",
    "estercaria": "estercar",
    "estercariam": "estercar",
    "estercarias": "estercar",
    "estercarmo": "estercar",
    "estercarmos": "estercar",
    "estercará": "estercar",
    "estercarás": "estercar",
    "estercarão": "estercar",
    "estercaríamos": "estercar",
    "estercaríeis": "estercar",
    "estercas": "estercar",
    "estercasse": "estercar",
    "estercassem": "estercar",
    "estercasses": "estercar",
    "estercaste": "estercar",
    "estercastes": "estercar",
    "estercava": "estercar",
    "estercavam": "estercar",
    "estercavas": "estercar",
    "esterco": "estercar",
    "estercorais": "estercoral",
    "estercoreira": "estercoreiro",
    "estercoreiras": "estercoreiro",
    "estercoreiros": "estercoreiro",
    "estercoremias": "estercoremia",
    "estercorosa": "estercoroso",
    "estercorosas": "estercoroso",
    "estercorosos": "estercoroso",
    "estercorária": "estercorário",
    "estercorárias": "estercorário",
    "estercorários": "estercorário",
    "estercos": "esterco",
    "estercou": "estercar",
    "esterculeáceas": "esterculeácea",
    "estercá": "estercar",
    "estercámo": "estercar",
    "estercámos": "estercar",
    "estercáramo": "estercar",
    "estercáramos": "estercar",
    "estercárei": "estercar",
    "estercáreis": "estercar",
    "estercásseis": "estercar",
    "estercássemos": "estercar",
    "estercávamo": "estercar",
    "estercávamos": "estercar",
    "estercávei": "estercar",
    "estercáveis": "estercar",
    "estereocorémica": "estereocorémico",
    "estereocorémicas": "estereocorémico",
    "estereocorémicos": "estereocorémico",
    "estereodinâmicas": "estereodinâmica",
    "estereodontes": "estereodonte",
    "estereofonias": "estereofonia",
    "estereofónica": "estereofónico",
    "estereofónicas": "estereofónico",
    "estereofónicos": "estereofónico",
    "estereografias": "estereografia",
    "estereogramas": "estereograma",
    "estereogrametrias": "estereogrametria",
    "estereogramétrica": "estereogramétrico",
    "estereogramétricas": "estereogramétrico",
    "estereogramétricos": "estereogramétrico",
    "estereográfica": "estereográfico",
    "estereográficas": "estereográfico",
    "estereográficos": "estereográfico",
    "estereoisomerismos": "estereoisomerismo",
    "estereoisomérica": "estereoisomérico",
    "estereoisoméricas": "estereoisomérico",
    "estereoisoméricos": "estereoisomérico",
    "estereoisómera": "estereoisómero",
    "estereoisómeras": "estereoisómero",
    "estereoisómeros": "estereoisómero",
    "estereologias": "estereologia",
    "estereológica": "estereológico",
    "estereológicas": "estereológico",
    "estereológicos": "estereológico",
    "estereomas": "estereoma",
    "estereometrias": "estereometria",
    "estereométrica": "estereométrico",
    "estereométricas": "estereométrico",
    "estereométricos": "estereométrico",
    "estereoquímica": "estereoquímico",
    "estereoquímicas": "estereoquímico",
    "estereoquímicos": "estereoquímico",
    "estereoramas": "estereorama",
    "estereoscopias": "estereoscopia",
    "estereoscópica": "estereoscópico",
    "estereoscópicas": "estereoscópico",
    "estereoscópicos": "estereoscópico",
    "estereoscópios": "estereoscópio",
    "estereotipa": "estereotipar",
    "estereotipada": "estereotipar",
    "estereotipadas": "estereotipar",
    "estereotipado": "estereotipar",
    "estereotipados": "estereotipar",
    "estereotipagens": "estereotipagem",
    "estereotipai": "estereotipar",
    "estereotipais": "estereotipar",
    "estereotipam": "estereotipar",
    "estereotipamo": "estereotipar",
    "estereotipamos": "estereotipar",
    "estereotipando": "estereotipar",
    "estereotipara": "estereotipar",
    "estereotiparam": "estereotipar",
    "estereotiparas": "estereotipar",
    "estereotiparde": "estereotipar",
    "estereotipardes": "estereotipar",
    "estereotipare": "estereotipar",
    "estereotiparei": "estereotipar",
    "estereotipareis": "estereotipar",
    "estereotiparem": "estereotipar",
    "estereotiparemos": "estereotipar",
    "estereotipares": "estereotipar",
    "estereotiparia": "estereotipar",
    "estereotipariam": "estereotipar",
    "estereotiparias": "estereotipar",
    "estereotiparmo": "estereotipar",
    "estereotiparmos": "estereotipar",
    "estereotipará": "estereotipar",
    "estereotiparás": "estereotipar",
    "estereotiparão": "estereotipar",
    "estereotiparíamos": "estereotipar",
    "estereotiparíeis": "estereotipar",
    "estereotipas": "estereotipar",
    "estereotipasse": "estereotipar",
    "estereotipassem": "estereotipar",
    "estereotipasses": "estereotipar",
    "estereotipaste": "estereotipar",
    "estereotipastes": "estereotipar",
    "estereotipava": "estereotipar",
    "estereotipavam": "estereotipar",
    "estereotipavas": "estereotipar",
    "estereotipe": "estereotipar",
    "estereotipei": "estereotipar",
    "estereotipeis": "estereotipar",
    "estereotipem": "estereotipar",
    "estereotipemo": "estereotipar",
    "estereotipemos": "estereotipar",
    "estereotipes": "estereotipar",
    "estereotipias": "estereotipia",
    "estereotipo": "estereotipar",
    "estereotipou": "estereotipar",
    "estereotipá": "estereotipar",
    "estereotipámo": "estereotipar",
    "estereotipámos": "estereotipar",
    "estereotipáramo": "estereotipar",
    "estereotipáramos": "estereotipar",
    "estereotipárei": "estereotipar",
    "estereotipáreis": "estereotipar",
    "estereotipásseis": "estereotipar",
    "estereotipássemos": "estereotipar",
    "estereotipávamo": "estereotipar",
    "estereotipávamos": "estereotipar",
    "estereotipávei": "estereotipar",
    "estereotipáveis": "estereotipável",
    "estereotípica": "estereotípico",
    "estereotípicas": "estereotípico",
    "estereotípicos": "estereotípico",
    "esteres": "estere",
    "estereóloga": "estereólogo",
    "estereólogas": "estereólogo",
    "estereólogos": "estereólogo",
    "estereómetros": "estereómetro",
    "estereótipos": "estereótipo",
    "esterifica": "esterificar",
    "esterificada": "esterificar",
    "esterificadas": "esterificar",
    "esterificado": "esterificar",
    "esterificados": "esterificar",
    "esterificai": "esterificar",
    "esterificais": "esterificar",
    "esterificam": "esterificar",
    "esterificamo": "esterificar",
    "esterificamos": "esterificar",
    "esterificando": "esterificar",
    "esterificara": "esterificar",
    "esterificaram": "esterificar",
    "esterificaras": "esterificar",
    "esterificarde": "esterificar",
    "esterificardes": "esterificar",
    "esterificare": "esterificar",
    "esterificarei": "esterificar",
    "esterificareis": "esterificar",
    "esterificarem": "esterificar",
    "esterificaremos": "esterificar",
    "esterificares": "esterificar",
    "esterificaria": "esterificar",
    "esterificariam": "esterificar",
    "esterificarias": "esterificar",
    "esterificarmo": "esterificar",
    "esterificarmos": "esterificar",
    "esterificará": "esterificar",
    "esterificarás": "esterificar",
    "esterificarão": "esterificar",
    "esterificaríamos": "esterificar",
    "esterificaríeis": "esterificar",
    "esterificas": "esterificar",
    "esterificasse": "esterificar",
    "esterificassem": "esterificar",
    "esterificasses": "esterificar",
    "esterificaste": "esterificar",
    "esterificastes": "esterificar",
    "esterificava": "esterificar",
    "esterificavam": "esterificar",
    "esterificavas": "esterificar",
    "esterificações": "esterificação",
    "esterifico": "esterificar",
    "esterificou": "esterificar",
    "esterificá": "esterificar",
    "esterificámo": "esterificar",
    "esterificámos": "esterificar",
    "esterificáramo": "esterificar",
    "esterificáramos": "esterificar",
    "esterificárei": "esterificar",
    "esterificáreis": "esterificar",
    "esterificásseis": "esterificar",
    "esterificássemos": "esterificar",
    "esterificávamo": "esterificar",
    "esterificávamos": "esterificar",
    "esterificávei": "esterificar",
    "esterificáveis": "esterificar",
    "esterifique": "esterificar",
    "esterifiquei": "esterificar",
    "esterifiqueis": "esterificar",
    "esterifiquem": "esterificar",
    "esterifiquemo": "esterificar",
    "esterifiquemos": "esterificar",
    "esterifiques": "esterificar",
    "esterilidades": "esterilidade",
    "esteriliza": "esterilizar",
    "esterilizada": "esterilizar",
    "esterilizadas": "esterilizar",
    "esterilizado": "esterilizar",
    "esterilizadora": "esterilizador",
    "esterilizadoras": "esterilizador",
    "esterilizadores": "esterilizador",
    "esterilizados": "esterilizar",
    "esterilizai": "esterilizar",
    "esterilizais": "esterilizar",
    "esterilizam": "esterilizar",
    "esterilizamentos": "esterilizamento",
    "esterilizamo": "esterilizar",
    "esterilizamos": "esterilizar",
    "esterilizando": "esterilizar",
    "esterilizantes": "esterilizante",
    "esterilizara": "esterilizar",
    "esterilizaram": "esterilizar",
    "esterilizaras": "esterilizar",
    "esterilizarde": "esterilizar",
    "esterilizardes": "esterilizar",
    "esterilizare": "esterilizar",
    "esterilizarei": "esterilizar",
    "esterilizareis": "esterilizar",
    "esterilizarem": "esterilizar",
    "esterilizaremos": "esterilizar",
    "esterilizares": "esterilizar",
    "esterilizaria": "esterilizar",
    "esterilizariam": "esterilizar",
    "esterilizarias": "esterilizar",
    "esterilizarmo": "esterilizar",
    "esterilizarmos": "esterilizar",
    "esterilizará": "esterilizar",
    "esterilizarás": "esterilizar",
    "esterilizarão": "esterilizar",
    "esterilizaríamos": "esterilizar",
    "esterilizaríeis": "esterilizar",
    "esterilizas": "esterilizar",
    "esterilizasse": "esterilizar",
    "esterilizassem": "esterilizar",
    "esterilizasses": "esterilizar",
    "esterilizaste": "esterilizar",
    "esterilizastes": "esterilizar",
    "esterilizava": "esterilizar",
    "esterilizavam": "esterilizar",
    "esterilizavas": "esterilizar",
    "esterilizações": "esterilização",
    "esterilize": "esterilizar",
    "esterilizei": "esterilizar",
    "esterilizeis": "esterilizar",
    "esterilizem": "esterilizar",
    "esterilizemo": "esterilizar",
    "esterilizemos": "esterilizar",
    "esterilizes": "esterilizar",
    "esterilizo": "esterilizar",
    "esterilizou": "esterilizar",
    "esterilizá": "esterilizar",
    "esterilizámo": "esterilizar",
    "esterilizámos": "esterilizar",
    "esterilizáramo": "esterilizar",
    "esterilizáramos": "esterilizar",
    "esterilizárei": "esterilizar",
    "esterilizáreis": "esterilizar",
    "esterilizásseis": "esterilizar",
    "esterilizássemos": "esterilizar",
    "esterilizávamo": "esterilizar",
    "esterilizávamos": "esterilizar",
    "esterilizávei": "esterilizar",
    "esterilizáveis": "esterilizável",
    "esterlica": "esterlicar",
    "esterlicada": "esterlicar",
    "esterlicadas": "esterlicar",
    "esterlicado": "esterlicar",
    "esterlicados": "esterlicar",
    "esterlicai": "esterlicar",
    "esterlicais": "esterlicar",
    "esterlicam": "esterlicar",
    "esterlicamo": "esterlicar",
    "esterlicamos": "esterlicar",
    "esterlicando": "esterlicar",
    "esterlicara": "esterlicar",
    "esterlicaram": "esterlicar",
    "esterlicaras": "esterlicar",
    "esterlicarde": "esterlicar",
    "esterlicardes": "esterlicar",
    "esterlicare": "esterlicar",
    "esterlicarei": "esterlicar",
    "esterlicareis": "esterlicar",
    "esterlicarem": "esterlicar",
    "esterlicaremos": "esterlicar",
    "esterlicares": "esterlicar",
    "esterlicaria": "esterlicar",
    "esterlicariam": "esterlicar",
    "esterlicarias": "esterlicar",
    "esterlicarmo": "esterlicar",
    "esterlicarmos": "esterlicar",
    "esterlicará": "esterlicar",
    "esterlicarás": "esterlicar",
    "esterlicarão": "esterlicar",
    "esterlicaríamos": "esterlicar",
    "esterlicaríeis": "esterlicar",
    "esterlicas": "esterlicar",
    "esterlicasse": "esterlicar",
    "esterlicassem": "esterlicar",
    "esterlicasses": "esterlicar",
    "esterlicaste": "esterlicar",
    "esterlicastes": "esterlicar",
    "esterlicava": "esterlicar",
    "esterlicavam": "esterlicar",
    "esterlicavas": "esterlicar",
    "esterlico": "esterlicar",
    "esterlicou": "esterlicar",
    "esterlicá": "esterlicar",
    "esterlicámo": "esterlicar",
    "esterlicámos": "esterlicar",
    "esterlicáramo": "esterlicar",
    "esterlicáramos": "esterlicar",
    "esterlicárei": "esterlicar",
    "esterlicáreis": "esterlicar",
    "esterlicásseis": "esterlicar",
    "esterlicássemos": "esterlicar",
    "esterlicávamo": "esterlicar",
    "esterlicávamos": "esterlicar",
    "esterlicávei": "esterlicar",
    "esterlicáveis": "esterlicar",
    "esterlina": "esterlino",
    "esterlinas": "esterlino",
    "esterlinos": "esterlino",
    "esterlique": "esterlicar",
    "esterliquei": "esterlicar",
    "esterliqueis": "esterlicar",
    "esterliquem": "esterlicar",
    "esterliquemo": "esterlicar",
    "esterliquemos": "esterlicar",
    "esterliques": "esterlicar",
    "esternais": "esternal",
    "esternalgias": "esternalgia",
    "esternites": "esternite",
    "esternos": "esterno",
    "esternutatória": "esternutatório",
    "esternutatórias": "esternutatório",
    "esternutatórios": "esternutatório",
    "esternutações": "esternutação",
    "esternálgica": "esternálgico",
    "esternálgicas": "esternálgico",
    "esternálgicos": "esternálgico",
    "esternítica": "esternítico",
    "esterníticas": "esternítico",
    "esterníticos": "esternítico",
    "esteros": "estero",
    "esterque": "estercar",
    "esterquei": "estercar",
    "esterqueiras": "esterqueira",
    "esterqueiros": "esterqueiro",
    "esterqueis": "estercar",
    "esterquem": "estercar",
    "esterquemo": "estercar",
    "esterquemos": "estercar",
    "esterques": "estercar",
    "esterquices": "esterquice",
    "esterquilinos": "esterquilino",
    "esterquilínios": "esterquilínio",
    "esterradianos": "esterradiano",
    "esterroa": "esterroar",
    "esterroada": "esterroar",
    "esterroadas": "esterroar",
    "esterroado": "esterroar",
    "esterroadores": "esterroador",
    "esterroados": "esterroar",
    "esterroai": "esterroar",
    "esterroais": "esterroar",
    "esterroam": "esterroar",
    "esterroamentos": "esterroamento",
    "esterroamo": "esterroar",
    "esterroamos": "esterroar",
    "esterroando": "esterroar",
    "esterroara": "esterroar",
    "esterroaram": "esterroar",
    "esterroaras": "esterroar",
    "esterroarde": "esterroar",
    "esterroardes": "esterroar",
    "esterroare": "esterroar",
    "esterroarei": "esterroar",
    "esterroareis": "esterroar",
    "esterroarem": "esterroar",
    "esterroaremos": "esterroar",
    "esterroares": "esterroar",
    "esterroaria": "esterroar",
    "esterroariam": "esterroar",
    "esterroarias": "esterroar",
    "esterroarmo": "esterroar",
    "esterroarmos": "esterroar",
    "esterroará": "esterroar",
    "esterroarás": "esterroar",
    "esterroarão": "esterroar",
    "esterroaríamos": "esterroar",
    "esterroaríeis": "esterroar",
    "esterroas": "esterroar",
    "esterroasse": "esterroar",
    "esterroassem": "esterroar",
    "esterroasses": "esterroar",
    "esterroaste": "esterroar",
    "esterroastes": "esterroar",
    "esterroava": "esterroar",
    "esterroavam": "esterroar",
    "esterroavas": "esterroar",
    "esterroe": "esterroar",
    "esterroei": "esterroar",
    "esterroeis": "esterroar",
    "esterroem": "esterroar",
    "esterroemo": "esterroar",
    "esterroemos": "esterroar",
    "esterroes": "esterroar",
    "esterroo": "esterroar",
    "esterroou": "esterroar",
    "esterroá": "esterroar",
    "esterroámo": "esterroar",
    "esterroámos": "esterroar",
    "esterroáramo": "esterroar",
    "esterroáramos": "esterroar",
    "esterroárei": "esterroar",
    "esterroáreis": "esterroar",
    "esterroásseis": "esterroar",
    "esterroássemos": "esterroar",
    "esterroávamo": "esterroar",
    "esterroávamos": "esterroar",
    "esterroávei": "esterroar",
    "esterroáveis": "esterroar",
    "estertoa": "estertoar",
    "estertoada": "estertoar",
    "estertoadas": "estertoar",
    "estertoado": "estertoar",
    "estertoados": "estertoar",
    "estertoai": "estertoar",
    "estertoais": "estertoar",
    "estertoam": "estertoar",
    "estertoamo": "estertoar",
    "estertoamos": "estertoar",
    "estertoando": "estertoar",
    "estertoara": "estertoar",
    "estertoaram": "estertoar",
    "estertoaras": "estertoar",
    "estertoardes": "estertoar",
    "estertoarei": "estertoar",
    "estertoareis": "estertoar",
    "estertoarem": "estertoar",
    "estertoaremos": "estertoar",
    "estertoares": "estertoar",
    "estertoaria": "estertoar",
    "estertoariam": "estertoar",
    "estertoarias": "estertoar",
    "estertoarmo": "estertoar",
    "estertoarmos": "estertoar",
    "estertoará": "estertoar",
    "estertoarás": "estertoar",
    "estertoarão": "estertoar",
    "estertoaríamos": "estertoar",
    "estertoaríeis": "estertoar",
    "estertoas": "estertoar",
    "estertoasse": "estertoar",
    "estertoassem": "estertoar",
    "estertoasses": "estertoar",
    "estertoaste": "estertoar",
    "estertoastes": "estertoar",
    "estertoava": "estertoar",
    "estertoavam": "estertoar",
    "estertoavas": "estertoar",
    "estertoe": "estertoar",
    "estertoei": "estertoar",
    "estertoeis": "estertoar",
    "estertoem": "estertoar",
    "estertoemo": "estertoar",
    "estertoemos": "estertoar",
    "estertoes": "estertoar",
    "estertoo": "estertoar",
    "estertoou": "estertoar",
    "estertores": "estertor",
    "estertorosa": "estertoroso",
    "estertorosas": "estertoroso",
    "estertorosos": "estertoroso",
    "estertoámo": "estertoar",
    "estertoámos": "estertoar",
    "estertoáramo": "estertoar",
    "estertoáramos": "estertoar",
    "estertoáreis": "estertoar",
    "estertoásseis": "estertoar",
    "estertoássemos": "estertoar",
    "estertoávamo": "estertoar",
    "estertoávamos": "estertoar",
    "estertoáveis": "estertoar",
    "esteróides": "esteróide",
    "esteróis": "esterol",
    "estes": "este",
    "esteseolósica": "esteseolósico",
    "esteseolósicas": "esteseolósico",
    "esteseolósicos": "esteseolósico",
    "esteses": "estese",
    "estesia": "estesiar",
    "estesiada": "estesiar",
    "estesiadas": "estesiar",
    "estesiado": "estesiar",
    "estesiados": "estesiar",
    "estesiai": "estesiar",
    "estesiais": "estesiar",
    "estesiam": "estesiar",
    "estesiamo": "estesiar",
    "estesiamos": "estesiar",
    "estesiando": "estesiar",
    "estesiara": "estesiar",
    "estesiaram": "estesiar",
    "estesiaras": "estesiar",
    "estesiarde": "estesiar",
    "estesiardes": "estesiar",
    "estesiare": "estesiar",
    "estesiarei": "estesiar",
    "estesiareis": "estesiar",
    "estesiarem": "estesiar",
    "estesiaremos": "estesiar",
    "estesiares": "estesiar",
    "estesiaria": "estesiar",
    "estesiariam": "estesiar",
    "estesiarias": "estesiar",
    "estesiarmo": "estesiar",
    "estesiarmos": "estesiar",
    "estesiará": "estesiar",
    "estesiarás": "estesiar",
    "estesiarão": "estesiar",
    "estesiaríamos": "estesiar",
    "estesiaríeis": "estesiar",
    "estesias": "estesiar",
    "estesiasse": "estesiar",
    "estesiassem": "estesiar",
    "estesiasses": "estesiar",
    "estesiaste": "estesiar",
    "estesiastes": "estesiar",
    "estesiava": "estesiar",
    "estesiavam": "estesiar",
    "estesiavas": "estesiar",
    "estesie": "estesiar",
    "estesiei": "estesiar",
    "estesieis": "estesiar",
    "estesiem": "estesiar",
    "estesiemo": "estesiar",
    "estesiemos": "estesiar",
    "estesies": "estesiar",
    "estesio": "estesiar",
    "estesiologistas": "estesiologista",
    "estesiou": "estesiar",
    "estesiá": "estesiar",
    "estesiámo": "estesiar",
    "estesiámos": "estesiar",
    "estesiáramo": "estesiar",
    "estesiáramos": "estesiar",
    "estesiárei": "estesiar",
    "estesiáreis": "estesiar",
    "estesiásseis": "estesiar",
    "estesiássemos": "estesiar",
    "estesiávamo": "estesiar",
    "estesiávamos": "estesiar",
    "estesiávei": "estesiar",
    "estesiáveis": "estesiar",
    "estetas": "esteta",
    "esteticismos": "esteticismo",
    "esteticistas": "esteticista",
    "estetismos": "estetismo",
    "estetiza": "estetizar",
    "estetizada": "estetizar",
    "estetizadas": "estetizar",
    "estetizado": "estetizar",
    "estetizados": "estetizar",
    "estetizai": "estetizar",
    "estetizais": "estetizar",
    "estetizam": "estetizar",
    "estetizamo": "estetizar",
    "estetizamos": "estetizar",
    "estetizando": "estetizar",
    "estetizara": "estetizar",
    "estetizaram": "estetizar",
    "estetizaras": "estetizar",
    "estetizarde": "estetizar",
    "estetizardes": "estetizar",
    "estetizare": "estetizar",
    "estetizarei": "estetizar",
    "estetizareis": "estetizar",
    "estetizarem": "estetizar",
    "estetizaremos": "estetizar",
    "estetizares": "estetizar",
    "estetizaria": "estetizar",
    "estetizariam": "estetizar",
    "estetizarias": "estetizar",
    "estetizarmo": "estetizar",
    "estetizarmos": "estetizar",
    "estetizará": "estetizar",
    "estetizarás": "estetizar",
    "estetizarão": "estetizar",
    "estetizaríamos": "estetizar",
    "estetizaríeis": "estetizar",
    "estetizas": "estetizar",
    "estetizasse": "estetizar",
    "estetizassem": "estetizar",
    "estetizasses": "estetizar",
    "estetizaste": "estetizar",
    "estetizastes": "estetizar",
    "estetizava": "estetizar",
    "estetizavam": "estetizar",
    "estetizavas": "estetizar",
    "estetize": "estetizar",
    "estetizei": "estetizar",
    "estetizeis": "estetizar",
    "estetizem": "estetizar",
    "estetizemo": "estetizar",
    "estetizemos": "estetizar",
    "estetizes": "estetizar",
    "estetizo": "estetizar",
    "estetizou": "estetizar",
    "estetizá": "estetizar",
    "estetizámo": "estetizar",
    "estetizámos": "estetizar",
    "estetizáramo": "estetizar",
    "estetizáramos": "estetizar",
    "estetizárei": "estetizar",
    "estetizáreis": "estetizar",
    "estetizásseis": "estetizar",
    "estetizássemos": "estetizar",
    "estetizávamo": "estetizar",
    "estetizávamos": "estetizar",
    "estetizávei": "estetizar",
    "estetizáveis": "estetizar",
    "estetografias": "estetografia",
    "estetográfica": "estetográfico",
    "estetográficas": "estetográfico",
    "estetográficos": "estetográfico",
    "estetometrias": "estetometria",
    "estetométrica": "estetométrico",
    "estetométricas": "estetométrico",
    "estetométricos": "estetométrico",
    "estetoscopias": "estetoscopia",
    "estetoscópica": "estetoscópico",
    "estetoscópicas": "estetoscópico",
    "estetoscópicos": "estetoscópico",
    "estetoscópios": "estetoscópio",
    "estetógrafos": "estetógrafo",
    "estetómetros": "estetómetro",
    "esteva": "estevar",
    "estevada": "estevar",
    "estevadas": "estevar",
    "estevado": "estevar",
    "estevados": "estevar",
    "estevai": "estevar",
    "estevais": "estevar",
    "estevam": "estevar",
    "estevamo": "estevar",
    "estevamos": "estevar",
    "estevando": "estevar",
    "estevara": "estevar",
    "estevaram": "estevar",
    "estevaras": "estevar",
    "estevardes": "estevar",
    "estevarei": "estevar",
    "estevareis": "estevar",
    "estevarem": "estevar",
    "estevaremos": "estevar",
    "estevares": "estevar",
    "estevaria": "estevar",
    "estevariam": "estevar",
    "estevarias": "estevar",
    "estevarmo": "estevar",
    "estevarmos": "estevar",
    "estevará": "estevar",
    "estevarás": "estevar",
    "estevarão": "estevar",
    "estevaríamos": "estevar",
    "estevaríeis": "estevar",
    "estevas": "estevar",
    "estevasse": "estevar",
    "estevassem": "estevar",
    "estevasses": "estevar",
    "estevaste": "estevar",
    "estevastes": "estevar",
    "estevava": "estevar",
    "estevavam": "estevar",
    "estevavas": "estevar",
    "esteve": "estevar",
    "estevei": "estevar",
    "esteveis": "estevar",
    "estevem": "estevar",
    "estevemo": "estevar",
    "estevemos": "estevar",
    "esteves": "estevar",
    "estevo": "estevar",
    "estevou": "estevar",
    "estevámo": "estevar",
    "estevámos": "estevar",
    "esteváramo": "estevar",
    "esteváramos": "estevar",
    "esteváreis": "estevar",
    "estevásseis": "estevar",
    "estevássemos": "estevar",
    "estevávamo": "estevar",
    "estevávamos": "estevar",
    "esteváveis": "estevar",
    "estevões": "estevão",
    "esteá": "estear",
    "esteámo": "estear",
    "esteámos": "estear",
    "esteáramo": "estear",
    "esteáramos": "estear",
    "esteárei": "estear",
    "esteáreis": "estear",
    "esteárica": "esteárico",
    "esteáricas": "esteárico",
    "esteáricos": "esteárico",
    "esteásseis": "estear",
    "esteássemos": "estear",
    "esteávamo": "estear",
    "esteávamos": "estear",
    "esteávei": "estear",
    "esteáveis": "estear",
    "estia": "estiar",
    "estiada": "estiar",
    "estiadas": "estiar",
    "estiado": "estiar",
    "estiados": "estiar",
    "estiagens": "estiagem",
    "estiai": "estiar",
    "estiais": "estiar",
    "estiam": "estiar",
    "estiamo": "estiar",
    "estiamos": "estiar",
    "estiando": "estiar",
    "estiara": "estiar",
    "estiaram": "estiar",
    "estiaras": "estiar",
    "estiardes": "estiar",
    "estiarei": "estiar",
    "estiareis": "estiar",
    "estiarem": "estiar",
    "estiaremos": "estiar",
    "estiares": "estiar",
    "estiaria": "estiar",
    "estiariam": "estiar",
    "estiarias": "estiar",
    "estiarmo": "estiar",
    "estiarmos": "estiar",
    "estiará": "estiar",
    "estiarás": "estiar",
    "estiarão": "estiar",
    "estiaríamos": "estiar",
    "estiaríeis": "estiar",
    "estias": "estiar",
    "estiasse": "estiar",
    "estiassem": "estiar",
    "estiasses": "estiar",
    "estiaste": "estiar",
    "estiastes": "estiar",
    "estiava": "estiar",
    "estiavam": "estiar",
    "estiavas": "estiar",
    "estibinas": "estibina",
    "estibordos": "estibordo",
    "estica": "esticar",
    "esticada": "esticar",
    "esticadas": "esticar",
    "esticadelas": "esticadela",
    "esticado": "esticar",
    "esticadora": "esticador",
    "esticadoras": "esticador",
    "esticadores": "esticador",
    "esticados": "esticar",
    "esticadíssima": "esticado",
    "esticadíssimas": "esticado",
    "esticadíssimo": "esticado",
    "esticadíssimos": "esticado",
    "esticai": "esticar",
    "esticais": "esticar",
    "esticam": "esticar",
    "esticamo": "esticar",
    "esticamos": "esticar",
    "esticando": "esticar",
    "esticanços": "esticanço",
    "esticara": "esticar",
    "esticaram": "esticar",
    "esticaras": "esticar",
    "esticarde": "esticar",
    "esticardes": "esticar",
    "esticare": "esticar",
    "esticarei": "esticar",
    "esticareis": "esticar",
    "esticarem": "esticar",
    "esticaremos": "esticar",
    "esticares": "esticar",
    "esticaria": "esticar",
    "esticariam": "esticar",
    "esticarias": "esticar",
    "esticarmo": "esticar",
    "esticarmos": "esticar",
    "esticará": "esticar",
    "esticarás": "esticar",
    "esticarão": "esticar",
    "esticaríamos": "esticar",
    "esticaríeis": "esticar",
    "esticas": "esticar",
    "esticasse": "esticar",
    "esticassem": "esticar",
    "esticasses": "esticar",
    "esticaste": "esticar",
    "esticastes": "esticar",
    "esticava": "esticar",
    "esticavam": "esticar",
    "esticavas": "esticar",
    "estico": "esticar",
    "esticou": "esticar",
    "esticá": "esticar",
    "esticámo": "esticar",
    "esticámos": "esticar",
    "esticáramo": "esticar",
    "esticáramos": "esticar",
    "esticárei": "esticar",
    "esticáreis": "esticar",
    "esticásseis": "esticar",
    "esticássemos": "esticar",
    "esticávamo": "esticar",
    "esticávamos": "esticar",
    "esticávei": "esticar",
    "esticáveis": "esticar",
    "esticões": "esticão",
    "estie": "estiar",
    "estiei": "estiar",
    "estieis": "estiar",
    "estiem": "estiar",
    "estiemo": "estiar",
    "estiemos": "estiar",
    "esties": "estiar",
    "estigmas": "estigma",
    "estigmatismos": "estigmatismo",
    "estigmatiza": "estigmatizar",
    "estigmatizada": "estigmatizar",
    "estigmatizadas": "estigmatizar",
    "estigmatizado": "estigmatizar",
    "estigmatizados": "estigmatizar",
    "estigmatizai": "estigmatizar",
    "estigmatizais": "estigmatizar",
    "estigmatizam": "estigmatizar",
    "estigmatizamo": "estigmatizar",
    "estigmatizamos": "estigmatizar",
    "estigmatizando": "estigmatizar",
    "estigmatizara": "estigmatizar",
    "estigmatizaram": "estigmatizar",
    "estigmatizaras": "estigmatizar",
    "estigmatizarde": "estigmatizar",
    "estigmatizardes": "estigmatizar",
    "estigmatizare": "estigmatizar",
    "estigmatizarei": "estigmatizar",
    "estigmatizareis": "estigmatizar",
    "estigmatizarem": "estigmatizar",
    "estigmatizaremos": "estigmatizar",
    "estigmatizares": "estigmatizar",
    "estigmatizaria": "estigmatizar",
    "estigmatizariam": "estigmatizar",
    "estigmatizarias": "estigmatizar",
    "estigmatizarmo": "estigmatizar",
    "estigmatizarmos": "estigmatizar",
    "estigmatizará": "estigmatizar",
    "estigmatizarás": "estigmatizar",
    "estigmatizarão": "estigmatizar",
    "estigmatizaríamos": "estigmatizar",
    "estigmatizaríeis": "estigmatizar",
    "estigmatizas": "estigmatizar",
    "estigmatizasse": "estigmatizar",
    "estigmatizassem": "estigmatizar",
    "estigmatizasses": "estigmatizar",
    "estigmatizaste": "estigmatizar",
    "estigmatizastes": "estigmatizar",
    "estigmatizava": "estigmatizar",
    "estigmatizavam": "estigmatizar",
    "estigmatizavas": "estigmatizar",
    "estigmatizações": "estigmatização",
    "estigmatize": "estigmatizar",
    "estigmatizei": "estigmatizar",
    "estigmatizeis": "estigmatizar",
    "estigmatizem": "estigmatizar",
    "estigmatizemo": "estigmatizar",
    "estigmatizemos": "estigmatizar",
    "estigmatizes": "estigmatizar",
    "estigmatizo": "estigmatizar",
    "estigmatizou": "estigmatizar",
    "estigmatizá": "estigmatizar",
    "estigmatizámo": "estigmatizar",
    "estigmatizámos": "estigmatizar",
    "estigmatizáramo": "estigmatizar",
    "estigmatizáramos": "estigmatizar",
    "estigmatizárei": "estigmatizar",
    "estigmatizáreis": "estigmatizar",
    "estigmatizásseis": "estigmatizar",
    "estigmatizássemos": "estigmatizar",
    "estigmatizávamo": "estigmatizar",
    "estigmatizávamos": "estigmatizar",
    "estigmatizávei": "estigmatizar",
    "estigmatizáveis": "estigmatizar",
    "estigmatografias": "estigmatografia",
    "estigmatográfica": "estigmatográfico",
    "estigmatográficas": "estigmatográfico",
    "estigmatográficos": "estigmatográfico",
    "estigmatógrafos": "estigmatógrafo",
    "estigmática": "estigmático",
    "estigmáticas": "estigmático",
    "estigmáticos": "estigmático",
    "estigmónimos": "estigmónimo",
    "estila": "estilar",
    "estilada": "estilar",
    "estiladas": "estilar",
    "estilado": "estilar",
    "estilados": "estilar",
    "estilai": "estilar",
    "estilais": "estilar",
    "estilam": "estilar",
    "estilamo": "estilar",
    "estilamos": "estilar",
    "estilando": "estilar",
    "estilara": "estilar",
    "estilaram": "estilar",
    "estilaras": "estilar",
    "estilarde": "estilar",
    "estilardes": "estilar",
    "estilare": "estilar",
    "estilarei": "estilar",
    "estilareis": "estilar",
    "estilarem": "estilar",
    "estilaremos": "estilar",
    "estilares": "estilar",
    "estilaria": "estilar",
    "estilariam": "estilar",
    "estilarias": "estilar",
    "estilarmo": "estilar",
    "estilarmos": "estilar",
    "estilará": "estilar",
    "estilarás": "estilar",
    "estilarão": "estilar",
    "estilaríamos": "estilar",
    "estilaríeis": "estilar",
    "estilas": "estilar",
    "estilasse": "estilar",
    "estilassem": "estilar",
    "estilasses": "estilar",
    "estilaste": "estilar",
    "estilastes": "estilar",
    "estilava": "estilar",
    "estilavam": "estilar",
    "estilavas": "estilar",
    "estilações": "estilação",
    "estile": "estilar",
    "estilei": "estilar",
    "estileis": "estilar",
    "estilem": "estilar",
    "estilemo": "estilar",
    "estilemos": "estilar",
    "estiles": "estilar",
    "estileteada": "estiletear",
    "estileteadas": "estiletear",
    "estileteado": "estiletear",
    "estileteados": "estiletear",
    "estileteai": "estiletear",
    "estileteais": "estiletear",
    "estileteamo": "estiletear",
    "estileteamos": "estiletear",
    "estileteando": "estiletear",
    "estileteara": "estiletear",
    "estiletearam": "estiletear",
    "estiletearas": "estiletear",
    "estiletearde": "estiletear",
    "estileteardes": "estiletear",
    "estileteare": "estiletear",
    "estiletearei": "estiletear",
    "estileteareis": "estiletear",
    "estiletearem": "estiletear",
    "estiletearemos": "estiletear",
    "estileteares": "estiletear",
    "estiletearia": "estiletear",
    "estileteariam": "estiletear",
    "estiletearias": "estiletear",
    "estiletearmo": "estiletear",
    "estiletearmos": "estiletear",
    "estileteará": "estiletear",
    "estiletearás": "estiletear",
    "estiletearão": "estiletear",
    "estiletearíamos": "estiletear",
    "estiletearíeis": "estiletear",
    "estileteasse": "estiletear",
    "estileteassem": "estiletear",
    "estileteasses": "estiletear",
    "estileteaste": "estiletear",
    "estileteastes": "estiletear",
    "estileteava": "estiletear",
    "estileteavam": "estiletear",
    "estileteavas": "estiletear",
    "estileteei": "estiletear",
    "estileteeis": "estiletear",
    "estileteemo": "estiletear",
    "estileteemos": "estiletear",
    "estileteia": "estiletear",
    "estileteiam": "estiletear",
    "estileteias": "estiletear",
    "estileteie": "estiletear",
    "estileteiem": "estiletear",
    "estileteies": "estiletear",
    "estileteio": "estiletear",
    "estileteou": "estiletear",
    "estiletes": "estilete",
    "estileteá": "estiletear",
    "estileteámo": "estiletear",
    "estileteámos": "estiletear",
    "estileteáramo": "estiletear",
    "estileteáramos": "estiletear",
    "estileteárei": "estiletear",
    "estileteáreis": "estiletear",
    "estileteásseis": "estiletear",
    "estileteássemos": "estiletear",
    "estileteávamo": "estiletear",
    "estileteávamos": "estiletear",
    "estileteávei": "estiletear",
    "estileteáveis": "estiletear",
    "estiletiza": "estiletizar",
    "estiletizada": "estiletizar",
    "estiletizadas": "estiletizar",
    "estiletizado": "estiletizar",
    "estiletizados": "estiletizar",
    "estiletizai": "estiletizar",
    "estiletizais": "estiletizar",
    "estiletizam": "estiletizar",
    "estiletizamo": "estiletizar",
    "estiletizamos": "estiletizar",
    "estiletizando": "estiletizar",
    "estiletizara": "estiletizar",
    "estiletizaram": "estiletizar",
    "estiletizaras": "estiletizar",
    "estiletizarde": "estiletizar",
    "estiletizardes": "estiletizar",
    "estiletizare": "estiletizar",
    "estiletizarei": "estiletizar",
    "estiletizareis": "estiletizar",
    "estiletizarem": "estiletizar",
    "estiletizaremos": "estiletizar",
    "estiletizares": "estiletizar",
    "estiletizaria": "estiletizar",
    "estiletizariam": "estiletizar",
    "estiletizarias": "estiletizar",
    "estiletizarmo": "estiletizar",
    "estiletizarmos": "estiletizar",
    "estiletizará": "estiletizar",
    "estiletizarás": "estiletizar",
    "estiletizarão": "estiletizar",
    "estiletizaríamos": "estiletizar",
    "estiletizaríeis": "estiletizar",
    "estiletizas": "estiletizar",
    "estiletizasse": "estiletizar",
    "estiletizassem": "estiletizar",
    "estiletizasses": "estiletizar",
    "estiletizaste": "estiletizar",
    "estiletizastes": "estiletizar",
    "estiletizava": "estiletizar",
    "estiletizavam": "estiletizar",
    "estiletizavas": "estiletizar",
    "estiletize": "estiletizar",
    "estiletizei": "estiletizar",
    "estiletizeis": "estiletizar",
    "estiletizem": "estiletizar",
    "estiletizemo": "estiletizar",
    "estiletizemos": "estiletizar",
    "estiletizes": "estiletizar",
    "estiletizo": "estiletizar",
    "estiletizou": "estiletizar",
    "estiletizá": "estiletizar",
    "estiletizámo": "estiletizar",
    "estiletizámos": "estiletizar",
    "estiletizáramo": "estiletizar",
    "estiletizáramos": "estiletizar",
    "estiletizárei": "estiletizar",
    "estiletizáreis": "estiletizar",
    "estiletizásseis": "estiletizar",
    "estiletizássemos": "estiletizar",
    "estiletizávamo": "estiletizar",
    "estiletizávamos": "estiletizar",
    "estiletizávei": "estiletizar",
    "estiletizáveis": "estiletizar",
    "estilha": "estilhar",
    "estilhace": "estilhaçar",
    "estilhacei": "estilhaçar",
    "estilhaceis": "estilhaçar",
    "estilhacem": "estilhaçar",
    "estilhacemo": "estilhaçar",
    "estilhacemos": "estilhaçar",
    "estilhaces": "estilhaçar",
    "estilhada": "estilhar",
    "estilhadas": "estilhar",
    "estilhado": "estilhar",
    "estilhados": "estilhar",
    "estilhai": "estilhar",
    "estilhais": "estilhar",
    "estilham": "estilhar",
    "estilhamo": "estilhar",
    "estilhamos": "estilhar",
    "estilhando": "estilhar",
    "estilhara": "estilhar",
    "estilharam": "estilhar",
    "estilharas": "estilhar",
    "estilharde": "estilhar",
    "estilhardes": "estilhar",
    "estilhare": "estilhar",
    "estilharei": "estilhar",
    "estilhareis": "estilhar",
    "estilharem": "estilhar",
    "estilharemos": "estilhar",
    "estilhares": "estilhar",
    "estilharia": "estilhar",
    "estilhariam": "estilhar",
    "estilharias": "estilhar",
    "estilharmo": "estilhar",
    "estilharmos": "estilhar",
    "estilhará": "estilhar",
    "estilharás": "estilhar",
    "estilharão": "estilhar",
    "estilharíamos": "estilhar",
    "estilharíeis": "estilhar",
    "estilhas": "estilhar",
    "estilhasse": "estilhar",
    "estilhassem": "estilhar",
    "estilhasses": "estilhar",
    "estilhaste": "estilhar",
    "estilhastes": "estilhar",
    "estilhava": "estilhar",
    "estilhavam": "estilhar",
    "estilhavas": "estilhar",
    "estilhaça": "estilhaçar",
    "estilhaçada": "estilhaçar",
    "estilhaçadas": "estilhaçar",
    "estilhaçado": "estilhaçar",
    "estilhaçados": "estilhaçar",
    "estilhaçai": "estilhaçar",
    "estilhaçais": "estilhaçar",
    "estilhaçam": "estilhaçar",
    "estilhaçamo": "estilhaçar",
    "estilhaçamos": "estilhaçar",
    "estilhaçando": "estilhaçar",
    "estilhaçara": "estilhaçar",
    "estilhaçaram": "estilhaçar",
    "estilhaçaras": "estilhaçar",
    "estilhaçarde": "estilhaçar",
    "estilhaçardes": "estilhaçar",
    "estilhaçare": "estilhaçar",
    "estilhaçarei": "estilhaçar",
    "estilhaçareis": "estilhaçar",
    "estilhaçarem": "estilhaçar",
    "estilhaçaremos": "estilhaçar",
    "estilhaçares": "estilhaçar",
    "estilhaçaria": "estilhaçar",
    "estilhaçariam": "estilhaçar",
    "estilhaçarias": "estilhaçar",
    "estilhaçarmo": "estilhaçar",
    "estilhaçarmos": "estilhaçar",
    "estilhaçará": "estilhaçar",
    "estilhaçarás": "estilhaçar",
    "estilhaçarão": "estilhaçar",
    "estilhaçaríamos": "estilhaçar",
    "estilhaçaríeis": "estilhaçar",
    "estilhaças": "estilhaçar",
    "estilhaçasse": "estilhaçar",
    "estilhaçassem": "estilhaçar",
    "estilhaçasses": "estilhaçar",
    "estilhaçaste": "estilhaçar",
    "estilhaçastes": "estilhaçar",
    "estilhaçava": "estilhaçar",
    "estilhaçavam": "estilhaçar",
    "estilhaçavas": "estilhaçar",
    "estilhaço": "estilhaçar",
    "estilhaços": "estilhaço",
    "estilhaçou": "estilhaçar",
    "estilhaçá": "estilhaçar",
    "estilhaçámo": "estilhaçar",
    "estilhaçámos": "estilhaçar",
    "estilhaçáramo": "estilhaçar",
    "estilhaçáramos": "estilhaçar",
    "estilhaçárei": "estilhaçar",
    "estilhaçáreis": "estilhaçar",
    "estilhaçásseis": "estilhaçar",
    "estilhaçássemos": "estilhaçar",
    "estilhaçávamo": "estilhaçar",
    "estilhaçávamos": "estilhaçar",
    "estilhaçávei": "estilhaçar",
    "estilhaçáveis": "estilhaçar",
    "estilhe": "estilhar",
    "estilhei": "estilhar",
    "estilheiras": "estilheira",
    "estilheis": "estilhar",
    "estilhem": "estilhar",
    "estilhemo": "estilhar",
    "estilhemos": "estilhar",
    "estilhes": "estilhar",
    "estilho": "estilhar",
    "estilhou": "estilhar",
    "estilhá": "estilhar",
    "estilhámo": "estilhar",
    "estilhámos": "estilhar",
    "estilháramo": "estilhar",
    "estilháramos": "estilhar",
    "estilhárei": "estilhar",
    "estilháreis": "estilhar",
    "estilhásseis": "estilhar",
    "estilhássemos": "estilhar",
    "estilhávamo": "estilhar",
    "estilhávamos": "estilhar",
    "estilhávei": "estilhar",
    "estilháveis": "estilhar",
    "estilibites": "estilibite",
    "estilicídios": "estilicídio",
    "estiliformes": "estiliforme",
    "estilismos": "estilismo",
    "estilistas": "estilista",
    "estilitas": "estilita",
    "estiliza": "estilizar",
    "estilizada": "estilizar",
    "estilizadas": "estilizar",
    "estilizado": "estilizar",
    "estilizados": "estilizar",
    "estilizai": "estilizar",
    "estilizais": "estilizar",
    "estilizam": "estilizar",
    "estilizamo": "estilizar",
    "estilizamos": "estilizar",
    "estilizando": "estilizar",
    "estilizara": "estilizar",
    "estilizaram": "estilizar",
    "estilizaras": "estilizar",
    "estilizarde": "estilizar",
    "estilizardes": "estilizar",
    "estilizare": "estilizar",
    "estilizarei": "estilizar",
    "estilizareis": "estilizar",
    "estilizarem": "estilizar",
    "estilizaremos": "estilizar",
    "estilizares": "estilizar",
    "estilizaria": "estilizar",
    "estilizariam": "estilizar",
    "estilizarias": "estilizar",
    "estilizarmo": "estilizar",
    "estilizarmos": "estilizar",
    "estilizará": "estilizar",
    "estilizarás": "estilizar",
    "estilizarão": "estilizar",
    "estilizaríamos": "estilizar",
    "estilizaríeis": "estilizar",
    "estilizas": "estilizar",
    "estilizasse": "estilizar",
    "estilizassem": "estilizar",
    "estilizasses": "estilizar",
    "estilizaste": "estilizar",
    "estilizastes": "estilizar",
    "estilizava": "estilizar",
    "estilizavam": "estilizar",
    "estilizavas": "estilizar",
    "estilizações": "estilização",
    "estilize": "estilizar",
    "estilizei": "estilizar",
    "estilizeis": "estilizar",
    "estilizem": "estilizar",
    "estilizemo": "estilizar",
    "estilizemos": "estilizar",
    "estilizes": "estilizar",
    "estilizo": "estilizar",
    "estilizou": "estilizar",
    "estilizá": "estilizar",
    "estilizámo": "estilizar",
    "estilizámos": "estilizar",
    "estilizáramo": "estilizar",
    "estilizáramos": "estilizar",
    "estilizárei": "estilizar",
    "estilizáreis": "estilizar",
    "estilizásseis": "estilizar",
    "estilizássemos": "estilizar",
    "estilizávamo": "estilizar",
    "estilizávamos": "estilizar",
    "estilizávei": "estilizar",
    "estilizáveis": "estilizar",
    "estilo": "estilar",
    "estilografias": "estilografia",
    "estilográfica": "estilográfico",
    "estilográficas": "estilográfico",
    "estilográficos": "estilográfico",
    "estilometrias": "estilometria",
    "estilométrica": "estilométrico",
    "estilométricas": "estilométrico",
    "estilométricos": "estilométrico",
    "estiloníquias": "estiloníquia",
    "estilos": "estilo",
    "estilou": "estilar",
    "estilá": "estilar",
    "estilámo": "estilar",
    "estilámos": "estilar",
    "estiláramo": "estilar",
    "estiláramos": "estilar",
    "estilárei": "estilar",
    "estiláreis": "estilar",
    "estilásseis": "estilar",
    "estilássemos": "estilar",
    "estilávamo": "estilar",
    "estilávamos": "estilar",
    "estilávei": "estilar",
    "estiláveis": "estilar",
    "estilística": "estilístico",
    "estilísticas": "estilístico",
    "estilísticos": "estilístico",
    "estilóbatas": "estilóbata",
    "estilógrafa": "estilógrafo",
    "estilógrafas": "estilógrafo",
    "estilógrafos": "estilógrafo",
    "estilóides": "estilóide",
    "estilómetros": "estilómetro",
    "estima": "estimar",
    "estimada": "estimar",
    "estimadas": "estimar",
    "estimado": "estimar",
    "estimadora": "estimador",
    "estimadoras": "estimador",
    "estimadores": "estimador",
    "estimados": "estimar",
    "estimadíssima": "estimado",
    "estimadíssimas": "estimado",
    "estimadíssimo": "estimado",
    "estimadíssimos": "estimado",
    "estimai": "estimar",
    "estimais": "estimar",
    "estimam": "estimar",
    "estimamo": "estimar",
    "estimamos": "estimar",
    "estimando": "estimar",
    "estimara": "estimar",
    "estimaram": "estimar",
    "estimaras": "estimar",
    "estimarde": "estimar",
    "estimardes": "estimar",
    "estimare": "estimar",
    "estimarei": "estimar",
    "estimareis": "estimar",
    "estimarem": "estimar",
    "estimaremos": "estimar",
    "estimares": "estimar",
    "estimaria": "estimar",
    "estimariam": "estimar",
    "estimarias": "estimar",
    "estimarmo": "estimar",
    "estimarmos": "estimar",
    "estimará": "estimar",
    "estimarás": "estimar",
    "estimarão": "estimar",
    "estimaríamos": "estimar",
    "estimaríeis": "estimar",
    "estimas": "estimar",
    "estimasse": "estimar",
    "estimassem": "estimar",
    "estimasses": "estimar",
    "estimaste": "estimar",
    "estimastes": "estimar",
    "estimativa": "estimativo",
    "estimativas": "estimativo",
    "estimativos": "estimativo",
    "estimava": "estimar",
    "estimavam": "estimar",
    "estimavas": "estimar",
    "estimações": "estimação",
    "estime": "estimar",
    "estimei": "estimar",
    "estimeis": "estimar",
    "estimem": "estimar",
    "estimemo": "estimar",
    "estimemos": "estimar",
    "estimes": "estimar",
    "estimo": "estimar",
    "estimou": "estimar",
    "estimula": "estimular",
    "estimulada": "estimular",
    "estimuladas": "estimular",
    "estimulado": "estimular",
    "estimuladora": "estimulador",
    "estimuladoras": "estimulador",
    "estimuladores": "estimulador",
    "estimulados": "estimular",
    "estimuladíssima": "estimulado",
    "estimuladíssimas": "estimulado",
    "estimuladíssimo": "estimulado",
    "estimuladíssimos": "estimulado",
    "estimulai": "estimular",
    "estimulais": "estimular",
    "estimulam": "estimular",
    "estimulamo": "estimular",
    "estimulamos": "estimular",
    "estimulando": "estimular",
    "estimulantes": "estimulante",
    "estimulantezinho": "estimulante",
    "estimulantezinhos": "estimulante",
    "estimulantezito": "estimulante",
    "estimulantezitos": "estimulante",
    "estimulara": "estimular",
    "estimularam": "estimular",
    "estimularas": "estimular",
    "estimularde": "estimular",
    "estimulardes": "estimular",
    "estimulare": "estimular",
    "estimularei": "estimular",
    "estimulareis": "estimular",
    "estimularem": "estimular",
    "estimularemos": "estimular",
    "estimulares": "estimular",
    "estimularia": "estimular",
    "estimulariam": "estimular",
    "estimularias": "estimular",
    "estimularmo": "estimular",
    "estimularmos": "estimular",
    "estimulará": "estimular",
    "estimularás": "estimular",
    "estimularão": "estimular",
    "estimularíamos": "estimular",
    "estimularíeis": "estimular",
    "estimulas": "estimular",
    "estimulasse": "estimular",
    "estimulassem": "estimular",
    "estimulasses": "estimular",
    "estimulaste": "estimular",
    "estimulastes": "estimular",
    "estimulava": "estimular",
    "estimulavam": "estimular",
    "estimulavas": "estimular",
    "estimulações": "estimulação",
    "estimule": "estimular",
    "estimulei": "estimular",
    "estimuleis": "estimular",
    "estimulem": "estimular",
    "estimulemo": "estimular",
    "estimulemos": "estimular",
    "estimules": "estimular",
    "estimulo": "estimular",
    "estimulosa": "estimuloso",
    "estimulosas": "estimuloso",
    "estimulosos": "estimuloso",
    "estimulou": "estimular",
    "estimulozinho": "estímulo",
    "estimulozinhos": "estímulo",
    "estimulozito": "estímulo",
    "estimulozitos": "estímulo",
    "estimulá": "estimular",
    "estimulámo": "estimular",
    "estimulámos": "estimular",
    "estimuláramo": "estimular",
    "estimuláramos": "estimular",
    "estimulárei": "estimular",
    "estimuláreis": "estimular",
    "estimulásseis": "estimular",
    "estimulássemos": "estimular",
    "estimulávamo": "estimular",
    "estimulávamos": "estimular",
    "estimulávei": "estimular",
    "estimuláveis": "estimular",
    "estimá": "estimar",
    "estimámo": "estimar",
    "estimámos": "estimar",
    "estimáramo": "estimar",
    "estimáramos": "estimar",
    "estimárei": "estimar",
    "estimáreis": "estimar",
    "estimásseis": "estimar",
    "estimássemos": "estimar",
    "estimávamo": "estimar",
    "estimávamos": "estimar",
    "estimávei": "estimar",
    "estimáveis": "estimável",
    "estimónia": "estimónio",
    "estimónias": "estimónio",
    "estimónios": "estimónio",
    "estinga": "estingar",
    "estingada": "estingar",
    "estingadas": "estingar",
    "estingado": "estingar",
    "estingados": "estingar",
    "estingai": "estingar",
    "estingais": "estingar",
    "estingam": "estingar",
    "estingamo": "estingar",
    "estingamos": "estingar",
    "estingando": "estingar",
    "estingara": "estingar",
    "estingaram": "estingar",
    "estingaras": "estingar",
    "estingarde": "estingar",
    "estingardes": "estingar",
    "estingare": "estingar",
    "estingarei": "estingar",
    "estingareis": "estingar",
    "estingarem": "estingar",
    "estingaremos": "estingar",
    "estingares": "estingar",
    "estingaria": "estingar",
    "estingariam": "estingar",
    "estingarias": "estingar",
    "estingarmo": "estingar",
    "estingarmos": "estingar",
    "estingará": "estingar",
    "estingarás": "estingar",
    "estingarão": "estingar",
    "estingaríamos": "estingar",
    "estingaríeis": "estingar",
    "estingas": "estingar",
    "estingasse": "estingar",
    "estingassem": "estingar",
    "estingasses": "estingar",
    "estingaste": "estingar",
    "estingastes": "estingar",
    "estingava": "estingar",
    "estingavam": "estingar",
    "estingavas": "estingar",
    "estingo": "estingar",
    "estingou": "estingar",
    "estingue": "estingar",
    "estinguei": "estingar",
    "estingueis": "estingar",
    "estinguem": "estingar",
    "estinguemo": "estingar",
    "estinguemos": "estingar",
    "estingues": "estingue",
    "estingá": "estingar",
    "estingámo": "estingar",
    "estingámos": "estingar",
    "estingáramo": "estingar",
    "estingáramos": "estingar",
    "estingárei": "estingar",
    "estingáreis": "estingar",
    "estingásseis": "estingar",
    "estingássemos": "estingar",
    "estingávamo": "estingar",
    "estingávamos": "estingar",
    "estingávei": "estingar",
    "estingáveis": "estingar",
    "estinhas": "estinha",
    "estio": "estiar",
    "estiola": "estiolar",
    "estiolada": "estiolar",
    "estioladas": "estiolar",
    "estiolado": "estiolar",
    "estiolados": "estiolar",
    "estiolai": "estiolar",
    "estiolais": "estiolar",
    "estiolam": "estiolar",
    "estiolamentos": "estiolamento",
    "estiolamo": "estiolar",
    "estiolamos": "estiolar",
    "estiolando": "estiolar",
    "estiolara": "estiolar",
    "estiolaram": "estiolar",
    "estiolaras": "estiolar",
    "estiolarde": "estiolar",
    "estiolardes": "estiolar",
    "estiolare": "estiolar",
    "estiolarei": "estiolar",
    "estiolareis": "estiolar",
    "estiolarem": "estiolar",
    "estiolaremos": "estiolar",
    "estiolares": "estiolar",
    "estiolaria": "estiolar",
    "estiolariam": "estiolar",
    "estiolarias": "estiolar",
    "estiolarmo": "estiolar",
    "estiolarmos": "estiolar",
    "estiolará": "estiolar",
    "estiolarás": "estiolar",
    "estiolarão": "estiolar",
    "estiolaríamos": "estiolar",
    "estiolaríeis": "estiolar",
    "estiolas": "estiolar",
    "estiolasse": "estiolar",
    "estiolassem": "estiolar",
    "estiolasses": "estiolar",
    "estiolaste": "estiolar",
    "estiolastes": "estiolar",
    "estiolava": "estiolar",
    "estiolavam": "estiolar",
    "estiolavas": "estiolar",
    "estiole": "estiolar",
    "estiolei": "estiolar",
    "estioleis": "estiolar",
    "estiolem": "estiolar",
    "estiolemo": "estiolar",
    "estiolemos": "estiolar",
    "estioles": "estiolar",
    "estiolo": "estiolar",
    "estiolou": "estiolar",
    "estiolá": "estiolar",
    "estiolámo": "estiolar",
    "estiolámos": "estiolar",
    "estioláramo": "estiolar",
    "estioláramos": "estiolar",
    "estiolárei": "estiolar",
    "estioláreis": "estiolar",
    "estiolásseis": "estiolar",
    "estiolássemos": "estiolar",
    "estiolávamo": "estiolar",
    "estiolávamos": "estiolar",
    "estiolávei": "estiolar",
    "estioláveis": "estiolar",
    "estios": "estio",
    "estiou": "estiar",
    "estipendia": "estipendiar",
    "estipendiada": "estipendiar",
    "estipendiadas": "estipendiar",
    "estipendiado": "estipendiar",
    "estipendiados": "estipendiar",
    "estipendiai": "estipendiar",
    "estipendiais": "estipendiar",
    "estipendiam": "estipendiar",
    "estipendiamo": "estipendiar",
    "estipendiamos": "estipendiar",
    "estipendiando": "estipendiar",
    "estipendiara": "estipendiar",
    "estipendiaram": "estipendiar",
    "estipendiaras": "estipendiar",
    "estipendiarde": "estipendiar",
    "estipendiardes": "estipendiar",
    "estipendiare": "estipendiar",
    "estipendiarei": "estipendiar",
    "estipendiareis": "estipendiar",
    "estipendiarem": "estipendiar",
    "estipendiaremos": "estipendiar",
    "estipendiares": "estipendiar",
    "estipendiaria": "estipendiar",
    "estipendiariam": "estipendiar",
    "estipendiarias": "estipendiar",
    "estipendiarmo": "estipendiar",
    "estipendiarmos": "estipendiar",
    "estipendiará": "estipendiar",
    "estipendiarás": "estipendiar",
    "estipendiarão": "estipendiar",
    "estipendiaríamos": "estipendiar",
    "estipendiaríeis": "estipendiar",
    "estipendias": "estipendiar",
    "estipendiasse": "estipendiar",
    "estipendiassem": "estipendiar",
    "estipendiasses": "estipendiar",
    "estipendiaste": "estipendiar",
    "estipendiastes": "estipendiar",
    "estipendiava": "estipendiar",
    "estipendiavam": "estipendiar",
    "estipendiavas": "estipendiar",
    "estipendie": "estipendiar",
    "estipendiei": "estipendiar",
    "estipendieis": "estipendiar",
    "estipendiem": "estipendiar",
    "estipendiemo": "estipendiar",
    "estipendiemos": "estipendiar",
    "estipendies": "estipendiar",
    "estipendio": "estipendiar",
    "estipendiou": "estipendiar",
    "estipendiá": "estipendiar",
    "estipendiámo": "estipendiar",
    "estipendiámos": "estipendiar",
    "estipendiáramo": "estipendiar",
    "estipendiáramos": "estipendiar",
    "estipendiárei": "estipendiar",
    "estipendiáreis": "estipendiar",
    "estipendiária": "estipendiário",
    "estipendiárias": "estipendiário",
    "estipendiários": "estipendiário",
    "estipendiásseis": "estipendiar",
    "estipendiássemos": "estipendiar",
    "estipendiávamo": "estipendiar",
    "estipendiávamos": "estipendiar",
    "estipendiávei": "estipendiar",
    "estipendiáveis": "estipendiar",
    "estipes": "estipe",
    "estipitária": "estipitário",
    "estipitárias": "estipitário",
    "estipitários": "estipitário",
    "estipula": "estipular",
    "estipulada": "estipular",
    "estipuladas": "estipular",
    "estipulado": "estipular",
    "estipuladora": "estipulador",
    "estipuladoras": "estipulador",
    "estipuladores": "estipulador",
    "estipulados": "estipular",
    "estipulai": "estipular",
    "estipulais": "estipular",
    "estipulam": "estipular",
    "estipulamo": "estipular",
    "estipulamos": "estipular",
    "estipulando": "estipular",
    "estipulantes": "estipulante",
    "estipulara": "estipular",
    "estipularam": "estipular",
    "estipularas": "estipular",
    "estipularde": "estipular",
    "estipulardes": "estipular",
    "estipulare": "estipular",
    "estipularei": "estipular",
    "estipulareis": "estipular",
    "estipularem": "estipular",
    "estipularemos": "estipular",
    "estipulares": "estipular",
    "estipularia": "estipular",
    "estipulariam": "estipular",
    "estipularias": "estipular",
    "estipularmo": "estipular",
    "estipularmos": "estipular",
    "estipulará": "estipular",
    "estipularás": "estipular",
    "estipularão": "estipular",
    "estipularíamos": "estipular",
    "estipularíeis": "estipular",
    "estipulas": "estipular",
    "estipulasse": "estipular",
    "estipulassem": "estipular",
    "estipulasses": "estipular",
    "estipulaste": "estipular",
    "estipulastes": "estipular",
    "estipulava": "estipular",
    "estipulavam": "estipular",
    "estipulavas": "estipular",
    "estipulações": "estipulação",
    "estipule": "estipular",
    "estipulei": "estipular",
    "estipuleis": "estipular",
    "estipulem": "estipular",
    "estipulemo": "estipular",
    "estipulemos": "estipular",
    "estipules": "estipular",
    "estipulo": "estipular",
    "estipulosa": "estipuloso",
    "estipulosas": "estipuloso",
    "estipulosos": "estipuloso",
    "estipulou": "estipular",
    "estipulá": "estipular",
    "estipulámo": "estipular",
    "estipulámos": "estipular",
    "estipuláramo": "estipular",
    "estipuláramos": "estipular",
    "estipulárei": "estipular",
    "estipuláreis": "estipular",
    "estipulásseis": "estipular",
    "estipulássemos": "estipular",
    "estipulávamo": "estipular",
    "estipulávamos": "estipular",
    "estipulávei": "estipular",
    "estipuláveis": "estipulável",
    "estipêndios": "estipêndio",
    "estique": "esticar",
    "estiquei": "esticar",
    "estiqueis": "esticar",
    "estiquem": "esticar",
    "estiquemo": "esticar",
    "estiquemos": "esticar",
    "estiques": "estique",
    "estira": "estirar",
    "estirace": "estiraçar",
    "estiracei": "estiraçar",
    "estiraceis": "estiraçar",
    "estiracem": "estiraçar",
    "estiracemo": "estiraçar",
    "estiracemos": "estiraçar",
    "estiraces": "estiraçar",
    "estiracácea": "estiracáceo",
    "estiracáceas": "estiracáceo",
    "estiracáceos": "estiracáceo",
    "estirada": "estirar",
    "estiradas": "estirar",
    "estiradeira": "estiradeiro",
    "estiradeiras": "estiradeiro",
    "estiradeiros": "estiradeiro",
    "estirado": "estirar",
    "estiradores": "estirador",
    "estirados": "estirar",
    "estirai": "estirar",
    "estirais": "estirar",
    "estiram": "estirar",
    "estiramentos": "estiramento",
    "estiramo": "estirar",
    "estiramos": "estirar",
    "estirando": "estirar",
    "estirara": "estirar",
    "estiraram": "estirar",
    "estiraras": "estirar",
    "estirarde": "estirar",
    "estirardes": "estirar",
    "estirare": "estirar",
    "estirarei": "estirar",
    "estirareis": "estirar",
    "estirarem": "estirar",
    "estiraremos": "estirar",
    "estirares": "estirar",
    "estiraria": "estirar",
    "estirariam": "estirar",
    "estirarias": "estirar",
    "estirarmo": "estirar",
    "estirarmos": "estirar",
    "estirará": "estirar",
    "estirarás": "estirar",
    "estirarão": "estirar",
    "estiraríamos": "estirar",
    "estiraríeis": "estirar",
    "estiras": "estirar",
    "estirasse": "estirar",
    "estirassem": "estirar",
    "estirasses": "estirar",
    "estiraste": "estirar",
    "estirastes": "estirar",
    "estirava": "estirar",
    "estiravam": "estirar",
    "estiravas": "estirar",
    "estiraça": "estiraçar",
    "estiraçada": "estiraçar",
    "estiraçadas": "estiraçar",
    "estiraçado": "estiraçar",
    "estiraçados": "estiraçar",
    "estiraçai": "estiraçar",
    "estiraçais": "estiraçar",
    "estiraçam": "estiraçar",
    "estiraçamo": "estiraçar",
    "estiraçamos": "estiraçar",
    "estiraçando": "estiraçar",
    "estiraçara": "estiraçar",
    "estiraçaram": "estiraçar",
    "estiraçaras": "estiraçar",
    "estiraçarde": "estiraçar",
    "estiraçardes": "estiraçar",
    "estiraçare": "estiraçar",
    "estiraçarei": "estiraçar",
    "estiraçareis": "estiraçar",
    "estiraçarem": "estiraçar",
    "estiraçaremos": "estiraçar",
    "estiraçares": "estiraçar",
    "estiraçaria": "estiraçar",
    "estiraçariam": "estiraçar",
    "estiraçarias": "estiraçar",
    "estiraçarmo": "estiraçar",
    "estiraçarmos": "estiraçar",
    "estiraçará": "estiraçar",
    "estiraçarás": "estiraçar",
    "estiraçarão": "estiraçar",
    "estiraçaríamos": "estiraçar",
    "estiraçaríeis": "estiraçar",
    "estiraças": "estiraçar",
    "estiraçasse": "estiraçar",
    "estiraçassem": "estiraçar",
    "estiraçasses": "estiraçar",
    "estiraçaste": "estiraçar",
    "estiraçastes": "estiraçar",
    "estiraçava": "estiraçar",
    "estiraçavam": "estiraçar",
    "estiraçavas": "estiraçar",
    "estiraço": "estiraçar",
    "estiraços": "estiraço",
    "estiraçou": "estiraçar",
    "estiraçá": "estiraçar",
    "estiraçámo": "estiraçar",
    "estiraçámos": "estiraçar",
    "estiraçáramo": "estiraçar",
    "estiraçáramos": "estiraçar",
    "estiraçárei": "estiraçar",
    "estiraçáreis": "estiraçar",
    "estiraçásseis": "estiraçar",
    "estiraçássemos": "estiraçar",
    "estiraçávamo": "estiraçar",
    "estiraçávamos": "estiraçar",
    "estiraçávei": "estiraçar",
    "estiraçáveis": "estiraçar",
    "estire": "estirar",
    "estirei": "estirar",
    "estireis": "estirar",
    "estirem": "estirar",
    "estiremo": "estirar",
    "estiremos": "estirar",
    "estires": "estirar",
    "estiro": "estirar",
    "estirodontes": "estirodonte",
    "estirotes": "estirote",
    "estirou": "estirar",
    "estirpes": "estirpe",
    "estirá": "estirar",
    "estirámo": "estirar",
    "estirámos": "estirar",
    "estiráramo": "estirar",
    "estiráramos": "estirar",
    "estirárei": "estirar",
    "estiráreis": "estirar",
    "estirásseis": "estirar",
    "estirássemos": "estirar",
    "estirávamo": "estirar",
    "estirávamos": "estirar",
    "estirávei": "estirar",
    "estiráveis": "estirar",
    "estirões": "estirão",
    "estiva": "estivo",
    "estivada": "estivar",
    "estivadas": "estivar",
    "estivado": "estivar",
    "estivadora": "estivador",
    "estivadoras": "estivador",
    "estivadores": "estivador",
    "estivados": "estivar",
    "estivagens": "estivagem",
    "estivai": "estivar",
    "estivais": "estivar",
    "estivam": "estivar",
    "estivamo": "estivar",
    "estivamos": "estivar",
    "estivando": "estivar",
    "estivara": "estivar",
    "estivaram": "estivar",
    "estivaras": "estivar",
    "estivarde": "estivar",
    "estivardes": "estivar",
    "estivare": "estivar",
    "estivarei": "estivar",
    "estivareis": "estivar",
    "estivarem": "estivar",
    "estivaremos": "estivar",
    "estivares": "estivar",
    "estivaria": "estivar",
    "estivariam": "estivar",
    "estivarias": "estivar",
    "estivarmo": "estivar",
    "estivarmos": "estivar",
    "estivará": "estivar",
    "estivarás": "estivar",
    "estivarão": "estivar",
    "estivaríamos": "estivar",
    "estivaríeis": "estivar",
    "estivas": "estivo",
    "estivasse": "estivar",
    "estivassem": "estivar",
    "estivasses": "estivar",
    "estivaste": "estivar",
    "estivastes": "estivar",
    "estivava": "estivar",
    "estivavam": "estivar",
    "estivavas": "estivar",
    "estivações": "estivação",
    "estive": "estivar",
    "estivei": "estivar",
    "estiveis": "estivar",
    "estivem": "estivar",
    "estivemo": "estivar",
    "estivemos": "estivar",
    "estiver": "estar",
    "estivera": "estar",
    "estiveram": "estar",
    "estiveras": "estar",
    "estiverdes": "estar",
    "estiverem": "estar",
    "estiveres": "estar",
    "estivermos": "estar",
    "estives": "estivar",
    "estivesse": "estar",
    "estivessem": "estar",
    "estivesses": "estar",
    "estiveste": "estar",
    "estivestes": "estar",
    "estivo": "estivar",
    "estivos": "estivo",
    "estivou": "estivar",
    "estivá": "estivar",
    "estivámo": "estivar",
    "estivámos": "estivar",
    "estiváramo": "estivar",
    "estiváramos": "estivar",
    "estivárei": "estivar",
    "estiváreis": "estivar",
    "estivásseis": "estivar",
    "estivássemos": "estivar",
    "estivávamo": "estivar",
    "estivávamos": "estivar",
    "estivávei": "estivar",
    "estiváveis": "estivar",
    "estivéramo": "estar",
    "estivéramos": "estar",
    "estivéreis": "estar",
    "estivésseis": "estar",
    "estivéssemos": "estar",
    "estiámo": "estiar",
    "estiámos": "estiar",
    "estiáramo": "estiar",
    "estiáramos": "estiar",
    "estiáreis": "estiar",
    "estiásseis": "estiar",
    "estiássemos": "estiar",
    "estiávamo": "estiar",
    "estiávamos": "estiar",
    "estiáveis": "estiar",
    "estoca": "estocar",
    "estocada": "estocar",
    "estocadas": "estocar",
    "estocado": "estocar",
    "estocados": "estocar",
    "estocai": "estocar",
    "estocais": "estocar",
    "estocam": "estocar",
    "estocamo": "estocar",
    "estocamos": "estocar",
    "estocando": "estocar",
    "estocara": "estocar",
    "estocaram": "estocar",
    "estocaras": "estocar",
    "estocarde": "estocar",
    "estocardes": "estocar",
    "estocare": "estocar",
    "estocarei": "estocar",
    "estocareis": "estocar",
    "estocarem": "estocar",
    "estocaremos": "estocar",
    "estocares": "estocar",
    "estocaria": "estocar",
    "estocariam": "estocar",
    "estocarias": "estocar",
    "estocarmo": "estocar",
    "estocarmos": "estocar",
    "estocará": "estocar",
    "estocarás": "estocar",
    "estocarão": "estocar",
    "estocaríamos": "estocar",
    "estocaríeis": "estocar",
    "estocas": "estocar",
    "estocasse": "estocar",
    "estocassem": "estocar",
    "estocasses": "estocar",
    "estocaste": "estocar",
    "estocastes": "estocar",
    "estocava": "estocar",
    "estocavam": "estocar",
    "estocavas": "estocar",
    "estoco": "estocar",
    "estocou": "estocar",
    "estocá": "estocar",
    "estocámo": "estocar",
    "estocámos": "estocar",
    "estocáramo": "estocar",
    "estocáramos": "estocar",
    "estocárei": "estocar",
    "estocáreis": "estocar",
    "estocásseis": "estocar",
    "estocássemos": "estocar",
    "estocástica": "estocástico",
    "estocásticas": "estocástico",
    "estocásticos": "estocástico",
    "estocávamo": "estocar",
    "estocávamos": "estocar",
    "estocávei": "estocar",
    "estocáveis": "estocar",
    "estofa": "estofo",
    "estofada": "estofar",
    "estofadas": "estofar",
    "estofado": "estofar",
    "estofadora": "estofador",
    "estofadoras": "estofador",
    "estofadores": "estofador",
    "estofados": "estofar",
    "estofai": "estofar",
    "estofais": "estofar",
    "estofam": "estofar",
    "estofamo": "estofar",
    "estofamos": "estofar",
    "estofando": "estofar",
    "estofara": "estofar",
    "estofaram": "estofar",
    "estofaras": "estofar",
    "estofarde": "estofar",
    "estofardes": "estofar",
    "estofare": "estofar",
    "estofarei": "estofar",
    "estofareis": "estofar",
    "estofarem": "estofar",
    "estofaremos": "estofar",
    "estofares": "estofar",
    "estofaria": "estofar",
    "estofariam": "estofar",
    "estofarias": "estofar",
    "estofarmo": "estofar",
    "estofarmos": "estofar",
    "estofará": "estofar",
    "estofarás": "estofar",
    "estofarão": "estofar",
    "estofaríamos": "estofar",
    "estofaríeis": "estofar",
    "estofas": "estofo",
    "estofasse": "estofar",
    "estofassem": "estofar",
    "estofasses": "estofar",
    "estofaste": "estofar",
    "estofastes": "estofar",
    "estofava": "estofar",
    "estofavam": "estofar",
    "estofavas": "estofar",
    "estofe": "estofar",
    "estofei": "estofar",
    "estofeis": "estofar",
    "estofem": "estofar",
    "estofemo": "estofar",
    "estofemos": "estofar",
    "estofes": "estofar",
    "estofo": "estofar",
    "estofos": "estofo",
    "estofou": "estofar",
    "estofá": "estofar",
    "estofámo": "estofar",
    "estofámos": "estofar",
    "estofáramo": "estofar",
    "estofáramos": "estofar",
    "estofárei": "estofar",
    "estofáreis": "estofar",
    "estofásseis": "estofar",
    "estofássemos": "estofar",
    "estofávamo": "estofar",
    "estofávamos": "estofar",
    "estofávei": "estofar",
    "estofáveis": "estofar",
    "estoicidades": "estoicidade",
    "estoicismos": "estoicismo",
    "estoicistas": "estoicista",
    "estoira": "estoirar",
    "estoirada": "estoirar",
    "estoiradas": "estoirar",
    "estoiradinha": "estoiradinho",
    "estoiradinhas": "estoiradinho",
    "estoiradinhos": "estoiradinho",
    "estoirado": "estoirar",
    "estoirados": "estoirar",
    "estoiradíssima": "estoirado",
    "estoiradíssimas": "estoirado",
    "estoiradíssimo": "estoirado",
    "estoiradíssimos": "estoirado",
    "estoirai": "estoirar",
    "estoirais": "estoirar",
    "estoiram": "estoirar",
    "estoiramo": "estoirar",
    "estoiramos": "estoirar",
    "estoirando": "estoirar",
    "estoirara": "estoirar",
    "estoiraram": "estoirar",
    "estoiraras": "estoirar",
    "estoirarde": "estoirar",
    "estoirardes": "estoirar",
    "estoirare": "estoirar",
    "estoirarei": "estoirar",
    "estoirareis": "estoirar",
    "estoirarem": "estoirar",
    "estoiraremos": "estoirar",
    "estoirares": "estoirar",
    "estoiraria": "estoirar",
    "estoirariam": "estoirar",
    "estoirarias": "estoirar",
    "estoirarmo": "estoirar",
    "estoirarmos": "estoirar",
    "estoirará": "estoirar",
    "estoirarás": "estoirar",
    "estoirarão": "estoirar",
    "estoiraríamos": "estoirar",
    "estoiraríeis": "estoirar",
    "estoiras": "estoirar",
    "estoirasse": "estoirar",
    "estoirassem": "estoirar",
    "estoirasses": "estoirar",
    "estoiraste": "estoirar",
    "estoirastes": "estoirar",
    "estoirava": "estoirar",
    "estoiravam": "estoirar",
    "estoiravas": "estoirar",
    "estoirazes": "estoiraz",
    "estoire": "estoirar",
    "estoirei": "estoirar",
    "estoireis": "estoirar",
    "estoirem": "estoirar",
    "estoiremo": "estoirar",
    "estoiremos": "estoirar",
    "estoires": "estoirar",
    "estoirinha": "estoirinhar",
    "estoirinhada": "estoirinhar",
    "estoirinhadas": "estoirinhar",
    "estoirinhado": "estoirinhar",
    "estoirinhados": "estoirinhar",
    "estoirinhai": "estoirinhar",
    "estoirinhais": "estoirinhar",
    "estoirinham": "estoirinhar",
    "estoirinhamo": "estoirinhar",
    "estoirinhamos": "estoirinhar",
    "estoirinhando": "estoirinhar",
    "estoirinhara": "estoirinhar",
    "estoirinharam": "estoirinhar",
    "estoirinharas": "estoirinhar",
    "estoirinharde": "estoirinhar",
    "estoirinhardes": "estoirinhar",
    "estoirinhare": "estoirinhar",
    "estoirinharei": "estoirinhar",
    "estoirinhareis": "estoirinhar",
    "estoirinharem": "estoirinhar",
    "estoirinharemos": "estoirinhar",
    "estoirinhares": "estoirinhar",
    "estoirinharia": "estoirinhar",
    "estoirinhariam": "estoirinhar",
    "estoirinharias": "estoirinhar",
    "estoirinharmo": "estoirinhar",
    "estoirinharmos": "estoirinhar",
    "estoirinhará": "estoirinhar",
    "estoirinharás": "estoirinhar",
    "estoirinharão": "estoirinhar",
    "estoirinharíamos": "estoirinhar",
    "estoirinharíeis": "estoirinhar",
    "estoirinhas": "estoirinhar",
    "estoirinhasse": "estoirinhar",
    "estoirinhassem": "estoirinhar",
    "estoirinhasses": "estoirinhar",
    "estoirinhaste": "estoirinhar",
    "estoirinhastes": "estoirinhar",
    "estoirinhava": "estoirinhar",
    "estoirinhavam": "estoirinhar",
    "estoirinhavas": "estoirinhar",
    "estoirinhe": "estoirinhar",
    "estoirinhei": "estoirinhar",
    "estoirinheis": "estoirinhar",
    "estoirinhem": "estoirinhar",
    "estoirinhemo": "estoirinhar",
    "estoirinhemos": "estoirinhar",
    "estoirinhes": "estoirinhar",
    "estoirinho": "estoirinhar",
    "estoirinhou": "estoirinhar",
    "estoirinhá": "estoirinhar",
    "estoirinhámo": "estoirinhar",
    "estoirinhámos": "estoirinhar",
    "estoirinháramo": "estoirinhar",
    "estoirinháramos": "estoirinhar",
    "estoirinhárei": "estoirinhar",
    "estoirinháreis": "estoirinhar",
    "estoirinhásseis": "estoirinhar",
    "estoirinhássemos": "estoirinhar",
    "estoirinhávamo": "estoirinhar",
    "estoirinhávamos": "estoirinhar",
    "estoirinhávei": "estoirinhar",
    "estoirinháveis": "estoirinhar",
    "estoiro": "estoirar",
    "estoiros": "estoiro",
    "estoirou": "estoirar",
    "estoirá": "estoirar",
    "estoirámo": "estoirar",
    "estoirámos": "estoirar",
    "estoiráramo": "estoirar",
    "estoiráramos": "estoirar",
    "estoirárei": "estoirar",
    "estoiráreis": "estoirar",
    "estoirásseis": "estoirar",
    "estoirássemos": "estoirar",
    "estoirávamo": "estoirar",
    "estoirávamos": "estoirar",
    "estoirávei": "estoirar",
    "estoiráveis": "estoirar",
    "estoja": "estojar",
    "estojada": "estojar",
    "estojadas": "estojar",
    "estojado": "estojar",
    "estojados": "estojar",
    "estojai": "estojar",
    "estojais": "estojar",
    "estojam": "estojar",
    "estojamo": "estojar",
    "estojamos": "estojar",
    "estojando": "estojar",
    "estojara": "estojar",
    "estojaram": "estojar",
    "estojaras": "estojar",
    "estojarde": "estojar",
    "estojardes": "estojar",
    "estojare": "estojar",
    "estojarei": "estojar",
    "estojareis": "estojar",
    "estojarem": "estojar",
    "estojaremos": "estojar",
    "estojares": "estojar",
    "estojaria": "estojar",
    "estojariam": "estojar",
    "estojarias": "estojaria",
    "estojarmo": "estojar",
    "estojarmos": "estojar",
    "estojará": "estojar",
    "estojarás": "estojar",
    "estojarão": "estojar",
    "estojaríamos": "estojar",
    "estojaríeis": "estojar",
    "estojas": "estojar",
    "estojasse": "estojar",
    "estojassem": "estojar",
    "estojasses": "estojar",
    "estojaste": "estojar",
    "estojastes": "estojar",
    "estojava": "estojar",
    "estojavam": "estojar",
    "estojavas": "estojar",
    "estoje": "estojar",
    "estojei": "estojar",
    "estojeira": "estojeiro",
    "estojeiras": "estojeiro",
    "estojeiros": "estojeiro",
    "estojeis": "estojar",
    "estojem": "estojar",
    "estojemo": "estojar",
    "estojemos": "estojar",
    "estojes": "estojar",
    "estojo": "estojar",
    "estojos": "estojo",
    "estojou": "estojar",
    "estojá": "estojar",
    "estojámo": "estojar",
    "estojámos": "estojar",
    "estojáramo": "estojar",
    "estojáramos": "estojar",
    "estojárei": "estojar",
    "estojáreis": "estojar",
    "estojásseis": "estojar",
    "estojássemos": "estojar",
    "estojávamo": "estojar",
    "estojávamos": "estojar",
    "estojávei": "estojar",
    "estojáveis": "estojar",
    "estolas": "estola",
    "estolhos": "estolho",
    "estolhosa": "estolhoso",
    "estolhosas": "estolhoso",
    "estolhosos": "estolhoso",
    "estolões": "estolão",
    "estomacais": "estomacal",
    "estomaga": "estomagar",
    "estomagada": "estomagar",
    "estomagadas": "estomagar",
    "estomagado": "estomagar",
    "estomagados": "estomagar",
    "estomagai": "estomagar",
    "estomagais": "estomagar",
    "estomagam": "estomagar",
    "estomagamo": "estomagar",
    "estomagamos": "estomagar",
    "estomagando": "estomagar",
    "estomagara": "estomagar",
    "estomagaram": "estomagar",
    "estomagaras": "estomagar",
    "estomagarde": "estomagar",
    "estomagardes": "estomagar",
    "estomagare": "estomagar",
    "estomagarei": "estomagar",
    "estomagareis": "estomagar",
    "estomagarem": "estomagar",
    "estomagaremos": "estomagar",
    "estomagares": "estomagar",
    "estomagaria": "estomagar",
    "estomagariam": "estomagar",
    "estomagarias": "estomagar",
    "estomagarmo": "estomagar",
    "estomagarmos": "estomagar",
    "estomagará": "estomagar",
    "estomagarás": "estomagar",
    "estomagarão": "estomagar",
    "estomagaríamos": "estomagar",
    "estomagaríeis": "estomagar",
    "estomagas": "estomagar",
    "estomagasse": "estomagar",
    "estomagassem": "estomagar",
    "estomagasses": "estomagar",
    "estomagaste": "estomagar",
    "estomagastes": "estomagar",
    "estomagava": "estomagar",
    "estomagavam": "estomagar",
    "estomagavas": "estomagar",
    "estomago": "estomagar",
    "estomagou": "estomagar",
    "estomague": "estomagar",
    "estomaguei": "estomagar",
    "estomagueis": "estomagar",
    "estomaguem": "estomagar",
    "estomaguemo": "estomagar",
    "estomaguemos": "estomagar",
    "estomagues": "estomagar",
    "estomagá": "estomagar",
    "estomagámo": "estomagar",
    "estomagámos": "estomagar",
    "estomagáramo": "estomagar",
    "estomagáramos": "estomagar",
    "estomagárei": "estomagar",
    "estomagáreis": "estomagar",
    "estomagásseis": "estomagar",
    "estomagássemos": "estomagar",
    "estomagávamo": "estomagar",
    "estomagávamos": "estomagar",
    "estomagávei": "estomagar",
    "estomagáveis": "estomagar",
    "estomas": "estoma",
    "estomatites": "estomatite",
    "estomatologias": "estomatologia",
    "estomatologistas": "estomatologista",
    "estomatológica": "estomatológico",
    "estomatológicas": "estomatológico",
    "estomatológicos": "estomatológico",
    "estomatoscópica": "estomatoscópico",
    "estomatoscópicas": "estomatoscópico",
    "estomatoscópicos": "estomatoscópico",
    "estomatoscópios": "estomatoscópio",
    "estomatítica": "estomatítico",
    "estomatíticas": "estomatítico",
    "estomatíticos": "estomatítico",
    "estomatópodes": "estomatópode",
    "estomenta": "estomentar",
    "estomentada": "estomentar",
    "estomentadas": "estomentar",
    "estomentado": "estomentar",
    "estomentados": "estomentar",
    "estomentai": "estomentar",
    "estomentais": "estomentar",
    "estomentam": "estomentar",
    "estomentamo": "estomentar",
    "estomentamos": "estomentar",
    "estomentando": "estomentar",
    "estomentara": "estomentar",
    "estomentaram": "estomentar",
    "estomentaras": "estomentar",
    "estomentarde": "estomentar",
    "estomentardes": "estomentar",
    "estomentare": "estomentar",
    "estomentarei": "estomentar",
    "estomentareis": "estomentar",
    "estomentarem": "estomentar",
    "estomentaremos": "estomentar",
    "estomentares": "estomentar",
    "estomentaria": "estomentar",
    "estomentariam": "estomentar",
    "estomentarias": "estomentar",
    "estomentarmo": "estomentar",
    "estomentarmos": "estomentar",
    "estomentará": "estomentar",
    "estomentarás": "estomentar",
    "estomentarão": "estomentar",
    "estomentaríamos": "estomentar",
    "estomentaríeis": "estomentar",
    "estomentas": "estomentar",
    "estomentasse": "estomentar",
    "estomentassem": "estomentar",
    "estomentasses": "estomentar",
    "estomentaste": "estomentar",
    "estomentastes": "estomentar",
    "estomentava": "estomentar",
    "estomentavam": "estomentar",
    "estomentavas": "estomentar",
    "estomentações": "estomentação",
    "estomente": "estomentar",
    "estomentei": "estomentar",
    "estomenteis": "estomentar",
    "estomentem": "estomentar",
    "estomentemo": "estomentar",
    "estomentemos": "estomentar",
    "estomentes": "estomentar",
    "estomento": "estomentar",
    "estomentou": "estomentar",
    "estomentá": "estomentar",
    "estomentámo": "estomentar",
    "estomentámos": "estomentar",
    "estomentáramo": "estomentar",
    "estomentáramos": "estomentar",
    "estomentárei": "estomentar",
    "estomentáreis": "estomentar",
    "estomentásseis": "estomentar",
    "estomentássemos": "estomentar",
    "estomentávamo": "estomentar",
    "estomentávamos": "estomentar",
    "estomentávei": "estomentar",
    "estomentáveis": "estomentar",
    "estomáquica": "estomáquico",
    "estomáquicas": "estomáquico",
    "estomáquicos": "estomáquico",
    "estomática": "estomático",
    "estomáticas": "estomático",
    "estomáticos": "estomático",
    "estona": "estonar",
    "estonada": "estonar",
    "estonadas": "estonar",
    "estonado": "estonar",
    "estonadores": "estonador",
    "estonados": "estonar",
    "estonaduras": "estonadura",
    "estonai": "estonar",
    "estonais": "estonar",
    "estonam": "estonar",
    "estonamentos": "estonamento",
    "estonamo": "estonar",
    "estonamos": "estonar",
    "estonando": "estonar",
    "estonara": "estonar",
    "estonaram": "estonar",
    "estonaras": "estonar",
    "estonarde": "estonar",
    "estonardes": "estonar",
    "estonare": "estonar",
    "estonarei": "estonar",
    "estonareis": "estonar",
    "estonarem": "estonar",
    "estonaremos": "estonar",
    "estonares": "estonar",
    "estonaria": "estonar",
    "estonariam": "estonar",
    "estonarias": "estonar",
    "estonarmo": "estonar",
    "estonarmos": "estonar",
    "estonará": "estonar",
    "estonarás": "estonar",
    "estonarão": "estonar",
    "estonaríamos": "estonar",
    "estonaríeis": "estonar",
    "estonas": "estonar",
    "estonasse": "estonar",
    "estonassem": "estonar",
    "estonasses": "estonar",
    "estonaste": "estonar",
    "estonastes": "estonar",
    "estonava": "estonar",
    "estonavam": "estonar",
    "estonavas": "estonar",
    "estone": "estonar",
    "estonei": "estonar",
    "estoneis": "estonar",
    "estonem": "estonar",
    "estonemo": "estonar",
    "estonemos": "estonar",
    "estones": "estonar",
    "estoniana": "estoniano",
    "estonianas": "estoniano",
    "estonianos": "estoniano",
    "estono": "estonar",
    "estonou": "estonar",
    "estonta": "estontar",
    "estontada": "estontar",
    "estontadas": "estontar",
    "estontado": "estontar",
    "estontados": "estontar",
    "estontai": "estontar",
    "estontais": "estontar",
    "estontam": "estontar",
    "estontamo": "estontar",
    "estontamos": "estontar",
    "estontando": "estontar",
    "estontara": "estontar",
    "estontaram": "estontar",
    "estontaras": "estontar",
    "estontarde": "estontar",
    "estontardes": "estontar",
    "estontare": "estontar",
    "estontarei": "estontar",
    "estontareis": "estontar",
    "estontarem": "estontar",
    "estontaremos": "estontar",
    "estontares": "estontar",
    "estontaria": "estontar",
    "estontariam": "estontar",
    "estontarias": "estontar",
    "estontarmo": "estontar",
    "estontarmos": "estontar",
    "estontará": "estontar",
    "estontarás": "estontar",
    "estontarão": "estontar",
    "estontaríamos": "estontar",
    "estontaríeis": "estontar",
    "estontas": "estontar",
    "estontasse": "estontar",
    "estontassem": "estontar",
    "estontasses": "estontar",
    "estontaste": "estontar",
    "estontastes": "estontar",
    "estontava": "estontar",
    "estontavam": "estontar",
    "estontavas": "estontar",
    "estonte": "estontar",
    "estonteada": "estontear",
    "estonteadas": "estontear",
    "estonteado": "estontear",
    "estonteadora": "estonteador",
    "estonteadoras": "estonteador",
    "estonteadores": "estonteador",
    "estonteados": "estontear",
    "estonteai": "estontear",
    "estonteais": "estontear",
    "estonteamentos": "estonteamento",
    "estonteamo": "estontear",
    "estonteamos": "estontear",
    "estonteando": "estontear",
    "estonteantes": "estonteante",
    "estonteara": "estontear",
    "estontearam": "estontear",
    "estontearas": "estontear",
    "estontearde": "estontear",
    "estonteardes": "estontear",
    "estonteare": "estontear",
    "estontearei": "estontear",
    "estonteareis": "estontear",
    "estontearem": "estontear",
    "estontearemos": "estontear",
    "estonteares": "estontear",
    "estontearia": "estontear",
    "estonteariam": "estontear",
    "estontearias": "estontear",
    "estontearmo": "estontear",
    "estontearmos": "estontear",
    "estonteará": "estontear",
    "estontearás": "estontear",
    "estontearão": "estontear",
    "estontearíamos": "estontear",
    "estontearíeis": "estontear",
    "estonteasse": "estontear",
    "estonteassem": "estontear",
    "estonteasses": "estontear",
    "estonteaste": "estontear",
    "estonteastes": "estontear",
    "estonteava": "estontear",
    "estonteavam": "estontear",
    "estonteavas": "estontear",
    "estontece": "estontecer",
    "estontecei": "estontecer",
    "estonteceis": "estontecer",
    "estontecem": "estontecer",
    "estontecemo": "estontecer",
    "estontecemos": "estontecer",
    "estontecendo": "estontecer",
    "estontecera": "estontecer",
    "estonteceram": "estontecer",
    "estonteceras": "estontecer",
    "estontecerdes": "estontecer",
    "estontecerei": "estontecer",
    "estontecereis": "estontecer",
    "estontecerem": "estontecer",
    "estonteceremos": "estontecer",
    "estonteceres": "estontecer",
    "estonteceria": "estontecer",
    "estonteceriam": "estontecer",
    "estontecerias": "estontecer",
    "estontecermo": "estontecer",
    "estontecermos": "estontecer",
    "estontecerá": "estontecer",
    "estontecerás": "estontecer",
    "estontecerão": "estontecer",
    "estonteceríamos": "estontecer",
    "estonteceríeis": "estontecer",
    "estonteces": "estontecer",
    "estontecesse": "estontecer",
    "estontecessem": "estontecer",
    "estontecesses": "estontecer",
    "estonteceste": "estontecer",
    "estontecestes": "estontecer",
    "estonteceu": "estontecer",
    "estonteci": "estontecer",
    "estontecia": "estontecer",
    "estonteciam": "estontecer",
    "estontecias": "estontecer",
    "estontecida": "estontecer",
    "estontecidas": "estontecer",
    "estontecido": "estontecer",
    "estontecidos": "estontecer",
    "estontecêramo": "estontecer",
    "estontecêramos": "estontecer",
    "estontecêreis": "estontecer",
    "estontecêsseis": "estontecer",
    "estontecêssemos": "estontecer",
    "estontecíamo": "estontecer",
    "estontecíamos": "estontecer",
    "estontecíeis": "estontecer",
    "estonteei": "estontear",
    "estonteeis": "estontear",
    "estonteemo": "estontear",
    "estonteemos": "estontear",
    "estontei": "estontar",
    "estonteia": "estontear",
    "estonteiam": "estontear",
    "estonteias": "estontear",
    "estonteie": "estontear",
    "estonteiem": "estontear",
    "estonteies": "estontear",
    "estonteio": "estontear",
    "estonteis": "estontar",
    "estontem": "estontar",
    "estontemo": "estontar",
    "estontemos": "estontar",
    "estonteou": "estontear",
    "estontes": "estontar",
    "estonteá": "estontear",
    "estonteámo": "estontear",
    "estonteámos": "estontear",
    "estonteáramo": "estontear",
    "estonteáramos": "estontear",
    "estonteárei": "estontear",
    "estonteáreis": "estontear",
    "estonteásseis": "estontear",
    "estonteássemos": "estontear",
    "estonteávamo": "estontear",
    "estonteávamos": "estontear",
    "estonteávei": "estontear",
    "estonteáveis": "estontear",
    "estonteça": "estontecer",
    "estonteçais": "estontecer",
    "estonteçam": "estontecer",
    "estonteçamo": "estontecer",
    "estonteçamos": "estontecer",
    "estonteças": "estontecer",
    "estonteço": "estontecer",
    "estonto": "estontar",
    "estontou": "estontar",
    "estontá": "estontar",
    "estontámo": "estontar",
    "estontámos": "estontar",
    "estontáramo": "estontar",
    "estontáramos": "estontar",
    "estontárei": "estontar",
    "estontáreis": "estontar",
    "estontásseis": "estontar",
    "estontássemos": "estontar",
    "estontávamo": "estontar",
    "estontávamos": "estontar",
    "estontávei": "estontar",
    "estontáveis": "estontar",
    "estoná": "estonar",
    "estonámo": "estonar",
    "estonámos": "estonar",
    "estonáramo": "estonar",
    "estonáramos": "estonar",
    "estonárei": "estonar",
    "estonáreis": "estonar",
    "estonásseis": "estonar",
    "estonássemos": "estonar",
    "estonávamo": "estonar",
    "estonávamos": "estonar",
    "estonávei": "estonar",
    "estonáveis": "estonar",
    "estopa": "estopar",
    "estopada": "estopar",
    "estopadas": "estopar",
    "estopado": "estopar",
    "estopados": "estopar",
    "estopai": "estopar",
    "estopais": "estopar",
    "estopam": "estopar",
    "estopamo": "estopar",
    "estopamos": "estopar",
    "estopando": "estopar",
    "estopantes": "estopante",
    "estopara": "estopar",
    "estoparam": "estopar",
    "estoparas": "estopar",
    "estoparde": "estopar",
    "estopardes": "estopar",
    "estopare": "estopar",
    "estoparei": "estopar",
    "estopareis": "estopar",
    "estoparem": "estopar",
    "estoparemos": "estopar",
    "estopares": "estopar",
    "estoparia": "estopar",
    "estopariam": "estopar",
    "estoparias": "estopar",
    "estoparmo": "estopar",
    "estoparmos": "estopar",
    "estopará": "estopar",
    "estoparás": "estopar",
    "estoparão": "estopar",
    "estoparíamos": "estopar",
    "estoparíeis": "estopar",
    "estopas": "estopar",
    "estopasse": "estopar",
    "estopassem": "estopar",
    "estopasses": "estopar",
    "estopaste": "estopar",
    "estopastes": "estopar",
    "estopava": "estopar",
    "estopavam": "estopar",
    "estopavas": "estopar",
    "estope": "estopar",
    "estopei": "estopar",
    "estopeis": "estopar",
    "estopem": "estopar",
    "estopemo": "estopar",
    "estopemos": "estopar",
    "estopenta": "estopento",
    "estopentas": "estopento",
    "estopentos": "estopento",
    "estopes": "estopar",
    "estopeta": "estopetar",
    "estopetada": "estopetar",
    "estopetadas": "estopetar",
    "estopetado": "estopetar",
    "estopetados": "estopetar",
    "estopetai": "estopetar",
    "estopetais": "estopetar",
    "estopetam": "estopetar",
    "estopetamo": "estopetar",
    "estopetamos": "estopetar",
    "estopetando": "estopetar",
    "estopetara": "estopetar",
    "estopetaram": "estopetar",
    "estopetaras": "estopetar",
    "estopetarde": "estopetar",
    "estopetardes": "estopetar",
    "estopetare": "estopetar",
    "estopetarei": "estopetar",
    "estopetareis": "estopetar",
    "estopetarem": "estopetar",
    "estopetaremos": "estopetar",
    "estopetares": "estopetar",
    "estopetaria": "estopetar",
    "estopetariam": "estopetar",
    "estopetarias": "estopetar",
    "estopetarmo": "estopetar",
    "estopetarmos": "estopetar",
    "estopetará": "estopetar",
    "estopetarás": "estopetar",
    "estopetarão": "estopetar",
    "estopetaríamos": "estopetar",
    "estopetaríeis": "estopetar",
    "estopetas": "estopetar",
    "estopetasse": "estopetar",
    "estopetassem": "estopetar",
    "estopetasses": "estopetar",
    "estopetaste": "estopetar",
    "estopetastes": "estopetar",
    "estopetava": "estopetar",
    "estopetavam": "estopetar",
    "estopetavas": "estopetar",
    "estopete": "estopetar",
    "estopetei": "estopetar",
    "estopeteis": "estopetar",
    "estopetem": "estopetar",
    "estopetemo": "estopetar",
    "estopetemos": "estopetar",
    "estopetes": "estopetar",
    "estopeto": "estopetar",
    "estopetou": "estopetar",
    "estopetá": "estopetar",
    "estopetámo": "estopetar",
    "estopetámos": "estopetar",
    "estopetáramo": "estopetar",
    "estopetáramos": "estopetar",
    "estopetárei": "estopetar",
    "estopetáreis": "estopetar",
    "estopetásseis": "estopetar",
    "estopetássemos": "estopetar",
    "estopetávamo": "estopetar",
    "estopetávamos": "estopetar",
    "estopetávei": "estopetar",
    "estopetáveis": "estopetar",
    "estopinhas": "estopinha",
    "estopins": "estopim",
    "estopo": "estopar",
    "estoposa": "estoposo",
    "estoposas": "estoposo",
    "estoposos": "estoposo",
    "estopou": "estopar",
    "estopá": "estopar",
    "estopámo": "estopar",
    "estopámos": "estopar",
    "estopáramo": "estopar",
    "estopáramos": "estopar",
    "estopárei": "estopar",
    "estopáreis": "estopar",
    "estopásseis": "estopar",
    "estopássemos": "estopar",
    "estopávamo": "estopar",
    "estopávamos": "estopar",
    "estopávei": "estopar",
    "estopáveis": "estopar",
    "estopões": "estopão",
    "estoque": "estocar",
    "estoqueada": "estoquear",
    "estoqueadas": "estoquear",
    "estoqueado": "estoquear",
    "estoqueados": "estoquear",
    "estoqueaduras": "estoqueadura",
    "estoqueai": "estoquear",
    "estoqueais": "estoquear",
    "estoqueamo": "estoquear",
    "estoqueamos": "estoquear",
    "estoqueando": "estoquear",
    "estoqueara": "estoquear",
    "estoquearam": "estoquear",
    "estoquearas": "estoquear",
    "estoquearde": "estoquear",
    "estoqueardes": "estoquear",
    "estoqueare": "estoquear",
    "estoquearei": "estoquear",
    "estoqueareis": "estoquear",
    "estoquearem": "estoquear",
    "estoquearemos": "estoquear",
    "estoqueares": "estoquear",
    "estoquearia": "estoquear",
    "estoqueariam": "estoquear",
    "estoquearias": "estoquear",
    "estoquearmo": "estoquear",
    "estoquearmos": "estoquear",
    "estoqueará": "estoquear",
    "estoquearás": "estoquear",
    "estoquearão": "estoquear",
    "estoquearíamos": "estoquear",
    "estoquearíeis": "estoquear",
    "estoqueasse": "estoquear",
    "estoqueassem": "estoquear",
    "estoqueasses": "estoquear",
    "estoqueaste": "estoquear",
    "estoqueastes": "estoquear",
    "estoqueava": "estoquear",
    "estoqueavam": "estoquear",
    "estoqueavas": "estoquear",
    "estoqueei": "estoquear",
    "estoqueeis": "estoquear",
    "estoqueemo": "estoquear",
    "estoqueemos": "estoquear",
    "estoquei": "estocar",
    "estoqueia": "estoquear",
    "estoqueiam": "estoquear",
    "estoqueias": "estoquear",
    "estoqueie": "estoquear",
    "estoqueiem": "estoquear",
    "estoqueies": "estoquear",
    "estoqueio": "estoquear",
    "estoqueis": "estocar",
    "estoquem": "estocar",
    "estoquemo": "estocar",
    "estoquemos": "estocar",
    "estoqueou": "estoquear",
    "estoques": "estoque",
    "estoqueá": "estoquear",
    "estoqueámo": "estoquear",
    "estoqueámos": "estoquear",
    "estoqueáramo": "estoquear",
    "estoqueáramos": "estoquear",
    "estoqueárei": "estoquear",
    "estoqueáreis": "estoquear",
    "estoqueásseis": "estoquear",
    "estoqueássemos": "estoquear",
    "estoqueávamo": "estoquear",
    "estoqueávamos": "estoquear",
    "estoqueávei": "estoquear",
    "estoqueáveis": "estoquear",
    "estoraques": "estoraque",
    "estorce": "estorcer",
    "estorcega": "estorcegar",
    "estorcegada": "estorcegar",
    "estorcegadas": "estorcegar",
    "estorcegadelas": "estorcegadela",
    "estorcegado": "estorcegar",
    "estorcegados": "estorcegar",
    "estorcegaduras": "estorcegadura",
    "estorcegai": "estorcegar",
    "estorcegais": "estorcegar",
    "estorcegam": "estorcegar",
    "estorcegamo": "estorcegar",
    "estorcegamos": "estorcegar",
    "estorcegando": "estorcegar",
    "estorcegara": "estorcegar",
    "estorcegaram": "estorcegar",
    "estorcegaras": "estorcegar",
    "estorcegarde": "estorcegar",
    "estorcegardes": "estorcegar",
    "estorcegare": "estorcegar",
    "estorcegarei": "estorcegar",
    "estorcegareis": "estorcegar",
    "estorcegarem": "estorcegar",
    "estorcegaremos": "estorcegar",
    "estorcegares": "estorcegar",
    "estorcegaria": "estorcegar",
    "estorcegariam": "estorcegar",
    "estorcegarias": "estorcegar",
    "estorcegarmo": "estorcegar",
    "estorcegarmos": "estorcegar",
    "estorcegará": "estorcegar",
    "estorcegarás": "estorcegar",
    "estorcegarão": "estorcegar",
    "estorcegaríamos": "estorcegar",
    "estorcegaríeis": "estorcegar",
    "estorcegas": "estorcegar",
    "estorcegasse": "estorcegar",
    "estorcegassem": "estorcegar",
    "estorcegasses": "estorcegar",
    "estorcegaste": "estorcegar",
    "estorcegastes": "estorcegar",
    "estorcegava": "estorcegar",
    "estorcegavam": "estorcegar",
    "estorcegavas": "estorcegar",
    "estorcego": "estorcegar",
    "estorcegou": "estorcegar",
    "estorcegue": "estorcegar",
    "estorceguei": "estorcegar",
    "estorcegueis": "estorcegar",
    "estorceguem": "estorcegar",
    "estorceguemo": "estorcegar",
    "estorceguemos": "estorcegar",
    "estorcegues": "estorcegar",
    "estorcegá": "estorcegar",
    "estorcegámo": "estorcegar",
    "estorcegámos": "estorcegar",
    "estorcegáramo": "estorcegar",
    "estorcegáramos": "estorcegar",
    "estorcegárei": "estorcegar",
    "estorcegáreis": "estorcegar",
    "estorcegásseis": "estorcegar",
    "estorcegássemos": "estorcegar",
    "estorcegávamo": "estorcegar",
    "estorcegávamos": "estorcegar",
    "estorcegávei": "estorcegar",
    "estorcegáveis": "estorcegar",
    "estorcegões": "estorcegão",
    "estorcei": "estorcer",
    "estorceis": "estorcer",
    "estorcem": "estorcer",
    "estorcemo": "estorcer",
    "estorcemos": "estorcer",
    "estorcendo": "estorcer",
    "estorcera": "estorcer",
    "estorceram": "estorcer",
    "estorceras": "estorcer",
    "estorcerde": "estorcer",
    "estorcerdes": "estorcer",
    "estorcere": "estorcer",
    "estorcerei": "estorcer",
    "estorcereis": "estorcer",
    "estorcerem": "estorcer",
    "estorceremos": "estorcer",
    "estorceres": "estorcer",
    "estorceria": "estorcer",
    "estorceriam": "estorcer",
    "estorcerias": "estorcer",
    "estorcermo": "estorcer",
    "estorcermos": "estorcer",
    "estorcerá": "estorcer",
    "estorcerás": "estorcer",
    "estorcerão": "estorcer",
    "estorceríamos": "estorcer",
    "estorceríeis": "estorcer",
    "estorces": "estorcer",
    "estorcesse": "estorcer",
    "estorcessem": "estorcer",
    "estorcesses": "estorcer",
    "estorceste": "estorcer",
    "estorcestes": "estorcer",
    "estorceu": "estorcer",
    "estorci": "estorcer",
    "estorcia": "estorcer",
    "estorciam": "estorcer",
    "estorcias": "estorcer",
    "estorcida": "estorcer",
    "estorcidas": "estorcer",
    "estorcido": "estorcer",
    "estorcidos": "estorcer",
    "estorcimentos": "estorcimento",
    "estorcê": "estorcer",
    "estorcêramo": "estorcer",
    "estorcêramos": "estorcer",
    "estorcêrei": "estorcer",
    "estorcêreis": "estorcer",
    "estorcêsseis": "estorcer",
    "estorcêssemos": "estorcer",
    "estorcíamo": "estorcer",
    "estorcíamos": "estorcer",
    "estorcíei": "estorcer",
    "estorcíeis": "estorcer",
    "estores": "estore",
    "estorgas": "estorga",
    "estorna": "estornar",
    "estornada": "estornar",
    "estornadas": "estornar",
    "estornado": "estornar",
    "estornados": "estornar",
    "estornai": "estornar",
    "estornais": "estornar",
    "estornam": "estornar",
    "estornamo": "estornar",
    "estornamos": "estornar",
    "estornando": "estornar",
    "estornara": "estornar",
    "estornaram": "estornar",
    "estornaras": "estornar",
    "estornarde": "estornar",
    "estornardes": "estornar",
    "estornare": "estornar",
    "estornarei": "estornar",
    "estornareis": "estornar",
    "estornarem": "estornar",
    "estornaremos": "estornar",
    "estornares": "estornar",
    "estornaria": "estornar",
    "estornariam": "estornar",
    "estornarias": "estornar",
    "estornarmo": "estornar",
    "estornarmos": "estornar",
    "estornará": "estornar",
    "estornarás": "estornar",
    "estornarão": "estornar",
    "estornaríamos": "estornar",
    "estornaríeis": "estornar",
    "estornas": "estornar",
    "estornasse": "estornar",
    "estornassem": "estornar",
    "estornasses": "estornar",
    "estornaste": "estornar",
    "estornastes": "estornar",
    "estornava": "estornar",
    "estornavam": "estornar",
    "estornavas": "estornar",
    "estorne": "estornar",
    "estornei": "estornar",
    "estorneis": "estornar",
    "estornem": "estornar",
    "estornemo": "estornar",
    "estornemos": "estornar",
    "estornes": "estornar",
    "estornica": "estornicar",
    "estornicada": "estornicar",
    "estornicadas": "estornicar",
    "estornicado": "estornicar",
    "estornicados": "estornicar",
    "estornicai": "estornicar",
    "estornicais": "estornicar",
    "estornicam": "estornicar",
    "estornicamo": "estornicar",
    "estornicamos": "estornicar",
    "estornicando": "estornicar",
    "estornicara": "estornicar",
    "estornicaram": "estornicar",
    "estornicaras": "estornicar",
    "estornicarde": "estornicar",
    "estornicardes": "estornicar",
    "estornicare": "estornicar",
    "estornicarei": "estornicar",
    "estornicareis": "estornicar",
    "estornicarem": "estornicar",
    "estornicaremos": "estornicar",
    "estornicares": "estornicar",
    "estornicaria": "estornicar",
    "estornicariam": "estornicar",
    "estornicarias": "estornicar",
    "estornicarmo": "estornicar",
    "estornicarmos": "estornicar",
    "estornicará": "estornicar",
    "estornicarás": "estornicar",
    "estornicarão": "estornicar",
    "estornicaríamos": "estornicar",
    "estornicaríeis": "estornicar",
    "estornicas": "estornicar",
    "estornicasse": "estornicar",
    "estornicassem": "estornicar",
    "estornicasses": "estornicar",
    "estornicaste": "estornicar",
    "estornicastes": "estornicar",
    "estornicava": "estornicar",
    "estornicavam": "estornicar",
    "estornicavas": "estornicar",
    "estornico": "estornicar",
    "estornicou": "estornicar",
    "estornicá": "estornicar",
    "estornicámo": "estornicar",
    "estornicámos": "estornicar",
    "estornicáramo": "estornicar",
    "estornicáramos": "estornicar",
    "estornicárei": "estornicar",
    "estornicáreis": "estornicar",
    "estornicásseis": "estornicar",
    "estornicássemos": "estornicar",
    "estornicávamo": "estornicar",
    "estornicávamos": "estornicar",
    "estornicávei": "estornicar",
    "estornicáveis": "estornicar",
    "estorninhos": "estorninho",
    "estornique": "estornicar",
    "estorniquei": "estornicar",
    "estorniqueis": "estornicar",
    "estorniquem": "estornicar",
    "estorniquemo": "estornicar",
    "estorniquemos": "estornicar",
    "estorniques": "estornicar",
    "estorno": "estornar",
    "estornos": "estorno",
    "estornou": "estornar",
    "estorná": "estornar",
    "estornámo": "estornar",
    "estornámos": "estornar",
    "estornáramo": "estornar",
    "estornáramos": "estornar",
    "estornárei": "estornar",
    "estornáreis": "estornar",
    "estornásseis": "estornar",
    "estornássemos": "estornar",
    "estornávamo": "estornar",
    "estornávamos": "estornar",
    "estornávei": "estornar",
    "estornáveis": "estornável",
    "estorrica": "estorricar",
    "estorricada": "estorricar",
    "estorricadas": "estorricar",
    "estorricado": "estorricar",
    "estorricados": "estorricar",
    "estorricai": "estorricar",
    "estorricais": "estorricar",
    "estorricam": "estorricar",
    "estorricamo": "estorricar",
    "estorricamos": "estorricar",
    "estorricando": "estorricar",
    "estorricara": "estorricar",
    "estorricaram": "estorricar",
    "estorricaras": "estorricar",
    "estorricarde": "estorricar",
    "estorricardes": "estorricar",
    "estorricare": "estorricar",
    "estorricarei": "estorricar",
    "estorricareis": "estorricar",
    "estorricarem": "estorricar",
    "estorricaremos": "estorricar",
    "estorricares": "estorricar",
    "estorricaria": "estorricar",
    "estorricariam": "estorricar",
    "estorricarias": "estorricar",
    "estorricarmo": "estorricar",
    "estorricarmos": "estorricar",
    "estorricará": "estorricar",
    "estorricarás": "estorricar",
    "estorricarão": "estorricar",
    "estorricaríamos": "estorricar",
    "estorricaríeis": "estorricar",
    "estorricas": "estorricar",
    "estorricasse": "estorricar",
    "estorricassem": "estorricar",
    "estorricasses": "estorricar",
    "estorricaste": "estorricar",
    "estorricastes": "estorricar",
    "estorricava": "estorricar",
    "estorricavam": "estorricar",
    "estorricavas": "estorricar",
    "estorrico": "estorricar",
    "estorricou": "estorricar",
    "estorricá": "estorricar",
    "estorricámo": "estorricar",
    "estorricámos": "estorricar",
    "estorricáramo": "estorricar",
    "estorricáramos": "estorricar",
    "estorricárei": "estorricar",
    "estorricáreis": "estorricar",
    "estorricásseis": "estorricar",
    "estorricássemos": "estorricar",
    "estorricávamo": "estorricar",
    "estorricávamos": "estorricar",
    "estorricávei": "estorricar",
    "estorricáveis": "estorricar",
    "estorrique": "estorricar",
    "estorriquei": "estorricar",
    "estorriqueis": "estorricar",
    "estorriquem": "estorricar",
    "estorriquemo": "estorricar",
    "estorriquemos": "estorricar",
    "estorriques": "estorricar",
    "estorroa": "estorroar",
    "estorroada": "estorroar",
    "estorroadas": "estorroar",
    "estorroado": "estorroar",
    "estorroados": "estorroar",
    "estorroai": "estorroar",
    "estorroais": "estorroar",
    "estorroam": "estorroar",
    "estorroamo": "estorroar",
    "estorroamos": "estorroar",
    "estorroando": "estorroar",
    "estorroara": "estorroar",
    "estorroaram": "estorroar",
    "estorroaras": "estorroar",
    "estorroarde": "estorroar",
    "estorroardes": "estorroar",
    "estorroare": "estorroar",
    "estorroarei": "estorroar",
    "estorroareis": "estorroar",
    "estorroarem": "estorroar",
    "estorroaremos": "estorroar",
    "estorroares": "estorroar",
    "estorroaria": "estorroar",
    "estorroariam": "estorroar",
    "estorroarias": "estorroar",
    "estorroarmo": "estorroar",
    "estorroarmos": "estorroar",
    "estorroará": "estorroar",
    "estorroarás": "estorroar",
    "estorroarão": "estorroar",
    "estorroaríamos": "estorroar",
    "estorroaríeis": "estorroar",
    "estorroas": "estorroar",
    "estorroasse": "estorroar",
    "estorroassem": "estorroar",
    "estorroasses": "estorroar",
    "estorroaste": "estorroar",
    "estorroastes": "estorroar",
    "estorroava": "estorroar",
    "estorroavam": "estorroar",
    "estorroavas": "estorroar",
    "estorroe": "estorroar",
    "estorroei": "estorroar",
    "estorroeis": "estorroar",
    "estorroem": "estorroar",
    "estorroemo": "estorroar",
    "estorroemos": "estorroar",
    "estorroes": "estorroar",
    "estorroo": "estorroar",
    "estorroou": "estorroar",
    "estorroá": "estorroar",
    "estorroámo": "estorroar",
    "estorroámos": "estorroar",
    "estorroáramo": "estorroar",
    "estorroáramos": "estorroar",
    "estorroárei": "estorroar",
    "estorroáreis": "estorroar",
    "estorroásseis": "estorroar",
    "estorroássemos": "estorroar",
    "estorroávamo": "estorroar",
    "estorroávamos": "estorroar",
    "estorroávei": "estorroar",
    "estorroáveis": "estorroar",
    "estortega": "estortegar",
    "estortegada": "estortegar",
    "estortegadas": "estortegar",
    "estortegadelas": "estortegadela",
    "estortegado": "estortegar",
    "estortegados": "estortegar",
    "estortegaduras": "estortegadura",
    "estortegai": "estortegar",
    "estortegais": "estortegar",
    "estortegam": "estortegar",
    "estortegamo": "estortegar",
    "estortegamos": "estortegar",
    "estortegando": "estortegar",
    "estortegara": "estortegar",
    "estortegaram": "estortegar",
    "estortegaras": "estortegar",
    "estortegarde": "estortegar",
    "estortegardes": "estortegar",
    "estortegare": "estortegar",
    "estortegarei": "estortegar",
    "estortegareis": "estortegar",
    "estortegarem": "estortegar",
    "estortegaremos": "estortegar",
    "estortegares": "estortegar",
    "estortegaria": "estortegar",
    "estortegariam": "estortegar",
    "estortegarias": "estortegar",
    "estortegarmo": "estortegar",
    "estortegarmos": "estortegar",
    "estortegará": "estortegar",
    "estortegarás": "estortegar",
    "estortegarão": "estortegar",
    "estortegaríamos": "estortegar",
    "estortegaríeis": "estortegar",
    "estortegas": "estortegar",
    "estortegasse": "estortegar",
    "estortegassem": "estortegar",
    "estortegasses": "estortegar",
    "estortegaste": "estortegar",
    "estortegastes": "estortegar",
    "estortegava": "estortegar",
    "estortegavam": "estortegar",
    "estortegavas": "estortegar",
    "estortego": "estortegar",
    "estortegou": "estortegar",
    "estortegue": "estortegar",
    "estorteguei": "estortegar",
    "estortegueis": "estortegar",
    "estorteguem": "estortegar",
    "estorteguemo": "estortegar",
    "estorteguemos": "estortegar",
    "estortegues": "estortegar",
    "estortegá": "estortegar",
    "estortegámo": "estortegar",
    "estortegámos": "estortegar",
    "estortegáramo": "estortegar",
    "estortegáramos": "estortegar",
    "estortegárei": "estortegar",
    "estortegáreis": "estortegar",
    "estortegásseis": "estortegar",
    "estortegássemos": "estortegar",
    "estortegávamo": "estortegar",
    "estortegávamos": "estortegar",
    "estortegávei": "estortegar",
    "estortegáveis": "estortegar",
    "estortura": "estorturar",
    "estorturada": "estorturar",
    "estorturadas": "estorturar",
    "estorturado": "estorturar",
    "estorturados": "estorturar",
    "estorturai": "estorturar",
    "estorturais": "estorturar",
    "estorturam": "estorturar",
    "estorturamo": "estorturar",
    "estorturamos": "estorturar",
    "estorturando": "estorturar",
    "estorturara": "estorturar",
    "estorturaram": "estorturar",
    "estorturaras": "estorturar",
    "estorturarde": "estorturar",
    "estorturardes": "estorturar",
    "estorturare": "estorturar",
    "estorturarei": "estorturar",
    "estorturareis": "estorturar",
    "estorturarem": "estorturar",
    "estorturaremos": "estorturar",
    "estorturares": "estorturar",
    "estorturaria": "estorturar",
    "estorturariam": "estorturar",
    "estorturarias": "estorturar",
    "estorturarmo": "estorturar",
    "estorturarmos": "estorturar",
    "estorturará": "estorturar",
    "estorturarás": "estorturar",
    "estorturarão": "estorturar",
    "estorturaríamos": "estorturar",
    "estorturaríeis": "estorturar",
    "estorturas": "estorturar",
    "estorturasse": "estorturar",
    "estorturassem": "estorturar",
    "estorturasses": "estorturar",
    "estorturaste": "estorturar",
    "estorturastes": "estorturar",
    "estorturava": "estorturar",
    "estorturavam": "estorturar",
    "estorturavas": "estorturar",
    "estorture": "estorturar",
    "estorturei": "estorturar",
    "estortureis": "estorturar",
    "estorturem": "estorturar",
    "estorturemo": "estorturar",
    "estorturemos": "estorturar",
    "estortures": "estorturar",
    "estorturo": "estorturar",
    "estorturou": "estorturar",
    "estorturá": "estorturar",
    "estorturámo": "estorturar",
    "estorturámos": "estorturar",
    "estorturáramo": "estorturar",
    "estorturáramos": "estorturar",
    "estorturárei": "estorturar",
    "estorturáreis": "estorturar",
    "estorturásseis": "estorturar",
    "estorturássemos": "estorturar",
    "estorturávamo": "estorturar",
    "estorturávamos": "estorturar",
    "estorturávei": "estorturar",
    "estorturáveis": "estorturar",
    "estorva": "estorvar",
    "estorvada": "estorvar",
    "estorvadas": "estorvar",
    "estorvado": "estorvar",
    "estorvadora": "estorvador",
    "estorvadoras": "estorvador",
    "estorvadores": "estorvador",
    "estorvados": "estorvar",
    "estorvai": "estorvar",
    "estorvais": "estorvar",
    "estorvam": "estorvar",
    "estorvamentos": "estorvamento",
    "estorvamo": "estorvar",
    "estorvamos": "estorvar",
    "estorvando": "estorvar",
    "estorvara": "estorvar",
    "estorvaram": "estorvar",
    "estorvaras": "estorvar",
    "estorvarde": "estorvar",
    "estorvardes": "estorvar",
    "estorvare": "estorvar",
    "estorvarei": "estorvar",
    "estorvareis": "estorvar",
    "estorvarem": "estorvar",
    "estorvaremos": "estorvar",
    "estorvares": "estorvar",
    "estorvaria": "estorvar",
    "estorvariam": "estorvar",
    "estorvarias": "estorvar",
    "estorvarmo": "estorvar",
    "estorvarmos": "estorvar",
    "estorvará": "estorvar",
    "estorvarás": "estorvar",
    "estorvarão": "estorvar",
    "estorvaríamos": "estorvar",
    "estorvaríeis": "estorvar",
    "estorvas": "estorvar",
    "estorvasse": "estorvar",
    "estorvassem": "estorvar",
    "estorvasses": "estorvar",
    "estorvaste": "estorvar",
    "estorvastes": "estorvar",
    "estorvava": "estorvar",
    "estorvavam": "estorvar",
    "estorvavas": "estorvar",
    "estorve": "estorvar",
    "estorvei": "estorvar",
    "estorveis": "estorvar",
    "estorvem": "estorvar",
    "estorvemo": "estorvar",
    "estorvemos": "estorvar",
    "estorves": "estorvar",
    "estorvilhos": "estorvilho",
    "estorvo": "estorvar",
    "estorvos": "estorvo",
    "estorvou": "estorvar",
    "estorvá": "estorvar",
    "estorvámo": "estorvar",
    "estorvámos": "estorvar",
    "estorváramo": "estorvar",
    "estorváramos": "estorvar",
    "estorvárei": "estorvar",
    "estorváreis": "estorvar",
    "estorvásseis": "estorvar",
    "estorvássemos": "estorvar",
    "estorvávamo": "estorvar",
    "estorvávamos": "estorvar",
    "estorvávei": "estorvar",
    "estorváveis": "estorvar",
    "estorça": "estorcer",
    "estorçais": "estorcer",
    "estorçam": "estorcer",
    "estorçamo": "estorcer",
    "estorçamos": "estorcer",
    "estorças": "estorcer",
    "estorço": "estorcer",
    "estorços": "estorço",
    "estos": "esto",
    "estou": "estar",
    "estoura": "estourar",
    "estourada": "estourar",
    "estouradas": "estourar",
    "estouradinha": "estouradinho",
    "estouradinhas": "estouradinho",
    "estouradinhos": "estouradinho",
    "estourado": "estourar",
    "estourados": "estourar",
    "estourai": "estourar",
    "estourais": "estourar",
    "estouram": "estourar",
    "estouramo": "estourar",
    "estouramos": "estourar",
    "estourando": "estourar",
    "estourara": "estourar",
    "estouraram": "estourar",
    "estouraras": "estourar",
    "estourarde": "estourar",
    "estourardes": "estourar",
    "estourare": "estourar",
    "estourarei": "estourar",
    "estourareis": "estourar",
    "estourarem": "estourar",
    "estouraremos": "estourar",
    "estourares": "estourar",
    "estouraria": "estourar",
    "estourariam": "estourar",
    "estourarias": "estourar",
    "estourarmo": "estourar",
    "estourarmos": "estourar",
    "estourará": "estourar",
    "estourarás": "estourar",
    "estourarão": "estourar",
    "estouraríamos": "estourar",
    "estouraríeis": "estourar",
    "estouras": "estourar",
    "estourasse": "estourar",
    "estourassem": "estourar",
    "estourasses": "estourar",
    "estouraste": "estourar",
    "estourastes": "estourar",
    "estourava": "estourar",
    "estouravam": "estourar",
    "estouravas": "estourar",
    "estourazes": "estouraz",
    "estoure": "estourar",
    "estourei": "estourar",
    "estoureis": "estourar",
    "estourem": "estourar",
    "estouremo": "estourar",
    "estouremos": "estourar",
    "estoures": "estourar",
    "estourinha": "estourinhar",
    "estourinhada": "estourinhar",
    "estourinhadas": "estourinhar",
    "estourinhado": "estourinhar",
    "estourinhados": "estourinhar",
    "estourinhai": "estourinhar",
    "estourinhais": "estourinhar",
    "estourinham": "estourinhar",
    "estourinhamo": "estourinhar",
    "estourinhamos": "estourinhar",
    "estourinhando": "estourinhar",
    "estourinhara": "estourinhar",
    "estourinharam": "estourinhar",
    "estourinharas": "estourinhar",
    "estourinharde": "estourinhar",
    "estourinhardes": "estourinhar",
    "estourinhare": "estourinhar",
    "estourinharei": "estourinhar",
    "estourinhareis": "estourinhar",
    "estourinharem": "estourinhar",
    "estourinharemos": "estourinhar",
    "estourinhares": "estourinhar",
    "estourinharia": "estourinhar",
    "estourinhariam": "estourinhar",
    "estourinharias": "estourinhar",
    "estourinharmo": "estourinhar",
    "estourinharmos": "estourinhar",
    "estourinhará": "estourinhar",
    "estourinharás": "estourinhar",
    "estourinharão": "estourinhar",
    "estourinharíamos": "estourinhar",
    "estourinharíeis": "estourinhar",
    "estourinhas": "estourinhar",
    "estourinhasse": "estourinhar",
    "estourinhassem": "estourinhar",
    "estourinhasses": "estourinhar",
    "estourinhaste": "estourinhar",
    "estourinhastes": "estourinhar",
    "estourinhava": "estourinhar",
    "estourinhavam": "estourinhar",
    "estourinhavas": "estourinhar",
    "estourinhe": "estourinhar",
    "estourinhei": "estourinhar",
    "estourinheis": "estourinhar",
    "estourinhem": "estourinhar",
    "estourinhemo": "estourinhar",
    "estourinhemos": "estourinhar",
    "estourinhes": "estourinhar",
    "estourinho": "estourinhar",
    "estourinhou": "estourinhar",
    "estourinhá": "estourinhar",
    "estourinhámo": "estourinhar",
    "estourinhámos": "estourinhar",
    "estourinháramo": "estourinhar",
    "estourinháramos": "estourinhar",
    "estourinhárei": "estourinhar",
    "estourinháreis": "estourinhar",
    "estourinhásseis": "estourinhar",
    "estourinhássemos": "estourinhar",
    "estourinhávamo": "estourinhar",
    "estourinhávamos": "estourinhar",
    "estourinhávei": "estourinhar",
    "estourinháveis": "estourinhar",
    "estouro": "estourar",
    "estouros": "estouro",
    "estourou": "estourar",
    "estourá": "estourar",
    "estourámo": "estourar",
    "estourámos": "estourar",
    "estouráramo": "estourar",
    "estouráramos": "estourar",
    "estourárei": "estourar",
    "estouráreis": "estourar",
    "estourásseis": "estourar",
    "estourássemos": "estourar",
    "estourávamo": "estourar",
    "estourávamos": "estourar",
    "estourávei": "estourar",
    "estouráveis": "estourar",
    "estouvada": "estouvado",
    "estouvadas": "estouvado",
    "estouvadiça": "estouvadiço",
    "estouvadiças": "estouvadiço",
    "estouvadiços": "estouvadiço",
    "estouvados": "estouvado",
    "estouvamentos": "estouvamento",
    "estouvanices": "estouvanice",
    "estouvona": "estouvão",
    "estouvonas": "estouvão",
    "estouvões": "estouvão",
    "estra": "estrar",
    "estraba": "estrabar",
    "estrabada": "estrabar",
    "estrabadas": "estrabar",
    "estrabado": "estrabar",
    "estrabados": "estrabar",
    "estrabai": "estrabar",
    "estrabais": "estrabar",
    "estrabam": "estrabar",
    "estrabamo": "estrabar",
    "estrabamos": "estrabar",
    "estrabando": "estrabar",
    "estrabara": "estrabar",
    "estrabaram": "estrabar",
    "estrabaras": "estrabar",
    "estrabardes": "estrabar",
    "estrabarei": "estrabar",
    "estrabareis": "estrabar",
    "estrabarem": "estrabar",
    "estrabaremos": "estrabar",
    "estrabares": "estrabar",
    "estrabaria": "estrabar",
    "estrabariam": "estrabar",
    "estrabarias": "estrabar",
    "estrabarmo": "estrabar",
    "estrabarmos": "estrabar",
    "estrabará": "estrabar",
    "estrabarás": "estrabar",
    "estrabarão": "estrabar",
    "estrabaríamos": "estrabar",
    "estrabaríeis": "estrabar",
    "estrabas": "estrabar",
    "estrabasse": "estrabar",
    "estrabassem": "estrabar",
    "estrabasses": "estrabar",
    "estrabaste": "estrabar",
    "estrabastes": "estrabar",
    "estrabava": "estrabar",
    "estrabavam": "estrabar",
    "estrabavas": "estrabar",
    "estrabe": "estrabar",
    "estrabei": "estrabar",
    "estrabeis": "estrabar",
    "estrabem": "estrabar",
    "estrabemo": "estrabar",
    "estrabemos": "estrabar",
    "estrabes": "estrabar",
    "estrabismos": "estrabismo",
    "estrabo": "estrabar",
    "estrabometrias": "estrabometria",
    "estrabos": "estrabo",
    "estrabotomias": "estrabotomia",
    "estrabotómica": "estrabotómico",
    "estrabotómicas": "estrabotómico",
    "estrabotómicos": "estrabotómico",
    "estrabou": "estrabar",
    "estrabámo": "estrabar",
    "estrabámos": "estrabar",
    "estrabáramo": "estrabar",
    "estrabáramos": "estrabar",
    "estrabáreis": "estrabar",
    "estrabásseis": "estrabar",
    "estrabássemos": "estrabar",
    "estrabávamo": "estrabar",
    "estrabávamos": "estrabar",
    "estrabáveis": "estrabar",
    "estrabómetros": "estrabómetro",
    "estrabões": "estrabão",
    "estracinha": "estracinhar",
    "estracinhada": "estracinhar",
    "estracinhadas": "estracinhar",
    "estracinhado": "estracinhar",
    "estracinhados": "estracinhar",
    "estracinhai": "estracinhar",
    "estracinhais": "estracinhar",
    "estracinham": "estracinhar",
    "estracinhamo": "estracinhar",
    "estracinhamos": "estracinhar",
    "estracinhando": "estracinhar",
    "estracinhara": "estracinhar",
    "estracinharam": "estracinhar",
    "estracinharas": "estracinhar",
    "estracinharde": "estracinhar",
    "estracinhardes": "estracinhar",
    "estracinhare": "estracinhar",
    "estracinharei": "estracinhar",
    "estracinhareis": "estracinhar",
    "estracinharem": "estracinhar",
    "estracinharemos": "estracinhar",
    "estracinhares": "estracinhar",
    "estracinharia": "estracinhar",
    "estracinhariam": "estracinhar",
    "estracinharias": "estracinhar",
    "estracinharmo": "estracinhar",
    "estracinharmos": "estracinhar",
    "estracinhará": "estracinhar",
    "estracinharás": "estracinhar",
    "estracinharão": "estracinhar",
    "estracinharíamos": "estracinhar",
    "estracinharíeis": "estracinhar",
    "estracinhas": "estracinhar",
    "estracinhasse": "estracinhar",
    "estracinhassem": "estracinhar",
    "estracinhasses": "estracinhar",
    "estracinhaste": "estracinhar",
    "estracinhastes": "estracinhar",
    "estracinhava": "estracinhar",
    "estracinhavam": "estracinhar",
    "estracinhavas": "estracinhar",
    "estracinhe": "estracinhar",
    "estracinhei": "estracinhar",
    "estracinheis": "estracinhar",
    "estracinhem": "estracinhar",
    "estracinhemo": "estracinhar",
    "estracinhemos": "estracinhar",
    "estracinhes": "estracinhar",
    "estracinho": "estracinhar",
    "estracinhou": "estracinhar",
    "estracinhá": "estracinhar",
    "estracinhámo": "estracinhar",
    "estracinhámos": "estracinhar",
    "estracinháramo": "estracinhar",
    "estracinháramos": "estracinhar",
    "estracinhárei": "estracinhar",
    "estracinháreis": "estracinhar",
    "estracinhásseis": "estracinhar",
    "estracinhássemos": "estracinhar",
    "estracinhávamo": "estracinhar",
    "estracinhávamos": "estracinhar",
    "estracinhávei": "estracinhar",
    "estracinháveis": "estracinhar",
    "estracúmulos": "estracúmulo",
    "estrada": "estrar",
    "estradada": "estradar",
    "estradadas": "estradar",
    "estradado": "estradar",
    "estradados": "estradar",
    "estradai": "estradar",
    "estradais": "estradar",
    "estradam": "estradar",
    "estradamo": "estradar",
    "estradamos": "estradar",
    "estradando": "estradar",
    "estradara": "estradar",
    "estradaram": "estradar",
    "estradaras": "estradar",
    "estradarde": "estradar",
    "estradardes": "estradar",
    "estradare": "estradar",
    "estradarei": "estradar",
    "estradareis": "estradar",
    "estradarem": "estradar",
    "estradaremos": "estradar",
    "estradares": "estradar",
    "estradaria": "estradar",
    "estradariam": "estradar",
    "estradarias": "estradar",
    "estradarmo": "estradar",
    "estradarmos": "estradar",
    "estradará": "estradar",
    "estradarás": "estradar",
    "estradarão": "estradar",
    "estradaríamos": "estradar",
    "estradaríeis": "estradar",
    "estradas": "estrar",
    "estradasse": "estradar",
    "estradassem": "estradar",
    "estradasses": "estradar",
    "estradaste": "estradar",
    "estradastes": "estradar",
    "estradava": "estradar",
    "estradavam": "estradar",
    "estradavas": "estradar",
    "estrade": "estradar",
    "estradei": "estradar",
    "estradeira": "estradeiro",
    "estradeiras": "estradeiro",
    "estradeiros": "estradeiro",
    "estradeis": "estradar",
    "estradem": "estradar",
    "estrademo": "estradar",
    "estrademos": "estradar",
    "estrades": "estradar",
    "estradinha": "estrada",
    "estradinhas": "estrada",
    "estradinho": "estrado",
    "estradinhos": "estrado",
    "estradiotas": "estradiota",
    "estradiotes": "estradiote",
    "estradistas": "estradista",
    "estradita": "estrada",
    "estraditas": "estrada",
    "estradito": "estrado",
    "estraditos": "estrado",
    "estradivários": "estradivário",
    "estrado": "estrar",
    "estradonas": "estradona",
    "estrados": "estrar",
    "estradou": "estradar",
    "estradá": "estradar",
    "estradámo": "estradar",
    "estradámos": "estradar",
    "estradáramo": "estradar",
    "estradáramos": "estradar",
    "estradárei": "estradar",
    "estradáreis": "estradar",
    "estradásseis": "estradar",
    "estradássemos": "estradar",
    "estradávamo": "estradar",
    "estradávamos": "estradar",
    "estradávei": "estradar",
    "estradáveis": "estradar",
    "estradões": "estradão",
    "estrafalária": "estrafalário",
    "estrafalárias": "estrafalário",
    "estrafalários": "estrafalário",
    "estrafega": "estrafegar",
    "estrafegada": "estrafegar",
    "estrafegadas": "estrafegar",
    "estrafegado": "estrafegar",
    "estrafegados": "estrafegar",
    "estrafegai": "estrafegar",
    "estrafegais": "estrafegar",
    "estrafegam": "estrafegar",
    "estrafegamo": "estrafegar",
    "estrafegamos": "estrafegar",
    "estrafegando": "estrafegar",
    "estrafegara": "estrafegar",
    "estrafegaram": "estrafegar",
    "estrafegaras": "estrafegar",
    "estrafegarde": "estrafegar",
    "estrafegardes": "estrafegar",
    "estrafegare": "estrafegar",
    "estrafegarei": "estrafegar",
    "estrafegareis": "estrafegar",
    "estrafegarem": "estrafegar",
    "estrafegaremos": "estrafegar",
    "estrafegares": "estrafegar",
    "estrafegaria": "estrafegar",
    "estrafegariam": "estrafegar",
    "estrafegarias": "estrafegar",
    "estrafegarmo": "estrafegar",
    "estrafegarmos": "estrafegar",
    "estrafegará": "estrafegar",
    "estrafegarás": "estrafegar",
    "estrafegarão": "estrafegar",
    "estrafegaríamos": "estrafegar",
    "estrafegaríeis": "estrafegar",
    "estrafegas": "estrafegar",
    "estrafegasse": "estrafegar",
    "estrafegassem": "estrafegar",
    "estrafegasses": "estrafegar",
    "estrafegaste": "estrafegar",
    "estrafegastes": "estrafegar",
    "estrafegava": "estrafegar",
    "estrafegavam": "estrafegar",
    "estrafegavas": "estrafegar",
    "estrafego": "estrafegar",
    "estrafegos": "estrafego",
    "estrafegou": "estrafegar",
    "estrafegue": "estrafegar",
    "estrafeguei": "estrafegar",
    "estrafegueis": "estrafegar",
    "estrafeguem": "estrafegar",
    "estrafeguemo": "estrafegar",
    "estrafeguemos": "estrafegar",
    "estrafegues": "estrafegar",
    "estrafegá": "estrafegar",
    "estrafegámo": "estrafegar",
    "estrafegámos": "estrafegar",
    "estrafegáramo": "estrafegar",
    "estrafegáramos": "estrafegar",
    "estrafegárei": "estrafegar",
    "estrafegáreis": "estrafegar",
    "estrafegásseis": "estrafegar",
    "estrafegássemos": "estrafegar",
    "estrafegávamo": "estrafegar",
    "estrafegávamos": "estrafegar",
    "estrafegávei": "estrafegar",
    "estrafegáveis": "estrafegar",
    "estraga": "estragar",
    "estragada": "estragar",
    "estragadas": "estragar",
    "estragado": "estragar",
    "estragadona": "estragadão",
    "estragadonas": "estragadão",
    "estragadora": "estragador",
    "estragadoras": "estragador",
    "estragadores": "estragador",
    "estragados": "estragar",
    "estragadíssima": "estragado",
    "estragadíssimas": "estragado",
    "estragadíssimo": "estragado",
    "estragadíssimos": "estragado",
    "estragadões": "estragadão",
    "estragai": "estragar",
    "estragais": "estragar",
    "estragam": "estragar",
    "estragamentos": "estragamento",
    "estragamo": "estragar",
    "estragamos": "estragar",
    "estragando": "estragar",
    "estragara": "estragar",
    "estragaram": "estragar",
    "estragaras": "estragar",
    "estragarde": "estragar",
    "estragardes": "estragar",
    "estragare": "estragar",
    "estragarei": "estragar",
    "estragareis": "estragar",
    "estragarem": "estragar",
    "estragaremos": "estragar",
    "estragares": "estragar",
    "estragaria": "estragar",
    "estragariam": "estragar",
    "estragarias": "estragar",
    "estragarmo": "estragar",
    "estragarmos": "estragar",
    "estragará": "estragar",
    "estragarás": "estragar",
    "estragarão": "estragar",
    "estragaríamos": "estragar",
    "estragaríeis": "estragar",
    "estragas": "estragar",
    "estragasse": "estragar",
    "estragassem": "estragar",
    "estragasses": "estragar",
    "estragaste": "estragar",
    "estragastes": "estragar",
    "estragava": "estragar",
    "estragavam": "estragar",
    "estragavas": "estragar",
    "estragações": "estragação",
    "estrago": "estragar",
    "estragos": "estrago",
    "estragou": "estragar",
    "estrague": "estragar",
    "estraguei": "estragar",
    "estragueis": "estragar",
    "estraguem": "estragar",
    "estraguemo": "estragar",
    "estraguemos": "estragar",
    "estragues": "estragar",
    "estragá": "estragar",
    "estragámo": "estragar",
    "estragámos": "estragar",
    "estragáramo": "estragar",
    "estragáramos": "estragar",
    "estragárei": "estragar",
    "estragáreis": "estragar",
    "estragásseis": "estragar",
    "estragássemos": "estragar",
    "estragávamo": "estragar",
    "estragávamos": "estragar",
    "estragávei": "estragar",
    "estragáveis": "estragar",
    "estragões": "estragão",
    "estrai": "estrar",
    "estrais": "estrar",
    "estrala": "estralar",
    "estralada": "estralar",
    "estraladas": "estralar",
    "estralado": "estralar",
    "estralados": "estralar",
    "estralai": "estralar",
    "estralais": "estralar",
    "estralam": "estralar",
    "estralamo": "estralar",
    "estralamos": "estralar",
    "estralando": "estralar",
    "estralara": "estralar",
    "estralaram": "estralar",
    "estralaras": "estralar",
    "estralardes": "estralar",
    "estralarei": "estralar",
    "estralareis": "estralar",
    "estralarem": "estralar",
    "estralaremos": "estralar",
    "estralares": "estralar",
    "estralaria": "estralar",
    "estralariam": "estralar",
    "estralarias": "estralar",
    "estralarmo": "estralar",
    "estralarmos": "estralar",
    "estralará": "estralar",
    "estralarás": "estralar",
    "estralarão": "estralar",
    "estralaríamos": "estralar",
    "estralaríeis": "estralar",
    "estralas": "estralar",
    "estralasse": "estralar",
    "estralassem": "estralar",
    "estralasses": "estralar",
    "estralaste": "estralar",
    "estralastes": "estralar",
    "estralava": "estralar",
    "estralavam": "estralar",
    "estralavas": "estralar",
    "estrale": "estralar",
    "estralei": "estralar",
    "estraleis": "estralar",
    "estraleja": "estralejar",
    "estralejada": "estralejar",
    "estralejadas": "estralejar",
    "estralejado": "estralejar",
    "estralejados": "estralejar",
    "estralejai": "estralejar",
    "estralejais": "estralejar",
    "estralejam": "estralejar",
    "estralejamo": "estralejar",
    "estralejamos": "estralejar",
    "estralejando": "estralejar",
    "estralejara": "estralejar",
    "estralejaram": "estralejar",
    "estralejaras": "estralejar",
    "estralejardes": "estralejar",
    "estralejarei": "estralejar",
    "estralejareis": "estralejar",
    "estralejarem": "estralejar",
    "estralejaremos": "estralejar",
    "estralejares": "estralejar",
    "estralejaria": "estralejar",
    "estralejariam": "estralejar",
    "estralejarias": "estralejar",
    "estralejarmo": "estralejar",
    "estralejarmos": "estralejar",
    "estralejará": "estralejar",
    "estralejarás": "estralejar",
    "estralejarão": "estralejar",
    "estralejaríamos": "estralejar",
    "estralejaríeis": "estralejar",
    "estralejas": "estralejar",
    "estralejasse": "estralejar",
    "estralejassem": "estralejar",
    "estralejasses": "estralejar",
    "estralejaste": "estralejar",
    "estralejastes": "estralejar",
    "estralejava": "estralejar",
    "estralejavam": "estralejar",
    "estralejavas": "estralejar",
    "estraleje": "estralejar",
    "estralejei": "estralejar",
    "estralejeis": "estralejar",
    "estralejem": "estralejar",
    "estralejemo": "estralejar",
    "estralejemos": "estralejar",
    "estralejes": "estralejar",
    "estralejo": "estralejar",
    "estralejou": "estralejar",
    "estralejámo": "estralejar",
    "estralejámos": "estralejar",
    "estralejáramo": "estralejar",
    "estralejáramos": "estralejar",
    "estralejáreis": "estralejar",
    "estralejásseis": "estralejar",
    "estralejássemos": "estralejar",
    "estralejávamo": "estralejar",
    "estralejávamos": "estralejar",
    "estralejáveis": "estralejar",
    "estralem": "estralar",
    "estralemo": "estralar",
    "estralemos": "estralar",
    "estrales": "estralar",
    "estralheiras": "estralheira",
    "estralhos": "estralho",
    "estralo": "estralar",
    "estralou": "estralar",
    "estralámo": "estralar",
    "estralámos": "estralar",
    "estraláramo": "estralar",
    "estraláramos": "estralar",
    "estraláreis": "estralar",
    "estralásseis": "estralar",
    "estralássemos": "estralar",
    "estralávamo": "estralar",
    "estralávamos": "estralar",
    "estraláveis": "estralar",
    "estram": "estrar",
    "estrambalha": "estrambalhar",
    "estrambalhada": "estrambalhar",
    "estrambalhadas": "estrambalhar",
    "estrambalhado": "estrambalhar",
    "estrambalhados": "estrambalhar",
    "estrambalhai": "estrambalhar",
    "estrambalhais": "estrambalhar",
    "estrambalham": "estrambalhar",
    "estrambalhamo": "estrambalhar",
    "estrambalhamos": "estrambalhar",
    "estrambalhando": "estrambalhar",
    "estrambalhara": "estrambalhar",
    "estrambalharam": "estrambalhar",
    "estrambalharas": "estrambalhar",
    "estrambalharde": "estrambalhar",
    "estrambalhardes": "estrambalhar",
    "estrambalhare": "estrambalhar",
    "estrambalharei": "estrambalhar",
    "estrambalhareis": "estrambalhar",
    "estrambalharem": "estrambalhar",
    "estrambalharemos": "estrambalhar",
    "estrambalhares": "estrambalhar",
    "estrambalharia": "estrambalhar",
    "estrambalhariam": "estrambalhar",
    "estrambalharias": "estrambalhar",
    "estrambalharmo": "estrambalhar",
    "estrambalharmos": "estrambalhar",
    "estrambalhará": "estrambalhar",
    "estrambalharás": "estrambalhar",
    "estrambalharão": "estrambalhar",
    "estrambalharíamos": "estrambalhar",
    "estrambalharíeis": "estrambalhar",
    "estrambalhas": "estrambalhar",
    "estrambalhasse": "estrambalhar",
    "estrambalhassem": "estrambalhar",
    "estrambalhasses": "estrambalhar",
    "estrambalhaste": "estrambalhar",
    "estrambalhastes": "estrambalhar",
    "estrambalhava": "estrambalhar",
    "estrambalhavam": "estrambalhar",
    "estrambalhavas": "estrambalhar",
    "estrambalhe": "estrambalhar",
    "estrambalhei": "estrambalhar",
    "estrambalheis": "estrambalhar",
    "estrambalhem": "estrambalhar",
    "estrambalhemo": "estrambalhar",
    "estrambalhemos": "estrambalhar",
    "estrambalhes": "estrambalhar",
    "estrambalho": "estrambalhar",
    "estrambalhou": "estrambalhar",
    "estrambalhá": "estrambalhar",
    "estrambalhámo": "estrambalhar",
    "estrambalhámos": "estrambalhar",
    "estrambalháramo": "estrambalhar",
    "estrambalháramos": "estrambalhar",
    "estrambalhárei": "estrambalhar",
    "estrambalháreis": "estrambalhar",
    "estrambalhásseis": "estrambalhar",
    "estrambalhássemos": "estrambalhar",
    "estrambalhávamo": "estrambalhar",
    "estrambalhávamos": "estrambalhar",
    "estrambalhávei": "estrambalhar",
    "estrambalháveis": "estrambalhar",
    "estrambeiros": "estrambeiro",
    "estrambelha": "estrambelhar",
    "estrambelhada": "estrambelhar",
    "estrambelhadas": "estrambelhar",
    "estrambelhado": "estrambelhar",
    "estrambelhados": "estrambelhar",
    "estrambelhai": "estrambelhar",
    "estrambelhais": "estrambelhar",
    "estrambelham": "estrambelhar",
    "estrambelhamo": "estrambelhar",
    "estrambelhamos": "estrambelhar",
    "estrambelhando": "estrambelhar",
    "estrambelhara": "estrambelhar",
    "estrambelharam": "estrambelhar",
    "estrambelharas": "estrambelhar",
    "estrambelharde": "estrambelhar",
    "estrambelhardes": "estrambelhar",
    "estrambelhare": "estrambelhar",
    "estrambelharei": "estrambelhar",
    "estrambelhareis": "estrambelhar",
    "estrambelharem": "estrambelhar",
    "estrambelharemos": "estrambelhar",
    "estrambelhares": "estrambelhar",
    "estrambelharia": "estrambelhar",
    "estrambelhariam": "estrambelhar",
    "estrambelharias": "estrambelhar",
    "estrambelharmo": "estrambelhar",
    "estrambelharmos": "estrambelhar",
    "estrambelhará": "estrambelhar",
    "estrambelharás": "estrambelhar",
    "estrambelharão": "estrambelhar",
    "estrambelharíamos": "estrambelhar",
    "estrambelharíeis": "estrambelhar",
    "estrambelhas": "estrambelhar",
    "estrambelhasse": "estrambelhar",
    "estrambelhassem": "estrambelhar",
    "estrambelhasses": "estrambelhar",
    "estrambelhaste": "estrambelhar",
    "estrambelhastes": "estrambelhar",
    "estrambelhava": "estrambelhar",
    "estrambelhavam": "estrambelhar",
    "estrambelhavas": "estrambelhar",
    "estrambelhe": "estrambelhar",
    "estrambelhei": "estrambelhar",
    "estrambelheis": "estrambelhar",
    "estrambelhem": "estrambelhar",
    "estrambelhemo": "estrambelhar",
    "estrambelhemos": "estrambelhar",
    "estrambelhes": "estrambelhar",
    "estrambelho": "estrambelhar",
    "estrambelhou": "estrambelhar",
    "estrambelhá": "estrambelhar",
    "estrambelhámo": "estrambelhar",
    "estrambelhámos": "estrambelhar",
    "estrambelháramo": "estrambelhar",
    "estrambelháramos": "estrambelhar",
    "estrambelhárei": "estrambelhar",
    "estrambelháreis": "estrambelhar",
    "estrambelhásseis": "estrambelhar",
    "estrambelhássemos": "estrambelhar",
    "estrambelhávamo": "estrambelhar",
    "estrambelhávamos": "estrambelhar",
    "estrambelhávei": "estrambelhar",
    "estrambelháveis": "estrambelhar",
    "estrambotes": "estrambote",
    "estrambólica": "estrambólico",
    "estrambólicas": "estrambólico",
    "estrambólicos": "estrambólico",
    "estrambótica": "estrambótico",
    "estrambóticas": "estrambótico",
    "estrambóticos": "estrambótico",
    "estramentos": "estramento",
    "estramo": "estrar",
    "estramoninas": "estramonina",
    "estramontana": "estramontano",
    "estramontanas": "estramontano",
    "estramontanos": "estramontano",
    "estramos": "estrar",
    "estrampalha": "estrampalhar",
    "estrampalhada": "estrampalhar",
    "estrampalhadas": "estrampalhar",
    "estrampalhado": "estrampalhar",
    "estrampalhados": "estrampalhar",
    "estrampalhai": "estrampalhar",
    "estrampalhais": "estrampalhar",
    "estrampalham": "estrampalhar",
    "estrampalhamo": "estrampalhar",
    "estrampalhamos": "estrampalhar",
    "estrampalhando": "estrampalhar",
    "estrampalhara": "estrampalhar",
    "estrampalharam": "estrampalhar",
    "estrampalharas": "estrampalhar",
    "estrampalharde": "estrampalhar",
    "estrampalhardes": "estrampalhar",
    "estrampalhare": "estrampalhar",
    "estrampalharei": "estrampalhar",
    "estrampalhareis": "estrampalhar",
    "estrampalharem": "estrampalhar",
    "estrampalharemos": "estrampalhar",
    "estrampalhares": "estrampalhar",
    "estrampalharia": "estrampalhar",
    "estrampalhariam": "estrampalhar",
    "estrampalharias": "estrampalhar",
    "estrampalharmo": "estrampalhar",
    "estrampalharmos": "estrampalhar",
    "estrampalhará": "estrampalhar",
    "estrampalharás": "estrampalhar",
    "estrampalharão": "estrampalhar",
    "estrampalharíamos": "estrampalhar",
    "estrampalharíeis": "estrampalhar",
    "estrampalhas": "estrampalhar",
    "estrampalhasse": "estrampalhar",
    "estrampalhassem": "estrampalhar",
    "estrampalhasses": "estrampalhar",
    "estrampalhaste": "estrampalhar",
    "estrampalhastes": "estrampalhar",
    "estrampalhava": "estrampalhar",
    "estrampalhavam": "estrampalhar",
    "estrampalhavas": "estrampalhar",
    "estrampalhe": "estrampalhar",
    "estrampalhei": "estrampalhar",
    "estrampalheis": "estrampalhar",
    "estrampalhem": "estrampalhar",
    "estrampalhemo": "estrampalhar",
    "estrampalhemos": "estrampalhar",
    "estrampalhes": "estrampalhar",
    "estrampalho": "estrampalhar",
    "estrampalhou": "estrampalhar",
    "estrampalhá": "estrampalhar",
    "estrampalhámo": "estrampalhar",
    "estrampalhámos": "estrampalhar",
    "estrampalháramo": "estrampalhar",
    "estrampalháramos": "estrampalhar",
    "estrampalhárei": "estrampalhar",
    "estrampalháreis": "estrampalhar",
    "estrampalhásseis": "estrampalhar",
    "estrampalhássemos": "estrampalhar",
    "estrampalhávamo": "estrampalhar",
    "estrampalhávamos": "estrampalhar",
    "estrampalhávei": "estrampalhar",
    "estrampalháveis": "estrampalhar",
    "estramónios": "estramónio",
    "estrance": "estrançar",
    "estrancei": "estrançar",
    "estranceis": "estrançar",
    "estrancem": "estrançar",
    "estrancemo": "estrançar",
    "estrancemos": "estrançar",
    "estrances": "estrançar",
    "estrancilha": "estrancilhar",
    "estrancilhada": "estrancilhar",
    "estrancilhadas": "estrancilhar",
    "estrancilhado": "estrancilhar",
    "estrancilhados": "estrancilhar",
    "estrancilhai": "estrancilhar",
    "estrancilhais": "estrancilhar",
    "estrancilham": "estrancilhar",
    "estrancilhamo": "estrancilhar",
    "estrancilhamos": "estrancilhar",
    "estrancilhando": "estrancilhar",
    "estrancilhara": "estrancilhar",
    "estrancilharam": "estrancilhar",
    "estrancilharas": "estrancilhar",
    "estrancilharde": "estrancilhar",
    "estrancilhardes": "estrancilhar",
    "estrancilhare": "estrancilhar",
    "estrancilharei": "estrancilhar",
    "estrancilhareis": "estrancilhar",
    "estrancilharem": "estrancilhar",
    "estrancilharemos": "estrancilhar",
    "estrancilhares": "estrancilhar",
    "estrancilharia": "estrancilhar",
    "estrancilhariam": "estrancilhar",
    "estrancilharias": "estrancilhar",
    "estrancilharmo": "estrancilhar",
    "estrancilharmos": "estrancilhar",
    "estrancilhará": "estrancilhar",
    "estrancilharás": "estrancilhar",
    "estrancilharão": "estrancilhar",
    "estrancilharíamos": "estrancilhar",
    "estrancilharíeis": "estrancilhar",
    "estrancilhas": "estrancilhar",
    "estrancilhasse": "estrancilhar",
    "estrancilhassem": "estrancilhar",
    "estrancilhasses": "estrancilhar",
    "estrancilhaste": "estrancilhar",
    "estrancilhastes": "estrancilhar",
    "estrancilhava": "estrancilhar",
    "estrancilhavam": "estrancilhar",
    "estrancilhavas": "estrancilhar",
    "estrancilhe": "estrancilhar",
    "estrancilhei": "estrancilhar",
    "estrancilheis": "estrancilhar",
    "estrancilhem": "estrancilhar",
    "estrancilhemo": "estrancilhar",
    "estrancilhemos": "estrancilhar",
    "estrancilhes": "estrancilhar",
    "estrancilho": "estrancilhar",
    "estrancilhou": "estrancilhar",
    "estrancilhá": "estrancilhar",
    "estrancilhámo": "estrancilhar",
    "estrancilhámos": "estrancilhar",
    "estrancilháramo": "estrancilhar",
    "estrancilháramos": "estrancilhar",
    "estrancilhárei": "estrancilhar",
    "estrancilháreis": "estrancilhar",
    "estrancilhásseis": "estrancilhar",
    "estrancilhássemos": "estrancilhar",
    "estrancilhávamo": "estrancilhar",
    "estrancilhávamos": "estrancilhar",
    "estrancilhávei": "estrancilhar",
    "estrancilháveis": "estrancilhar",
    "estrancinha": "estrancinhar",
    "estrancinhada": "estrancinhar",
    "estrancinhadas": "estrancinhar",
    "estrancinhado": "estrancinhar",
    "estrancinhados": "estrancinhar",
    "estrancinhai": "estrancinhar",
    "estrancinhais": "estrancinhar",
    "estrancinham": "estrancinhar",
    "estrancinhamo": "estrancinhar",
    "estrancinhamos": "estrancinhar",
    "estrancinhando": "estrancinhar",
    "estrancinhara": "estrancinhar",
    "estrancinharam": "estrancinhar",
    "estrancinharas": "estrancinhar",
    "estrancinharde": "estrancinhar",
    "estrancinhardes": "estrancinhar",
    "estrancinhare": "estrancinhar",
    "estrancinharei": "estrancinhar",
    "estrancinhareis": "estrancinhar",
    "estrancinharem": "estrancinhar",
    "estrancinharemos": "estrancinhar",
    "estrancinhares": "estrancinhar",
    "estrancinharia": "estrancinhar",
    "estrancinhariam": "estrancinhar",
    "estrancinharias": "estrancinhar",
    "estrancinharmo": "estrancinhar",
    "estrancinharmos": "estrancinhar",
    "estrancinhará": "estrancinhar",
    "estrancinharás": "estrancinhar",
    "estrancinharão": "estrancinhar",
    "estrancinharíamos": "estrancinhar",
    "estrancinharíeis": "estrancinhar",
    "estrancinhas": "estrancinhar",
    "estrancinhasse": "estrancinhar",
    "estrancinhassem": "estrancinhar",
    "estrancinhasses": "estrancinhar",
    "estrancinhaste": "estrancinhar",
    "estrancinhastes": "estrancinhar",
    "estrancinhava": "estrancinhar",
    "estrancinhavam": "estrancinhar",
    "estrancinhavas": "estrancinhar",
    "estrancinhe": "estrancinhar",
    "estrancinhei": "estrancinhar",
    "estrancinheis": "estrancinhar",
    "estrancinhem": "estrancinhar",
    "estrancinhemo": "estrancinhar",
    "estrancinhemos": "estrancinhar",
    "estrancinhes": "estrancinhar",
    "estrancinho": "estrancinhar",
    "estrancinhou": "estrancinhar",
    "estrancinhá": "estrancinhar",
    "estrancinhámo": "estrancinhar",
    "estrancinhámos": "estrancinhar",
    "estrancinháramo": "estrancinhar",
    "estrancinháramos": "estrancinhar",
    "estrancinhárei": "estrancinhar",
    "estrancinháreis": "estrancinhar",
    "estrancinhásseis": "estrancinhar",
    "estrancinhássemos": "estrancinhar",
    "estrancinhávamo": "estrancinhar",
    "estrancinhávamos": "estrancinhar",
    "estrancinhávei": "estrancinhar",
    "estrancinháveis": "estrancinhar",
    "estrando": "estrar",
    "estraneidades": "estraneidade",
    "estrangalha": "estrangalhar",
    "estrangalhada": "estrangalhar",
    "estrangalhadas": "estrangalhar",
    "estrangalhado": "estrangalhar",
    "estrangalhados": "estrangalhar",
    "estrangalhai": "estrangalhar",
    "estrangalhais": "estrangalhar",
    "estrangalham": "estrangalhar",
    "estrangalhamo": "estrangalhar",
    "estrangalhamos": "estrangalhar",
    "estrangalhando": "estrangalhar",
    "estrangalhara": "estrangalhar",
    "estrangalharam": "estrangalhar",
    "estrangalharas": "estrangalhar",
    "estrangalharde": "estrangalhar",
    "estrangalhardes": "estrangalhar",
    "estrangalhare": "estrangalhar",
    "estrangalharei": "estrangalhar",
    "estrangalhareis": "estrangalhar",
    "estrangalharem": "estrangalhar",
    "estrangalharemos": "estrangalhar",
    "estrangalhares": "estrangalhar",
    "estrangalharia": "estrangalhar",
    "estrangalhariam": "estrangalhar",
    "estrangalharias": "estrangalhar",
    "estrangalharmo": "estrangalhar",
    "estrangalharmos": "estrangalhar",
    "estrangalhará": "estrangalhar",
    "estrangalharás": "estrangalhar",
    "estrangalharão": "estrangalhar",
    "estrangalharíamos": "estrangalhar",
    "estrangalharíeis": "estrangalhar",
    "estrangalhas": "estrangalhar",
    "estrangalhasse": "estrangalhar",
    "estrangalhassem": "estrangalhar",
    "estrangalhasses": "estrangalhar",
    "estrangalhaste": "estrangalhar",
    "estrangalhastes": "estrangalhar",
    "estrangalhava": "estrangalhar",
    "estrangalhavam": "estrangalhar",
    "estrangalhavas": "estrangalhar",
    "estrangalhe": "estrangalhar",
    "estrangalhei": "estrangalhar",
    "estrangalheis": "estrangalhar",
    "estrangalhem": "estrangalhar",
    "estrangalhemo": "estrangalhar",
    "estrangalhemos": "estrangalhar",
    "estrangalhes": "estrangalhar",
    "estrangalho": "estrangalhar",
    "estrangalhou": "estrangalhar",
    "estrangalhá": "estrangalhar",
    "estrangalhámo": "estrangalhar",
    "estrangalhámos": "estrangalhar",
    "estrangalháramo": "estrangalhar",
    "estrangalháramos": "estrangalhar",
    "estrangalhárei": "estrangalhar",
    "estrangalháreis": "estrangalhar",
    "estrangalhásseis": "estrangalhar",
    "estrangalhássemos": "estrangalhar",
    "estrangalhávamo": "estrangalhar",
    "estrangalhávamos": "estrangalhar",
    "estrangalhávei": "estrangalhar",
    "estrangalháveis": "estrangalhar",
    "estrangeira": "estrangeiro",
    "estrangeirada": "estrangeirar",
    "estrangeiradas": "estrangeirar",
    "estrangeirado": "estrangeirar",
    "estrangeirados": "estrangeirar",
    "estrangeirai": "estrangeirar",
    "estrangeirais": "estrangeirar",
    "estrangeiram": "estrangeirar",
    "estrangeiramo": "estrangeirar",
    "estrangeiramos": "estrangeirar",
    "estrangeirando": "estrangeirar",
    "estrangeirara": "estrangeirar",
    "estrangeiraram": "estrangeirar",
    "estrangeiraras": "estrangeirar",
    "estrangeirarde": "estrangeirar",
    "estrangeirardes": "estrangeirar",
    "estrangeirare": "estrangeirar",
    "estrangeirarei": "estrangeirar",
    "estrangeirareis": "estrangeirar",
    "estrangeirarem": "estrangeirar",
    "estrangeiraremos": "estrangeirar",
    "estrangeirares": "estrangeirar",
    "estrangeiraria": "estrangeirar",
    "estrangeirariam": "estrangeirar",
    "estrangeirarias": "estrangeirar",
    "estrangeirarmo": "estrangeirar",
    "estrangeirarmos": "estrangeirar",
    "estrangeirará": "estrangeirar",
    "estrangeirarás": "estrangeirar",
    "estrangeirarão": "estrangeirar",
    "estrangeiraríamos": "estrangeirar",
    "estrangeiraríeis": "estrangeirar",
    "estrangeiras": "estrangeiro",
    "estrangeirasse": "estrangeirar",
    "estrangeirassem": "estrangeirar",
    "estrangeirasses": "estrangeirar",
    "estrangeiraste": "estrangeirar",
    "estrangeirastes": "estrangeirar",
    "estrangeirava": "estrangeirar",
    "estrangeiravam": "estrangeirar",
    "estrangeiravas": "estrangeirar",
    "estrangeire": "estrangeirar",
    "estrangeirei": "estrangeirar",
    "estrangeireis": "estrangeirar",
    "estrangeirem": "estrangeirar",
    "estrangeiremo": "estrangeirar",
    "estrangeiremos": "estrangeirar",
    "estrangeires": "estrangeirar",
    "estrangeirices": "estrangeirice",
    "estrangeirinhas": "estrangeirinha",
    "estrangeirismos": "estrangeirismo",
    "estrangeiristas": "estrangeirista",
    "estrangeiro": "estrangeirar",
    "estrangeiros": "estrangeiro",
    "estrangeirou": "estrangeirar",
    "estrangeirá": "estrangeirar",
    "estrangeirámo": "estrangeirar",
    "estrangeirámos": "estrangeirar",
    "estrangeiráramo": "estrangeirar",
    "estrangeiráramos": "estrangeirar",
    "estrangeirárei": "estrangeirar",
    "estrangeiráreis": "estrangeirar",
    "estrangeirásseis": "estrangeirar",
    "estrangeirássemos": "estrangeirar",
    "estrangeirávamo": "estrangeirar",
    "estrangeirávamos": "estrangeirar",
    "estrangeirávei": "estrangeirar",
    "estrangeiráveis": "estrangeirar",
    "estrangula": "estrangular",
    "estrangulada": "estrangular",
    "estranguladas": "estrangular",
    "estrangulado": "estrangular",
    "estranguladora": "estrangulador",
    "estranguladoras": "estrangulador",
    "estranguladores": "estrangulador",
    "estrangulados": "estrangular",
    "estrangulai": "estrangular",
    "estrangulais": "estrangular",
    "estrangulam": "estrangular",
    "estrangulamentos": "estrangulamento",
    "estrangulamo": "estrangular",
    "estrangulamos": "estrangular",
    "estrangulando": "estrangular",
    "estrangulara": "estrangular",
    "estrangularam": "estrangular",
    "estrangularas": "estrangular",
    "estrangularde": "estrangular",
    "estrangulardes": "estrangular",
    "estrangulare": "estrangular",
    "estrangularei": "estrangular",
    "estrangulareis": "estrangular",
    "estrangularem": "estrangular",
    "estrangularemos": "estrangular",
    "estrangulares": "estrangular",
    "estrangularia": "estrangular",
    "estrangulariam": "estrangular",
    "estrangularias": "estrangular",
    "estrangularmo": "estrangular",
    "estrangularmos": "estrangular",
    "estrangulará": "estrangular",
    "estrangularás": "estrangular",
    "estrangularão": "estrangular",
    "estrangularíamos": "estrangular",
    "estrangularíeis": "estrangular",
    "estrangulas": "estrangular",
    "estrangulasse": "estrangular",
    "estrangulassem": "estrangular",
    "estrangulasses": "estrangular",
    "estrangulaste": "estrangular",
    "estrangulastes": "estrangular",
    "estrangulava": "estrangular",
    "estrangulavam": "estrangular",
    "estrangulavas": "estrangular",
    "estrangulações": "estrangulação",
    "estrangule": "estrangular",
    "estrangulei": "estrangular",
    "estranguleis": "estrangular",
    "estrangulem": "estrangular",
    "estrangulemo": "estrangular",
    "estrangulemos": "estrangular",
    "estrangules": "estrangular",
    "estrangulo": "estrangular",
    "estrangulou": "estrangular",
    "estrangulá": "estrangular",
    "estrangulámo": "estrangular",
    "estrangulámos": "estrangular",
    "estranguláramo": "estrangular",
    "estranguláramos": "estrangular",
    "estrangulárei": "estrangular",
    "estranguláreis": "estrangular",
    "estrangulásseis": "estrangular",
    "estrangulássemos": "estrangular",
    "estrangulávamo": "estrangular",
    "estrangulávamos": "estrangular",
    "estrangulávei": "estrangular",
    "estranguláveis": "estrangular",
    "estrangúrias": "estrangúria",
    "estranha": "estranho",
    "estranhada": "estranhar",
    "estranhadas": "estranhar",
    "estranhado": "estranhar",
    "estranhados": "estranhar",
    "estranhai": "estranhar",
    "estranhais": "estranhar",
    "estranham": "estranhar",
    "estranhamentos": "estranhamento",
    "estranhamo": "estranhar",
    "estranhamos": "estranhar",
    "estranhando": "estranhar",
    "estranhara": "estranhar",
    "estranharam": "estranhar",
    "estranharas": "estranhar",
    "estranharde": "estranhar",
    "estranhardes": "estranhar",
    "estranhare": "estranhar",
    "estranharei": "estranhar",
    "estranhareis": "estranhar",
    "estranharem": "estranhar",
    "estranharemos": "estranhar",
    "estranhares": "estranhar",
    "estranharia": "estranhar",
    "estranhariam": "estranhar",
    "estranharias": "estranhar",
    "estranharmo": "estranhar",
    "estranharmos": "estranhar",
    "estranhará": "estranhar",
    "estranharás": "estranhar",
    "estranharão": "estranhar",
    "estranharíamos": "estranhar",
    "estranharíeis": "estranhar",
    "estranhas": "estranho",
    "estranhasse": "estranhar",
    "estranhassem": "estranhar",
    "estranhasses": "estranhar",
    "estranhaste": "estranhar",
    "estranhastes": "estranhar",
    "estranhava": "estranhar",
    "estranhavam": "estranhar",
    "estranhavas": "estranhar",
    "estranhe": "estranhar",
    "estranhei": "estranhar",
    "estranheis": "estranhar",
    "estranhem": "estranhar",
    "estranhemo": "estranhar",
    "estranhemos": "estranhar",
    "estranhes": "estranhar",
    "estranhezas": "estranheza",
    "estranho": "estranhar",
    "estranhona": "estranhão",
    "estranhonas": "estranhão",
    "estranhos": "estranho",
    "estranhou": "estranhar",
    "estranhá": "estranhar",
    "estranhámo": "estranhar",
    "estranhámos": "estranhar",
    "estranháramo": "estranhar",
    "estranháramos": "estranhar",
    "estranhárei": "estranhar",
    "estranháreis": "estranhar",
    "estranhásseis": "estranhar",
    "estranhássemos": "estranhar",
    "estranhávamo": "estranhar",
    "estranhávamos": "estranhar",
    "estranhávei": "estranhar",
    "estranháveis": "estranhar",
    "estranhíssima": "estranho",
    "estranhíssimas": "estranho",
    "estranhíssimo": "estranho",
    "estranhíssimos": "estranho",
    "estranhões": "estranhão",
    "estranjas": "estranja",
    "estransa": "estransir",
    "estransais": "estransir",
    "estransam": "estransir",
    "estransamo": "estransir",
    "estransamos": "estransir",
    "estransas": "estransir",
    "estranse": "estransir",
    "estransem": "estransir",
    "estranses": "estransir",
    "estransi": "estransir",
    "estransia": "estransir",
    "estransiam": "estransir",
    "estransias": "estransir",
    "estransida": "estransir",
    "estransidas": "estransir",
    "estransido": "estransir",
    "estransidos": "estransir",
    "estransimo": "estransir",
    "estransimos": "estransir",
    "estransindo": "estransir",
    "estransira": "estransir",
    "estransiram": "estransir",
    "estransiras": "estransir",
    "estransirde": "estransir",
    "estransirdes": "estransir",
    "estransire": "estransir",
    "estransirei": "estransir",
    "estransireis": "estransir",
    "estransirem": "estransir",
    "estransiremos": "estransir",
    "estransires": "estransir",
    "estransiria": "estransir",
    "estransiriam": "estransir",
    "estransirias": "estransir",
    "estransirmo": "estransir",
    "estransirmos": "estransir",
    "estransirá": "estransir",
    "estransirás": "estransir",
    "estransirão": "estransir",
    "estransiríamos": "estransir",
    "estransiríeis": "estransir",
    "estransis": "estransir",
    "estransisse": "estransir",
    "estransissem": "estransir",
    "estransisses": "estransir",
    "estransiste": "estransir",
    "estransistes": "estransir",
    "estransiu": "estransir",
    "estranso": "estransir",
    "estransíamo": "estransir",
    "estransíamos": "estransir",
    "estransíei": "estransir",
    "estransíeis": "estransir",
    "estransíramo": "estransir",
    "estransíramos": "estransir",
    "estransírei": "estransir",
    "estransíreis": "estransir",
    "estransísseis": "estransir",
    "estransíssemos": "estransir",
    "estrança": "estrançar",
    "estrançada": "estrançar",
    "estrançadas": "estrançar",
    "estrançado": "estrançar",
    "estrançados": "estrançar",
    "estrançai": "estrançar",
    "estrançais": "estrançar",
    "estrançam": "estrançar",
    "estrançamo": "estrançar",
    "estrançamos": "estrançar",
    "estrançando": "estrançar",
    "estrançara": "estrançar",
    "estrançaram": "estrançar",
    "estrançaras": "estrançar",
    "estrançarde": "estrançar",
    "estrançardes": "estrançar",
    "estrançare": "estrançar",
    "estrançarei": "estrançar",
    "estrançareis": "estrançar",
    "estrançarem": "estrançar",
    "estrançaremos": "estrançar",
    "estrançares": "estrançar",
    "estrançaria": "estrançar",
    "estrançariam": "estrançar",
    "estrançarias": "estrançar",
    "estrançarmo": "estrançar",
    "estrançarmos": "estrançar",
    "estrançará": "estrançar",
    "estrançarás": "estrançar",
    "estrançarão": "estrançar",
    "estrançaríamos": "estrançar",
    "estrançaríeis": "estrançar",
    "estranças": "estrançar",
    "estrançasse": "estrançar",
    "estrançassem": "estrançar",
    "estrançasses": "estrançar",
    "estrançaste": "estrançar",
    "estrançastes": "estrançar",
    "estrançava": "estrançar",
    "estrançavam": "estrançar",
    "estrançavas": "estrançar",
    "estranço": "estrançar",
    "estrançou": "estrançar",
    "estrançá": "estrançar",
    "estrançámo": "estrançar",
    "estrançámos": "estrançar",
    "estrançáramo": "estrançar",
    "estrançáramos": "estrançar",
    "estrançárei": "estrançar",
    "estrançáreis": "estrançar",
    "estrançásseis": "estrançar",
    "estrançássemos": "estrançar",
    "estrançávamo": "estrançar",
    "estrançávamos": "estrançar",
    "estrançávei": "estrançar",
    "estrançáveis": "estrançar",
    "estrapadas": "estrapada",
    "estrara": "estrar",
    "estraram": "estrar",
    "estraras": "estrar",
    "estrarde": "estrar",
    "estrardes": "estrar",
    "estrare": "estrar",
    "estrarei": "estrar",
    "estrareis": "estrar",
    "estrarem": "estrar",
    "estraremos": "estrar",
    "estrares": "estrar",
    "estraria": "estrar",
    "estrariam": "estrar",
    "estrarias": "estrar",
    "estrarmo": "estrar",
    "estrarmos": "estrar",
    "estrará": "estrar",
    "estrarás": "estrar",
    "estrarão": "estrar",
    "estraríamos": "estrar",
    "estraríeis": "estrar",
    "estras": "estrar",
    "estrasburguesa": "estrasburguês",
    "estrasburguesas": "estrasburguês",
    "estrasburgueses": "estrasburguês",
    "estrasse": "estrar",
    "estrassem": "estrar",
    "estrasses": "estrar",
    "estraste": "estrar",
    "estrastes": "estrar",
    "estratagemas": "estratagema",
    "estratega": "estratego",
    "estrategas": "estratego",
    "estrategistas": "estrategista",
    "estrategos": "estratego",
    "estratifica": "estratificar",
    "estratificada": "estratificar",
    "estratificadas": "estratificar",
    "estratificado": "estratificar",
    "estratificados": "estratificar",
    "estratificai": "estratificar",
    "estratificais": "estratificar",
    "estratificam": "estratificar",
    "estratificamo": "estratificar",
    "estratificamos": "estratificar",
    "estratificando": "estratificar",
    "estratificara": "estratificar",
    "estratificaram": "estratificar",
    "estratificaras": "estratificar",
    "estratificarde": "estratificar",
    "estratificardes": "estratificar",
    "estratificare": "estratificar",
    "estratificarei": "estratificar",
    "estratificareis": "estratificar",
    "estratificarem": "estratificar",
    "estratificaremos": "estratificar",
    "estratificares": "estratificar",
    "estratificaria": "estratificar",
    "estratificariam": "estratificar",
    "estratificarias": "estratificar",
    "estratificarmo": "estratificar",
    "estratificarmos": "estratificar",
    "estratificará": "estratificar",
    "estratificarás": "estratificar",
    "estratificarão": "estratificar",
    "estratificaríamos": "estratificar",
    "estratificaríeis": "estratificar",
    "estratificas": "estratificar",
    "estratificasse": "estratificar",
    "estratificassem": "estratificar",
    "estratificasses": "estratificar",
    "estratificaste": "estratificar",
    "estratificastes": "estratificar",
    "estratificava": "estratificar",
    "estratificavam": "estratificar",
    "estratificavas": "estratificar",
    "estratificações": "estratificação",
    "estratifico": "estratificar",
    "estratificou": "estratificar",
    "estratificá": "estratificar",
    "estratificámo": "estratificar",
    "estratificámos": "estratificar",
    "estratificáramo": "estratificar",
    "estratificáramos": "estratificar",
    "estratificárei": "estratificar",
    "estratificáreis": "estratificar",
    "estratificásseis": "estratificar",
    "estratificássemos": "estratificar",
    "estratificávamo": "estratificar",
    "estratificávamos": "estratificar",
    "estratificávei": "estratificar",
    "estratificáveis": "estratificável",
    "estratifique": "estratificar",
    "estratifiquei": "estratificar",
    "estratifiqueis": "estratificar",
    "estratifiquem": "estratificar",
    "estratifiquemo": "estratificar",
    "estratifiquemos": "estratificar",
    "estratifiques": "estratificar",
    "estratiformes": "estratiforme",
    "estratigrafias": "estratigrafia",
    "estratigráfica": "estratigráfico",
    "estratigráficas": "estratigráfico",
    "estratigráficos": "estratigráfico",
    "estratocracias": "estratocracia",
    "estratografias": "estratografia",
    "estratopausas": "estratopausa",
    "estratos": "estrato",
    "estratosferas": "estratosfera",
    "estratégias": "estratégia",
    "estratégica": "estratégico",
    "estratégicas": "estratégico",
    "estratégicos": "estratégico",
    "estratígrafos": "estratígrafo",
    "estrava": "estravar",
    "estravada": "estravar",
    "estravadas": "estravar",
    "estravado": "estravar",
    "estravados": "estravar",
    "estravai": "estravar",
    "estravais": "estravar",
    "estravam": "estravar",
    "estravamo": "estravar",
    "estravamos": "estravar",
    "estravando": "estravar",
    "estravara": "estravar",
    "estravaram": "estravar",
    "estravaras": "estravar",
    "estravardes": "estravar",
    "estravarei": "estravar",
    "estravareis": "estravar",
    "estravarem": "estravar",
    "estravaremos": "estravar",
    "estravares": "estravar",
    "estravaria": "estravar",
    "estravariam": "estravar",
    "estravarias": "estravar",
    "estravarmo": "estravar",
    "estravarmos": "estravar",
    "estravará": "estravar",
    "estravarás": "estravar",
    "estravarão": "estravar",
    "estravaríamos": "estravar",
    "estravaríeis": "estravar",
    "estravas": "estravar",
    "estravasse": "estravar",
    "estravassem": "estravar",
    "estravasses": "estravar",
    "estravaste": "estravar",
    "estravastes": "estravar",
    "estravava": "estravar",
    "estravavam": "estravar",
    "estravavas": "estravar",
    "estrave": "estravar",
    "estravei": "estravar",
    "estraveis": "estravar",
    "estravem": "estravar",
    "estravemo": "estravar",
    "estravemos": "estravar",
    "estraves": "estravar",
    "estravo": "estravar",
    "estravos": "estravo",
    "estravou": "estravar",
    "estravámo": "estravar",
    "estravámos": "estravar",
    "estraváramo": "estravar",
    "estraváramos": "estravar",
    "estraváreis": "estravar",
    "estravásseis": "estravar",
    "estravássemos": "estravar",
    "estravávamo": "estravar",
    "estravávamos": "estravar",
    "estraváveis": "estravar",
    "estraçalha": "estraçalhar",
    "estraçalhada": "estraçalhar",
    "estraçalhadas": "estraçalhar",
    "estraçalhado": "estraçalhar",
    "estraçalhados": "estraçalhar",
    "estraçalhai": "estraçalhar",
    "estraçalhais": "estraçalhar",
    "estraçalham": "estraçalhar",
    "estraçalhamentos": "estraçalhamento",
    "estraçalhamo": "estraçalhar",
    "estraçalhamos": "estraçalhar",
    "estraçalhando": "estraçalhar",
    "estraçalhar": "alhar",
    "estraçalhara": "estraçalhar",
    "estraçalharam": "estraçalhar",
    "estraçalharas": "estraçalhar",
    "estraçalharde": "estraçalhar",
    "estraçalhardes": "estraçalhar",
    "estraçalhare": "estraçalhar",
    "estraçalharei": "estraçalhar",
    "estraçalhareis": "estraçalhar",
    "estraçalharem": "estraçalhar",
    "estraçalharemos": "estraçalhar",
    "estraçalhares": "estraçalhar",
    "estraçalharia": "estraçalhar",
    "estraçalhariam": "estraçalhar",
    "estraçalharias": "estraçalhar",
    "estraçalharmo": "estraçalhar",
    "estraçalharmos": "estraçalhar",
    "estraçalhará": "estraçalhar",
    "estraçalharás": "estraçalhar",
    "estraçalharão": "estraçalhar",
    "estraçalharíamos": "estraçalhar",
    "estraçalharíeis": "estraçalhar",
    "estraçalhas": "estraçalhar",
    "estraçalhasse": "estraçalhar",
    "estraçalhassem": "estraçalhar",
    "estraçalhasses": "estraçalhar",
    "estraçalhaste": "estraçalhar",
    "estraçalhastes": "estraçalhar",
    "estraçalhava": "estraçalhar",
    "estraçalhavam": "estraçalhar",
    "estraçalhavas": "estraçalhar",
    "estraçalhe": "estraçalhar",
    "estraçalhei": "estraçalhar",
    "estraçalheis": "estraçalhar",
    "estraçalhem": "estraçalhar",
    "estraçalhemo": "estraçalhar",
    "estraçalhemos": "estraçalhar",
    "estraçalhes": "estraçalhar",
    "estraçalho": "estraçalhar",
    "estraçalhou": "estraçalhar",
    "estraçalhá": "estraçalhar",
    "estraçalhámo": "estraçalhar",
    "estraçalhámos": "estraçalhar",
    "estraçalháramo": "estraçalhar",
    "estraçalháramos": "estraçalhar",
    "estraçalhárei": "estraçalhar",
    "estraçalháreis": "estraçalhar",
    "estraçalhásseis": "estraçalhar",
    "estraçalhássemos": "estraçalhar",
    "estraçalhávamo": "estraçalhar",
    "estraçalhávamos": "estraçalhar",
    "estraçalhávei": "estraçalhar",
    "estraçalháveis": "estraçalhar",
    "estraçoa": "estraçoar",
    "estraçoada": "estraçoar",
    "estraçoadas": "estraçoar",
    "estraçoado": "estraçoar",
    "estraçoados": "estraçoar",
    "estraçoai": "estraçoar",
    "estraçoais": "estraçoar",
    "estraçoam": "estraçoar",
    "estraçoamo": "estraçoar",
    "estraçoamos": "estraçoar",
    "estraçoando": "estraçoar",
    "estraçoara": "estraçoar",
    "estraçoaram": "estraçoar",
    "estraçoaras": "estraçoar",
    "estraçoarde": "estraçoar",
    "estraçoardes": "estraçoar",
    "estraçoare": "estraçoar",
    "estraçoarei": "estraçoar",
    "estraçoareis": "estraçoar",
    "estraçoarem": "estraçoar",
    "estraçoaremos": "estraçoar",
    "estraçoares": "estraçoar",
    "estraçoaria": "estraçoar",
    "estraçoariam": "estraçoar",
    "estraçoarias": "estraçoar",
    "estraçoarmo": "estraçoar",
    "estraçoarmos": "estraçoar",
    "estraçoará": "estraçoar",
    "estraçoarás": "estraçoar",
    "estraçoarão": "estraçoar",
    "estraçoaríamos": "estraçoar",
    "estraçoaríeis": "estraçoar",
    "estraçoas": "estraçoar",
    "estraçoasse": "estraçoar",
    "estraçoassem": "estraçoar",
    "estraçoasses": "estraçoar",
    "estraçoaste": "estraçoar",
    "estraçoastes": "estraçoar",
    "estraçoava": "estraçoar",
    "estraçoavam": "estraçoar",
    "estraçoavas": "estraçoar",
    "estraçoe": "estraçoar",
    "estraçoei": "estraçoar",
    "estraçoeis": "estraçoar",
    "estraçoem": "estraçoar",
    "estraçoemo": "estraçoar",
    "estraçoemos": "estraçoar",
    "estraçoes": "estraçoar",
    "estraçoo": "estraçoar",
    "estraçoou": "estraçoar",
    "estraçoá": "estraçoar",
    "estraçoámo": "estraçoar",
    "estraçoámos": "estraçoar",
    "estraçoáramo": "estraçoar",
    "estraçoáramos": "estraçoar",
    "estraçoárei": "estraçoar",
    "estraçoáreis": "estraçoar",
    "estraçoásseis": "estraçoar",
    "estraçoássemos": "estraçoar",
    "estraçoávamo": "estraçoar",
    "estraçoávamos": "estraçoar",
    "estraçoávei": "estraçoar",
    "estraçoáveis": "estraçoar",
    "estre": "estrar",
    "estreada": "estrear",
    "estreadas": "estrear",
    "estreado": "estrear",
    "estreados": "estrear",
    "estreai": "estrear",
    "estreais": "estrear",
    "estreamo": "estrear",
    "estreamos": "estrear",
    "estreando": "estrear",
    "estreantes": "estreante",
    "estreara": "estrear",
    "estrearam": "estrear",
    "estrearas": "estrear",
    "estrearde": "estrear",
    "estreardes": "estrear",
    "estreare": "estrear",
    "estrearei": "estrear",
    "estreareis": "estrear",
    "estrearem": "estrear",
    "estrearemos": "estrear",
    "estreares": "estrear",
    "estrearia": "estrear",
    "estreariam": "estrear",
    "estrearias": "estrear",
    "estrearmo": "estrear",
    "estrearmos": "estrear",
    "estreará": "estrear",
    "estrearás": "estrear",
    "estrearão": "estrear",
    "estrearíamos": "estrear",
    "estrearíeis": "estrear",
    "estreasse": "estrear",
    "estreassem": "estrear",
    "estreasses": "estrear",
    "estreaste": "estrear",
    "estreastes": "estrear",
    "estreava": "estrear",
    "estreavam": "estrear",
    "estreavas": "estrear",
    "estrebarias": "estrebaria",
    "estreborda": "estrebordar",
    "estrebordada": "estrebordar",
    "estrebordadas": "estrebordar",
    "estrebordado": "estrebordar",
    "estrebordados": "estrebordar",
    "estrebordai": "estrebordar",
    "estrebordais": "estrebordar",
    "estrebordam": "estrebordar",
    "estrebordamo": "estrebordar",
    "estrebordamos": "estrebordar",
    "estrebordando": "estrebordar",
    "estrebordara": "estrebordar",
    "estrebordaram": "estrebordar",
    "estrebordaras": "estrebordar",
    "estrebordardes": "estrebordar",
    "estrebordarei": "estrebordar",
    "estrebordareis": "estrebordar",
    "estrebordarem": "estrebordar",
    "estrebordaremos": "estrebordar",
    "estrebordares": "estrebordar",
    "estrebordaria": "estrebordar",
    "estrebordariam": "estrebordar",
    "estrebordarias": "estrebordar",
    "estrebordarmo": "estrebordar",
    "estrebordarmos": "estrebordar",
    "estrebordará": "estrebordar",
    "estrebordarás": "estrebordar",
    "estrebordarão": "estrebordar",
    "estrebordaríamos": "estrebordar",
    "estrebordaríeis": "estrebordar",
    "estrebordas": "estrebordar",
    "estrebordasse": "estrebordar",
    "estrebordassem": "estrebordar",
    "estrebordasses": "estrebordar",
    "estrebordaste": "estrebordar",
    "estrebordastes": "estrebordar",
    "estrebordava": "estrebordar",
    "estrebordavam": "estrebordar",
    "estrebordavas": "estrebordar",
    "estreborde": "estrebordar",
    "estrebordei": "estrebordar",
    "estrebordeis": "estrebordar",
    "estrebordem": "estrebordar",
    "estrebordemo": "estrebordar",
    "estrebordemos": "estrebordar",
    "estrebordes": "estrebordar",
    "estrebordo": "estrebordar",
    "estrebordou": "estrebordar",
    "estrebordámo": "estrebordar",
    "estrebordámos": "estrebordar",
    "estrebordáramo": "estrebordar",
    "estrebordáramos": "estrebordar",
    "estrebordáreis": "estrebordar",
    "estrebordásseis": "estrebordar",
    "estrebordássemos": "estrebordar",
    "estrebordávamo": "estrebordar",
    "estrebordávamos": "estrebordar",
    "estrebordáveis": "estrebordar",
    "estrebucha": "estrebuchar",
    "estrebuchada": "estrebuchar",
    "estrebuchadas": "estrebuchar",
    "estrebuchado": "estrebuchar",
    "estrebuchados": "estrebuchar",
    "estrebuchai": "estrebuchar",
    "estrebuchais": "estrebuchar",
    "estrebucham": "estrebuchar",
    "estrebuchamentos": "estrebuchamento",
    "estrebuchamo": "estrebuchar",
    "estrebuchamos": "estrebuchar",
    "estrebuchando": "estrebuchar",
    "estrebuchara": "estrebuchar",
    "estrebucharam": "estrebuchar",
    "estrebucharas": "estrebuchar",
    "estrebucharde": "estrebuchar",
    "estrebuchardes": "estrebuchar",
    "estrebuchare": "estrebuchar",
    "estrebucharei": "estrebuchar",
    "estrebuchareis": "estrebuchar",
    "estrebucharem": "estrebuchar",
    "estrebucharemos": "estrebuchar",
    "estrebuchares": "estrebuchar",
    "estrebucharia": "estrebuchar",
    "estrebuchariam": "estrebuchar",
    "estrebucharias": "estrebuchar",
    "estrebucharmo": "estrebuchar",
    "estrebucharmos": "estrebuchar",
    "estrebuchará": "estrebuchar",
    "estrebucharás": "estrebuchar",
    "estrebucharão": "estrebuchar",
    "estrebucharíamos": "estrebuchar",
    "estrebucharíeis": "estrebuchar",
    "estrebuchas": "estrebuchar",
    "estrebuchasse": "estrebuchar",
    "estrebuchassem": "estrebuchar",
    "estrebuchasses": "estrebuchar",
    "estrebuchaste": "estrebuchar",
    "estrebuchastes": "estrebuchar",
    "estrebuchava": "estrebuchar",
    "estrebuchavam": "estrebuchar",
    "estrebuchavas": "estrebuchar",
    "estrebuche": "estrebuchar",
    "estrebuchei": "estrebuchar",
    "estrebucheis": "estrebuchar",
    "estrebuchem": "estrebuchar",
    "estrebuchemo": "estrebuchar",
    "estrebuchemos": "estrebuchar",
    "estrebuches": "estrebuchar",
    "estrebucho": "estrebuchar",
    "estrebuchou": "estrebuchar",
    "estrebuchá": "estrebuchar",
    "estrebuchámo": "estrebuchar",
    "estrebuchámos": "estrebuchar",
    "estrebucháramo": "estrebuchar",
    "estrebucháramos": "estrebuchar",
    "estrebuchárei": "estrebuchar",
    "estrebucháreis": "estrebuchar",
    "estrebuchásseis": "estrebuchar",
    "estrebuchássemos": "estrebuchar",
    "estrebuchávamo": "estrebuchar",
    "estrebuchávamos": "estrebuchar",
    "estrebuchávei": "estrebuchar",
    "estrebucháveis": "estrebuchar",
    "estreei": "estrear",
    "estreeis": "estrear",
    "estreemo": "estrear",
    "estreemos": "estrear",
    "estrefega": "estrefegar",
    "estrefegada": "estrefegar",
    "estrefegadas": "estrefegar",
    "estrefegado": "estrefegar",
    "estrefegados": "estrefegar",
    "estrefegai": "estrefegar",
    "estrefegais": "estrefegar",
    "estrefegam": "estrefegar",
    "estrefegamo": "estrefegar",
    "estrefegamos": "estrefegar",
    "estrefegando": "estrefegar",
    "estrefegara": "estrefegar",
    "estrefegaram": "estrefegar",
    "estrefegaras": "estrefegar",
    "estrefegarde": "estrefegar",
    "estrefegardes": "estrefegar",
    "estrefegare": "estrefegar",
    "estrefegarei": "estrefegar",
    "estrefegareis": "estrefegar",
    "estrefegarem": "estrefegar",
    "estrefegaremos": "estrefegar",
    "estrefegares": "estrefegar",
    "estrefegaria": "estrefegar",
    "estrefegariam": "estrefegar",
    "estrefegarias": "estrefegar",
    "estrefegarmo": "estrefegar",
    "estrefegarmos": "estrefegar",
    "estrefegará": "estrefegar",
    "estrefegarás": "estrefegar",
    "estrefegarão": "estrefegar",
    "estrefegaríamos": "estrefegar",
    "estrefegaríeis": "estrefegar",
    "estrefegas": "estrefegar",
    "estrefegasse": "estrefegar",
    "estrefegassem": "estrefegar",
    "estrefegasses": "estrefegar",
    "estrefegaste": "estrefegar",
    "estrefegastes": "estrefegar",
    "estrefegava": "estrefegar",
    "estrefegavam": "estrefegar",
    "estrefegavas": "estrefegar",
    "estrefego": "estrefegar",
    "estrefegou": "estrefegar",
    "estrefegue": "estrefegar",
    "estrefeguei": "estrefegar",
    "estrefegueis": "estrefegar",
    "estrefeguem": "estrefegar",
    "estrefeguemo": "estrefegar",
    "estrefeguemos": "estrefegar",
    "estrefegues": "estrefegar",
    "estrefegá": "estrefegar",
    "estrefegámo": "estrefegar",
    "estrefegámos": "estrefegar",
    "estrefegáramo": "estrefegar",
    "estrefegáramos": "estrefegar",
    "estrefegárei": "estrefegar",
    "estrefegáreis": "estrefegar",
    "estrefegásseis": "estrefegar",
    "estrefegássemos": "estrefegar",
    "estrefegávamo": "estrefegar",
    "estrefegávamos": "estrefegar",
    "estrefegávei": "estrefegar",
    "estrefegáveis": "estrefegar",
    "estrei": "estrar",
    "estreia": "estrear",
    "estreiam": "estrear",
    "estreias": "estreia",
    "estreie": "estrear",
    "estreiem": "estrear",
    "estreies": "estrear",
    "estreio": "estrear",
    "estreis": "estrar",
    "estreita": "estreito",
    "estreitada": "estreitar",
    "estreitadas": "estreitar",
    "estreitado": "estreitar",
    "estreitadora": "estreitador",
    "estreitadoras": "estreitador",
    "estreitadores": "estreitador",
    "estreitados": "estreitar",
    "estreitai": "estreitar",
    "estreitais": "estreitar",
    "estreitam": "estreitar",
    "estreitamentos": "estreitamento",
    "estreitamo": "estreitar",
    "estreitamos": "estreitar",
    "estreitando": "estreitar",
    "estreitara": "estreitar",
    "estreitaram": "estreitar",
    "estreitaras": "estreitar",
    "estreitarde": "estreitar",
    "estreitardes": "estreitar",
    "estreitare": "estreitar",
    "estreitarei": "estreitar",
    "estreitareis": "estreitar",
    "estreitarem": "estreitar",
    "estreitaremos": "estreitar",
    "estreitares": "estreitar",
    "estreitaria": "estreitar",
    "estreitariam": "estreitar",
    "estreitarias": "estreitar",
    "estreitarmo": "estreitar",
    "estreitarmos": "estreitar",
    "estreitará": "estreitar",
    "estreitarás": "estreitar",
    "estreitarão": "estreitar",
    "estreitaríamos": "estreitar",
    "estreitaríeis": "estreitar",
    "estreitas": "estreito",
    "estreitasse": "estreitar",
    "estreitassem": "estreitar",
    "estreitasses": "estreitar",
    "estreitaste": "estreitar",
    "estreitastes": "estreitar",
    "estreitava": "estreitar",
    "estreitavam": "estreitar",
    "estreitavas": "estreitar",
    "estreite": "estreitar",
    "estreitei": "estreitar",
    "estreiteis": "estreitar",
    "estreitem": "estreitar",
    "estreitemo": "estreitar",
    "estreitemos": "estreitar",
    "estreites": "estreitar",
    "estreitezas": "estreiteza",
    "estreitinha": "estreito",
    "estreitinhas": "estreito",
    "estreitinho": "estreito",
    "estreitinhos": "estreito",
    "estreitita": "estreito",
    "estreititas": "estreito",
    "estreitito": "estreito",
    "estreititos": "estreito",
    "estreito": "estreitar",
    "estreitos": "estreito",
    "estreitou": "estreitar",
    "estreituras": "estreitura",
    "estreitá": "estreitar",
    "estreitámo": "estreitar",
    "estreitámos": "estreitar",
    "estreitáramo": "estreitar",
    "estreitáramos": "estreitar",
    "estreitárei": "estreitar",
    "estreitáreis": "estreitar",
    "estreitásseis": "estreitar",
    "estreitássemos": "estreitar",
    "estreitávamo": "estreitar",
    "estreitávamos": "estreitar",
    "estreitávei": "estreitar",
    "estreitáveis": "estreitável",
    "estreitíssima": "estreito",
    "estreitíssimas": "estreito",
    "estreitíssimo": "estreito",
    "estreitíssimos": "estreito",
    "estrela": "estrelo",
    "estrelada": "estrelar",
    "estreladas": "estrelar",
    "estreladeiras": "estreladeira",
    "estrelado": "estrelar",
    "estrelados": "estrelar",
    "estrelai": "estrelar",
    "estrelais": "estrelar",
    "estrelam": "estrelar",
    "estrelamins": "estrelamim",
    "estrelamo": "estrelar",
    "estrelamos": "estrelar",
    "estrelando": "estrelar",
    "estrelantes": "estrelante",
    "estrelara": "estrelar",
    "estrelaram": "estrelar",
    "estrelaras": "estrelar",
    "estrelarde": "estrelar",
    "estrelardes": "estrelar",
    "estrelare": "estrelar",
    "estrelarei": "estrelar",
    "estrelareis": "estrelar",
    "estrelarem": "estrelar",
    "estrelaremos": "estrelar",
    "estrelares": "estrelar",
    "estrelaria": "estrelar",
    "estrelariam": "estrelar",
    "estrelarias": "estrelar",
    "estrelarmo": "estrelar",
    "estrelarmos": "estrelar",
    "estrelará": "estrelar",
    "estrelarás": "estrelar",
    "estrelarão": "estrelar",
    "estrelaríamos": "estrelar",
    "estrelaríeis": "estrelar",
    "estrelas": "estrelo",
    "estrelasse": "estrelar",
    "estrelassem": "estrelar",
    "estrelasses": "estrelar",
    "estrelaste": "estrelar",
    "estrelastes": "estrelar",
    "estrelatos": "estrelato",
    "estrelava": "estrelar",
    "estrelavam": "estrelar",
    "estrelavas": "estrelar",
    "estrele": "estrelar",
    "estrelei": "estrelar",
    "estreleira": "estreleiro",
    "estreleiras": "estreleiro",
    "estreleiros": "estreleiro",
    "estreleis": "estrelar",
    "estreleja": "estrelejar",
    "estrelejada": "estrelejar",
    "estrelejadas": "estrelejar",
    "estrelejado": "estrelejar",
    "estrelejados": "estrelejar",
    "estrelejai": "estrelejar",
    "estrelejais": "estrelejar",
    "estrelejam": "estrelejar",
    "estrelejamo": "estrelejar",
    "estrelejamos": "estrelejar",
    "estrelejando": "estrelejar",
    "estrelejara": "estrelejar",
    "estrelejaram": "estrelejar",
    "estrelejaras": "estrelejar",
    "estrelejardes": "estrelejar",
    "estrelejarei": "estrelejar",
    "estrelejareis": "estrelejar",
    "estrelejarem": "estrelejar",
    "estrelejaremos": "estrelejar",
    "estrelejares": "estrelejar",
    "estrelejaria": "estrelejar",
    "estrelejariam": "estrelejar",
    "estrelejarias": "estrelejar",
    "estrelejarmo": "estrelejar",
    "estrelejarmos": "estrelejar",
    "estrelejará": "estrelejar",
    "estrelejarás": "estrelejar",
    "estrelejarão": "estrelejar",
    "estrelejaríamos": "estrelejar",
    "estrelejaríeis": "estrelejar",
    "estrelejas": "estrelejar",
    "estrelejasse": "estrelejar",
    "estrelejassem": "estrelejar",
    "estrelejasses": "estrelejar",
    "estrelejaste": "estrelejar",
    "estrelejastes": "estrelejar",
    "estrelejava": "estrelejar",
    "estrelejavam": "estrelejar",
    "estrelejavas": "estrelejar",
    "estreleje": "estrelejar",
    "estrelejei": "estrelejar",
    "estrelejeis": "estrelejar",
    "estrelejem": "estrelejar",
    "estrelejemo": "estrelejar",
    "estrelejemos": "estrelejar",
    "estrelejes": "estrelejar",
    "estrelejo": "estrelejar",
    "estrelejou": "estrelejar",
    "estrelejámo": "estrelejar",
    "estrelejámos": "estrelejar",
    "estrelejáramo": "estrelejar",
    "estrelejáramos": "estrelejar",
    "estrelejáreis": "estrelejar",
    "estrelejásseis": "estrelejar",
    "estrelejássemos": "estrelejar",
    "estrelejávamo": "estrelejar",
    "estrelejávamos": "estrelejar",
    "estrelejáveis": "estrelejar",
    "estrelem": "estrelar",
    "estrelemo": "estrelar",
    "estrelemos": "estrelar",
    "estreles": "estrelar",
    "estrelinha": "estrela",
    "estrelinhas": "estrelinha",
    "estrelita": "estrela",
    "estrelitas": "estrela",
    "estrelo": "estrelar",
    "estrelos": "estrelo",
    "estrelou": "estrelar",
    "estrelouce": "estrelouçar",
    "estreloucei": "estrelouçar",
    "estrelouceis": "estrelouçar",
    "estreloucem": "estrelouçar",
    "estreloucemo": "estrelouçar",
    "estreloucemos": "estrelouçar",
    "estrelouces": "estrelouçar",
    "estrelouça": "estrelouçar",
    "estrelouçada": "estrelouçar",
    "estrelouçadas": "estrelouçar",
    "estrelouçado": "estrelouçar",
    "estrelouçados": "estrelouçar",
    "estrelouçai": "estrelouçar",
    "estrelouçais": "estrelouçar",
    "estrelouçam": "estrelouçar",
    "estrelouçamo": "estrelouçar",
    "estrelouçamos": "estrelouçar",
    "estrelouçando": "estrelouçar",
    "estrelouçara": "estrelouçar",
    "estrelouçaram": "estrelouçar",
    "estrelouçaras": "estrelouçar",
    "estrelouçardes": "estrelouçar",
    "estrelouçarei": "estrelouçar",
    "estrelouçareis": "estrelouçar",
    "estrelouçarem": "estrelouçar",
    "estrelouçaremos": "estrelouçar",
    "estrelouçares": "estrelouçar",
    "estrelouçaria": "estrelouçar",
    "estrelouçariam": "estrelouçar",
    "estrelouçarias": "estrelouçar",
    "estrelouçarmo": "estrelouçar",
    "estrelouçarmos": "estrelouçar",
    "estrelouçará": "estrelouçar",
    "estrelouçarás": "estrelouçar",
    "estrelouçarão": "estrelouçar",
    "estrelouçaríamos": "estrelouçar",
    "estrelouçaríeis": "estrelouçar",
    "estrelouças": "estrelouçar",
    "estrelouçasse": "estrelouçar",
    "estrelouçassem": "estrelouçar",
    "estrelouçasses": "estrelouçar",
    "estrelouçaste": "estrelouçar",
    "estrelouçastes": "estrelouçar",
    "estrelouçava": "estrelouçar",
    "estrelouçavam": "estrelouçar",
    "estrelouçavas": "estrelouçar",
    "estrelouço": "estrelouçar",
    "estrelouçou": "estrelouçar",
    "estrelouçámo": "estrelouçar",
    "estrelouçámos": "estrelouçar",
    "estrelouçáramo": "estrelouçar",
    "estrelouçáramos": "estrelouçar",
    "estrelouçáreis": "estrelouçar",
    "estrelouçásseis": "estrelouçar",
    "estrelouçássemos": "estrelouçar",
    "estrelouçávamo": "estrelouçar",
    "estrelouçávamos": "estrelouçar",
    "estrelouçáveis": "estrelouçar",
    "estrelá": "estrelar",
    "estrelámo": "estrelar",
    "estrelámos": "estrelar",
    "estreláramo": "estrelar",
    "estreláramos": "estrelar",
    "estrelárei": "estrelar",
    "estreláreis": "estrelar",
    "estrelária": "estrelário",
    "estrelárias": "estrelário",
    "estrelários": "estrelário",
    "estrelásseis": "estrelar",
    "estrelássemos": "estrelar",
    "estrelávamo": "estrelar",
    "estrelávamos": "estrelar",
    "estrelávei": "estrelar",
    "estreláveis": "estrelar",
    "estrem": "estrar",
    "estrema": "estremar",
    "estremada": "estremar",
    "estremadas": "estremar",
    "estremadelas": "estremadela",
    "estremado": "estremar",
    "estremados": "estremar",
    "estremaduras": "estremadura",
    "estremai": "estremar",
    "estremais": "estremar",
    "estremam": "estremar",
    "estremamo": "estremar",
    "estremamos": "estremar",
    "estremando": "estremar",
    "estremara": "estremar",
    "estremaram": "estremar",
    "estremaras": "estremar",
    "estremarde": "estremar",
    "estremardes": "estremar",
    "estremare": "estremar",
    "estremarei": "estremar",
    "estremareis": "estremar",
    "estremarem": "estremar",
    "estremaremos": "estremar",
    "estremares": "estremar",
    "estremaria": "estremar",
    "estremariam": "estremar",
    "estremarias": "estremar",
    "estremarmo": "estremar",
    "estremarmos": "estremar",
    "estremará": "estremar",
    "estremarás": "estremar",
    "estremarão": "estremar",
    "estremaríamos": "estremar",
    "estremaríeis": "estremar",
    "estremas": "estremar",
    "estremasse": "estremar",
    "estremassem": "estremar",
    "estremasses": "estremar",
    "estremaste": "estremar",
    "estremastes": "estremar",
    "estremava": "estremar",
    "estremavam": "estremar",
    "estremavas": "estremar",
    "estreme": "estremar",
    "estremece": "estremecer",
    "estremecedora": "estremecedor",
    "estremecedoras": "estremecedor",
    "estremecedores": "estremecedor",
    "estremecei": "estremecer",
    "estremeceis": "estremecer",
    "estremecem": "estremecer",
    "estremecemo": "estremecer",
    "estremecemos": "estremecer",
    "estremecendo": "estremecer",
    "estremecera": "estremecer",
    "estremeceram": "estremecer",
    "estremeceras": "estremecer",
    "estremecerde": "estremecer",
    "estremecerdes": "estremecer",
    "estremecere": "estremecer",
    "estremecerei": "estremecer",
    "estremecereis": "estremecer",
    "estremecerem": "estremecer",
    "estremeceremos": "estremecer",
    "estremeceres": "estremecer",
    "estremeceria": "estremecer",
    "estremeceriam": "estremecer",
    "estremecerias": "estremecer",
    "estremecermo": "estremecer",
    "estremecermos": "estremecer",
    "estremecerá": "estremecer",
    "estremecerás": "estremecer",
    "estremecerão": "estremecer",
    "estremeceríamos": "estremecer",
    "estremeceríeis": "estremecer",
    "estremeces": "estremecer",
    "estremecesse": "estremecer",
    "estremecessem": "estremecer",
    "estremecesses": "estremecer",
    "estremeceste": "estremecer",
    "estremecestes": "estremecer",
    "estremeceu": "estremecer",
    "estremeci": "estremecer",
    "estremecia": "estremecer",
    "estremeciam": "estremecer",
    "estremecias": "estremecer",
    "estremecida": "estremecido",
    "estremecidas": "estremecido",
    "estremecido": "estremecer",
    "estremecidos": "estremecido",
    "estremecimentos": "estremecimento",
    "estremecê": "estremecer",
    "estremecêramo": "estremecer",
    "estremecêramos": "estremecer",
    "estremecêrei": "estremecer",
    "estremecêreis": "estremecer",
    "estremecêsseis": "estremecer",
    "estremecêssemos": "estremecer",
    "estremecíamo": "estremecer",
    "estremecíamos": "estremecer",
    "estremecíei": "estremecer",
    "estremecíeis": "estremecer",
    "estremei": "estremar",
    "estremeis": "estremar",
    "estremem": "estremar",
    "estrememo": "estremar",
    "estrememos": "estremar",
    "estremenha": "estremenho",
    "estremenhas": "estremenho",
    "estremenhos": "estremenho",
    "estremes": "estremar",
    "estremeça": "estremecer",
    "estremeçais": "estremecer",
    "estremeçam": "estremecer",
    "estremeçamo": "estremecer",
    "estremeçamos": "estremecer",
    "estremeças": "estremecer",
    "estremeço": "estremecer",
    "estremeções": "estremeção",
    "estremo": "estremar",
    "estremocenses": "estremocense",
    "estremos": "estrar",
    "estremou": "estremar",
    "estremunha": "estremunhar",
    "estremunhada": "estremunhar",
    "estremunhadas": "estremunhar",
    "estremunhado": "estremunhar",
    "estremunhados": "estremunhar",
    "estremunhai": "estremunhar",
    "estremunhais": "estremunhar",
    "estremunham": "estremunhar",
    "estremunhamo": "estremunhar",
    "estremunhamos": "estremunhar",
    "estremunhando": "estremunhar",
    "estremunhara": "estremunhar",
    "estremunharam": "estremunhar",
    "estremunharas": "estremunhar",
    "estremunharde": "estremunhar",
    "estremunhardes": "estremunhar",
    "estremunhare": "estremunhar",
    "estremunharei": "estremunhar",
    "estremunhareis": "estremunhar",
    "estremunharem": "estremunhar",
    "estremunharemos": "estremunhar",
    "estremunhares": "estremunhar",
    "estremunharia": "estremunhar",
    "estremunhariam": "estremunhar",
    "estremunharias": "estremunhar",
    "estremunharmo": "estremunhar",
    "estremunharmos": "estremunhar",
    "estremunhará": "estremunhar",
    "estremunharás": "estremunhar",
    "estremunharão": "estremunhar",
    "estremunharíamos": "estremunhar",
    "estremunharíeis": "estremunhar",
    "estremunhas": "estremunhar",
    "estremunhasse": "estremunhar",
    "estremunhassem": "estremunhar",
    "estremunhasses": "estremunhar",
    "estremunhaste": "estremunhar",
    "estremunhastes": "estremunhar",
    "estremunhava": "estremunhar",
    "estremunhavam": "estremunhar",
    "estremunhavas": "estremunhar",
    "estremunhe": "estremunhar",
    "estremunhei": "estremunhar",
    "estremunheis": "estremunhar",
    "estremunhem": "estremunhar",
    "estremunhemo": "estremunhar",
    "estremunhemos": "estremunhar",
    "estremunhes": "estremunhar",
    "estremunho": "estremunhar",
    "estremunhou": "estremunhar",
    "estremunhá": "estremunhar",
    "estremunhámo": "estremunhar",
    "estremunhámos": "estremunhar",
    "estremunháramo": "estremunhar",
    "estremunháramos": "estremunhar",
    "estremunhárei": "estremunhar",
    "estremunháreis": "estremunhar",
    "estremunhásseis": "estremunhar",
    "estremunhássemos": "estremunhar",
    "estremunhávamo": "estremunhar",
    "estremunhávamos": "estremunhar",
    "estremunhávei": "estremunhar",
    "estremunháveis": "estremunhar",
    "estremá": "estremar",
    "estremámo": "estremar",
    "estremámos": "estremar",
    "estremáramo": "estremar",
    "estremáramos": "estremar",
    "estremárei": "estremar",
    "estremáreis": "estremar",
    "estremásseis": "estremar",
    "estremássemos": "estremar",
    "estremávamo": "estremar",
    "estremávamos": "estremar",
    "estremávei": "estremar",
    "estremáveis": "estremável",
    "estrenoita": "estrenoitar",
    "estrenoitada": "estrenoitar",
    "estrenoitadas": "estrenoitar",
    "estrenoitado": "estrenoitar",
    "estrenoitados": "estrenoitar",
    "estrenoitai": "estrenoitar",
    "estrenoitais": "estrenoitar",
    "estrenoitam": "estrenoitar",
    "estrenoitamo": "estrenoitar",
    "estrenoitamos": "estrenoitar",
    "estrenoitando": "estrenoitar",
    "estrenoitara": "estrenoitar",
    "estrenoitaram": "estrenoitar",
    "estrenoitaras": "estrenoitar",
    "estrenoitarde": "estrenoitar",
    "estrenoitardes": "estrenoitar",
    "estrenoitare": "estrenoitar",
    "estrenoitarei": "estrenoitar",
    "estrenoitareis": "estrenoitar",
    "estrenoitarem": "estrenoitar",
    "estrenoitaremos": "estrenoitar",
    "estrenoitares": "estrenoitar",
    "estrenoitaria": "estrenoitar",
    "estrenoitariam": "estrenoitar",
    "estrenoitarias": "estrenoitar",
    "estrenoitarmo": "estrenoitar",
    "estrenoitarmos": "estrenoitar",
    "estrenoitará": "estrenoitar",
    "estrenoitarás": "estrenoitar",
    "estrenoitarão": "estrenoitar",
    "estrenoitaríamos": "estrenoitar",
    "estrenoitaríeis": "estrenoitar",
    "estrenoitas": "estrenoitar",
    "estrenoitasse": "estrenoitar",
    "estrenoitassem": "estrenoitar",
    "estrenoitasses": "estrenoitar",
    "estrenoitaste": "estrenoitar",
    "estrenoitastes": "estrenoitar",
    "estrenoitava": "estrenoitar",
    "estrenoitavam": "estrenoitar",
    "estrenoitavas": "estrenoitar",
    "estrenoite": "estrenoitar",
    "estrenoitei": "estrenoitar",
    "estrenoiteis": "estrenoitar",
    "estrenoitem": "estrenoitar",
    "estrenoitemo": "estrenoitar",
    "estrenoitemos": "estrenoitar",
    "estrenoites": "estrenoitar",
    "estrenoito": "estrenoitar",
    "estrenoitou": "estrenoitar",
    "estrenoitá": "estrenoitar",
    "estrenoitámo": "estrenoitar",
    "estrenoitámos": "estrenoitar",
    "estrenoitáramo": "estrenoitar",
    "estrenoitáramos": "estrenoitar",
    "estrenoitárei": "estrenoitar",
    "estrenoitáreis": "estrenoitar",
    "estrenoitásseis": "estrenoitar",
    "estrenoitássemos": "estrenoitar",
    "estrenoitávamo": "estrenoitar",
    "estrenoitávamos": "estrenoitar",
    "estrenoitávei": "estrenoitar",
    "estrenoitáveis": "estrenoitar",
    "estrenouta": "estrenoutar",
    "estrenoutada": "estrenoutar",
    "estrenoutadas": "estrenoutar",
    "estrenoutado": "estrenoutar",
    "estrenoutados": "estrenoutar",
    "estrenoutai": "estrenoutar",
    "estrenoutais": "estrenoutar",
    "estrenoutam": "estrenoutar",
    "estrenoutamo": "estrenoutar",
    "estrenoutamos": "estrenoutar",
    "estrenoutando": "estrenoutar",
    "estrenoutara": "estrenoutar",
    "estrenoutaram": "estrenoutar",
    "estrenoutaras": "estrenoutar",
    "estrenoutarde": "estrenoutar",
    "estrenoutardes": "estrenoutar",
    "estrenoutare": "estrenoutar",
    "estrenoutarei": "estrenoutar",
    "estrenoutareis": "estrenoutar",
    "estrenoutarem": "estrenoutar",
    "estrenoutaremos": "estrenoutar",
    "estrenoutares": "estrenoutar",
    "estrenoutaria": "estrenoutar",
    "estrenoutariam": "estrenoutar",
    "estrenoutarias": "estrenoutar",
    "estrenoutarmo": "estrenoutar",
    "estrenoutarmos": "estrenoutar",
    "estrenoutará": "estrenoutar",
    "estrenoutarás": "estrenoutar",
    "estrenoutarão": "estrenoutar",
    "estrenoutaríamos": "estrenoutar",
    "estrenoutaríeis": "estrenoutar",
    "estrenoutas": "estrenoutar",
    "estrenoutasse": "estrenoutar",
    "estrenoutassem": "estrenoutar",
    "estrenoutasses": "estrenoutar",
    "estrenoutaste": "estrenoutar",
    "estrenoutastes": "estrenoutar",
    "estrenoutava": "estrenoutar",
    "estrenoutavam": "estrenoutar",
    "estrenoutavas": "estrenoutar",
    "estrenoute": "estrenoutar",
    "estrenoutei": "estrenoutar",
    "estrenouteis": "estrenoutar",
    "estrenoutem": "estrenoutar",
    "estrenoutemo": "estrenoutar",
    "estrenoutemos": "estrenoutar",
    "estrenoutes": "estrenoutar",
    "estrenouto": "estrenoutar",
    "estrenoutou": "estrenoutar",
    "estrenoutá": "estrenoutar",
    "estrenoutámo": "estrenoutar",
    "estrenoutámos": "estrenoutar",
    "estrenoutáramo": "estrenoutar",
    "estrenoutáramos": "estrenoutar",
    "estrenoutárei": "estrenoutar",
    "estrenoutáreis": "estrenoutar",
    "estrenoutásseis": "estrenoutar",
    "estrenoutássemos": "estrenoutar",
    "estrenoutávamo": "estrenoutar",
    "estrenoutávamos": "estrenoutar",
    "estrenoutávei": "estrenoutar",
    "estrenoutáveis": "estrenoutar",
    "estrens": "estrem",
    "estreou": "estrear",
    "estrepa": "estrepar",
    "estrepada": "estrepar",
    "estrepadas": "estrepar",
    "estrepadelas": "estrepadela",
    "estrepado": "estrepar",
    "estrepados": "estrepar",
    "estrepai": "estrepar",
    "estrepais": "estrepar",
    "estrepam": "estrepar",
    "estrepamo": "estrepar",
    "estrepamos": "estrepar",
    "estrepando": "estrepar",
    "estrepara": "estrepar",
    "estreparam": "estrepar",
    "estreparas": "estrepar",
    "estreparde": "estrepar",
    "estrepardes": "estrepar",
    "estrepare": "estrepar",
    "estreparei": "estrepar",
    "estrepareis": "estrepar",
    "estreparem": "estrepar",
    "estreparemos": "estrepar",
    "estrepares": "estrepar",
    "estreparia": "estrepar",
    "estrepariam": "estrepar",
    "estreparias": "estrepar",
    "estreparmo": "estrepar",
    "estreparmos": "estrepar",
    "estrepará": "estrepar",
    "estreparás": "estrepar",
    "estreparão": "estrepar",
    "estreparíamos": "estrepar",
    "estreparíeis": "estrepar",
    "estrepas": "estrepar",
    "estrepasse": "estrepar",
    "estrepassem": "estrepar",
    "estrepasses": "estrepar",
    "estrepaste": "estrepar",
    "estrepastes": "estrepar",
    "estrepava": "estrepar",
    "estrepavam": "estrepar",
    "estrepavas": "estrepar",
    "estrepe": "estrepar",
    "estrepei": "estrepar",
    "estrepeiros": "estrepeiro",
    "estrepeis": "estrepar",
    "estrepem": "estrepar",
    "estrepemo": "estrepar",
    "estrepemos": "estrepar",
    "estrepes": "estrepe",
    "estrepita": "estrepitar",
    "estrepitada": "estrepitar",
    "estrepitadas": "estrepitar",
    "estrepitado": "estrepitar",
    "estrepitados": "estrepitar",
    "estrepitai": "estrepitar",
    "estrepitais": "estrepitar",
    "estrepitam": "estrepitar",
    "estrepitamo": "estrepitar",
    "estrepitamos": "estrepitar",
    "estrepitando": "estrepitar",
    "estrepitantes": "estrepitante",
    "estrepitara": "estrepitar",
    "estrepitaram": "estrepitar",
    "estrepitaras": "estrepitar",
    "estrepitarde": "estrepitar",
    "estrepitardes": "estrepitar",
    "estrepitare": "estrepitar",
    "estrepitarei": "estrepitar",
    "estrepitareis": "estrepitar",
    "estrepitarem": "estrepitar",
    "estrepitaremos": "estrepitar",
    "estrepitares": "estrepitar",
    "estrepitaria": "estrepitar",
    "estrepitariam": "estrepitar",
    "estrepitarias": "estrepitar",
    "estrepitarmo": "estrepitar",
    "estrepitarmos": "estrepitar",
    "estrepitará": "estrepitar",
    "estrepitarás": "estrepitar",
    "estrepitarão": "estrepitar",
    "estrepitaríamos": "estrepitar",
    "estrepitaríeis": "estrepitar",
    "estrepitas": "estrepitar",
    "estrepitasse": "estrepitar",
    "estrepitassem": "estrepitar",
    "estrepitasses": "estrepitar",
    "estrepitaste": "estrepitar",
    "estrepitastes": "estrepitar",
    "estrepitava": "estrepitar",
    "estrepitavam": "estrepitar",
    "estrepitavas": "estrepitar",
    "estrepite": "estrepitar",
    "estrepitei": "estrepitar",
    "estrepiteis": "estrepitar",
    "estrepitem": "estrepitar",
    "estrepitemo": "estrepitar",
    "estrepitemos": "estrepitar",
    "estrepites": "estrepitar",
    "estrepito": "estrepitar",
    "estrepitosa": "estrepitoso",
    "estrepitosas": "estrepitoso",
    "estrepitosos": "estrepitoso",
    "estrepitou": "estrepitar",
    "estrepitá": "estrepitar",
    "estrepitámo": "estrepitar",
    "estrepitámos": "estrepitar",
    "estrepitáramo": "estrepitar",
    "estrepitáramos": "estrepitar",
    "estrepitárei": "estrepitar",
    "estrepitáreis": "estrepitar",
    "estrepitásseis": "estrepitar",
    "estrepitássemos": "estrepitar",
    "estrepitávamo": "estrepitar",
    "estrepitávamos": "estrepitar",
    "estrepitávei": "estrepitar",
    "estrepitáveis": "estrepitar",
    "estrepo": "estrepar",
    "estrepou": "estrepar",
    "estreptococos": "estreptococo",
    "estreptocócica": "estreptocócico",
    "estreptocócicas": "estreptocócico",
    "estreptocócicos": "estreptocócico",
    "estreptomicinas": "estreptomicina",
    "estrepá": "estrepar",
    "estrepámo": "estrepar",
    "estrepámos": "estrepar",
    "estrepáramo": "estrepar",
    "estrepáramos": "estrepar",
    "estrepárei": "estrepar",
    "estrepáreis": "estrepar",
    "estrepásseis": "estrepar",
    "estrepássemos": "estrepar",
    "estrepávamo": "estrepar",
    "estrepávamos": "estrepar",
    "estrepávei": "estrepar",
    "estrepáveis": "estrepar",
    "estres": "estrar",
    "estresa": "estresir",
    "estresais": "estresir",
    "estresam": "estresir",
    "estresamo": "estresir",
    "estresamos": "estresir",
    "estresas": "estresir",
    "estrese": "estresir",
    "estresem": "estresir",
    "estreses": "estresir",
    "estresi": "estresir",
    "estresia": "estresir",
    "estresiam": "estresir",
    "estresias": "estresir",
    "estresida": "estresir",
    "estresidas": "estresir",
    "estresido": "estresir",
    "estresidos": "estresir",
    "estresimo": "estresir",
    "estresimos": "estresir",
    "estresindo": "estresir",
    "estresira": "estresir",
    "estresiram": "estresir",
    "estresiras": "estresir",
    "estresirde": "estresir",
    "estresirdes": "estresir",
    "estresire": "estresir",
    "estresirei": "estresir",
    "estresireis": "estresir",
    "estresirem": "estresir",
    "estresiremos": "estresir",
    "estresires": "estresir",
    "estresiria": "estresir",
    "estresiriam": "estresir",
    "estresirias": "estresir",
    "estresirmo": "estresir",
    "estresirmos": "estresir",
    "estresirá": "estresir",
    "estresirás": "estresir",
    "estresirão": "estresir",
    "estresiríamos": "estresir",
    "estresiríeis": "estresir",
    "estresis": "estresir",
    "estresisse": "estresir",
    "estresissem": "estresir",
    "estresisses": "estresir",
    "estresiste": "estresir",
    "estresistes": "estresir",
    "estresiu": "estresir",
    "estreso": "estresir",
    "estresses": "estresse",
    "estresíamo": "estresir",
    "estresíamos": "estresir",
    "estresíei": "estresir",
    "estresíeis": "estresir",
    "estresíramo": "estresir",
    "estresíramos": "estresir",
    "estresírei": "estresir",
    "estresíreis": "estresir",
    "estresísseis": "estresir",
    "estresíssemos": "estresir",
    "estrevengas": "estrevenga",
    "estreá": "estrear",
    "estreámo": "estrear",
    "estreámos": "estrear",
    "estreáramo": "estrear",
    "estreáramos": "estrear",
    "estreárei": "estrear",
    "estreáreis": "estrear",
    "estreásseis": "estrear",
    "estreássemos": "estrear",
    "estreávamo": "estrear",
    "estreávamos": "estrear",
    "estreávei": "estrear",
    "estreáveis": "estrear",
    "estria": "estriar",
    "estriada": "estriar",
    "estriadas": "estriar",
    "estriado": "estriar",
    "estriados": "estriar",
    "estriai": "estriar",
    "estriais": "estriar",
    "estriam": "estriar",
    "estriamentos": "estriamento",
    "estriamo": "estriar",
    "estriamos": "estriar",
    "estriando": "estriar",
    "estriara": "estriar",
    "estriaram": "estriar",
    "estriaras": "estriar",
    "estriarde": "estriar",
    "estriardes": "estriar",
    "estriare": "estriar",
    "estriarei": "estriar",
    "estriareis": "estriar",
    "estriarem": "estriar",
    "estriaremos": "estriar",
    "estriares": "estriar",
    "estriaria": "estriar",
    "estriariam": "estriar",
    "estriarias": "estriar",
    "estriarmo": "estriar",
    "estriarmos": "estriar",
    "estriará": "estriar",
    "estriarás": "estriar",
    "estriarão": "estriar",
    "estriaríamos": "estriar",
    "estriaríeis": "estriar",
    "estrias": "estriar",
    "estriasse": "estriar",
    "estriassem": "estriar",
    "estriasses": "estriar",
    "estriaste": "estriar",
    "estriastes": "estriar",
    "estriava": "estriar",
    "estriavam": "estriar",
    "estriavas": "estriar",
    "estriba": "estribar",
    "estribada": "estribar",
    "estribadas": "estribar",
    "estribado": "estribar",
    "estribados": "estribar",
    "estribai": "estribar",
    "estribais": "estribar",
    "estribam": "estribar",
    "estribamentos": "estribamento",
    "estribamo": "estribar",
    "estribamos": "estribar",
    "estribando": "estribar",
    "estribara": "estribar",
    "estribaram": "estribar",
    "estribaras": "estribar",
    "estribarde": "estribar",
    "estribardes": "estribar",
    "estribare": "estribar",
    "estribarei": "estribar",
    "estribareis": "estribar",
    "estribarem": "estribar",
    "estribaremos": "estribar",
    "estribares": "estribar",
    "estribaria": "estribar",
    "estribariam": "estribar",
    "estribarias": "estribar",
    "estribarmo": "estribar",
    "estribarmos": "estribar",
    "estribará": "estribar",
    "estribarás": "estribar",
    "estribarão": "estribar",
    "estribaríamos": "estribar",
    "estribaríeis": "estribar",
    "estribas": "estribar",
    "estribasse": "estribar",
    "estribassem": "estribar",
    "estribasses": "estribar",
    "estribaste": "estribar",
    "estribastes": "estribar",
    "estribava": "estribar",
    "estribavam": "estribar",
    "estribavas": "estribar",
    "estribe": "estribar",
    "estribei": "estribar",
    "estribeiras": "estribeira",
    "estribeiros": "estribeiro",
    "estribeis": "estribar",
    "estribem": "estribar",
    "estribemo": "estribar",
    "estribemos": "estribar",
    "estribes": "estribar",
    "estribilhas": "estribilha",
    "estribilhos": "estribilho",
    "estribo": "estribar",
    "estribos": "estribo",
    "estribou": "estribar",
    "estribá": "estribar",
    "estribámo": "estribar",
    "estribámos": "estribar",
    "estribáramo": "estribar",
    "estribáramos": "estribar",
    "estribárei": "estribar",
    "estribáreis": "estribar",
    "estribásseis": "estribar",
    "estribássemos": "estribar",
    "estribávamo": "estribar",
    "estribávamos": "estribar",
    "estribávei": "estribar",
    "estribáveis": "estribar",
    "estricha": "estrichar",
    "estrichada": "estrichar",
    "estrichadas": "estrichar",
    "estrichado": "estrichar",
    "estrichados": "estrichar",
    "estrichai": "estrichar",
    "estrichais": "estrichar",
    "estricham": "estrichar",
    "estrichamo": "estrichar",
    "estrichamos": "estrichar",
    "estrichando": "estrichar",
    "estrichara": "estrichar",
    "estricharam": "estrichar",
    "estricharas": "estrichar",
    "estrichardes": "estrichar",
    "estricharei": "estrichar",
    "estrichareis": "estrichar",
    "estricharem": "estrichar",
    "estricharemos": "estrichar",
    "estrichares": "estrichar",
    "estricharia": "estrichar",
    "estrichariam": "estrichar",
    "estricharias": "estrichar",
    "estricharmo": "estrichar",
    "estricharmos": "estrichar",
    "estrichará": "estrichar",
    "estricharás": "estrichar",
    "estricharão": "estrichar",
    "estricharíamos": "estrichar",
    "estricharíeis": "estrichar",
    "estrichas": "estrichar",
    "estrichasse": "estrichar",
    "estrichassem": "estrichar",
    "estrichasses": "estrichar",
    "estrichaste": "estrichar",
    "estrichastes": "estrichar",
    "estrichava": "estrichar",
    "estrichavam": "estrichar",
    "estrichavas": "estrichar",
    "estriche": "estrichar",
    "estrichei": "estrichar",
    "estricheis": "estrichar",
    "estrichem": "estrichar",
    "estrichemo": "estrichar",
    "estrichemos": "estrichar",
    "estriches": "estrichar",
    "estricho": "estrichar",
    "estrichou": "estrichar",
    "estrichámo": "estrichar",
    "estrichámos": "estrichar",
    "estricháramo": "estrichar",
    "estricháramos": "estrichar",
    "estricháreis": "estrichar",
    "estrichásseis": "estrichar",
    "estrichássemos": "estrichar",
    "estrichávamo": "estrichar",
    "estrichávamos": "estrichar",
    "estricháveis": "estrichar",
    "estricninas": "estricnina",
    "estricções": "estricção",
    "estridentes": "estridente",
    "estridores": "estridor",
    "estridorosa": "estridoroso",
    "estridorosas": "estridoroso",
    "estridorosos": "estridoroso",
    "estridula": "estridular",
    "estridulada": "estridular",
    "estriduladas": "estridular",
    "estridulado": "estridular",
    "estridulados": "estridular",
    "estridulai": "estridular",
    "estridulais": "estridular",
    "estridulam": "estridular",
    "estridulamo": "estridular",
    "estridulamos": "estridular",
    "estridulando": "estridular",
    "estridulantes": "estridulante",
    "estridulara": "estridular",
    "estridularam": "estridular",
    "estridularas": "estridular",
    "estridularde": "estridular",
    "estridulardes": "estridular",
    "estridulare": "estridular",
    "estridularei": "estridular",
    "estridulareis": "estridular",
    "estridularem": "estridular",
    "estridularemos": "estridular",
    "estridulares": "estridular",
    "estridularia": "estridular",
    "estridulariam": "estridular",
    "estridularias": "estridular",
    "estridularmo": "estridular",
    "estridularmos": "estridular",
    "estridulará": "estridular",
    "estridularás": "estridular",
    "estridularão": "estridular",
    "estridularíamos": "estridular",
    "estridularíeis": "estridular",
    "estridulas": "estridular",
    "estridulasse": "estridular",
    "estridulassem": "estridular",
    "estridulasses": "estridular",
    "estridulaste": "estridular",
    "estridulastes": "estridular",
    "estridulava": "estridular",
    "estridulavam": "estridular",
    "estridulavas": "estridular",
    "estridulações": "estridulação",
    "estridule": "estridular",
    "estridulei": "estridular",
    "estriduleis": "estridular",
    "estridulem": "estridular",
    "estridulemo": "estridular",
    "estridulemos": "estridular",
    "estridules": "estridular",
    "estridulo": "estridular",
    "estridulosa": "estriduloso",
    "estridulosas": "estriduloso",
    "estridulosos": "estriduloso",
    "estridulou": "estridular",
    "estridulá": "estridular",
    "estridulámo": "estridular",
    "estridulámos": "estridular",
    "estriduláramo": "estridular",
    "estriduláramos": "estridular",
    "estridulárei": "estridular",
    "estriduláreis": "estridular",
    "estridulásseis": "estridular",
    "estridulássemos": "estridular",
    "estridulávamo": "estridular",
    "estridulávamos": "estridular",
    "estridulávei": "estridular",
    "estriduláveis": "estridular",
    "estridências": "estridência",
    "estrie": "estriar",
    "estriei": "estriar",
    "estrieis": "estriar",
    "estriem": "estriar",
    "estriemo": "estriar",
    "estriemos": "estriar",
    "estries": "estriar",
    "estriga": "estrigar",
    "estrigada": "estrigar",
    "estrigadas": "estrigar",
    "estrigado": "estrigar",
    "estrigados": "estrigar",
    "estrigai": "estrigar",
    "estrigais": "estrigar",
    "estrigam": "estrigar",
    "estrigamo": "estrigar",
    "estrigamos": "estrigar",
    "estrigando": "estrigar",
    "estrigara": "estrigar",
    "estrigaram": "estrigar",
    "estrigaras": "estrigar",
    "estrigarde": "estrigar",
    "estrigardes": "estrigar",
    "estrigare": "estrigar",
    "estrigarei": "estrigar",
    "estrigareis": "estrigar",
    "estrigarem": "estrigar",
    "estrigaremos": "estrigar",
    "estrigares": "estrigar",
    "estrigaria": "estrigar",
    "estrigariam": "estrigar",
    "estrigarias": "estrigar",
    "estrigarmo": "estrigar",
    "estrigarmos": "estrigar",
    "estrigará": "estrigar",
    "estrigarás": "estrigar",
    "estrigarão": "estrigar",
    "estrigaríamos": "estrigar",
    "estrigaríeis": "estrigar",
    "estrigas": "estrigar",
    "estrigasse": "estrigar",
    "estrigassem": "estrigar",
    "estrigasses": "estrigar",
    "estrigaste": "estrigar",
    "estrigastes": "estrigar",
    "estrigava": "estrigar",
    "estrigavam": "estrigar",
    "estrigavas": "estrigar",
    "estrige": "estrigir",
    "estrigem": "estrigir",
    "estriges": "estrigir",
    "estrigi": "estrigir",
    "estrigia": "estrigir",
    "estrigiam": "estrigir",
    "estrigias": "estrigir",
    "estrigida": "estrigir",
    "estrigidas": "estrigir",
    "estrigido": "estrigir",
    "estrigidos": "estrigir",
    "estrigimo": "estrigir",
    "estrigimos": "estrigir",
    "estrigindo": "estrigir",
    "estrigira": "estrigir",
    "estrigiram": "estrigir",
    "estrigiras": "estrigir",
    "estrigirde": "estrigir",
    "estrigirdes": "estrigir",
    "estrigire": "estrigir",
    "estrigirei": "estrigir",
    "estrigireis": "estrigir",
    "estrigirem": "estrigir",
    "estrigiremos": "estrigir",
    "estrigires": "estrigir",
    "estrigiria": "estrigir",
    "estrigiriam": "estrigir",
    "estrigirias": "estrigir",
    "estrigirmo": "estrigir",
    "estrigirmos": "estrigir",
    "estrigirá": "estrigir",
    "estrigirás": "estrigir",
    "estrigirão": "estrigir",
    "estrigiríamos": "estrigir",
    "estrigiríeis": "estrigir",
    "estrigis": "estrigir",
    "estrigisse": "estrigir",
    "estrigissem": "estrigir",
    "estrigisses": "estrigir",
    "estrigiste": "estrigir",
    "estrigistes": "estrigir",
    "estrigiu": "estrigir",
    "estrigo": "estrigar",
    "estrigou": "estrigar",
    "estrigue": "estrigar",
    "estriguei": "estrigar",
    "estrigueis": "estrigar",
    "estriguem": "estrigar",
    "estriguemo": "estrigar",
    "estriguemos": "estrigar",
    "estrigues": "estrigar",
    "estrigá": "estrigar",
    "estrigámo": "estrigar",
    "estrigámos": "estrigar",
    "estrigáramo": "estrigar",
    "estrigáramos": "estrigar",
    "estrigárei": "estrigar",
    "estrigáreis": "estrigar",
    "estrigásseis": "estrigar",
    "estrigássemos": "estrigar",
    "estrigávamo": "estrigar",
    "estrigávamos": "estrigar",
    "estrigávei": "estrigar",
    "estrigáveis": "estrigar",
    "estrigíamo": "estrigir",
    "estrigíamos": "estrigir",
    "estrigídeos": "estrigídeo",
    "estrigíei": "estrigir",
    "estrigíeis": "estrigir",
    "estrigíramo": "estrigir",
    "estrigíramos": "estrigir",
    "estrigírei": "estrigir",
    "estrigíreis": "estrigir",
    "estrigísseis": "estrigir",
    "estrigíssemos": "estrigir",
    "estrija": "estrigir",
    "estrijais": "estrigir",
    "estrijam": "estrigir",
    "estrijamo": "estrigir",
    "estrijamos": "estrigir",
    "estrijas": "estrigir",
    "estrijo": "estrigir",
    "estrila": "estrilar",
    "estrilada": "estrilar",
    "estriladas": "estrilar",
    "estrilado": "estrilar",
    "estrilados": "estrilar",
    "estrilai": "estrilar",
    "estrilais": "estrilar",
    "estrilam": "estrilar",
    "estrilamo": "estrilar",
    "estrilamos": "estrilar",
    "estrilando": "estrilar",
    "estrilara": "estrilar",
    "estrilaram": "estrilar",
    "estrilaras": "estrilar",
    "estrilardes": "estrilar",
    "estrilarei": "estrilar",
    "estrilareis": "estrilar",
    "estrilarem": "estrilar",
    "estrilaremos": "estrilar",
    "estrilares": "estrilar",
    "estrilaria": "estrilar",
    "estrilariam": "estrilar",
    "estrilarias": "estrilar",
    "estrilarmo": "estrilar",
    "estrilarmos": "estrilar",
    "estrilará": "estrilar",
    "estrilarás": "estrilar",
    "estrilarão": "estrilar",
    "estrilaríamos": "estrilar",
    "estrilaríeis": "estrilar",
    "estrilas": "estrilar",
    "estrilasse": "estrilar",
    "estrilassem": "estrilar",
    "estrilasses": "estrilar",
    "estrilaste": "estrilar",
    "estrilastes": "estrilar",
    "estrilava": "estrilar",
    "estrilavam": "estrilar",
    "estrilavas": "estrilar",
    "estrile": "estrilar",
    "estrilei": "estrilar",
    "estrileis": "estrilar",
    "estrilem": "estrilar",
    "estrilemo": "estrilar",
    "estrilemos": "estrilar",
    "estriles": "estrilar",
    "estrilhos": "estrilho",
    "estrilo": "estrilar",
    "estrilou": "estrilar",
    "estrilámo": "estrilar",
    "estrilámos": "estrilar",
    "estriláramo": "estrilar",
    "estriláramos": "estrilar",
    "estriláreis": "estrilar",
    "estrilásseis": "estrilar",
    "estrilássemos": "estrilar",
    "estrilávamo": "estrilar",
    "estrilávamos": "estrilar",
    "estriláveis": "estrilar",
    "estrinca": "estrincar",
    "estrincada": "estrincar",
    "estrincadas": "estrincar",
    "estrincado": "estrincar",
    "estrincados": "estrincar",
    "estrincai": "estrincar",
    "estrincais": "estrincar",
    "estrincam": "estrincar",
    "estrincamo": "estrincar",
    "estrincamos": "estrincar",
    "estrincando": "estrincar",
    "estrincara": "estrincar",
    "estrincaram": "estrincar",
    "estrincaras": "estrincar",
    "estrincarde": "estrincar",
    "estrincardes": "estrincar",
    "estrincare": "estrincar",
    "estrincarei": "estrincar",
    "estrincareis": "estrincar",
    "estrincarem": "estrincar",
    "estrincaremos": "estrincar",
    "estrincares": "estrincar",
    "estrincaria": "estrincar",
    "estrincariam": "estrincar",
    "estrincarias": "estrincar",
    "estrincarmo": "estrincar",
    "estrincarmos": "estrincar",
    "estrincará": "estrincar",
    "estrincarás": "estrincar",
    "estrincarão": "estrincar",
    "estrincaríamos": "estrincar",
    "estrincaríeis": "estrincar",
    "estrincas": "estrincar",
    "estrincasse": "estrincar",
    "estrincassem": "estrincar",
    "estrincasses": "estrincar",
    "estrincaste": "estrincar",
    "estrincastes": "estrincar",
    "estrincava": "estrincar",
    "estrincavam": "estrincar",
    "estrincavas": "estrincar",
    "estrince": "estrinçar",
    "estrincei": "estrinçar",
    "estrinceis": "estrinçar",
    "estrincem": "estrinçar",
    "estrincemo": "estrinçar",
    "estrincemos": "estrinçar",
    "estrinces": "estrinçar",
    "estrincha": "estrinchar",
    "estrinchada": "estrinchar",
    "estrinchadas": "estrinchar",
    "estrinchado": "estrinchar",
    "estrinchados": "estrinchar",
    "estrinchai": "estrinchar",
    "estrinchais": "estrinchar",
    "estrincham": "estrinchar",
    "estrinchamo": "estrinchar",
    "estrinchamos": "estrinchar",
    "estrinchando": "estrinchar",
    "estrinchara": "estrinchar",
    "estrincharam": "estrinchar",
    "estrincharas": "estrinchar",
    "estrincharde": "estrinchar",
    "estrinchardes": "estrinchar",
    "estrinchare": "estrinchar",
    "estrincharei": "estrinchar",
    "estrinchareis": "estrinchar",
    "estrincharem": "estrinchar",
    "estrincharemos": "estrinchar",
    "estrinchares": "estrinchar",
    "estrincharia": "estrinchar",
    "estrinchariam": "estrinchar",
    "estrincharias": "estrinchar",
    "estrincharmo": "estrinchar",
    "estrincharmos": "estrinchar",
    "estrinchará": "estrinchar",
    "estrincharás": "estrinchar",
    "estrincharão": "estrinchar",
    "estrincharíamos": "estrinchar",
    "estrincharíeis": "estrinchar",
    "estrinchas": "estrinchar",
    "estrinchasse": "estrinchar",
    "estrinchassem": "estrinchar",
    "estrinchasses": "estrinchar",
    "estrinchaste": "estrinchar",
    "estrinchastes": "estrinchar",
    "estrinchava": "estrinchar",
    "estrinchavam": "estrinchar",
    "estrinchavas": "estrinchar",
    "estrinche": "estrinchar",
    "estrinchei": "estrinchar",
    "estrincheis": "estrinchar",
    "estrinchem": "estrinchar",
    "estrinchemo": "estrinchar",
    "estrinchemos": "estrinchar",
    "estrinches": "estrinchar",
    "estrincho": "estrinchar",
    "estrinchou": "estrinchar",
    "estrinchá": "estrinchar",
    "estrinchámo": "estrinchar",
    "estrinchámos": "estrinchar",
    "estrincháramo": "estrinchar",
    "estrincháramos": "estrinchar",
    "estrinchárei": "estrinchar",
    "estrincháreis": "estrinchar",
    "estrinchásseis": "estrinchar",
    "estrinchássemos": "estrinchar",
    "estrinchávamo": "estrinchar",
    "estrinchávamos": "estrinchar",
    "estrinchávei": "estrinchar",
    "estrincháveis": "estrinchar",
    "estrinco": "estrincar",
    "estrincou": "estrincar",
    "estrincá": "estrincar",
    "estrincámo": "estrincar",
    "estrincámos": "estrincar",
    "estrincáramo": "estrincar",
    "estrincáramos": "estrincar",
    "estrincárei": "estrincar",
    "estrincáreis": "estrincar",
    "estrincásseis": "estrincar",
    "estrincássemos": "estrincar",
    "estrincávamo": "estrincar",
    "estrincávamos": "estrincar",
    "estrincávei": "estrincar",
    "estrincáveis": "estrincar",
    "estringes": "estringe",
    "estrinque": "estrincar",
    "estrinquei": "estrincar",
    "estrinqueis": "estrincar",
    "estrinquem": "estrincar",
    "estrinquemo": "estrincar",
    "estrinquemos": "estrincar",
    "estrinques": "estrinque",
    "estrinça": "estrinçar",
    "estrinçada": "estrinçar",
    "estrinçadas": "estrinçar",
    "estrinçado": "estrinçar",
    "estrinçados": "estrinçar",
    "estrinçai": "estrinçar",
    "estrinçais": "estrinçar",
    "estrinçam": "estrinçar",
    "estrinçamo": "estrinçar",
    "estrinçamos": "estrinçar",
    "estrinçando": "estrinçar",
    "estrinçara": "estrinçar",
    "estrinçaram": "estrinçar",
    "estrinçaras": "estrinçar",
    "estrinçarde": "estrinçar",
    "estrinçardes": "estrinçar",
    "estrinçare": "estrinçar",
    "estrinçarei": "estrinçar",
    "estrinçareis": "estrinçar",
    "estrinçarem": "estrinçar",
    "estrinçaremos": "estrinçar",
    "estrinçares": "estrinçar",
    "estrinçaria": "estrinçar",
    "estrinçariam": "estrinçar",
    "estrinçarias": "estrinçar",
    "estrinçarmo": "estrinçar",
    "estrinçarmos": "estrinçar",
    "estrinçará": "estrinçar",
    "estrinçarás": "estrinçar",
    "estrinçarão": "estrinçar",
    "estrinçaríamos": "estrinçar",
    "estrinçaríeis": "estrinçar",
    "estrinças": "estrinçar",
    "estrinçasse": "estrinçar",
    "estrinçassem": "estrinçar",
    "estrinçasses": "estrinçar",
    "estrinçaste": "estrinçar",
    "estrinçastes": "estrinçar",
    "estrinçava": "estrinçar",
    "estrinçavam": "estrinçar",
    "estrinçavas": "estrinçar",
    "estrinço": "estrinçar",
    "estrinçou": "estrinçar",
    "estrinçá": "estrinçar",
    "estrinçámo": "estrinçar",
    "estrinçámos": "estrinçar",
    "estrinçáramo": "estrinçar",
    "estrinçáramos": "estrinçar",
    "estrinçárei": "estrinçar",
    "estrinçáreis": "estrinçar",
    "estrinçásseis": "estrinçar",
    "estrinçássemos": "estrinçar",
    "estrinçávamo": "estrinçar",
    "estrinçávamos": "estrinçar",
    "estrinçávei": "estrinçar",
    "estrinçáveis": "estrinçar",
    "estrio": "estriar",
    "estriou": "estriar",
    "estripa": "estripar",
    "estripada": "estripar",
    "estripadas": "estripar",
    "estripado": "estripar",
    "estripadora": "estripador",
    "estripadoras": "estripador",
    "estripadores": "estripador",
    "estripados": "estripar",
    "estripai": "estripar",
    "estripais": "estripar",
    "estripam": "estripar",
    "estripamo": "estripar",
    "estripamos": "estripar",
    "estripando": "estripar",
    "estripara": "estripar",
    "estriparam": "estripar",
    "estriparas": "estripar",
    "estriparde": "estripar",
    "estripardes": "estripar",
    "estripare": "estripar",
    "estriparei": "estripar",
    "estripareis": "estripar",
    "estriparem": "estripar",
    "estriparemos": "estripar",
    "estripares": "estripar",
    "estriparia": "estripar",
    "estripariam": "estripar",
    "estriparias": "estripar",
    "estriparmo": "estripar",
    "estriparmos": "estripar",
    "estripará": "estripar",
    "estriparás": "estripar",
    "estriparão": "estripar",
    "estriparíamos": "estripar",
    "estriparíeis": "estripar",
    "estripas": "estripar",
    "estripasse": "estripar",
    "estripassem": "estripar",
    "estripasses": "estripar",
    "estripaste": "estripar",
    "estripastes": "estripar",
    "estripava": "estripar",
    "estripavam": "estripar",
    "estripavas": "estripar",
    "estripações": "estripação",
    "estripe": "estripar",
    "estripei": "estripar",
    "estripeis": "estripar",
    "estripem": "estripar",
    "estripemo": "estripar",
    "estripemos": "estripar",
    "estripes": "estripar",
    "estripo": "estripar",
    "estripou": "estripar",
    "estripá": "estripar",
    "estripámo": "estripar",
    "estripámos": "estripar",
    "estripáramo": "estripar",
    "estripáramos": "estripar",
    "estripárei": "estripar",
    "estripáreis": "estripar",
    "estripásseis": "estripar",
    "estripássemos": "estripar",
    "estripávamo": "estripar",
    "estripávamos": "estripar",
    "estripávei": "estripar",
    "estripáveis": "estripar",
    "estrita": "estrito",
    "estritas": "estrito",
    "estritos": "estrito",
    "estrituras": "estritura",
    "estriá": "estriar",
    "estriámo": "estriar",
    "estriámos": "estriar",
    "estriáramo": "estriar",
    "estriáramos": "estriar",
    "estriárei": "estriar",
    "estriáreis": "estriar",
    "estriásseis": "estriar",
    "estriássemos": "estriar",
    "estriávamo": "estriar",
    "estriávamos": "estriar",
    "estriávei": "estriar",
    "estriáveis": "estriar",
    "estro": "estrar",
    "estroboscopias": "estroboscopia",
    "estroboscópios": "estroboscópio",
    "estrofantinas": "estrofantina",
    "estrofantos": "estrofanto",
    "estrofes": "estrofe",
    "estrogénios": "estrogénio",
    "estroina": "estroinar",
    "estroinada": "estroinar",
    "estroinadas": "estroinar",
    "estroinado": "estroinar",
    "estroinados": "estroinar",
    "estroinai": "estroinar",
    "estroinais": "estroinar",
    "estroinam": "estroinar",
    "estroinamo": "estroinar",
    "estroinamos": "estroinar",
    "estroinando": "estroinar",
    "estroinara": "estroinar",
    "estroinaram": "estroinar",
    "estroinaras": "estroinar",
    "estroinarde": "estroinar",
    "estroinardes": "estroinar",
    "estroinare": "estroinar",
    "estroinarei": "estroinar",
    "estroinareis": "estroinar",
    "estroinarem": "estroinar",
    "estroinaremos": "estroinar",
    "estroinares": "estroinar",
    "estroinaria": "estroinar",
    "estroinariam": "estroinar",
    "estroinarias": "estroinar",
    "estroinarmo": "estroinar",
    "estroinarmos": "estroinar",
    "estroinará": "estroinar",
    "estroinarás": "estroinar",
    "estroinarão": "estroinar",
    "estroinaríamos": "estroinar",
    "estroinaríeis": "estroinar",
    "estroinas": "estroinar",
    "estroinasse": "estroinar",
    "estroinassem": "estroinar",
    "estroinasses": "estroinar",
    "estroinaste": "estroinar",
    "estroinastes": "estroinar",
    "estroinava": "estroinar",
    "estroinavam": "estroinar",
    "estroinavas": "estroinar",
    "estroine": "estroinar",
    "estroinei": "estroinar",
    "estroineis": "estroinar",
    "estroinem": "estroinar",
    "estroinemo": "estroinar",
    "estroinemos": "estroinar",
    "estroines": "estroinar",
    "estroinices": "estroinice",
    "estroino": "estroinar",
    "estroinou": "estroinar",
    "estroiná": "estroinar",
    "estroinámo": "estroinar",
    "estroinámos": "estroinar",
    "estroináramo": "estroinar",
    "estroináramos": "estroinar",
    "estroinárei": "estroinar",
    "estroináreis": "estroinar",
    "estroinásseis": "estroinar",
    "estroinássemos": "estroinar",
    "estroinávamo": "estroinar",
    "estroinávamos": "estroinar",
    "estroinávei": "estroinar",
    "estroináveis": "estroinar",
    "estromanias": "estromania",
    "estromaníaca": "estromaníaco",
    "estromaníacas": "estromaníaco",
    "estromaníacos": "estromaníaco",
    "estromas": "estroma",
    "estromaturgias": "estromaturgia",
    "estromatúrgica": "estromatúrgico",
    "estromatúrgicas": "estromatúrgico",
    "estromatúrgicos": "estromatúrgico",
    "estromboliana": "estromboliano",
    "estrombolianas": "estromboliano",
    "estrombolianos": "estromboliano",
    "estrombídeos": "estrombídeo",
    "estrompa": "estrompar",
    "estrompada": "estrompar",
    "estrompadas": "estrompar",
    "estrompado": "estrompar",
    "estrompados": "estrompar",
    "estrompai": "estrompar",
    "estrompais": "estrompar",
    "estrompam": "estrompar",
    "estrompamo": "estrompar",
    "estrompamos": "estrompar",
    "estrompando": "estrompar",
    "estrompara": "estrompar",
    "estromparam": "estrompar",
    "estromparas": "estrompar",
    "estromparde": "estrompar",
    "estrompardes": "estrompar",
    "estrompare": "estrompar",
    "estromparei": "estrompar",
    "estrompareis": "estrompar",
    "estromparem": "estrompar",
    "estromparemos": "estrompar",
    "estrompares": "estrompar",
    "estromparia": "estrompar",
    "estrompariam": "estrompar",
    "estromparias": "estrompar",
    "estromparmo": "estrompar",
    "estromparmos": "estrompar",
    "estrompará": "estrompar",
    "estromparás": "estrompar",
    "estromparão": "estrompar",
    "estromparíamos": "estrompar",
    "estromparíeis": "estrompar",
    "estrompas": "estrompar",
    "estrompasse": "estrompar",
    "estrompassem": "estrompar",
    "estrompasses": "estrompar",
    "estrompaste": "estrompar",
    "estrompastes": "estrompar",
    "estrompava": "estrompar",
    "estrompavam": "estrompar",
    "estrompavas": "estrompar",
    "estrompe": "estrompar",
    "estrompei": "estrompar",
    "estrompeis": "estrompar",
    "estrompem": "estrompar",
    "estrompemo": "estrompar",
    "estrompemos": "estrompar",
    "estrompes": "estrompar",
    "estrompo": "estrompar",
    "estrompou": "estrompar",
    "estrompá": "estrompar",
    "estrompámo": "estrompar",
    "estrompámos": "estrompar",
    "estrompáramo": "estrompar",
    "estrompáramos": "estrompar",
    "estrompárei": "estrompar",
    "estrompáreis": "estrompar",
    "estrompásseis": "estrompar",
    "estrompássemos": "estrompar",
    "estrompávamo": "estrompar",
    "estrompávamos": "estrompar",
    "estrompávei": "estrompar",
    "estrompáveis": "estrompar",
    "estronca": "estroncar",
    "estroncada": "estroncar",
    "estroncadas": "estroncar",
    "estroncado": "estroncar",
    "estroncados": "estroncar",
    "estroncai": "estroncar",
    "estroncais": "estroncar",
    "estroncam": "estroncar",
    "estroncamentos": "estroncamento",
    "estroncamo": "estroncar",
    "estroncamos": "estroncar",
    "estroncando": "estroncar",
    "estroncara": "estroncar",
    "estroncaram": "estroncar",
    "estroncaras": "estroncar",
    "estroncarde": "estroncar",
    "estroncardes": "estroncar",
    "estroncare": "estroncar",
    "estroncarei": "estroncar",
    "estroncareis": "estroncar",
    "estroncarem": "estroncar",
    "estroncaremos": "estroncar",
    "estroncares": "estroncar",
    "estroncaria": "estroncar",
    "estroncariam": "estroncar",
    "estroncarias": "estroncar",
    "estroncarmo": "estroncar",
    "estroncarmos": "estroncar",
    "estroncará": "estroncar",
    "estroncarás": "estroncar",
    "estroncarão": "estroncar",
    "estroncaríamos": "estroncar",
    "estroncaríeis": "estroncar",
    "estroncas": "estroncar",
    "estroncasse": "estroncar",
    "estroncassem": "estroncar",
    "estroncasses": "estroncar",
    "estroncaste": "estroncar",
    "estroncastes": "estroncar",
    "estroncava": "estroncar",
    "estroncavam": "estroncar",
    "estroncavas": "estroncar",
    "estronce": "estronçar",
    "estronceanas": "estronceana",
    "estroncei": "estronçar",
    "estronceis": "estronçar",
    "estroncem": "estronçar",
    "estroncemo": "estronçar",
    "estroncemos": "estronçar",
    "estronces": "estronçar",
    "estroncianites": "estroncianite",
    "estronco": "estroncar",
    "estroncou": "estroncar",
    "estroncá": "estroncar",
    "estroncámo": "estroncar",
    "estroncámos": "estroncar",
    "estroncáramo": "estroncar",
    "estroncáramos": "estroncar",
    "estroncárei": "estroncar",
    "estroncáreis": "estroncar",
    "estroncásseis": "estroncar",
    "estroncássemos": "estroncar",
    "estroncávamo": "estroncar",
    "estroncávamos": "estroncar",
    "estroncávei": "estroncar",
    "estroncáveis": "estroncar",
    "estronda": "estrondar",
    "estrondada": "estrondar",
    "estrondadas": "estrondar",
    "estrondado": "estrondar",
    "estrondados": "estrondar",
    "estrondai": "estrondar",
    "estrondais": "estrondar",
    "estrondam": "estrondar",
    "estrondamo": "estrondar",
    "estrondamos": "estrondar",
    "estrondando": "estrondar",
    "estrondara": "estrondar",
    "estrondaram": "estrondar",
    "estrondaras": "estrondar",
    "estrondardes": "estrondar",
    "estrondarei": "estrondar",
    "estrondareis": "estrondar",
    "estrondarem": "estrondar",
    "estrondaremos": "estrondar",
    "estrondares": "estrondar",
    "estrondaria": "estrondar",
    "estrondariam": "estrondar",
    "estrondarias": "estrondar",
    "estrondarmo": "estrondar",
    "estrondarmos": "estrondar",
    "estrondará": "estrondar",
    "estrondarás": "estrondar",
    "estrondarão": "estrondar",
    "estrondaríamos": "estrondar",
    "estrondaríeis": "estrondar",
    "estrondas": "estrondar",
    "estrondasse": "estrondar",
    "estrondassem": "estrondar",
    "estrondasses": "estrondar",
    "estrondaste": "estrondar",
    "estrondastes": "estrondar",
    "estrondava": "estrondar",
    "estrondavam": "estrondar",
    "estrondavas": "estrondar",
    "estronde": "estrondar",
    "estrondeada": "estrondear",
    "estrondeadas": "estrondear",
    "estrondeado": "estrondear",
    "estrondeados": "estrondear",
    "estrondeai": "estrondear",
    "estrondeais": "estrondear",
    "estrondeamo": "estrondear",
    "estrondeamos": "estrondear",
    "estrondeando": "estrondear",
    "estrondeantes": "estrondeante",
    "estrondeara": "estrondear",
    "estrondearam": "estrondear",
    "estrondearas": "estrondear",
    "estrondeardes": "estrondear",
    "estrondearei": "estrondear",
    "estrondeareis": "estrondear",
    "estrondearem": "estrondear",
    "estrondearemos": "estrondear",
    "estrondeares": "estrondear",
    "estrondearia": "estrondear",
    "estrondeariam": "estrondear",
    "estrondearias": "estrondear",
    "estrondearmo": "estrondear",
    "estrondearmos": "estrondear",
    "estrondeará": "estrondear",
    "estrondearás": "estrondear",
    "estrondearão": "estrondear",
    "estrondearíamos": "estrondear",
    "estrondearíeis": "estrondear",
    "estrondeasse": "estrondear",
    "estrondeassem": "estrondear",
    "estrondeasses": "estrondear",
    "estrondeaste": "estrondear",
    "estrondeastes": "estrondear",
    "estrondeava": "estrondear",
    "estrondeavam": "estrondear",
    "estrondeavas": "estrondear",
    "estrondeei": "estrondear",
    "estrondeeis": "estrondear",
    "estrondeemo": "estrondear",
    "estrondeemos": "estrondear",
    "estrondei": "estrondar",
    "estrondeia": "estrondear",
    "estrondeiam": "estrondear",
    "estrondeias": "estrondear",
    "estrondeie": "estrondear",
    "estrondeiem": "estrondear",
    "estrondeies": "estrondear",
    "estrondeio": "estrondear",
    "estrondeis": "estrondar",
    "estrondem": "estrondar",
    "estrondemo": "estrondar",
    "estrondemos": "estrondar",
    "estrondeou": "estrondear",
    "estrondes": "estrondar",
    "estrondeámo": "estrondear",
    "estrondeámos": "estrondear",
    "estrondeáramo": "estrondear",
    "estrondeáramos": "estrondear",
    "estrondeáreis": "estrondear",
    "estrondeásseis": "estrondear",
    "estrondeássemos": "estrondear",
    "estrondeávamo": "estrondear",
    "estrondeávamos": "estrondear",
    "estrondeáveis": "estrondear",
    "estrondo": "estrondar",
    "estrondos": "estrondo",
    "estrondosa": "estrondoso",
    "estrondosas": "estrondoso",
    "estrondosos": "estrondoso",
    "estrondou": "estrondar",
    "estrondámo": "estrondar",
    "estrondámos": "estrondar",
    "estrondáramo": "estrondar",
    "estrondáramos": "estrondar",
    "estrondáreis": "estrondar",
    "estrondásseis": "estrondar",
    "estrondássemos": "estrondar",
    "estrondávamo": "estrondar",
    "estrondávamos": "estrondar",
    "estrondáveis": "estrondar",
    "estronque": "estroncar",
    "estronquei": "estroncar",
    "estronqueis": "estroncar",
    "estronquem": "estroncar",
    "estronquemo": "estroncar",
    "estronquemos": "estroncar",
    "estronques": "estroncar",
    "estronça": "estronçar",
    "estronçada": "estronçar",
    "estronçadas": "estronçar",
    "estronçado": "estronçar",
    "estronçados": "estronçar",
    "estronçai": "estronçar",
    "estronçais": "estronçar",
    "estronçam": "estronçar",
    "estronçamo": "estronçar",
    "estronçamos": "estronçar",
    "estronçando": "estronçar",
    "estronçara": "estronçar",
    "estronçaram": "estronçar",
    "estronçaras": "estronçar",
    "estronçarde": "estronçar",
    "estronçardes": "estronçar",
    "estronçare": "estronçar",
    "estronçarei": "estronçar",
    "estronçareis": "estronçar",
    "estronçarem": "estronçar",
    "estronçaremos": "estronçar",
    "estronçares": "estronçar",
    "estronçaria": "estronçar",
    "estronçariam": "estronçar",
    "estronçarias": "estronçar",
    "estronçarmo": "estronçar",
    "estronçarmos": "estronçar",
    "estronçará": "estronçar",
    "estronçarás": "estronçar",
    "estronçarão": "estronçar",
    "estronçaríamos": "estronçar",
    "estronçaríeis": "estronçar",
    "estronças": "estronçar",
    "estronçasse": "estronçar",
    "estronçassem": "estronçar",
    "estronçasses": "estronçar",
    "estronçaste": "estronçar",
    "estronçastes": "estronçar",
    "estronçava": "estronçar",
    "estronçavam": "estronçar",
    "estronçavas": "estronçar",
    "estronço": "estronçar",
    "estronçou": "estronçar",
    "estronçá": "estronçar",
    "estronçámo": "estronçar",
    "estronçámos": "estronçar",
    "estronçáramo": "estronçar",
    "estronçáramos": "estronçar",
    "estronçárei": "estronçar",
    "estronçáreis": "estronçar",
    "estronçásseis": "estronçar",
    "estronçássemos": "estronçar",
    "estronçávamo": "estronçar",
    "estronçávamos": "estronçar",
    "estronçávei": "estronçar",
    "estronçáveis": "estronçar",
    "estropalhos": "estropalho",
    "estropeada": "estropear",
    "estropeadas": "estropear",
    "estropeado": "estropear",
    "estropeados": "estropear",
    "estropeai": "estropear",
    "estropeais": "estropear",
    "estropeamo": "estropear",
    "estropeamos": "estropear",
    "estropeando": "estropear",
    "estropeara": "estropear",
    "estropearam": "estropear",
    "estropearas": "estropear",
    "estropeardes": "estropear",
    "estropearei": "estropear",
    "estropeareis": "estropear",
    "estropearem": "estropear",
    "estropearemos": "estropear",
    "estropeares": "estropear",
    "estropearia": "estropear",
    "estropeariam": "estropear",
    "estropearias": "estropear",
    "estropearmo": "estropear",
    "estropearmos": "estropear",
    "estropeará": "estropear",
    "estropearás": "estropear",
    "estropearão": "estropear",
    "estropearíamos": "estropear",
    "estropearíeis": "estropear",
    "estropeasse": "estropear",
    "estropeassem": "estropear",
    "estropeasses": "estropear",
    "estropeaste": "estropear",
    "estropeastes": "estropear",
    "estropeava": "estropear",
    "estropeavam": "estropear",
    "estropeavas": "estropear",
    "estropeações": "estropeação",
    "estropeei": "estropear",
    "estropeeis": "estropear",
    "estropeemo": "estropear",
    "estropeemos": "estropear",
    "estropeia": "estropear",
    "estropeiam": "estropear",
    "estropeias": "estropear",
    "estropeie": "estropear",
    "estropeiem": "estropear",
    "estropeies": "estropear",
    "estropeio": "estropear",
    "estropeou": "estropear",
    "estropeámo": "estropear",
    "estropeámos": "estropear",
    "estropeáramo": "estropear",
    "estropeáramos": "estropear",
    "estropeáreis": "estropear",
    "estropeásseis": "estropear",
    "estropeássemos": "estropear",
    "estropeávamo": "estropear",
    "estropeávamos": "estropear",
    "estropeáveis": "estropear",
    "estropia": "estropiar",
    "estropiada": "estropiar",
    "estropiadas": "estropiar",
    "estropiado": "estropiar",
    "estropiados": "estropiar",
    "estropiai": "estropiar",
    "estropiais": "estropiar",
    "estropiam": "estropiar",
    "estropiamentos": "estropiamento",
    "estropiamo": "estropiar",
    "estropiamos": "estropiar",
    "estropiando": "estropiar",
    "estropiara": "estropiar",
    "estropiaram": "estropiar",
    "estropiaras": "estropiar",
    "estropiarde": "estropiar",
    "estropiardes": "estropiar",
    "estropiare": "estropiar",
    "estropiarei": "estropiar",
    "estropiareis": "estropiar",
    "estropiarem": "estropiar",
    "estropiaremos": "estropiar",
    "estropiares": "estropiar",
    "estropiaria": "estropiar",
    "estropiariam": "estropiar",
    "estropiarias": "estropiar",
    "estropiarmo": "estropiar",
    "estropiarmos": "estropiar",
    "estropiará": "estropiar",
    "estropiarás": "estropiar",
    "estropiarão": "estropiar",
    "estropiaríamos": "estropiar",
    "estropiaríeis": "estropiar",
    "estropias": "estropiar",
    "estropiasse": "estropiar",
    "estropiassem": "estropiar",
    "estropiasses": "estropiar",
    "estropiaste": "estropiar",
    "estropiastes": "estropiar",
    "estropiava": "estropiar",
    "estropiavam": "estropiar",
    "estropiavas": "estropiar",
    "estropiações": "estropiação",
    "estropie": "estropiar",
    "estropiei": "estropiar",
    "estropieis": "estropiar",
    "estropiem": "estropiar",
    "estropiemo": "estropiar",
    "estropiemos": "estropiar",
    "estropies": "estropiar",
    "estropio": "estropiar",
    "estropiou": "estropiar",
    "estropiá": "estropiar",
    "estropiámo": "estropiar",
    "estropiámos": "estropiar",
    "estropiáramo": "estropiar",
    "estropiáramos": "estropiar",
    "estropiárei": "estropiar",
    "estropiáreis": "estropiar",
    "estropiásseis": "estropiar",
    "estropiássemos": "estropiar",
    "estropiávamo": "estropiar",
    "estropiávamos": "estropiar",
    "estropiávei": "estropiar",
    "estropiáveis": "estropiar",
    "estropos": "estropo",
    "estropícios": "estropício",
    "estros": "estro",
    "estrosa": "estroso",
    "estrosas": "estroso",
    "estrosos": "estroso",
    "estroteja": "estrotejar",
    "estrotejada": "estrotejar",
    "estrotejadas": "estrotejar",
    "estrotejado": "estrotejar",
    "estrotejados": "estrotejar",
    "estrotejai": "estrotejar",
    "estrotejais": "estrotejar",
    "estrotejam": "estrotejar",
    "estrotejamo": "estrotejar",
    "estrotejamos": "estrotejar",
    "estrotejando": "estrotejar",
    "estrotejara": "estrotejar",
    "estrotejaram": "estrotejar",
    "estrotejaras": "estrotejar",
    "estrotejardes": "estrotejar",
    "estrotejarei": "estrotejar",
    "estrotejareis": "estrotejar",
    "estrotejarem": "estrotejar",
    "estrotejaremos": "estrotejar",
    "estrotejares": "estrotejar",
    "estrotejaria": "estrotejar",
    "estrotejariam": "estrotejar",
    "estrotejarias": "estrotejar",
    "estrotejarmo": "estrotejar",
    "estrotejarmos": "estrotejar",
    "estrotejará": "estrotejar",
    "estrotejarás": "estrotejar",
    "estrotejarão": "estrotejar",
    "estrotejaríamos": "estrotejar",
    "estrotejaríeis": "estrotejar",
    "estrotejas": "estrotejar",
    "estrotejasse": "estrotejar",
    "estrotejassem": "estrotejar",
    "estrotejasses": "estrotejar",
    "estrotejaste": "estrotejar",
    "estrotejastes": "estrotejar",
    "estrotejava": "estrotejar",
    "estrotejavam": "estrotejar",
    "estrotejavas": "estrotejar",
    "estroteje": "estrotejar",
    "estrotejei": "estrotejar",
    "estrotejeis": "estrotejar",
    "estrotejem": "estrotejar",
    "estrotejemo": "estrotejar",
    "estrotejemos": "estrotejar",
    "estrotejes": "estrotejar",
    "estrotejo": "estrotejar",
    "estrotejou": "estrotejar",
    "estrotejámo": "estrotejar",
    "estrotejámos": "estrotejar",
    "estrotejáramo": "estrotejar",
    "estrotejáramos": "estrotejar",
    "estrotejáreis": "estrotejar",
    "estrotejásseis": "estrotejar",
    "estrotejássemos": "estrotejar",
    "estrotejávamo": "estrotejar",
    "estrotejávamos": "estrotejar",
    "estrotejáveis": "estrotejar",
    "estrou": "estrar",
    "estrovengas": "estrovenga",
    "estrovinha": "estrovinhar",
    "estrovinhada": "estrovinhar",
    "estrovinhadas": "estrovinhar",
    "estrovinhado": "estrovinhar",
    "estrovinhados": "estrovinhar",
    "estrovinhai": "estrovinhar",
    "estrovinhais": "estrovinhar",
    "estrovinham": "estrovinhar",
    "estrovinhamo": "estrovinhar",
    "estrovinhamos": "estrovinhar",
    "estrovinhando": "estrovinhar",
    "estrovinhara": "estrovinhar",
    "estrovinharam": "estrovinhar",
    "estrovinharas": "estrovinhar",
    "estrovinharde": "estrovinhar",
    "estrovinhardes": "estrovinhar",
    "estrovinhare": "estrovinhar",
    "estrovinharei": "estrovinhar",
    "estrovinhareis": "estrovinhar",
    "estrovinharem": "estrovinhar",
    "estrovinharemos": "estrovinhar",
    "estrovinhares": "estrovinhar",
    "estrovinharia": "estrovinhar",
    "estrovinhariam": "estrovinhar",
    "estrovinharias": "estrovinhar",
    "estrovinharmo": "estrovinhar",
    "estrovinharmos": "estrovinhar",
    "estrovinhará": "estrovinhar",
    "estrovinharás": "estrovinhar",
    "estrovinharão": "estrovinhar",
    "estrovinharíamos": "estrovinhar",
    "estrovinharíeis": "estrovinhar",
    "estrovinhas": "estrovinhar",
    "estrovinhasse": "estrovinhar",
    "estrovinhassem": "estrovinhar",
    "estrovinhasses": "estrovinhar",
    "estrovinhaste": "estrovinhar",
    "estrovinhastes": "estrovinhar",
    "estrovinhava": "estrovinhar",
    "estrovinhavam": "estrovinhar",
    "estrovinhavas": "estrovinhar",
    "estrovinhe": "estrovinhar",
    "estrovinhei": "estrovinhar",
    "estrovinheis": "estrovinhar",
    "estrovinhem": "estrovinhar",
    "estrovinhemo": "estrovinhar",
    "estrovinhemos": "estrovinhar",
    "estrovinhes": "estrovinhar",
    "estrovinho": "estrovinhar",
    "estrovinhou": "estrovinhar",
    "estrovinhá": "estrovinhar",
    "estrovinhámo": "estrovinhar",
    "estrovinhámos": "estrovinhar",
    "estrovinháramo": "estrovinhar",
    "estrovinháramos": "estrovinhar",
    "estrovinhárei": "estrovinhar",
    "estrovinháreis": "estrovinhar",
    "estrovinhásseis": "estrovinhar",
    "estrovinhássemos": "estrovinhar",
    "estrovinhávamo": "estrovinhar",
    "estrovinhávamos": "estrovinhar",
    "estrovinhávei": "estrovinhar",
    "estrovinháveis": "estrovinhar",
    "estrovos": "estrovo",
    "estroços": "estroço",
    "estrua": "estruir",
    "estruais": "estruir",
    "estruam": "estruir",
    "estruamo": "estruir",
    "estruamos": "estruir",
    "estruas": "estruir",
    "estruem": "estruir",
    "estruge": "estrugir",
    "estrugedora": "estrugedor",
    "estrugedoras": "estrugedor",
    "estrugedores": "estrugedor",
    "estrugem": "estrugir",
    "estruges": "estrugir",
    "estrugi": "estrugir",
    "estrugia": "estrugir",
    "estrugiam": "estrugir",
    "estrugias": "estrugir",
    "estrugida": "estrugir",
    "estrugidas": "estrugir",
    "estrugido": "estrugir",
    "estrugidos": "estrugir",
    "estrugimentos": "estrugimento",
    "estrugimo": "estrugir",
    "estrugimos": "estrugir",
    "estrugindo": "estrugir",
    "estrugira": "estrugir",
    "estrugiram": "estrugir",
    "estrugiras": "estrugir",
    "estrugirde": "estrugir",
    "estrugirdes": "estrugir",
    "estrugire": "estrugir",
    "estrugirei": "estrugir",
    "estrugireis": "estrugir",
    "estrugirem": "estrugir",
    "estrugiremos": "estrugir",
    "estrugires": "estrugir",
    "estrugiria": "estrugir",
    "estrugiriam": "estrugir",
    "estrugirias": "estrugir",
    "estrugirmo": "estrugir",
    "estrugirmos": "estrugir",
    "estrugirá": "estrugir",
    "estrugirás": "estrugir",
    "estrugirão": "estrugir",
    "estrugiríamos": "estrugir",
    "estrugiríeis": "estrugir",
    "estrugis": "estrugir",
    "estrugisse": "estrugir",
    "estrugissem": "estrugir",
    "estrugisses": "estrugir",
    "estrugiste": "estrugir",
    "estrugistes": "estrugir",
    "estrugiu": "estrugir",
    "estrugíamo": "estrugir",
    "estrugíamos": "estrugir",
    "estrugíei": "estrugir",
    "estrugíeis": "estrugir",
    "estrugíramo": "estrugir",
    "estrugíramos": "estrugir",
    "estrugírei": "estrugir",
    "estrugíreis": "estrugir",
    "estrugísseis": "estrugir",
    "estrugíssemos": "estrugir",
    "estrui": "estruir",
    "estruindo": "estruir",
    "estruirde": "estruir",
    "estruirdes": "estruir",
    "estruirei": "estruir",
    "estruireis": "estruir",
    "estruiremos": "estruir",
    "estruiria": "estruir",
    "estruiriam": "estruir",
    "estruirias": "estruir",
    "estruirmo": "estruir",
    "estruirmos": "estruir",
    "estruirá": "estruir",
    "estruirás": "estruir",
    "estruirão": "estruir",
    "estruiríamos": "estruir",
    "estruiríeis": "estruir",
    "estruis": "estruir",
    "estruiu": "estruir",
    "estruja": "estrugir",
    "estrujais": "estrugir",
    "estrujam": "estrugir",
    "estrujamo": "estrugir",
    "estrujamos": "estrugir",
    "estrujas": "estrugir",
    "estrujo": "estrugir",
    "estruma": "estrumar",
    "estrumada": "estrumar",
    "estrumadas": "estrumar",
    "estrumadelas": "estrumadela",
    "estrumado": "estrumar",
    "estrumados": "estrumar",
    "estrumai": "estrumar",
    "estrumais": "estrumar",
    "estrumam": "estrumar",
    "estrumamo": "estrumar",
    "estrumamos": "estrumar",
    "estrumando": "estrumar",
    "estrumara": "estrumar",
    "estrumaram": "estrumar",
    "estrumaras": "estrumar",
    "estrumarde": "estrumar",
    "estrumardes": "estrumar",
    "estrumare": "estrumar",
    "estrumarei": "estrumar",
    "estrumareis": "estrumar",
    "estrumarem": "estrumar",
    "estrumaremos": "estrumar",
    "estrumares": "estrumar",
    "estrumaria": "estrumar",
    "estrumariam": "estrumar",
    "estrumarias": "estrumar",
    "estrumarmo": "estrumar",
    "estrumarmos": "estrumar",
    "estrumará": "estrumar",
    "estrumarás": "estrumar",
    "estrumarão": "estrumar",
    "estrumaríamos": "estrumar",
    "estrumaríeis": "estrumar",
    "estrumas": "estrumar",
    "estrumasse": "estrumar",
    "estrumassem": "estrumar",
    "estrumasses": "estrumar",
    "estrumaste": "estrumar",
    "estrumastes": "estrumar",
    "estrumava": "estrumar",
    "estrumavam": "estrumar",
    "estrumavas": "estrumar",
    "estrumações": "estrumação",
    "estrume": "estrumar",
    "estrumei": "estrumar",
    "estrumeiras": "estrumeira",
    "estrumeiros": "estrumeiro",
    "estrumeis": "estrumar",
    "estrumelas": "estrumela",
    "estrumem": "estrumar",
    "estrumemo": "estrumar",
    "estrumemos": "estrumar",
    "estrumes": "estrume",
    "estrumo": "estrumar",
    "estrumosa": "estrumoso",
    "estrumosas": "estrumoso",
    "estrumosos": "estrumoso",
    "estrumou": "estrumar",
    "estrumá": "estrumar",
    "estrumámo": "estrumar",
    "estrumámos": "estrumar",
    "estrumáramo": "estrumar",
    "estrumáramos": "estrumar",
    "estrumárei": "estrumar",
    "estrumáreis": "estrumar",
    "estrumásseis": "estrumar",
    "estrumássemos": "estrumar",
    "estrumávamo": "estrumar",
    "estrumávamos": "estrumar",
    "estrumávei": "estrumar",
    "estrumáveis": "estrumar",
    "estruo": "estruir",
    "estrupida": "estrupidar",
    "estrupidada": "estrupidar",
    "estrupidadas": "estrupidar",
    "estrupidado": "estrupidar",
    "estrupidados": "estrupidar",
    "estrupidai": "estrupidar",
    "estrupidais": "estrupidar",
    "estrupidam": "estrupidar",
    "estrupidamo": "estrupidar",
    "estrupidamos": "estrupidar",
    "estrupidando": "estrupidar",
    "estrupidantes": "estrupidante",
    "estrupidara": "estrupidar",
    "estrupidaram": "estrupidar",
    "estrupidaras": "estrupidar",
    "estrupidardes": "estrupidar",
    "estrupidarei": "estrupidar",
    "estrupidareis": "estrupidar",
    "estrupidarem": "estrupidar",
    "estrupidaremos": "estrupidar",
    "estrupidares": "estrupidar",
    "estrupidaria": "estrupidar",
    "estrupidariam": "estrupidar",
    "estrupidarias": "estrupidar",
    "estrupidarmo": "estrupidar",
    "estrupidarmos": "estrupidar",
    "estrupidará": "estrupidar",
    "estrupidarás": "estrupidar",
    "estrupidarão": "estrupidar",
    "estrupidaríamos": "estrupidar",
    "estrupidaríeis": "estrupidar",
    "estrupidas": "estrupidar",
    "estrupidasse": "estrupidar",
    "estrupidassem": "estrupidar",
    "estrupidasses": "estrupidar",
    "estrupidaste": "estrupidar",
    "estrupidastes": "estrupidar",
    "estrupidava": "estrupidar",
    "estrupidavam": "estrupidar",
    "estrupidavas": "estrupidar",
    "estrupide": "estrupidar",
    "estrupidei": "estrupidar",
    "estrupideis": "estrupidar",
    "estrupidem": "estrupidar",
    "estrupidemo": "estrupidar",
    "estrupidemos": "estrupidar",
    "estrupides": "estrupidar",
    "estrupido": "estrupidar",
    "estrupidos": "estrupido",
    "estrupidou": "estrupidar",
    "estrupidámo": "estrupidar",
    "estrupidámos": "estrupidar",
    "estrupidáramo": "estrupidar",
    "estrupidáramos": "estrupidar",
    "estrupidáreis": "estrupidar",
    "estrupidásseis": "estrupidar",
    "estrupidássemos": "estrupidar",
    "estrupidávamo": "estrupidar",
    "estrupidávamos": "estrupidar",
    "estrupidáveis": "estrupidar",
    "estrupícios": "estrupício",
    "estrutionídios": "estrutionídio",
    "estrutiónidas": "estrutiónida",
    "estrutura": "estruturar",
    "estruturada": "estruturar",
    "estruturadas": "estruturar",
    "estruturado": "estruturar",
    "estruturados": "estruturar",
    "estruturai": "estruturar",
    "estruturais": "estruturar",
    "estruturalismos": "estruturalismo",
    "estruturalistas": "estruturalista",
    "estruturam": "estruturar",
    "estruturamo": "estruturar",
    "estruturamos": "estruturar",
    "estruturando": "estruturar",
    "estruturantes": "estruturante",
    "estruturara": "estruturar",
    "estruturaram": "estruturar",
    "estruturaras": "estruturar",
    "estruturarde": "estruturar",
    "estruturardes": "estruturar",
    "estruturare": "estruturar",
    "estruturarei": "estruturar",
    "estruturareis": "estruturar",
    "estruturarem": "estruturar",
    "estruturaremos": "estruturar",
    "estruturares": "estruturar",
    "estruturaria": "estruturar",
    "estruturariam": "estruturar",
    "estruturarias": "estruturar",
    "estruturarmo": "estruturar",
    "estruturarmos": "estruturar",
    "estruturará": "estruturar",
    "estruturarás": "estruturar",
    "estruturarão": "estruturar",
    "estruturaríamos": "estruturar",
    "estruturaríeis": "estruturar",
    "estruturas": "estruturar",
    "estruturasse": "estruturar",
    "estruturassem": "estruturar",
    "estruturasses": "estruturar",
    "estruturaste": "estruturar",
    "estruturastes": "estruturar",
    "estruturava": "estruturar",
    "estruturavam": "estruturar",
    "estruturavas": "estruturar",
    "estruturações": "estruturação",
    "estruture": "estruturar",
    "estruturei": "estruturar",
    "estrutureis": "estruturar",
    "estruturem": "estruturar",
    "estruturemo": "estruturar",
    "estruturemos": "estruturar",
    "estrutures": "estruturar",
    "estruturo": "estruturar",
    "estruturou": "estruturar",
    "estruturá": "estruturar",
    "estruturámo": "estruturar",
    "estruturámos": "estruturar",
    "estruturáramo": "estruturar",
    "estruturáramos": "estruturar",
    "estruturárei": "estruturar",
    "estruturáreis": "estruturar",
    "estruturásseis": "estruturar",
    "estruturássemos": "estruturar",
    "estruturávamo": "estruturar",
    "estruturávamos": "estruturar",
    "estruturávei": "estruturar",
    "estruturáveis": "estruturável",
    "estruí": "estruir",
    "estruía": "estruir",
    "estruíam": "estruir",
    "estruíamo": "estruir",
    "estruíamos": "estruir",
    "estruías": "estruir",
    "estruída": "estruir",
    "estruídas": "estruir",
    "estruído": "estruir",
    "estruídos": "estruir",
    "estruíei": "estruir",
    "estruíeis": "estruir",
    "estruímo": "estruir",
    "estruímos": "estruir",
    "estruíra": "estruir",
    "estruíram": "estruir",
    "estruíramo": "estruir",
    "estruíramos": "estruir",
    "estruíras": "estruir",
    "estruíre": "estruir",
    "estruírei": "estruir",
    "estruíreis": "estruir",
    "estruírem": "estruir",
    "estruíres": "estruir",
    "estruís": "estruir",
    "estruísse": "estruir",
    "estruísseis": "estruir",
    "estruíssem": "estruir",
    "estruíssemos": "estruir",
    "estruísses": "estruir",
    "estruíste": "estruir",
    "estruístes": "estruir",
    "estrá": "estrar",
    "estrábica": "estrábico",
    "estrábicas": "estrábico",
    "estrábicos": "estrábico",
    "estrágulos": "estrágulo",
    "estrámo": "estrar",
    "estrámos": "estrar",
    "estráramo": "estrar",
    "estráramos": "estrar",
    "estrárei": "estrar",
    "estráreis": "estrar",
    "estrásseis": "estrar",
    "estrássemos": "estrar",
    "estrávamo": "estrar",
    "estrávamos": "estrar",
    "estrávei": "estrar",
    "estráveis": "estrável",
    "estrénua": "estrénuo",
    "estrénuas": "estrénuo",
    "estrénuos": "estrénuo",
    "estrépitos": "estrépito",
    "estrídula": "estrídulo",
    "estrídulas": "estrídulo",
    "estrídulos": "estrídulo",
    "estrígidas": "estrígida",
    "estróbilos": "estróbilo",
    "estrófica": "estrófico",
    "estróficas": "estrófico",
    "estróficos": "estrófico",
    "estrógenos": "estrógeno",
    "estróinas": "estróina",
    "estrôncios": "estrôncio",
    "esttroboscópica": "esttroboscópico",
    "esttroboscópicas": "esttroboscópico",
    "esttroboscópicos": "esttroboscópico",
    "estua": "estuar",
    "estuada": "estuar",
    "estuadas": "estuar",
    "estuado": "estuar",
    "estuados": "estuar",
    "estuai": "estuar",
    "estuais": "estuar",
    "estuam": "estuar",
    "estuamo": "estuar",
    "estuamos": "estuar",
    "estuando": "estuar",
    "estuantes": "estuante",
    "estuara": "estuar",
    "estuaram": "estuar",
    "estuaras": "estuar",
    "estuardes": "estuar",
    "estuarei": "estuar",
    "estuareis": "estuar",
    "estuarem": "estuar",
    "estuaremos": "estuar",
    "estuares": "estuar",
    "estuaria": "estuar",
    "estuariam": "estuar",
    "estuarias": "estuar",
    "estuarmo": "estuar",
    "estuarmos": "estuar",
    "estuará": "estuar",
    "estuarás": "estuar",
    "estuarão": "estuar",
    "estuaríamos": "estuar",
    "estuaríeis": "estuar",
    "estuas": "estuar",
    "estuasse": "estuar",
    "estuassem": "estuar",
    "estuasses": "estuar",
    "estuaste": "estuar",
    "estuastes": "estuar",
    "estuava": "estuar",
    "estuavam": "estuar",
    "estuavas": "estuar",
    "estuações": "estuação",
    "estuca": "estucar",
    "estucada": "estucar",
    "estucadas": "estucar",
    "estucado": "estucar",
    "estucadora": "estucador",
    "estucadoras": "estucador",
    "estucadores": "estucador",
    "estucados": "estucar",
    "estucagens": "estucagem",
    "estucai": "estucar",
    "estucais": "estucar",
    "estucam": "estucar",
    "estucamo": "estucar",
    "estucamos": "estucar",
    "estucando": "estucar",
    "estucara": "estucar",
    "estucaram": "estucar",
    "estucaras": "estucar",
    "estucarde": "estucar",
    "estucardes": "estucar",
    "estucare": "estucar",
    "estucarei": "estucar",
    "estucareis": "estucar",
    "estucarem": "estucar",
    "estucaremos": "estucar",
    "estucares": "estucar",
    "estucaria": "estucar",
    "estucariam": "estucar",
    "estucarias": "estucar",
    "estucarmo": "estucar",
    "estucarmos": "estucar",
    "estucará": "estucar",
    "estucarás": "estucar",
    "estucarão": "estucar",
    "estucaríamos": "estucar",
    "estucaríeis": "estucar",
    "estucas": "estucar",
    "estucasse": "estucar",
    "estucassem": "estucar",
    "estucasses": "estucar",
    "estucaste": "estucar",
    "estucastes": "estucar",
    "estucava": "estucar",
    "estucavam": "estucar",
    "estucavas": "estucar",
    "estucha": "estuchar",
    "estuchada": "estuchar",
    "estuchadas": "estuchar",
    "estuchado": "estuchar",
    "estuchados": "estuchar",
    "estuchai": "estuchar",
    "estuchais": "estuchar",
    "estucham": "estuchar",
    "estuchamo": "estuchar",
    "estuchamos": "estuchar",
    "estuchando": "estuchar",
    "estuchara": "estuchar",
    "estucharam": "estuchar",
    "estucharas": "estuchar",
    "estucharde": "estuchar",
    "estuchardes": "estuchar",
    "estuchare": "estuchar",
    "estucharei": "estuchar",
    "estuchareis": "estuchar",
    "estucharem": "estuchar",
    "estucharemos": "estuchar",
    "estuchares": "estuchar",
    "estucharia": "estuchar",
    "estuchariam": "estuchar",
    "estucharias": "estuchar",
    "estucharmo": "estuchar",
    "estucharmos": "estuchar",
    "estuchará": "estuchar",
    "estucharás": "estuchar",
    "estucharão": "estuchar",
    "estucharíamos": "estuchar",
    "estucharíeis": "estuchar",
    "estuchas": "estuchar",
    "estuchasse": "estuchar",
    "estuchassem": "estuchar",
    "estuchasses": "estuchar",
    "estuchaste": "estuchar",
    "estuchastes": "estuchar",
    "estuchava": "estuchar",
    "estuchavam": "estuchar",
    "estuchavas": "estuchar",
    "estuche": "estuchar",
    "estuchei": "estuchar",
    "estucheis": "estuchar",
    "estuchem": "estuchar",
    "estuchemo": "estuchar",
    "estuchemos": "estuchar",
    "estuches": "estuche",
    "estucho": "estuchar",
    "estuchou": "estuchar",
    "estuchá": "estuchar",
    "estuchámo": "estuchar",
    "estuchámos": "estuchar",
    "estucháramo": "estuchar",
    "estucháramos": "estuchar",
    "estuchárei": "estuchar",
    "estucháreis": "estuchar",
    "estuchásseis": "estuchar",
    "estuchássemos": "estuchar",
    "estuchávamo": "estuchar",
    "estuchávamos": "estuchar",
    "estuchávei": "estuchar",
    "estucháveis": "estuchar",
    "estuco": "estucar",
    "estucou": "estucar",
    "estucá": "estucar",
    "estucámo": "estucar",
    "estucámos": "estucar",
    "estucáramo": "estucar",
    "estucáramos": "estucar",
    "estucárei": "estucar",
    "estucáreis": "estucar",
    "estucásseis": "estucar",
    "estucássemos": "estucar",
    "estucávamo": "estucar",
    "estucávamos": "estucar",
    "estucávei": "estucar",
    "estucáveis": "estucar",
    "estuda": "estudar",
    "estudada": "estudar",
    "estudadas": "estudar",
    "estudado": "estudar",
    "estudados": "estudar",
    "estudai": "estudar",
    "estudais": "estudar",
    "estudam": "estudar",
    "estudamo": "estudar",
    "estudamos": "estudar",
    "estudando": "estudar",
    "estudantadas": "estudantada",
    "estudantados": "estudantado",
    "estudantaços": "estudantaço",
    "estudanteca": "estudanteco",
    "estudantecas": "estudanteco",
    "estudantecos": "estudanteco",
    "estudantes": "estudante",
    "estudantesca": "estudantesco",
    "estudantescas": "estudantesco",
    "estudantescos": "estudantesco",
    "estudantinas": "estudantina",
    "estudantis": "estudantil",
    "estudantória": "estudantório",
    "estudantórias": "estudantório",
    "estudantórios": "estudantório",
    "estudara": "estudar",
    "estudaram": "estudar",
    "estudaras": "estudar",
    "estudarde": "estudar",
    "estudardes": "estudar",
    "estudare": "estudar",
    "estudarei": "estudar",
    "estudareis": "estudar",
    "estudarem": "estudar",
    "estudaremos": "estudar",
    "estudares": "estudar",
    "estudaria": "estudar",
    "estudariam": "estudar",
    "estudarias": "estudar",
    "estudarmo": "estudar",
    "estudarmos": "estudar",
    "estudará": "estudar",
    "estudarás": "estudar",
    "estudarão": "estudar",
    "estudaríamos": "estudar",
    "estudaríeis": "estudar",
    "estudas": "estudar",
    "estudasse": "estudar",
    "estudassem": "estudar",
    "estudasses": "estudar",
    "estudaste": "estudar",
    "estudastes": "estudar",
    "estudava": "estudar",
    "estudavam": "estudar",
    "estudavas": "estudar",
    "estude": "estudar",
    "estudei": "estudar",
    "estudeis": "estudar",
    "estudem": "estudar",
    "estudemo": "estudar",
    "estudemos": "estudar",
    "estudes": "estudar",
    "estudiosa": "estudioso",
    "estudiosas": "estudioso",
    "estudiosidades": "estudiosidade",
    "estudiosos": "estudioso",
    "estudo": "estudar",
    "estudos": "estudo",
    "estudou": "estudar",
    "estudá": "estudar",
    "estudámo": "estudar",
    "estudámos": "estudar",
    "estudáramo": "estudar",
    "estudáramos": "estudar",
    "estudárei": "estudar",
    "estudáreis": "estudar",
    "estudásseis": "estudar",
    "estudássemos": "estudar",
    "estudávamo": "estudar",
    "estudávamos": "estudar",
    "estudávei": "estudar",
    "estudáveis": "estudar",
    "estue": "estuar",
    "estuei": "estuar",
    "estueis": "estuar",
    "estuem": "estuar",
    "estuemo": "estuar",
    "estuemos": "estuar",
    "estues": "estuar",
    "estufa": "estufar",
    "estufada": "estufar",
    "estufadas": "estufar",
    "estufadeiras": "estufadeira",
    "estufado": "estufar",
    "estufados": "estufar",
    "estufagens": "estufagem",
    "estufai": "estufar",
    "estufais": "estufar",
    "estufam": "estufar",
    "estufamo": "estufar",
    "estufamos": "estufar",
    "estufando": "estufar",
    "estufara": "estufar",
    "estufaram": "estufar",
    "estufaras": "estufar",
    "estufarde": "estufar",
    "estufardes": "estufar",
    "estufare": "estufar",
    "estufarei": "estufar",
    "estufareis": "estufar",
    "estufarem": "estufar",
    "estufaremos": "estufar",
    "estufares": "estufar",
    "estufaria": "estufar",
    "estufariam": "estufar",
    "estufarias": "estufar",
    "estufarmo": "estufar",
    "estufarmos": "estufar",
    "estufará": "estufar",
    "estufarás": "estufar",
    "estufarão": "estufar",
    "estufaríamos": "estufar",
    "estufaríeis": "estufar",
    "estufas": "estufar",
    "estufasse": "estufar",
    "estufassem": "estufar",
    "estufasses": "estufar",
    "estufaste": "estufar",
    "estufastes": "estufar",
    "estufava": "estufar",
    "estufavam": "estufar",
    "estufavas": "estufar",
    "estufe": "estufar",
    "estufei": "estufar",
    "estufeiros": "estufeiro",
    "estufeis": "estufar",
    "estufem": "estufar",
    "estufemo": "estufar",
    "estufemos": "estufar",
    "estufes": "estufar",
    "estufilhas": "estufilha",
    "estufins": "estufim",
    "estufo": "estufar",
    "estufou": "estufar",
    "estufá": "estufar",
    "estufámo": "estufar",
    "estufámos": "estufar",
    "estufáramo": "estufar",
    "estufáramos": "estufar",
    "estufárei": "estufar",
    "estufáreis": "estufar",
    "estufásseis": "estufar",
    "estufássemos": "estufar",
    "estufávamo": "estufar",
    "estufávamos": "estufar",
    "estufávei": "estufar",
    "estufáveis": "estufar",
    "estuga": "estugar",
    "estugada": "estugar",
    "estugadas": "estugar",
    "estugado": "estugar",
    "estugados": "estugar",
    "estugai": "estugar",
    "estugais": "estugar",
    "estugam": "estugar",
    "estugamo": "estugar",
    "estugamos": "estugar",
    "estugando": "estugar",
    "estugara": "estugar",
    "estugaram": "estugar",
    "estugaras": "estugar",
    "estugarde": "estugar",
    "estugardes": "estugar",
    "estugare": "estugar",
    "estugarei": "estugar",
    "estugareis": "estugar",
    "estugarem": "estugar",
    "estugaremos": "estugar",
    "estugares": "estugar",
    "estugaria": "estugar",
    "estugariam": "estugar",
    "estugarias": "estugar",
    "estugarmo": "estugar",
    "estugarmos": "estugar",
    "estugará": "estugar",
    "estugarás": "estugar",
    "estugarão": "estugar",
    "estugaríamos": "estugar",
    "estugaríeis": "estugar",
    "estugas": "estugar",
    "estugasse": "estugar",
    "estugassem": "estugar",
    "estugasses": "estugar",
    "estugaste": "estugar",
    "estugastes": "estugar",
    "estugava": "estugar",
    "estugavam": "estugar",
    "estugavas": "estugar",
    "estugo": "estugar",
    "estugou": "estugar",
    "estugue": "estugar",
    "estuguei": "estugar",
    "estugueis": "estugar",
    "estuguem": "estugar",
    "estuguemo": "estugar",
    "estuguemos": "estugar",
    "estugues": "estugar",
    "estugá": "estugar",
    "estugámo": "estugar",
    "estugámos": "estugar",
    "estugáramo": "estugar",
    "estugáramos": "estugar",
    "estugárei": "estugar",
    "estugáreis": "estugar",
    "estugásseis": "estugar",
    "estugássemos": "estugar",
    "estugávamo": "estugar",
    "estugávamos": "estugar",
    "estugávei": "estugar",
    "estugáveis": "estugar",
    "estulta": "estulto",
    "estultas": "estulto",
    "estultices": "estultice",
    "estultifica": "estultificar",
    "estultificada": "estultificar",
    "estultificadas": "estultificar",
    "estultificado": "estultificar",
    "estultificados": "estultificar",
    "estultificai": "estultificar",
    "estultificais": "estultificar",
    "estultificam": "estultificar",
    "estultificamo": "estultificar",
    "estultificamos": "estultificar",
    "estultificando": "estultificar",
    "estultificara": "estultificar",
    "estultificaram": "estultificar",
    "estultificaras": "estultificar",
    "estultificarde": "estultificar",
    "estultificardes": "estultificar",
    "estultificare": "estultificar",
    "estultificarei": "estultificar",
    "estultificareis": "estultificar",
    "estultificarem": "estultificar",
    "estultificaremos": "estultificar",
    "estultificares": "estultificar",
    "estultificaria": "estultificar",
    "estultificariam": "estultificar",
    "estultificarias": "estultificar",
    "estultificarmo": "estultificar",
    "estultificarmos": "estultificar",
    "estultificará": "estultificar",
    "estultificarás": "estultificar",
    "estultificarão": "estultificar",
    "estultificaríamos": "estultificar",
    "estultificaríeis": "estultificar",
    "estultificas": "estultificar",
    "estultificasse": "estultificar",
    "estultificassem": "estultificar",
    "estultificasses": "estultificar",
    "estultificaste": "estultificar",
    "estultificastes": "estultificar",
    "estultificava": "estultificar",
    "estultificavam": "estultificar",
    "estultificavas": "estultificar",
    "estultificações": "estultificação",
    "estultifico": "estultificar",
    "estultificou": "estultificar",
    "estultificá": "estultificar",
    "estultificámo": "estultificar",
    "estultificámos": "estultificar",
    "estultificáramo": "estultificar",
    "estultificáramos": "estultificar",
    "estultificárei": "estultificar",
    "estultificáreis": "estultificar",
    "estultificásseis": "estultificar",
    "estultificássemos": "estultificar",
    "estultificávamo": "estultificar",
    "estultificávamos": "estultificar",
    "estultificávei": "estultificar",
    "estultificáveis": "estultificar",
    "estultifique": "estultificar",
    "estultifiquei": "estultificar",
    "estultifiqueis": "estultificar",
    "estultifiquem": "estultificar",
    "estultifiquemo": "estultificar",
    "estultifiquemos": "estultificar",
    "estultifiques": "estultificar",
    "estultilóquios": "estultilóquio",
    "estultos": "estulto",
    "estultícias": "estultícia",
    "estuo": "estuar",
    "estuosa": "estuoso",
    "estuosas": "estuoso",
    "estuosos": "estuoso",
    "estuou": "estuar",
    "estupefacientes": "estupefaciente",
    "estupefacta": "estupefacto",
    "estupefactas": "estupefacto",
    "estupefactiva": "estupefactivo",
    "estupefactivas": "estupefactivo",
    "estupefactivos": "estupefactivo",
    "estupefactos": "estupefacto",
    "estupefacções": "estupefacção",
    "estupefarei": "estupefazer",
    "estupefareis": "estupefazer",
    "estupefaremos": "estupefazer",
    "estupefaria": "estupefazer",
    "estupefariam": "estupefazer",
    "estupefarias": "estupefazer",
    "estupefará": "estupefazer",
    "estupefarás": "estupefazer",
    "estupefarão": "estupefazer",
    "estupefaríamos": "estupefazer",
    "estupefaríeis": "estupefazer",
    "estupefaz": "estupefazer",
    "estupefaze": "estupefazer",
    "estupefazei": "estupefazer",
    "estupefazeis": "estupefazer",
    "estupefazem": "estupefazer",
    "estupefazemo": "estupefazer",
    "estupefazemos": "estupefazer",
    "estupefazendo": "estupefazer",
    "estupefazerde": "estupefazer",
    "estupefazerdes": "estupefazer",
    "estupefazere": "estupefazer",
    "estupefazerem": "estupefazer",
    "estupefazeres": "estupefazer",
    "estupefazermo": "estupefazer",
    "estupefazermos": "estupefazer",
    "estupefazes": "estupefazer",
    "estupefazia": "estupefazer",
    "estupefaziam": "estupefazer",
    "estupefazias": "estupefazer",
    "estupefazê": "estupefazer",
    "estupefazíamo": "estupefazer",
    "estupefazíamos": "estupefazer",
    "estupefazíei": "estupefazer",
    "estupefazíeis": "estupefazer",
    "estupefaça": "estupefazer",
    "estupefaçais": "estupefazer",
    "estupefaçam": "estupefazer",
    "estupefaçamo": "estupefazer",
    "estupefaçamos": "estupefazer",
    "estupefaças": "estupefazer",
    "estupefaço": "estupefazer",
    "estupefeita": "estupefazer",
    "estupefeitas": "estupefazer",
    "estupefeito": "estupefazer",
    "estupefeitos": "estupefazer",
    "estupefez": "estupefazer",
    "estupefi": "estupefazer",
    "estupefica": "estupeficar",
    "estupeficada": "estupeficar",
    "estupeficadas": "estupeficar",
    "estupeficado": "estupeficar",
    "estupeficados": "estupeficar",
    "estupeficai": "estupeficar",
    "estupeficais": "estupeficar",
    "estupeficam": "estupeficar",
    "estupeficamo": "estupeficar",
    "estupeficamos": "estupeficar",
    "estupeficando": "estupeficar",
    "estupeficara": "estupeficar",
    "estupeficaram": "estupeficar",
    "estupeficaras": "estupeficar",
    "estupeficarde": "estupeficar",
    "estupeficardes": "estupeficar",
    "estupeficare": "estupeficar",
    "estupeficarei": "estupeficar",
    "estupeficareis": "estupeficar",
    "estupeficarem": "estupeficar",
    "estupeficaremos": "estupeficar",
    "estupeficares": "estupeficar",
    "estupeficaria": "estupeficar",
    "estupeficariam": "estupeficar",
    "estupeficarias": "estupeficar",
    "estupeficarmo": "estupeficar",
    "estupeficarmos": "estupeficar",
    "estupeficará": "estupeficar",
    "estupeficarás": "estupeficar",
    "estupeficarão": "estupeficar",
    "estupeficaríamos": "estupeficar",
    "estupeficaríeis": "estupeficar",
    "estupeficas": "estupeficar",
    "estupeficasse": "estupeficar",
    "estupeficassem": "estupeficar",
    "estupeficasses": "estupeficar",
    "estupeficaste": "estupeficar",
    "estupeficastes": "estupeficar",
    "estupeficava": "estupeficar",
    "estupeficavam": "estupeficar",
    "estupeficavas": "estupeficar",
    "estupefico": "estupeficar",
    "estupeficou": "estupeficar",
    "estupeficá": "estupeficar",
    "estupeficámo": "estupeficar",
    "estupeficámos": "estupeficar",
    "estupeficáramo": "estupeficar",
    "estupeficáramos": "estupeficar",
    "estupeficárei": "estupeficar",
    "estupeficáreis": "estupeficar",
    "estupeficásseis": "estupeficar",
    "estupeficássemos": "estupeficar",
    "estupeficávamo": "estupeficar",
    "estupeficávamos": "estupeficar",
    "estupeficávei": "estupeficar",
    "estupeficáveis": "estupeficar",
    "estupefique": "estupeficar",
    "estupefiquei": "estupeficar",
    "estupefiqueis": "estupeficar",
    "estupefiquem": "estupeficar",
    "estupefiquemo": "estupeficar",
    "estupefiquemos": "estupeficar",
    "estupefiques": "estupeficar",
    "estupefiz": "estupefazer",
    "estupefizemo": "estupefazer",
    "estupefizemos": "estupefazer",
    "estupefizer": "estupefazer",
    "estupefizera": "estupefazer",
    "estupefizeram": "estupefazer",
    "estupefizeras": "estupefazer",
    "estupefizerdes": "estupefazer",
    "estupefizerem": "estupefazer",
    "estupefizeres": "estupefazer",
    "estupefizermos": "estupefazer",
    "estupefizesse": "estupefazer",
    "estupefizessem": "estupefazer",
    "estupefizesses": "estupefazer",
    "estupefizeste": "estupefazer",
    "estupefizestes": "estupefazer",
    "estupefizéramo": "estupefazer",
    "estupefizéramos": "estupefazer",
    "estupefizérei": "estupefazer",
    "estupefizéreis": "estupefazer",
    "estupefizésseis": "estupefazer",
    "estupefizéssemos": "estupefazer",
    "estupefá": "estupefazer",
    "estupefê": "estupefazer",
    "estupenda": "estupendo",
    "estupendas": "estupendo",
    "estupendos": "estupendo",
    "estupidarrona": "estupidarrão",
    "estupidarronas": "estupidarrão",
    "estupidarrões": "estupidarrão",
    "estupidece": "estupidecer",
    "estupidecei": "estupidecer",
    "estupideceis": "estupidecer",
    "estupidecem": "estupidecer",
    "estupidecemo": "estupidecer",
    "estupidecemos": "estupidecer",
    "estupidecendo": "estupidecer",
    "estupidecera": "estupidecer",
    "estupideceram": "estupidecer",
    "estupideceras": "estupidecer",
    "estupidecerde": "estupidecer",
    "estupidecerdes": "estupidecer",
    "estupidecere": "estupidecer",
    "estupidecerei": "estupidecer",
    "estupidecereis": "estupidecer",
    "estupidecerem": "estupidecer",
    "estupideceremos": "estupidecer",
    "estupideceres": "estupidecer",
    "estupideceria": "estupidecer",
    "estupideceriam": "estupidecer",
    "estupidecerias": "estupidecer",
    "estupidecermo": "estupidecer",
    "estupidecermos": "estupidecer",
    "estupidecerá": "estupidecer",
    "estupidecerás": "estupidecer",
    "estupidecerão": "estupidecer",
    "estupideceríamos": "estupidecer",
    "estupideceríeis": "estupidecer",
    "estupideces": "estupidecer",
    "estupidecesse": "estupidecer",
    "estupidecessem": "estupidecer",
    "estupidecesses": "estupidecer",
    "estupideceste": "estupidecer",
    "estupidecestes": "estupidecer",
    "estupideceu": "estupidecer",
    "estupideci": "estupidecer",
    "estupidecia": "estupidecer",
    "estupideciam": "estupidecer",
    "estupidecias": "estupidecer",
    "estupidecida": "estupidecer",
    "estupidecidas": "estupidecer",
    "estupidecido": "estupidecer",
    "estupidecidos": "estupidecer",
    "estupidecê": "estupidecer",
    "estupidecêramo": "estupidecer",
    "estupidecêramos": "estupidecer",
    "estupidecêrei": "estupidecer",
    "estupidecêreis": "estupidecer",
    "estupidecêsseis": "estupidecer",
    "estupidecêssemos": "estupidecer",
    "estupidecíamo": "estupidecer",
    "estupidecíamos": "estupidecer",
    "estupidecíei": "estupidecer",
    "estupidecíeis": "estupidecer",
    "estupidezes": "estupidez",
    "estupideça": "estupidecer",
    "estupideçais": "estupidecer",
    "estupideçam": "estupidecer",
    "estupideçamo": "estupidecer",
    "estupideçamos": "estupidecer",
    "estupideças": "estupidecer",
    "estupideço": "estupidecer",
    "estupidifica": "estupidificar",
    "estupidificada": "estupidificar",
    "estupidificadas": "estupidificar",
    "estupidificado": "estupidificar",
    "estupidificados": "estupidificar",
    "estupidificai": "estupidificar",
    "estupidificais": "estupidificar",
    "estupidificam": "estupidificar",
    "estupidificamo": "estupidificar",
    "estupidificamos": "estupidificar",
    "estupidificando": "estupidificar",
    "estupidificantes": "estupidificante",
    "estupidificara": "estupidificar",
    "estupidificaram": "estupidificar",
    "estupidificaras": "estupidificar",
    "estupidificarde": "estupidificar",
    "estupidificardes": "estupidificar",
    "estupidificare": "estupidificar",
    "estupidificarei": "estupidificar",
    "estupidificareis": "estupidificar",
    "estupidificarem": "estupidificar",
    "estupidificaremos": "estupidificar",
    "estupidificares": "estupidificar",
    "estupidificaria": "estupidificar",
    "estupidificariam": "estupidificar",
    "estupidificarias": "estupidificar",
    "estupidificarmo": "estupidificar",
    "estupidificarmos": "estupidificar",
    "estupidificará": "estupidificar",
    "estupidificarás": "estupidificar",
    "estupidificarão": "estupidificar",
    "estupidificaríamos": "estupidificar",
    "estupidificaríeis": "estupidificar",
    "estupidificas": "estupidificar",
    "estupidificasse": "estupidificar",
    "estupidificassem": "estupidificar",
    "estupidificasses": "estupidificar",
    "estupidificaste": "estupidificar",
    "estupidificastes": "estupidificar",
    "estupidificava": "estupidificar",
    "estupidificavam": "estupidificar",
    "estupidificavas": "estupidificar",
    "estupidifico": "estupidificar",
    "estupidificou": "estupidificar",
    "estupidificá": "estupidificar",
    "estupidificámo": "estupidificar",
    "estupidificámos": "estupidificar",
    "estupidificáramo": "estupidificar",
    "estupidificáramos": "estupidificar",
    "estupidificárei": "estupidificar",
    "estupidificáreis": "estupidificar",
    "estupidificásseis": "estupidificar",
    "estupidificássemos": "estupidificar",
    "estupidificávamo": "estupidificar",
    "estupidificávamos": "estupidificar",
    "estupidificávei": "estupidificar",
    "estupidificáveis": "estupidificar",
    "estupidifique": "estupidificar",
    "estupidifiquei": "estupidificar",
    "estupidifiqueis": "estupidificar",
    "estupidifiquem": "estupidificar",
    "estupidifiquemo": "estupidificar",
    "estupidifiquemos": "estupidificar",
    "estupidifiques": "estupidificar",
    "estupora": "estuporar",
    "estuporada": "estuporar",
    "estuporadas": "estuporar",
    "estuporado": "estuporar",
    "estuporados": "estuporar",
    "estuporai": "estuporar",
    "estuporais": "estuporar",
    "estuporam": "estuporar",
    "estuporamo": "estuporar",
    "estuporamos": "estuporar",
    "estuporando": "estuporar",
    "estuporara": "estuporar",
    "estuporaram": "estuporar",
    "estuporaras": "estuporar",
    "estuporarde": "estuporar",
    "estuporardes": "estuporar",
    "estuporare": "estuporar",
    "estuporarei": "estuporar",
    "estuporareis": "estuporar",
    "estuporarem": "estuporar",
    "estuporaremos": "estuporar",
    "estuporares": "estuporar",
    "estuporaria": "estuporar",
    "estuporariam": "estuporar",
    "estuporarias": "estuporar",
    "estuporarmo": "estuporar",
    "estuporarmos": "estuporar",
    "estuporará": "estuporar",
    "estuporarás": "estuporar",
    "estuporarão": "estuporar",
    "estuporaríamos": "estuporar",
    "estuporaríeis": "estuporar",
    "estuporas": "estuporar",
    "estuporasse": "estuporar",
    "estuporassem": "estuporar",
    "estuporasses": "estuporar",
    "estuporaste": "estuporar",
    "estuporastes": "estuporar",
    "estuporava": "estuporar",
    "estuporavam": "estuporar",
    "estuporavas": "estuporar",
    "estupore": "estuporar",
    "estuporei": "estuporar",
    "estuporeis": "estuporar",
    "estuporem": "estuporar",
    "estuporemo": "estuporar",
    "estuporemos": "estuporar",
    "estupores": "estuporar",
    "estuporo": "estuporar",
    "estuporosa": "estuporoso",
    "estuporosas": "estuporoso",
    "estuporosos": "estuporoso",
    "estuporou": "estuporar",
    "estuporá": "estuporar",
    "estuporámo": "estuporar",
    "estuporámos": "estuporar",
    "estuporáramo": "estuporar",
    "estuporáramos": "estuporar",
    "estuporárei": "estuporar",
    "estuporáreis": "estuporar",
    "estuporásseis": "estuporar",
    "estuporássemos": "estuporar",
    "estuporávamo": "estuporar",
    "estuporávamos": "estuporar",
    "estuporávei": "estuporar",
    "estuporáveis": "estuporar",
    "estupra": "estuprar",
    "estuprada": "estuprar",
    "estupradas": "estuprar",
    "estuprado": "estuprar",
    "estuprados": "estuprar",
    "estuprai": "estuprar",
    "estuprais": "estuprar",
    "estupram": "estuprar",
    "estupramo": "estuprar",
    "estupramos": "estuprar",
    "estuprando": "estuprar",
    "estuprara": "estuprar",
    "estupraram": "estuprar",
    "estupraras": "estuprar",
    "estuprarde": "estuprar",
    "estuprardes": "estuprar",
    "estuprare": "estuprar",
    "estuprarei": "estuprar",
    "estuprareis": "estuprar",
    "estuprarem": "estuprar",
    "estupraremos": "estuprar",
    "estuprares": "estuprar",
    "estupraria": "estuprar",
    "estuprariam": "estuprar",
    "estuprarias": "estuprar",
    "estuprarmo": "estuprar",
    "estuprarmos": "estuprar",
    "estuprará": "estuprar",
    "estuprarás": "estuprar",
    "estuprarão": "estuprar",
    "estupraríamos": "estuprar",
    "estupraríeis": "estuprar",
    "estupras": "estuprar",
    "estuprasse": "estuprar",
    "estuprassem": "estuprar",
    "estuprasses": "estuprar",
    "estupraste": "estuprar",
    "estuprastes": "estuprar",
    "estuprava": "estuprar",
    "estupravam": "estuprar",
    "estupravas": "estuprar",
    "estupre": "estuprar",
    "estuprei": "estuprar",
    "estupreis": "estuprar",
    "estuprem": "estuprar",
    "estupremo": "estuprar",
    "estupremos": "estuprar",
    "estupres": "estuprar",
    "estupro": "estuprar",
    "estupros": "estupro",
    "estuprou": "estuprar",
    "estuprá": "estuprar",
    "estuprámo": "estuprar",
    "estuprámos": "estuprar",
    "estupráramo": "estuprar",
    "estupráramos": "estuprar",
    "estuprárei": "estuprar",
    "estupráreis": "estuprar",
    "estuprásseis": "estuprar",
    "estuprássemos": "estuprar",
    "estuprávamo": "estuprar",
    "estuprávamos": "estuprar",
    "estuprávei": "estuprar",
    "estupráveis": "estuprar",
    "estuque": "estucar",
    "estuquei": "estucar",
    "estuqueis": "estucar",
    "estuquem": "estucar",
    "estuquemo": "estucar",
    "estuquemos": "estucar",
    "estuques": "estuque",
    "estuquias": "estuquia",
    "esturdia": "esturdiar",
    "esturdiada": "esturdiar",
    "esturdiadas": "esturdiar",
    "esturdiado": "esturdiar",
    "esturdiados": "esturdiar",
    "esturdiai": "esturdiar",
    "esturdiais": "esturdiar",
    "esturdiam": "esturdiar",
    "esturdiamo": "esturdiar",
    "esturdiamos": "esturdiar",
    "esturdiando": "esturdiar",
    "esturdiara": "esturdiar",
    "esturdiaram": "esturdiar",
    "esturdiaras": "esturdiar",
    "esturdiardes": "esturdiar",
    "esturdiarei": "esturdiar",
    "esturdiareis": "esturdiar",
    "esturdiarem": "esturdiar",
    "esturdiaremos": "esturdiar",
    "esturdiares": "esturdiar",
    "esturdiaria": "esturdiar",
    "esturdiariam": "esturdiar",
    "esturdiarias": "esturdiar",
    "esturdiarmo": "esturdiar",
    "esturdiarmos": "esturdiar",
    "esturdiará": "esturdiar",
    "esturdiarás": "esturdiar",
    "esturdiarão": "esturdiar",
    "esturdiaríamos": "esturdiar",
    "esturdiaríeis": "esturdiar",
    "esturdias": "esturdiar",
    "esturdiasse": "esturdiar",
    "esturdiassem": "esturdiar",
    "esturdiasses": "esturdiar",
    "esturdiaste": "esturdiar",
    "esturdiastes": "esturdiar",
    "esturdiava": "esturdiar",
    "esturdiavam": "esturdiar",
    "esturdiavas": "esturdiar",
    "esturdie": "esturdiar",
    "esturdiei": "esturdiar",
    "esturdieis": "esturdiar",
    "esturdiem": "esturdiar",
    "esturdiemo": "esturdiar",
    "esturdiemos": "esturdiar",
    "esturdies": "esturdiar",
    "esturdio": "esturdiar",
    "esturdiou": "esturdiar",
    "esturdiámo": "esturdiar",
    "esturdiámos": "esturdiar",
    "esturdiáramo": "esturdiar",
    "esturdiáramos": "esturdiar",
    "esturdiáreis": "esturdiar",
    "esturdiásseis": "esturdiar",
    "esturdiássemos": "esturdiar",
    "esturdiávamo": "esturdiar",
    "esturdiávamos": "esturdiar",
    "esturdiáveis": "esturdiar",
    "esturdídia": "esturdídio",
    "esturdídias": "esturdídio",
    "esturdídios": "esturdídio",
    "esturgiões": "esturgião",
    "esturiões": "esturião",
    "esturjões": "esturjão",
    "esturnídeos": "esturnídeo",
    "esturra": "esturrar",
    "esturrada": "esturrar",
    "esturradas": "esturrar",
    "esturrado": "esturrar",
    "esturrados": "esturrar",
    "esturrai": "esturrar",
    "esturrais": "esturrar",
    "esturram": "esturrar",
    "esturramo": "esturrar",
    "esturramos": "esturrar",
    "esturrando": "esturrar",
    "esturrara": "esturrar",
    "esturraram": "esturrar",
    "esturraras": "esturrar",
    "esturrarde": "esturrar",
    "esturrardes": "esturrar",
    "esturrare": "esturrar",
    "esturrarei": "esturrar",
    "esturrareis": "esturrar",
    "esturrarem": "esturrar",
    "esturraremos": "esturrar",
    "esturrares": "esturrar",
    "esturraria": "esturrar",
    "esturrariam": "esturrar",
    "esturrarias": "esturrar",
    "esturrarmo": "esturrar",
    "esturrarmos": "esturrar",
    "esturrará": "esturrar",
    "esturrarás": "esturrar",
    "esturrarão": "esturrar",
    "esturraríamos": "esturrar",
    "esturraríeis": "esturrar",
    "esturras": "esturrar",
    "esturrasse": "esturrar",
    "esturrassem": "esturrar",
    "esturrasses": "esturrar",
    "esturraste": "esturrar",
    "esturrastes": "esturrar",
    "esturrava": "esturrar",
    "esturravam": "esturrar",
    "esturravas": "esturrar",
    "esturre": "esturrar",
    "esturrei": "esturrar",
    "esturreis": "esturrar",
    "esturrem": "esturrar",
    "esturremo": "esturrar",
    "esturremos": "esturrar",
    "esturres": "esturrar",
    "esturrica": "esturricar",
    "esturricada": "esturricar",
    "esturricadas": "esturricar",
    "esturricado": "esturricar",
    "esturricados": "esturricar",
    "esturricai": "esturricar",
    "esturricais": "esturricar",
    "esturricam": "esturricar",
    "esturricamo": "esturricar",
    "esturricamos": "esturricar",
    "esturricando": "esturricar",
    "esturricara": "esturricar",
    "esturricaram": "esturricar",
    "esturricaras": "esturricar",
    "esturricarde": "esturricar",
    "esturricardes": "esturricar",
    "esturricare": "esturricar",
    "esturricarei": "esturricar",
    "esturricareis": "esturricar",
    "esturricarem": "esturricar",
    "esturricaremos": "esturricar",
    "esturricares": "esturricar",
    "esturricaria": "esturricar",
    "esturricariam": "esturricar",
    "esturricarias": "esturricar",
    "esturricarmo": "esturricar",
    "esturricarmos": "esturricar",
    "esturricará": "esturricar",
    "esturricarás": "esturricar",
    "esturricarão": "esturricar",
    "esturricaríamos": "esturricar",
    "esturricaríeis": "esturricar",
    "esturricas": "esturricar",
    "esturricasse": "esturricar",
    "esturricassem": "esturricar",
    "esturricasses": "esturricar",
    "esturricaste": "esturricar",
    "esturricastes": "esturricar",
    "esturricava": "esturricar",
    "esturricavam": "esturricar",
    "esturricavas": "esturricar",
    "esturrices": "esturrice",
    "esturrico": "esturricar",
    "esturricou": "esturricar",
    "esturricá": "esturricar",
    "esturricámo": "esturricar",
    "esturricámos": "esturricar",
    "esturricáramo": "esturricar",
    "esturricáramos": "esturricar",
    "esturricárei": "esturricar",
    "esturricáreis": "esturricar",
    "esturricásseis": "esturricar",
    "esturricássemos": "esturricar",
    "esturricávamo": "esturricar",
    "esturricávamos": "esturricar",
    "esturricávei": "esturricar",
    "esturricáveis": "esturricar",
    "esturrinha": "esturrinhar",
    "esturrinhada": "esturrinhar",
    "esturrinhadas": "esturrinhar",
    "esturrinhado": "esturrinhar",
    "esturrinhados": "esturrinhar",
    "esturrinhai": "esturrinhar",
    "esturrinhais": "esturrinhar",
    "esturrinham": "esturrinhar",
    "esturrinhamo": "esturrinhar",
    "esturrinhamos": "esturrinhar",
    "esturrinhando": "esturrinhar",
    "esturrinhara": "esturrinhar",
    "esturrinharam": "esturrinhar",
    "esturrinharas": "esturrinhar",
    "esturrinharde": "esturrinhar",
    "esturrinhardes": "esturrinhar",
    "esturrinhare": "esturrinhar",
    "esturrinharei": "esturrinhar",
    "esturrinhareis": "esturrinhar",
    "esturrinharem": "esturrinhar",
    "esturrinharemos": "esturrinhar",
    "esturrinhares": "esturrinhar",
    "esturrinharia": "esturrinhar",
    "esturrinhariam": "esturrinhar",
    "esturrinharias": "esturrinhar",
    "esturrinharmo": "esturrinhar",
    "esturrinharmos": "esturrinhar",
    "esturrinhará": "esturrinhar",
    "esturrinharás": "esturrinhar",
    "esturrinharão": "esturrinhar",
    "esturrinharíamos": "esturrinhar",
    "esturrinharíeis": "esturrinhar",
    "esturrinhas": "esturrinhar",
    "esturrinhasse": "esturrinhar",
    "esturrinhassem": "esturrinhar",
    "esturrinhasses": "esturrinhar",
    "esturrinhaste": "esturrinhar",
    "esturrinhastes": "esturrinhar",
    "esturrinhava": "esturrinhar",
    "esturrinhavam": "esturrinhar",
    "esturrinhavas": "esturrinhar",
    "esturrinhe": "esturrinhar",
    "esturrinhei": "esturrinhar",
    "esturrinheis": "esturrinhar",
    "esturrinhem": "esturrinhar",
    "esturrinhemo": "esturrinhar",
    "esturrinhemos": "esturrinhar",
    "esturrinhes": "esturrinhar",
    "esturrinho": "esturrinhar",
    "esturrinhos": "esturrinho",
    "esturrinhou": "esturrinhar",
    "esturrinhá": "esturrinhar",
    "esturrinhámo": "esturrinhar",
    "esturrinhámos": "esturrinhar",
    "esturrinháramo": "esturrinhar",
    "esturrinháramos": "esturrinhar",
    "esturrinhárei": "esturrinhar",
    "esturrinháreis": "esturrinhar",
    "esturrinhásseis": "esturrinhar",
    "esturrinhássemos": "esturrinhar",
    "esturrinhávamo": "esturrinhar",
    "esturrinhávamos": "esturrinhar",
    "esturrinhávei": "esturrinhar",
    "esturrinháveis": "esturrinhar",
    "esturrique": "esturricar",
    "esturriquei": "esturricar",
    "esturriqueis": "esturricar",
    "esturriquem": "esturricar",
    "esturriquemo": "esturricar",
    "esturriquemos": "esturricar",
    "esturriques": "esturricar",
    "esturro": "esturrar",
    "esturros": "esturro",
    "esturrou": "esturrar",
    "esturrá": "esturrar",
    "esturrámo": "esturrar",
    "esturrámos": "esturrar",
    "esturráramo": "esturrar",
    "esturráramos": "esturrar",
    "esturrárei": "esturrar",
    "esturráreis": "esturrar",
    "esturrásseis": "esturrar",
    "esturrássemos": "esturrar",
    "esturrávamo": "esturrar",
    "esturrávamos": "esturrar",
    "esturrávei": "esturrar",
    "esturráveis": "esturrar",
    "esturvinhada": "esturvinhado",
    "esturvinhadas": "esturvinhado",
    "esturvinhados": "esturvinhado",
    "estuámo": "estuar",
    "estuámos": "estuar",
    "estuáramo": "estuar",
    "estuáramos": "estuar",
    "estuáreis": "estuar",
    "estuários": "estuário",
    "estuásseis": "estuar",
    "estuássemos": "estuar",
    "estuávamo": "estuar",
    "estuávamos": "estuar",
    "estuáveis": "estuar",
    "está": "estar",
    "estábulos": "estábulo",
    "estádios": "estádio",
    "estágios": "estágio",
    "estáquidas": "estáquida",
    "estás": "estar",
    "estática": "estático",
    "estáticas": "estático",
    "estáticos": "estático",
    "estátuas": "estátua",
    "estávamo": "estar",
    "estávamos": "estar",
    "estáveis": "estável",
    "estâncias": "estância",
    "estânica": "estânico",
    "estânicas": "estânico",
    "estânicos": "estânico",
    "estão": "estar",
    "esténica": "esténico",
    "esténicas": "esténico",
    "esténicos": "esténico",
    "estépica": "estépico",
    "estépicas": "estépico",
    "estépicos": "estépico",
    "estéreis": "estéril",
    "estéreos": "estéreo",
    "estésica": "estésico",
    "estésicas": "estésico",
    "estésicos": "estésico",
    "estética": "estético",
    "estéticas": "estético",
    "estéticos": "estético",
    "estíbios": "estíbio",
    "estímulos": "estímulo",
    "estípites": "estípite",
    "estíptica": "estíptico",
    "estípticas": "estíptico",
    "estípticos": "estíptico",
    "estípulas": "estípula",
    "estíraces": "estírace",
    "estóica": "estóico",
    "estóicas": "estóico",
    "estóicos": "estóico",
    "estólida": "estólido",
    "estólidas": "estólido",
    "estólidos": "estólido",
    "estómatos": "estómato",
    "estónia": "estónio",
    "estónias": "estónio",
    "estónios": "estónio",
    "estórias": "estória",
    "estômagos": "estômago",
    "estúdios": "estúdio",
    "estúpida": "estúpido",
    "estúpidas": "estúpido",
    "estúpidos": "estúpido",
    "estúrdias": "estúrdia",
    "estúrdidas": "estúrdida",
    "estúrnidas": "estúrnida",
    "esurina": "esurino",
    "esurinas": "esurino",
    "esurinos": "esurino",
    "esvaece": "esvaecer",
    "esvaecei": "esvaecer",
    "esvaeceis": "esvaecer",
    "esvaecem": "esvaecer",
    "esvaecemo": "esvaecer",
    "esvaecemos": "esvaecer",
    "esvaecendo": "esvaecer",
    "esvaecera": "esvaecer",
    "esvaeceram": "esvaecer",
    "esvaeceras": "esvaecer",
    "esvaecerde": "esvaecer",
    "esvaecerdes": "esvaecer",
    "esvaecere": "esvaecer",
    "esvaecerei": "esvaecer",
    "esvaecereis": "esvaecer",
    "esvaecerem": "esvaecer",
    "esvaeceremos": "esvaecer",
    "esvaeceres": "esvaecer",
    "esvaeceria": "esvaecer",
    "esvaeceriam": "esvaecer",
    "esvaecerias": "esvaecer",
    "esvaecermo": "esvaecer",
    "esvaecermos": "esvaecer",
    "esvaecerá": "esvaecer",
    "esvaecerás": "esvaecer",
    "esvaecerão": "esvaecer",
    "esvaeceríamos": "esvaecer",
    "esvaeceríeis": "esvaecer",
    "esvaeces": "esvaecer",
    "esvaecesse": "esvaecer",
    "esvaecessem": "esvaecer",
    "esvaecesses": "esvaecer",
    "esvaeceste": "esvaecer",
    "esvaecestes": "esvaecer",
    "esvaeceu": "esvaecer",
    "esvaeci": "esvaecer",
    "esvaecia": "esvaecer",
    "esvaeciam": "esvaecer",
    "esvaecias": "esvaecer",
    "esvaecida": "esvaecido",
    "esvaecidas": "esvaecido",
    "esvaecido": "esvaecer",
    "esvaecidos": "esvaecido",
    "esvaecimentos": "esvaecimento",
    "esvaecê": "esvaecer",
    "esvaecêramo": "esvaecer",
    "esvaecêramos": "esvaecer",
    "esvaecêrei": "esvaecer",
    "esvaecêreis": "esvaecer",
    "esvaecêsseis": "esvaecer",
    "esvaecêssemos": "esvaecer",
    "esvaecíamo": "esvaecer",
    "esvaecíamos": "esvaecer",
    "esvaecíei": "esvaecer",
    "esvaecíeis": "esvaecer",
    "esvaem": "esvair",
    "esvaeça": "esvaecer",
    "esvaeçais": "esvaecer",
    "esvaeçam": "esvaecer",
    "esvaeçamo": "esvaecer",
    "esvaeçamos": "esvaecer",
    "esvaeças": "esvaecer",
    "esvaeço": "esvaecer",
    "esvai": "esvair",
    "esvaia": "esvair",
    "esvaiais": "esvair",
    "esvaiam": "esvair",
    "esvaiamo": "esvair",
    "esvaiamos": "esvair",
    "esvaias": "esvair",
    "esvaimentos": "esvaimento",
    "esvaindo": "esvair",
    "esvaio": "esvair",
    "esvairde": "esvair",
    "esvairdes": "esvair",
    "esvairei": "esvair",
    "esvaireis": "esvair",
    "esvairemos": "esvair",
    "esvairia": "esvair",
    "esvairiam": "esvair",
    "esvairias": "esvair",
    "esvairmo": "esvair",
    "esvairmos": "esvair",
    "esvairá": "esvair",
    "esvairás": "esvair",
    "esvairão": "esvair",
    "esvairíamos": "esvair",
    "esvairíeis": "esvair",
    "esvais": "esvair",
    "esvaiu": "esvair",
    "esvanece": "esvanecer",
    "esvanecei": "esvanecer",
    "esvaneceis": "esvanecer",
    "esvanecem": "esvanecer",
    "esvanecemo": "esvanecer",
    "esvanecemos": "esvanecer",
    "esvanecendo": "esvanecer",
    "esvanecera": "esvanecer",
    "esvaneceram": "esvanecer",
    "esvaneceras": "esvanecer",
    "esvanecerde": "esvanecer",
    "esvanecerdes": "esvanecer",
    "esvanecere": "esvanecer",
    "esvanecerei": "esvanecer",
    "esvanecereis": "esvanecer",
    "esvanecerem": "esvanecer",
    "esvaneceremos": "esvanecer",
    "esvaneceres": "esvanecer",
    "esvaneceria": "esvanecer",
    "esvaneceriam": "esvanecer",
    "esvanecerias": "esvanecer",
    "esvanecermo": "esvanecer",
    "esvanecermos": "esvanecer",
    "esvanecerá": "esvanecer",
    "esvanecerás": "esvanecer",
    "esvanecerão": "esvanecer",
    "esvaneceríamos": "esvanecer",
    "esvaneceríeis": "esvanecer",
    "esvaneces": "esvanecer",
    "esvanecesse": "esvanecer",
    "esvanecessem": "esvanecer",
    "esvanecesses": "esvanecer",
    "esvaneceste": "esvanecer",
    "esvanecestes": "esvanecer",
    "esvaneceu": "esvanecer",
    "esvaneci": "esvanecer",
    "esvanecia": "esvanecer",
    "esvaneciam": "esvanecer",
    "esvanecias": "esvanecer",
    "esvanecida": "esvanecer",
    "esvanecidas": "esvanecer",
    "esvanecido": "esvanecer",
    "esvanecidos": "esvanecer",
    "esvanecimentos": "esvanecimento",
    "esvanecê": "esvanecer",
    "esvanecêramo": "esvanecer",
    "esvanecêramos": "esvanecer",
    "esvanecêrei": "esvanecer",
    "esvanecêreis": "esvanecer",
    "esvanecêsseis": "esvanecer",
    "esvanecêssemos": "esvanecer",
    "esvanecíamo": "esvanecer",
    "esvanecíamos": "esvanecer",
    "esvanecíei": "esvanecer",
    "esvanecíeis": "esvanecer",
    "esvaneça": "esvanecer",
    "esvaneçais": "esvanecer",
    "esvaneçam": "esvanecer",
    "esvaneçamo": "esvanecer",
    "esvaneçamos": "esvanecer",
    "esvaneças": "esvanecer",
    "esvaneço": "esvanecer",
    "esvazia": "esvaziar",
    "esvaziada": "esvaziar",
    "esvaziadas": "esvaziar",
    "esvaziado": "esvaziar",
    "esvaziados": "esvaziar",
    "esvaziai": "esvaziar",
    "esvaziais": "esvaziar",
    "esvaziam": "esvaziar",
    "esvaziamentos": "esvaziamento",
    "esvaziamo": "esvaziar",
    "esvaziamos": "esvaziar",
    "esvaziando": "esvaziar",
    "esvaziara": "esvaziar",
    "esvaziaram": "esvaziar",
    "esvaziaras": "esvaziar",
    "esvaziarde": "esvaziar",
    "esvaziardes": "esvaziar",
    "esvaziare": "esvaziar",
    "esvaziarei": "esvaziar",
    "esvaziareis": "esvaziar",
    "esvaziarem": "esvaziar",
    "esvaziaremos": "esvaziar",
    "esvaziares": "esvaziar",
    "esvaziaria": "esvaziar",
    "esvaziariam": "esvaziar",
    "esvaziarias": "esvaziar",
    "esvaziarmo": "esvaziar",
    "esvaziarmos": "esvaziar",
    "esvaziará": "esvaziar",
    "esvaziarás": "esvaziar",
    "esvaziarão": "esvaziar",
    "esvaziaríamos": "esvaziar",
    "esvaziaríeis": "esvaziar",
    "esvazias": "esvaziar",
    "esvaziasse": "esvaziar",
    "esvaziassem": "esvaziar",
    "esvaziasses": "esvaziar",
    "esvaziaste": "esvaziar",
    "esvaziastes": "esvaziar",
    "esvaziava": "esvaziar",
    "esvaziavam": "esvaziar",
    "esvaziavas": "esvaziar",
    "esvazie": "esvaziar",
    "esvaziei": "esvaziar",
    "esvazieis": "esvaziar",
    "esvaziem": "esvaziar",
    "esvaziemo": "esvaziar",
    "esvaziemos": "esvaziar",
    "esvazies": "esvaziar",
    "esvazio": "esvaziar",
    "esvaziou": "esvaziar",
    "esvaziá": "esvaziar",
    "esvaziámo": "esvaziar",
    "esvaziámos": "esvaziar",
    "esvaziáramo": "esvaziar",
    "esvaziáramos": "esvaziar",
    "esvaziárei": "esvaziar",
    "esvaziáreis": "esvaziar",
    "esvaziásseis": "esvaziar",
    "esvaziássemos": "esvaziar",
    "esvaziávamo": "esvaziar",
    "esvaziávamos": "esvaziar",
    "esvaziávei": "esvaziar",
    "esvaziáveis": "esvaziar",
    "esvaí": "esvair",
    "esvaía": "esvair",
    "esvaíam": "esvair",
    "esvaíamo": "esvair",
    "esvaíamos": "esvair",
    "esvaías": "esvair",
    "esvaída": "esvair",
    "esvaídas": "esvair",
    "esvaído": "esvair",
    "esvaídos": "esvair",
    "esvaíei": "esvair",
    "esvaíeis": "esvair",
    "esvaímo": "esvair",
    "esvaímos": "esvair",
    "esvaíra": "esvair",
    "esvaíram": "esvair",
    "esvaíramo": "esvair",
    "esvaíramos": "esvair",
    "esvaíras": "esvair",
    "esvaíre": "esvair",
    "esvaírei": "esvair",
    "esvaíreis": "esvair",
    "esvaírem": "esvair",
    "esvaíres": "esvair",
    "esvaís": "esvair",
    "esvaísse": "esvair",
    "esvaísseis": "esvair",
    "esvaíssem": "esvair",
    "esvaíssemos": "esvair",
    "esvaísses": "esvair",
    "esvaíste": "esvair",
    "esvaístes": "esvair",
    "esventa": "esventar",
    "esventada": "esventar",
    "esventadas": "esventar",
    "esventado": "esventar",
    "esventados": "esventar",
    "esventai": "esventar",
    "esventais": "esventar",
    "esventam": "esventar",
    "esventamentos": "esventamento",
    "esventamo": "esventar",
    "esventamos": "esventar",
    "esventando": "esventar",
    "esventara": "esventar",
    "esventaram": "esventar",
    "esventaras": "esventar",
    "esventarde": "esventar",
    "esventardes": "esventar",
    "esventare": "esventar",
    "esventarei": "esventar",
    "esventareis": "esventar",
    "esventarem": "esventar",
    "esventaremos": "esventar",
    "esventares": "esventar",
    "esventaria": "esventar",
    "esventariam": "esventar",
    "esventarias": "esventar",
    "esventarmo": "esventar",
    "esventarmos": "esventar",
    "esventará": "esventar",
    "esventarás": "esventar",
    "esventarão": "esventar",
    "esventaríamos": "esventar",
    "esventaríeis": "esventar",
    "esventas": "esventar",
    "esventasse": "esventar",
    "esventassem": "esventar",
    "esventasses": "esventar",
    "esventaste": "esventar",
    "esventastes": "esventar",
    "esventava": "esventar",
    "esventavam": "esventar",
    "esventavas": "esventar",
    "esvente": "esventar",
    "esventei": "esventar",
    "esventeis": "esventar",
    "esventem": "esventar",
    "esventemo": "esventar",
    "esventemos": "esventar",
    "esventes": "esventar",
    "esvento": "esventar",
    "esventou": "esventar",
    "esventra": "esventrar",
    "esventrada": "esventrar",
    "esventradas": "esventrar",
    "esventrado": "esventrar",
    "esventrados": "esventrar",
    "esventrai": "esventrar",
    "esventrais": "esventrar",
    "esventram": "esventrar",
    "esventramentos": "esventramento",
    "esventramo": "esventrar",
    "esventramos": "esventrar",
    "esventrando": "esventrar",
    "esventrara": "esventrar",
    "esventraram": "esventrar",
    "esventraras": "esventrar",
    "esventrarde": "esventrar",
    "esventrardes": "esventrar",
    "esventrare": "esventrar",
    "esventrarei": "esventrar",
    "esventrareis": "esventrar",
    "esventrarem": "esventrar",
    "esventraremos": "esventrar",
    "esventrares": "esventrar",
    "esventraria": "esventrar",
    "esventrariam": "esventrar",
    "esventrarias": "esventrar",
    "esventrarmo": "esventrar",
    "esventrarmos": "esventrar",
    "esventrará": "esventrar",
    "esventrarás": "esventrar",
    "esventrarão": "esventrar",
    "esventraríamos": "esventrar",
    "esventraríeis": "esventrar",
    "esventras": "esventrar",
    "esventrasse": "esventrar",
    "esventrassem": "esventrar",
    "esventrasses": "esventrar",
    "esventraste": "esventrar",
    "esventrastes": "esventrar",
    "esventrava": "esventrar",
    "esventravam": "esventrar",
    "esventravas": "esventrar",
    "esventre": "esventrar",
    "esventrei": "esventrar",
    "esventreis": "esventrar",
    "esventrem": "esventrar",
    "esventremo": "esventrar",
    "esventremos": "esventrar",
    "esventres": "esventrar",
    "esventro": "esventrar",
    "esventrou": "esventrar",
    "esventrá": "esventrar",
    "esventrámo": "esventrar",
    "esventrámos": "esventrar",
    "esventráramo": "esventrar",
    "esventráramos": "esventrar",
    "esventrárei": "esventrar",
    "esventráreis": "esventrar",
    "esventrásseis": "esventrar",
    "esventrássemos": "esventrar",
    "esventrávamo": "esventrar",
    "esventrávamos": "esventrar",
    "esventrávei": "esventrar",
    "esventráveis": "esventrar",
    "esventá": "esventar",
    "esventámo": "esventar",
    "esventámos": "esventar",
    "esventáramo": "esventar",
    "esventáramos": "esventar",
    "esventárei": "esventar",
    "esventáreis": "esventar",
    "esventásseis": "esventar",
    "esventássemos": "esventar",
    "esventávamo": "esventar",
    "esventávamos": "esventar",
    "esventávei": "esventar",
    "esventáveis": "esventar",
    "esverce": "esverçar",
    "esvercei": "esverçar",
    "esverceis": "esverçar",
    "esvercem": "esverçar",
    "esvercemo": "esverçar",
    "esvercemos": "esverçar",
    "esverces": "esverçar",
    "esverdeada": "esverdear",
    "esverdeadas": "esverdear",
    "esverdeado": "esverdear",
    "esverdeados": "esverdear",
    "esverdeai": "esverdear",
    "esverdeais": "esverdear",
    "esverdeamo": "esverdear",
    "esverdeamos": "esverdear",
    "esverdeando": "esverdear",
    "esverdeara": "esverdear",
    "esverdearam": "esverdear",
    "esverdearas": "esverdear",
    "esverdearde": "esverdear",
    "esverdeardes": "esverdear",
    "esverdeare": "esverdear",
    "esverdearei": "esverdear",
    "esverdeareis": "esverdear",
    "esverdearem": "esverdear",
    "esverdearemos": "esverdear",
    "esverdeares": "esverdear",
    "esverdearia": "esverdear",
    "esverdeariam": "esverdear",
    "esverdearias": "esverdear",
    "esverdearmo": "esverdear",
    "esverdearmos": "esverdear",
    "esverdeará": "esverdear",
    "esverdearás": "esverdear",
    "esverdearão": "esverdear",
    "esverdearíamos": "esverdear",
    "esverdearíeis": "esverdear",
    "esverdeasse": "esverdear",
    "esverdeassem": "esverdear",
    "esverdeasses": "esverdear",
    "esverdeaste": "esverdear",
    "esverdeastes": "esverdear",
    "esverdeava": "esverdear",
    "esverdeavam": "esverdear",
    "esverdeavas": "esverdear",
    "esverdeei": "esverdear",
    "esverdeeis": "esverdear",
    "esverdeemo": "esverdear",
    "esverdeemos": "esverdear",
    "esverdeia": "esverdear",
    "esverdeiam": "esverdear",
    "esverdeias": "esverdear",
    "esverdeie": "esverdear",
    "esverdeiem": "esverdear",
    "esverdeies": "esverdear",
    "esverdeio": "esverdear",
    "esverdeou": "esverdear",
    "esverdeá": "esverdear",
    "esverdeámo": "esverdear",
    "esverdeámos": "esverdear",
    "esverdeáramo": "esverdear",
    "esverdeáramos": "esverdear",
    "esverdeárei": "esverdear",
    "esverdeáreis": "esverdear",
    "esverdeásseis": "esverdear",
    "esverdeássemos": "esverdear",
    "esverdeávamo": "esverdear",
    "esverdeávamos": "esverdear",
    "esverdeávei": "esverdear",
    "esverdeáveis": "esverdear",
    "esverdinha": "esverdinhar",
    "esverdinhada": "esverdinhar",
    "esverdinhadas": "esverdinhar",
    "esverdinhado": "esverdinhar",
    "esverdinhados": "esverdinhar",
    "esverdinhai": "esverdinhar",
    "esverdinhais": "esverdinhar",
    "esverdinham": "esverdinhar",
    "esverdinhamo": "esverdinhar",
    "esverdinhamos": "esverdinhar",
    "esverdinhando": "esverdinhar",
    "esverdinhara": "esverdinhar",
    "esverdinharam": "esverdinhar",
    "esverdinharas": "esverdinhar",
    "esverdinharde": "esverdinhar",
    "esverdinhardes": "esverdinhar",
    "esverdinhare": "esverdinhar",
    "esverdinharei": "esverdinhar",
    "esverdinhareis": "esverdinhar",
    "esverdinharem": "esverdinhar",
    "esverdinharemos": "esverdinhar",
    "esverdinhares": "esverdinhar",
    "esverdinharia": "esverdinhar",
    "esverdinhariam": "esverdinhar",
    "esverdinharias": "esverdinhar",
    "esverdinharmo": "esverdinhar",
    "esverdinharmos": "esverdinhar",
    "esverdinhará": "esverdinhar",
    "esverdinharás": "esverdinhar",
    "esverdinharão": "esverdinhar",
    "esverdinharíamos": "esverdinhar",
    "esverdinharíeis": "esverdinhar",
    "esverdinhas": "esverdinhar",
    "esverdinhasse": "esverdinhar",
    "esverdinhassem": "esverdinhar",
    "esverdinhasses": "esverdinhar",
    "esverdinhaste": "esverdinhar",
    "esverdinhastes": "esverdinhar",
    "esverdinhava": "esverdinhar",
    "esverdinhavam": "esverdinhar",
    "esverdinhavas": "esverdinhar",
    "esverdinhe": "esverdinhar",
    "esverdinhei": "esverdinhar",
    "esverdinheis": "esverdinhar",
    "esverdinhem": "esverdinhar",
    "esverdinhemo": "esverdinhar",
    "esverdinhemos": "esverdinhar",
    "esverdinhes": "esverdinhar",
    "esverdinho": "esverdinhar",
    "esverdinhou": "esverdinhar",
    "esverdinhá": "esverdinhar",
    "esverdinhámo": "esverdinhar",
    "esverdinhámos": "esverdinhar",
    "esverdinháramo": "esverdinhar",
    "esverdinháramos": "esverdinhar",
    "esverdinhárei": "esverdinhar",
    "esverdinháreis": "esverdinhar",
    "esverdinhásseis": "esverdinhar",
    "esverdinhássemos": "esverdinhar",
    "esverdinhávamo": "esverdinhar",
    "esverdinhávamos": "esverdinhar",
    "esverdinhávei": "esverdinhar",
    "esverdinháveis": "esverdinhar",
    "esverça": "esverçar",
    "esverçada": "esverçar",
    "esverçadas": "esverçar",
    "esverçado": "esverçar",
    "esverçados": "esverçar",
    "esverçai": "esverçar",
    "esverçais": "esverçar",
    "esverçam": "esverçar",
    "esverçamentos": "esverçamento",
    "esverçamo": "esverçar",
    "esverçamos": "esverçar",
    "esverçando": "esverçar",
    "esverçara": "esverçar",
    "esverçaram": "esverçar",
    "esverçaras": "esverçar",
    "esverçarde": "esverçar",
    "esverçardes": "esverçar",
    "esverçare": "esverçar",
    "esverçarei": "esverçar",
    "esverçareis": "esverçar",
    "esverçarem": "esverçar",
    "esverçaremos": "esverçar",
    "esverçares": "esverçar",
    "esverçaria": "esverçar",
    "esverçariam": "esverçar",
    "esverçarias": "esverçar",
    "esverçarmo": "esverçar",
    "esverçarmos": "esverçar",
    "esverçará": "esverçar",
    "esverçarás": "esverçar",
    "esverçarão": "esverçar",
    "esverçaríamos": "esverçar",
    "esverçaríeis": "esverçar",
    "esverças": "esverçar",
    "esverçasse": "esverçar",
    "esverçassem": "esverçar",
    "esverçasses": "esverçar",
    "esverçaste": "esverçar",
    "esverçastes": "esverçar",
    "esverçava": "esverçar",
    "esverçavam": "esverçar",
    "esverçavas": "esverçar",
    "esverço": "esverçar",
    "esverçou": "esverçar",
    "esverçá": "esverçar",
    "esverçámo": "esverçar",
    "esverçámos": "esverçar",
    "esverçáramo": "esverçar",
    "esverçáramos": "esverçar",
    "esverçárei": "esverçar",
    "esverçáreis": "esverçar",
    "esverçásseis": "esverçar",
    "esverçássemos": "esverçar",
    "esverçávamo": "esverçar",
    "esverçávamos": "esverçar",
    "esverçávei": "esverçar",
    "esverçáveis": "esverçar",
    "esvida": "esvidar",
    "esvidada": "esvidar",
    "esvidadas": "esvidar",
    "esvidado": "esvidar",
    "esvidadora": "esvidador",
    "esvidadoras": "esvidador",
    "esvidadores": "esvidador",
    "esvidados": "esvidar",
    "esvidai": "esvidar",
    "esvidais": "esvidar",
    "esvidam": "esvidar",
    "esvidamo": "esvidar",
    "esvidamos": "esvidar",
    "esvidando": "esvidar",
    "esvidara": "esvidar",
    "esvidaram": "esvidar",
    "esvidaras": "esvidar",
    "esvidarde": "esvidar",
    "esvidardes": "esvidar",
    "esvidare": "esvidar",
    "esvidarei": "esvidar",
    "esvidareis": "esvidar",
    "esvidarem": "esvidar",
    "esvidaremos": "esvidar",
    "esvidares": "esvidar",
    "esvidaria": "esvidar",
    "esvidariam": "esvidar",
    "esvidarias": "esvidar",
    "esvidarmo": "esvidar",
    "esvidarmos": "esvidar",
    "esvidará": "esvidar",
    "esvidarás": "esvidar",
    "esvidarão": "esvidar",
    "esvidaríamos": "esvidar",
    "esvidaríeis": "esvidar",
    "esvidas": "esvidar",
    "esvidasse": "esvidar",
    "esvidassem": "esvidar",
    "esvidasses": "esvidar",
    "esvidaste": "esvidar",
    "esvidastes": "esvidar",
    "esvidava": "esvidar",
    "esvidavam": "esvidar",
    "esvidavas": "esvidar",
    "esvide": "esvidar",
    "esvidei": "esvidar",
    "esvideis": "esvidar",
    "esvidem": "esvidar",
    "esvidemo": "esvidar",
    "esvidemos": "esvidar",
    "esvides": "esvidar",
    "esvidiga": "esvidigar",
    "esvidigada": "esvidigar",
    "esvidigadas": "esvidigar",
    "esvidigado": "esvidigar",
    "esvidigadora": "esvidigador",
    "esvidigadoras": "esvidigador",
    "esvidigadores": "esvidigador",
    "esvidigados": "esvidigar",
    "esvidigai": "esvidigar",
    "esvidigais": "esvidigar",
    "esvidigam": "esvidigar",
    "esvidigamo": "esvidigar",
    "esvidigamos": "esvidigar",
    "esvidigando": "esvidigar",
    "esvidigara": "esvidigar",
    "esvidigaram": "esvidigar",
    "esvidigaras": "esvidigar",
    "esvidigarde": "esvidigar",
    "esvidigardes": "esvidigar",
    "esvidigare": "esvidigar",
    "esvidigarei": "esvidigar",
    "esvidigareis": "esvidigar",
    "esvidigarem": "esvidigar",
    "esvidigaremos": "esvidigar",
    "esvidigares": "esvidigar",
    "esvidigaria": "esvidigar",
    "esvidigariam": "esvidigar",
    "esvidigarias": "esvidigar",
    "esvidigarmo": "esvidigar",
    "esvidigarmos": "esvidigar",
    "esvidigará": "esvidigar",
    "esvidigarás": "esvidigar",
    "esvidigarão": "esvidigar",
    "esvidigaríamos": "esvidigar",
    "esvidigaríeis": "esvidigar",
    "esvidigas": "esvidigar",
    "esvidigasse": "esvidigar",
    "esvidigassem": "esvidigar",
    "esvidigasses": "esvidigar",
    "esvidigaste": "esvidigar",
    "esvidigastes": "esvidigar",
    "esvidigava": "esvidigar",
    "esvidigavam": "esvidigar",
    "esvidigavas": "esvidigar",
    "esvidigo": "esvidigar",
    "esvidigou": "esvidigar",
    "esvidigue": "esvidigar",
    "esvidiguei": "esvidigar",
    "esvidigueis": "esvidigar",
    "esvidiguem": "esvidigar",
    "esvidiguemo": "esvidigar",
    "esvidiguemos": "esvidigar",
    "esvidigues": "esvidigar",
    "esvidigá": "esvidigar",
    "esvidigámo": "esvidigar",
    "esvidigámos": "esvidigar",
    "esvidigáramo": "esvidigar",
    "esvidigáramos": "esvidigar",
    "esvidigárei": "esvidigar",
    "esvidigáreis": "esvidigar",
    "esvidigásseis": "esvidigar",
    "esvidigássemos": "esvidigar",
    "esvidigávamo": "esvidigar",
    "esvidigávamos": "esvidigar",
    "esvidigávei": "esvidigar",
    "esvidigáveis": "esvidigar",
    "esvido": "esvidar",
    "esvidou": "esvidar",
    "esvidá": "esvidar",
    "esvidámo": "esvidar",
    "esvidámos": "esvidar",
    "esvidáramo": "esvidar",
    "esvidáramos": "esvidar",
    "esvidárei": "esvidar",
    "esvidáreis": "esvidar",
    "esvidásseis": "esvidar",
    "esvidássemos": "esvidar",
    "esvidávamo": "esvidar",
    "esvidávamos": "esvidar",
    "esvidávei": "esvidar",
    "esvidáveis": "esvidar",
    "esvigadora": "esvigador",
    "esvigadoras": "esvigador",
    "esvigadores": "esvigador",
    "esviscera": "esviscerar",
    "esviscerada": "esviscerar",
    "esvisceradas": "esviscerar",
    "esviscerado": "esviscerar",
    "esviscerados": "esviscerar",
    "esviscerai": "esviscerar",
    "esviscerais": "esviscerar",
    "esvisceram": "esviscerar",
    "esvisceramo": "esviscerar",
    "esvisceramos": "esviscerar",
    "esviscerando": "esviscerar",
    "esviscerara": "esviscerar",
    "esvisceraram": "esviscerar",
    "esvisceraras": "esviscerar",
    "esviscerarde": "esviscerar",
    "esviscerardes": "esviscerar",
    "esviscerare": "esviscerar",
    "esviscerarei": "esviscerar",
    "esviscerareis": "esviscerar",
    "esviscerarem": "esviscerar",
    "esvisceraremos": "esviscerar",
    "esviscerares": "esviscerar",
    "esvisceraria": "esviscerar",
    "esviscerariam": "esviscerar",
    "esviscerarias": "esviscerar",
    "esviscerarmo": "esviscerar",
    "esviscerarmos": "esviscerar",
    "esviscerará": "esviscerar",
    "esviscerarás": "esviscerar",
    "esviscerarão": "esviscerar",
    "esvisceraríamos": "esviscerar",
    "esvisceraríeis": "esviscerar",
    "esvisceras": "esviscerar",
    "esviscerasse": "esviscerar",
    "esviscerassem": "esviscerar",
    "esviscerasses": "esviscerar",
    "esvisceraste": "esviscerar",
    "esviscerastes": "esviscerar",
    "esviscerava": "esviscerar",
    "esvisceravam": "esviscerar",
    "esvisceravas": "esviscerar",
    "esviscere": "esviscerar",
    "esviscerei": "esviscerar",
    "esviscereis": "esviscerar",
    "esviscerem": "esviscerar",
    "esvisceremo": "esviscerar",
    "esvisceremos": "esviscerar",
    "esvisceres": "esviscerar",
    "esviscero": "esviscerar",
    "esviscerou": "esviscerar",
    "esviscerá": "esviscerar",
    "esviscerámo": "esviscerar",
    "esviscerámos": "esviscerar",
    "esvisceráramo": "esviscerar",
    "esvisceráramos": "esviscerar",
    "esviscerárei": "esviscerar",
    "esvisceráreis": "esviscerar",
    "esviscerásseis": "esviscerar",
    "esviscerássemos": "esviscerar",
    "esviscerávamo": "esviscerar",
    "esviscerávamos": "esviscerar",
    "esviscerávei": "esviscerar",
    "esvisceráveis": "esviscerar",
    "esvisçeramentos": "esvisçeramento",
    "esvoace": "esvoaçar",
    "esvoacei": "esvoaçar",
    "esvoaceis": "esvoaçar",
    "esvoacem": "esvoaçar",
    "esvoacemo": "esvoaçar",
    "esvoacemos": "esvoaçar",
    "esvoaces": "esvoaçar",
    "esvoaça": "esvoaçar",
    "esvoaçada": "esvoaçar",
    "esvoaçadas": "esvoaçar",
    "esvoaçado": "esvoaçar",
    "esvoaçados": "esvoaçar",
    "esvoaçai": "esvoaçar",
    "esvoaçais": "esvoaçar",
    "esvoaçam": "esvoaçar",
    "esvoaçamentos": "esvoaçamento",
    "esvoaçamo": "esvoaçar",
    "esvoaçamos": "esvoaçar",
    "esvoaçando": "esvoaçar",
    "esvoaçantes": "esvoaçante",
    "esvoaçara": "esvoaçar",
    "esvoaçaram": "esvoaçar",
    "esvoaçaras": "esvoaçar",
    "esvoaçarde": "esvoaçar",
    "esvoaçardes": "esvoaçar",
    "esvoaçare": "esvoaçar",
    "esvoaçarei": "esvoaçar",
    "esvoaçareis": "esvoaçar",
    "esvoaçarem": "esvoaçar",
    "esvoaçaremos": "esvoaçar",
    "esvoaçares": "esvoaçar",
    "esvoaçaria": "esvoaçar",
    "esvoaçariam": "esvoaçar",
    "esvoaçarias": "esvoaçar",
    "esvoaçarmo": "esvoaçar",
    "esvoaçarmos": "esvoaçar",
    "esvoaçará": "esvoaçar",
    "esvoaçarás": "esvoaçar",
    "esvoaçarão": "esvoaçar",
    "esvoaçaríamos": "esvoaçar",
    "esvoaçaríeis": "esvoaçar",
    "esvoaças": "esvoaçar",
    "esvoaçasse": "esvoaçar",
    "esvoaçassem": "esvoaçar",
    "esvoaçasses": "esvoaçar",
    "esvoaçaste": "esvoaçar",
    "esvoaçastes": "esvoaçar",
    "esvoaçava": "esvoaçar",
    "esvoaçavam": "esvoaçar",
    "esvoaçavas": "esvoaçar",
    "esvoaço": "esvoaçar",
    "esvoaçou": "esvoaçar",
    "esvoaçá": "esvoaçar",
    "esvoaçámo": "esvoaçar",
    "esvoaçámos": "esvoaçar",
    "esvoaçáramo": "esvoaçar",
    "esvoaçáramos": "esvoaçar",
    "esvoaçárei": "esvoaçar",
    "esvoaçáreis": "esvoaçar",
    "esvoaçásseis": "esvoaçar",
    "esvoaçássemos": "esvoaçar",
    "esvoaçávamo": "esvoaçar",
    "esvoaçávamos": "esvoaçar",
    "esvoaçávei": "esvoaçar",
    "esvoaçáveis": "esvoaçar",
    "esvurma": "esvurmar",
    "esvurmada": "esvurmar",
    "esvurmadas": "esvurmar",
    "esvurmado": "esvurmar",
    "esvurmados": "esvurmar",
    "esvurmai": "esvurmar",
    "esvurmais": "esvurmar",
    "esvurmam": "esvurmar",
    "esvurmamo": "esvurmar",
    "esvurmamos": "esvurmar",
    "esvurmando": "esvurmar",
    "esvurmara": "esvurmar",
    "esvurmaram": "esvurmar",
    "esvurmaras": "esvurmar",
    "esvurmarde": "esvurmar",
    "esvurmardes": "esvurmar",
    "esvurmare": "esvurmar",
    "esvurmarei": "esvurmar",
    "esvurmareis": "esvurmar",
    "esvurmarem": "esvurmar",
    "esvurmaremos": "esvurmar",
    "esvurmares": "esvurmar",
    "esvurmaria": "esvurmar",
    "esvurmariam": "esvurmar",
    "esvurmarias": "esvurmar",
    "esvurmarmo": "esvurmar",
    "esvurmarmos": "esvurmar",
    "esvurmará": "esvurmar",
    "esvurmarás": "esvurmar",
    "esvurmarão": "esvurmar",
    "esvurmaríamos": "esvurmar",
    "esvurmaríeis": "esvurmar",
    "esvurmas": "esvurmar",
    "esvurmasse": "esvurmar",
    "esvurmassem": "esvurmar",
    "esvurmasses": "esvurmar",
    "esvurmaste": "esvurmar",
    "esvurmastes": "esvurmar",
    "esvurmava": "esvurmar",
    "esvurmavam": "esvurmar",
    "esvurmavas": "esvurmar",
    "esvurme": "esvurmar",
    "esvurmei": "esvurmar",
    "esvurmeis": "esvurmar",
    "esvurmem": "esvurmar",
    "esvurmemo": "esvurmar",
    "esvurmemos": "esvurmar",
    "esvurmes": "esvurmar",
    "esvurmo": "esvurmar",
    "esvurmou": "esvurmar",
    "esvurmá": "esvurmar",
    "esvurmámo": "esvurmar",
    "esvurmámos": "esvurmar",
    "esvurmáramo": "esvurmar",
    "esvurmáramos": "esvurmar",
    "esvurmárei": "esvurmar",
    "esvurmáreis": "esvurmar",
    "esvurmásseis": "esvurmar",
    "esvurmássemos": "esvurmar",
    "esvurmávamo": "esvurmar",
    "esvurmávamos": "esvurmar",
    "esvurmávei": "esvurmar",
    "esvurmáveis": "esvurmar",
    "esvões": "esvão",
    "esócidas": "esócida",
    "esófagos": "esófago",
    "esópica": "esópico",
    "esópicas": "esópico",
    "esópicos": "esópico",
    "etais": "etal",
    "etanais": "etanal",
    "etanoatos": "etanoato",
    "etanodióis": "etanodiol",
    "etanoidióca": "etanoidióco",
    "etanoidiócas": "etanoidióco",
    "etanoidiócos": "etanoidióco",
    "etanos": "etano",
    "etanóica": "etanóico",
    "etanóicas": "etanóico",
    "etanóicos": "etanóico",
    "etanóis": "etanol",
    "etapas": "etapa",
    "etapazinha": "etapa",
    "etapazinhas": "etapa",
    "etapazita": "etapa",
    "etapazitas": "etapa",
    "etarras": "etarra",
    "etas": "eta",
    "etc.": "etcétera",
    "etcs": "etc",
    "etcéteras": "etcétera",
    "etenos": "eteno",
    "eterifica": "eterificar",
    "eterificada": "eterificar",
    "eterificadas": "eterificar",
    "eterificado": "eterificar",
    "eterificados": "eterificar",
    "eterificai": "eterificar",
    "eterificais": "eterificar",
    "eterificam": "eterificar",
    "eterificamo": "eterificar",
    "eterificamos": "eterificar",
    "eterificando": "eterificar",
    "eterificara": "eterificar",
    "eterificaram": "eterificar",
    "eterificaras": "eterificar",
    "eterificarde": "eterificar",
    "eterificardes": "eterificar",
    "eterificare": "eterificar",
    "eterificarei": "eterificar",
    "eterificareis": "eterificar",
    "eterificarem": "eterificar",
    "eterificaremos": "eterificar",
    "eterificares": "eterificar",
    "eterificaria": "eterificar",
    "eterificariam": "eterificar",
    "eterificarias": "eterificar",
    "eterificarmo": "eterificar",
    "eterificarmos": "eterificar",
    "eterificará": "eterificar",
    "eterificarás": "eterificar",
    "eterificarão": "eterificar",
    "eterificaríamos": "eterificar",
    "eterificaríeis": "eterificar",
    "eterificas": "eterificar",
    "eterificasse": "eterificar",
    "eterificassem": "eterificar",
    "eterificasses": "eterificar",
    "eterificaste": "eterificar",
    "eterificastes": "eterificar",
    "eterificava": "eterificar",
    "eterificavam": "eterificar",
    "eterificavas": "eterificar",
    "eterificações": "eterificação",
    "eterifico": "eterificar",
    "eterificou": "eterificar",
    "eterificá": "eterificar",
    "eterificámo": "eterificar",
    "eterificámos": "eterificar",
    "eterificáramo": "eterificar",
    "eterificáramos": "eterificar",
    "eterificárei": "eterificar",
    "eterificáreis": "eterificar",
    "eterificásseis": "eterificar",
    "eterificássemos": "eterificar",
    "eterificávamo": "eterificar",
    "eterificávamos": "eterificar",
    "eterificávei": "eterificar",
    "eterificáveis": "eterificar",
    "eterifique": "eterificar",
    "eterifiquei": "eterificar",
    "eterifiqueis": "eterificar",
    "eterifiquem": "eterificar",
    "eterifiquemo": "eterificar",
    "eterifiquemos": "eterificar",
    "eterifiques": "eterificar",
    "eterismos": "eterismo",
    "eteriza": "eterizar",
    "eterizada": "eterizar",
    "eterizadas": "eterizar",
    "eterizado": "eterizar",
    "eterizadores": "eterizador",
    "eterizados": "eterizar",
    "eterizai": "eterizar",
    "eterizais": "eterizar",
    "eterizam": "eterizar",
    "eterizamo": "eterizar",
    "eterizamos": "eterizar",
    "eterizando": "eterizar",
    "eterizara": "eterizar",
    "eterizaram": "eterizar",
    "eterizaras": "eterizar",
    "eterizarde": "eterizar",
    "eterizardes": "eterizar",
    "eterizare": "eterizar",
    "eterizarei": "eterizar",
    "eterizareis": "eterizar",
    "eterizarem": "eterizar",
    "eterizaremos": "eterizar",
    "eterizares": "eterizar",
    "eterizaria": "eterizar",
    "eterizariam": "eterizar",
    "eterizarias": "eterizar",
    "eterizarmo": "eterizar",
    "eterizarmos": "eterizar",
    "eterizará": "eterizar",
    "eterizarás": "eterizar",
    "eterizarão": "eterizar",
    "eterizaríamos": "eterizar",
    "eterizaríeis": "eterizar",
    "eterizas": "eterizar",
    "eterizasse": "eterizar",
    "eterizassem": "eterizar",
    "eterizasses": "eterizar",
    "eterizaste": "eterizar",
    "eterizastes": "eterizar",
    "eterizava": "eterizar",
    "eterizavam": "eterizar",
    "eterizavas": "eterizar",
    "eterizações": "eterização",
    "eterize": "eterizar",
    "eterizei": "eterizar",
    "eterizeis": "eterizar",
    "eterizem": "eterizar",
    "eterizemo": "eterizar",
    "eterizemos": "eterizar",
    "eterizes": "eterizar",
    "eterizo": "eterizar",
    "eterizou": "eterizar",
    "eterizá": "eterizar",
    "eterizámo": "eterizar",
    "eterizámos": "eterizar",
    "eterizáramo": "eterizar",
    "eterizáramos": "eterizar",
    "eterizárei": "eterizar",
    "eterizáreis": "eterizar",
    "eterizásseis": "eterizar",
    "eterizássemos": "eterizar",
    "eterizávamo": "eterizar",
    "eterizávamos": "eterizar",
    "eterizávei": "eterizar",
    "eterizáveis": "eterizar",
    "eterna": "eterno",
    "eternada": "eternar",
    "eternadas": "eternar",
    "eternado": "eternar",
    "eternados": "eternar",
    "eternai": "eternar",
    "eternais": "eternar",
    "eternam": "eternar",
    "eternamo": "eternar",
    "eternamos": "eternar",
    "eternando": "eternar",
    "eternara": "eternar",
    "eternaram": "eternar",
    "eternaras": "eternar",
    "eternarde": "eternar",
    "eternardes": "eternar",
    "eternare": "eternar",
    "eternarei": "eternar",
    "eternareis": "eternar",
    "eternarem": "eternar",
    "eternaremos": "eternar",
    "eternares": "eternar",
    "eternaria": "eternar",
    "eternariam": "eternar",
    "eternarias": "eternar",
    "eternarmo": "eternar",
    "eternarmos": "eternar",
    "eternará": "eternar",
    "eternarás": "eternar",
    "eternarão": "eternar",
    "eternaríamos": "eternar",
    "eternaríeis": "eternar",
    "eternas": "eterno",
    "eternasse": "eternar",
    "eternassem": "eternar",
    "eternasses": "eternar",
    "eternaste": "eternar",
    "eternastes": "eternar",
    "eternava": "eternar",
    "eternavam": "eternar",
    "eternavas": "eternar",
    "eterne": "eternar",
    "eternei": "eternar",
    "eterneis": "eternar",
    "eternem": "eternar",
    "eternemo": "eternar",
    "eternemos": "eternar",
    "eternes": "eternar",
    "eternidades": "eternidade",
    "eterniza": "eternizar",
    "eternizada": "eternizar",
    "eternizadas": "eternizar",
    "eternizado": "eternizar",
    "eternizados": "eternizar",
    "eternizai": "eternizar",
    "eternizais": "eternizar",
    "eternizam": "eternizar",
    "eternizamo": "eternizar",
    "eternizamos": "eternizar",
    "eternizando": "eternizar",
    "eternizara": "eternizar",
    "eternizaram": "eternizar",
    "eternizaras": "eternizar",
    "eternizarde": "eternizar",
    "eternizardes": "eternizar",
    "eternizare": "eternizar",
    "eternizarei": "eternizar",
    "eternizareis": "eternizar",
    "eternizarem": "eternizar",
    "eternizaremos": "eternizar",
    "eternizares": "eternizar",
    "eternizaria": "eternizar",
    "eternizariam": "eternizar",
    "eternizarias": "eternizar",
    "eternizarmo": "eternizar",
    "eternizarmos": "eternizar",
    "eternizará": "eternizar",
    "eternizarás": "eternizar",
    "eternizarão": "eternizar",
    "eternizaríamos": "eternizar",
    "eternizaríeis": "eternizar",
    "eternizas": "eternizar",
    "eternizasse": "eternizar",
    "eternizassem": "eternizar",
    "eternizasses": "eternizar",
    "eternizaste": "eternizar",
    "eternizastes": "eternizar",
    "eternizava": "eternizar",
    "eternizavam": "eternizar",
    "eternizavas": "eternizar",
    "eternizações": "eternização",
    "eternize": "eternizar",
    "eternizei": "eternizar",
    "eternizeis": "eternizar",
    "eternizem": "eternizar",
    "eternizemo": "eternizar",
    "eternizemos": "eternizar",
    "eternizes": "eternizar",
    "eternizo": "eternizar",
    "eternizou": "eternizar",
    "eternizá": "eternizar",
    "eternizámo": "eternizar",
    "eternizámos": "eternizar",
    "eternizáramo": "eternizar",
    "eternizáramos": "eternizar",
    "eternizárei": "eternizar",
    "eternizáreis": "eternizar",
    "eternizásseis": "eternizar",
    "eternizássemos": "eternizar",
    "eternizávamo": "eternizar",
    "eternizávamos": "eternizar",
    "eternizávei": "eternizar",
    "eternizáveis": "eternizar",
    "eterno": "eternar",
    "eternos": "eterno",
    "eternou": "eternar",
    "eterná": "eternar",
    "eternámo": "eternar",
    "eternámos": "eternar",
    "eternáramo": "eternar",
    "eternáramos": "eternar",
    "eternárei": "eternar",
    "eternáreis": "eternar",
    "eternásseis": "eternar",
    "eternássemos": "eternar",
    "eternávamo": "eternar",
    "eternávamos": "eternar",
    "eternávei": "eternar",
    "eternáveis": "eternar",
    "eterolatos": "eterolato",
    "eterolaturas": "eterolatura",
    "eteromanias": "eteromania",
    "eteróleos": "eteróleo",
    "eterómana": "eterómano",
    "eterómanas": "eterómano",
    "eterómanos": "eterómano",
    "etilaminas": "etilamina",
    "etilatos": "etilato",
    "etilenos": "etileno",
    "etilismos": "etilismo",
    "etiliza": "etilizar",
    "etilizada": "etilizar",
    "etilizadas": "etilizar",
    "etilizado": "etilizar",
    "etilizados": "etilizar",
    "etilizai": "etilizar",
    "etilizais": "etilizar",
    "etilizam": "etilizar",
    "etilizamo": "etilizar",
    "etilizamos": "etilizar",
    "etilizando": "etilizar",
    "etilizara": "etilizar",
    "etilizaram": "etilizar",
    "etilizaras": "etilizar",
    "etilizarde": "etilizar",
    "etilizardes": "etilizar",
    "etilizare": "etilizar",
    "etilizarei": "etilizar",
    "etilizareis": "etilizar",
    "etilizarem": "etilizar",
    "etilizaremos": "etilizar",
    "etilizares": "etilizar",
    "etilizaria": "etilizar",
    "etilizariam": "etilizar",
    "etilizarias": "etilizar",
    "etilizarmo": "etilizar",
    "etilizarmos": "etilizar",
    "etilizará": "etilizar",
    "etilizarás": "etilizar",
    "etilizarão": "etilizar",
    "etilizaríamos": "etilizar",
    "etilizaríeis": "etilizar",
    "etilizas": "etilizar",
    "etilizasse": "etilizar",
    "etilizassem": "etilizar",
    "etilizasses": "etilizar",
    "etilizaste": "etilizar",
    "etilizastes": "etilizar",
    "etilizava": "etilizar",
    "etilizavam": "etilizar",
    "etilizavas": "etilizar",
    "etilize": "etilizar",
    "etilizei": "etilizar",
    "etilizeis": "etilizar",
    "etilizem": "etilizar",
    "etilizemo": "etilizar",
    "etilizemos": "etilizar",
    "etilizes": "etilizar",
    "etilizo": "etilizar",
    "etilizou": "etilizar",
    "etilizá": "etilizar",
    "etilizámo": "etilizar",
    "etilizámos": "etilizar",
    "etilizáramo": "etilizar",
    "etilizáramos": "etilizar",
    "etilizárei": "etilizar",
    "etilizáreis": "etilizar",
    "etilizásseis": "etilizar",
    "etilizássemos": "etilizar",
    "etilizávamo": "etilizar",
    "etilizávamos": "etilizar",
    "etilizávei": "etilizar",
    "etilizáveis": "etilizar",
    "etilos": "etilo",
    "etilénica": "etilénico",
    "etilénicas": "etilénico",
    "etilénicos": "etilénico",
    "etimologias": "etimologia",
    "etimologismos": "etimologismo",
    "etimologistas": "etimologista",
    "etimológica": "etimológico",
    "etimológicas": "etimológico",
    "etimológicos": "etimológico",
    "etimóides": "etimóide",
    "etimóloga": "etimólogo",
    "etimólogas": "etimólogo",
    "etimólogos": "etimólogo",
    "etinos": "etino",
    "etiologias": "etiologia",
    "etiologistas": "etiologista",
    "etiológica": "etiológico",
    "etiológicas": "etiológico",
    "etiológicos": "etiológico",
    "etiopisas": "etiopisa",
    "etiqueta": "etiquetar",
    "etiquetada": "etiquetar",
    "etiquetadas": "etiquetar",
    "etiquetado": "etiquetar",
    "etiquetados": "etiquetar",
    "etiquetagens": "etiquetagem",
    "etiquetai": "etiquetar",
    "etiquetais": "etiquetar",
    "etiquetam": "etiquetar",
    "etiquetamo": "etiquetar",
    "etiquetamos": "etiquetar",
    "etiquetando": "etiquetar",
    "etiquetara": "etiquetar",
    "etiquetaram": "etiquetar",
    "etiquetaras": "etiquetar",
    "etiquetarde": "etiquetar",
    "etiquetardes": "etiquetar",
    "etiquetare": "etiquetar",
    "etiquetarei": "etiquetar",
    "etiquetareis": "etiquetar",
    "etiquetarem": "etiquetar",
    "etiquetaremos": "etiquetar",
    "etiquetares": "etiquetar",
    "etiquetaria": "etiquetar",
    "etiquetariam": "etiquetar",
    "etiquetarias": "etiquetar",
    "etiquetarmo": "etiquetar",
    "etiquetarmos": "etiquetar",
    "etiquetará": "etiquetar",
    "etiquetarás": "etiquetar",
    "etiquetarão": "etiquetar",
    "etiquetaríamos": "etiquetar",
    "etiquetaríeis": "etiquetar",
    "etiquetas": "etiquetar",
    "etiquetasse": "etiquetar",
    "etiquetassem": "etiquetar",
    "etiquetasses": "etiquetar",
    "etiquetaste": "etiquetar",
    "etiquetastes": "etiquetar",
    "etiquetava": "etiquetar",
    "etiquetavam": "etiquetar",
    "etiquetavas": "etiquetar",
    "etiquete": "etiquetar",
    "etiquetei": "etiquetar",
    "etiqueteis": "etiquetar",
    "etiquetem": "etiquetar",
    "etiquetemo": "etiquetar",
    "etiquetemos": "etiquetar",
    "etiquetes": "etiquetar",
    "etiqueto": "etiquetar",
    "etiquetou": "etiquetar",
    "etiquetá": "etiquetar",
    "etiquetámo": "etiquetar",
    "etiquetámos": "etiquetar",
    "etiquetáramo": "etiquetar",
    "etiquetáramos": "etiquetar",
    "etiquetárei": "etiquetar",
    "etiquetáreis": "etiquetar",
    "etiquetásseis": "etiquetar",
    "etiquetássemos": "etiquetar",
    "etiquetávamo": "etiquetar",
    "etiquetávamos": "etiquetar",
    "etiquetávei": "etiquetar",
    "etiquetáveis": "etiquetável",
    "etis": "etil",
    "etiópica": "etiópico",
    "etiópicas": "etiópico",
    "etiópicos": "etiópico",
    "etmoidais": "etmoidal",
    "etmóidea": "etmóideo",
    "etmóideas": "etmóideo",
    "etmóideos": "etmóideo",
    "etmóides": "etmóide",
    "etnarcas": "etnarca",
    "etnarquias": "etnarquia",
    "etnias": "etnia",
    "etnicismos": "etnicismo",
    "etnocentrismos": "etnocentrismo",
    "etnocrática": "etnocrático",
    "etnocráticas": "etnocrático",
    "etnocráticos": "etnocrático",
    "etnocêntrica": "etnocêntrico",
    "etnocêntricas": "etnocêntrico",
    "etnocêntricos": "etnocêntrico",
    "etnodiceia": "etnodiceu",
    "etnodiceias": "etnodiceu",
    "etnodiceus": "etnodiceu",
    "etnogenias": "etnogenia",
    "etnogenésica": "etnogenésico",
    "etnogenésicas": "etnogenésico",
    "etnogenésicos": "etnogenésico",
    "etnogenética": "etnogenético",
    "etnogenéticas": "etnogenético",
    "etnogenéticos": "etnogenético",
    "etnogeografias": "etnogeografia",
    "etnogeográfica": "etnogeográfico",
    "etnogeográficas": "etnogeográfico",
    "etnogeográficos": "etnogeográfico",
    "etnognosiológica": "etnognosiológico",
    "etnognosiológicas": "etnognosiológico",
    "etnognosiológicos": "etnognosiológico",
    "etnognósica": "etnognósico",
    "etnognósicas": "etnognósico",
    "etnognósicos": "etnognósico",
    "etnognóstica": "etnognóstico",
    "etnognósticas": "etnognóstico",
    "etnognósticos": "etnognóstico",
    "etnografias": "etnografia",
    "etnográfica": "etnográfico",
    "etnográficas": "etnográfico",
    "etnográficos": "etnográfico",
    "etnogénica": "etnogénico",
    "etnogénicas": "etnogénico",
    "etnogénicos": "etnogénico",
    "etnolinguísticas": "etnolinguística",
    "etnologias": "etnologia",
    "etnologistas": "etnologista",
    "etnológica": "etnológico",
    "etnológicas": "etnológico",
    "etnológicos": "etnológico",
    "etnometrias": "etnometria",
    "etnomusicologias": "etnomusicologia",
    "etnomética": "etnomético",
    "etnométicas": "etnomético",
    "etnométicos": "etnomético",
    "etnonímias": "etnonímia",
    "etnonímica": "etnonímico",
    "etnonímicas": "etnonímico",
    "etnonímicos": "etnonímico",
    "etnopsicologias": "etnopsicologia",
    "etnopsicológica": "etnopsicológico",
    "etnopsicológicas": "etnopsicológico",
    "etnopsicológicos": "etnopsicológico",
    "etnopsicóloga": "etnopsicólogo",
    "etnopsicólogas": "etnopsicólogo",
    "etnopsicólogos": "etnopsicólogo",
    "etnógrafa": "etnógrafo",
    "etnógrafas": "etnógrafo",
    "etnógrafos": "etnógrafo",
    "etnóloga": "etnólogo",
    "etnólogas": "etnólogo",
    "etnólogos": "etnólogo",
    "etnónimos": "etnónimo",
    "etocracias": "etocracia",
    "etocratas": "etocrata",
    "etogenias": "etogenia",
    "etognosias": "etognosia",
    "etografias": "etografia",
    "etogénica": "etogénico",
    "etogénicas": "etogénico",
    "etogénicos": "etogénico",
    "etologias": "etologia",
    "etologistas": "etologista",
    "etológica": "etológico",
    "etológicas": "etológico",
    "etológicos": "etológico",
    "etopeia": "etopeu",
    "etopeias": "etopeu",
    "etopeus": "etopeu",
    "etopéica": "etopéico",
    "etopéicas": "etopéico",
    "etopéicos": "etopéico",
    "etrusca": "etrusco",
    "etruscas": "etrusco",
    "etruscos": "etrusco",
    "etária": "etário",
    "etárias": "etário",
    "etários": "etário",
    "etérea": "etéreo",
    "etéreas": "etéreo",
    "etéreos": "etéreo",
    "etérica": "etérico",
    "etéricas": "etérico",
    "etéricos": "etérico",
    "etílica": "etílico",
    "etílicas": "etílico",
    "etílicos": "etílico",
    "etíopes": "etíope",
    "etóloga": "etólogo",
    "etólogas": "etólogo",
    "etólogos": "etólogo",
    "eubages": "eubage",
    "eubiótica": "eubiótico",
    "eubióticas": "eubiótico",
    "eubióticos": "eubiótico",
    "eucaliptais": "eucaliptal",
    "eucaliptos": "eucalipto",
    "eucaliptóis": "eucaliptol",
    "eucaristias": "eucaristia",
    "eucarística": "eucarístico",
    "eucarísticas": "eucarístico",
    "eucarísticos": "eucarístico",
    "eucaínas": "eucaína",
    "euclidiana": "euclidiano",
    "euclidianas": "euclidiano",
    "euclidianos": "euclidiano",
    "eucrasias": "eucrasia",
    "eucromática": "eucromático",
    "eucromáticas": "eucromático",
    "eucromáticos": "eucromático",
    "eucrásica": "eucrásico",
    "eucrásicas": "eucrásico",
    "eucrásicos": "eucrásico",
    "eudemonismos": "eudemonismo",
    "eudemónica": "eudemónico",
    "eudemónicas": "eudemónico",
    "eudemónicos": "eudemónico",
    "eudiapneustias": "eudiapneustia",
    "eudiapnêustica": "eudiapnêustico",
    "eudiapnêusticas": "eudiapnêustico",
    "eudiapnêusticos": "eudiapnêustico",
    "eudiometrias": "eudiometria",
    "eudiométrica": "eudiométrico",
    "eudiométricas": "eudiométrico",
    "eudiométricos": "eudiométrico",
    "eudiómetros": "eudiómetro",
    "euemias": "euemia",
    "eufemias": "eufemia",
    "eufemismos": "eufemismo",
    "eufemística": "eufemístico",
    "eufemísticas": "eufemístico",
    "eufemísticos": "eufemístico",
    "eufomanias": "eufomania",
    "eufomaníaca": "eufomaníaco",
    "eufomaníacas": "eufomaníaco",
    "eufomaníacos": "eufomaníaco",
    "eufonias": "eufonia",
    "euforbiácea": "euforbiáceo",
    "euforbiáceas": "euforbiáceo",
    "euforbiáceos": "euforbiáceo",
    "euforias": "euforia",
    "eufrásias": "eufrásia",
    "eufuistas": "eufuista",
    "eufuísmos": "eufuísmo",
    "eufuístas": "eufuísta",
    "eufuística": "eufuístico",
    "eufuísticas": "eufuístico",
    "eufuísticos": "eufuístico",
    "eufémica": "eufémico",
    "eufémicas": "eufémico",
    "eufémicos": "eufémico",
    "eufónica": "eufónico",
    "eufónicas": "eufónico",
    "eufónicos": "eufónico",
    "eufónios": "eufónio",
    "eufórbias": "eufórbia",
    "eufórbica": "eufórbico",
    "eufórbicas": "eufórbico",
    "eufórbicos": "eufórbico",
    "eufórbios": "eufórbio",
    "eufórica": "eufórico",
    "eufóricas": "eufórico",
    "eufóricos": "eufórico",
    "eugenesias": "eugenesia",
    "eugenias": "eugenia",
    "eugenismos": "eugenismo",
    "eugenistas": "eugenista",
    "eugenésica": "eugenésico",
    "eugenésicas": "eugenésico",
    "eugenésicos": "eugenésico",
    "eugenética": "eugenético",
    "eugenéticas": "eugenético",
    "eugenéticos": "eugenético",
    "eugenística": "eugenístico",
    "eugenísticas": "eugenístico",
    "eugenísticos": "eugenístico",
    "eugráfica": "eugráfico",
    "eugráficas": "eugráfico",
    "eugráficos": "eugráfico",
    "eugénica": "eugénico",
    "eugénicas": "eugénico",
    "eugénicos": "eugénico",
    "eulalias": "eulalia",
    "eulógias": "eulógia",
    "euménides": "euménide",
    "eunucos": "eunuco",
    "eunuquismos": "eunuquismo",
    "eupatas": "eupata",
    "eupatias": "eupatia",
    "eupatoscópica": "eupatoscópico",
    "eupatoscópicas": "eupatoscópico",
    "eupatoscópicos": "eupatoscópico",
    "eupatoscópios": "eupatoscópio",
    "eupatórios": "eupatório",
    "eupepsias": "eupepsia",
    "euplástica": "euplástico",
    "euplásticas": "euplástico",
    "euplásticos": "euplástico",
    "eupneias": "eupneia",
    "eupática": "eupático",
    "eupáticas": "eupático",
    "eupáticos": "eupático",
    "eupátridas": "eupátrida",
    "eupépsica": "eupépsico",
    "eupépsicas": "eupépsico",
    "eupépsicos": "eupépsico",
    "eupéptica": "eupéptico",
    "eupépticas": "eupéptico",
    "eupépticos": "eupéptico",
    "euquimos": "euquimo",
    "eurafricana": "eurafricano",
    "eurafricanas": "eurafricano",
    "eurafricanos": "eurafricano",
    "eurasiana": "eurasiano",
    "eurasianas": "eurasiano",
    "eurasianos": "eurasiano",
    "eurasiática": "eurasiático",
    "eurasiáticas": "eurasiático",
    "eurasiáticos": "eurasiático",
    "euribática": "euribático",
    "euribáticas": "euribático",
    "euribáticos": "euribático",
    "euricefalias": "euricefalia",
    "euricefálica": "euricefálico",
    "euricefálicas": "euricefálico",
    "euricefálicos": "euricefálico",
    "euricéfala": "euricéfalo",
    "euricéfalas": "euricéfalo",
    "euricéfalos": "euricéfalo",
    "eurignata": "eurignato",
    "eurignatas": "eurignato",
    "eurignatismos": "eurignatismo",
    "eurignatos": "eurignato",
    "eurignática": "eurignático",
    "eurignáticas": "eurignático",
    "eurignáticos": "eurignático",
    "eurina": "eurino",
    "eurinas": "eurino",
    "eurinos": "eurino",
    "euripos": "euripo",
    "euriterma": "euritermo",
    "euritermas": "euritermo",
    "euritermos": "euritermo",
    "euritmias": "euritmia",
    "euriónica": "euriónico",
    "euriónicas": "euriónico",
    "euriónicos": "euriónico",
    "euroafricana": "euroafricano",
    "euroafricanas": "euroafricano",
    "euroafricanos": "euroafricano",
    "euroasiática": "euroasiático",
    "euroasiáticas": "euroasiático",
    "euroasiáticos": "euroasiático",
    "eurocepticismos": "eurocepticismo",
    "eurocidades": "eurocidade",
    "eurocomunismos": "eurocomunismo",
    "eurocomunistas": "eurocomunista",
    "eurocratas": "eurocrata",
    "eurocéptica": "eurocéptico",
    "eurocépticas": "eurocéptico",
    "eurocépticos": "eurocéptico",
    "eurocêntrica": "eurocêntrico",
    "eurocêntricas": "eurocêntrico",
    "eurocêntricos": "eurocêntrico",
    "eurodeputada": "eurodeputado",
    "eurodeputadas": "eurodeputado",
    "eurodeputados": "eurodeputado",
    "eurodolares": "eurodolar",
    "euromercados": "euromercado",
    "europas": "europa",
    "europeia": "europeu",
    "europeias": "europeu",
    "europeiza": "europeizar",
    "europeizada": "europeizar",
    "europeizadas": "europeizar",
    "europeizado": "europeizar",
    "europeizados": "europeizar",
    "europeizai": "europeizar",
    "europeizais": "europeizar",
    "europeizam": "europeizar",
    "europeizamo": "europeizar",
    "europeizamos": "europeizar",
    "europeizando": "europeizar",
    "europeizara": "europeizar",
    "europeizaram": "europeizar",
    "europeizaras": "europeizar",
    "europeizarde": "europeizar",
    "europeizardes": "europeizar",
    "europeizare": "europeizar",
    "europeizarei": "europeizar",
    "europeizareis": "europeizar",
    "europeizarem": "europeizar",
    "europeizaremos": "europeizar",
    "europeizares": "europeizar",
    "europeizaria": "europeizar",
    "europeizariam": "europeizar",
    "europeizarias": "europeizar",
    "europeizarmo": "europeizar",
    "europeizarmos": "europeizar",
    "europeizará": "europeizar",
    "europeizarás": "europeizar",
    "europeizarão": "europeizar",
    "europeizaríamos": "europeizar",
    "europeizaríeis": "europeizar",
    "europeizas": "europeizar",
    "europeizasse": "europeizar",
    "europeizassem": "europeizar",
    "europeizasses": "europeizar",
    "europeizaste": "europeizar",
    "europeizastes": "europeizar",
    "europeizava": "europeizar",
    "europeizavam": "europeizar",
    "europeizavas": "europeizar",
    "europeizações": "europeização",
    "europeize": "europeizar",
    "europeizei": "europeizar",
    "europeizeis": "europeizar",
    "europeizem": "europeizar",
    "europeizemo": "europeizar",
    "europeizemos": "europeizar",
    "europeizes": "europeizar",
    "europeizo": "europeizar",
    "europeizou": "europeizar",
    "europeizá": "europeizar",
    "europeizámo": "europeizar",
    "europeizámos": "europeizar",
    "europeizáramo": "europeizar",
    "europeizáramos": "europeizar",
    "europeizárei": "europeizar",
    "europeizáreis": "europeizar",
    "europeizásseis": "europeizar",
    "europeizássemos": "europeizar",
    "europeizávamo": "europeizar",
    "europeizávamos": "europeizar",
    "europeizávei": "europeizar",
    "europeizáveis": "europeizar",
    "europeus": "europeu",
    "europeísmos": "europeísmo",
    "europeístas": "europeísta",
    "euros": "euro",
    "eurovisões": "eurovisão",
    "eurásia": "eurásio",
    "eurásias": "eurásio",
    "eurásios": "eurásio",
    "eurícera": "eurícero",
    "euríceras": "eurícero",
    "euríceros": "eurícero",
    "eurítmica": "eurítmico",
    "eurítmicas": "eurítmico",
    "eurítmicos": "eurítmico",
    "európios": "európio",
    "eurótonos": "eurótono",
    "eus": "eu",
    "euscalduna": "euscalduno",
    "euscaldunas": "euscalduno",
    "euscaldunos": "euscalduno",
    "eussemias": "eussemia",
    "eustasias": "eustasia",
    "eustilos": "eustilo",
    "eustomias": "eustomia",
    "eustática": "eustático",
    "eustáticas": "eustático",
    "eustáticos": "eustático",
    "eutanásias": "eutanásia",
    "eutaxias": "eutaxia",
    "eutexias": "eutexia",
    "eutimias": "eutimia",
    "eutiquianismos": "eutiquianismo",
    "eutrofias": "eutrofia",
    "eutuberácea": "eutuberáceo",
    "eutuberáceas": "eutuberáceo",
    "eutuberáceos": "eutuberáceo",
    "eutérios": "eutério",
    "eutética": "eutético",
    "eutéticas": "eutético",
    "eutéticos": "eutético",
    "eutícoma": "eutícomo",
    "eutícomas": "eutícomo",
    "eutícomos": "eutícomo",
    "eutócica": "eutócico",
    "eutócicas": "eutócico",
    "eutócicos": "eutócico",
    "euxenites": "euxenite",
    "euémica": "euémico",
    "euémicas": "euémico",
    "euémicos": "euémico",
    "evacua": "evacuar",
    "evacuada": "evacuar",
    "evacuadas": "evacuar",
    "evacuado": "evacuar",
    "evacuados": "evacuar",
    "evacuai": "evacuar",
    "evacuais": "evacuar",
    "evacuam": "evacuar",
    "evacuamo": "evacuar",
    "evacuamos": "evacuar",
    "evacuando": "evacuar",
    "evacuantes": "evacuante",
    "evacuara": "evacuar",
    "evacuaram": "evacuar",
    "evacuaras": "evacuar",
    "evacuarde": "evacuar",
    "evacuardes": "evacuar",
    "evacuare": "evacuar",
    "evacuarei": "evacuar",
    "evacuareis": "evacuar",
    "evacuarem": "evacuar",
    "evacuaremos": "evacuar",
    "evacuares": "evacuar",
    "evacuaria": "evacuar",
    "evacuariam": "evacuar",
    "evacuarias": "evacuar",
    "evacuarmo": "evacuar",
    "evacuarmos": "evacuar",
    "evacuará": "evacuar",
    "evacuarás": "evacuar",
    "evacuarão": "evacuar",
    "evacuaríamos": "evacuar",
    "evacuaríeis": "evacuar",
    "evacuas": "evacuar",
    "evacuasse": "evacuar",
    "evacuassem": "evacuar",
    "evacuasses": "evacuar",
    "evacuaste": "evacuar",
    "evacuastes": "evacuar",
    "evacuativa": "evacuativo",
    "evacuativas": "evacuativo",
    "evacuativos": "evacuativo",
    "evacuatória": "evacuatório",
    "evacuatórias": "evacuatório",
    "evacuatórios": "evacuatório",
    "evacuava": "evacuar",
    "evacuavam": "evacuar",
    "evacuavas": "evacuar",
    "evacuações": "evacuação",
    "evacue": "evacuar",
    "evacuei": "evacuar",
    "evacueis": "evacuar",
    "evacuem": "evacuar",
    "evacuemo": "evacuar",
    "evacuemos": "evacuar",
    "evacues": "evacuar",
    "evacuo": "evacuar",
    "evacuou": "evacuar",
    "evacuá": "evacuar",
    "evacuámo": "evacuar",
    "evacuámos": "evacuar",
    "evacuáramo": "evacuar",
    "evacuáramos": "evacuar",
    "evacuárei": "evacuar",
    "evacuáreis": "evacuar",
    "evacuásseis": "evacuar",
    "evacuássemos": "evacuar",
    "evacuávamo": "evacuar",
    "evacuávamos": "evacuar",
    "evacuávei": "evacuar",
    "evacuáveis": "evacuar",
    "evada": "evadir",
    "evadais": "evadir",
    "evadam": "evadir",
    "evadamo": "evadir",
    "evadamos": "evadir",
    "evadas": "evadir",
    "evade": "evadir",
    "evadem": "evadir",
    "evades": "evadir",
    "evadi": "evadir",
    "evadia": "evadir",
    "evadiam": "evadir",
    "evadias": "evadir",
    "evadida": "evadir",
    "evadidas": "evadir",
    "evadido": "evadir",
    "evadidos": "evadir",
    "evadimo": "evadir",
    "evadimos": "evadir",
    "evadindo": "evadir",
    "evadira": "evadir",
    "evadiram": "evadir",
    "evadiras": "evadir",
    "evadirdes": "evadir",
    "evadirei": "evadir",
    "evadireis": "evadir",
    "evadirem": "evadir",
    "evadiremos": "evadir",
    "evadires": "evadir",
    "evadiria": "evadir",
    "evadiriam": "evadir",
    "evadirias": "evadir",
    "evadirmo": "evadir",
    "evadirmos": "evadir",
    "evadirá": "evadir",
    "evadirás": "evadir",
    "evadirão": "evadir",
    "evadiríamos": "evadir",
    "evadiríeis": "evadir",
    "evadis": "evadir",
    "evadisse": "evadir",
    "evadissem": "evadir",
    "evadisses": "evadir",
    "evadiste": "evadir",
    "evadistes": "evadir",
    "evadiu": "evadir",
    "evado": "evadir",
    "evadíamo": "evadir",
    "evadíamos": "evadir",
    "evadíeis": "evadir",
    "evadíramo": "evadir",
    "evadíramos": "evadir",
    "evadíreis": "evadir",
    "evadísseis": "evadir",
    "evadíssemos": "evadir",
    "evagações": "evagação",
    "evalves": "evalve",
    "evanescentes": "evanescente",
    "evangelhos": "evangelho",
    "evangelismos": "evangelismo",
    "evangelistas": "evangelista",
    "evangeliza": "evangelizar",
    "evangelizada": "evangelizar",
    "evangelizadas": "evangelizar",
    "evangelizado": "evangelizar",
    "evangelizadora": "evangelizador",
    "evangelizadoras": "evangelizador",
    "evangelizadores": "evangelizador",
    "evangelizados": "evangelizar",
    "evangelizai": "evangelizar",
    "evangelizais": "evangelizar",
    "evangelizam": "evangelizar",
    "evangelizamo": "evangelizar",
    "evangelizamos": "evangelizar",
    "evangelizando": "evangelizar",
    "evangelizantes": "evangelizante",
    "evangelizara": "evangelizar",
    "evangelizaram": "evangelizar",
    "evangelizaras": "evangelizar",
    "evangelizarde": "evangelizar",
    "evangelizardes": "evangelizar",
    "evangelizare": "evangelizar",
    "evangelizarei": "evangelizar",
    "evangelizareis": "evangelizar",
    "evangelizarem": "evangelizar",
    "evangelizaremos": "evangelizar",
    "evangelizares": "evangelizar",
    "evangelizaria": "evangelizar",
    "evangelizariam": "evangelizar",
    "evangelizarias": "evangelizar",
    "evangelizarmo": "evangelizar",
    "evangelizarmos": "evangelizar",
    "evangelizará": "evangelizar",
    "evangelizarás": "evangelizar",
    "evangelizarão": "evangelizar",
    "evangelizaríamos": "evangelizar",
    "evangelizaríeis": "evangelizar",
    "evangelizas": "evangelizar",
    "evangelizasse": "evangelizar",
    "evangelizassem": "evangelizar",
    "evangelizasses": "evangelizar",
    "evangelizaste": "evangelizar",
    "evangelizastes": "evangelizar",
    "evangelizava": "evangelizar",
    "evangelizavam": "evangelizar",
    "evangelizavas": "evangelizar",
    "evangelizações": "evangelização",
    "evangelize": "evangelizar",
    "evangelizei": "evangelizar",
    "evangelizeis": "evangelizar",
    "evangelizem": "evangelizar",
    "evangelizemo": "evangelizar",
    "evangelizemos": "evangelizar",
    "evangelizes": "evangelizar",
    "evangelizo": "evangelizar",
    "evangelizou": "evangelizar",
    "evangelizá": "evangelizar",
    "evangelizámo": "evangelizar",
    "evangelizámos": "evangelizar",
    "evangelizáramo": "evangelizar",
    "evangelizáramos": "evangelizar",
    "evangelizárei": "evangelizar",
    "evangelizáreis": "evangelizar",
    "evangelizásseis": "evangelizar",
    "evangelizássemos": "evangelizar",
    "evangelizávamo": "evangelizar",
    "evangelizávamos": "evangelizar",
    "evangelizávei": "evangelizar",
    "evangelizáveis": "evangelizável",
    "evangeliários": "evangeliário",
    "evangélica": "evangélico",
    "evangélicas": "evangélico",
    "evangélicos": "evangélico",
    "evapora": "evaporar",
    "evaporada": "evaporar",
    "evaporadas": "evaporar",
    "evaporado": "evaporar",
    "evaporadores": "evaporador",
    "evaporados": "evaporar",
    "evaporai": "evaporar",
    "evaporais": "evaporar",
    "evaporam": "evaporar",
    "evaporamo": "evaporar",
    "evaporamos": "evaporar",
    "evaporando": "evaporar",
    "evaporantes": "evaporante",
    "evaporara": "evaporar",
    "evaporaram": "evaporar",
    "evaporaras": "evaporar",
    "evaporarde": "evaporar",
    "evaporardes": "evaporar",
    "evaporare": "evaporar",
    "evaporarei": "evaporar",
    "evaporareis": "evaporar",
    "evaporarem": "evaporar",
    "evaporaremos": "evaporar",
    "evaporares": "evaporar",
    "evaporaria": "evaporar",
    "evaporariam": "evaporar",
    "evaporarias": "evaporar",
    "evaporarmo": "evaporar",
    "evaporarmos": "evaporar",
    "evaporará": "evaporar",
    "evaporarás": "evaporar",
    "evaporarão": "evaporar",
    "evaporaríamos": "evaporar",
    "evaporaríeis": "evaporar",
    "evaporas": "evaporar",
    "evaporasse": "evaporar",
    "evaporassem": "evaporar",
    "evaporasses": "evaporar",
    "evaporaste": "evaporar",
    "evaporastes": "evaporar",
    "evaporativa": "evaporativo",
    "evaporativas": "evaporativo",
    "evaporativos": "evaporativo",
    "evaporatória": "evaporatório",
    "evaporatórias": "evaporatório",
    "evaporatórios": "evaporatório",
    "evaporava": "evaporar",
    "evaporavam": "evaporar",
    "evaporavas": "evaporar",
    "evaporações": "evaporação",
    "evapore": "evaporar",
    "evaporei": "evaporar",
    "evaporeis": "evaporar",
    "evaporem": "evaporar",
    "evaporemo": "evaporar",
    "evaporemos": "evaporar",
    "evapores": "evaporar",
    "evaporimetrias": "evaporimetria",
    "evaporimétrica": "evaporimétrico",
    "evaporimétricas": "evaporimétrico",
    "evaporimétricos": "evaporimétrico",
    "evaporitos": "evaporito",
    "evaporiza": "evaporizar",
    "evaporizada": "evaporizar",
    "evaporizadas": "evaporizar",
    "evaporizado": "evaporizar",
    "evaporizados": "evaporizar",
    "evaporizai": "evaporizar",
    "evaporizais": "evaporizar",
    "evaporizam": "evaporizar",
    "evaporizamo": "evaporizar",
    "evaporizamos": "evaporizar",
    "evaporizando": "evaporizar",
    "evaporizara": "evaporizar",
    "evaporizaram": "evaporizar",
    "evaporizaras": "evaporizar",
    "evaporizarde": "evaporizar",
    "evaporizardes": "evaporizar",
    "evaporizare": "evaporizar",
    "evaporizarei": "evaporizar",
    "evaporizareis": "evaporizar",
    "evaporizarem": "evaporizar",
    "evaporizaremos": "evaporizar",
    "evaporizares": "evaporizar",
    "evaporizaria": "evaporizar",
    "evaporizariam": "evaporizar",
    "evaporizarias": "evaporizar",
    "evaporizarmo": "evaporizar",
    "evaporizarmos": "evaporizar",
    "evaporizará": "evaporizar",
    "evaporizarás": "evaporizar",
    "evaporizarão": "evaporizar",
    "evaporizaríamos": "evaporizar",
    "evaporizaríeis": "evaporizar",
    "evaporizas": "evaporizar",
    "evaporizasse": "evaporizar",
    "evaporizassem": "evaporizar",
    "evaporizasses": "evaporizar",
    "evaporizaste": "evaporizar",
    "evaporizastes": "evaporizar",
    "evaporizava": "evaporizar",
    "evaporizavam": "evaporizar",
    "evaporizavas": "evaporizar",
    "evaporize": "evaporizar",
    "evaporizei": "evaporizar",
    "evaporizeis": "evaporizar",
    "evaporizem": "evaporizar",
    "evaporizemo": "evaporizar",
    "evaporizemos": "evaporizar",
    "evaporizes": "evaporizar",
    "evaporizo": "evaporizar",
    "evaporizou": "evaporizar",
    "evaporizá": "evaporizar",
    "evaporizámo": "evaporizar",
    "evaporizámos": "evaporizar",
    "evaporizáramo": "evaporizar",
    "evaporizáramos": "evaporizar",
    "evaporizárei": "evaporizar",
    "evaporizáreis": "evaporizar",
    "evaporizásseis": "evaporizar",
    "evaporizássemos": "evaporizar",
    "evaporizávamo": "evaporizar",
    "evaporizávamos": "evaporizar",
    "evaporizávei": "evaporizar",
    "evaporizáveis": "evaporizar",
    "evaporo": "evaporar",
    "evaporometrias": "evaporometria",
    "evaporométrica": "evaporométrico",
    "evaporométricas": "evaporométrico",
    "evaporométricos": "evaporométrico",
    "evaporou": "evaporar",
    "evaporá": "evaporar",
    "evaporámo": "evaporar",
    "evaporámos": "evaporar",
    "evaporáramo": "evaporar",
    "evaporáramos": "evaporar",
    "evaporárei": "evaporar",
    "evaporáreis": "evaporar",
    "evaporásseis": "evaporar",
    "evaporássemos": "evaporar",
    "evaporávamo": "evaporar",
    "evaporávamos": "evaporar",
    "evaporávei": "evaporar",
    "evaporáveis": "evaporável",
    "evaporímetros": "evaporímetro",
    "evaporómetros": "evaporómetro",
    "evasiva": "evasivo",
    "evasivas": "evasivo",
    "evasivos": "evasivo",
    "evasora": "evasor",
    "evasoras": "evasor",
    "evasores": "evasor",
    "evasões": "evasão",
    "evecções": "evecção",
    "evemerismos": "evemerismo",
    "evemerística": "evemerístico",
    "evemerísticas": "evemerístico",
    "evemerísticos": "evemerístico",
    "evemias": "evemia",
    "evence": "evencer",
    "evencei": "evencer",
    "evenceis": "evencer",
    "evencem": "evencer",
    "evencemo": "evencer",
    "evencemos": "evencer",
    "evencendo": "evencer",
    "evencera": "evencer",
    "evenceram": "evencer",
    "evenceras": "evencer",
    "evencerde": "evencer",
    "evencerdes": "evencer",
    "evencere": "evencer",
    "evencerei": "evencer",
    "evencereis": "evencer",
    "evencerem": "evencer",
    "evenceremos": "evencer",
    "evenceres": "evencer",
    "evenceria": "evencer",
    "evenceriam": "evencer",
    "evencerias": "evencer",
    "evencermo": "evencer",
    "evencermos": "evencer",
    "evencerá": "evencer",
    "evencerás": "evencer",
    "evencerão": "evencer",
    "evenceríamos": "evencer",
    "evenceríeis": "evencer",
    "evences": "evencer",
    "evencesse": "evencer",
    "evencessem": "evencer",
    "evencesses": "evencer",
    "evenceste": "evencer",
    "evencestes": "evencer",
    "evenceu": "evencer",
    "evenci": "evencer",
    "evencia": "evencer",
    "evenciam": "evencer",
    "evencias": "evencer",
    "evencida": "evencer",
    "evencidas": "evencer",
    "evencido": "evencer",
    "evencidos": "evencer",
    "evencê": "evencer",
    "evencêramo": "evencer",
    "evencêramos": "evencer",
    "evencêrei": "evencer",
    "evencêreis": "evencer",
    "evencêsseis": "evencer",
    "evencêssemos": "evencer",
    "evencíamo": "evencer",
    "evencíamos": "evencer",
    "evencíei": "evencer",
    "evencíeis": "evencer",
    "eventos": "evento",
    "eventrações": "eventração",
    "eventuais": "eventual",
    "eventualidades": "eventualidade",
    "evença": "evencer",
    "evençais": "evencer",
    "evençam": "evencer",
    "evençamo": "evencer",
    "evençamos": "evencer",
    "evenças": "evencer",
    "evenço": "evencer",
    "eversiva": "eversivo",
    "eversivas": "eversivo",
    "eversivos": "eversivo",
    "eversora": "eversor",
    "eversoras": "eversor",
    "eversores": "eversor",
    "eversões": "eversão",
    "everta": "everter",
    "evertais": "everter",
    "evertam": "everter",
    "evertamo": "everter",
    "evertamos": "everter",
    "evertas": "everter",
    "everte": "everter",
    "evertei": "everter",
    "everteis": "everter",
    "evertem": "everter",
    "evertemo": "everter",
    "evertemos": "everter",
    "evertendo": "everter",
    "evertera": "everter",
    "everteram": "everter",
    "everteras": "everter",
    "everterde": "everter",
    "everterdes": "everter",
    "evertere": "everter",
    "everterei": "everter",
    "evertereis": "everter",
    "everterem": "everter",
    "everteremos": "everter",
    "everteres": "everter",
    "everteria": "everter",
    "everteriam": "everter",
    "everterias": "everter",
    "evertermo": "everter",
    "evertermos": "everter",
    "everterá": "everter",
    "everterás": "everter",
    "everterão": "everter",
    "everteríamos": "everter",
    "everteríeis": "everter",
    "evertes": "everter",
    "evertesse": "everter",
    "evertessem": "everter",
    "evertesses": "everter",
    "everteste": "everter",
    "evertestes": "everter",
    "everteu": "everter",
    "everti": "everter",
    "evertia": "everter",
    "evertiam": "everter",
    "evertias": "everter",
    "evertida": "everter",
    "evertidas": "everter",
    "evertido": "everter",
    "evertidos": "everter",
    "everto": "everter",
    "evertê": "everter",
    "evertêramo": "everter",
    "evertêramos": "everter",
    "evertêrei": "everter",
    "evertêreis": "everter",
    "evertêsseis": "everter",
    "evertêssemos": "everter",
    "evertíamo": "everter",
    "evertíamos": "everter",
    "evertíei": "everter",
    "evertíeis": "everter",
    "evexias": "evexia",
    "evicta": "evicto",
    "evictas": "evicto",
    "evictora": "evictor",
    "evictoras": "evictor",
    "evictores": "evictor",
    "evictos": "evicto",
    "evicções": "evicção",
    "evidencia": "evidenciar",
    "evidenciada": "evidenciar",
    "evidenciadas": "evidenciar",
    "evidenciado": "evidenciar",
    "evidenciados": "evidenciar",
    "evidenciai": "evidenciar",
    "evidenciais": "evidenciar",
    "evidenciam": "evidenciar",
    "evidenciamo": "evidenciar",
    "evidenciamos": "evidenciar",
    "evidenciando": "evidenciar",
    "evidenciara": "evidenciar",
    "evidenciaram": "evidenciar",
    "evidenciaras": "evidenciar",
    "evidenciarde": "evidenciar",
    "evidenciardes": "evidenciar",
    "evidenciare": "evidenciar",
    "evidenciarei": "evidenciar",
    "evidenciareis": "evidenciar",
    "evidenciarem": "evidenciar",
    "evidenciaremos": "evidenciar",
    "evidenciares": "evidenciar",
    "evidenciaria": "evidenciar",
    "evidenciariam": "evidenciar",
    "evidenciarias": "evidenciar",
    "evidenciarmo": "evidenciar",
    "evidenciarmos": "evidenciar",
    "evidenciará": "evidenciar",
    "evidenciarás": "evidenciar",
    "evidenciarão": "evidenciar",
    "evidenciaríamos": "evidenciar",
    "evidenciaríeis": "evidenciar",
    "evidencias": "evidenciar",
    "evidenciasse": "evidenciar",
    "evidenciassem": "evidenciar",
    "evidenciasses": "evidenciar",
    "evidenciaste": "evidenciar",
    "evidenciastes": "evidenciar",
    "evidenciava": "evidenciar",
    "evidenciavam": "evidenciar",
    "evidenciavas": "evidenciar",
    "evidencie": "evidenciar",
    "evidenciei": "evidenciar",
    "evidencieis": "evidenciar",
    "evidenciem": "evidenciar",
    "evidenciemo": "evidenciar",
    "evidenciemos": "evidenciar",
    "evidencies": "evidenciar",
    "evidencio": "evidenciar",
    "evidenciou": "evidenciar",
    "evidenciá": "evidenciar",
    "evidenciámo": "evidenciar",
    "evidenciámos": "evidenciar",
    "evidenciáramo": "evidenciar",
    "evidenciáramos": "evidenciar",
    "evidenciárei": "evidenciar",
    "evidenciáreis": "evidenciar",
    "evidenciásseis": "evidenciar",
    "evidenciássemos": "evidenciar",
    "evidenciávamo": "evidenciar",
    "evidenciávamos": "evidenciar",
    "evidenciávei": "evidenciar",
    "evidenciáveis": "evidenciável",
    "evidentes": "evidente",
    "evidilhas": "evidilha",
    "evidências": "evidência",
    "eviscera": "eviscerar",
    "eviscerada": "eviscerar",
    "evisceradas": "eviscerar",
    "eviscerado": "eviscerar",
    "eviscerados": "eviscerar",
    "eviscerai": "eviscerar",
    "eviscerais": "eviscerar",
    "evisceram": "eviscerar",
    "evisceramo": "eviscerar",
    "evisceramos": "eviscerar",
    "eviscerando": "eviscerar",
    "eviscerara": "eviscerar",
    "evisceraram": "eviscerar",
    "evisceraras": "eviscerar",
    "eviscerarde": "eviscerar",
    "eviscerardes": "eviscerar",
    "eviscerare": "eviscerar",
    "eviscerarei": "eviscerar",
    "eviscerareis": "eviscerar",
    "eviscerarem": "eviscerar",
    "evisceraremos": "eviscerar",
    "eviscerares": "eviscerar",
    "evisceraria": "eviscerar",
    "eviscerariam": "eviscerar",
    "eviscerarias": "eviscerar",
    "eviscerarmo": "eviscerar",
    "eviscerarmos": "eviscerar",
    "eviscerará": "eviscerar",
    "eviscerarás": "eviscerar",
    "eviscerarão": "eviscerar",
    "evisceraríamos": "eviscerar",
    "evisceraríeis": "eviscerar",
    "evisceras": "eviscerar",
    "eviscerasse": "eviscerar",
    "eviscerassem": "eviscerar",
    "eviscerasses": "eviscerar",
    "evisceraste": "eviscerar",
    "eviscerastes": "eviscerar",
    "eviscerava": "eviscerar",
    "evisceravam": "eviscerar",
    "evisceravas": "eviscerar",
    "eviscerações": "evisceração",
    "eviscere": "eviscerar",
    "eviscerei": "eviscerar",
    "eviscereis": "eviscerar",
    "eviscerem": "eviscerar",
    "evisceremo": "eviscerar",
    "evisceremos": "eviscerar",
    "evisceres": "eviscerar",
    "eviscero": "eviscerar",
    "eviscerou": "eviscerar",
    "eviscerá": "eviscerar",
    "eviscerámo": "eviscerar",
    "eviscerámos": "eviscerar",
    "evisceráramo": "eviscerar",
    "evisceráramos": "eviscerar",
    "eviscerárei": "eviscerar",
    "evisceráreis": "eviscerar",
    "eviscerásseis": "eviscerar",
    "eviscerássemos": "eviscerar",
    "eviscerávamo": "eviscerar",
    "eviscerávamos": "eviscerar",
    "eviscerávei": "eviscerar",
    "evisceráveis": "eviscerar",
    "evita": "evitar",
    "evitada": "evitar",
    "evitadas": "evitar",
    "evitado": "evitar",
    "evitados": "evitar",
    "evitai": "evitar",
    "evitais": "evitar",
    "evitam": "evitar",
    "evitamentos": "evitamento",
    "evitamo": "evitar",
    "evitamos": "evitar",
    "evitando": "evitar",
    "evitara": "evitar",
    "evitaram": "evitar",
    "evitaras": "evitar",
    "evitarde": "evitar",
    "evitardes": "evitar",
    "evitare": "evitar",
    "evitarei": "evitar",
    "evitareis": "evitar",
    "evitarem": "evitar",
    "evitaremos": "evitar",
    "evitares": "evitar",
    "evitaria": "evitar",
    "evitariam": "evitar",
    "evitarias": "evitar",
    "evitarmo": "evitar",
    "evitarmos": "evitar",
    "evitará": "evitar",
    "evitarás": "evitar",
    "evitarão": "evitar",
    "evitaríamos": "evitar",
    "evitaríeis": "evitar",
    "evitas": "evitar",
    "evitasse": "evitar",
    "evitassem": "evitar",
    "evitasses": "evitar",
    "evitaste": "evitar",
    "evitastes": "evitar",
    "evitava": "evitar",
    "evitavam": "evitar",
    "evitavas": "evitar",
    "evitações": "evitação",
    "evite": "evitar",
    "evitei": "evitar",
    "eviteis": "evitar",
    "evitem": "evitar",
    "evitemo": "evitar",
    "evitemos": "evitar",
    "eviterna": "eviterno",
    "eviternas": "eviterno",
    "eviternidades": "eviternidade",
    "eviternos": "eviterno",
    "evites": "evitar",
    "evito": "evitar",
    "evitou": "evitar",
    "evitá": "evitar",
    "evitámo": "evitar",
    "evitámos": "evitar",
    "evitáramo": "evitar",
    "evitáramos": "evitar",
    "evitárei": "evitar",
    "evitáreis": "evitar",
    "evitásseis": "evitar",
    "evitássemos": "evitar",
    "evitávamo": "evitar",
    "evitávamos": "evitar",
    "evitávei": "evitar",
    "evitáveis": "evitável",
    "evoca": "evocar",
    "evocada": "evocar",
    "evocadas": "evocar",
    "evocado": "evocar",
    "evocadora": "evocador",
    "evocadoras": "evocador",
    "evocadores": "evocador",
    "evocados": "evocar",
    "evocai": "evocar",
    "evocais": "evocar",
    "evocam": "evocar",
    "evocamo": "evocar",
    "evocamos": "evocar",
    "evocando": "evocar",
    "evocantes": "evocante",
    "evocara": "evocar",
    "evocaram": "evocar",
    "evocaras": "evocar",
    "evocarde": "evocar",
    "evocardes": "evocar",
    "evocare": "evocar",
    "evocarei": "evocar",
    "evocareis": "evocar",
    "evocarem": "evocar",
    "evocaremos": "evocar",
    "evocares": "evocar",
    "evocaria": "evocar",
    "evocariam": "evocar",
    "evocarias": "evocar",
    "evocarmo": "evocar",
    "evocarmos": "evocar",
    "evocará": "evocar",
    "evocarás": "evocar",
    "evocarão": "evocar",
    "evocaríamos": "evocar",
    "evocaríeis": "evocar",
    "evocas": "evocar",
    "evocasse": "evocar",
    "evocassem": "evocar",
    "evocasses": "evocar",
    "evocaste": "evocar",
    "evocastes": "evocar",
    "evocativa": "evocativo",
    "evocativas": "evocativo",
    "evocativos": "evocativo",
    "evocatória": "evocatório",
    "evocatórias": "evocatório",
    "evocatórios": "evocatório",
    "evocava": "evocar",
    "evocavam": "evocar",
    "evocavas": "evocar",
    "evocações": "evocação",
    "evoco": "evocar",
    "evocou": "evocar",
    "evocá": "evocar",
    "evocámo": "evocar",
    "evocámos": "evocar",
    "evocáramo": "evocar",
    "evocáramos": "evocar",
    "evocárei": "evocar",
    "evocáreis": "evocar",
    "evocásseis": "evocar",
    "evocássemos": "evocar",
    "evocávamo": "evocar",
    "evocávamos": "evocar",
    "evocávei": "evocar",
    "evocáveis": "evocável",
    "evola": "evolar",
    "evolada": "evolar",
    "evoladas": "evolar",
    "evolado": "evolar",
    "evolados": "evolar",
    "evolai": "evolar",
    "evolais": "evolar",
    "evolam": "evolar",
    "evolamo": "evolar",
    "evolamos": "evolar",
    "evolando": "evolar",
    "evolara": "evolar",
    "evolaram": "evolar",
    "evolaras": "evolar",
    "evolarde": "evolar",
    "evolardes": "evolar",
    "evolare": "evolar",
    "evolarei": "evolar",
    "evolareis": "evolar",
    "evolarem": "evolar",
    "evolaremos": "evolar",
    "evolares": "evolar",
    "evolaria": "evolar",
    "evolariam": "evolar",
    "evolarias": "evolar",
    "evolarmo": "evolar",
    "evolarmos": "evolar",
    "evolará": "evolar",
    "evolarás": "evolar",
    "evolarão": "evolar",
    "evolaríamos": "evolar",
    "evolaríeis": "evolar",
    "evolas": "evolar",
    "evolasse": "evolar",
    "evolassem": "evolar",
    "evolasses": "evolar",
    "evolaste": "evolar",
    "evolastes": "evolar",
    "evolava": "evolar",
    "evolavam": "evolar",
    "evolavas": "evolar",
    "evole": "evolar",
    "evolei": "evolar",
    "evoleis": "evolar",
    "evolem": "evolar",
    "evolemo": "evolar",
    "evolemos": "evolar",
    "evoles": "evolar",
    "evolo": "evolar",
    "evolou": "evolar",
    "evolua": "evoluir",
    "evoluais": "evoluir",
    "evoluam": "evoluir",
    "evoluamo": "evoluir",
    "evoluamos": "evoluir",
    "evoluas": "evoluir",
    "evoluciona": "evolucionar",
    "evolucionada": "evolucionar",
    "evolucionadas": "evolucionar",
    "evolucionado": "evolucionar",
    "evolucionados": "evolucionar",
    "evolucionai": "evolucionar",
    "evolucionais": "evolucionar",
    "evolucionam": "evolucionar",
    "evolucionamo": "evolucionar",
    "evolucionamos": "evolucionar",
    "evolucionando": "evolucionar",
    "evolucionara": "evolucionar",
    "evolucionaram": "evolucionar",
    "evolucionaras": "evolucionar",
    "evolucionardes": "evolucionar",
    "evolucionarei": "evolucionar",
    "evolucionareis": "evolucionar",
    "evolucionarem": "evolucionar",
    "evolucionaremos": "evolucionar",
    "evolucionares": "evolucionar",
    "evolucionaria": "evolucionar",
    "evolucionariam": "evolucionar",
    "evolucionarias": "evolucionar",
    "evolucionarmo": "evolucionar",
    "evolucionarmos": "evolucionar",
    "evolucionará": "evolucionar",
    "evolucionarás": "evolucionar",
    "evolucionarão": "evolucionar",
    "evolucionaríamos": "evolucionar",
    "evolucionaríeis": "evolucionar",
    "evolucionas": "evolucionar",
    "evolucionasse": "evolucionar",
    "evolucionassem": "evolucionar",
    "evolucionasses": "evolucionar",
    "evolucionaste": "evolucionar",
    "evolucionastes": "evolucionar",
    "evolucionava": "evolucionar",
    "evolucionavam": "evolucionar",
    "evolucionavas": "evolucionar",
    "evolucione": "evolucionar",
    "evolucionei": "evolucionar",
    "evolucioneis": "evolucionar",
    "evolucionem": "evolucionar",
    "evolucionemo": "evolucionar",
    "evolucionemos": "evolucionar",
    "evoluciones": "evolucionar",
    "evolucionismos": "evolucionismo",
    "evolucionistas": "evolucionista",
    "evoluciono": "evolucionar",
    "evolucionou": "evolucionar",
    "evolucionámo": "evolucionar",
    "evolucionámos": "evolucionar",
    "evolucionáramo": "evolucionar",
    "evolucionáramos": "evolucionar",
    "evolucionáreis": "evolucionar",
    "evolucionária": "evolucionário",
    "evolucionárias": "evolucionário",
    "evolucionários": "evolucionário",
    "evolucionásseis": "evolucionar",
    "evolucionássemos": "evolucionar",
    "evolucionávamo": "evolucionar",
    "evolucionávamos": "evolucionar",
    "evolucionáveis": "evolucionável",
    "evoluem": "evoluir",
    "evolui": "evoluir",
    "evoluindo": "evoluir",
    "evoluirde": "evoluir",
    "evoluirdes": "evoluir",
    "evoluirei": "evoluir",
    "evoluireis": "evoluir",
    "evoluiremos": "evoluir",
    "evoluiria": "evoluir",
    "evoluiriam": "evoluir",
    "evoluirias": "evoluir",
    "evoluirmo": "evoluir",
    "evoluirmos": "evoluir",
    "evoluirá": "evoluir",
    "evoluirás": "evoluir",
    "evoluirão": "evoluir",
    "evoluiríamos": "evoluir",
    "evoluiríeis": "evoluir",
    "evoluis": "evoluir",
    "evoluiu": "evoluir",
    "evoluo": "evoluir",
    "evoluta": "evoluto",
    "evolutas": "evoluto",
    "evolutistas": "evolutista",
    "evolutiva": "evolutivo",
    "evolutivas": "evolutivo",
    "evolutivos": "evolutivo",
    "evolutos": "evoluto",
    "evoluções": "evolução",
    "evoluí": "evoluir",
    "evoluía": "evoluir",
    "evoluíam": "evoluir",
    "evoluíamo": "evoluir",
    "evoluíamos": "evoluir",
    "evoluías": "evoluir",
    "evoluída": "evoluir",
    "evoluídas": "evoluir",
    "evoluído": "evoluir",
    "evoluídos": "evoluir",
    "evoluíei": "evoluir",
    "evoluíeis": "evoluir",
    "evoluímo": "evoluir",
    "evoluímos": "evoluir",
    "evoluíra": "evoluir",
    "evoluíram": "evoluir",
    "evoluíramo": "evoluir",
    "evoluíramos": "evoluir",
    "evoluíras": "evoluir",
    "evoluíre": "evoluir",
    "evoluírei": "evoluir",
    "evoluíreis": "evoluir",
    "evoluírem": "evoluir",
    "evoluíres": "evoluir",
    "evoluís": "evoluir",
    "evoluísse": "evoluir",
    "evoluísseis": "evoluir",
    "evoluíssem": "evoluir",
    "evoluíssemos": "evoluir",
    "evoluísses": "evoluir",
    "evoluíste": "evoluir",
    "evoluístes": "evoluir",
    "evolva": "evolver",
    "evolvais": "evolver",
    "evolvam": "evolver",
    "evolvamo": "evolver",
    "evolvamos": "evolver",
    "evolvas": "evolver",
    "evolve": "evolver",
    "evolvei": "evolver",
    "evolveis": "evolver",
    "evolvem": "evolver",
    "evolvemo": "evolver",
    "evolvemos": "evolver",
    "evolvendo": "evolver",
    "evolventes": "evolvente",
    "evolvera": "evolver",
    "evolveram": "evolver",
    "evolveras": "evolver",
    "evolverdes": "evolver",
    "evolverei": "evolver",
    "evolvereis": "evolver",
    "evolverem": "evolver",
    "evolveremos": "evolver",
    "evolveres": "evolver",
    "evolveria": "evolver",
    "evolveriam": "evolver",
    "evolverias": "evolver",
    "evolvermo": "evolver",
    "evolvermos": "evolver",
    "evolverá": "evolver",
    "evolverás": "evolver",
    "evolverão": "evolver",
    "evolveríamos": "evolver",
    "evolveríeis": "evolver",
    "evolves": "evolver",
    "evolvesse": "evolver",
    "evolvessem": "evolver",
    "evolvesses": "evolver",
    "evolveste": "evolver",
    "evolvestes": "evolver",
    "evolveu": "evolver",
    "evolvi": "evolver",
    "evolvia": "evolver",
    "evolviam": "evolver",
    "evolvias": "evolver",
    "evolvida": "evolver",
    "evolvidas": "evolver",
    "evolvido": "evolver",
    "evolvidos": "evolver",
    "evolvo": "evolver",
    "evolvêramo": "evolver",
    "evolvêramos": "evolver",
    "evolvêreis": "evolver",
    "evolvêsseis": "evolver",
    "evolvêssemos": "evolver",
    "evolvíamo": "evolver",
    "evolvíamos": "evolver",
    "evolvíeis": "evolver",
    "evolá": "evolar",
    "evolámo": "evolar",
    "evolámos": "evolar",
    "evoláramo": "evolar",
    "evoláramos": "evolar",
    "evolárei": "evolar",
    "evoláreis": "evolar",
    "evolásseis": "evolar",
    "evolássemos": "evolar",
    "evolávamo": "evolar",
    "evolávamos": "evolar",
    "evolávei": "evolar",
    "evoláveis": "evolar",
    "evoque": "evocar",
    "evoquei": "evocar",
    "evoqueis": "evocar",
    "evoquem": "evocar",
    "evoquemo": "evocar",
    "evoquemos": "evocar",
    "evoques": "evocar",
    "evos": "evo",
    "evulsiva": "evulsivo",
    "evulsivas": "evulsivo",
    "evulsivos": "evulsivo",
    "evulsões": "evulsão",
    "evémica": "evémico",
    "evémicas": "evémico",
    "evémicos": "evémico",
    "evérgetas": "evérgeta",
    "evônimos": "evônimo",
    "exabunda": "exabundar",
    "exabundada": "exabundar",
    "exabundadas": "exabundar",
    "exabundado": "exabundar",
    "exabundados": "exabundar",
    "exabundai": "exabundar",
    "exabundais": "exabundar",
    "exabundam": "exabundar",
    "exabundamo": "exabundar",
    "exabundamos": "exabundar",
    "exabundando": "exabundar",
    "exabundara": "exabundar",
    "exabundaram": "exabundar",
    "exabundaras": "exabundar",
    "exabundardes": "exabundar",
    "exabundarei": "exabundar",
    "exabundareis": "exabundar",
    "exabundarem": "exabundar",
    "exabundaremos": "exabundar",
    "exabundares": "exabundar",
    "exabundaria": "exabundar",
    "exabundariam": "exabundar",
    "exabundarias": "exabundar",
    "exabundarmo": "exabundar",
    "exabundarmos": "exabundar",
    "exabundará": "exabundar",
    "exabundarás": "exabundar",
    "exabundarão": "exabundar",
    "exabundaríamos": "exabundar",
    "exabundaríeis": "exabundar",
    "exabundas": "exabundar",
    "exabundasse": "exabundar",
    "exabundassem": "exabundar",
    "exabundasses": "exabundar",
    "exabundaste": "exabundar",
    "exabundastes": "exabundar",
    "exabundava": "exabundar",
    "exabundavam": "exabundar",
    "exabundavas": "exabundar",
    "exabunde": "exabundar",
    "exabundei": "exabundar",
    "exabundeis": "exabundar",
    "exabundem": "exabundar",
    "exabundemo": "exabundar",
    "exabundemos": "exabundar",
    "exabundes": "exabundar",
    "exabundo": "exabundar",
    "exabundou": "exabundar",
    "exabundámo": "exabundar",
    "exabundámos": "exabundar",
    "exabundáramo": "exabundar",
    "exabundáramos": "exabundar",
    "exabundáreis": "exabundar",
    "exabundásseis": "exabundar",
    "exabundássemos": "exabundar",
    "exabundávamo": "exabundar",
    "exabundávamos": "exabundar",
    "exabundáveis": "exabundar",
    "exabundâncias": "exabundância",
    "exacerba": "exacerbar",
    "exacerbada": "exacerbar",
    "exacerbadas": "exacerbar",
    "exacerbado": "exacerbar",
    "exacerbadora": "exacerbador",
    "exacerbadoras": "exacerbador",
    "exacerbadores": "exacerbador",
    "exacerbados": "exacerbar",
    "exacerbadíssima": "exacerbado",
    "exacerbadíssimas": "exacerbado",
    "exacerbadíssimo": "exacerbado",
    "exacerbadíssimos": "exacerbado",
    "exacerbai": "exacerbar",
    "exacerbais": "exacerbar",
    "exacerbam": "exacerbar",
    "exacerbamentos": "exacerbamento",
    "exacerbamo": "exacerbar",
    "exacerbamos": "exacerbar",
    "exacerbando": "exacerbar",
    "exacerbara": "exacerbar",
    "exacerbaram": "exacerbar",
    "exacerbaras": "exacerbar",
    "exacerbarde": "exacerbar",
    "exacerbardes": "exacerbar",
    "exacerbare": "exacerbar",
    "exacerbarei": "exacerbar",
    "exacerbareis": "exacerbar",
    "exacerbarem": "exacerbar",
    "exacerbaremos": "exacerbar",
    "exacerbares": "exacerbar",
    "exacerbaria": "exacerbar",
    "exacerbariam": "exacerbar",
    "exacerbarias": "exacerbar",
    "exacerbarmo": "exacerbar",
    "exacerbarmos": "exacerbar",
    "exacerbará": "exacerbar",
    "exacerbarás": "exacerbar",
    "exacerbarão": "exacerbar",
    "exacerbaríamos": "exacerbar",
    "exacerbaríeis": "exacerbar",
    "exacerbas": "exacerbar",
    "exacerbasse": "exacerbar",
    "exacerbassem": "exacerbar",
    "exacerbasses": "exacerbar",
    "exacerbaste": "exacerbar",
    "exacerbastes": "exacerbar",
    "exacerbava": "exacerbar",
    "exacerbavam": "exacerbar",
    "exacerbavas": "exacerbar",
    "exacerbações": "exacerbação",
    "exacerbe": "exacerbar",
    "exacerbei": "exacerbar",
    "exacerbeis": "exacerbar",
    "exacerbem": "exacerbar",
    "exacerbemo": "exacerbar",
    "exacerbemos": "exacerbar",
    "exacerbes": "exacerbar",
    "exacerbo": "exacerbar",
    "exacerbou": "exacerbar",
    "exacerbá": "exacerbar",
    "exacerbámo": "exacerbar",
    "exacerbámos": "exacerbar",
    "exacerbáramo": "exacerbar",
    "exacerbáramos": "exacerbar",
    "exacerbárei": "exacerbar",
    "exacerbáreis": "exacerbar",
    "exacerbásseis": "exacerbar",
    "exacerbássemos": "exacerbar",
    "exacerbávamo": "exacerbar",
    "exacerbávamos": "exacerbar",
    "exacerbávei": "exacerbar",
    "exacerbáveis": "exacerbável",
    "exacta": "exacto",
    "exactas": "exacto",
    "exactidões": "exactidão",
    "exactitudes": "exactitude",
    "exactora": "exactor",
    "exactoras": "exactor",
    "exactores": "exactor",
    "exactos": "exacto",
    "exacções": "exacção",
    "exagera": "exagerar",
    "exagerada": "exagerar",
    "exageradas": "exagerar",
    "exagerado": "exagerar",
    "exageradora": "exagerador",
    "exageradoras": "exagerador",
    "exageradores": "exagerador",
    "exagerados": "exagerar",
    "exagerai": "exagerar",
    "exagerais": "exagerar",
    "exageram": "exagerar",
    "exageramentos": "exageramento",
    "exageramo": "exagerar",
    "exageramos": "exagerar",
    "exagerando": "exagerar",
    "exagerara": "exagerar",
    "exageraram": "exagerar",
    "exageraras": "exagerar",
    "exagerarde": "exagerar",
    "exagerardes": "exagerar",
    "exagerare": "exagerar",
    "exagerarei": "exagerar",
    "exagerareis": "exagerar",
    "exagerarem": "exagerar",
    "exageraremos": "exagerar",
    "exagerares": "exagerar",
    "exageraria": "exagerar",
    "exagerariam": "exagerar",
    "exagerarias": "exagerar",
    "exagerarmo": "exagerar",
    "exagerarmos": "exagerar",
    "exagerará": "exagerar",
    "exagerarás": "exagerar",
    "exagerarão": "exagerar",
    "exageraríamos": "exagerar",
    "exageraríeis": "exagerar",
    "exageras": "exagerar",
    "exagerasse": "exagerar",
    "exagerassem": "exagerar",
    "exagerasses": "exagerar",
    "exageraste": "exagerar",
    "exagerastes": "exagerar",
    "exagerativa": "exagerativo",
    "exagerativas": "exagerativo",
    "exagerativos": "exagerativo",
    "exagerava": "exagerar",
    "exageravam": "exagerar",
    "exageravas": "exagerar",
    "exagerações": "exageração",
    "exagere": "exagerar",
    "exagerei": "exagerar",
    "exagereis": "exagerar",
    "exagerem": "exagerar",
    "exageremo": "exagerar",
    "exageremos": "exagerar",
    "exageres": "exagerar",
    "exagero": "exagerar",
    "exageros": "exagero",
    "exagerou": "exagerar",
    "exagerá": "exagerar",
    "exagerámo": "exagerar",
    "exagerámos": "exagerar",
    "exageráramo": "exagerar",
    "exageráramos": "exagerar",
    "exagerárei": "exagerar",
    "exageráreis": "exagerar",
    "exagerásseis": "exagerar",
    "exagerássemos": "exagerar",
    "exagerávamo": "exagerar",
    "exagerávamos": "exagerar",
    "exagerávei": "exagerar",
    "exageráveis": "exagerar",
    "exagita": "exagitar",
    "exagitada": "exagitar",
    "exagitadas": "exagitar",
    "exagitado": "exagitar",
    "exagitados": "exagitar",
    "exagitai": "exagitar",
    "exagitais": "exagitar",
    "exagitam": "exagitar",
    "exagitamo": "exagitar",
    "exagitamos": "exagitar",
    "exagitando": "exagitar",
    "exagitara": "exagitar",
    "exagitaram": "exagitar",
    "exagitaras": "exagitar",
    "exagitarde": "exagitar",
    "exagitardes": "exagitar",
    "exagitare": "exagitar",
    "exagitarei": "exagitar",
    "exagitareis": "exagitar",
    "exagitarem": "exagitar",
    "exagitaremos": "exagitar",
    "exagitares": "exagitar",
    "exagitaria": "exagitar",
    "exagitariam": "exagitar",
    "exagitarias": "exagitar",
    "exagitarmo": "exagitar",
    "exagitarmos": "exagitar",
    "exagitará": "exagitar",
    "exagitarás": "exagitar",
    "exagitarão": "exagitar",
    "exagitaríamos": "exagitar",
    "exagitaríeis": "exagitar",
    "exagitas": "exagitar",
    "exagitasse": "exagitar",
    "exagitassem": "exagitar",
    "exagitasses": "exagitar",
    "exagitaste": "exagitar",
    "exagitastes": "exagitar",
    "exagitava": "exagitar",
    "exagitavam": "exagitar",
    "exagitavas": "exagitar",
    "exagite": "exagitar",
    "exagitei": "exagitar",
    "exagiteis": "exagitar",
    "exagitem": "exagitar",
    "exagitemo": "exagitar",
    "exagitemos": "exagitar",
    "exagites": "exagitar",
    "exagito": "exagitar",
    "exagitou": "exagitar",
    "exagitá": "exagitar",
    "exagitámo": "exagitar",
    "exagitámos": "exagitar",
    "exagitáramo": "exagitar",
    "exagitáramos": "exagitar",
    "exagitárei": "exagitar",
    "exagitáreis": "exagitar",
    "exagitásseis": "exagitar",
    "exagitássemos": "exagitar",
    "exagitávamo": "exagitar",
    "exagitávamos": "exagitar",
    "exagitávei": "exagitar",
    "exagitáveis": "exagitar",
    "exala": "exalar",
    "exalada": "exalar",
    "exaladas": "exalar",
    "exalado": "exalar",
    "exalados": "exalar",
    "exalai": "exalar",
    "exalais": "exalar",
    "exalam": "exalar",
    "exalamo": "exalar",
    "exalamos": "exalar",
    "exalando": "exalar",
    "exalantes": "exalante",
    "exalara": "exalar",
    "exalaram": "exalar",
    "exalaras": "exalar",
    "exalarde": "exalar",
    "exalardes": "exalar",
    "exalare": "exalar",
    "exalarei": "exalar",
    "exalareis": "exalar",
    "exalarem": "exalar",
    "exalaremos": "exalar",
    "exalares": "exalar",
    "exalaria": "exalar",
    "exalariam": "exalar",
    "exalarias": "exalar",
    "exalarmo": "exalar",
    "exalarmos": "exalar",
    "exalará": "exalar",
    "exalarás": "exalar",
    "exalarão": "exalar",
    "exalaríamos": "exalar",
    "exalaríeis": "exalar",
    "exalas": "exalar",
    "exalasse": "exalar",
    "exalassem": "exalar",
    "exalasses": "exalar",
    "exalaste": "exalar",
    "exalastes": "exalar",
    "exalava": "exalar",
    "exalavam": "exalar",
    "exalavas": "exalar",
    "exalações": "exalação",
    "exalce": "exalçar",
    "exalcei": "exalçar",
    "exalceis": "exalçar",
    "exalcem": "exalçar",
    "exalcemo": "exalçar",
    "exalcemos": "exalçar",
    "exalces": "exalçar",
    "exale": "exalar",
    "exalei": "exalar",
    "exaleis": "exalar",
    "exalem": "exalar",
    "exalemo": "exalar",
    "exalemos": "exalar",
    "exales": "exalar",
    "exalo": "exalar",
    "exalou": "exalar",
    "exalta": "exaltar",
    "exaltada": "exaltar",
    "exaltadas": "exaltar",
    "exaltado": "exaltar",
    "exaltadora": "exaltador",
    "exaltadoras": "exaltador",
    "exaltadores": "exaltador",
    "exaltados": "exaltar",
    "exaltadíssima": "exaltado",
    "exaltadíssimas": "exaltado",
    "exaltadíssimo": "exaltado",
    "exaltadíssimos": "exaltado",
    "exaltai": "exaltar",
    "exaltais": "exaltar",
    "exaltam": "exaltar",
    "exaltamentos": "exaltamento",
    "exaltamo": "exaltar",
    "exaltamos": "exaltar",
    "exaltando": "exaltar",
    "exaltantes": "exaltante",
    "exaltara": "exaltar",
    "exaltaram": "exaltar",
    "exaltaras": "exaltar",
    "exaltarde": "exaltar",
    "exaltardes": "exaltar",
    "exaltare": "exaltar",
    "exaltarei": "exaltar",
    "exaltareis": "exaltar",
    "exaltarem": "exaltar",
    "exaltaremos": "exaltar",
    "exaltares": "exaltar",
    "exaltaria": "exaltar",
    "exaltariam": "exaltar",
    "exaltarias": "exaltar",
    "exaltarmo": "exaltar",
    "exaltarmos": "exaltar",
    "exaltará": "exaltar",
    "exaltarás": "exaltar",
    "exaltarão": "exaltar",
    "exaltaríamos": "exaltar",
    "exaltaríeis": "exaltar",
    "exaltas": "exaltar",
    "exaltasse": "exaltar",
    "exaltassem": "exaltar",
    "exaltasses": "exaltar",
    "exaltaste": "exaltar",
    "exaltastes": "exaltar",
    "exaltava": "exaltar",
    "exaltavam": "exaltar",
    "exaltavas": "exaltar",
    "exaltações": "exaltação",
    "exalte": "exaltar",
    "exaltei": "exaltar",
    "exalteis": "exaltar",
    "exaltem": "exaltar",
    "exaltemo": "exaltar",
    "exaltemos": "exaltar",
    "exaltes": "exaltar",
    "exalto": "exaltar",
    "exaltou": "exaltar",
    "exaltá": "exaltar",
    "exaltámo": "exaltar",
    "exaltámos": "exaltar",
    "exaltáramo": "exaltar",
    "exaltáramos": "exaltar",
    "exaltárei": "exaltar",
    "exaltáreis": "exaltar",
    "exaltásseis": "exaltar",
    "exaltássemos": "exaltar",
    "exaltávamo": "exaltar",
    "exaltávamos": "exaltar",
    "exaltávei": "exaltar",
    "exaltáveis": "exaltar",
    "exalá": "exalar",
    "exalámo": "exalar",
    "exalámos": "exalar",
    "exaláramo": "exalar",
    "exaláramos": "exalar",
    "exalárei": "exalar",
    "exaláreis": "exalar",
    "exalásseis": "exalar",
    "exalássemos": "exalar",
    "exalávamo": "exalar",
    "exalávamos": "exalar",
    "exalávei": "exalar",
    "exaláveis": "exalar",
    "exalça": "exalçar",
    "exalçada": "exalçar",
    "exalçadas": "exalçar",
    "exalçado": "exalçar",
    "exalçados": "exalçar",
    "exalçai": "exalçar",
    "exalçais": "exalçar",
    "exalçam": "exalçar",
    "exalçamentos": "exalçamento",
    "exalçamo": "exalçar",
    "exalçamos": "exalçar",
    "exalçando": "exalçar",
    "exalçara": "exalçar",
    "exalçaram": "exalçar",
    "exalçaras": "exalçar",
    "exalçarde": "exalçar",
    "exalçardes": "exalçar",
    "exalçare": "exalçar",
    "exalçarei": "exalçar",
    "exalçareis": "exalçar",
    "exalçarem": "exalçar",
    "exalçaremos": "exalçar",
    "exalçares": "exalçar",
    "exalçaria": "exalçar",
    "exalçariam": "exalçar",
    "exalçarias": "exalçar",
    "exalçarmo": "exalçar",
    "exalçarmos": "exalçar",
    "exalçará": "exalçar",
    "exalçarás": "exalçar",
    "exalçarão": "exalçar",
    "exalçaríamos": "exalçar",
    "exalçaríeis": "exalçar",
    "exalças": "exalçar",
    "exalçasse": "exalçar",
    "exalçassem": "exalçar",
    "exalçasses": "exalçar",
    "exalçaste": "exalçar",
    "exalçastes": "exalçar",
    "exalçava": "exalçar",
    "exalçavam": "exalçar",
    "exalçavas": "exalçar",
    "exalçações": "exalçação",
    "exalço": "exalçar",
    "exalçou": "exalçar",
    "exalçá": "exalçar",
    "exalçámo": "exalçar",
    "exalçámos": "exalçar",
    "exalçáramo": "exalçar",
    "exalçáramos": "exalçar",
    "exalçárei": "exalçar",
    "exalçáreis": "exalçar",
    "exalçásseis": "exalçar",
    "exalçássemos": "exalçar",
    "exalçávamo": "exalçar",
    "exalçávamos": "exalçar",
    "exalçávei": "exalçar",
    "exalçáveis": "exalçar",
    "exames": "exame",
    "examina": "examinar",
    "examinada": "examinar",
    "examinadas": "examinar",
    "examinado": "examinar",
    "examinadora": "examinador",
    "examinadoras": "examinador",
    "examinadores": "examinador",
    "examinados": "examinar",
    "examinai": "examinar",
    "examinais": "examinar",
    "examinam": "examinar",
    "examinamo": "examinar",
    "examinamos": "examinar",
    "examinanda": "examinando",
    "examinandas": "examinando",
    "examinando": "examinar",
    "examinandos": "examinando",
    "examinara": "examinar",
    "examinaram": "examinar",
    "examinaras": "examinar",
    "examinarde": "examinar",
    "examinardes": "examinar",
    "examinare": "examinar",
    "examinarei": "examinar",
    "examinareis": "examinar",
    "examinarem": "examinar",
    "examinaremos": "examinar",
    "examinares": "examinar",
    "examinaria": "examinar",
    "examinariam": "examinar",
    "examinarias": "examinar",
    "examinarmo": "examinar",
    "examinarmos": "examinar",
    "examinará": "examinar",
    "examinarás": "examinar",
    "examinarão": "examinar",
    "examinaríamos": "examinar",
    "examinaríeis": "examinar",
    "examinas": "examinar",
    "examinasse": "examinar",
    "examinassem": "examinar",
    "examinasses": "examinar",
    "examinaste": "examinar",
    "examinastes": "examinar",
    "examinava": "examinar",
    "examinavam": "examinar",
    "examinavas": "examinar",
    "examine": "examinar",
    "examinei": "examinar",
    "examineis": "examinar",
    "examinem": "examinar",
    "examinemo": "examinar",
    "examinemos": "examinar",
    "examines": "examinar",
    "examino": "examinar",
    "examinou": "examinar",
    "examiná": "examinar",
    "examinámo": "examinar",
    "examinámos": "examinar",
    "examináramo": "examinar",
    "examináramos": "examinar",
    "examinárei": "examinar",
    "examináreis": "examinar",
    "examinásseis": "examinar",
    "examinássemos": "examinar",
    "examinávamo": "examinar",
    "examinávamos": "examinar",
    "examinávei": "examinar",
    "examináveis": "examinável",
    "exangues": "exangue",
    "exanias": "exania",
    "exanimada": "exanimado",
    "exanimadas": "exanimado",
    "exanimados": "exanimado",
    "exanimações": "exanimação",
    "exantemas": "exantema",
    "exantemosa": "exantemoso",
    "exantemosas": "exantemoso",
    "exantemosos": "exantemoso",
    "exantemática": "exantemático",
    "exantemáticas": "exantemático",
    "exantemáticos": "exantemático",
    "exara": "exarar",
    "exarada": "exarar",
    "exaradas": "exarar",
    "exarado": "exarar",
    "exarados": "exarar",
    "exarai": "exarar",
    "exarais": "exarar",
    "exaram": "exarar",
    "exaramo": "exarar",
    "exaramos": "exarar",
    "exarando": "exarar",
    "exarara": "exarar",
    "exararam": "exarar",
    "exararas": "exarar",
    "exararde": "exarar",
    "exarardes": "exarar",
    "exarare": "exarar",
    "exararei": "exarar",
    "exarareis": "exarar",
    "exararem": "exarar",
    "exararemos": "exarar",
    "exarares": "exarar",
    "exararia": "exarar",
    "exarariam": "exarar",
    "exararias": "exarar",
    "exararmo": "exarar",
    "exararmos": "exarar",
    "exarará": "exarar",
    "exararás": "exarar",
    "exararão": "exarar",
    "exararíamos": "exarar",
    "exararíeis": "exarar",
    "exaras": "exarar",
    "exarasse": "exarar",
    "exarassem": "exarar",
    "exarasses": "exarar",
    "exaraste": "exarar",
    "exarastes": "exarar",
    "exarava": "exarar",
    "exaravam": "exarar",
    "exaravas": "exarar",
    "exarcados": "exarcado",
    "exarcos": "exarco",
    "exare": "exarar",
    "exarei": "exarar",
    "exareis": "exarar",
    "exarem": "exarar",
    "exaremo": "exarar",
    "exaremos": "exarar",
    "exares": "exarar",
    "exaro": "exarar",
    "exarou": "exarar",
    "exará": "exarar",
    "exarámo": "exarar",
    "exarámos": "exarar",
    "exaráramo": "exarar",
    "exaráramos": "exarar",
    "exarárei": "exarar",
    "exaráreis": "exarar",
    "exarásseis": "exarar",
    "exarássemos": "exarar",
    "exarávamo": "exarar",
    "exarávamos": "exarar",
    "exarávei": "exarar",
    "exaráveis": "exarar",
    "exaspera": "exasperar",
    "exasperada": "exasperar",
    "exasperadas": "exasperar",
    "exasperado": "exasperar",
    "exasperadora": "exasperador",
    "exasperadoras": "exasperador",
    "exasperadores": "exasperador",
    "exasperados": "exasperar",
    "exasperai": "exasperar",
    "exasperais": "exasperar",
    "exasperam": "exasperar",
    "exasperamentos": "exasperamento",
    "exasperamo": "exasperar",
    "exasperamos": "exasperar",
    "exasperando": "exasperar",
    "exasperantes": "exasperante",
    "exasperara": "exasperar",
    "exasperaram": "exasperar",
    "exasperaras": "exasperar",
    "exasperarde": "exasperar",
    "exasperardes": "exasperar",
    "exasperare": "exasperar",
    "exasperarei": "exasperar",
    "exasperareis": "exasperar",
    "exasperarem": "exasperar",
    "exasperaremos": "exasperar",
    "exasperares": "exasperar",
    "exasperaria": "exasperar",
    "exasperariam": "exasperar",
    "exasperarias": "exasperar",
    "exasperarmo": "exasperar",
    "exasperarmos": "exasperar",
    "exasperará": "exasperar",
    "exasperarás": "exasperar",
    "exasperarão": "exasperar",
    "exasperaríamos": "exasperar",
    "exasperaríeis": "exasperar",
    "exasperas": "exasperar",
    "exasperasse": "exasperar",
    "exasperassem": "exasperar",
    "exasperasses": "exasperar",
    "exasperaste": "exasperar",
    "exasperastes": "exasperar",
    "exasperava": "exasperar",
    "exasperavam": "exasperar",
    "exasperavas": "exasperar",
    "exasperações": "exasperação",
    "exaspere": "exasperar",
    "exasperei": "exasperar",
    "exaspereis": "exasperar",
    "exasperem": "exasperar",
    "exasperemo": "exasperar",
    "exasperemos": "exasperar",
    "exasperes": "exasperar",
    "exaspero": "exasperar",
    "exasperos": "exaspero",
    "exasperou": "exasperar",
    "exasperá": "exasperar",
    "exasperámo": "exasperar",
    "exasperámos": "exasperar",
    "exasperáramo": "exasperar",
    "exasperáramos": "exasperar",
    "exasperárei": "exasperar",
    "exasperáreis": "exasperar",
    "exasperásseis": "exasperar",
    "exasperássemos": "exasperar",
    "exasperávamo": "exasperar",
    "exasperávamos": "exasperar",
    "exasperávei": "exasperar",
    "exasperáveis": "exasperar",
    "exaura": "exaurir",
    "exaurais": "exaurir",
    "exauram": "exaurir",
    "exauramo": "exaurir",
    "exauramos": "exaurir",
    "exauras": "exaurir",
    "exaure": "exaurir",
    "exaurem": "exaurir",
    "exaures": "exaurir",
    "exauri": "exaurir",
    "exauria": "exaurir",
    "exauriam": "exaurir",
    "exaurias": "exaurir",
    "exaurida": "exaurir",
    "exauridas": "exaurir",
    "exaurido": "exaurir",
    "exauridos": "exaurir",
    "exaurimo": "exaurir",
    "exaurimos": "exaurir",
    "exaurindo": "exaurir",
    "exaurira": "exaurir",
    "exauriram": "exaurir",
    "exauriras": "exaurir",
    "exaurirde": "exaurir",
    "exaurirdes": "exaurir",
    "exaurire": "exaurir",
    "exaurirei": "exaurir",
    "exaurireis": "exaurir",
    "exaurirem": "exaurir",
    "exauriremos": "exaurir",
    "exaurires": "exaurir",
    "exauriria": "exaurir",
    "exauririam": "exaurir",
    "exauririas": "exaurir",
    "exaurirmo": "exaurir",
    "exaurirmos": "exaurir",
    "exaurirá": "exaurir",
    "exaurirás": "exaurir",
    "exaurirão": "exaurir",
    "exauriríamos": "exaurir",
    "exauriríeis": "exaurir",
    "exauris": "exaurir",
    "exaurisse": "exaurir",
    "exaurissem": "exaurir",
    "exaurisses": "exaurir",
    "exauriste": "exaurir",
    "exauristes": "exaurir",
    "exauriu": "exaurir",
    "exauro": "exaurir",
    "exauríamo": "exaurir",
    "exauríamos": "exaurir",
    "exauríei": "exaurir",
    "exauríeis": "exaurir",
    "exauríramo": "exaurir",
    "exauríramos": "exaurir",
    "exaurírei": "exaurir",
    "exauríreis": "exaurir",
    "exaurísseis": "exaurir",
    "exauríssemos": "exaurir",
    "exauríveis": "exaurível",
    "exausta": "exausto",
    "exaustada": "exaustar",
    "exaustadas": "exaustar",
    "exaustado": "exaustar",
    "exaustados": "exaustar",
    "exaustai": "exaustar",
    "exaustais": "exaustar",
    "exaustam": "exaustar",
    "exaustamo": "exaustar",
    "exaustamos": "exaustar",
    "exaustando": "exaustar",
    "exaustara": "exaustar",
    "exaustaram": "exaustar",
    "exaustaras": "exaustar",
    "exaustarde": "exaustar",
    "exaustardes": "exaustar",
    "exaustare": "exaustar",
    "exaustarei": "exaustar",
    "exaustareis": "exaustar",
    "exaustarem": "exaustar",
    "exaustaremos": "exaustar",
    "exaustares": "exaustar",
    "exaustaria": "exaustar",
    "exaustariam": "exaustar",
    "exaustarias": "exaustar",
    "exaustarmo": "exaustar",
    "exaustarmos": "exaustar",
    "exaustará": "exaustar",
    "exaustarás": "exaustar",
    "exaustarão": "exaustar",
    "exaustaríamos": "exaustar",
    "exaustaríeis": "exaustar",
    "exaustas": "exausto",
    "exaustasse": "exaustar",
    "exaustassem": "exaustar",
    "exaustasses": "exaustar",
    "exaustaste": "exaustar",
    "exaustastes": "exaustar",
    "exaustava": "exaustar",
    "exaustavam": "exaustar",
    "exaustavas": "exaustar",
    "exaustações": "exaustação",
    "exauste": "exaustar",
    "exaustei": "exaustar",
    "exausteis": "exaustar",
    "exaustem": "exaustar",
    "exaustemo": "exaustar",
    "exaustemos": "exaustar",
    "exaustes": "exaustar",
    "exaustiva": "exaustivo",
    "exaustivas": "exaustivo",
    "exaustivos": "exaustivo",
    "exausto": "exaustar",
    "exaustores": "exaustor",
    "exaustos": "exausto",
    "exaustou": "exaustar",
    "exaustá": "exaustar",
    "exaustámo": "exaustar",
    "exaustámos": "exaustar",
    "exaustáramo": "exaustar",
    "exaustáramos": "exaustar",
    "exaustárei": "exaustar",
    "exaustáreis": "exaustar",
    "exaustásseis": "exaustar",
    "exaustássemos": "exaustar",
    "exaustávamo": "exaustar",
    "exaustávamos": "exaustar",
    "exaustávei": "exaustar",
    "exaustáveis": "exaustar",
    "exaustões": "exaustão",
    "exautividades": "exautividade",
    "exautora": "exautorar",
    "exautorada": "exautorar",
    "exautoradas": "exautorar",
    "exautorado": "exautorar",
    "exautorados": "exautorar",
    "exautorai": "exautorar",
    "exautorais": "exautorar",
    "exautoram": "exautorar",
    "exautoramo": "exautorar",
    "exautoramos": "exautorar",
    "exautorando": "exautorar",
    "exautorara": "exautorar",
    "exautoraram": "exautorar",
    "exautoraras": "exautorar",
    "exautorarde": "exautorar",
    "exautorardes": "exautorar",
    "exautorare": "exautorar",
    "exautorarei": "exautorar",
    "exautorareis": "exautorar",
    "exautorarem": "exautorar",
    "exautoraremos": "exautorar",
    "exautorares": "exautorar",
    "exautoraria": "exautorar",
    "exautorariam": "exautorar",
    "exautorarias": "exautorar",
    "exautorarmo": "exautorar",
    "exautorarmos": "exautorar",
    "exautorará": "exautorar",
    "exautorarás": "exautorar",
    "exautorarão": "exautorar",
    "exautoraríamos": "exautorar",
    "exautoraríeis": "exautorar",
    "exautoras": "exautorar",
    "exautorasse": "exautorar",
    "exautorassem": "exautorar",
    "exautorasses": "exautorar",
    "exautoraste": "exautorar",
    "exautorastes": "exautorar",
    "exautorava": "exautorar",
    "exautoravam": "exautorar",
    "exautoravas": "exautorar",
    "exautorações": "exautoração",
    "exautore": "exautorar",
    "exautorei": "exautorar",
    "exautoreis": "exautorar",
    "exautorem": "exautorar",
    "exautoremo": "exautorar",
    "exautoremos": "exautorar",
    "exautores": "exautorar",
    "exautoro": "exautorar",
    "exautorou": "exautorar",
    "exautorá": "exautorar",
    "exautorámo": "exautorar",
    "exautorámos": "exautorar",
    "exautoráramo": "exautorar",
    "exautoráramos": "exautorar",
    "exautorárei": "exautorar",
    "exautoráreis": "exautorar",
    "exautorásseis": "exautorar",
    "exautorássemos": "exautorar",
    "exautorávamo": "exautorar",
    "exautorávamos": "exautorar",
    "exautorávei": "exautorar",
    "exautoráveis": "exautorar",
    "excarcera": "excarcerar",
    "excarcerada": "excarcerar",
    "excarceradas": "excarcerar",
    "excarcerado": "excarcerar",
    "excarcerados": "excarcerar",
    "excarcerai": "excarcerar",
    "excarcerais": "excarcerar",
    "excarceram": "excarcerar",
    "excarceramo": "excarcerar",
    "excarceramos": "excarcerar",
    "excarcerando": "excarcerar",
    "excarcerara": "excarcerar",
    "excarceraram": "excarcerar",
    "excarceraras": "excarcerar",
    "excarcerarde": "excarcerar",
    "excarcerardes": "excarcerar",
    "excarcerare": "excarcerar",
    "excarcerarei": "excarcerar",
    "excarcerareis": "excarcerar",
    "excarcerarem": "excarcerar",
    "excarceraremos": "excarcerar",
    "excarcerares": "excarcerar",
    "excarceraria": "excarcerar",
    "excarcerariam": "excarcerar",
    "excarcerarias": "excarcerar",
    "excarcerarmo": "excarcerar",
    "excarcerarmos": "excarcerar",
    "excarcerará": "excarcerar",
    "excarcerarás": "excarcerar",
    "excarcerarão": "excarcerar",
    "excarceraríamos": "excarcerar",
    "excarceraríeis": "excarcerar",
    "excarceras": "excarcerar",
    "excarcerasse": "excarcerar",
    "excarcerassem": "excarcerar",
    "excarcerasses": "excarcerar",
    "excarceraste": "excarcerar",
    "excarcerastes": "excarcerar",
    "excarcerava": "excarcerar",
    "excarceravam": "excarcerar",
    "excarceravas": "excarcerar",
    "excarcerações": "excarceração",
    "excarcere": "excarcerar",
    "excarcerei": "excarcerar",
    "excarcereis": "excarcerar",
    "excarcerem": "excarcerar",
    "excarceremo": "excarcerar",
    "excarceremos": "excarcerar",
    "excarceres": "excarcerar",
    "excarcero": "excarcerar",
    "excarcerou": "excarcerar",
    "excarcerá": "excarcerar",
    "excarcerámo": "excarcerar",
    "excarcerámos": "excarcerar",
    "excarceráramo": "excarcerar",
    "excarceráramos": "excarcerar",
    "excarcerárei": "excarcerar",
    "excarceráreis": "excarcerar",
    "excarcerásseis": "excarcerar",
    "excarcerássemos": "excarcerar",
    "excarcerávamo": "excarcerar",
    "excarcerávamos": "excarcerar",
    "excarcerávei": "excarcerar",
    "excarceráveis": "excarcerar",
    "excardina": "excardinar",
    "excardinada": "excardinar",
    "excardinadas": "excardinar",
    "excardinado": "excardinar",
    "excardinados": "excardinar",
    "excardinai": "excardinar",
    "excardinais": "excardinar",
    "excardinam": "excardinar",
    "excardinamo": "excardinar",
    "excardinamos": "excardinar",
    "excardinando": "excardinar",
    "excardinara": "excardinar",
    "excardinaram": "excardinar",
    "excardinaras": "excardinar",
    "excardinarde": "excardinar",
    "excardinardes": "excardinar",
    "excardinare": "excardinar",
    "excardinarei": "excardinar",
    "excardinareis": "excardinar",
    "excardinarem": "excardinar",
    "excardinaremos": "excardinar",
    "excardinares": "excardinar",
    "excardinaria": "excardinar",
    "excardinariam": "excardinar",
    "excardinarias": "excardinar",
    "excardinarmo": "excardinar",
    "excardinarmos": "excardinar",
    "excardinará": "excardinar",
    "excardinarás": "excardinar",
    "excardinarão": "excardinar",
    "excardinaríamos": "excardinar",
    "excardinaríeis": "excardinar",
    "excardinas": "excardinar",
    "excardinasse": "excardinar",
    "excardinassem": "excardinar",
    "excardinasses": "excardinar",
    "excardinaste": "excardinar",
    "excardinastes": "excardinar",
    "excardinava": "excardinar",
    "excardinavam": "excardinar",
    "excardinavas": "excardinar",
    "excardinações": "excardinação",
    "excardine": "excardinar",
    "excardinei": "excardinar",
    "excardineis": "excardinar",
    "excardinem": "excardinar",
    "excardinemo": "excardinar",
    "excardinemos": "excardinar",
    "excardines": "excardinar",
    "excardino": "excardinar",
    "excardinou": "excardinar",
    "excardiná": "excardinar",
    "excardinámo": "excardinar",
    "excardinámos": "excardinar",
    "excardináramo": "excardinar",
    "excardináramos": "excardinar",
    "excardinárei": "excardinar",
    "excardináreis": "excardinar",
    "excardinásseis": "excardinar",
    "excardinássemos": "excardinar",
    "excardinávamo": "excardinar",
    "excardinávamos": "excardinar",
    "excardinávei": "excardinar",
    "excardináveis": "excardinar",
    "excarnifica": "excarnificar",
    "excarnificada": "excarnificar",
    "excarnificadas": "excarnificar",
    "excarnificado": "excarnificar",
    "excarnificados": "excarnificar",
    "excarnificai": "excarnificar",
    "excarnificais": "excarnificar",
    "excarnificam": "excarnificar",
    "excarnificamo": "excarnificar",
    "excarnificamos": "excarnificar",
    "excarnificando": "excarnificar",
    "excarnificara": "excarnificar",
    "excarnificaram": "excarnificar",
    "excarnificaras": "excarnificar",
    "excarnificarde": "excarnificar",
    "excarnificardes": "excarnificar",
    "excarnificare": "excarnificar",
    "excarnificarei": "excarnificar",
    "excarnificareis": "excarnificar",
    "excarnificarem": "excarnificar",
    "excarnificaremos": "excarnificar",
    "excarnificares": "excarnificar",
    "excarnificaria": "excarnificar",
    "excarnificariam": "excarnificar",
    "excarnificarias": "excarnificar",
    "excarnificarmo": "excarnificar",
    "excarnificarmos": "excarnificar",
    "excarnificará": "excarnificar",
    "excarnificarás": "excarnificar",
    "excarnificarão": "excarnificar",
    "excarnificaríamos": "excarnificar",
    "excarnificaríeis": "excarnificar",
    "excarnificas": "excarnificar",
    "excarnificasse": "excarnificar",
    "excarnificassem": "excarnificar",
    "excarnificasses": "excarnificar",
    "excarnificaste": "excarnificar",
    "excarnificastes": "excarnificar",
    "excarnificava": "excarnificar",
    "excarnificavam": "excarnificar",
    "excarnificavas": "excarnificar",
    "excarnifico": "excarnificar",
    "excarnificou": "excarnificar",
    "excarnificá": "excarnificar",
    "excarnificámo": "excarnificar",
    "excarnificámos": "excarnificar",
    "excarnificáramo": "excarnificar",
    "excarnificáramos": "excarnificar",
    "excarnificárei": "excarnificar",
    "excarnificáreis": "excarnificar",
    "excarnificásseis": "excarnificar",
    "excarnificássemos": "excarnificar",
    "excarnificávamo": "excarnificar",
    "excarnificávamos": "excarnificar",
    "excarnificávei": "excarnificar",
    "excarnificáveis": "excarnificar",
    "excarnifique": "excarnificar",
    "excarnifiquei": "excarnificar",
    "excarnifiqueis": "excarnificar",
    "excarnifiquem": "excarnificar",
    "excarnifiquemo": "excarnificar",
    "excarnifiquemos": "excarnificar",
    "excarnifiques": "excarnificar",
    "exceda": "exceder",
    "excedais": "exceder",
    "excedam": "exceder",
    "excedamo": "exceder",
    "excedamos": "exceder",
    "excedas": "exceder",
    "excede": "exceder",
    "excedei": "exceder",
    "excedeis": "exceder",
    "excedem": "exceder",
    "excedemo": "exceder",
    "excedemos": "exceder",
    "excedendo": "exceder",
    "excedentes": "excedente",
    "excedentária": "excedentário",
    "excedentárias": "excedentário",
    "excedentários": "excedentário",
    "excedera": "exceder",
    "excederam": "exceder",
    "excederas": "exceder",
    "excederde": "exceder",
    "excederdes": "exceder",
    "excedere": "exceder",
    "excederei": "exceder",
    "excedereis": "exceder",
    "excederem": "exceder",
    "excederemos": "exceder",
    "excederes": "exceder",
    "excederia": "exceder",
    "excederiam": "exceder",
    "excederias": "exceder",
    "excedermo": "exceder",
    "excedermos": "exceder",
    "excederá": "exceder",
    "excederás": "exceder",
    "excederão": "exceder",
    "excederíamos": "exceder",
    "excederíeis": "exceder",
    "excedes": "exceder",
    "excedesse": "exceder",
    "excedessem": "exceder",
    "excedesses": "exceder",
    "excedeste": "exceder",
    "excedestes": "exceder",
    "excedeu": "exceder",
    "excedi": "exceder",
    "excedia": "exceder",
    "excediam": "exceder",
    "excedias": "exceder",
    "excedida": "excedido",
    "excedidas": "excedido",
    "excedido": "exceder",
    "excedidos": "excedido",
    "excedo": "exceder",
    "excedê": "exceder",
    "excedêramo": "exceder",
    "excedêramos": "exceder",
    "excedêrei": "exceder",
    "excedêreis": "exceder",
    "excedêsseis": "exceder",
    "excedêssemos": "exceder",
    "excedíamo": "exceder",
    "excedíamos": "exceder",
    "excedíei": "exceder",
    "excedíeis": "exceder",
    "excedíveis": "excedível",
    "excela": "exceler",
    "excelais": "exceler",
    "excelam": "exceler",
    "excelamo": "exceler",
    "excelamos": "exceler",
    "excelas": "exceler",
    "excele": "exceler",
    "excelei": "exceler",
    "exceleis": "exceler",
    "excelem": "exceler",
    "excelemo": "exceler",
    "excelemos": "exceler",
    "excelendo": "exceler",
    "excelentes": "excelente",
    "excelentíssima": "excelente",
    "excelentíssimas": "excelente",
    "excelentíssimo": "excelente",
    "excelentíssimos": "excelente",
    "excelera": "exceler",
    "exceleram": "exceler",
    "exceleras": "exceler",
    "excelerdes": "exceler",
    "excelerei": "exceler",
    "excelereis": "exceler",
    "excelerem": "exceler",
    "exceleremos": "exceler",
    "exceleres": "exceler",
    "exceleria": "exceler",
    "exceleriam": "exceler",
    "excelerias": "exceler",
    "excelermo": "exceler",
    "excelermos": "exceler",
    "excelerá": "exceler",
    "excelerás": "exceler",
    "excelerão": "exceler",
    "exceleríamos": "exceler",
    "exceleríeis": "exceler",
    "exceles": "exceler",
    "excelesse": "exceler",
    "excelessem": "exceler",
    "excelesses": "exceler",
    "exceleste": "exceler",
    "excelestes": "exceler",
    "exceleu": "exceler",
    "exceli": "exceler",
    "excelia": "exceler",
    "exceliam": "exceler",
    "excelias": "exceler",
    "excelida": "exceler",
    "excelidas": "exceler",
    "excelido": "exceler",
    "excelidos": "exceler",
    "excelo": "exceler",
    "excelsa": "excelso",
    "excelsas": "excelso",
    "excelsitudes": "excelsitude",
    "excelsos": "excelso",
    "excelências": "excelência",
    "excelêramo": "exceler",
    "excelêramos": "exceler",
    "excelêreis": "exceler",
    "excelêsseis": "exceler",
    "excelêssemos": "exceler",
    "excelíamo": "exceler",
    "excelíamos": "exceler",
    "excelíeis": "exceler",
    "excentricidades": "excentricidade",
    "excentridades": "excentridade",
    "excepcionais": "excepcional",
    "excepcionalidades": "excepcionalidade",
    "exceptiva": "exceptivo",
    "exceptivas": "exceptivo",
    "exceptivos": "exceptivo",
    "exceptua": "exceptuar",
    "exceptuada": "exceptuar",
    "exceptuadas": "exceptuar",
    "exceptuado": "exceptuar",
    "exceptuadora": "exceptuador",
    "exceptuadoras": "exceptuador",
    "exceptuadores": "exceptuador",
    "exceptuados": "exceptuar",
    "exceptuai": "exceptuar",
    "exceptuais": "exceptuar",
    "exceptuam": "exceptuar",
    "exceptuamo": "exceptuar",
    "exceptuamos": "exceptuar",
    "exceptuando": "exceptuar",
    "exceptuara": "exceptuar",
    "exceptuaram": "exceptuar",
    "exceptuaras": "exceptuar",
    "exceptuarde": "exceptuar",
    "exceptuardes": "exceptuar",
    "exceptuare": "exceptuar",
    "exceptuarei": "exceptuar",
    "exceptuareis": "exceptuar",
    "exceptuarem": "exceptuar",
    "exceptuaremos": "exceptuar",
    "exceptuares": "exceptuar",
    "exceptuaria": "exceptuar",
    "exceptuariam": "exceptuar",
    "exceptuarias": "exceptuar",
    "exceptuarmo": "exceptuar",
    "exceptuarmos": "exceptuar",
    "exceptuará": "exceptuar",
    "exceptuarás": "exceptuar",
    "exceptuarão": "exceptuar",
    "exceptuaríamos": "exceptuar",
    "exceptuaríeis": "exceptuar",
    "exceptuas": "exceptuar",
    "exceptuasse": "exceptuar",
    "exceptuassem": "exceptuar",
    "exceptuasses": "exceptuar",
    "exceptuaste": "exceptuar",
    "exceptuastes": "exceptuar",
    "exceptuava": "exceptuar",
    "exceptuavam": "exceptuar",
    "exceptuavas": "exceptuar",
    "exceptue": "exceptuar",
    "exceptuei": "exceptuar",
    "exceptueis": "exceptuar",
    "exceptuem": "exceptuar",
    "exceptuemo": "exceptuar",
    "exceptuemos": "exceptuar",
    "exceptues": "exceptuar",
    "exceptuo": "exceptuar",
    "exceptuou": "exceptuar",
    "exceptuá": "exceptuar",
    "exceptuámo": "exceptuar",
    "exceptuámos": "exceptuar",
    "exceptuáramo": "exceptuar",
    "exceptuáramos": "exceptuar",
    "exceptuárei": "exceptuar",
    "exceptuáreis": "exceptuar",
    "exceptuásseis": "exceptuar",
    "exceptuássemos": "exceptuar",
    "exceptuávamo": "exceptuar",
    "exceptuávamos": "exceptuar",
    "exceptuávei": "exceptuar",
    "exceptuáveis": "exceptuar",
    "excepções": "excepção",
    "excerta": "excerto",
    "excertas": "excerto",
    "excertos": "excerto",
    "excessiva": "excessivo",
    "excessivas": "excessivo",
    "excessividades": "excessividade",
    "excessivos": "excessivo",
    "excessos": "excesso",
    "excessozinho": "excesso",
    "excessozinhos": "excesso",
    "excessozito": "excesso",
    "excessozitos": "excesso",
    "excipientes": "excipiente",
    "excisa": "excisar",
    "excisada": "excisar",
    "excisadas": "excisar",
    "excisado": "excisar",
    "excisados": "excisar",
    "excisai": "excisar",
    "excisais": "excisar",
    "excisam": "excisar",
    "excisamo": "excisar",
    "excisamos": "excisar",
    "excisando": "excisar",
    "excisara": "excisar",
    "excisaram": "excisar",
    "excisaras": "excisar",
    "excisarde": "excisar",
    "excisardes": "excisar",
    "excisare": "excisar",
    "excisarei": "excisar",
    "excisareis": "excisar",
    "excisarem": "excisar",
    "excisaremos": "excisar",
    "excisares": "excisar",
    "excisaria": "excisar",
    "excisariam": "excisar",
    "excisarias": "excisar",
    "excisarmo": "excisar",
    "excisarmos": "excisar",
    "excisará": "excisar",
    "excisarás": "excisar",
    "excisarão": "excisar",
    "excisaríamos": "excisar",
    "excisaríeis": "excisar",
    "excisas": "excisar",
    "excisasse": "excisar",
    "excisassem": "excisar",
    "excisasses": "excisar",
    "excisaste": "excisar",
    "excisastes": "excisar",
    "excisava": "excisar",
    "excisavam": "excisar",
    "excisavas": "excisar",
    "excise": "excisar",
    "excisei": "excisar",
    "exciseis": "excisar",
    "excisem": "excisar",
    "excisemo": "excisar",
    "excisemos": "excisar",
    "excises": "excisar",
    "exciso": "excisar",
    "excisou": "excisar",
    "excisá": "excisar",
    "excisámo": "excisar",
    "excisámos": "excisar",
    "excisáramo": "excisar",
    "excisáramos": "excisar",
    "excisárei": "excisar",
    "excisáreis": "excisar",
    "excisásseis": "excisar",
    "excisássemos": "excisar",
    "excisávamo": "excisar",
    "excisávamos": "excisar",
    "excisávei": "excisar",
    "excisáveis": "excisar",
    "excisões": "excisão",
    "excita": "excitar",
    "excitabilidades": "excitabilidade",
    "excitada": "excitar",
    "excitadas": "excitar",
    "excitado": "excitar",
    "excitadora": "excitador",
    "excitadoras": "excitador",
    "excitadores": "excitador",
    "excitados": "excitar",
    "excitadíssima": "excitado",
    "excitadíssimas": "excitado",
    "excitadíssimo": "excitado",
    "excitadíssimos": "excitado",
    "excitai": "excitar",
    "excitais": "excitar",
    "excitam": "excitar",
    "excitamentos": "excitamento",
    "excitamo": "excitar",
    "excitamos": "excitar",
    "excitando": "excitar",
    "excitantes": "excitante",
    "excitara": "excitar",
    "excitaram": "excitar",
    "excitaras": "excitar",
    "excitarde": "excitar",
    "excitardes": "excitar",
    "excitare": "excitar",
    "excitarei": "excitar",
    "excitareis": "excitar",
    "excitarem": "excitar",
    "excitaremos": "excitar",
    "excitares": "excitar",
    "excitaria": "excitar",
    "excitariam": "excitar",
    "excitarias": "excitar",
    "excitarmo": "excitar",
    "excitarmos": "excitar",
    "excitará": "excitar",
    "excitarás": "excitar",
    "excitarão": "excitar",
    "excitaríamos": "excitar",
    "excitaríeis": "excitar",
    "excitas": "excitar",
    "excitasse": "excitar",
    "excitassem": "excitar",
    "excitasses": "excitar",
    "excitaste": "excitar",
    "excitastes": "excitar",
    "excitativa": "excitativo",
    "excitativas": "excitativo",
    "excitativos": "excitativo",
    "excitatrizes": "excitatriz",
    "excitatória": "excitatório",
    "excitatórias": "excitatório",
    "excitatórios": "excitatório",
    "excitava": "excitar",
    "excitavam": "excitar",
    "excitavas": "excitar",
    "excitações": "excitação",
    "excite": "excitar",
    "excitei": "excitar",
    "exciteis": "excitar",
    "excitem": "excitar",
    "excitemo": "excitar",
    "excitemos": "excitar",
    "excites": "excitar",
    "excito": "excitar",
    "excitou": "excitar",
    "excitá": "excitar",
    "excitámo": "excitar",
    "excitámos": "excitar",
    "excitáramo": "excitar",
    "excitáramos": "excitar",
    "excitárei": "excitar",
    "excitáreis": "excitar",
    "excitásseis": "excitar",
    "excitássemos": "excitar",
    "excitávamo": "excitar",
    "excitávamos": "excitar",
    "excitávei": "excitar",
    "excitáveis": "excitável",
    "exclama": "exclamar",
    "exclamada": "exclamar",
    "exclamadas": "exclamar",
    "exclamado": "exclamar",
    "exclamadora": "exclamador",
    "exclamadoras": "exclamador",
    "exclamadores": "exclamador",
    "exclamados": "exclamar",
    "exclamai": "exclamar",
    "exclamais": "exclamar",
    "exclamam": "exclamar",
    "exclamamo": "exclamar",
    "exclamamos": "exclamar",
    "exclamando": "exclamar",
    "exclamara": "exclamar",
    "exclamaram": "exclamar",
    "exclamaras": "exclamar",
    "exclamarde": "exclamar",
    "exclamardes": "exclamar",
    "exclamare": "exclamar",
    "exclamarei": "exclamar",
    "exclamareis": "exclamar",
    "exclamarem": "exclamar",
    "exclamaremos": "exclamar",
    "exclamares": "exclamar",
    "exclamaria": "exclamar",
    "exclamariam": "exclamar",
    "exclamarias": "exclamar",
    "exclamarmo": "exclamar",
    "exclamarmos": "exclamar",
    "exclamará": "exclamar",
    "exclamarás": "exclamar",
    "exclamarão": "exclamar",
    "exclamaríamos": "exclamar",
    "exclamaríeis": "exclamar",
    "exclamas": "exclamar",
    "exclamasse": "exclamar",
    "exclamassem": "exclamar",
    "exclamasses": "exclamar",
    "exclamaste": "exclamar",
    "exclamastes": "exclamar",
    "exclamativa": "exclamativo",
    "exclamativas": "exclamativo",
    "exclamativos": "exclamativo",
    "exclamatória": "exclamatório",
    "exclamatórias": "exclamatório",
    "exclamatórios": "exclamatório",
    "exclamava": "exclamar",
    "exclamavam": "exclamar",
    "exclamavas": "exclamar",
    "exclamações": "exclamação",
    "exclame": "exclamar",
    "exclamei": "exclamar",
    "exclameis": "exclamar",
    "exclamem": "exclamar",
    "exclamemo": "exclamar",
    "exclamemos": "exclamar",
    "exclames": "exclamar",
    "exclamo": "exclamar",
    "exclamou": "exclamar",
    "exclamá": "exclamar",
    "exclamámo": "exclamar",
    "exclamámos": "exclamar",
    "exclamáramo": "exclamar",
    "exclamáramos": "exclamar",
    "exclamárei": "exclamar",
    "exclamáreis": "exclamar",
    "exclamásseis": "exclamar",
    "exclamássemos": "exclamar",
    "exclamávamo": "exclamar",
    "exclamávamos": "exclamar",
    "exclamávei": "exclamar",
    "exclamáveis": "exclamar",
    "exclua": "excluir",
    "excluais": "excluir",
    "excluam": "excluir",
    "excluamo": "excluir",
    "excluamos": "excluir",
    "excluas": "excluir",
    "excluem": "excluir",
    "exclui": "excluir",
    "excluindo": "excluir",
    "excluirde": "excluir",
    "excluirdes": "excluir",
    "excluirei": "excluir",
    "excluireis": "excluir",
    "excluiremos": "excluir",
    "excluiria": "excluir",
    "excluiriam": "excluir",
    "excluirias": "excluir",
    "excluirmo": "excluir",
    "excluirmos": "excluir",
    "excluirá": "excluir",
    "excluirás": "excluir",
    "excluirão": "excluir",
    "excluiríamos": "excluir",
    "excluiríeis": "excluir",
    "excluis": "excluir",
    "excluiu": "excluir",
    "excluo": "excluir",
    "exclusa": "excluso",
    "exclusas": "excluso",
    "exclusiva": "exclusivo",
    "exclusivas": "exclusivo",
    "exclusividades": "exclusividade",
    "exclusivismos": "exclusivismo",
    "exclusivistas": "exclusivista",
    "exclusivos": "exclusivo",
    "exclusos": "excluso",
    "exclusões": "exclusão",
    "excluí": "excluir",
    "excluía": "excluir",
    "excluíam": "excluir",
    "excluíamo": "excluir",
    "excluíamos": "excluir",
    "excluías": "excluir",
    "excluída": "excluir",
    "excluídas": "excluir",
    "excluído": "excluir",
    "excluídos": "excluir",
    "excluíei": "excluir",
    "excluíeis": "excluir",
    "excluímo": "excluir",
    "excluímos": "excluir",
    "excluíra": "excluir",
    "excluíram": "excluir",
    "excluíramo": "excluir",
    "excluíramos": "excluir",
    "excluíras": "excluir",
    "excluíre": "excluir",
    "excluírei": "excluir",
    "excluíreis": "excluir",
    "excluírem": "excluir",
    "excluíres": "excluir",
    "excluís": "excluir",
    "excluísse": "excluir",
    "excluísseis": "excluir",
    "excluíssem": "excluir",
    "excluíssemos": "excluir",
    "excluísses": "excluir",
    "excluíste": "excluir",
    "excluístes": "excluir",
    "excluíveis": "excluível",
    "excogita": "excogitar",
    "excogitada": "excogitar",
    "excogitadas": "excogitar",
    "excogitado": "excogitar",
    "excogitadora": "excogitador",
    "excogitadoras": "excogitador",
    "excogitadores": "excogitador",
    "excogitados": "excogitar",
    "excogitai": "excogitar",
    "excogitais": "excogitar",
    "excogitam": "excogitar",
    "excogitamo": "excogitar",
    "excogitamos": "excogitar",
    "excogitando": "excogitar",
    "excogitara": "excogitar",
    "excogitaram": "excogitar",
    "excogitaras": "excogitar",
    "excogitarde": "excogitar",
    "excogitardes": "excogitar",
    "excogitare": "excogitar",
    "excogitarei": "excogitar",
    "excogitareis": "excogitar",
    "excogitarem": "excogitar",
    "excogitaremos": "excogitar",
    "excogitares": "excogitar",
    "excogitaria": "excogitar",
    "excogitariam": "excogitar",
    "excogitarias": "excogitar",
    "excogitarmo": "excogitar",
    "excogitarmos": "excogitar",
    "excogitará": "excogitar",
    "excogitarás": "excogitar",
    "excogitarão": "excogitar",
    "excogitaríamos": "excogitar",
    "excogitaríeis": "excogitar",
    "excogitas": "excogitar",
    "excogitasse": "excogitar",
    "excogitassem": "excogitar",
    "excogitasses": "excogitar",
    "excogitaste": "excogitar",
    "excogitastes": "excogitar",
    "excogitava": "excogitar",
    "excogitavam": "excogitar",
    "excogitavas": "excogitar",
    "excogitações": "excogitação",
    "excogite": "excogitar",
    "excogitei": "excogitar",
    "excogiteis": "excogitar",
    "excogitem": "excogitar",
    "excogitemo": "excogitar",
    "excogitemos": "excogitar",
    "excogites": "excogitar",
    "excogito": "excogitar",
    "excogitou": "excogitar",
    "excogitá": "excogitar",
    "excogitámo": "excogitar",
    "excogitámos": "excogitar",
    "excogitáramo": "excogitar",
    "excogitáramos": "excogitar",
    "excogitárei": "excogitar",
    "excogitáreis": "excogitar",
    "excogitásseis": "excogitar",
    "excogitássemos": "excogitar",
    "excogitávamo": "excogitar",
    "excogitávamos": "excogitar",
    "excogitávei": "excogitar",
    "excogitáveis": "excogitar",
    "excomunga": "excomungar",
    "excomungada": "excomungar",
    "excomungadas": "excomungar",
    "excomungado": "excomungar",
    "excomungados": "excomungar",
    "excomungai": "excomungar",
    "excomungais": "excomungar",
    "excomungam": "excomungar",
    "excomungamo": "excomungar",
    "excomungamos": "excomungar",
    "excomungando": "excomungar",
    "excomungara": "excomungar",
    "excomungaram": "excomungar",
    "excomungaras": "excomungar",
    "excomungarde": "excomungar",
    "excomungardes": "excomungar",
    "excomungare": "excomungar",
    "excomungarei": "excomungar",
    "excomungareis": "excomungar",
    "excomungarem": "excomungar",
    "excomungaremos": "excomungar",
    "excomungares": "excomungar",
    "excomungaria": "excomungar",
    "excomungariam": "excomungar",
    "excomungarias": "excomungar",
    "excomungarmo": "excomungar",
    "excomungarmos": "excomungar",
    "excomungará": "excomungar",
    "excomungarás": "excomungar",
    "excomungarão": "excomungar",
    "excomungaríamos": "excomungar",
    "excomungaríeis": "excomungar",
    "excomungas": "excomungar",
    "excomungasse": "excomungar",
    "excomungassem": "excomungar",
    "excomungasses": "excomungar",
    "excomungaste": "excomungar",
    "excomungastes": "excomungar",
    "excomungava": "excomungar",
    "excomungavam": "excomungar",
    "excomungavas": "excomungar",
    "excomungo": "excomungar",
    "excomungou": "excomungar",
    "excomungue": "excomungar",
    "excomunguei": "excomungar",
    "excomungueis": "excomungar",
    "excomunguem": "excomungar",
    "excomunguemo": "excomungar",
    "excomunguemos": "excomungar",
    "excomungues": "excomungar",
    "excomungá": "excomungar",
    "excomungámo": "excomungar",
    "excomungámos": "excomungar",
    "excomungáramo": "excomungar",
    "excomungáramos": "excomungar",
    "excomungárei": "excomungar",
    "excomungáreis": "excomungar",
    "excomungásseis": "excomungar",
    "excomungássemos": "excomungar",
    "excomungávamo": "excomungar",
    "excomungávamos": "excomungar",
    "excomungávei": "excomungar",
    "excomungáveis": "excomungável",
    "excomunhais": "excomunhal",
    "excomunhões": "excomunhão",
    "excrementos": "excremento",
    "excrementosa": "excrementoso",
    "excrementosas": "excrementoso",
    "excrementosos": "excrementoso",
    "excrementícia": "excrementício",
    "excrementícias": "excrementício",
    "excrementícios": "excrementício",
    "excresce": "excrescer",
    "excrescei": "excrescer",
    "excresceis": "excrescer",
    "excrescem": "excrescer",
    "excrescemo": "excrescer",
    "excrescemos": "excrescer",
    "excrescendo": "excrescer",
    "excrescentes": "excrescente",
    "excrescera": "excrescer",
    "excresceram": "excrescer",
    "excresceras": "excrescer",
    "excrescerdes": "excrescer",
    "excrescerei": "excrescer",
    "excrescereis": "excrescer",
    "excrescerem": "excrescer",
    "excresceremos": "excrescer",
    "excresceres": "excrescer",
    "excresceria": "excrescer",
    "excresceriam": "excrescer",
    "excrescerias": "excrescer",
    "excrescermo": "excrescer",
    "excrescermos": "excrescer",
    "excrescerá": "excrescer",
    "excrescerás": "excrescer",
    "excrescerão": "excrescer",
    "excresceríamos": "excrescer",
    "excresceríeis": "excrescer",
    "excresces": "excrescer",
    "excrescesse": "excrescer",
    "excrescessem": "excrescer",
    "excrescesses": "excrescer",
    "excresceste": "excrescer",
    "excrescestes": "excrescer",
    "excresceu": "excrescer",
    "excresci": "excrescer",
    "excrescia": "excrescer",
    "excresciam": "excrescer",
    "excrescias": "excrescer",
    "excrescida": "excrescer",
    "excrescidas": "excrescer",
    "excrescido": "excrescer",
    "excrescidos": "excrescer",
    "excrescências": "excrescência",
    "excrescêramo": "excrescer",
    "excrescêramos": "excrescer",
    "excrescêreis": "excrescer",
    "excrescêsseis": "excrescer",
    "excrescêssemos": "excrescer",
    "excrescíamo": "excrescer",
    "excrescíamos": "excrescer",
    "excrescíeis": "excrescer",
    "excresça": "excrescer",
    "excresçais": "excrescer",
    "excresçam": "excrescer",
    "excresçamo": "excrescer",
    "excresçamos": "excrescer",
    "excresças": "excrescer",
    "excresço": "excrescer",
    "excreta": "excretar",
    "excretada": "excretar",
    "excretadas": "excretar",
    "excretado": "excretar",
    "excretados": "excretar",
    "excretai": "excretar",
    "excretais": "excretar",
    "excretam": "excretar",
    "excretamo": "excretar",
    "excretamos": "excretar",
    "excretando": "excretar",
    "excretara": "excretar",
    "excretaram": "excretar",
    "excretaras": "excretar",
    "excretarde": "excretar",
    "excretardes": "excretar",
    "excretare": "excretar",
    "excretarei": "excretar",
    "excretareis": "excretar",
    "excretarem": "excretar",
    "excretaremos": "excretar",
    "excretares": "excretar",
    "excretaria": "excretar",
    "excretariam": "excretar",
    "excretarias": "excretar",
    "excretarmo": "excretar",
    "excretarmos": "excretar",
    "excretará": "excretar",
    "excretarás": "excretar",
    "excretarão": "excretar",
    "excretaríamos": "excretar",
    "excretaríeis": "excretar",
    "excretas": "excretar",
    "excretasse": "excretar",
    "excretassem": "excretar",
    "excretasses": "excretar",
    "excretaste": "excretar",
    "excretastes": "excretar",
    "excretava": "excretar",
    "excretavam": "excretar",
    "excretavas": "excretar",
    "excrete": "excretar",
    "excretei": "excretar",
    "excreteis": "excretar",
    "excretem": "excretar",
    "excretemo": "excretar",
    "excretemos": "excretar",
    "excretes": "excretar",
    "excreto": "excretar",
    "excretora": "excretor",
    "excretoras": "excretor",
    "excretores": "excretor",
    "excretos": "excreto",
    "excretou": "excretar",
    "excretá": "excretar",
    "excretámo": "excretar",
    "excretámos": "excretar",
    "excretáramo": "excretar",
    "excretáramos": "excretar",
    "excretárei": "excretar",
    "excretáreis": "excretar",
    "excretásseis": "excretar",
    "excretássemos": "excretar",
    "excretávamo": "excretar",
    "excretávamos": "excretar",
    "excretávei": "excretar",
    "excretáveis": "excretável",
    "excretícia": "excretício",
    "excretícias": "excretício",
    "excretícios": "excretício",
    "excretória": "excretório",
    "excretórias": "excretório",
    "excretórios": "excretório",
    "excreções": "excreção",
    "excrucia": "excruciar",
    "excruciada": "excruciar",
    "excruciadas": "excruciar",
    "excruciado": "excruciar",
    "excruciados": "excruciar",
    "excruciai": "excruciar",
    "excruciais": "excruciar",
    "excruciam": "excruciar",
    "excruciamo": "excruciar",
    "excruciamos": "excruciar",
    "excruciando": "excruciar",
    "excruciantes": "excruciante",
    "excruciara": "excruciar",
    "excruciaram": "excruciar",
    "excruciaras": "excruciar",
    "excruciarde": "excruciar",
    "excruciardes": "excruciar",
    "excruciare": "excruciar",
    "excruciarei": "excruciar",
    "excruciareis": "excruciar",
    "excruciarem": "excruciar",
    "excruciaremos": "excruciar",
    "excruciares": "excruciar",
    "excruciaria": "excruciar",
    "excruciariam": "excruciar",
    "excruciarias": "excruciar",
    "excruciarmo": "excruciar",
    "excruciarmos": "excruciar",
    "excruciará": "excruciar",
    "excruciarás": "excruciar",
    "excruciarão": "excruciar",
    "excruciaríamos": "excruciar",
    "excruciaríeis": "excruciar",
    "excrucias": "excruciar",
    "excruciasse": "excruciar",
    "excruciassem": "excruciar",
    "excruciasses": "excruciar",
    "excruciaste": "excruciar",
    "excruciastes": "excruciar",
    "excruciava": "excruciar",
    "excruciavam": "excruciar",
    "excruciavas": "excruciar",
    "excruciações": "excruciação",
    "excrucie": "excruciar",
    "excruciei": "excruciar",
    "excrucieis": "excruciar",
    "excruciem": "excruciar",
    "excruciemo": "excruciar",
    "excruciemos": "excruciar",
    "excrucies": "excruciar",
    "excrucio": "excruciar",
    "excruciou": "excruciar",
    "excruciá": "excruciar",
    "excruciámo": "excruciar",
    "excruciámos": "excruciar",
    "excruciáramo": "excruciar",
    "excruciáramos": "excruciar",
    "excruciárei": "excruciar",
    "excruciáreis": "excruciar",
    "excruciásseis": "excruciar",
    "excruciássemos": "excruciar",
    "excruciávamo": "excruciar",
    "excruciávamos": "excruciar",
    "excruciávei": "excruciar",
    "excruciáveis": "excruciar",
    "exculpa": "exculpar",
    "exculpada": "exculpar",
    "exculpadas": "exculpar",
    "exculpado": "exculpar",
    "exculpados": "exculpar",
    "exculpai": "exculpar",
    "exculpais": "exculpar",
    "exculpam": "exculpar",
    "exculpamo": "exculpar",
    "exculpamos": "exculpar",
    "exculpando": "exculpar",
    "exculpara": "exculpar",
    "exculparam": "exculpar",
    "exculparas": "exculpar",
    "exculparde": "exculpar",
    "exculpardes": "exculpar",
    "exculpare": "exculpar",
    "exculparei": "exculpar",
    "exculpareis": "exculpar",
    "exculparem": "exculpar",
    "exculparemos": "exculpar",
    "exculpares": "exculpar",
    "exculparia": "exculpar",
    "exculpariam": "exculpar",
    "exculparias": "exculpar",
    "exculparmo": "exculpar",
    "exculparmos": "exculpar",
    "exculpará": "exculpar",
    "exculparás": "exculpar",
    "exculparão": "exculpar",
    "exculparíamos": "exculpar",
    "exculparíeis": "exculpar",
    "exculpas": "exculpar",
    "exculpasse": "exculpar",
    "exculpassem": "exculpar",
    "exculpasses": "exculpar",
    "exculpaste": "exculpar",
    "exculpastes": "exculpar",
    "exculpava": "exculpar",
    "exculpavam": "exculpar",
    "exculpavas": "exculpar",
    "exculpações": "exculpação",
    "exculpe": "exculpar",
    "exculpei": "exculpar",
    "exculpeis": "exculpar",
    "exculpem": "exculpar",
    "exculpemo": "exculpar",
    "exculpemos": "exculpar",
    "exculpes": "exculpar",
    "exculpo": "exculpar",
    "exculpou": "exculpar",
    "exculpá": "exculpar",
    "exculpámo": "exculpar",
    "exculpámos": "exculpar",
    "exculpáramo": "exculpar",
    "exculpáramos": "exculpar",
    "exculpárei": "exculpar",
    "exculpáreis": "exculpar",
    "exculpásseis": "exculpar",
    "exculpássemos": "exculpar",
    "exculpávamo": "exculpar",
    "exculpávamos": "exculpar",
    "exculpávei": "exculpar",
    "exculpáveis": "exculpar",
    "excurciona": "excurcionar",
    "excurcionada": "excurcionar",
    "excurcionadas": "excurcionar",
    "excurcionado": "excurcionar",
    "excurcionados": "excurcionar",
    "excurcionai": "excurcionar",
    "excurcionais": "excurcionar",
    "excurcionam": "excurcionar",
    "excurcionamo": "excurcionar",
    "excurcionamos": "excurcionar",
    "excurcionando": "excurcionar",
    "excurcionara": "excurcionar",
    "excurcionaram": "excurcionar",
    "excurcionaras": "excurcionar",
    "excurcionardes": "excurcionar",
    "excurcionarei": "excurcionar",
    "excurcionareis": "excurcionar",
    "excurcionarem": "excurcionar",
    "excurcionaremos": "excurcionar",
    "excurcionares": "excurcionar",
    "excurcionaria": "excurcionar",
    "excurcionariam": "excurcionar",
    "excurcionarias": "excurcionar",
    "excurcionarmo": "excurcionar",
    "excurcionarmos": "excurcionar",
    "excurcionará": "excurcionar",
    "excurcionarás": "excurcionar",
    "excurcionarão": "excurcionar",
    "excurcionaríamos": "excurcionar",
    "excurcionaríeis": "excurcionar",
    "excurcionas": "excurcionar",
    "excurcionasse": "excurcionar",
    "excurcionassem": "excurcionar",
    "excurcionasses": "excurcionar",
    "excurcionaste": "excurcionar",
    "excurcionastes": "excurcionar",
    "excurcionava": "excurcionar",
    "excurcionavam": "excurcionar",
    "excurcionavas": "excurcionar",
    "excurcione": "excurcionar",
    "excurcionei": "excurcionar",
    "excurcioneis": "excurcionar",
    "excurcionem": "excurcionar",
    "excurcionemo": "excurcionar",
    "excurcionemos": "excurcionar",
    "excurciones": "excurcionar",
    "excurciono": "excurcionar",
    "excurcionou": "excurcionar",
    "excurcionámo": "excurcionar",
    "excurcionámos": "excurcionar",
    "excurcionáramo": "excurcionar",
    "excurcionáramos": "excurcionar",
    "excurcionáreis": "excurcionar",
    "excurcionásseis": "excurcionar",
    "excurcionássemos": "excurcionar",
    "excurcionávamo": "excurcionar",
    "excurcionávamos": "excurcionar",
    "excurcionáveis": "excurcionar",
    "excursa": "excursar",
    "excursada": "excursar",
    "excursadas": "excursar",
    "excursado": "excursar",
    "excursados": "excursar",
    "excursai": "excursar",
    "excursais": "excursar",
    "excursam": "excursar",
    "excursamo": "excursar",
    "excursamos": "excursar",
    "excursando": "excursar",
    "excursara": "excursar",
    "excursaram": "excursar",
    "excursaras": "excursar",
    "excursardes": "excursar",
    "excursarei": "excursar",
    "excursareis": "excursar",
    "excursarem": "excursar",
    "excursaremos": "excursar",
    "excursares": "excursar",
    "excursaria": "excursar",
    "excursariam": "excursar",
    "excursarias": "excursar",
    "excursarmo": "excursar",
    "excursarmos": "excursar",
    "excursará": "excursar",
    "excursarás": "excursar",
    "excursarão": "excursar",
    "excursaríamos": "excursar",
    "excursaríeis": "excursar",
    "excursas": "excursar",
    "excursasse": "excursar",
    "excursassem": "excursar",
    "excursasses": "excursar",
    "excursaste": "excursar",
    "excursastes": "excursar",
    "excursava": "excursar",
    "excursavam": "excursar",
    "excursavas": "excursar",
    "excurse": "excursar",
    "excursei": "excursar",
    "excurseis": "excursar",
    "excursem": "excursar",
    "excursemo": "excursar",
    "excursemos": "excursar",
    "excurses": "excursar",
    "excursionismos": "excursionismo",
    "excursionistas": "excursionista",
    "excurso": "excursar",
    "excursos": "excurso",
    "excursou": "excursar",
    "excursámo": "excursar",
    "excursámos": "excursar",
    "excursáramo": "excursar",
    "excursáramos": "excursar",
    "excursáreis": "excursar",
    "excursásseis": "excursar",
    "excursássemos": "excursar",
    "excursávamo": "excursar",
    "excursávamos": "excursar",
    "excursáveis": "excursar",
    "excursões": "excursão",
    "excurva": "excurvar",
    "excurvada": "excurvar",
    "excurvadas": "excurvar",
    "excurvado": "excurvar",
    "excurvados": "excurvar",
    "excurvai": "excurvar",
    "excurvais": "excurvar",
    "excurvam": "excurvar",
    "excurvamo": "excurvar",
    "excurvamos": "excurvar",
    "excurvando": "excurvar",
    "excurvara": "excurvar",
    "excurvaram": "excurvar",
    "excurvaras": "excurvar",
    "excurvarde": "excurvar",
    "excurvardes": "excurvar",
    "excurvare": "excurvar",
    "excurvarei": "excurvar",
    "excurvareis": "excurvar",
    "excurvarem": "excurvar",
    "excurvaremos": "excurvar",
    "excurvares": "excurvar",
    "excurvaria": "excurvar",
    "excurvariam": "excurvar",
    "excurvarias": "excurvar",
    "excurvarmo": "excurvar",
    "excurvarmos": "excurvar",
    "excurvará": "excurvar",
    "excurvarás": "excurvar",
    "excurvarão": "excurvar",
    "excurvaríamos": "excurvar",
    "excurvaríeis": "excurvar",
    "excurvas": "excurvar",
    "excurvasse": "excurvar",
    "excurvassem": "excurvar",
    "excurvasses": "excurvar",
    "excurvaste": "excurvar",
    "excurvastes": "excurvar",
    "excurvava": "excurvar",
    "excurvavam": "excurvar",
    "excurvavas": "excurvar",
    "excurve": "excurvar",
    "excurvei": "excurvar",
    "excurveis": "excurvar",
    "excurvem": "excurvar",
    "excurvemo": "excurvar",
    "excurvemos": "excurvar",
    "excurves": "excurvar",
    "excurvo": "excurvar",
    "excurvou": "excurvar",
    "excurvá": "excurvar",
    "excurvámo": "excurvar",
    "excurvámos": "excurvar",
    "excurváramo": "excurvar",
    "excurváramos": "excurvar",
    "excurvárei": "excurvar",
    "excurváreis": "excurvar",
    "excurvásseis": "excurvar",
    "excurvássemos": "excurvar",
    "excurvávamo": "excurvar",
    "excurvávamos": "excurvar",
    "excurvávei": "excurvar",
    "excurváveis": "excurvar",
    "excussões": "excussão",
    "excuta": "excutir",
    "excutais": "excutir",
    "excutam": "excutir",
    "excutamo": "excutir",
    "excutamos": "excutir",
    "excutas": "excutir",
    "excute": "excutir",
    "excutem": "excutir",
    "excutes": "excutir",
    "excuti": "excutir",
    "excutia": "excutir",
    "excutiam": "excutir",
    "excutias": "excutir",
    "excutida": "excutir",
    "excutidas": "excutir",
    "excutido": "excutir",
    "excutidos": "excutir",
    "excutimo": "excutir",
    "excutimos": "excutir",
    "excutindo": "excutir",
    "excutira": "excutir",
    "excutiram": "excutir",
    "excutiras": "excutir",
    "excutirde": "excutir",
    "excutirdes": "excutir",
    "excutire": "excutir",
    "excutirei": "excutir",
    "excutireis": "excutir",
    "excutirem": "excutir",
    "excutiremos": "excutir",
    "excutires": "excutir",
    "excutiria": "excutir",
    "excutiriam": "excutir",
    "excutirias": "excutir",
    "excutirmo": "excutir",
    "excutirmos": "excutir",
    "excutirá": "excutir",
    "excutirás": "excutir",
    "excutirão": "excutir",
    "excutiríamos": "excutir",
    "excutiríeis": "excutir",
    "excutis": "excutir",
    "excutisse": "excutir",
    "excutissem": "excutir",
    "excutisses": "excutir",
    "excutiste": "excutir",
    "excutistes": "excutir",
    "excutiu": "excutir",
    "excuto": "excutir",
    "excutíamo": "excutir",
    "excutíamos": "excutir",
    "excutíei": "excutir",
    "excutíeis": "excutir",
    "excutíramo": "excutir",
    "excutíramos": "excutir",
    "excutírei": "excutir",
    "excutíreis": "excutir",
    "excutísseis": "excutir",
    "excutíssemos": "excutir",
    "excêntrica": "excêntrico",
    "excêntricas": "excêntrico",
    "excêntricos": "excêntrico",
    "excídios": "excídio",
    "execra": "execrar",
    "execrabilidades": "execrabilidade",
    "execrada": "execrar",
    "execradas": "execrar",
    "execrado": "execrar",
    "execradora": "execrador",
    "execradoras": "execrador",
    "execradores": "execrador",
    "execrados": "execrar",
    "execrai": "execrar",
    "execrais": "execrar",
    "execram": "execrar",
    "execramo": "execrar",
    "execramos": "execrar",
    "execranda": "execrando",
    "execrandas": "execrando",
    "execrando": "execrar",
    "execrandos": "execrando",
    "execrara": "execrar",
    "execraram": "execrar",
    "execraras": "execrar",
    "execrarde": "execrar",
    "execrardes": "execrar",
    "execrare": "execrar",
    "execrarei": "execrar",
    "execrareis": "execrar",
    "execrarem": "execrar",
    "execraremos": "execrar",
    "execrares": "execrar",
    "execraria": "execrar",
    "execrariam": "execrar",
    "execrarias": "execrar",
    "execrarmo": "execrar",
    "execrarmos": "execrar",
    "execrará": "execrar",
    "execrarás": "execrar",
    "execrarão": "execrar",
    "execraríamos": "execrar",
    "execraríeis": "execrar",
    "execras": "execrar",
    "execrasse": "execrar",
    "execrassem": "execrar",
    "execrasses": "execrar",
    "execraste": "execrar",
    "execrastes": "execrar",
    "execratória": "execratório",
    "execratórias": "execratório",
    "execratórios": "execratório",
    "execrava": "execrar",
    "execravam": "execrar",
    "execravas": "execrar",
    "execrações": "execração",
    "execre": "execrar",
    "execrei": "execrar",
    "execreis": "execrar",
    "execrem": "execrar",
    "execremo": "execrar",
    "execremos": "execrar",
    "execres": "execrar",
    "execro": "execrar",
    "execrou": "execrar",
    "execrá": "execrar",
    "execrámo": "execrar",
    "execrámos": "execrar",
    "execráramo": "execrar",
    "execráramos": "execrar",
    "execrárei": "execrar",
    "execráreis": "execrar",
    "execrásseis": "execrar",
    "execrássemos": "execrar",
    "execrávamo": "execrar",
    "execrávamos": "execrar",
    "execrávei": "execrar",
    "execráveis": "execrável",
    "executa": "executar",
    "executada": "executar",
    "executadas": "executar",
    "executado": "executar",
    "executados": "executar",
    "executai": "executar",
    "executais": "executar",
    "executam": "executar",
    "executamo": "executar",
    "executamos": "executar",
    "executando": "executar",
    "executantes": "executante",
    "executara": "executar",
    "executaram": "executar",
    "executaras": "executar",
    "executarde": "executar",
    "executardes": "executar",
    "executare": "executar",
    "executarei": "executar",
    "executareis": "executar",
    "executarem": "executar",
    "executaremos": "executar",
    "executares": "executar",
    "executaria": "executar",
    "executariam": "executar",
    "executarias": "executar",
    "executarmo": "executar",
    "executarmos": "executar",
    "executará": "executar",
    "executarás": "executar",
    "executarão": "executar",
    "executaríamos": "executar",
    "executaríeis": "executar",
    "executas": "executar",
    "executasse": "executar",
    "executassem": "executar",
    "executasses": "executar",
    "executaste": "executar",
    "executastes": "executar",
    "executava": "executar",
    "executavam": "executar",
    "executavas": "executar",
    "execute": "executar",
    "executei": "executar",
    "executeis": "executar",
    "executem": "executar",
    "executemo": "executar",
    "executemos": "executar",
    "executes": "executar",
    "executiva": "executivo",
    "executivas": "executivo",
    "executivos": "executivo",
    "executo": "executar",
    "executora": "executor",
    "executoras": "executor",
    "executores": "executor",
    "executou": "executar",
    "executá": "executar",
    "executámo": "executar",
    "executámos": "executar",
    "executáramo": "executar",
    "executáramos": "executar",
    "executárei": "executar",
    "executáreis": "executar",
    "executásseis": "executar",
    "executássemos": "executar",
    "executávamo": "executar",
    "executávamos": "executar",
    "executávei": "executar",
    "executáveis": "executável",
    "executória": "executório",
    "executórias": "executório",
    "executórios": "executório",
    "execuções": "execução",
    "exegeses": "exegese",
    "exegetas": "exegeta",
    "exegética": "exegético",
    "exegéticas": "exegético",
    "exegéticos": "exegético",
    "exemplares": "exemplar",
    "exemplaridades": "exemplaridade",
    "exemplifica": "exemplificar",
    "exemplificada": "exemplificar",
    "exemplificadas": "exemplificar",
    "exemplificado": "exemplificar",
    "exemplificadora": "exemplificador",
    "exemplificadoras": "exemplificador",
    "exemplificadores": "exemplificador",
    "exemplificados": "exemplificar",
    "exemplificai": "exemplificar",
    "exemplificais": "exemplificar",
    "exemplificam": "exemplificar",
    "exemplificamo": "exemplificar",
    "exemplificamos": "exemplificar",
    "exemplificando": "exemplificar",
    "exemplificara": "exemplificar",
    "exemplificaram": "exemplificar",
    "exemplificaras": "exemplificar",
    "exemplificarde": "exemplificar",
    "exemplificardes": "exemplificar",
    "exemplificare": "exemplificar",
    "exemplificarei": "exemplificar",
    "exemplificareis": "exemplificar",
    "exemplificarem": "exemplificar",
    "exemplificaremos": "exemplificar",
    "exemplificares": "exemplificar",
    "exemplificaria": "exemplificar",
    "exemplificariam": "exemplificar",
    "exemplificarias": "exemplificar",
    "exemplificarmo": "exemplificar",
    "exemplificarmos": "exemplificar",
    "exemplificará": "exemplificar",
    "exemplificarás": "exemplificar",
    "exemplificarão": "exemplificar",
    "exemplificaríamos": "exemplificar",
    "exemplificaríeis": "exemplificar",
    "exemplificas": "exemplificar",
    "exemplificasse": "exemplificar",
    "exemplificassem": "exemplificar",
    "exemplificasses": "exemplificar",
    "exemplificaste": "exemplificar",
    "exemplificastes": "exemplificar",
    "exemplificativa": "exemplificativo",
    "exemplificativas": "exemplificativo",
    "exemplificativos": "exemplificativo",
    "exemplificava": "exemplificar",
    "exemplificavam": "exemplificar",
    "exemplificavas": "exemplificar",
    "exemplificações": "exemplificação",
    "exemplifico": "exemplificar",
    "exemplificou": "exemplificar",
    "exemplificá": "exemplificar",
    "exemplificámo": "exemplificar",
    "exemplificámos": "exemplificar",
    "exemplificáramo": "exemplificar",
    "exemplificáramos": "exemplificar",
    "exemplificárei": "exemplificar",
    "exemplificáreis": "exemplificar",
    "exemplificásseis": "exemplificar",
    "exemplificássemos": "exemplificar",
    "exemplificávamo": "exemplificar",
    "exemplificávamos": "exemplificar",
    "exemplificávei": "exemplificar",
    "exemplificáveis": "exemplificável",
    "exemplifique": "exemplificar",
    "exemplifiquei": "exemplificar",
    "exemplifiqueis": "exemplificar",
    "exemplifiquem": "exemplificar",
    "exemplifiquemo": "exemplificar",
    "exemplifiquemos": "exemplificar",
    "exemplifiques": "exemplificar",
    "exemplos": "exemplo",
    "exemplários": "exemplário",
    "exencefalias": "exencefalia",
    "exencefálica": "exencefálico",
    "exencefálicas": "exencefálico",
    "exencefálicos": "exencefálico",
    "exencéfala": "exencéfalo",
    "exencéfalas": "exencéfalo",
    "exencéfalos": "exencéfalo",
    "exenterações": "exenteração",
    "exequatures": "exequatur",
    "exequentes": "exequente",
    "exequiais": "exequial",
    "exequibilidades": "exequibilidade",
    "exequíveis": "exequível",
    "exerce": "exercer",
    "exercei": "exercer",
    "exerceis": "exercer",
    "exercem": "exercer",
    "exercemo": "exercer",
    "exercemos": "exercer",
    "exercendo": "exercer",
    "exercera": "exercer",
    "exerceram": "exercer",
    "exerceras": "exercer",
    "exercerde": "exercer",
    "exercerdes": "exercer",
    "exercere": "exercer",
    "exercerei": "exercer",
    "exercereis": "exercer",
    "exercerem": "exercer",
    "exerceremos": "exercer",
    "exerceres": "exercer",
    "exerceria": "exercer",
    "exerceriam": "exercer",
    "exercerias": "exercer",
    "exercermo": "exercer",
    "exercermos": "exercer",
    "exercerá": "exercer",
    "exercerás": "exercer",
    "exercerão": "exercer",
    "exerceríamos": "exercer",
    "exerceríeis": "exercer",
    "exerces": "exercer",
    "exercesse": "exercer",
    "exercessem": "exercer",
    "exercesses": "exercer",
    "exerceste": "exercer",
    "exercestes": "exercer",
    "exerceu": "exercer",
    "exerci": "exercer",
    "exercia": "exercer",
    "exerciam": "exercer",
    "exercias": "exercer",
    "exercida": "exercido",
    "exercidas": "exercido",
    "exercido": "exercer",
    "exercidos": "exercido",
    "exercita": "exercitar",
    "exercitada": "exercitar",
    "exercitadas": "exercitar",
    "exercitado": "exercitar",
    "exercitadora": "exercitador",
    "exercitadoras": "exercitador",
    "exercitadores": "exercitador",
    "exercitados": "exercitar",
    "exercitai": "exercitar",
    "exercitais": "exercitar",
    "exercitam": "exercitar",
    "exercitamo": "exercitar",
    "exercitamos": "exercitar",
    "exercitando": "exercitar",
    "exercitantes": "exercitante",
    "exercitara": "exercitar",
    "exercitaram": "exercitar",
    "exercitaras": "exercitar",
    "exercitarde": "exercitar",
    "exercitardes": "exercitar",
    "exercitare": "exercitar",
    "exercitarei": "exercitar",
    "exercitareis": "exercitar",
    "exercitarem": "exercitar",
    "exercitaremos": "exercitar",
    "exercitares": "exercitar",
    "exercitaria": "exercitar",
    "exercitariam": "exercitar",
    "exercitarias": "exercitar",
    "exercitarmo": "exercitar",
    "exercitarmos": "exercitar",
    "exercitará": "exercitar",
    "exercitarás": "exercitar",
    "exercitarão": "exercitar",
    "exercitaríamos": "exercitar",
    "exercitaríeis": "exercitar",
    "exercitas": "exercitar",
    "exercitasse": "exercitar",
    "exercitassem": "exercitar",
    "exercitasses": "exercitar",
    "exercitaste": "exercitar",
    "exercitastes": "exercitar",
    "exercitava": "exercitar",
    "exercitavam": "exercitar",
    "exercitavas": "exercitar",
    "exercitações": "exercitação",
    "exercite": "exercitar",
    "exercitei": "exercitar",
    "exerciteis": "exercitar",
    "exercitem": "exercitar",
    "exercitemo": "exercitar",
    "exercitemos": "exercitar",
    "exercites": "exercitar",
    "exercito": "exercitar",
    "exercitora": "exercitor",
    "exercitoras": "exercitor",
    "exercitores": "exercitor",
    "exercitou": "exercitar",
    "exercitá": "exercitar",
    "exercitámo": "exercitar",
    "exercitámos": "exercitar",
    "exercitáramo": "exercitar",
    "exercitáramos": "exercitar",
    "exercitárei": "exercitar",
    "exercitáreis": "exercitar",
    "exercitásseis": "exercitar",
    "exercitássemos": "exercitar",
    "exercitávamo": "exercitar",
    "exercitávamos": "exercitar",
    "exercitávei": "exercitar",
    "exercitáveis": "exercitável",
    "exercitória": "exercitório",
    "exercitórias": "exercitório",
    "exercitórios": "exercitório",
    "exercê": "exercer",
    "exercêramo": "exercer",
    "exercêramos": "exercer",
    "exercêrei": "exercer",
    "exercêreis": "exercer",
    "exercêsseis": "exercer",
    "exercêssemos": "exercer",
    "exercíamo": "exercer",
    "exercíamos": "exercer",
    "exercícios": "exercício",
    "exercíei": "exercer",
    "exercíeis": "exercer",
    "exerda": "exerdar",
    "exerdada": "exerdar",
    "exerdadas": "exerdar",
    "exerdado": "exerdar",
    "exerdados": "exerdar",
    "exerdai": "exerdar",
    "exerdais": "exerdar",
    "exerdam": "exerdar",
    "exerdamo": "exerdar",
    "exerdamos": "exerdar",
    "exerdando": "exerdar",
    "exerdara": "exerdar",
    "exerdaram": "exerdar",
    "exerdaras": "exerdar",
    "exerdarde": "exerdar",
    "exerdardes": "exerdar",
    "exerdare": "exerdar",
    "exerdarei": "exerdar",
    "exerdareis": "exerdar",
    "exerdarem": "exerdar",
    "exerdaremos": "exerdar",
    "exerdares": "exerdar",
    "exerdaria": "exerdar",
    "exerdariam": "exerdar",
    "exerdarias": "exerdar",
    "exerdarmo": "exerdar",
    "exerdarmos": "exerdar",
    "exerdará": "exerdar",
    "exerdarás": "exerdar",
    "exerdarão": "exerdar",
    "exerdaríamos": "exerdar",
    "exerdaríeis": "exerdar",
    "exerdas": "exerdar",
    "exerdasse": "exerdar",
    "exerdassem": "exerdar",
    "exerdasses": "exerdar",
    "exerdaste": "exerdar",
    "exerdastes": "exerdar",
    "exerdava": "exerdar",
    "exerdavam": "exerdar",
    "exerdavas": "exerdar",
    "exerdações": "exerdação",
    "exerde": "exerdar",
    "exerdei": "exerdar",
    "exerdeis": "exerdar",
    "exerdem": "exerdar",
    "exerdemo": "exerdar",
    "exerdemos": "exerdar",
    "exerdes": "exerdar",
    "exerdo": "exerdar",
    "exerdou": "exerdar",
    "exerdá": "exerdar",
    "exerdámo": "exerdar",
    "exerdámos": "exerdar",
    "exerdáramo": "exerdar",
    "exerdáramos": "exerdar",
    "exerdárei": "exerdar",
    "exerdáreis": "exerdar",
    "exerdásseis": "exerdar",
    "exerdássemos": "exerdar",
    "exerdávamo": "exerdar",
    "exerdávamos": "exerdar",
    "exerdávei": "exerdar",
    "exerdáveis": "exerdar",
    "exergos": "exergo",
    "exergásias": "exergásia",
    "exergásica": "exergásico",
    "exergásicas": "exergásico",
    "exergásicos": "exergásico",
    "exergástica": "exergástico",
    "exergásticas": "exergástico",
    "exergásticos": "exergástico",
    "exerça": "exercer",
    "exerçais": "exercer",
    "exerçam": "exercer",
    "exerçamo": "exercer",
    "exerçamos": "exercer",
    "exerças": "exercer",
    "exerço": "exercer",
    "exerética": "exerético",
    "exeréticas": "exerético",
    "exeréticos": "exerético",
    "exfetações": "exfetação",
    "exfolia": "exfoliar",
    "exfoliada": "exfoliar",
    "exfoliadas": "exfoliar",
    "exfoliado": "exfoliar",
    "exfoliados": "exfoliar",
    "exfoliai": "exfoliar",
    "exfoliais": "exfoliar",
    "exfoliam": "exfoliar",
    "exfoliamo": "exfoliar",
    "exfoliamos": "exfoliar",
    "exfoliando": "exfoliar",
    "exfoliara": "exfoliar",
    "exfoliaram": "exfoliar",
    "exfoliaras": "exfoliar",
    "exfoliarde": "exfoliar",
    "exfoliardes": "exfoliar",
    "exfoliare": "exfoliar",
    "exfoliarei": "exfoliar",
    "exfoliareis": "exfoliar",
    "exfoliarem": "exfoliar",
    "exfoliaremos": "exfoliar",
    "exfoliares": "exfoliar",
    "exfoliaria": "exfoliar",
    "exfoliariam": "exfoliar",
    "exfoliarias": "exfoliar",
    "exfoliarmo": "exfoliar",
    "exfoliarmos": "exfoliar",
    "exfoliará": "exfoliar",
    "exfoliarás": "exfoliar",
    "exfoliarão": "exfoliar",
    "exfoliaríamos": "exfoliar",
    "exfoliaríeis": "exfoliar",
    "exfolias": "exfoliar",
    "exfoliasse": "exfoliar",
    "exfoliassem": "exfoliar",
    "exfoliasses": "exfoliar",
    "exfoliaste": "exfoliar",
    "exfoliastes": "exfoliar",
    "exfoliava": "exfoliar",
    "exfoliavam": "exfoliar",
    "exfoliavas": "exfoliar",
    "exfoliações": "exfoliação",
    "exfolie": "exfoliar",
    "exfoliei": "exfoliar",
    "exfolieis": "exfoliar",
    "exfoliem": "exfoliar",
    "exfoliemo": "exfoliar",
    "exfoliemos": "exfoliar",
    "exfolies": "exfoliar",
    "exfolio": "exfoliar",
    "exfoliou": "exfoliar",
    "exfoliá": "exfoliar",
    "exfoliámo": "exfoliar",
    "exfoliámos": "exfoliar",
    "exfoliáramo": "exfoliar",
    "exfoliáramos": "exfoliar",
    "exfoliárei": "exfoliar",
    "exfoliáreis": "exfoliar",
    "exfoliásseis": "exfoliar",
    "exfoliássemos": "exfoliar",
    "exfoliávamo": "exfoliar",
    "exfoliávamos": "exfoliar",
    "exfoliávei": "exfoliar",
    "exfoliáveis": "exfoliar",
    "exiba": "exibir",
    "exibais": "exibir",
    "exibam": "exibir",
    "exibamo": "exibir",
    "exibamos": "exibir",
    "exibas": "exibir",
    "exibe": "exibir",
    "exibem": "exibir",
    "exibes": "exibir",
    "exibi": "exibir",
    "exibia": "exibir",
    "exibiam": "exibir",
    "exibias": "exibir",
    "exibicionismos": "exibicionismo",
    "exibicionistas": "exibicionista",
    "exibida": "exibir",
    "exibidas": "exibir",
    "exibido": "exibir",
    "exibidora": "exibidor",
    "exibidoras": "exibidor",
    "exibidores": "exibidor",
    "exibidos": "exibir",
    "exibimo": "exibir",
    "exibimos": "exibir",
    "exibindo": "exibir",
    "exibira": "exibir",
    "exibiram": "exibir",
    "exibiras": "exibir",
    "exibirde": "exibir",
    "exibirdes": "exibir",
    "exibire": "exibir",
    "exibirei": "exibir",
    "exibireis": "exibir",
    "exibirem": "exibir",
    "exibiremos": "exibir",
    "exibires": "exibir",
    "exibiria": "exibir",
    "exibiriam": "exibir",
    "exibirias": "exibir",
    "exibirmo": "exibir",
    "exibirmos": "exibir",
    "exibirá": "exibir",
    "exibirás": "exibir",
    "exibirão": "exibir",
    "exibiríamos": "exibir",
    "exibiríeis": "exibir",
    "exibis": "exibir",
    "exibisse": "exibir",
    "exibissem": "exibir",
    "exibisses": "exibir",
    "exibiste": "exibir",
    "exibistes": "exibir",
    "exibitiva": "exibitivo",
    "exibitivas": "exibitivo",
    "exibitivos": "exibitivo",
    "exibitória": "exibitório",
    "exibitórias": "exibitório",
    "exibitórios": "exibitório",
    "exibiu": "exibir",
    "exibições": "exibição",
    "exibo": "exibir",
    "exibíamo": "exibir",
    "exibíamos": "exibir",
    "exibíei": "exibir",
    "exibíeis": "exibir",
    "exibíramo": "exibir",
    "exibíramos": "exibir",
    "exibírei": "exibir",
    "exibíreis": "exibir",
    "exibísseis": "exibir",
    "exibíssemos": "exibir",
    "exiciais": "exicial",
    "exidos": "exido",
    "exige": "exigir",
    "exigem": "exigir",
    "exigentes": "exigente",
    "exiges": "exigir",
    "exigi": "exigir",
    "exigia": "exigir",
    "exigiam": "exigir",
    "exigias": "exigir",
    "exigibilidades": "exigibilidade",
    "exigida": "exigir",
    "exigidas": "exigir",
    "exigido": "exigir",
    "exigidos": "exigir",
    "exigimo": "exigir",
    "exigimos": "exigir",
    "exigindo": "exigir",
    "exigira": "exigir",
    "exigiram": "exigir",
    "exigiras": "exigir",
    "exigirde": "exigir",
    "exigirdes": "exigir",
    "exigire": "exigir",
    "exigirei": "exigir",
    "exigireis": "exigir",
    "exigirem": "exigir",
    "exigiremos": "exigir",
    "exigires": "exigir",
    "exigiria": "exigir",
    "exigiriam": "exigir",
    "exigirias": "exigir",
    "exigirmo": "exigir",
    "exigirmos": "exigir",
    "exigirá": "exigir",
    "exigirás": "exigir",
    "exigirão": "exigir",
    "exigiríamos": "exigir",
    "exigiríeis": "exigir",
    "exigis": "exigir",
    "exigisse": "exigir",
    "exigissem": "exigir",
    "exigisses": "exigir",
    "exigiste": "exigir",
    "exigistes": "exigir",
    "exigiu": "exigir",
    "exiguidades": "exiguidade",
    "exigências": "exigência",
    "exigíamo": "exigir",
    "exigíamos": "exigir",
    "exigíei": "exigir",
    "exigíeis": "exigir",
    "exigíramo": "exigir",
    "exigíramos": "exigir",
    "exigírei": "exigir",
    "exigíreis": "exigir",
    "exigísseis": "exigir",
    "exigíssemos": "exigir",
    "exigíveis": "exigível",
    "exija": "exigir",
    "exijais": "exigir",
    "exijam": "exigir",
    "exijamo": "exigir",
    "exijamos": "exigir",
    "exijas": "exigir",
    "exijo": "exigir",
    "exila": "exilar",
    "exilada": "exilar",
    "exiladas": "exilar",
    "exilado": "exilar",
    "exilados": "exilar",
    "exilai": "exilar",
    "exilais": "exilar",
    "exilam": "exilar",
    "exilamo": "exilar",
    "exilamos": "exilar",
    "exilando": "exilar",
    "exilara": "exilar",
    "exilaram": "exilar",
    "exilaras": "exilar",
    "exilarde": "exilar",
    "exilardes": "exilar",
    "exilare": "exilar",
    "exilarei": "exilar",
    "exilareis": "exilar",
    "exilarem": "exilar",
    "exilaremos": "exilar",
    "exilares": "exilar",
    "exilaria": "exilar",
    "exilariam": "exilar",
    "exilarias": "exilar",
    "exilarmo": "exilar",
    "exilarmos": "exilar",
    "exilará": "exilar",
    "exilarás": "exilar",
    "exilarão": "exilar",
    "exilaríamos": "exilar",
    "exilaríeis": "exilar",
    "exilas": "exilar",
    "exilasse": "exilar",
    "exilassem": "exilar",
    "exilasses": "exilar",
    "exilaste": "exilar",
    "exilastes": "exilar",
    "exilava": "exilar",
    "exilavam": "exilar",
    "exilavas": "exilar",
    "exile": "exilar",
    "exilei": "exilar",
    "exileis": "exilar",
    "exilem": "exilar",
    "exilemo": "exilar",
    "exilemos": "exilar",
    "exiles": "exile",
    "exilo": "exilar",
    "exilou": "exilar",
    "exilá": "exilar",
    "exilámo": "exilar",
    "exilámos": "exilar",
    "exiláramo": "exilar",
    "exiláramos": "exilar",
    "exilárei": "exilar",
    "exiláreis": "exilar",
    "exilásseis": "exilar",
    "exilássemos": "exilar",
    "exilávamo": "exilar",
    "exilávamos": "exilar",
    "exilávei": "exilar",
    "exiláveis": "exilar",
    "exima": "eximir",
    "eximais": "eximir",
    "eximam": "eximir",
    "eximamo": "eximir",
    "eximamos": "eximir",
    "eximas": "eximir",
    "exime": "eximir",
    "eximem": "eximir",
    "eximes": "eximir",
    "eximi": "eximir",
    "eximia": "eximir",
    "eximiam": "eximir",
    "eximias": "eximir",
    "eximida": "eximir",
    "eximidas": "eximir",
    "eximido": "eximir",
    "eximidos": "eximir",
    "eximimo": "eximir",
    "eximimos": "eximir",
    "eximindo": "eximir",
    "eximira": "eximir",
    "eximiram": "eximir",
    "eximiras": "eximir",
    "eximirde": "eximir",
    "eximirdes": "eximir",
    "eximire": "eximir",
    "eximirei": "eximir",
    "eximireis": "eximir",
    "eximirem": "eximir",
    "eximiremos": "eximir",
    "eximires": "eximir",
    "eximiria": "eximir",
    "eximiriam": "eximir",
    "eximirias": "eximir",
    "eximirmo": "eximir",
    "eximirmos": "eximir",
    "eximirá": "eximir",
    "eximirás": "eximir",
    "eximirão": "eximir",
    "eximiríamos": "eximir",
    "eximiríeis": "eximir",
    "eximis": "eximir",
    "eximisse": "eximir",
    "eximissem": "eximir",
    "eximisses": "eximir",
    "eximiste": "eximir",
    "eximistes": "eximir",
    "eximiu": "eximir",
    "eximo": "eximir",
    "eximíamo": "eximir",
    "eximíamos": "eximir",
    "eximíei": "eximir",
    "eximíeis": "eximir",
    "eximíramo": "eximir",
    "eximíramos": "eximir",
    "eximírei": "eximir",
    "eximíreis": "eximir",
    "eximísseis": "eximir",
    "eximíssemos": "eximir",
    "exinana": "exinanir",
    "exinanais": "exinanir",
    "exinanam": "exinanir",
    "exinanamo": "exinanir",
    "exinanamos": "exinanir",
    "exinanas": "exinanir",
    "exinane": "exinanir",
    "exinanem": "exinanir",
    "exinanes": "exinanir",
    "exinani": "exinanir",
    "exinania": "exinanir",
    "exinaniam": "exinanir",
    "exinanias": "exinanir",
    "exinanida": "exinanir",
    "exinanidas": "exinanir",
    "exinanido": "exinanir",
    "exinanidos": "exinanir",
    "exinanimo": "exinanir",
    "exinanimos": "exinanir",
    "exinanindo": "exinanir",
    "exinanira": "exinanir",
    "exinaniram": "exinanir",
    "exinaniras": "exinanir",
    "exinanirde": "exinanir",
    "exinanirdes": "exinanir",
    "exinanire": "exinanir",
    "exinanirei": "exinanir",
    "exinanireis": "exinanir",
    "exinanirem": "exinanir",
    "exinaniremos": "exinanir",
    "exinanires": "exinanir",
    "exinaniria": "exinanir",
    "exinaniriam": "exinanir",
    "exinanirias": "exinanir",
    "exinanirmo": "exinanir",
    "exinanirmos": "exinanir",
    "exinanirá": "exinanir",
    "exinanirás": "exinanir",
    "exinanirão": "exinanir",
    "exinaniríamos": "exinanir",
    "exinaniríeis": "exinanir",
    "exinanis": "exinanir",
    "exinanisse": "exinanir",
    "exinanissem": "exinanir",
    "exinanisses": "exinanir",
    "exinaniste": "exinanir",
    "exinanistes": "exinanir",
    "exinaniu": "exinanir",
    "exinanições": "exinanição",
    "exinano": "exinanir",
    "exinaníamo": "exinanir",
    "exinaníamos": "exinanir",
    "exinaníei": "exinanir",
    "exinaníeis": "exinanir",
    "exinaníramo": "exinanir",
    "exinaníramos": "exinanir",
    "exinanírei": "exinanir",
    "exinaníreis": "exinanir",
    "exinanísseis": "exinanir",
    "exinaníssemos": "exinanir",
    "exinas": "exina",
    "exinguidora": "exinguidor",
    "exinguidoras": "exinguidor",
    "exinguidores": "exinguidor",
    "exis": "exil",
    "exista": "existir",
    "existais": "existir",
    "existam": "existir",
    "existamo": "existir",
    "existamos": "existir",
    "existas": "existir",
    "existe": "existir",
    "existem": "existir",
    "existenciais": "existencial",
    "existencialismos": "existencialismo",
    "existencialistas": "existencialista",
    "existentes": "existente",
    "existes": "existir",
    "existi": "existir",
    "existia": "existir",
    "existiam": "existir",
    "existias": "existir",
    "existida": "existir",
    "existidas": "existir",
    "existido": "existir",
    "existidos": "existir",
    "existimo": "existir",
    "existimos": "existir",
    "existindo": "existir",
    "existira": "existir",
    "existiram": "existir",
    "existiras": "existir",
    "existirdes": "existir",
    "existirei": "existir",
    "existireis": "existir",
    "existirem": "existir",
    "existiremos": "existir",
    "existires": "existir",
    "existiria": "existir",
    "existiriam": "existir",
    "existirias": "existir",
    "existirmo": "existir",
    "existirmos": "existir",
    "existirá": "existir",
    "existirás": "existir",
    "existirão": "existir",
    "existiríamos": "existir",
    "existiríeis": "existir",
    "existis": "existir",
    "existisse": "existir",
    "existissem": "existir",
    "existisses": "existir",
    "exististe": "existir",
    "exististes": "existir",
    "existiu": "existir",
    "existo": "existir",
    "existências": "existência",
    "existíamo": "existir",
    "existíamos": "existir",
    "existíeis": "existir",
    "existíramo": "existir",
    "existíramos": "existir",
    "existíreis": "existir",
    "existísseis": "existir",
    "existíssemos": "existir",
    "exitâncias": "exitância",
    "exma": "exmo",
    "exmas": "exmo",
    "exmos": "exmo",
    "exocarpos": "exocarpo",
    "exocrânia": "exocrânio",
    "exocrânias": "exocrânio",
    "exocrânica": "exocrânico",
    "exocrânicas": "exocrânico",
    "exocrânicos": "exocrânico",
    "exocrânios": "exocrânio",
    "exocrínica": "exocrínico",
    "exocrínicas": "exocrínico",
    "exocrínicos": "exocrínico",
    "exocárpica": "exocárpico",
    "exocárpicas": "exocárpico",
    "exocárpicos": "exocárpico",
    "exocíclica": "exocíclico",
    "exocíclicas": "exocíclico",
    "exocíclicos": "exocíclico",
    "exoderma": "exodermo",
    "exodermas": "exodermo",
    "exodermes": "exoderme",
    "exodermos": "exodermo",
    "exodérmica": "exodérmico",
    "exodérmicas": "exodérmico",
    "exodérmicos": "exodérmico",
    "exoforias": "exoforia",
    "exoftalmias": "exoftalmia",
    "exoftalmos": "exoftalmo",
    "exoftálmica": "exoftálmico",
    "exoftálmicas": "exoftálmico",
    "exoftálmicos": "exoftálmico",
    "exofórica": "exofórico",
    "exofóricas": "exofórico",
    "exofóricos": "exofórico",
    "exogamias": "exogamia",
    "exogenias": "exogenia",
    "exogâmica": "exogâmico",
    "exogâmicas": "exogâmico",
    "exogâmicos": "exogâmico",
    "exogénea": "exogéneo",
    "exogéneas": "exogéneo",
    "exogéneos": "exogéneo",
    "exogénica": "exogénico",
    "exogénicas": "exogénico",
    "exogénicos": "exogénico",
    "exometras": "exometra",
    "exometrias": "exometria",
    "exomologeses": "exomologese",
    "exomologésica": "exomologésico",
    "exomologésicas": "exomologésico",
    "exomologésicos": "exomologésico",
    "exomologética": "exomologético",
    "exomologéticas": "exomologético",
    "exomologéticos": "exomologético",
    "exomorfismos": "exomorfismo",
    "exomorfistas": "exomorfista",
    "exométrica": "exométrico",
    "exométricas": "exométrico",
    "exométricos": "exométrico",
    "exomórfica": "exomórfico",
    "exomórficas": "exomórfico",
    "exomórficos": "exomórfico",
    "exonera": "exonerar",
    "exonerabilidades": "exonerabilidade",
    "exonerada": "exonerar",
    "exoneradas": "exonerar",
    "exonerado": "exonerar",
    "exonerados": "exonerar",
    "exonerai": "exonerar",
    "exonerais": "exonerar",
    "exoneram": "exonerar",
    "exoneramo": "exonerar",
    "exoneramos": "exonerar",
    "exonerando": "exonerar",
    "exonerara": "exonerar",
    "exoneraram": "exonerar",
    "exoneraras": "exonerar",
    "exonerarde": "exonerar",
    "exonerardes": "exonerar",
    "exonerare": "exonerar",
    "exonerarei": "exonerar",
    "exonerareis": "exonerar",
    "exonerarem": "exonerar",
    "exoneraremos": "exonerar",
    "exonerares": "exonerar",
    "exoneraria": "exonerar",
    "exonerariam": "exonerar",
    "exonerarias": "exonerar",
    "exonerarmo": "exonerar",
    "exonerarmos": "exonerar",
    "exonerará": "exonerar",
    "exonerarás": "exonerar",
    "exonerarão": "exonerar",
    "exoneraríamos": "exonerar",
    "exoneraríeis": "exonerar",
    "exoneras": "exonerar",
    "exonerasse": "exonerar",
    "exonerassem": "exonerar",
    "exonerasses": "exonerar",
    "exoneraste": "exonerar",
    "exonerastes": "exonerar",
    "exonerativa": "exonerativo",
    "exonerativas": "exonerativo",
    "exonerativos": "exonerativo",
    "exoneratória": "exoneratório",
    "exoneratórias": "exoneratório",
    "exoneratórios": "exoneratório",
    "exonerava": "exonerar",
    "exoneravam": "exonerar",
    "exoneravas": "exonerar",
    "exonerações": "exoneração",
    "exonere": "exonerar",
    "exonerei": "exonerar",
    "exonereis": "exonerar",
    "exonerem": "exonerar",
    "exoneremo": "exonerar",
    "exoneremos": "exonerar",
    "exoneres": "exonerar",
    "exonero": "exonerar",
    "exonerou": "exonerar",
    "exonerá": "exonerar",
    "exonerámo": "exonerar",
    "exonerámos": "exonerar",
    "exoneráramo": "exonerar",
    "exoneráramos": "exonerar",
    "exonerárei": "exonerar",
    "exoneráreis": "exonerar",
    "exonerásseis": "exonerar",
    "exonerássemos": "exonerar",
    "exonerávamo": "exonerar",
    "exonerávamos": "exonerar",
    "exonerávei": "exonerar",
    "exoneráveis": "exonerável",
    "exonfalias": "exonfalia",
    "exonfálica": "exonfálico",
    "exonfálicas": "exonfálico",
    "exonfálicos": "exonfálico",
    "exopódios": "exopódio",
    "exora": "exorar",
    "exorada": "exorar",
    "exoradas": "exorar",
    "exorado": "exorar",
    "exorados": "exorar",
    "exorai": "exorar",
    "exorais": "exorar",
    "exoram": "exorar",
    "exoramo": "exorar",
    "exoramos": "exorar",
    "exorando": "exorar",
    "exorara": "exorar",
    "exoraram": "exorar",
    "exoraras": "exorar",
    "exorarde": "exorar",
    "exorardes": "exorar",
    "exorare": "exorar",
    "exorarei": "exorar",
    "exorareis": "exorar",
    "exorarem": "exorar",
    "exoraremos": "exorar",
    "exorares": "exorar",
    "exoraria": "exorar",
    "exorariam": "exorar",
    "exorarias": "exorar",
    "exorarmo": "exorar",
    "exorarmos": "exorar",
    "exorará": "exorar",
    "exorarás": "exorar",
    "exorarão": "exorar",
    "exoraríamos": "exorar",
    "exoraríeis": "exorar",
    "exoras": "exorar",
    "exorasse": "exorar",
    "exorassem": "exorar",
    "exorasses": "exorar",
    "exoraste": "exorar",
    "exorastes": "exorar",
    "exorava": "exorar",
    "exoravam": "exorar",
    "exoravas": "exorar",
    "exorações": "exoração",
    "exorbita": "exorbitar",
    "exorbitada": "exorbitar",
    "exorbitadas": "exorbitar",
    "exorbitado": "exorbitar",
    "exorbitados": "exorbitar",
    "exorbitai": "exorbitar",
    "exorbitais": "exorbitar",
    "exorbitam": "exorbitar",
    "exorbitamo": "exorbitar",
    "exorbitamos": "exorbitar",
    "exorbitando": "exorbitar",
    "exorbitantes": "exorbitante",
    "exorbitara": "exorbitar",
    "exorbitaram": "exorbitar",
    "exorbitaras": "exorbitar",
    "exorbitardes": "exorbitar",
    "exorbitarei": "exorbitar",
    "exorbitareis": "exorbitar",
    "exorbitarem": "exorbitar",
    "exorbitaremos": "exorbitar",
    "exorbitares": "exorbitar",
    "exorbitaria": "exorbitar",
    "exorbitariam": "exorbitar",
    "exorbitarias": "exorbitar",
    "exorbitarmo": "exorbitar",
    "exorbitarmos": "exorbitar",
    "exorbitará": "exorbitar",
    "exorbitarás": "exorbitar",
    "exorbitarão": "exorbitar",
    "exorbitaríamos": "exorbitar",
    "exorbitaríeis": "exorbitar",
    "exorbitas": "exorbitar",
    "exorbitasse": "exorbitar",
    "exorbitassem": "exorbitar",
    "exorbitasses": "exorbitar",
    "exorbitaste": "exorbitar",
    "exorbitastes": "exorbitar",
    "exorbitava": "exorbitar",
    "exorbitavam": "exorbitar",
    "exorbitavas": "exorbitar",
    "exorbite": "exorbitar",
    "exorbitei": "exorbitar",
    "exorbiteis": "exorbitar",
    "exorbitem": "exorbitar",
    "exorbitemo": "exorbitar",
    "exorbitemos": "exorbitar",
    "exorbites": "exorbitar",
    "exorbito": "exorbitar",
    "exorbitou": "exorbitar",
    "exorbitámo": "exorbitar",
    "exorbitámos": "exorbitar",
    "exorbitáramo": "exorbitar",
    "exorbitáramos": "exorbitar",
    "exorbitáreis": "exorbitar",
    "exorbitásseis": "exorbitar",
    "exorbitássemos": "exorbitar",
    "exorbitávamo": "exorbitar",
    "exorbitávamos": "exorbitar",
    "exorbitáveis": "exorbitar",
    "exorbitâncias": "exorbitância",
    "exorcisada": "exorcisado",
    "exorcisadas": "exorcisado",
    "exorcisados": "exorcisado",
    "exorcisma": "exorcismar",
    "exorcismada": "exorcismar",
    "exorcismadas": "exorcismar",
    "exorcismado": "exorcismar",
    "exorcismados": "exorcismar",
    "exorcismai": "exorcismar",
    "exorcismais": "exorcismar",
    "exorcismam": "exorcismar",
    "exorcismamo": "exorcismar",
    "exorcismamos": "exorcismar",
    "exorcismando": "exorcismar",
    "exorcismara": "exorcismar",
    "exorcismaram": "exorcismar",
    "exorcismaras": "exorcismar",
    "exorcismarde": "exorcismar",
    "exorcismardes": "exorcismar",
    "exorcismare": "exorcismar",
    "exorcismarei": "exorcismar",
    "exorcismareis": "exorcismar",
    "exorcismarem": "exorcismar",
    "exorcismaremos": "exorcismar",
    "exorcismares": "exorcismar",
    "exorcismaria": "exorcismar",
    "exorcismariam": "exorcismar",
    "exorcismarias": "exorcismar",
    "exorcismarmo": "exorcismar",
    "exorcismarmos": "exorcismar",
    "exorcismará": "exorcismar",
    "exorcismarás": "exorcismar",
    "exorcismarão": "exorcismar",
    "exorcismaríamos": "exorcismar",
    "exorcismaríeis": "exorcismar",
    "exorcismas": "exorcismar",
    "exorcismasse": "exorcismar",
    "exorcismassem": "exorcismar",
    "exorcismasses": "exorcismar",
    "exorcismaste": "exorcismar",
    "exorcismastes": "exorcismar",
    "exorcismava": "exorcismar",
    "exorcismavam": "exorcismar",
    "exorcismavas": "exorcismar",
    "exorcisme": "exorcismar",
    "exorcismei": "exorcismar",
    "exorcismeis": "exorcismar",
    "exorcismem": "exorcismar",
    "exorcismemo": "exorcismar",
    "exorcismemos": "exorcismar",
    "exorcismes": "exorcismar",
    "exorcismo": "exorcismar",
    "exorcismos": "exorcismo",
    "exorcismou": "exorcismar",
    "exorcismá": "exorcismar",
    "exorcismámo": "exorcismar",
    "exorcismámos": "exorcismar",
    "exorcismáramo": "exorcismar",
    "exorcismáramos": "exorcismar",
    "exorcismárei": "exorcismar",
    "exorcismáreis": "exorcismar",
    "exorcismásseis": "exorcismar",
    "exorcismássemos": "exorcismar",
    "exorcismávamo": "exorcismar",
    "exorcismávamos": "exorcismar",
    "exorcismávei": "exorcismar",
    "exorcismáveis": "exorcismar",
    "exorcistada": "exorcistado",
    "exorcistadas": "exorcistado",
    "exorcistados": "exorcistado",
    "exorcistas": "exorcista",
    "exorciza": "exorcizar",
    "exorcizada": "exorcizar",
    "exorcizadas": "exorcizar",
    "exorcizado": "exorcizar",
    "exorcizados": "exorcizar",
    "exorcizai": "exorcizar",
    "exorcizais": "exorcizar",
    "exorcizam": "exorcizar",
    "exorcizamo": "exorcizar",
    "exorcizamos": "exorcizar",
    "exorcizando": "exorcizar",
    "exorcizara": "exorcizar",
    "exorcizaram": "exorcizar",
    "exorcizaras": "exorcizar",
    "exorcizarde": "exorcizar",
    "exorcizardes": "exorcizar",
    "exorcizare": "exorcizar",
    "exorcizarei": "exorcizar",
    "exorcizareis": "exorcizar",
    "exorcizarem": "exorcizar",
    "exorcizaremos": "exorcizar",
    "exorcizares": "exorcizar",
    "exorcizaria": "exorcizar",
    "exorcizariam": "exorcizar",
    "exorcizarias": "exorcizar",
    "exorcizarmo": "exorcizar",
    "exorcizarmos": "exorcizar",
    "exorcizará": "exorcizar",
    "exorcizarás": "exorcizar",
    "exorcizarão": "exorcizar",
    "exorcizaríamos": "exorcizar",
    "exorcizaríeis": "exorcizar",
    "exorcizas": "exorcizar",
    "exorcizasse": "exorcizar",
    "exorcizassem": "exorcizar",
    "exorcizasses": "exorcizar",
    "exorcizaste": "exorcizar",
    "exorcizastes": "exorcizar",
    "exorcizava": "exorcizar",
    "exorcizavam": "exorcizar",
    "exorcizavas": "exorcizar",
    "exorcize": "exorcizar",
    "exorcizei": "exorcizar",
    "exorcizeis": "exorcizar",
    "exorcizem": "exorcizar",
    "exorcizemo": "exorcizar",
    "exorcizemos": "exorcizar",
    "exorcizes": "exorcizar",
    "exorcizo": "exorcizar",
    "exorcizou": "exorcizar",
    "exorcizá": "exorcizar",
    "exorcizámo": "exorcizar",
    "exorcizámos": "exorcizar",
    "exorcizáramo": "exorcizar",
    "exorcizáramos": "exorcizar",
    "exorcizárei": "exorcizar",
    "exorcizáreis": "exorcizar",
    "exorcizásseis": "exorcizar",
    "exorcizássemos": "exorcizar",
    "exorcizávamo": "exorcizar",
    "exorcizávamos": "exorcizar",
    "exorcizávei": "exorcizar",
    "exorcizáveis": "exorcizável",
    "exordia": "exordiar",
    "exordiada": "exordiar",
    "exordiadas": "exordiar",
    "exordiado": "exordiar",
    "exordiados": "exordiar",
    "exordiai": "exordiar",
    "exordiais": "exordiar",
    "exordiam": "exordiar",
    "exordiamo": "exordiar",
    "exordiamos": "exordiar",
    "exordiando": "exordiar",
    "exordiara": "exordiar",
    "exordiaram": "exordiar",
    "exordiaras": "exordiar",
    "exordiarde": "exordiar",
    "exordiardes": "exordiar",
    "exordiare": "exordiar",
    "exordiarei": "exordiar",
    "exordiareis": "exordiar",
    "exordiarem": "exordiar",
    "exordiaremos": "exordiar",
    "exordiares": "exordiar",
    "exordiaria": "exordiar",
    "exordiariam": "exordiar",
    "exordiarias": "exordiar",
    "exordiarmo": "exordiar",
    "exordiarmos": "exordiar",
    "exordiará": "exordiar",
    "exordiarás": "exordiar",
    "exordiarão": "exordiar",
    "exordiaríamos": "exordiar",
    "exordiaríeis": "exordiar",
    "exordias": "exordiar",
    "exordiasse": "exordiar",
    "exordiassem": "exordiar",
    "exordiasses": "exordiar",
    "exordiaste": "exordiar",
    "exordiastes": "exordiar",
    "exordiava": "exordiar",
    "exordiavam": "exordiar",
    "exordiavas": "exordiar",
    "exordie": "exordiar",
    "exordiei": "exordiar",
    "exordieis": "exordiar",
    "exordiem": "exordiar",
    "exordiemo": "exordiar",
    "exordiemos": "exordiar",
    "exordies": "exordiar",
    "exordio": "exordiar",
    "exordiou": "exordiar",
    "exordiá": "exordiar",
    "exordiámo": "exordiar",
    "exordiámos": "exordiar",
    "exordiáramo": "exordiar",
    "exordiáramos": "exordiar",
    "exordiárei": "exordiar",
    "exordiáreis": "exordiar",
    "exordiásseis": "exordiar",
    "exordiássemos": "exordiar",
    "exordiávamo": "exordiar",
    "exordiávamos": "exordiar",
    "exordiávei": "exordiar",
    "exordiáveis": "exordiar",
    "exore": "exorar",
    "exorei": "exorar",
    "exoreis": "exorar",
    "exorem": "exorar",
    "exoremo": "exorar",
    "exoremos": "exorar",
    "exores": "exorar",
    "exorna": "exornar",
    "exornada": "exornar",
    "exornadas": "exornar",
    "exornado": "exornar",
    "exornados": "exornar",
    "exornai": "exornar",
    "exornais": "exornar",
    "exornam": "exornar",
    "exornamo": "exornar",
    "exornamos": "exornar",
    "exornando": "exornar",
    "exornara": "exornar",
    "exornaram": "exornar",
    "exornaras": "exornar",
    "exornarde": "exornar",
    "exornardes": "exornar",
    "exornare": "exornar",
    "exornarei": "exornar",
    "exornareis": "exornar",
    "exornarem": "exornar",
    "exornaremos": "exornar",
    "exornares": "exornar",
    "exornaria": "exornar",
    "exornariam": "exornar",
    "exornarias": "exornar",
    "exornarmo": "exornar",
    "exornarmos": "exornar",
    "exornará": "exornar",
    "exornarás": "exornar",
    "exornarão": "exornar",
    "exornaríamos": "exornar",
    "exornaríeis": "exornar",
    "exornas": "exornar",
    "exornasse": "exornar",
    "exornassem": "exornar",
    "exornasses": "exornar",
    "exornaste": "exornar",
    "exornastes": "exornar",
    "exornativa": "exornativo",
    "exornativas": "exornativo",
    "exornativos": "exornativo",
    "exornava": "exornar",
    "exornavam": "exornar",
    "exornavas": "exornar",
    "exornações": "exornação",
    "exorne": "exornar",
    "exornei": "exornar",
    "exorneis": "exornar",
    "exornem": "exornar",
    "exornemo": "exornar",
    "exornemos": "exornar",
    "exornes": "exornar",
    "exorno": "exornar",
    "exornou": "exornar",
    "exorná": "exornar",
    "exornámo": "exornar",
    "exornámos": "exornar",
    "exornáramo": "exornar",
    "exornáramos": "exornar",
    "exornárei": "exornar",
    "exornáreis": "exornar",
    "exornásseis": "exornar",
    "exornássemos": "exornar",
    "exornávamo": "exornar",
    "exornávamos": "exornar",
    "exornávei": "exornar",
    "exornáveis": "exornar",
    "exoro": "exorar",
    "exorou": "exorar",
    "exorreica": "exorreico",
    "exorreicas": "exorreico",
    "exorreicos": "exorreico",
    "exorta": "exortar",
    "exortada": "exortar",
    "exortadas": "exortar",
    "exortado": "exortar",
    "exortadora": "exortador",
    "exortadoras": "exortador",
    "exortadores": "exortador",
    "exortados": "exortar",
    "exortai": "exortar",
    "exortais": "exortar",
    "exortam": "exortar",
    "exortamo": "exortar",
    "exortamos": "exortar",
    "exortando": "exortar",
    "exortara": "exortar",
    "exortaram": "exortar",
    "exortaras": "exortar",
    "exortarde": "exortar",
    "exortardes": "exortar",
    "exortare": "exortar",
    "exortarei": "exortar",
    "exortareis": "exortar",
    "exortarem": "exortar",
    "exortaremos": "exortar",
    "exortares": "exortar",
    "exortaria": "exortar",
    "exortariam": "exortar",
    "exortarias": "exortar",
    "exortarmo": "exortar",
    "exortarmos": "exortar",
    "exortará": "exortar",
    "exortarás": "exortar",
    "exortarão": "exortar",
    "exortaríamos": "exortar",
    "exortaríeis": "exortar",
    "exortas": "exortar",
    "exortasse": "exortar",
    "exortassem": "exortar",
    "exortasses": "exortar",
    "exortaste": "exortar",
    "exortastes": "exortar",
    "exortativa": "exortativo",
    "exortativas": "exortativo",
    "exortativos": "exortativo",
    "exortatória": "exortatório",
    "exortatórias": "exortatório",
    "exortatórios": "exortatório",
    "exortava": "exortar",
    "exortavam": "exortar",
    "exortavas": "exortar",
    "exortações": "exortação",
    "exorte": "exortar",
    "exortei": "exortar",
    "exorteis": "exortar",
    "exortem": "exortar",
    "exortemo": "exortar",
    "exortemos": "exortar",
    "exortes": "exortar",
    "exorto": "exortar",
    "exortou": "exortar",
    "exortá": "exortar",
    "exortámo": "exortar",
    "exortámos": "exortar",
    "exortáramo": "exortar",
    "exortáramos": "exortar",
    "exortárei": "exortar",
    "exortáreis": "exortar",
    "exortásseis": "exortar",
    "exortássemos": "exortar",
    "exortávamo": "exortar",
    "exortávamos": "exortar",
    "exortávei": "exortar",
    "exortáveis": "exortar",
    "exorá": "exorar",
    "exorámo": "exorar",
    "exorámos": "exorar",
    "exoráramo": "exorar",
    "exoráramos": "exorar",
    "exorárei": "exorar",
    "exoráreis": "exorar",
    "exorásseis": "exorar",
    "exorássemos": "exorar",
    "exorávamo": "exorar",
    "exorávamos": "exorar",
    "exorávei": "exorar",
    "exoráveis": "exorável",
    "exosferas": "exosfera",
    "exosférica": "exosférico",
    "exosféricas": "exosférico",
    "exosféricos": "exosférico",
    "exosmoses": "exosmose",
    "exosmótica": "exosmótico",
    "exosmóticas": "exosmótico",
    "exosmóticos": "exosmótico",
    "exospórica": "exospórico",
    "exospóricas": "exospórico",
    "exospóricos": "exospórico",
    "exosqueletos": "exosqueleto",
    "exosquelética": "exosquelético",
    "exosqueléticas": "exosquelético",
    "exosqueléticos": "exosquelético",
    "exosteoses": "exosteose",
    "exosteótica": "exosteótico",
    "exosteóticas": "exosteótico",
    "exosteóticos": "exosteótico",
    "exostoses": "exostose",
    "exostósica": "exostósico",
    "exostósicas": "exostósico",
    "exostósicos": "exostósico",
    "exostótica": "exostótico",
    "exostóticas": "exostótico",
    "exostóticos": "exostótico",
    "exoterismos": "exoterismo",
    "exotismos": "exotismo",
    "exotérica": "exotérico",
    "exotéricas": "exotérico",
    "exotéricos": "exotérico",
    "exotérmica": "exotérmico",
    "exotérmicas": "exotérmico",
    "exotérmicos": "exotérmico",
    "expanda": "expandir",
    "expandais": "expandir",
    "expandam": "expandir",
    "expandamo": "expandir",
    "expandamos": "expandir",
    "expandas": "expandir",
    "expande": "expandir",
    "expandem": "expandir",
    "expandes": "expandir",
    "expandi": "expandir",
    "expandia": "expandir",
    "expandiam": "expandir",
    "expandias": "expandir",
    "expandida": "expandir",
    "expandidas": "expandir",
    "expandido": "expandir",
    "expandidos": "expandir",
    "expandimo": "expandir",
    "expandimos": "expandir",
    "expandindo": "expandir",
    "expandira": "expandir",
    "expandiram": "expandir",
    "expandiras": "expandir",
    "expandirde": "expandir",
    "expandirdes": "expandir",
    "expandire": "expandir",
    "expandirei": "expandir",
    "expandireis": "expandir",
    "expandirem": "expandir",
    "expandiremos": "expandir",
    "expandires": "expandir",
    "expandiria": "expandir",
    "expandiriam": "expandir",
    "expandirias": "expandir",
    "expandirmo": "expandir",
    "expandirmos": "expandir",
    "expandirá": "expandir",
    "expandirás": "expandir",
    "expandirão": "expandir",
    "expandiríamos": "expandir",
    "expandiríeis": "expandir",
    "expandis": "expandir",
    "expandisse": "expandir",
    "expandissem": "expandir",
    "expandisses": "expandir",
    "expandiste": "expandir",
    "expandistes": "expandir",
    "expandiu": "expandir",
    "expando": "expandir",
    "expandíamo": "expandir",
    "expandíamos": "expandir",
    "expandíei": "expandir",
    "expandíeis": "expandir",
    "expandíramo": "expandir",
    "expandíramos": "expandir",
    "expandírei": "expandir",
    "expandíreis": "expandir",
    "expandísseis": "expandir",
    "expandíssemos": "expandir",
    "expansibilidades": "expansibilidade",
    "expansionismos": "expansionismo",
    "expansionistas": "expansionista",
    "expansiva": "expansivo",
    "expansivas": "expansivo",
    "expansividades": "expansividade",
    "expansivos": "expansivo",
    "expansíveis": "expansível",
    "expansões": "expansão",
    "expatria": "expatriar",
    "expatriada": "expatriar",
    "expatriadas": "expatriar",
    "expatriado": "expatriar",
    "expatriados": "expatriar",
    "expatriai": "expatriar",
    "expatriais": "expatriar",
    "expatriam": "expatriar",
    "expatriamentos": "expatriamento",
    "expatriamo": "expatriar",
    "expatriamos": "expatriar",
    "expatriando": "expatriar",
    "expatriara": "expatriar",
    "expatriaram": "expatriar",
    "expatriaras": "expatriar",
    "expatriarde": "expatriar",
    "expatriardes": "expatriar",
    "expatriare": "expatriar",
    "expatriarei": "expatriar",
    "expatriareis": "expatriar",
    "expatriarem": "expatriar",
    "expatriaremos": "expatriar",
    "expatriares": "expatriar",
    "expatriaria": "expatriar",
    "expatriariam": "expatriar",
    "expatriarias": "expatriar",
    "expatriarmo": "expatriar",
    "expatriarmos": "expatriar",
    "expatriará": "expatriar",
    "expatriarás": "expatriar",
    "expatriarão": "expatriar",
    "expatriaríamos": "expatriar",
    "expatriaríeis": "expatriar",
    "expatrias": "expatriar",
    "expatriasse": "expatriar",
    "expatriassem": "expatriar",
    "expatriasses": "expatriar",
    "expatriaste": "expatriar",
    "expatriastes": "expatriar",
    "expatriava": "expatriar",
    "expatriavam": "expatriar",
    "expatriavas": "expatriar",
    "expatriações": "expatriação",
    "expatrie": "expatriar",
    "expatriei": "expatriar",
    "expatrieis": "expatriar",
    "expatriem": "expatriar",
    "expatriemo": "expatriar",
    "expatriemos": "expatriar",
    "expatries": "expatriar",
    "expatrio": "expatriar",
    "expatriou": "expatriar",
    "expatriá": "expatriar",
    "expatriámo": "expatriar",
    "expatriámos": "expatriar",
    "expatriáramo": "expatriar",
    "expatriáramos": "expatriar",
    "expatriárei": "expatriar",
    "expatriáreis": "expatriar",
    "expatriásseis": "expatriar",
    "expatriássemos": "expatriar",
    "expatriávamo": "expatriar",
    "expatriávamos": "expatriar",
    "expatriávei": "expatriar",
    "expatriáveis": "expatriável",
    "expecta": "expectar",
    "expectada": "expectar",
    "expectadas": "expectar",
    "expectado": "expectar",
    "expectadora": "expectador",
    "expectadoras": "expectador",
    "expectadores": "expectador",
    "expectados": "expectar",
    "expectai": "expectar",
    "expectais": "expectar",
    "expectam": "expectar",
    "expectamo": "expectar",
    "expectamos": "expectar",
    "expectando": "expectar",
    "expectantes": "expectante",
    "expectara": "expectar",
    "expectaram": "expectar",
    "expectaras": "expectar",
    "expectarde": "expectar",
    "expectardes": "expectar",
    "expectare": "expectar",
    "expectarei": "expectar",
    "expectareis": "expectar",
    "expectarem": "expectar",
    "expectaremos": "expectar",
    "expectares": "expectar",
    "expectaria": "expectar",
    "expectariam": "expectar",
    "expectarias": "expectar",
    "expectarmo": "expectar",
    "expectarmos": "expectar",
    "expectará": "expectar",
    "expectarás": "expectar",
    "expectarão": "expectar",
    "expectaríamos": "expectar",
    "expectaríeis": "expectar",
    "expectas": "expectar",
    "expectasse": "expectar",
    "expectassem": "expectar",
    "expectasses": "expectar",
    "expectaste": "expectar",
    "expectastes": "expectar",
    "expectativas": "expectativa",
    "expectatória": "expectatório",
    "expectatórias": "expectatório",
    "expectatórios": "expectatório",
    "expectava": "expectar",
    "expectavam": "expectar",
    "expectavas": "expectar",
    "expectações": "expectação",
    "expecte": "expectar",
    "expectei": "expectar",
    "expecteis": "expectar",
    "expectem": "expectar",
    "expectemo": "expectar",
    "expectemos": "expectar",
    "expectes": "expectar",
    "expecto": "expectar",
    "expectora": "expectorar",
    "expectorada": "expectorar",
    "expectoradas": "expectorar",
    "expectorado": "expectorar",
    "expectorados": "expectorar",
    "expectorai": "expectorar",
    "expectorais": "expectorar",
    "expectoram": "expectorar",
    "expectoramo": "expectorar",
    "expectoramos": "expectorar",
    "expectorando": "expectorar",
    "expectorantes": "expectorante",
    "expectorara": "expectorar",
    "expectoraram": "expectorar",
    "expectoraras": "expectorar",
    "expectorarde": "expectorar",
    "expectorardes": "expectorar",
    "expectorare": "expectorar",
    "expectorarei": "expectorar",
    "expectorareis": "expectorar",
    "expectorarem": "expectorar",
    "expectoraremos": "expectorar",
    "expectorares": "expectorar",
    "expectoraria": "expectorar",
    "expectorariam": "expectorar",
    "expectorarias": "expectorar",
    "expectorarmo": "expectorar",
    "expectorarmos": "expectorar",
    "expectorará": "expectorar",
    "expectorarás": "expectorar",
    "expectorarão": "expectorar",
    "expectoraríamos": "expectorar",
    "expectoraríeis": "expectorar",
    "expectoras": "expectorar",
    "expectorasse": "expectorar",
    "expectorassem": "expectorar",
    "expectorasses": "expectorar",
    "expectoraste": "expectorar",
    "expectorastes": "expectorar",
    "expectorava": "expectorar",
    "expectoravam": "expectorar",
    "expectoravas": "expectorar",
    "expectorações": "expectoração",
    "expectore": "expectorar",
    "expectorei": "expectorar",
    "expectoreis": "expectorar",
    "expectorem": "expectorar",
    "expectoremo": "expectorar",
    "expectoremos": "expectorar",
    "expectores": "expectorar",
    "expectoro": "expectorar",
    "expectorou": "expectorar",
    "expectorá": "expectorar",
    "expectorámo": "expectorar",
    "expectorámos": "expectorar",
    "expectoráramo": "expectorar",
    "expectoráramos": "expectorar",
    "expectorárei": "expectorar",
    "expectoráreis": "expectorar",
    "expectorásseis": "expectorar",
    "expectorássemos": "expectorar",
    "expectorávamo": "expectorar",
    "expectorávamos": "expectorar",
    "expectorávei": "expectorar",
    "expectoráveis": "expectorar",
    "expectou": "expectar",
    "expectá": "expectar",
    "expectámo": "expectar",
    "expectámos": "expectar",
    "expectáramo": "expectar",
    "expectáramos": "expectar",
    "expectárei": "expectar",
    "expectáreis": "expectar",
    "expectásseis": "expectar",
    "expectássemos": "expectar",
    "expectávamo": "expectar",
    "expectávamos": "expectar",
    "expectávei": "expectar",
    "expectáveis": "expectável",
    "expede": "expedir",
    "expedem": "expedir",
    "expedes": "expedir",
    "expedi": "expedir",
    "expedia": "expedir",
    "expediam": "expedir",
    "expedias": "expedir",
    "expedicionária": "expedicionário",
    "expedicionárias": "expedicionário",
    "expedicionários": "expedicionário",
    "expedida": "expedir",
    "expedidas": "expedir",
    "expedido": "expedir",
    "expedidora": "expedidor",
    "expedidoras": "expedidor",
    "expedidores": "expedidor",
    "expedidos": "expedir",
    "expedientes": "expediente",
    "expedimentos": "expedimento",
    "expedimo": "expedir",
    "expedimos": "expedir",
    "expedindo": "expedir",
    "expedira": "expedir",
    "expediram": "expedir",
    "expediras": "expedir",
    "expedirde": "expedir",
    "expedirdes": "expedir",
    "expedire": "expedir",
    "expedirei": "expedir",
    "expedireis": "expedir",
    "expedirem": "expedir",
    "expediremos": "expedir",
    "expedires": "expedir",
    "expediria": "expedir",
    "expediriam": "expedir",
    "expedirias": "expedir",
    "expedirmo": "expedir",
    "expedirmos": "expedir",
    "expedirá": "expedir",
    "expedirás": "expedir",
    "expedirão": "expedir",
    "expediríamos": "expedir",
    "expediríeis": "expedir",
    "expedis": "expedir",
    "expedisse": "expedir",
    "expedissem": "expedir",
    "expedisses": "expedir",
    "expediste": "expedir",
    "expedistes": "expedir",
    "expedita": "expedito",
    "expeditas": "expedito",
    "expeditiva": "expeditivo",
    "expeditivas": "expeditivo",
    "expeditivos": "expeditivo",
    "expeditos": "expedito",
    "expeditória": "expeditório",
    "expeditórias": "expeditório",
    "expeditórios": "expeditório",
    "expediu": "expedir",
    "expedições": "expedição",
    "expediências": "expediência",
    "expedíamo": "expedir",
    "expedíamos": "expedir",
    "expedíei": "expedir",
    "expedíeis": "expedir",
    "expedíramo": "expedir",
    "expedíramos": "expedir",
    "expedírei": "expedir",
    "expedíreis": "expedir",
    "expedísseis": "expedir",
    "expedíssemos": "expedir",
    "expele": "expelir",
    "expelem": "expelir",
    "expelentes": "expelente",
    "expeles": "expelir",
    "expeli": "expelir",
    "expelia": "expelir",
    "expeliam": "expelir",
    "expelias": "expelir",
    "expelida": "expelir",
    "expelidas": "expelir",
    "expelido": "expelir",
    "expelidos": "expelir",
    "expelimo": "expelir",
    "expelimos": "expelir",
    "expelindo": "expelir",
    "expelira": "expelir",
    "expeliram": "expelir",
    "expeliras": "expelir",
    "expelirde": "expelir",
    "expelirdes": "expelir",
    "expelire": "expelir",
    "expelirei": "expelir",
    "expelireis": "expelir",
    "expelirem": "expelir",
    "expeliremos": "expelir",
    "expelires": "expelir",
    "expeliria": "expelir",
    "expeliriam": "expelir",
    "expelirias": "expelir",
    "expelirmo": "expelir",
    "expelirmos": "expelir",
    "expelirá": "expelir",
    "expelirás": "expelir",
    "expelirão": "expelir",
    "expeliríamos": "expelir",
    "expeliríeis": "expelir",
    "expelis": "expelir",
    "expelisse": "expelir",
    "expelissem": "expelir",
    "expelisses": "expelir",
    "expeliste": "expelir",
    "expelistes": "expelir",
    "expeliu": "expelir",
    "expelíamo": "expelir",
    "expelíamos": "expelir",
    "expelíei": "expelir",
    "expelíeis": "expelir",
    "expelíramo": "expelir",
    "expelíramos": "expelir",
    "expelírei": "expelir",
    "expelíreis": "expelir",
    "expelísseis": "expelir",
    "expelíssemos": "expelir",
    "expelíveis": "expelível",
    "expenda": "expender",
    "expendais": "expender",
    "expendam": "expender",
    "expendamo": "expender",
    "expendamos": "expender",
    "expendas": "expender",
    "expende": "expender",
    "expendei": "expender",
    "expendeis": "expender",
    "expendem": "expender",
    "expendemo": "expender",
    "expendemos": "expender",
    "expendendo": "expender",
    "expendera": "expender",
    "expenderam": "expender",
    "expenderas": "expender",
    "expenderde": "expender",
    "expenderdes": "expender",
    "expendere": "expender",
    "expenderei": "expender",
    "expendereis": "expender",
    "expenderem": "expender",
    "expenderemos": "expender",
    "expenderes": "expender",
    "expenderia": "expender",
    "expenderiam": "expender",
    "expenderias": "expender",
    "expendermo": "expender",
    "expendermos": "expender",
    "expenderá": "expender",
    "expenderás": "expender",
    "expenderão": "expender",
    "expenderíamos": "expender",
    "expenderíeis": "expender",
    "expendes": "expender",
    "expendesse": "expender",
    "expendessem": "expender",
    "expendesses": "expender",
    "expendeste": "expender",
    "expendestes": "expender",
    "expendeu": "expender",
    "expendi": "expender",
    "expendia": "expender",
    "expendiam": "expender",
    "expendias": "expender",
    "expendida": "expendido",
    "expendidas": "expendido",
    "expendido": "expender",
    "expendidos": "expendido",
    "expendo": "expender",
    "expendê": "expender",
    "expendêramo": "expender",
    "expendêramos": "expender",
    "expendêrei": "expender",
    "expendêreis": "expender",
    "expendêsseis": "expender",
    "expendêssemos": "expender",
    "expendíamo": "expender",
    "expendíamos": "expender",
    "expendíei": "expender",
    "expendíeis": "expender",
    "expensíveis": "expensível",
    "expensões": "expensão",
    "experienciais": "experiencial",
    "experientes": "experiente",
    "experimenta": "experimentar",
    "experimentada": "experimentar",
    "experimentadas": "experimentar",
    "experimentado": "experimentar",
    "experimentadora": "experimentador",
    "experimentadoras": "experimentador",
    "experimentadores": "experimentador",
    "experimentados": "experimentar",
    "experimentadíssima": "experimentado",
    "experimentadíssimas": "experimentado",
    "experimentadíssimo": "experimentado",
    "experimentadíssimos": "experimentado",
    "experimentai": "experimentar",
    "experimentais": "experimentar",
    "experimentalismos": "experimentalismo",
    "experimentalistas": "experimentalista",
    "experimentam": "experimentar",
    "experimentamo": "experimentar",
    "experimentamos": "experimentar",
    "experimentando": "experimentar",
    "experimentara": "experimentar",
    "experimentaram": "experimentar",
    "experimentaras": "experimentar",
    "experimentarde": "experimentar",
    "experimentardes": "experimentar",
    "experimentare": "experimentar",
    "experimentarei": "experimentar",
    "experimentareis": "experimentar",
    "experimentarem": "experimentar",
    "experimentaremos": "experimentar",
    "experimentares": "experimentar",
    "experimentaria": "experimentar",
    "experimentariam": "experimentar",
    "experimentarias": "experimentar",
    "experimentarmo": "experimentar",
    "experimentarmos": "experimentar",
    "experimentará": "experimentar",
    "experimentarás": "experimentar",
    "experimentarão": "experimentar",
    "experimentaríamos": "experimentar",
    "experimentaríeis": "experimentar",
    "experimentas": "experimentar",
    "experimentasse": "experimentar",
    "experimentassem": "experimentar",
    "experimentasses": "experimentar",
    "experimentaste": "experimentar",
    "experimentastes": "experimentar",
    "experimentava": "experimentar",
    "experimentavam": "experimentar",
    "experimentavas": "experimentar",
    "experimentações": "experimentação",
    "experimente": "experimentar",
    "experimentei": "experimentar",
    "experimenteis": "experimentar",
    "experimentem": "experimentar",
    "experimentemo": "experimentar",
    "experimentemos": "experimentar",
    "experimentes": "experimentar",
    "experimento": "experimentar",
    "experimentos": "experimento",
    "experimentou": "experimentar",
    "experimentá": "experimentar",
    "experimentámo": "experimentar",
    "experimentámos": "experimentar",
    "experimentáramo": "experimentar",
    "experimentáramos": "experimentar",
    "experimentárei": "experimentar",
    "experimentáreis": "experimentar",
    "experimentásseis": "experimentar",
    "experimentássemos": "experimentar",
    "experimentávamo": "experimentar",
    "experimentávamos": "experimentar",
    "experimentávei": "experimentar",
    "experimentáveis": "experimentável",
    "experiências": "experiência",
    "experta": "experto",
    "expertas": "experto",
    "expertos": "experto",
    "experts": "expert",
    "expeça": "expedir",
    "expeçais": "expedir",
    "expeçam": "expedir",
    "expeçamo": "expedir",
    "expeçamos": "expedir",
    "expeças": "expedir",
    "expeço": "expedir",
    "expia": "expiar",
    "expiada": "expiar",
    "expiadas": "expiar",
    "expiado": "expiar",
    "expiadora": "expiador",
    "expiadoras": "expiador",
    "expiadores": "expiador",
    "expiados": "expiar",
    "expiai": "expiar",
    "expiais": "expiar",
    "expiam": "expiar",
    "expiamo": "expiar",
    "expiamos": "expiar",
    "expiando": "expiar",
    "expiara": "expiar",
    "expiaram": "expiar",
    "expiaras": "expiar",
    "expiarde": "expiar",
    "expiardes": "expiar",
    "expiare": "expiar",
    "expiarei": "expiar",
    "expiareis": "expiar",
    "expiarem": "expiar",
    "expiaremos": "expiar",
    "expiares": "expiar",
    "expiaria": "expiar",
    "expiariam": "expiar",
    "expiarias": "expiar",
    "expiarmo": "expiar",
    "expiarmos": "expiar",
    "expiará": "expiar",
    "expiarás": "expiar",
    "expiarão": "expiar",
    "expiaríamos": "expiar",
    "expiaríeis": "expiar",
    "expias": "expiar",
    "expiasse": "expiar",
    "expiassem": "expiar",
    "expiasses": "expiar",
    "expiaste": "expiar",
    "expiastes": "expiar",
    "expiatória": "expiatório",
    "expiatórias": "expiatório",
    "expiatórios": "expiatório",
    "expiava": "expiar",
    "expiavam": "expiar",
    "expiavas": "expiar",
    "expiações": "expiação",
    "expie": "expiar",
    "expiei": "expiar",
    "expieis": "expiar",
    "expiem": "expiar",
    "expiemo": "expiar",
    "expiemos": "expiar",
    "expies": "expiar",
    "expila": "expilar",
    "expilada": "expilar",
    "expiladas": "expilar",
    "expilado": "expilar",
    "expilados": "expilar",
    "expilai": "expilar",
    "expilais": "expilar",
    "expilam": "expilar",
    "expilamo": "expilar",
    "expilamos": "expilar",
    "expilando": "expilar",
    "expilara": "expilar",
    "expilaram": "expilar",
    "expilaras": "expilar",
    "expilarde": "expilar",
    "expilardes": "expilar",
    "expilare": "expilar",
    "expilarei": "expilar",
    "expilareis": "expilar",
    "expilarem": "expilar",
    "expilaremos": "expilar",
    "expilares": "expilar",
    "expilaria": "expilar",
    "expilariam": "expilar",
    "expilarias": "expilar",
    "expilarmo": "expilar",
    "expilarmos": "expilar",
    "expilará": "expilar",
    "expilarás": "expilar",
    "expilarão": "expilar",
    "expilaríamos": "expilar",
    "expilaríeis": "expilar",
    "expilas": "expilar",
    "expilasse": "expilar",
    "expilassem": "expilar",
    "expilasses": "expilar",
    "expilaste": "expilar",
    "expilastes": "expilar",
    "expilava": "expilar",
    "expilavam": "expilar",
    "expilavas": "expilar",
    "expilações": "expilação",
    "expile": "expilar",
    "expilei": "expilar",
    "expileis": "expilar",
    "expilem": "expilar",
    "expilemo": "expilar",
    "expilemos": "expilar",
    "expiles": "expilar",
    "expilo": "expilar",
    "expilou": "expilar",
    "expilá": "expilar",
    "expilámo": "expilar",
    "expilámos": "expilar",
    "expiláramo": "expilar",
    "expiláramos": "expilar",
    "expilárei": "expilar",
    "expiláreis": "expilar",
    "expilásseis": "expilar",
    "expilássemos": "expilar",
    "expilávamo": "expilar",
    "expilávamos": "expilar",
    "expilávei": "expilar",
    "expiláveis": "expilar",
    "expio": "expiar",
    "expiou": "expiar",
    "expira": "expirar",
    "expirada": "expirar",
    "expiradas": "expirar",
    "expirado": "expirar",
    "expiradora": "expirador",
    "expiradoras": "expirador",
    "expiradores": "expirador",
    "expirados": "expirar",
    "expirai": "expirar",
    "expirais": "expirar",
    "expiram": "expirar",
    "expiramo": "expirar",
    "expiramos": "expirar",
    "expirando": "expirar",
    "expirantes": "expirante",
    "expirara": "expirar",
    "expiraram": "expirar",
    "expiraras": "expirar",
    "expirarde": "expirar",
    "expirardes": "expirar",
    "expirare": "expirar",
    "expirarei": "expirar",
    "expirareis": "expirar",
    "expirarem": "expirar",
    "expiraremos": "expirar",
    "expirares": "expirar",
    "expiraria": "expirar",
    "expirariam": "expirar",
    "expirarias": "expirar",
    "expirarmo": "expirar",
    "expirarmos": "expirar",
    "expirará": "expirar",
    "expirarás": "expirar",
    "expirarão": "expirar",
    "expiraríamos": "expirar",
    "expiraríeis": "expirar",
    "expiras": "expirar",
    "expirasse": "expirar",
    "expirassem": "expirar",
    "expirasses": "expirar",
    "expiraste": "expirar",
    "expirastes": "expirar",
    "expirava": "expirar",
    "expiravam": "expirar",
    "expiravas": "expirar",
    "expirações": "expiração",
    "expire": "expirar",
    "expirei": "expirar",
    "expireis": "expirar",
    "expirem": "expirar",
    "expiremo": "expirar",
    "expiremos": "expirar",
    "expires": "expirar",
    "expiro": "expirar",
    "expirou": "expirar",
    "expirá": "expirar",
    "expirámo": "expirar",
    "expirámos": "expirar",
    "expiráramo": "expirar",
    "expiráramos": "expirar",
    "expirárei": "expirar",
    "expiráreis": "expirar",
    "expirásseis": "expirar",
    "expirássemos": "expirar",
    "expirávamo": "expirar",
    "expirávamos": "expirar",
    "expirávei": "expirar",
    "expiráveis": "expirar",
    "expiá": "expiar",
    "expiámo": "expiar",
    "expiámos": "expiar",
    "expiáramo": "expiar",
    "expiáramos": "expiar",
    "expiárei": "expiar",
    "expiáreis": "expiar",
    "expiásseis": "expiar",
    "expiássemos": "expiar",
    "expiávamo": "expiar",
    "expiávamos": "expiar",
    "expiávei": "expiar",
    "expiáveis": "expiável",
    "explana": "explanar",
    "explanada": "explanar",
    "explanadas": "explanar",
    "explanado": "explanar",
    "explanadora": "explanador",
    "explanadoras": "explanador",
    "explanadores": "explanador",
    "explanados": "explanar",
    "explanai": "explanar",
    "explanais": "explanar",
    "explanam": "explanar",
    "explanamo": "explanar",
    "explanamos": "explanar",
    "explanando": "explanar",
    "explanara": "explanar",
    "explanaram": "explanar",
    "explanaras": "explanar",
    "explanarde": "explanar",
    "explanardes": "explanar",
    "explanare": "explanar",
    "explanarei": "explanar",
    "explanareis": "explanar",
    "explanarem": "explanar",
    "explanaremos": "explanar",
    "explanares": "explanar",
    "explanaria": "explanar",
    "explanariam": "explanar",
    "explanarias": "explanar",
    "explanarmo": "explanar",
    "explanarmos": "explanar",
    "explanará": "explanar",
    "explanarás": "explanar",
    "explanarão": "explanar",
    "explanaríamos": "explanar",
    "explanaríeis": "explanar",
    "explanas": "explanar",
    "explanasse": "explanar",
    "explanassem": "explanar",
    "explanasses": "explanar",
    "explanaste": "explanar",
    "explanastes": "explanar",
    "explanatória": "explanatório",
    "explanatórias": "explanatório",
    "explanatórios": "explanatório",
    "explanava": "explanar",
    "explanavam": "explanar",
    "explanavas": "explanar",
    "explanações": "explanação",
    "explane": "explanar",
    "explanei": "explanar",
    "explaneis": "explanar",
    "explanem": "explanar",
    "explanemo": "explanar",
    "explanemos": "explanar",
    "explanes": "explanar",
    "explano": "explanar",
    "explanou": "explanar",
    "explaná": "explanar",
    "explanámo": "explanar",
    "explanámos": "explanar",
    "explanáramo": "explanar",
    "explanáramos": "explanar",
    "explanárei": "explanar",
    "explanáreis": "explanar",
    "explanásseis": "explanar",
    "explanássemos": "explanar",
    "explanávamo": "explanar",
    "explanávamos": "explanar",
    "explanávei": "explanar",
    "explanáveis": "explanar",
    "expletiva": "expletivo",
    "expletivas": "expletivo",
    "expletivos": "expletivo",
    "explica": "explicar",
    "explicabilidades": "explicabilidade",
    "explicada": "explicar",
    "explicadas": "explicar",
    "explicado": "explicar",
    "explicadora": "explicador",
    "explicadoras": "explicador",
    "explicadores": "explicador",
    "explicados": "explicar",
    "explicai": "explicar",
    "explicais": "explicar",
    "explicam": "explicar",
    "explicamo": "explicar",
    "explicamos": "explicar",
    "explicanda": "explicando",
    "explicandas": "explicando",
    "explicando": "explicar",
    "explicandos": "explicando",
    "explicara": "explicar",
    "explicaram": "explicar",
    "explicaras": "explicar",
    "explicarde": "explicar",
    "explicardes": "explicar",
    "explicare": "explicar",
    "explicarei": "explicar",
    "explicareis": "explicar",
    "explicarem": "explicar",
    "explicaremos": "explicar",
    "explicares": "explicar",
    "explicaria": "explicar",
    "explicariam": "explicar",
    "explicarias": "explicar",
    "explicarmo": "explicar",
    "explicarmos": "explicar",
    "explicará": "explicar",
    "explicarás": "explicar",
    "explicarão": "explicar",
    "explicaríamos": "explicar",
    "explicaríeis": "explicar",
    "explicas": "explicar",
    "explicasse": "explicar",
    "explicassem": "explicar",
    "explicasses": "explicar",
    "explicaste": "explicar",
    "explicastes": "explicar",
    "explicativa": "explicativo",
    "explicativas": "explicativo",
    "explicativos": "explicativo",
    "explicava": "explicar",
    "explicavam": "explicar",
    "explicavas": "explicar",
    "explicações": "explicação",
    "explicita": "explicitar",
    "explicitada": "explicitar",
    "explicitadas": "explicitar",
    "explicitado": "explicitar",
    "explicitados": "explicitar",
    "explicitai": "explicitar",
    "explicitais": "explicitar",
    "explicitam": "explicitar",
    "explicitamo": "explicitar",
    "explicitamos": "explicitar",
    "explicitando": "explicitar",
    "explicitara": "explicitar",
    "explicitaram": "explicitar",
    "explicitaras": "explicitar",
    "explicitarde": "explicitar",
    "explicitardes": "explicitar",
    "explicitare": "explicitar",
    "explicitarei": "explicitar",
    "explicitareis": "explicitar",
    "explicitarem": "explicitar",
    "explicitaremos": "explicitar",
    "explicitares": "explicitar",
    "explicitaria": "explicitar",
    "explicitariam": "explicitar",
    "explicitarias": "explicitar",
    "explicitarmo": "explicitar",
    "explicitarmos": "explicitar",
    "explicitará": "explicitar",
    "explicitarás": "explicitar",
    "explicitarão": "explicitar",
    "explicitaríamos": "explicitar",
    "explicitaríeis": "explicitar",
    "explicitas": "explicitar",
    "explicitasse": "explicitar",
    "explicitassem": "explicitar",
    "explicitasses": "explicitar",
    "explicitaste": "explicitar",
    "explicitastes": "explicitar",
    "explicitava": "explicitar",
    "explicitavam": "explicitar",
    "explicitavas": "explicitar",
    "explicitações": "explicitação",
    "explicite": "explicitar",
    "explicitei": "explicitar",
    "expliciteis": "explicitar",
    "explicitem": "explicitar",
    "explicitemo": "explicitar",
    "explicitemos": "explicitar",
    "explicites": "explicitar",
    "explicito": "explicitar",
    "explicitou": "explicitar",
    "explicitá": "explicitar",
    "explicitámo": "explicitar",
    "explicitámos": "explicitar",
    "explicitáramo": "explicitar",
    "explicitáramos": "explicitar",
    "explicitárei": "explicitar",
    "explicitáreis": "explicitar",
    "explicitásseis": "explicitar",
    "explicitássemos": "explicitar",
    "explicitávamo": "explicitar",
    "explicitávamos": "explicitar",
    "explicitávei": "explicitar",
    "explicitáveis": "explicitável",
    "explico": "explicar",
    "explicou": "explicar",
    "explicá": "explicar",
    "explicámo": "explicar",
    "explicámos": "explicar",
    "explicáramo": "explicar",
    "explicáramos": "explicar",
    "explicárei": "explicar",
    "explicáreis": "explicar",
    "explicásseis": "explicar",
    "explicássemos": "explicar",
    "explicávamo": "explicar",
    "explicávamos": "explicar",
    "explicávei": "explicar",
    "explicáveis": "explicável",
    "explique": "explicar",
    "expliquei": "explicar",
    "expliqueis": "explicar",
    "expliquem": "explicar",
    "expliquemo": "explicar",
    "expliquemos": "explicar",
    "expliques": "explicar",
    "explode": "explodir",
    "explodem": "explodir",
    "explodes": "explodir",
    "explodi": "explodir",
    "explodia": "explodir",
    "explodiam": "explodir",
    "explodias": "explodir",
    "explodida": "explodir",
    "explodidas": "explodir",
    "explodido": "explodir",
    "explodidos": "explodir",
    "explodimo": "explodir",
    "explodimos": "explodir",
    "explodindo": "explodir",
    "explodira": "explodir",
    "explodiram": "explodir",
    "explodiras": "explodir",
    "explodirde": "explodir",
    "explodirdes": "explodir",
    "explodire": "explodir",
    "explodirei": "explodir",
    "explodireis": "explodir",
    "explodirem": "explodir",
    "explodiremos": "explodir",
    "explodires": "explodir",
    "explodiria": "explodir",
    "explodiriam": "explodir",
    "explodirias": "explodir",
    "explodirmo": "explodir",
    "explodirmos": "explodir",
    "explodirá": "explodir",
    "explodirás": "explodir",
    "explodirão": "explodir",
    "explodiríamos": "explodir",
    "explodiríeis": "explodir",
    "explodis": "explodir",
    "explodisse": "explodir",
    "explodissem": "explodir",
    "explodisses": "explodir",
    "explodiste": "explodir",
    "explodistes": "explodir",
    "explodiu": "explodir",
    "explodíamo": "explodir",
    "explodíamos": "explodir",
    "explodíei": "explodir",
    "explodíeis": "explodir",
    "explodíramo": "explodir",
    "explodíramos": "explodir",
    "explodírei": "explodir",
    "explodíreis": "explodir",
    "explodísseis": "explodir",
    "explodíssemos": "explodir",
    "explora": "explorar",
    "explorabilidades": "explorabilidade",
    "explorada": "explorar",
    "exploradas": "explorar",
    "explorado": "explorar",
    "exploradora": "explorador",
    "exploradoras": "explorador",
    "exploradores": "explorador",
    "explorados": "explorar",
    "explorai": "explorar",
    "explorais": "explorar",
    "exploram": "explorar",
    "exploramo": "explorar",
    "exploramos": "explorar",
    "explorando": "explorar",
    "explorara": "explorar",
    "exploraram": "explorar",
    "exploraras": "explorar",
    "explorarde": "explorar",
    "explorardes": "explorar",
    "explorare": "explorar",
    "explorarei": "explorar",
    "explorareis": "explorar",
    "explorarem": "explorar",
    "exploraremos": "explorar",
    "explorares": "explorar",
    "exploraria": "explorar",
    "explorariam": "explorar",
    "explorarias": "explorar",
    "explorarmo": "explorar",
    "explorarmos": "explorar",
    "explorará": "explorar",
    "explorarás": "explorar",
    "explorarão": "explorar",
    "exploraríamos": "explorar",
    "exploraríeis": "explorar",
    "exploras": "explorar",
    "explorasse": "explorar",
    "explorassem": "explorar",
    "explorasses": "explorar",
    "exploraste": "explorar",
    "explorastes": "explorar",
    "exploratória": "exploratório",
    "exploratórias": "exploratório",
    "exploratórios": "exploratório",
    "explorava": "explorar",
    "exploravam": "explorar",
    "exploravas": "explorar",
    "explorações": "exploração",
    "explore": "explorar",
    "explorei": "explorar",
    "exploreis": "explorar",
    "explorem": "explorar",
    "exploremo": "explorar",
    "exploremos": "explorar",
    "explores": "explorar",
    "exploro": "explorar",
    "explorou": "explorar",
    "explorá": "explorar",
    "explorámo": "explorar",
    "explorámos": "explorar",
    "exploráramo": "explorar",
    "exploráramos": "explorar",
    "explorárei": "explorar",
    "exploráreis": "explorar",
    "explorásseis": "explorar",
    "explorássemos": "explorar",
    "explorávamo": "explorar",
    "explorávamos": "explorar",
    "explorávei": "explorar",
    "exploráveis": "explorável",
    "explosiva": "explosivo",
    "explosivas": "explosivo",
    "explosivos": "explosivo",
    "explosímetros": "explosímetro",
    "explosíveis": "explosível",
    "explosões": "explosão",
    "explua": "expluir",
    "expluais": "expluir",
    "expluam": "expluir",
    "expluamo": "expluir",
    "expluamos": "expluir",
    "expluas": "expluir",
    "expluda": "explodir",
    "expludais": "explodir",
    "expludam": "explodir",
    "expludamo": "explodir",
    "expludamos": "explodir",
    "expludas": "explodir",
    "expludo": "explodir",
    "expluem": "expluir",
    "explui": "expluir",
    "expluindo": "expluir",
    "expluirde": "expluir",
    "expluirdes": "expluir",
    "expluirei": "expluir",
    "expluireis": "expluir",
    "expluiremos": "expluir",
    "expluiria": "expluir",
    "expluiriam": "expluir",
    "expluirias": "expluir",
    "expluirmo": "expluir",
    "expluirmos": "expluir",
    "expluirá": "expluir",
    "expluirás": "expluir",
    "expluirão": "expluir",
    "expluiríamos": "expluir",
    "expluiríeis": "expluir",
    "expluis": "expluir",
    "expluiu": "expluir",
    "expluo": "expluir",
    "expluí": "expluir",
    "expluía": "expluir",
    "expluíam": "expluir",
    "expluíamo": "expluir",
    "expluíamos": "expluir",
    "expluías": "expluir",
    "expluída": "expluir",
    "expluídas": "expluir",
    "expluído": "expluir",
    "expluídos": "expluir",
    "expluíei": "expluir",
    "expluíeis": "expluir",
    "expluímo": "expluir",
    "expluímos": "expluir",
    "expluíra": "expluir",
    "expluíram": "expluir",
    "expluíramo": "expluir",
    "expluíramos": "expluir",
    "expluíras": "expluir",
    "expluíre": "expluir",
    "expluírei": "expluir",
    "expluíreis": "expluir",
    "expluírem": "expluir",
    "expluíres": "expluir",
    "expluís": "expluir",
    "expluísse": "expluir",
    "expluísseis": "expluir",
    "expluíssem": "expluir",
    "expluíssemos": "expluir",
    "expluísses": "expluir",
    "expluíste": "expluir",
    "expluístes": "expluir",
    "explícita": "explícito",
    "explícitas": "explícito",
    "explícitos": "explícito",
    "expoentes": "expoente",
    "expoli": "expolir",
    "expolia": "expolir",
    "expoliam": "expolir",
    "expolias": "expolir",
    "expolida": "expolir",
    "expolidas": "expolir",
    "expolido": "expolir",
    "expolidos": "expolir",
    "expolimo": "expolir",
    "expolimos": "expolir",
    "expolindo": "expolir",
    "expolira": "expolir",
    "expoliram": "expolir",
    "expoliras": "expolir",
    "expolirde": "expolir",
    "expolirdes": "expolir",
    "expolire": "expolir",
    "expolirei": "expolir",
    "expolireis": "expolir",
    "expolirem": "expolir",
    "expoliremos": "expolir",
    "expolires": "expolir",
    "expoliria": "expolir",
    "expoliriam": "expolir",
    "expolirias": "expolir",
    "expolirmo": "expolir",
    "expolirmos": "expolir",
    "expolirá": "expolir",
    "expolirás": "expolir",
    "expolirão": "expolir",
    "expoliríamos": "expolir",
    "expoliríeis": "expolir",
    "expolis": "expolir",
    "expolisse": "expolir",
    "expolissem": "expolir",
    "expolisses": "expolir",
    "expoliste": "expolir",
    "expolistes": "expolir",
    "expoliu": "expolir",
    "expolições": "expolição",
    "expolíamo": "expolir",
    "expolíamos": "expolir",
    "expolíei": "expolir",
    "expolíeis": "expolir",
    "expolíramo": "expolir",
    "expolíramos": "expolir",
    "expolírei": "expolir",
    "expolíreis": "expolir",
    "expolísseis": "expolir",
    "expolíssemos": "expolir",
    "expomo": "expor",
    "expomos": "expor",
    "exponde": "expor",
    "expondes": "expor",
    "expondo": "expor",
    "exponenciais": "exponencial",
    "exponentes": "exponente",
    "exponha": "expor",
    "exponhais": "expor",
    "exponham": "expor",
    "exponhamo": "expor",
    "exponhamos": "expor",
    "exponhas": "expor",
    "exponho": "expor",
    "exporde": "expor",
    "expordes": "expor",
    "expore": "expor",
    "exporei": "expor",
    "exporeis": "expor",
    "exporem": "expor",
    "exporemos": "expor",
    "expores": "expor",
    "exporia": "expor",
    "exporiam": "expor",
    "exporias": "expor",
    "expormo": "expor",
    "expormos": "expor",
    "exporta": "exportar",
    "exportada": "exportar",
    "exportadas": "exportar",
    "exportado": "exportar",
    "exportadora": "exportador",
    "exportadoras": "exportador",
    "exportadores": "exportador",
    "exportados": "exportar",
    "exportai": "exportar",
    "exportais": "exportar",
    "exportam": "exportar",
    "exportamo": "exportar",
    "exportamos": "exportar",
    "exportando": "exportar",
    "exportara": "exportar",
    "exportaram": "exportar",
    "exportaras": "exportar",
    "exportarde": "exportar",
    "exportardes": "exportar",
    "exportare": "exportar",
    "exportarei": "exportar",
    "exportareis": "exportar",
    "exportarem": "exportar",
    "exportaremos": "exportar",
    "exportares": "exportar",
    "exportaria": "exportar",
    "exportariam": "exportar",
    "exportarias": "exportar",
    "exportarmo": "exportar",
    "exportarmos": "exportar",
    "exportará": "exportar",
    "exportarás": "exportar",
    "exportarão": "exportar",
    "exportaríamos": "exportar",
    "exportaríeis": "exportar",
    "exportas": "exportar",
    "exportasse": "exportar",
    "exportassem": "exportar",
    "exportasses": "exportar",
    "exportaste": "exportar",
    "exportastes": "exportar",
    "exportava": "exportar",
    "exportavam": "exportar",
    "exportavas": "exportar",
    "exportações": "exportação",
    "exporte": "exportar",
    "exportei": "exportar",
    "exporteis": "exportar",
    "exportem": "exportar",
    "exportemo": "exportar",
    "exportemos": "exportar",
    "exportes": "exportar",
    "exporto": "exportar",
    "exportou": "exportar",
    "exportá": "exportar",
    "exportámo": "exportar",
    "exportámos": "exportar",
    "exportáramo": "exportar",
    "exportáramos": "exportar",
    "exportárei": "exportar",
    "exportáreis": "exportar",
    "exportásseis": "exportar",
    "exportássemos": "exportar",
    "exportávamo": "exportar",
    "exportávamos": "exportar",
    "exportávei": "exportar",
    "exportáveis": "exportável",
    "exporá": "expor",
    "exporás": "expor",
    "exporão": "expor",
    "exporíamos": "expor",
    "exporíeis": "expor",
    "expos": "expo",
    "expositiva": "expositivo",
    "expositivas": "expositivo",
    "expositivos": "expositivo",
    "expositora": "expositor",
    "expositoras": "expositor",
    "expositores": "expositor",
    "exposições": "exposição",
    "exposta": "exposto",
    "expostas": "exposto",
    "exposto": "expor",
    "expostos": "exposto",
    "expostula": "expostular",
    "expostulada": "expostular",
    "expostuladas": "expostular",
    "expostulado": "expostular",
    "expostulados": "expostular",
    "expostulai": "expostular",
    "expostulais": "expostular",
    "expostulam": "expostular",
    "expostulamo": "expostular",
    "expostulamos": "expostular",
    "expostulando": "expostular",
    "expostulara": "expostular",
    "expostularam": "expostular",
    "expostularas": "expostular",
    "expostulardes": "expostular",
    "expostularei": "expostular",
    "expostulareis": "expostular",
    "expostularem": "expostular",
    "expostularemos": "expostular",
    "expostulares": "expostular",
    "expostularia": "expostular",
    "expostulariam": "expostular",
    "expostularias": "expostular",
    "expostularmo": "expostular",
    "expostularmos": "expostular",
    "expostulará": "expostular",
    "expostularás": "expostular",
    "expostularão": "expostular",
    "expostularíamos": "expostular",
    "expostularíeis": "expostular",
    "expostulas": "expostular",
    "expostulasse": "expostular",
    "expostulassem": "expostular",
    "expostulasses": "expostular",
    "expostulaste": "expostular",
    "expostulastes": "expostular",
    "expostulava": "expostular",
    "expostulavam": "expostular",
    "expostulavas": "expostular",
    "expostulações": "expostulação",
    "expostule": "expostular",
    "expostulei": "expostular",
    "expostuleis": "expostular",
    "expostulem": "expostular",
    "expostulemo": "expostular",
    "expostulemos": "expostular",
    "expostules": "expostular",
    "expostulo": "expostular",
    "expostulou": "expostular",
    "expostulámo": "expostular",
    "expostulámos": "expostular",
    "expostuláramo": "expostular",
    "expostuláramos": "expostular",
    "expostuláreis": "expostular",
    "expostulásseis": "expostular",
    "expostulássemos": "expostular",
    "expostulávamo": "expostular",
    "expostulávamos": "expostular",
    "expostuláveis": "expostular",
    "expressa": "expresso",
    "expressada": "expressar",
    "expressadas": "expressar",
    "expressado": "expressar",
    "expressadora": "expressador",
    "expressadoras": "expressador",
    "expressadores": "expressador",
    "expressados": "expressar",
    "expressai": "expressar",
    "expressais": "expressar",
    "expressam": "expressar",
    "expressamo": "expressar",
    "expressamos": "expressar",
    "expressando": "expressar",
    "expressara": "expressar",
    "expressaram": "expressar",
    "expressaras": "expressar",
    "expressarde": "expressar",
    "expressardes": "expressar",
    "expressare": "expressar",
    "expressarei": "expressar",
    "expressareis": "expressar",
    "expressarem": "expressar",
    "expressaremos": "expressar",
    "expressares": "expressar",
    "expressaria": "expressar",
    "expressariam": "expressar",
    "expressarias": "expressar",
    "expressarmo": "expressar",
    "expressarmos": "expressar",
    "expressará": "expressar",
    "expressarás": "expressar",
    "expressarão": "expressar",
    "expressaríamos": "expressar",
    "expressaríeis": "expressar",
    "expressas": "expresso",
    "expressasse": "expressar",
    "expressassem": "expressar",
    "expressasses": "expressar",
    "expressaste": "expressar",
    "expressastes": "expressar",
    "expressava": "expressar",
    "expressavam": "expressar",
    "expressavas": "expressar",
    "expresse": "expressar",
    "expressei": "expressar",
    "expresseis": "expressar",
    "expressem": "expressar",
    "expressemo": "expressar",
    "expressemos": "expressar",
    "expresses": "expressar",
    "expressionismos": "expressionismo",
    "expressionistas": "expressionista",
    "expressiva": "expressivo",
    "expressivas": "expressivo",
    "expressividades": "expressividade",
    "expressivos": "expressivo",
    "expresso": "expressar",
    "expressos": "expresso",
    "expressou": "expressar",
    "expressá": "expressar",
    "expressámo": "expressar",
    "expressámos": "expressar",
    "expressáramo": "expressar",
    "expressáramos": "expressar",
    "expressárei": "expressar",
    "expressáreis": "expressar",
    "expressásseis": "expressar",
    "expressássemos": "expressar",
    "expressávamo": "expressar",
    "expressávamos": "expressar",
    "expressávei": "expressar",
    "expressáveis": "expressável",
    "expressões": "expressão",
    "exprima": "exprimir",
    "exprimais": "exprimir",
    "exprimam": "exprimir",
    "exprimamo": "exprimir",
    "exprimamos": "exprimir",
    "exprimas": "exprimir",
    "exprime": "exprimir",
    "exprimem": "exprimir",
    "exprimes": "exprimir",
    "exprimi": "exprimir",
    "exprimia": "exprimir",
    "exprimiam": "exprimir",
    "exprimias": "exprimir",
    "exprimida": "exprimir",
    "exprimidas": "exprimir",
    "exprimido": "exprimir",
    "exprimidos": "exprimir",
    "exprimimo": "exprimir",
    "exprimimos": "exprimir",
    "exprimindo": "exprimir",
    "exprimira": "exprimir",
    "exprimiram": "exprimir",
    "exprimiras": "exprimir",
    "exprimirde": "exprimir",
    "exprimirdes": "exprimir",
    "exprimire": "exprimir",
    "exprimirei": "exprimir",
    "exprimireis": "exprimir",
    "exprimirem": "exprimir",
    "exprimiremos": "exprimir",
    "exprimires": "exprimir",
    "exprimiria": "exprimir",
    "exprimiriam": "exprimir",
    "exprimirias": "exprimir",
    "exprimirmo": "exprimir",
    "exprimirmos": "exprimir",
    "exprimirá": "exprimir",
    "exprimirás": "exprimir",
    "exprimirão": "exprimir",
    "exprimiríamos": "exprimir",
    "exprimiríeis": "exprimir",
    "exprimis": "exprimir",
    "exprimisse": "exprimir",
    "exprimissem": "exprimir",
    "exprimisses": "exprimir",
    "exprimiste": "exprimir",
    "exprimistes": "exprimir",
    "exprimiu": "exprimir",
    "exprimo": "exprimir",
    "exprimíamo": "exprimir",
    "exprimíamos": "exprimir",
    "exprimíei": "exprimir",
    "exprimíeis": "exprimir",
    "exprimíramo": "exprimir",
    "exprimíramos": "exprimir",
    "exprimírei": "exprimir",
    "exprimíreis": "exprimir",
    "exprimísseis": "exprimir",
    "exprimíssemos": "exprimir",
    "exprimíveis": "exprimível",
    "exprobações": "exprobação",
    "exprobra": "exprobrar",
    "exprobrada": "exprobrar",
    "exprobradas": "exprobrar",
    "exprobrado": "exprobrar",
    "exprobradora": "exprobrador",
    "exprobradoras": "exprobrador",
    "exprobradores": "exprobrador",
    "exprobrados": "exprobrar",
    "exprobrai": "exprobrar",
    "exprobrais": "exprobrar",
    "exprobram": "exprobrar",
    "exprobramo": "exprobrar",
    "exprobramos": "exprobrar",
    "exprobrando": "exprobrar",
    "exprobrantes": "exprobrante",
    "exprobrara": "exprobrar",
    "exprobraram": "exprobrar",
    "exprobraras": "exprobrar",
    "exprobrarde": "exprobrar",
    "exprobrardes": "exprobrar",
    "exprobrare": "exprobrar",
    "exprobrarei": "exprobrar",
    "exprobrareis": "exprobrar",
    "exprobrarem": "exprobrar",
    "exprobraremos": "exprobrar",
    "exprobrares": "exprobrar",
    "exprobraria": "exprobrar",
    "exprobrariam": "exprobrar",
    "exprobrarias": "exprobrar",
    "exprobrarmo": "exprobrar",
    "exprobrarmos": "exprobrar",
    "exprobrará": "exprobrar",
    "exprobrarás": "exprobrar",
    "exprobrarão": "exprobrar",
    "exprobraríamos": "exprobrar",
    "exprobraríeis": "exprobrar",
    "exprobras": "exprobrar",
    "exprobrasse": "exprobrar",
    "exprobrassem": "exprobrar",
    "exprobrasses": "exprobrar",
    "exprobraste": "exprobrar",
    "exprobrastes": "exprobrar",
    "exprobrativa": "exprobrativo",
    "exprobrativas": "exprobrativo",
    "exprobrativos": "exprobrativo",
    "exprobratória": "exprobratório",
    "exprobratórias": "exprobratório",
    "exprobratórios": "exprobratório",
    "exprobrava": "exprobrar",
    "exprobravam": "exprobrar",
    "exprobravas": "exprobrar",
    "exprobrações": "exprobração",
    "exprobre": "exprobrar",
    "exprobrei": "exprobrar",
    "exprobreis": "exprobrar",
    "exprobrem": "exprobrar",
    "exprobremo": "exprobrar",
    "exprobremos": "exprobrar",
    "exprobres": "exprobrar",
    "exprobro": "exprobrar",
    "exprobrou": "exprobrar",
    "exprobrá": "exprobrar",
    "exprobrámo": "exprobrar",
    "exprobrámos": "exprobrar",
    "exprobráramo": "exprobrar",
    "exprobráramos": "exprobrar",
    "exprobrárei": "exprobrar",
    "exprobráreis": "exprobrar",
    "exprobrásseis": "exprobrar",
    "exprobrássemos": "exprobrar",
    "exprobrávamo": "exprobrar",
    "exprobrávamos": "exprobrar",
    "exprobrávei": "exprobrar",
    "exprobráveis": "exprobrar",
    "expromissora": "expromissor",
    "expromissoras": "expromissor",
    "expromissores": "expromissor",
    "expromissões": "expromissão",
    "expropria": "expropriar",
    "expropriada": "expropriar",
    "expropriadas": "expropriar",
    "expropriado": "expropriar",
    "expropriadora": "expropriador",
    "expropriadoras": "expropriador",
    "expropriadores": "expropriador",
    "expropriados": "expropriar",
    "expropriai": "expropriar",
    "expropriais": "expropriar",
    "expropriam": "expropriar",
    "expropriamo": "expropriar",
    "expropriamos": "expropriar",
    "expropriando": "expropriar",
    "expropriara": "expropriar",
    "expropriaram": "expropriar",
    "expropriaras": "expropriar",
    "expropriarde": "expropriar",
    "expropriardes": "expropriar",
    "expropriare": "expropriar",
    "expropriarei": "expropriar",
    "expropriareis": "expropriar",
    "expropriarem": "expropriar",
    "expropriaremos": "expropriar",
    "expropriares": "expropriar",
    "expropriaria": "expropriar",
    "expropriariam": "expropriar",
    "expropriarias": "expropriar",
    "expropriarmo": "expropriar",
    "expropriarmos": "expropriar",
    "expropriará": "expropriar",
    "expropriarás": "expropriar",
    "expropriarão": "expropriar",
    "expropriaríamos": "expropriar",
    "expropriaríeis": "expropriar",
    "exproprias": "expropriar",
    "expropriasse": "expropriar",
    "expropriassem": "expropriar",
    "expropriasses": "expropriar",
    "expropriaste": "expropriar",
    "expropriastes": "expropriar",
    "expropriava": "expropriar",
    "expropriavam": "expropriar",
    "expropriavas": "expropriar",
    "expropriações": "expropriação",
    "exproprie": "expropriar",
    "expropriei": "expropriar",
    "exproprieis": "expropriar",
    "expropriem": "expropriar",
    "expropriemo": "expropriar",
    "expropriemos": "expropriar",
    "expropries": "expropriar",
    "exproprio": "expropriar",
    "expropriou": "expropriar",
    "expropriá": "expropriar",
    "expropriámo": "expropriar",
    "expropriámos": "expropriar",
    "expropriáramo": "expropriar",
    "expropriáramos": "expropriar",
    "expropriárei": "expropriar",
    "expropriáreis": "expropriar",
    "expropriásseis": "expropriar",
    "expropriássemos": "expropriar",
    "expropriávamo": "expropriar",
    "expropriávamos": "expropriar",
    "expropriávei": "expropriar",
    "expropriáveis": "expropriável",
    "expugna": "expugnar",
    "expugnada": "expugnar",
    "expugnadas": "expugnar",
    "expugnado": "expugnar",
    "expugnadora": "expugnador",
    "expugnadoras": "expugnador",
    "expugnadores": "expugnador",
    "expugnados": "expugnar",
    "expugnai": "expugnar",
    "expugnais": "expugnar",
    "expugnam": "expugnar",
    "expugnamo": "expugnar",
    "expugnamos": "expugnar",
    "expugnando": "expugnar",
    "expugnara": "expugnar",
    "expugnaram": "expugnar",
    "expugnaras": "expugnar",
    "expugnarde": "expugnar",
    "expugnardes": "expugnar",
    "expugnare": "expugnar",
    "expugnarei": "expugnar",
    "expugnareis": "expugnar",
    "expugnarem": "expugnar",
    "expugnaremos": "expugnar",
    "expugnares": "expugnar",
    "expugnaria": "expugnar",
    "expugnariam": "expugnar",
    "expugnarias": "expugnar",
    "expugnarmo": "expugnar",
    "expugnarmos": "expugnar",
    "expugnará": "expugnar",
    "expugnarás": "expugnar",
    "expugnarão": "expugnar",
    "expugnaríamos": "expugnar",
    "expugnaríeis": "expugnar",
    "expugnas": "expugnar",
    "expugnasse": "expugnar",
    "expugnassem": "expugnar",
    "expugnasses": "expugnar",
    "expugnaste": "expugnar",
    "expugnastes": "expugnar",
    "expugnava": "expugnar",
    "expugnavam": "expugnar",
    "expugnavas": "expugnar",
    "expugnações": "expugnação",
    "expugne": "expugnar",
    "expugnei": "expugnar",
    "expugneis": "expugnar",
    "expugnem": "expugnar",
    "expugnemo": "expugnar",
    "expugnemos": "expugnar",
    "expugnes": "expugnar",
    "expugno": "expugnar",
    "expugnou": "expugnar",
    "expugná": "expugnar",
    "expugnámo": "expugnar",
    "expugnámos": "expugnar",
    "expugnáramo": "expugnar",
    "expugnáramos": "expugnar",
    "expugnárei": "expugnar",
    "expugnáreis": "expugnar",
    "expugnásseis": "expugnar",
    "expugnássemos": "expugnar",
    "expugnávamo": "expugnar",
    "expugnávamos": "expugnar",
    "expugnávei": "expugnar",
    "expugnáveis": "expugnável",
    "expuições": "expuição",
    "expula": "expolir",
    "expulais": "expolir",
    "expulam": "expolir",
    "expulamo": "expolir",
    "expulamos": "expolir",
    "expulas": "expolir",
    "expule": "expolir",
    "expulem": "expolir",
    "expules": "expolir",
    "expulo": "expolir",
    "expulsa": "expulso",
    "expulsada": "expulsar",
    "expulsadas": "expulsar",
    "expulsado": "expulsar",
    "expulsados": "expulsar",
    "expulsai": "expulsar",
    "expulsais": "expulsar",
    "expulsam": "expulsar",
    "expulsamo": "expulsar",
    "expulsamos": "expulsar",
    "expulsando": "expulsar",
    "expulsara": "expulsar",
    "expulsaram": "expulsar",
    "expulsaras": "expulsar",
    "expulsarde": "expulsar",
    "expulsardes": "expulsar",
    "expulsare": "expulsar",
    "expulsarei": "expulsar",
    "expulsareis": "expulsar",
    "expulsarem": "expulsar",
    "expulsaremos": "expulsar",
    "expulsares": "expulsar",
    "expulsaria": "expulsar",
    "expulsariam": "expulsar",
    "expulsarias": "expulsar",
    "expulsarmo": "expulsar",
    "expulsarmos": "expulsar",
    "expulsará": "expulsar",
    "expulsarás": "expulsar",
    "expulsarão": "expulsar",
    "expulsaríamos": "expulsar",
    "expulsaríeis": "expulsar",
    "expulsas": "expulso",
    "expulsasse": "expulsar",
    "expulsassem": "expulsar",
    "expulsasses": "expulsar",
    "expulsaste": "expulsar",
    "expulsastes": "expulsar",
    "expulsava": "expulsar",
    "expulsavam": "expulsar",
    "expulsavas": "expulsar",
    "expulse": "expulsar",
    "expulsei": "expulsar",
    "expulseis": "expulsar",
    "expulsem": "expulsar",
    "expulsemo": "expulsar",
    "expulsemos": "expulsar",
    "expulses": "expulsar",
    "expulsiva": "expulsivo",
    "expulsivas": "expulsivo",
    "expulsivos": "expulsivo",
    "expulso": "expulsar",
    "expulsora": "expulsor",
    "expulsoras": "expulsor",
    "expulsores": "expulsor",
    "expulsos": "expulso",
    "expulsou": "expulsar",
    "expulsá": "expulsar",
    "expulsámo": "expulsar",
    "expulsámos": "expulsar",
    "expulsáramo": "expulsar",
    "expulsáramos": "expulsar",
    "expulsárei": "expulsar",
    "expulsáreis": "expulsar",
    "expulsásseis": "expulsar",
    "expulsássemos": "expulsar",
    "expulsávamo": "expulsar",
    "expulsávamos": "expulsar",
    "expulsávei": "expulsar",
    "expulsáveis": "expulsável",
    "expulsória": "expulsório",
    "expulsórias": "expulsório",
    "expulsórios": "expulsório",
    "expulsões": "expulsão",
    "expunge": "expungir",
    "expungem": "expungir",
    "expunges": "expungir",
    "expungi": "expungir",
    "expungia": "expungir",
    "expungiam": "expungir",
    "expungias": "expungir",
    "expungida": "expungir",
    "expungidas": "expungir",
    "expungido": "expungir",
    "expungidos": "expungir",
    "expungimo": "expungir",
    "expungimos": "expungir",
    "expungindo": "expungir",
    "expungira": "expungir",
    "expungiram": "expungir",
    "expungiras": "expungir",
    "expungirde": "expungir",
    "expungirdes": "expungir",
    "expungire": "expungir",
    "expungirei": "expungir",
    "expungireis": "expungir",
    "expungirem": "expungir",
    "expungiremos": "expungir",
    "expungires": "expungir",
    "expungiria": "expungir",
    "expungiriam": "expungir",
    "expungirias": "expungir",
    "expungirmo": "expungir",
    "expungirmos": "expungir",
    "expungirá": "expungir",
    "expungirás": "expungir",
    "expungirão": "expungir",
    "expungiríamos": "expungir",
    "expungiríeis": "expungir",
    "expungis": "expungir",
    "expungisse": "expungir",
    "expungissem": "expungir",
    "expungisses": "expungir",
    "expungiste": "expungir",
    "expungistes": "expungir",
    "expungiu": "expungir",
    "expungíamo": "expungir",
    "expungíamos": "expungir",
    "expungíei": "expungir",
    "expungíeis": "expungir",
    "expungíramo": "expungir",
    "expungíramos": "expungir",
    "expungírei": "expungir",
    "expungíreis": "expungir",
    "expungísseis": "expungir",
    "expungíssemos": "expungir",
    "expungíveis": "expungível",
    "expunha": "expor",
    "expunham": "expor",
    "expunhas": "expor",
    "expunja": "expungir",
    "expunjais": "expungir",
    "expunjam": "expungir",
    "expunjamo": "expungir",
    "expunjamos": "expungir",
    "expunjas": "expungir",
    "expunjo": "expungir",
    "expunções": "expunção",
    "expurga": "expurgar",
    "expurgada": "expurgar",
    "expurgadas": "expurgar",
    "expurgado": "expurgar",
    "expurgadora": "expurgador",
    "expurgadoras": "expurgador",
    "expurgadores": "expurgador",
    "expurgados": "expurgar",
    "expurgai": "expurgar",
    "expurgais": "expurgar",
    "expurgam": "expurgar",
    "expurgamo": "expurgar",
    "expurgamos": "expurgar",
    "expurgando": "expurgar",
    "expurgara": "expurgar",
    "expurgaram": "expurgar",
    "expurgaras": "expurgar",
    "expurgarde": "expurgar",
    "expurgardes": "expurgar",
    "expurgare": "expurgar",
    "expurgarei": "expurgar",
    "expurgareis": "expurgar",
    "expurgarem": "expurgar",
    "expurgaremos": "expurgar",
    "expurgares": "expurgar",
    "expurgaria": "expurgar",
    "expurgariam": "expurgar",
    "expurgarias": "expurgar",
    "expurgarmo": "expurgar",
    "expurgarmos": "expurgar",
    "expurgará": "expurgar",
    "expurgarás": "expurgar",
    "expurgarão": "expurgar",
    "expurgaríamos": "expurgar",
    "expurgaríeis": "expurgar",
    "expurgas": "expurgar",
    "expurgasse": "expurgar",
    "expurgassem": "expurgar",
    "expurgasses": "expurgar",
    "expurgaste": "expurgar",
    "expurgastes": "expurgar",
    "expurgatória": "expurgatório",
    "expurgatórias": "expurgatório",
    "expurgatórios": "expurgatório",
    "expurgava": "expurgar",
    "expurgavam": "expurgar",
    "expurgavas": "expurgar",
    "expurgações": "expurgação",
    "expurgo": "expurgar",
    "expurgos": "expurgo",
    "expurgou": "expurgar",
    "expurgue": "expurgar",
    "expurguei": "expurgar",
    "expurgueis": "expurgar",
    "expurguem": "expurgar",
    "expurguemo": "expurgar",
    "expurguemos": "expurgar",
    "expurgues": "expurgar",
    "expurgá": "expurgar",
    "expurgámo": "expurgar",
    "expurgámos": "expurgar",
    "expurgáramo": "expurgar",
    "expurgáramos": "expurgar",
    "expurgárei": "expurgar",
    "expurgáreis": "expurgar",
    "expurgásseis": "expurgar",
    "expurgássemos": "expurgar",
    "expurgávamo": "expurgar",
    "expurgávamos": "expurgar",
    "expurgávei": "expurgar",
    "expurgáveis": "expurgar",
    "expus": "expor",
    "expusemo": "expor",
    "expusemos": "expor",
    "expuser": "expor",
    "expusera": "expor",
    "expuseram": "expor",
    "expuseras": "expor",
    "expuserdes": "expor",
    "expuserem": "expor",
    "expuseres": "expor",
    "expusermos": "expor",
    "expusesse": "expor",
    "expusessem": "expor",
    "expusesses": "expor",
    "expuseste": "expor",
    "expusestes": "expor",
    "expuséramo": "expor",
    "expuséramos": "expor",
    "expusérei": "expor",
    "expuséreis": "expor",
    "expusésseis": "expor",
    "expuséssemos": "expor",
    "expuída": "expuído",
    "expuídas": "expuído",
    "expuídos": "expuído",
    "expô": "expor",
    "expôs": "expor",
    "expõe": "expor",
    "expõem": "expor",
    "expões": "expor",
    "expúnhamo": "expor",
    "expúnhamos": "expor",
    "expúnhei": "expor",
    "expúnheis": "expor",
    "exsica": "exsicar",
    "exsicada": "exsicar",
    "exsicadas": "exsicar",
    "exsicado": "exsicar",
    "exsicadores": "exsicador",
    "exsicados": "exsicar",
    "exsicai": "exsicar",
    "exsicais": "exsicar",
    "exsicam": "exsicar",
    "exsicamo": "exsicar",
    "exsicamos": "exsicar",
    "exsicando": "exsicar",
    "exsicantes": "exsicante",
    "exsicara": "exsicar",
    "exsicaram": "exsicar",
    "exsicaras": "exsicar",
    "exsicarde": "exsicar",
    "exsicardes": "exsicar",
    "exsicare": "exsicar",
    "exsicarei": "exsicar",
    "exsicareis": "exsicar",
    "exsicarem": "exsicar",
    "exsicaremos": "exsicar",
    "exsicares": "exsicar",
    "exsicaria": "exsicar",
    "exsicariam": "exsicar",
    "exsicarias": "exsicar",
    "exsicarmo": "exsicar",
    "exsicarmos": "exsicar",
    "exsicará": "exsicar",
    "exsicarás": "exsicar",
    "exsicarão": "exsicar",
    "exsicaríamos": "exsicar",
    "exsicaríeis": "exsicar",
    "exsicas": "exsicar",
    "exsicasse": "exsicar",
    "exsicassem": "exsicar",
    "exsicasses": "exsicar",
    "exsicaste": "exsicar",
    "exsicastes": "exsicar",
    "exsicativa": "exsicativo",
    "exsicativas": "exsicativo",
    "exsicativos": "exsicativo",
    "exsicatória": "exsicatório",
    "exsicatórias": "exsicatório",
    "exsicatórios": "exsicatório",
    "exsicava": "exsicar",
    "exsicavam": "exsicar",
    "exsicavas": "exsicar",
    "exsicações": "exsicação",
    "exsico": "exsicar",
    "exsicou": "exsicar",
    "exsicá": "exsicar",
    "exsicámo": "exsicar",
    "exsicámos": "exsicar",
    "exsicáramo": "exsicar",
    "exsicáramos": "exsicar",
    "exsicárei": "exsicar",
    "exsicáreis": "exsicar",
    "exsicásseis": "exsicar",
    "exsicássemos": "exsicar",
    "exsicávamo": "exsicar",
    "exsicávamos": "exsicar",
    "exsicávei": "exsicar",
    "exsicáveis": "exsicar",
    "exsique": "exsicar",
    "exsiquei": "exsicar",
    "exsiqueis": "exsicar",
    "exsiquem": "exsicar",
    "exsiquemo": "exsicar",
    "exsiquemos": "exsicar",
    "exsiques": "exsicar",
    "exsolva": "exsolver",
    "exsolvais": "exsolver",
    "exsolvam": "exsolver",
    "exsolvamo": "exsolver",
    "exsolvamos": "exsolver",
    "exsolvas": "exsolver",
    "exsolve": "exsolver",
    "exsolvei": "exsolver",
    "exsolveis": "exsolver",
    "exsolvem": "exsolver",
    "exsolvemo": "exsolver",
    "exsolvemos": "exsolver",
    "exsolvendo": "exsolver",
    "exsolvera": "exsolver",
    "exsolveram": "exsolver",
    "exsolveras": "exsolver",
    "exsolverdes": "exsolver",
    "exsolverei": "exsolver",
    "exsolvereis": "exsolver",
    "exsolverem": "exsolver",
    "exsolveremos": "exsolver",
    "exsolveres": "exsolver",
    "exsolveria": "exsolver",
    "exsolveriam": "exsolver",
    "exsolverias": "exsolver",
    "exsolvermo": "exsolver",
    "exsolvermos": "exsolver",
    "exsolverá": "exsolver",
    "exsolverás": "exsolver",
    "exsolverão": "exsolver",
    "exsolveríamos": "exsolver",
    "exsolveríeis": "exsolver",
    "exsolves": "exsolver",
    "exsolvesse": "exsolver",
    "exsolvessem": "exsolver",
    "exsolvesses": "exsolver",
    "exsolveste": "exsolver",
    "exsolvestes": "exsolver",
    "exsolveu": "exsolver",
    "exsolvi": "exsolver",
    "exsolvia": "exsolver",
    "exsolviam": "exsolver",
    "exsolvias": "exsolver",
    "exsolvida": "exsolver",
    "exsolvidas": "exsolver",
    "exsolvido": "exsolver",
    "exsolvidos": "exsolver",
    "exsolvo": "exsolver",
    "exsolvêramo": "exsolver",
    "exsolvêramos": "exsolver",
    "exsolvêreis": "exsolver",
    "exsolvêsseis": "exsolver",
    "exsolvêssemos": "exsolver",
    "exsolvíamo": "exsolver",
    "exsolvíamos": "exsolver",
    "exsolvíeis": "exsolver",
    "exsua": "exsuar",
    "exsuada": "exsuar",
    "exsuadas": "exsuar",
    "exsuado": "exsuar",
    "exsuados": "exsuar",
    "exsuai": "exsuar",
    "exsuais": "exsuar",
    "exsuam": "exsuar",
    "exsuamo": "exsuar",
    "exsuamos": "exsuar",
    "exsuando": "exsuar",
    "exsuara": "exsuar",
    "exsuaram": "exsuar",
    "exsuaras": "exsuar",
    "exsuardes": "exsuar",
    "exsuarei": "exsuar",
    "exsuareis": "exsuar",
    "exsuarem": "exsuar",
    "exsuaremos": "exsuar",
    "exsuares": "exsuar",
    "exsuaria": "exsuar",
    "exsuariam": "exsuar",
    "exsuarias": "exsuar",
    "exsuarmo": "exsuar",
    "exsuarmos": "exsuar",
    "exsuará": "exsuar",
    "exsuarás": "exsuar",
    "exsuarão": "exsuar",
    "exsuaríamos": "exsuar",
    "exsuaríeis": "exsuar",
    "exsuas": "exsuar",
    "exsuasse": "exsuar",
    "exsuassem": "exsuar",
    "exsuasses": "exsuar",
    "exsuaste": "exsuar",
    "exsuastes": "exsuar",
    "exsuava": "exsuar",
    "exsuavam": "exsuar",
    "exsuavas": "exsuar",
    "exsucações": "exsucação",
    "exsucções": "exsucção",
    "exsuda": "exsudar",
    "exsudada": "exsudar",
    "exsudadas": "exsudar",
    "exsudado": "exsudar",
    "exsudados": "exsudar",
    "exsudai": "exsudar",
    "exsudais": "exsudar",
    "exsudam": "exsudar",
    "exsudamo": "exsudar",
    "exsudamos": "exsudar",
    "exsudando": "exsudar",
    "exsudara": "exsudar",
    "exsudaram": "exsudar",
    "exsudaras": "exsudar",
    "exsudardes": "exsudar",
    "exsudarei": "exsudar",
    "exsudareis": "exsudar",
    "exsudarem": "exsudar",
    "exsudaremos": "exsudar",
    "exsudares": "exsudar",
    "exsudaria": "exsudar",
    "exsudariam": "exsudar",
    "exsudarias": "exsudar",
    "exsudarmo": "exsudar",
    "exsudarmos": "exsudar",
    "exsudará": "exsudar",
    "exsudarás": "exsudar",
    "exsudarão": "exsudar",
    "exsudaríamos": "exsudar",
    "exsudaríeis": "exsudar",
    "exsudas": "exsudar",
    "exsudasse": "exsudar",
    "exsudassem": "exsudar",
    "exsudasses": "exsudar",
    "exsudaste": "exsudar",
    "exsudastes": "exsudar",
    "exsudatos": "exsudato",
    "exsudava": "exsudar",
    "exsudavam": "exsudar",
    "exsudavas": "exsudar",
    "exsudações": "exsudação",
    "exsude": "exsudar",
    "exsudei": "exsudar",
    "exsudeis": "exsudar",
    "exsudem": "exsudar",
    "exsudemo": "exsudar",
    "exsudemos": "exsudar",
    "exsudes": "exsudar",
    "exsudo": "exsudar",
    "exsudou": "exsudar",
    "exsudámo": "exsudar",
    "exsudámos": "exsudar",
    "exsudáramo": "exsudar",
    "exsudáramos": "exsudar",
    "exsudáreis": "exsudar",
    "exsudásseis": "exsudar",
    "exsudássemos": "exsudar",
    "exsudávamo": "exsudar",
    "exsudávamos": "exsudar",
    "exsudáveis": "exsudar",
    "exsue": "exsuar",
    "exsuei": "exsuar",
    "exsueis": "exsuar",
    "exsuem": "exsuar",
    "exsuemo": "exsuar",
    "exsuemos": "exsuar",
    "exsues": "exsuar",
    "exsuo": "exsuar",
    "exsuou": "exsuar",
    "exsurge": "exsurgir",
    "exsurgem": "exsurgir",
    "exsurgentes": "exsurgente",
    "exsurges": "exsurgir",
    "exsurgi": "exsurgir",
    "exsurgia": "exsurgir",
    "exsurgiam": "exsurgir",
    "exsurgias": "exsurgir",
    "exsurgida": "exsurgir",
    "exsurgidas": "exsurgir",
    "exsurgido": "exsurgir",
    "exsurgidos": "exsurgir",
    "exsurgimo": "exsurgir",
    "exsurgimos": "exsurgir",
    "exsurgindo": "exsurgir",
    "exsurgira": "exsurgir",
    "exsurgiram": "exsurgir",
    "exsurgiras": "exsurgir",
    "exsurgirdes": "exsurgir",
    "exsurgirei": "exsurgir",
    "exsurgireis": "exsurgir",
    "exsurgirem": "exsurgir",
    "exsurgiremos": "exsurgir",
    "exsurgires": "exsurgir",
    "exsurgiria": "exsurgir",
    "exsurgiriam": "exsurgir",
    "exsurgirias": "exsurgir",
    "exsurgirmo": "exsurgir",
    "exsurgirmos": "exsurgir",
    "exsurgirá": "exsurgir",
    "exsurgirás": "exsurgir",
    "exsurgirão": "exsurgir",
    "exsurgiríamos": "exsurgir",
    "exsurgiríeis": "exsurgir",
    "exsurgis": "exsurgir",
    "exsurgisse": "exsurgir",
    "exsurgissem": "exsurgir",
    "exsurgisses": "exsurgir",
    "exsurgiste": "exsurgir",
    "exsurgistes": "exsurgir",
    "exsurgiu": "exsurgir",
    "exsurgências": "exsurgência",
    "exsurgíamo": "exsurgir",
    "exsurgíamos": "exsurgir",
    "exsurgíeis": "exsurgir",
    "exsurgíramo": "exsurgir",
    "exsurgíramos": "exsurgir",
    "exsurgíreis": "exsurgir",
    "exsurgísseis": "exsurgir",
    "exsurgíssemos": "exsurgir",
    "exsurja": "exsurgir",
    "exsurjais": "exsurgir",
    "exsurjam": "exsurgir",
    "exsurjamo": "exsurgir",
    "exsurjamos": "exsurgir",
    "exsurjas": "exsurgir",
    "exsurjo": "exsurgir",
    "exsuámo": "exsuar",
    "exsuámos": "exsuar",
    "exsuáramo": "exsuar",
    "exsuáramos": "exsuar",
    "exsuáreis": "exsuar",
    "exsuásseis": "exsuar",
    "exsuássemos": "exsuar",
    "exsuávamo": "exsuar",
    "exsuávamos": "exsuar",
    "exsuáveis": "exsuar",
    "extasia": "extasiar",
    "extasiada": "extasiar",
    "extasiadas": "extasiar",
    "extasiado": "extasiar",
    "extasiados": "extasiar",
    "extasiai": "extasiar",
    "extasiais": "extasiar",
    "extasiam": "extasiar",
    "extasiamo": "extasiar",
    "extasiamos": "extasiar",
    "extasiando": "extasiar",
    "extasiara": "extasiar",
    "extasiaram": "extasiar",
    "extasiaras": "extasiar",
    "extasiarde": "extasiar",
    "extasiardes": "extasiar",
    "extasiare": "extasiar",
    "extasiarei": "extasiar",
    "extasiareis": "extasiar",
    "extasiarem": "extasiar",
    "extasiaremos": "extasiar",
    "extasiares": "extasiar",
    "extasiaria": "extasiar",
    "extasiariam": "extasiar",
    "extasiarias": "extasiar",
    "extasiarmo": "extasiar",
    "extasiarmos": "extasiar",
    "extasiará": "extasiar",
    "extasiarás": "extasiar",
    "extasiarão": "extasiar",
    "extasiaríamos": "extasiar",
    "extasiaríeis": "extasiar",
    "extasias": "extasiar",
    "extasiasse": "extasiar",
    "extasiassem": "extasiar",
    "extasiasses": "extasiar",
    "extasiaste": "extasiar",
    "extasiastes": "extasiar",
    "extasiava": "extasiar",
    "extasiavam": "extasiar",
    "extasiavas": "extasiar",
    "extasie": "extasiar",
    "extasiei": "extasiar",
    "extasieis": "extasiar",
    "extasiem": "extasiar",
    "extasiemo": "extasiar",
    "extasiemos": "extasiar",
    "extasies": "extasiar",
    "extasio": "extasiar",
    "extasiou": "extasiar",
    "extasiá": "extasiar",
    "extasiámo": "extasiar",
    "extasiámos": "extasiar",
    "extasiáramo": "extasiar",
    "extasiáramos": "extasiar",
    "extasiárei": "extasiar",
    "extasiáreis": "extasiar",
    "extasiásseis": "extasiar",
    "extasiássemos": "extasiar",
    "extasiávamo": "extasiar",
    "extasiávamos": "extasiar",
    "extasiávei": "extasiar",
    "extasiáveis": "extasiar",
    "extemporaneidades": "extemporaneidade",
    "extemporânea": "extemporâneo",
    "extemporâneas": "extemporâneo",
    "extemporâneos": "extemporâneo",
    "extensa": "extenso",
    "extensas": "extenso",
    "extensibilidades": "extensibilidade",
    "extensimétrica": "extensimétrico",
    "extensimétricas": "extensimétrico",
    "extensimétricos": "extensimétrico",
    "extensiva": "extensivo",
    "extensivas": "extensivo",
    "extensividades": "extensividade",
    "extensivos": "extensivo",
    "extensometrias": "extensometria",
    "extensométrica": "extensométrico",
    "extensométricas": "extensométrico",
    "extensométricos": "extensométrico",
    "extensora": "extensor",
    "extensoras": "extensor",
    "extensores": "extensor",
    "extensos": "extenso",
    "extensímetros": "extensímetro",
    "extensíssima": "extenso",
    "extensíssimas": "extenso",
    "extensíssimo": "extenso",
    "extensíssimos": "extenso",
    "extensíveis": "extensível",
    "extensómetros": "extensómetro",
    "extensões": "extensão",
    "extenua": "extenuar",
    "extenuada": "extenuar",
    "extenuadas": "extenuar",
    "extenuado": "extenuar",
    "extenuadora": "extenuador",
    "extenuadoras": "extenuador",
    "extenuadores": "extenuador",
    "extenuados": "extenuar",
    "extenuai": "extenuar",
    "extenuais": "extenuar",
    "extenuam": "extenuar",
    "extenuamo": "extenuar",
    "extenuamos": "extenuar",
    "extenuando": "extenuar",
    "extenuantes": "extenuante",
    "extenuara": "extenuar",
    "extenuaram": "extenuar",
    "extenuaras": "extenuar",
    "extenuarde": "extenuar",
    "extenuardes": "extenuar",
    "extenuare": "extenuar",
    "extenuarei": "extenuar",
    "extenuareis": "extenuar",
    "extenuarem": "extenuar",
    "extenuaremos": "extenuar",
    "extenuares": "extenuar",
    "extenuaria": "extenuar",
    "extenuariam": "extenuar",
    "extenuarias": "extenuar",
    "extenuarmo": "extenuar",
    "extenuarmos": "extenuar",
    "extenuará": "extenuar",
    "extenuarás": "extenuar",
    "extenuarão": "extenuar",
    "extenuaríamos": "extenuar",
    "extenuaríeis": "extenuar",
    "extenuas": "extenuar",
    "extenuasse": "extenuar",
    "extenuassem": "extenuar",
    "extenuasses": "extenuar",
    "extenuaste": "extenuar",
    "extenuastes": "extenuar",
    "extenuativa": "extenuativo",
    "extenuativas": "extenuativo",
    "extenuativos": "extenuativo",
    "extenuava": "extenuar",
    "extenuavam": "extenuar",
    "extenuavas": "extenuar",
    "extenuações": "extenuação",
    "extenue": "extenuar",
    "extenuei": "extenuar",
    "extenueis": "extenuar",
    "extenuem": "extenuar",
    "extenuemo": "extenuar",
    "extenuemos": "extenuar",
    "extenues": "extenuar",
    "extenuo": "extenuar",
    "extenuou": "extenuar",
    "extenuá": "extenuar",
    "extenuámo": "extenuar",
    "extenuámos": "extenuar",
    "extenuáramo": "extenuar",
    "extenuáramos": "extenuar",
    "extenuárei": "extenuar",
    "extenuáreis": "extenuar",
    "extenuásseis": "extenuar",
    "extenuássemos": "extenuar",
    "extenuávamo": "extenuar",
    "extenuávamos": "extenuar",
    "extenuávei": "extenuar",
    "extenuáveis": "extenuar",
    "exteriores": "exterior",
    "exterioridades": "exterioridade",
    "exterioriza": "exteriorizar",
    "exteriorizada": "exteriorizar",
    "exteriorizadas": "exteriorizar",
    "exteriorizado": "exteriorizar",
    "exteriorizados": "exteriorizar",
    "exteriorizai": "exteriorizar",
    "exteriorizais": "exteriorizar",
    "exteriorizam": "exteriorizar",
    "exteriorizamo": "exteriorizar",
    "exteriorizamos": "exteriorizar",
    "exteriorizando": "exteriorizar",
    "exteriorizara": "exteriorizar",
    "exteriorizaram": "exteriorizar",
    "exteriorizaras": "exteriorizar",
    "exteriorizarde": "exteriorizar",
    "exteriorizardes": "exteriorizar",
    "exteriorizare": "exteriorizar",
    "exteriorizarei": "exteriorizar",
    "exteriorizareis": "exteriorizar",
    "exteriorizarem": "exteriorizar",
    "exteriorizaremos": "exteriorizar",
    "exteriorizares": "exteriorizar",
    "exteriorizaria": "exteriorizar",
    "exteriorizariam": "exteriorizar",
    "exteriorizarias": "exteriorizar",
    "exteriorizarmo": "exteriorizar",
    "exteriorizarmos": "exteriorizar",
    "exteriorizará": "exteriorizar",
    "exteriorizarás": "exteriorizar",
    "exteriorizarão": "exteriorizar",
    "exteriorizaríamos": "exteriorizar",
    "exteriorizaríeis": "exteriorizar",
    "exteriorizas": "exteriorizar",
    "exteriorizasse": "exteriorizar",
    "exteriorizassem": "exteriorizar",
    "exteriorizasses": "exteriorizar",
    "exteriorizaste": "exteriorizar",
    "exteriorizastes": "exteriorizar",
    "exteriorizava": "exteriorizar",
    "exteriorizavam": "exteriorizar",
    "exteriorizavas": "exteriorizar",
    "exteriorizações": "exteriorização",
    "exteriorize": "exteriorizar",
    "exteriorizei": "exteriorizar",
    "exteriorizeis": "exteriorizar",
    "exteriorizem": "exteriorizar",
    "exteriorizemo": "exteriorizar",
    "exteriorizemos": "exteriorizar",
    "exteriorizes": "exteriorizar",
    "exteriorizo": "exteriorizar",
    "exteriorizou": "exteriorizar",
    "exteriorizá": "exteriorizar",
    "exteriorizámo": "exteriorizar",
    "exteriorizámos": "exteriorizar",
    "exteriorizáramo": "exteriorizar",
    "exteriorizáramos": "exteriorizar",
    "exteriorizárei": "exteriorizar",
    "exteriorizáreis": "exteriorizar",
    "exteriorizásseis": "exteriorizar",
    "exteriorizássemos": "exteriorizar",
    "exteriorizávamo": "exteriorizar",
    "exteriorizávamos": "exteriorizar",
    "exteriorizávei": "exteriorizar",
    "exteriorizáveis": "exteriorizável",
    "extermina": "exterminar",
    "exterminada": "exterminar",
    "exterminadas": "exterminar",
    "exterminado": "exterminar",
    "exterminadora": "exterminador",
    "exterminadoras": "exterminador",
    "exterminadores": "exterminador",
    "exterminados": "exterminar",
    "exterminai": "exterminar",
    "exterminais": "exterminar",
    "exterminam": "exterminar",
    "exterminamo": "exterminar",
    "exterminamos": "exterminar",
    "exterminando": "exterminar",
    "exterminantes": "exterminante",
    "exterminara": "exterminar",
    "exterminaram": "exterminar",
    "exterminaras": "exterminar",
    "exterminarde": "exterminar",
    "exterminardes": "exterminar",
    "exterminare": "exterminar",
    "exterminarei": "exterminar",
    "exterminareis": "exterminar",
    "exterminarem": "exterminar",
    "exterminaremos": "exterminar",
    "exterminares": "exterminar",
    "exterminaria": "exterminar",
    "exterminariam": "exterminar",
    "exterminarias": "exterminar",
    "exterminarmo": "exterminar",
    "exterminarmos": "exterminar",
    "exterminará": "exterminar",
    "exterminarás": "exterminar",
    "exterminarão": "exterminar",
    "exterminaríamos": "exterminar",
    "exterminaríeis": "exterminar",
    "exterminas": "exterminar",
    "exterminasse": "exterminar",
    "exterminassem": "exterminar",
    "exterminasses": "exterminar",
    "exterminaste": "exterminar",
    "exterminastes": "exterminar",
    "exterminava": "exterminar",
    "exterminavam": "exterminar",
    "exterminavas": "exterminar",
    "exterminações": "exterminação",
    "extermine": "exterminar",
    "exterminei": "exterminar",
    "extermineis": "exterminar",
    "exterminem": "exterminar",
    "exterminemo": "exterminar",
    "exterminemos": "exterminar",
    "extermines": "exterminar",
    "extermino": "exterminar",
    "exterminou": "exterminar",
    "exterminá": "exterminar",
    "exterminámo": "exterminar",
    "exterminámos": "exterminar",
    "extermináramo": "exterminar",
    "extermináramos": "exterminar",
    "exterminárei": "exterminar",
    "extermináreis": "exterminar",
    "exterminásseis": "exterminar",
    "exterminássemos": "exterminar",
    "exterminávamo": "exterminar",
    "exterminávamos": "exterminar",
    "exterminávei": "exterminar",
    "extermináveis": "exterminável",
    "extermínios": "extermínio",
    "externa": "externo",
    "externada": "externar",
    "externadas": "externar",
    "externado": "externar",
    "externados": "externar",
    "externai": "externar",
    "externais": "externar",
    "externam": "externar",
    "externamo": "externar",
    "externamos": "externar",
    "externando": "externar",
    "externara": "externar",
    "externaram": "externar",
    "externaras": "externar",
    "externarde": "externar",
    "externardes": "externar",
    "externare": "externar",
    "externarei": "externar",
    "externareis": "externar",
    "externarem": "externar",
    "externaremos": "externar",
    "externares": "externar",
    "externaria": "externar",
    "externariam": "externar",
    "externarias": "externar",
    "externarmo": "externar",
    "externarmos": "externar",
    "externará": "externar",
    "externarás": "externar",
    "externarão": "externar",
    "externaríamos": "externar",
    "externaríeis": "externar",
    "externas": "externo",
    "externasse": "externar",
    "externassem": "externar",
    "externasses": "externar",
    "externaste": "externar",
    "externastes": "externar",
    "externatos": "externato",
    "externava": "externar",
    "externavam": "externar",
    "externavas": "externar",
    "externações": "externação",
    "externe": "externar",
    "externei": "externar",
    "externeis": "externar",
    "externem": "externar",
    "externemo": "externar",
    "externemos": "externar",
    "externes": "externar",
    "externo": "externar",
    "externos": "externo",
    "externou": "externar",
    "externá": "externar",
    "externámo": "externar",
    "externámos": "externar",
    "externáramo": "externar",
    "externáramos": "externar",
    "externárei": "externar",
    "externáreis": "externar",
    "externásseis": "externar",
    "externássemos": "externar",
    "externávamo": "externar",
    "externávamos": "externar",
    "externávei": "externar",
    "externáveis": "externar",
    "exteroceptiva": "exteroceptivo",
    "exteroceptivas": "exteroceptivo",
    "exteroceptivos": "exteroceptivo",
    "exteroceptores": "exteroceptor",
    "exterritorialidades": "exterritorialidade",
    "extinga": "extinguir",
    "extingais": "extinguir",
    "extingam": "extinguir",
    "extingamo": "extinguir",
    "extingamos": "extinguir",
    "extingas": "extinguir",
    "extingo": "extinguir",
    "extingue": "extinguir",
    "extinguem": "extinguir",
    "extingues": "extinguir",
    "extingui": "extinguir",
    "extinguia": "extinguir",
    "extinguiam": "extinguir",
    "extinguias": "extinguir",
    "extinguida": "extinguir",
    "extinguidas": "extinguir",
    "extinguido": "extinguir",
    "extinguidora": "extinguidor",
    "extinguidoras": "extinguidor",
    "extinguidores": "extinguidor",
    "extinguidos": "extinguir",
    "extinguimo": "extinguir",
    "extinguimos": "extinguir",
    "extinguindo": "extinguir",
    "extinguira": "extinguir",
    "extinguiram": "extinguir",
    "extinguiras": "extinguir",
    "extinguirde": "extinguir",
    "extinguirdes": "extinguir",
    "extinguire": "extinguir",
    "extinguirei": "extinguir",
    "extinguireis": "extinguir",
    "extinguirem": "extinguir",
    "extinguiremos": "extinguir",
    "extinguires": "extinguir",
    "extinguiria": "extinguir",
    "extinguiriam": "extinguir",
    "extinguirias": "extinguir",
    "extinguirmo": "extinguir",
    "extinguirmos": "extinguir",
    "extinguirá": "extinguir",
    "extinguirás": "extinguir",
    "extinguirão": "extinguir",
    "extinguiríamos": "extinguir",
    "extinguiríeis": "extinguir",
    "extinguis": "extinguir",
    "extinguisse": "extinguir",
    "extinguissem": "extinguir",
    "extinguisses": "extinguir",
    "extinguiste": "extinguir",
    "extinguistes": "extinguir",
    "extinguiu": "extinguir",
    "extinguíamo": "extinguir",
    "extinguíamos": "extinguir",
    "extinguíei": "extinguir",
    "extinguíeis": "extinguir",
    "extinguíramo": "extinguir",
    "extinguíramos": "extinguir",
    "extinguírei": "extinguir",
    "extinguíreis": "extinguir",
    "extinguísseis": "extinguir",
    "extinguíssemos": "extinguir",
    "extinguíveis": "extinguível",
    "extinta": "extinto",
    "extintas": "extinto",
    "extintiva": "extintivo",
    "extintivas": "extintivo",
    "extintivos": "extintivo",
    "extinto": "extinguir",
    "extintora": "extintor",
    "extintoras": "extintor",
    "extintores": "extintor",
    "extintos": "extinto",
    "extinções": "extinção",
    "extipulada": "extipulado",
    "extipuladas": "extipulado",
    "extipulados": "extipulado",
    "extirpa": "extirpar",
    "extirpada": "extirpar",
    "extirpadas": "extirpar",
    "extirpado": "extirpar",
    "extirpadora": "extirpador",
    "extirpadoras": "extirpador",
    "extirpadores": "extirpador",
    "extirpados": "extirpar",
    "extirpai": "extirpar",
    "extirpais": "extirpar",
    "extirpam": "extirpar",
    "extirpamentos": "extirpamento",
    "extirpamo": "extirpar",
    "extirpamos": "extirpar",
    "extirpando": "extirpar",
    "extirpara": "extirpar",
    "extirparam": "extirpar",
    "extirparas": "extirpar",
    "extirparde": "extirpar",
    "extirpardes": "extirpar",
    "extirpare": "extirpar",
    "extirparei": "extirpar",
    "extirpareis": "extirpar",
    "extirparem": "extirpar",
    "extirparemos": "extirpar",
    "extirpares": "extirpar",
    "extirparia": "extirpar",
    "extirpariam": "extirpar",
    "extirparias": "extirpar",
    "extirparmo": "extirpar",
    "extirparmos": "extirpar",
    "extirpará": "extirpar",
    "extirparás": "extirpar",
    "extirparão": "extirpar",
    "extirparíamos": "extirpar",
    "extirparíeis": "extirpar",
    "extirpas": "extirpar",
    "extirpasse": "extirpar",
    "extirpassem": "extirpar",
    "extirpasses": "extirpar",
    "extirpaste": "extirpar",
    "extirpastes": "extirpar",
    "extirpava": "extirpar",
    "extirpavam": "extirpar",
    "extirpavas": "extirpar",
    "extirpações": "extirpação",
    "extirpe": "extirpar",
    "extirpei": "extirpar",
    "extirpeis": "extirpar",
    "extirpem": "extirpar",
    "extirpemo": "extirpar",
    "extirpemos": "extirpar",
    "extirpes": "extirpar",
    "extirpo": "extirpar",
    "extirpou": "extirpar",
    "extirpá": "extirpar",
    "extirpámo": "extirpar",
    "extirpámos": "extirpar",
    "extirpáramo": "extirpar",
    "extirpáramos": "extirpar",
    "extirpárei": "extirpar",
    "extirpáreis": "extirpar",
    "extirpásseis": "extirpar",
    "extirpássemos": "extirpar",
    "extirpávamo": "extirpar",
    "extirpávamos": "extirpar",
    "extirpávei": "extirpar",
    "extirpáveis": "extirpável",
    "extispícios": "extispício",
    "extorque": "extorquir",
    "extorquem": "extorquir",
    "extorques": "extorquir",
    "extorqui": "extorquir",
    "extorquia": "extorquir",
    "extorquiam": "extorquir",
    "extorquias": "extorquir",
    "extorquida": "extorquir",
    "extorquidas": "extorquir",
    "extorquido": "extorquir",
    "extorquidos": "extorquir",
    "extorquimo": "extorquir",
    "extorquimos": "extorquir",
    "extorquindo": "extorquir",
    "extorquira": "extorquir",
    "extorquiram": "extorquir",
    "extorquiras": "extorquir",
    "extorquirde": "extorquir",
    "extorquirdes": "extorquir",
    "extorquire": "extorquir",
    "extorquirei": "extorquir",
    "extorquireis": "extorquir",
    "extorquirem": "extorquir",
    "extorquiremos": "extorquir",
    "extorquires": "extorquir",
    "extorquiria": "extorquir",
    "extorquiriam": "extorquir",
    "extorquirias": "extorquir",
    "extorquirmo": "extorquir",
    "extorquirmos": "extorquir",
    "extorquirá": "extorquir",
    "extorquirás": "extorquir",
    "extorquirão": "extorquir",
    "extorquiríamos": "extorquir",
    "extorquiríeis": "extorquir",
    "extorquis": "extorquir",
    "extorquisse": "extorquir",
    "extorquissem": "extorquir",
    "extorquisses": "extorquir",
    "extorquiste": "extorquir",
    "extorquistes": "extorquir",
    "extorquiu": "extorquir",
    "extorquíamo": "extorquir",
    "extorquíamos": "extorquir",
    "extorquíei": "extorquir",
    "extorquíeis": "extorquir",
    "extorquíramo": "extorquir",
    "extorquíramos": "extorquir",
    "extorquírei": "extorquir",
    "extorquíreis": "extorquir",
    "extorquísseis": "extorquir",
    "extorquíssemos": "extorquir",
    "extorsionária": "extorsionário",
    "extorsionárias": "extorsionário",
    "extorsionários": "extorsionário",
    "extorsiva": "extorsivo",
    "extorsivas": "extorsivo",
    "extorsivos": "extorsivo",
    "extorsos": "extorso",
    "extorsões": "extorsão",
    "extortora": "extortor",
    "extortoras": "extortor",
    "extortores": "extortor",
    "extracompetições": "extracompetição",
    "extracomunitária": "extracomunitário",
    "extracomunitárias": "extracomunitário",
    "extracomunitários": "extracomunitário",
    "extraconcursos": "extraconcurso",
    "extraconjugais": "extraconjugal",
    "extracontinentais": "extracontinental",
    "extracontratuais": "extracontratual",
    "extracorrentes": "extracorrente",
    "extracrescentes": "extracrescente",
    "extractiva": "extractivo",
    "extractivas": "extractivo",
    "extractivos": "extractivo",
    "extractora": "extractor",
    "extractoras": "extractor",
    "extractores": "extractor",
    "extractos": "extracto",
    "extractíveis": "extractível",
    "extracurriculares": "extracurricular",
    "extracções": "extracção",
    "extradita": "extraditar",
    "extraditada": "extraditar",
    "extraditadas": "extraditar",
    "extraditado": "extraditar",
    "extraditados": "extraditar",
    "extraditai": "extraditar",
    "extraditais": "extraditar",
    "extraditam": "extraditar",
    "extraditamo": "extraditar",
    "extraditamos": "extraditar",
    "extraditanda": "extraditando",
    "extraditandas": "extraditando",
    "extraditando": "extraditar",
    "extraditandos": "extraditando",
    "extraditara": "extraditar",
    "extraditaram": "extraditar",
    "extraditaras": "extraditar",
    "extraditarde": "extraditar",
    "extraditardes": "extraditar",
    "extraditare": "extraditar",
    "extraditarei": "extraditar",
    "extraditareis": "extraditar",
    "extraditarem": "extraditar",
    "extraditaremos": "extraditar",
    "extraditares": "extraditar",
    "extraditaria": "extraditar",
    "extraditariam": "extraditar",
    "extraditarias": "extraditar",
    "extraditarmo": "extraditar",
    "extraditarmos": "extraditar",
    "extraditará": "extraditar",
    "extraditarás": "extraditar",
    "extraditarão": "extraditar",
    "extraditaríamos": "extraditar",
    "extraditaríeis": "extraditar",
    "extraditas": "extraditar",
    "extraditasse": "extraditar",
    "extraditassem": "extraditar",
    "extraditasses": "extraditar",
    "extraditaste": "extraditar",
    "extraditastes": "extraditar",
    "extraditava": "extraditar",
    "extraditavam": "extraditar",
    "extraditavas": "extraditar",
    "extradite": "extraditar",
    "extraditei": "extraditar",
    "extraditeis": "extraditar",
    "extraditem": "extraditar",
    "extraditemo": "extraditar",
    "extraditemos": "extraditar",
    "extradites": "extraditar",
    "extradito": "extraditar",
    "extraditora": "extraditor",
    "extraditoras": "extraditor",
    "extraditores": "extraditor",
    "extraditou": "extraditar",
    "extraditá": "extraditar",
    "extraditámo": "extraditar",
    "extraditámos": "extraditar",
    "extraditáramo": "extraditar",
    "extraditáramos": "extraditar",
    "extraditárei": "extraditar",
    "extraditáreis": "extraditar",
    "extraditásseis": "extraditar",
    "extraditássemos": "extraditar",
    "extraditávamo": "extraditar",
    "extraditávamos": "extraditar",
    "extraditávei": "extraditar",
    "extraditáveis": "extraditável",
    "extradições": "extradição",
    "extradorsada": "extradorsado",
    "extradorsadas": "extradorsado",
    "extradorsados": "extradorsado",
    "extradorsos": "extradorso",
    "extraem": "extrair",
    "extrafina": "extrafino",
    "extrafinas": "extrafino",
    "extrafinos": "extrafino",
    "extrafolia": "extrafoliar",
    "extrafoliada": "extrafoliar",
    "extrafoliadas": "extrafoliar",
    "extrafoliado": "extrafoliar",
    "extrafoliados": "extrafoliar",
    "extrafoliai": "extrafoliar",
    "extrafoliais": "extrafoliar",
    "extrafoliam": "extrafoliar",
    "extrafoliamo": "extrafoliar",
    "extrafoliamos": "extrafoliar",
    "extrafoliando": "extrafoliar",
    "extrafoliara": "extrafoliar",
    "extrafoliaram": "extrafoliar",
    "extrafoliaras": "extrafoliar",
    "extrafoliarde": "extrafoliar",
    "extrafoliardes": "extrafoliar",
    "extrafoliare": "extrafoliar",
    "extrafoliarei": "extrafoliar",
    "extrafoliareis": "extrafoliar",
    "extrafoliarem": "extrafoliar",
    "extrafoliaremos": "extrafoliar",
    "extrafoliares": "extrafoliar",
    "extrafoliaria": "extrafoliar",
    "extrafoliariam": "extrafoliar",
    "extrafoliarias": "extrafoliar",
    "extrafoliarmo": "extrafoliar",
    "extrafoliarmos": "extrafoliar",
    "extrafoliará": "extrafoliar",
    "extrafoliarás": "extrafoliar",
    "extrafoliarão": "extrafoliar",
    "extrafoliaríamos": "extrafoliar",
    "extrafoliaríeis": "extrafoliar",
    "extrafolias": "extrafoliar",
    "extrafoliasse": "extrafoliar",
    "extrafoliassem": "extrafoliar",
    "extrafoliasses": "extrafoliar",
    "extrafoliaste": "extrafoliar",
    "extrafoliastes": "extrafoliar",
    "extrafoliava": "extrafoliar",
    "extrafoliavam": "extrafoliar",
    "extrafoliavas": "extrafoliar",
    "extrafolie": "extrafoliar",
    "extrafoliei": "extrafoliar",
    "extrafolieis": "extrafoliar",
    "extrafoliem": "extrafoliar",
    "extrafoliemo": "extrafoliar",
    "extrafoliemos": "extrafoliar",
    "extrafolies": "extrafoliar",
    "extrafolio": "extrafoliar",
    "extrafoliou": "extrafoliar",
    "extrafoliá": "extrafoliar",
    "extrafoliácea": "extrafoliáceo",
    "extrafoliáceas": "extrafoliáceo",
    "extrafoliáceos": "extrafoliáceo",
    "extrafoliámo": "extrafoliar",
    "extrafoliámos": "extrafoliar",
    "extrafoliáramo": "extrafoliar",
    "extrafoliáramos": "extrafoliar",
    "extrafoliárei": "extrafoliar",
    "extrafoliáreis": "extrafoliar",
    "extrafoliásseis": "extrafoliar",
    "extrafoliássemos": "extrafoliar",
    "extrafoliávamo": "extrafoliar",
    "extrafoliávamos": "extrafoliar",
    "extrafoliávei": "extrafoliar",
    "extrafoliáveis": "extrafoliar",
    "extrafólia": "extrafólio",
    "extrafólias": "extrafólio",
    "extrafólios": "extrafólio",
    "extrai": "extrair",
    "extraia": "extrair",
    "extraiais": "extrair",
    "extraiam": "extrair",
    "extraiamo": "extrair",
    "extraiamos": "extrair",
    "extraias": "extrair",
    "extraindo": "extrair",
    "extraio": "extrair",
    "extrairde": "extrair",
    "extrairdes": "extrair",
    "extrairei": "extrair",
    "extraireis": "extrair",
    "extrairemos": "extrair",
    "extrairia": "extrair",
    "extrairiam": "extrair",
    "extrairias": "extrair",
    "extrairmo": "extrair",
    "extrairmos": "extrair",
    "extrairá": "extrair",
    "extrairás": "extrair",
    "extrairão": "extrair",
    "extrairíamos": "extrair",
    "extrairíeis": "extrair",
    "extrais": "extrair",
    "extraiu": "extrair",
    "extrajudiciais": "extrajudicial",
    "extrajudiciária": "extrajudiciário",
    "extrajudiciárias": "extrajudiciário",
    "extrajudiciários": "extrajudiciário",
    "extralegais": "extralegal",
    "extramatrimoniais": "extramatrimonial",
    "extramorais": "extramoral",
    "extramundana": "extramundano",
    "extramundanas": "extramundano",
    "extramundanos": "extramundano",
    "extranaturais": "extranatural",
    "extranormais": "extranormal",
    "extranumerais": "extranumeral",
    "extranumerária": "extranumerário",
    "extranumerárias": "extranumerário",
    "extranumerários": "extranumerário",
    "extraordinária": "extraordinário",
    "extraordinárias": "extraordinário",
    "extraordinários": "extraordinário",
    "extraparlamentares": "extraparlamentar",
    "extrapassa": "extrapassar",
    "extrapassada": "extrapassar",
    "extrapassadas": "extrapassar",
    "extrapassado": "extrapassar",
    "extrapassados": "extrapassar",
    "extrapassai": "extrapassar",
    "extrapassais": "extrapassar",
    "extrapassam": "extrapassar",
    "extrapassamo": "extrapassar",
    "extrapassamos": "extrapassar",
    "extrapassando": "extrapassar",
    "extrapassara": "extrapassar",
    "extrapassaram": "extrapassar",
    "extrapassaras": "extrapassar",
    "extrapassarde": "extrapassar",
    "extrapassardes": "extrapassar",
    "extrapassare": "extrapassar",
    "extrapassarei": "extrapassar",
    "extrapassareis": "extrapassar",
    "extrapassarem": "extrapassar",
    "extrapassaremos": "extrapassar",
    "extrapassares": "extrapassar",
    "extrapassaria": "extrapassar",
    "extrapassariam": "extrapassar",
    "extrapassarias": "extrapassar",
    "extrapassarmo": "extrapassar",
    "extrapassarmos": "extrapassar",
    "extrapassará": "extrapassar",
    "extrapassarás": "extrapassar",
    "extrapassarão": "extrapassar",
    "extrapassaríamos": "extrapassar",
    "extrapassaríeis": "extrapassar",
    "extrapassas": "extrapassar",
    "extrapassasse": "extrapassar",
    "extrapassassem": "extrapassar",
    "extrapassasses": "extrapassar",
    "extrapassaste": "extrapassar",
    "extrapassastes": "extrapassar",
    "extrapassava": "extrapassar",
    "extrapassavam": "extrapassar",
    "extrapassavas": "extrapassar",
    "extrapasse": "extrapassar",
    "extrapassei": "extrapassar",
    "extrapasseis": "extrapassar",
    "extrapassem": "extrapassar",
    "extrapassemo": "extrapassar",
    "extrapassemos": "extrapassar",
    "extrapasses": "extrapassar",
    "extrapasso": "extrapassar",
    "extrapassou": "extrapassar",
    "extrapassá": "extrapassar",
    "extrapassámo": "extrapassar",
    "extrapassámos": "extrapassar",
    "extrapassáramo": "extrapassar",
    "extrapassáramos": "extrapassar",
    "extrapassárei": "extrapassar",
    "extrapassáreis": "extrapassar",
    "extrapassásseis": "extrapassar",
    "extrapassássemos": "extrapassar",
    "extrapassávamo": "extrapassar",
    "extrapassávamos": "extrapassar",
    "extrapassávei": "extrapassar",
    "extrapassáveis": "extrapassar",
    "extrapola": "extrapolar",
    "extrapolada": "extrapolar",
    "extrapoladas": "extrapolar",
    "extrapolado": "extrapolar",
    "extrapolados": "extrapolar",
    "extrapolai": "extrapolar",
    "extrapolais": "extrapolar",
    "extrapolam": "extrapolar",
    "extrapolamo": "extrapolar",
    "extrapolamos": "extrapolar",
    "extrapolando": "extrapolar",
    "extrapolara": "extrapolar",
    "extrapolaram": "extrapolar",
    "extrapolaras": "extrapolar",
    "extrapolarde": "extrapolar",
    "extrapolardes": "extrapolar",
    "extrapolare": "extrapolar",
    "extrapolarei": "extrapolar",
    "extrapolareis": "extrapolar",
    "extrapolarem": "extrapolar",
    "extrapolaremos": "extrapolar",
    "extrapolares": "extrapolar",
    "extrapolaria": "extrapolar",
    "extrapolariam": "extrapolar",
    "extrapolarias": "extrapolar",
    "extrapolarmo": "extrapolar",
    "extrapolarmos": "extrapolar",
    "extrapolará": "extrapolar",
    "extrapolarás": "extrapolar",
    "extrapolarão": "extrapolar",
    "extrapolaríamos": "extrapolar",
    "extrapolaríeis": "extrapolar",
    "extrapolas": "extrapolar",
    "extrapolasse": "extrapolar",
    "extrapolassem": "extrapolar",
    "extrapolasses": "extrapolar",
    "extrapolaste": "extrapolar",
    "extrapolastes": "extrapolar",
    "extrapolava": "extrapolar",
    "extrapolavam": "extrapolar",
    "extrapolavas": "extrapolar",
    "extrapolações": "extrapolação",
    "extrapole": "extrapolar",
    "extrapolei": "extrapolar",
    "extrapoleis": "extrapolar",
    "extrapolem": "extrapolar",
    "extrapolemo": "extrapolar",
    "extrapolemos": "extrapolar",
    "extrapoles": "extrapolar",
    "extrapolo": "extrapolar",
    "extrapolou": "extrapolar",
    "extrapolá": "extrapolar",
    "extrapolámo": "extrapolar",
    "extrapolámos": "extrapolar",
    "extrapoláramo": "extrapolar",
    "extrapoláramos": "extrapolar",
    "extrapolárei": "extrapolar",
    "extrapoláreis": "extrapolar",
    "extrapolásseis": "extrapolar",
    "extrapolássemos": "extrapolar",
    "extrapolávamo": "extrapolar",
    "extrapolávamos": "extrapolar",
    "extrapolávei": "extrapolar",
    "extrapoláveis": "extrapolável",
    "extras": "extra",
    "extraterrestres": "extraterrestre",
    "extraterritoriais": "extraterritorial",
    "extraterritorialidades": "extraterritorialidade",
    "extratextos": "extratexto",
    "extratorácica": "extratorácico",
    "extratorácicas": "extratorácico",
    "extratorácicos": "extratorácico",
    "extravaga": "extravagar",
    "extravagada": "extravagar",
    "extravagadas": "extravagar",
    "extravagado": "extravagar",
    "extravagados": "extravagar",
    "extravagai": "extravagar",
    "extravagais": "extravagar",
    "extravagam": "extravagar",
    "extravagamo": "extravagar",
    "extravagamos": "extravagar",
    "extravagando": "extravagar",
    "extravagantes": "extravagante",
    "extravagara": "extravagar",
    "extravagaram": "extravagar",
    "extravagaras": "extravagar",
    "extravagardes": "extravagar",
    "extravagarei": "extravagar",
    "extravagareis": "extravagar",
    "extravagarem": "extravagar",
    "extravagaremos": "extravagar",
    "extravagares": "extravagar",
    "extravagaria": "extravagar",
    "extravagariam": "extravagar",
    "extravagarias": "extravagar",
    "extravagarmo": "extravagar",
    "extravagarmos": "extravagar",
    "extravagará": "extravagar",
    "extravagarás": "extravagar",
    "extravagarão": "extravagar",
    "extravagaríamos": "extravagar",
    "extravagaríeis": "extravagar",
    "extravagas": "extravagar",
    "extravagasse": "extravagar",
    "extravagassem": "extravagar",
    "extravagasses": "extravagar",
    "extravagaste": "extravagar",
    "extravagastes": "extravagar",
    "extravagava": "extravagar",
    "extravagavam": "extravagar",
    "extravagavas": "extravagar",
    "extravaginais": "extravaginal",
    "extravago": "extravagar",
    "extravagou": "extravagar",
    "extravague": "extravagar",
    "extravaguei": "extravagar",
    "extravagueis": "extravagar",
    "extravaguem": "extravagar",
    "extravaguemo": "extravagar",
    "extravaguemos": "extravagar",
    "extravagues": "extravagar",
    "extravagámo": "extravagar",
    "extravagámos": "extravagar",
    "extravagáramo": "extravagar",
    "extravagáramos": "extravagar",
    "extravagáreis": "extravagar",
    "extravagásseis": "extravagar",
    "extravagássemos": "extravagar",
    "extravagávamo": "extravagar",
    "extravagávamos": "extravagar",
    "extravagáveis": "extravagar",
    "extravagâncias": "extravagância",
    "extravasa": "extravasar",
    "extravasada": "extravasar",
    "extravasadas": "extravasar",
    "extravasado": "extravasar",
    "extravasados": "extravasar",
    "extravasai": "extravasar",
    "extravasais": "extravasar",
    "extravasam": "extravasar",
    "extravasamentos": "extravasamento",
    "extravasamo": "extravasar",
    "extravasamos": "extravasar",
    "extravasando": "extravasar",
    "extravasantes": "extravasante",
    "extravasara": "extravasar",
    "extravasaram": "extravasar",
    "extravasaras": "extravasar",
    "extravasarde": "extravasar",
    "extravasardes": "extravasar",
    "extravasare": "extravasar",
    "extravasarei": "extravasar",
    "extravasareis": "extravasar",
    "extravasarem": "extravasar",
    "extravasaremos": "extravasar",
    "extravasares": "extravasar",
    "extravasaria": "extravasar",
    "extravasariam": "extravasar",
    "extravasarias": "extravasar",
    "extravasarmo": "extravasar",
    "extravasarmos": "extravasar",
    "extravasará": "extravasar",
    "extravasarás": "extravasar",
    "extravasarão": "extravasar",
    "extravasaríamos": "extravasar",
    "extravasaríeis": "extravasar",
    "extravasas": "extravasar",
    "extravasasse": "extravasar",
    "extravasassem": "extravasar",
    "extravasasses": "extravasar",
    "extravasaste": "extravasar",
    "extravasastes": "extravasar",
    "extravasava": "extravasar",
    "extravasavam": "extravasar",
    "extravasavas": "extravasar",
    "extravasações": "extravasação",
    "extravase": "extravasar",
    "extravasei": "extravasar",
    "extravaseis": "extravasar",
    "extravasem": "extravasar",
    "extravasemo": "extravasar",
    "extravasemos": "extravasar",
    "extravases": "extravasar",
    "extravaso": "extravasar",
    "extravasou": "extravasar",
    "extravasá": "extravasar",
    "extravasámo": "extravasar",
    "extravasámos": "extravasar",
    "extravasáramo": "extravasar",
    "extravasáramos": "extravasar",
    "extravasárei": "extravasar",
    "extravasáreis": "extravasar",
    "extravasásseis": "extravasar",
    "extravasássemos": "extravasar",
    "extravasávamo": "extravasar",
    "extravasávamos": "extravasar",
    "extravasávei": "extravasar",
    "extravasáveis": "extravasável",
    "extravasões": "extravasão",
    "extravenada": "extravenado",
    "extravenadas": "extravenado",
    "extravenados": "extravenado",
    "extraversões": "extraversão",
    "extraverta": "extraverter",
    "extravertais": "extraverter",
    "extravertam": "extraverter",
    "extravertamo": "extraverter",
    "extravertamos": "extraverter",
    "extravertas": "extraverter",
    "extraverte": "extraverter",
    "extravertei": "extraverter",
    "extraverteis": "extraverter",
    "extravertem": "extraverter",
    "extravertemo": "extraverter",
    "extravertemos": "extraverter",
    "extravertendo": "extraverter",
    "extravertera": "extraverter",
    "extraverteram": "extraverter",
    "extraverteras": "extraverter",
    "extraverterdes": "extraverter",
    "extraverterei": "extraverter",
    "extravertereis": "extraverter",
    "extraverterem": "extraverter",
    "extraverteremos": "extraverter",
    "extraverteres": "extraverter",
    "extraverteria": "extraverter",
    "extraverteriam": "extraverter",
    "extraverterias": "extraverter",
    "extravertermo": "extraverter",
    "extravertermos": "extraverter",
    "extraverterá": "extraverter",
    "extraverterás": "extraverter",
    "extraverterão": "extraverter",
    "extraverteríamos": "extraverter",
    "extraverteríeis": "extraverter",
    "extravertes": "extraverter",
    "extravertesse": "extraverter",
    "extravertessem": "extraverter",
    "extravertesses": "extraverter",
    "extraverteste": "extraverter",
    "extravertestes": "extraverter",
    "extraverteu": "extraverter",
    "extraverti": "extraverter",
    "extravertia": "extraverter",
    "extravertiam": "extraverter",
    "extravertias": "extraverter",
    "extravertida": "extravertido",
    "extravertidas": "extravertido",
    "extravertido": "extraverter",
    "extravertidos": "extravertido",
    "extraverto": "extraverter",
    "extravertêramo": "extraverter",
    "extravertêramos": "extraverter",
    "extravertêreis": "extraverter",
    "extravertêsseis": "extraverter",
    "extravertêssemos": "extraverter",
    "extravertíamo": "extraverter",
    "extravertíamos": "extraverter",
    "extravertíeis": "extraverter",
    "extravia": "extraviar",
    "extraviada": "extraviar",
    "extraviadas": "extraviar",
    "extraviado": "extraviar",
    "extraviadora": "extraviador",
    "extraviadoras": "extraviador",
    "extraviadores": "extraviador",
    "extraviados": "extraviar",
    "extraviai": "extraviar",
    "extraviais": "extraviar",
    "extraviam": "extraviar",
    "extraviamo": "extraviar",
    "extraviamos": "extraviar",
    "extraviando": "extraviar",
    "extraviara": "extraviar",
    "extraviaram": "extraviar",
    "extraviaras": "extraviar",
    "extraviarde": "extraviar",
    "extraviardes": "extraviar",
    "extraviare": "extraviar",
    "extraviarei": "extraviar",
    "extraviareis": "extraviar",
    "extraviarem": "extraviar",
    "extraviaremos": "extraviar",
    "extraviares": "extraviar",
    "extraviaria": "extraviar",
    "extraviariam": "extraviar",
    "extraviarias": "extraviar",
    "extraviarmo": "extraviar",
    "extraviarmos": "extraviar",
    "extraviará": "extraviar",
    "extraviarás": "extraviar",
    "extraviarão": "extraviar",
    "extraviaríamos": "extraviar",
    "extraviaríeis": "extraviar",
    "extravias": "extraviar",
    "extraviasse": "extraviar",
    "extraviassem": "extraviar",
    "extraviasses": "extraviar",
    "extraviaste": "extraviar",
    "extraviastes": "extraviar",
    "extraviava": "extraviar",
    "extraviavam": "extraviar",
    "extraviavas": "extraviar",
    "extravie": "extraviar",
    "extraviei": "extraviar",
    "extravieis": "extraviar",
    "extraviem": "extraviar",
    "extraviemo": "extraviar",
    "extraviemos": "extraviar",
    "extravies": "extraviar",
    "extravio": "extraviar",
    "extravios": "extravio",
    "extraviou": "extraviar",
    "extraviá": "extraviar",
    "extraviámo": "extraviar",
    "extraviámos": "extraviar",
    "extraviáramo": "extraviar",
    "extraviáramos": "extraviar",
    "extraviárei": "extraviar",
    "extraviáreis": "extraviar",
    "extraviásseis": "extraviar",
    "extraviássemos": "extraviar",
    "extraviávamo": "extraviar",
    "extraviávamos": "extraviar",
    "extraviávei": "extraviar",
    "extraviáveis": "extraviar",
    "extraí": "extrair",
    "extraía": "extrair",
    "extraíam": "extrair",
    "extraíamo": "extrair",
    "extraíamos": "extrair",
    "extraías": "extrair",
    "extraída": "extrair",
    "extraídas": "extrair",
    "extraído": "extrair",
    "extraídos": "extrair",
    "extraíei": "extrair",
    "extraíeis": "extrair",
    "extraímo": "extrair",
    "extraímos": "extrair",
    "extraíra": "extrair",
    "extraíram": "extrair",
    "extraíramo": "extrair",
    "extraíramos": "extrair",
    "extraíras": "extrair",
    "extraíre": "extrair",
    "extraírei": "extrair",
    "extraíreis": "extrair",
    "extraírem": "extrair",
    "extraíres": "extrair",
    "extraís": "extrair",
    "extraísse": "extrair",
    "extraísseis": "extrair",
    "extraíssem": "extrair",
    "extraíssemos": "extrair",
    "extraísses": "extrair",
    "extraíste": "extrair",
    "extraístes": "extrair",
    "extraíveis": "extraível",
    "extrema": "extremo",
    "extremada": "extremar",
    "extremadas": "extremar",
    "extremado": "extremar",
    "extremados": "extremar",
    "extremai": "extremar",
    "extremais": "extremar",
    "extremam": "extremar",
    "extremamo": "extremar",
    "extremamos": "extremar",
    "extremando": "extremar",
    "extremara": "extremar",
    "extremaram": "extremar",
    "extremaras": "extremar",
    "extremarde": "extremar",
    "extremardes": "extremar",
    "extremare": "extremar",
    "extremarei": "extremar",
    "extremareis": "extremar",
    "extremarem": "extremar",
    "extremaremos": "extremar",
    "extremares": "extremar",
    "extremaria": "extremar",
    "extremariam": "extremar",
    "extremarias": "extremar",
    "extremarmo": "extremar",
    "extremarmos": "extremar",
    "extremará": "extremar",
    "extremarás": "extremar",
    "extremarão": "extremar",
    "extremaríamos": "extremar",
    "extremaríeis": "extremar",
    "extremas": "extremo",
    "extremasse": "extremar",
    "extremassem": "extremar",
    "extremasses": "extremar",
    "extremaste": "extremar",
    "extremastes": "extremar",
    "extremava": "extremar",
    "extremavam": "extremar",
    "extremavas": "extremar",
    "extreme": "extremar",
    "extremei": "extremar",
    "extremeis": "extremar",
    "extremem": "extremar",
    "extrememo": "extremar",
    "extrememos": "extremar",
    "extremes": "extremar",
    "extremidades": "extremidade",
    "extremismos": "extremismo",
    "extremistas": "extremista",
    "extremo": "extremar",
    "extremos": "extremo",
    "extremosa": "extremoso",
    "extremosas": "extremoso",
    "extremosos": "extremoso",
    "extremou": "extremar",
    "extremá": "extremar",
    "extremámo": "extremar",
    "extremámos": "extremar",
    "extremáramo": "extremar",
    "extremáramos": "extremar",
    "extremárei": "extremar",
    "extremáreis": "extremar",
    "extremásseis": "extremar",
    "extremássemos": "extremar",
    "extremávamo": "extremar",
    "extremávamos": "extremar",
    "extremávei": "extremar",
    "extremáveis": "extremável",
    "extrica": "extricar",
    "extricada": "extricar",
    "extricadas": "extricar",
    "extricado": "extricar",
    "extricados": "extricar",
    "extricai": "extricar",
    "extricais": "extricar",
    "extricam": "extricar",
    "extricamo": "extricar",
    "extricamos": "extricar",
    "extricando": "extricar",
    "extricara": "extricar",
    "extricaram": "extricar",
    "extricaras": "extricar",
    "extricarde": "extricar",
    "extricardes": "extricar",
    "extricare": "extricar",
    "extricarei": "extricar",
    "extricareis": "extricar",
    "extricarem": "extricar",
    "extricaremos": "extricar",
    "extricares": "extricar",
    "extricaria": "extricar",
    "extricariam": "extricar",
    "extricarias": "extricar",
    "extricarmo": "extricar",
    "extricarmos": "extricar",
    "extricará": "extricar",
    "extricarás": "extricar",
    "extricarão": "extricar",
    "extricaríamos": "extricar",
    "extricaríeis": "extricar",
    "extricas": "extricar",
    "extricasse": "extricar",
    "extricassem": "extricar",
    "extricasses": "extricar",
    "extricaste": "extricar",
    "extricastes": "extricar",
    "extricava": "extricar",
    "extricavam": "extricar",
    "extricavas": "extricar",
    "extrico": "extricar",
    "extricou": "extricar",
    "extricá": "extricar",
    "extricámo": "extricar",
    "extricámos": "extricar",
    "extricáramo": "extricar",
    "extricáramos": "extricar",
    "extricárei": "extricar",
    "extricáreis": "extricar",
    "extricásseis": "extricar",
    "extricássemos": "extricar",
    "extricávamo": "extricar",
    "extricávamos": "extricar",
    "extricávei": "extricar",
    "extricáveis": "extricar",
    "extrique": "extricar",
    "extriquei": "extricar",
    "extriqueis": "extricar",
    "extriquem": "extricar",
    "extriquemo": "extricar",
    "extriquemos": "extricar",
    "extriques": "extricar",
    "extrofias": "extrofia",
    "extrojectada": "extrojectado",
    "extrojectadas": "extrojectado",
    "extrojectados": "extrojectado",
    "extrojecções": "extrojecção",
    "extrorsa": "extrorso",
    "extrorsas": "extrorso",
    "extrorsos": "extrorso",
    "extrospectiva": "extrospectivo",
    "extrospectivas": "extrospectivo",
    "extrospectivos": "extrospectivo",
    "extrospecções": "extrospecção",
    "extroversões": "extroversão",
    "extrovertida": "extrovertido",
    "extrovertidas": "extrovertido",
    "extrovertidos": "extrovertido",
    "extrusiva": "extrusivo",
    "extrusivas": "extrusivo",
    "extrusivos": "extrusivo",
    "extrusões": "extrusão",
    "extrínseca": "extrínseco",
    "extrínsecas": "extrínseco",
    "extrínsecos": "extrínseco",
    "extrópica": "extrópico",
    "extrópicas": "extrópico",
    "extrópicos": "extrópico",
    "exturca": "extorquir",
    "exturcais": "extorquir",
    "exturcam": "extorquir",
    "exturcamo": "extorquir",
    "exturcamos": "extorquir",
    "exturcas": "extorquir",
    "exturco": "extorquir",
    "exturque": "extorquir",
    "exturquem": "extorquir",
    "exturques": "extorquir",
    "extática": "extático",
    "extáticas": "extático",
    "extáticos": "extático",
    "extíspices": "extíspice",
    "exubera": "exuberar",
    "exuberada": "exuberar",
    "exuberadas": "exuberar",
    "exuberado": "exuberar",
    "exuberados": "exuberar",
    "exuberai": "exuberar",
    "exuberais": "exuberar",
    "exuberam": "exuberar",
    "exuberamo": "exuberar",
    "exuberamos": "exuberar",
    "exuberando": "exuberar",
    "exuberantes": "exuberante",
    "exuberara": "exuberar",
    "exuberaram": "exuberar",
    "exuberaras": "exuberar",
    "exuberardes": "exuberar",
    "exuberarei": "exuberar",
    "exuberareis": "exuberar",
    "exuberarem": "exuberar",
    "exuberaremos": "exuberar",
    "exuberares": "exuberar",
    "exuberaria": "exuberar",
    "exuberariam": "exuberar",
    "exuberarias": "exuberar",
    "exuberarmo": "exuberar",
    "exuberarmos": "exuberar",
    "exuberará": "exuberar",
    "exuberarás": "exuberar",
    "exuberarão": "exuberar",
    "exuberaríamos": "exuberar",
    "exuberaríeis": "exuberar",
    "exuberas": "exuberar",
    "exuberasse": "exuberar",
    "exuberassem": "exuberar",
    "exuberasses": "exuberar",
    "exuberaste": "exuberar",
    "exuberastes": "exuberar",
    "exuberava": "exuberar",
    "exuberavam": "exuberar",
    "exuberavas": "exuberar",
    "exubere": "exuberar",
    "exuberei": "exuberar",
    "exubereis": "exuberar",
    "exuberem": "exuberar",
    "exuberemo": "exuberar",
    "exuberemos": "exuberar",
    "exuberes": "exuberar",
    "exubero": "exuberar",
    "exuberou": "exuberar",
    "exuberámo": "exuberar",
    "exuberámos": "exuberar",
    "exuberáramo": "exuberar",
    "exuberáramos": "exuberar",
    "exuberáreis": "exuberar",
    "exuberásseis": "exuberar",
    "exuberássemos": "exuberar",
    "exuberávamo": "exuberar",
    "exuberávamos": "exuberar",
    "exuberáveis": "exuberar",
    "exuberâncias": "exuberância",
    "exula": "exular",
    "exulada": "exular",
    "exuladas": "exular",
    "exulado": "exular",
    "exulados": "exular",
    "exulai": "exular",
    "exulais": "exular",
    "exulam": "exular",
    "exulamo": "exular",
    "exulamos": "exular",
    "exulando": "exular",
    "exulara": "exular",
    "exularam": "exular",
    "exularas": "exular",
    "exulardes": "exular",
    "exularei": "exular",
    "exulareis": "exular",
    "exularem": "exular",
    "exularemos": "exular",
    "exulares": "exular",
    "exularia": "exular",
    "exulariam": "exular",
    "exularias": "exular",
    "exularmo": "exular",
    "exularmos": "exular",
    "exulará": "exular",
    "exularás": "exular",
    "exularão": "exular",
    "exularíamos": "exular",
    "exularíeis": "exular",
    "exulas": "exular",
    "exulasse": "exular",
    "exulassem": "exular",
    "exulasses": "exular",
    "exulaste": "exular",
    "exulastes": "exular",
    "exulava": "exular",
    "exulavam": "exular",
    "exulavas": "exular",
    "exulcera": "exulcerar",
    "exulcerada": "exulcerar",
    "exulceradas": "exulcerar",
    "exulcerado": "exulcerar",
    "exulcerados": "exulcerar",
    "exulcerai": "exulcerar",
    "exulcerais": "exulcerar",
    "exulceram": "exulcerar",
    "exulceramo": "exulcerar",
    "exulceramos": "exulcerar",
    "exulcerando": "exulcerar",
    "exulcerantes": "exulcerante",
    "exulcerara": "exulcerar",
    "exulceraram": "exulcerar",
    "exulceraras": "exulcerar",
    "exulcerarde": "exulcerar",
    "exulcerardes": "exulcerar",
    "exulcerare": "exulcerar",
    "exulcerarei": "exulcerar",
    "exulcerareis": "exulcerar",
    "exulcerarem": "exulcerar",
    "exulceraremos": "exulcerar",
    "exulcerares": "exulcerar",
    "exulceraria": "exulcerar",
    "exulcerariam": "exulcerar",
    "exulcerarias": "exulcerar",
    "exulcerarmo": "exulcerar",
    "exulcerarmos": "exulcerar",
    "exulcerará": "exulcerar",
    "exulcerarás": "exulcerar",
    "exulcerarão": "exulcerar",
    "exulceraríamos": "exulcerar",
    "exulceraríeis": "exulcerar",
    "exulceras": "exulcerar",
    "exulcerasse": "exulcerar",
    "exulcerassem": "exulcerar",
    "exulcerasses": "exulcerar",
    "exulceraste": "exulcerar",
    "exulcerastes": "exulcerar",
    "exulcerativa": "exulcerativo",
    "exulcerativas": "exulcerativo",
    "exulcerativos": "exulcerativo",
    "exulcerava": "exulcerar",
    "exulceravam": "exulcerar",
    "exulceravas": "exulcerar",
    "exulcerações": "exulceração",
    "exulcere": "exulcerar",
    "exulcerei": "exulcerar",
    "exulcereis": "exulcerar",
    "exulcerem": "exulcerar",
    "exulceremo": "exulcerar",
    "exulceremos": "exulcerar",
    "exulceres": "exulcerar",
    "exulcero": "exulcerar",
    "exulcerou": "exulcerar",
    "exulcerá": "exulcerar",
    "exulcerámo": "exulcerar",
    "exulcerámos": "exulcerar",
    "exulceráramo": "exulcerar",
    "exulceráramos": "exulcerar",
    "exulcerárei": "exulcerar",
    "exulceráreis": "exulcerar",
    "exulcerásseis": "exulcerar",
    "exulcerássemos": "exulcerar",
    "exulcerávamo": "exulcerar",
    "exulcerávamos": "exulcerar",
    "exulcerávei": "exulcerar",
    "exulceráveis": "exulcerar",
    "exule": "exular",
    "exulei": "exular",
    "exuleis": "exular",
    "exulem": "exular",
    "exulemo": "exular",
    "exulemos": "exular",
    "exules": "exule",
    "exulo": "exular",
    "exulou": "exular",
    "exulta": "exultar",
    "exultada": "exultar",
    "exultadas": "exultar",
    "exultado": "exultar",
    "exultados": "exultar",
    "exultai": "exultar",
    "exultais": "exultar",
    "exultam": "exultar",
    "exultamo": "exultar",
    "exultamos": "exultar",
    "exultando": "exultar",
    "exultantes": "exultante",
    "exultara": "exultar",
    "exultaram": "exultar",
    "exultaras": "exultar",
    "exultardes": "exultar",
    "exultarei": "exultar",
    "exultareis": "exultar",
    "exultarem": "exultar",
    "exultaremos": "exultar",
    "exultares": "exultar",
    "exultaria": "exultar",
    "exultariam": "exultar",
    "exultarias": "exultar",
    "exultarmo": "exultar",
    "exultarmos": "exultar",
    "exultará": "exultar",
    "exultarás": "exultar",
    "exultarão": "exultar",
    "exultaríamos": "exultar",
    "exultaríeis": "exultar",
    "exultas": "exultar",
    "exultasse": "exultar",
    "exultassem": "exultar",
    "exultasses": "exultar",
    "exultaste": "exultar",
    "exultastes": "exultar",
    "exultava": "exultar",
    "exultavam": "exultar",
    "exultavas": "exultar",
    "exultações": "exultação",
    "exulte": "exultar",
    "exultei": "exultar",
    "exulteis": "exultar",
    "exultem": "exultar",
    "exultemo": "exultar",
    "exultemos": "exultar",
    "exultes": "exultar",
    "exulto": "exultar",
    "exultou": "exultar",
    "exultámo": "exultar",
    "exultámos": "exultar",
    "exultáramo": "exultar",
    "exultáramos": "exultar",
    "exultáreis": "exultar",
    "exultásseis": "exultar",
    "exultássemos": "exultar",
    "exultávamo": "exultar",
    "exultávamos": "exultar",
    "exultáveis": "exultar",
    "exulámo": "exular",
    "exulámos": "exular",
    "exuláramo": "exular",
    "exuláramos": "exular",
    "exuláreis": "exular",
    "exulásseis": "exular",
    "exulássemos": "exular",
    "exulávamo": "exular",
    "exulávamos": "exular",
    "exuláveis": "exular",
    "exuma": "exumar",
    "exumada": "exumar",
    "exumadas": "exumar",
    "exumado": "exumar",
    "exumados": "exumar",
    "exumai": "exumar",
    "exumais": "exumar",
    "exumam": "exumar",
    "exumamo": "exumar",
    "exumamos": "exumar",
    "exumando": "exumar",
    "exumara": "exumar",
    "exumaram": "exumar",
    "exumaras": "exumar",
    "exumarde": "exumar",
    "exumardes": "exumar",
    "exumare": "exumar",
    "exumarei": "exumar",
    "exumareis": "exumar",
    "exumarem": "exumar",
    "exumaremos": "exumar",
    "exumares": "exumar",
    "exumaria": "exumar",
    "exumariam": "exumar",
    "exumarias": "exumar",
    "exumarmo": "exumar",
    "exumarmos": "exumar",
    "exumará": "exumar",
    "exumarás": "exumar",
    "exumarão": "exumar",
    "exumaríamos": "exumar",
    "exumaríeis": "exumar",
    "exumas": "exumar",
    "exumasse": "exumar",
    "exumassem": "exumar",
    "exumasses": "exumar",
    "exumaste": "exumar",
    "exumastes": "exumar",
    "exumava": "exumar",
    "exumavam": "exumar",
    "exumavas": "exumar",
    "exumações": "exumação",
    "exume": "exumar",
    "exumei": "exumar",
    "exumeis": "exumar",
    "exumem": "exumar",
    "exumemo": "exumar",
    "exumemos": "exumar",
    "exumes": "exumar",
    "exumo": "exumar",
    "exumou": "exumar",
    "exumá": "exumar",
    "exumámo": "exumar",
    "exumámos": "exumar",
    "exumáramo": "exumar",
    "exumáramos": "exumar",
    "exumárei": "exumar",
    "exumáreis": "exumar",
    "exumásseis": "exumar",
    "exumássemos": "exumar",
    "exumávamo": "exumar",
    "exumávamos": "exumar",
    "exumávei": "exumar",
    "exumáveis": "exumável",
    "exunda": "exundar",
    "exundada": "exundar",
    "exundadas": "exundar",
    "exundado": "exundar",
    "exundados": "exundar",
    "exundai": "exundar",
    "exundais": "exundar",
    "exundam": "exundar",
    "exundamo": "exundar",
    "exundamos": "exundar",
    "exundando": "exundar",
    "exundara": "exundar",
    "exundaram": "exundar",
    "exundaras": "exundar",
    "exundardes": "exundar",
    "exundarei": "exundar",
    "exundareis": "exundar",
    "exundarem": "exundar",
    "exundaremos": "exundar",
    "exundares": "exundar",
    "exundaria": "exundar",
    "exundariam": "exundar",
    "exundarias": "exundar",
    "exundarmo": "exundar",
    "exundarmos": "exundar",
    "exundará": "exundar",
    "exundarás": "exundar",
    "exundarão": "exundar",
    "exundaríamos": "exundar",
    "exundaríeis": "exundar",
    "exundas": "exundar",
    "exundasse": "exundar",
    "exundassem": "exundar",
    "exundasses": "exundar",
    "exundaste": "exundar",
    "exundastes": "exundar",
    "exundava": "exundar",
    "exundavam": "exundar",
    "exundavas": "exundar",
    "exunde": "exundar",
    "exundei": "exundar",
    "exundeis": "exundar",
    "exundem": "exundar",
    "exundemo": "exundar",
    "exundemos": "exundar",
    "exundes": "exundar",
    "exundo": "exundar",
    "exundou": "exundar",
    "exundámo": "exundar",
    "exundámos": "exundar",
    "exundáramo": "exundar",
    "exundáramos": "exundar",
    "exundáreis": "exundar",
    "exundásseis": "exundar",
    "exundássemos": "exundar",
    "exundávamo": "exundar",
    "exundávamos": "exundar",
    "exundáveis": "exundar",
    "exus": "exul",
    "exuviabilidades": "exuviabilidade",
    "exuviáveis": "exuviável",
    "exânima": "exânimo",
    "exânimas": "exânimo",
    "exânimos": "exânimo",
    "exérases": "exérase",
    "exércitos": "exército",
    "exéreses": "exérese",
    "exícios": "exício",
    "exígua": "exíguo",
    "exíguas": "exíguo",
    "exíguos": "exíguo",
    "exílios": "exílio",
    "exímia": "exímio",
    "exímias": "exímio",
    "exímios": "exímio",
    "exócrina": "exócrino",
    "exócrinas": "exócrino",
    "exócrinos": "exócrino",
    "exódica": "exódico",
    "exódicas": "exódico",
    "exódicos": "exódico",
    "exógama": "exógamo",
    "exógamas": "exógamo",
    "exógamos": "exógamo",
    "exógena": "exógeno",
    "exógenas": "exógeno",
    "exógenos": "exógeno",
    "exógina": "exógino",
    "exóginas": "exógino",
    "exóginos": "exógino",
    "exómetras": "exómetra",
    "exópodes": "exópode",
    "exórdios": "exórdio",
    "exóspora": "exósporo",
    "exósporas": "exósporo",
    "exósporos": "exósporo",
    "exótica": "exótico",
    "exóticas": "exótico",
    "exóticos": "exótico",
    "exônfala": "exônfalo",
    "exônfalas": "exônfalo",
    "exônfalos": "exônfalo",
    "exúberes": "exúbere",
    "exúvias": "exúvia",
    "exúvios": "exúvio",
    "eólia": "eólio",
    "eólias": "eólio",
    "eólica": "eólico",
    "eólicas": "eólico",
    "eólicos": "eólico",
    "eólios": "eólio",
    "fabagelas": "fabagela",
    "fabelas": "fabela",
    "fabiana": "fabiano",
    "fabianas": "fabiano",
    "fabianos": "fabiano",
    "fabordões": "fabordão",
    "fabrica": "fabricar",
    "fabricada": "fabricar",
    "fabricadas": "fabricar",
    "fabricado": "fabricar",
    "fabricadora": "fabricador",
    "fabricadoras": "fabricador",
    "fabricadores": "fabricador",
    "fabricados": "fabricar",
    "fabricai": "fabricar",
    "fabricais": "fabricar",
    "fabricam": "fabricar",
    "fabricamo": "fabricar",
    "fabricamos": "fabricar",
    "fabricanda": "fabricando",
    "fabricandas": "fabricando",
    "fabricando": "fabricar",
    "fabricandos": "fabricando",
    "fabricantes": "fabricante",
    "fabricara": "fabricar",
    "fabricaram": "fabricar",
    "fabricaras": "fabricar",
    "fabricarde": "fabricar",
    "fabricardes": "fabricar",
    "fabricare": "fabricar",
    "fabricarei": "fabricar",
    "fabricareis": "fabricar",
    "fabricarem": "fabricar",
    "fabricaremos": "fabricar",
    "fabricares": "fabricar",
    "fabricaria": "fabricar",
    "fabricariam": "fabricar",
    "fabricarias": "fabricar",
    "fabricarmo": "fabricar",
    "fabricarmos": "fabricar",
    "fabricará": "fabricar",
    "fabricarás": "fabricar",
    "fabricarão": "fabricar",
    "fabricaríamos": "fabricar",
    "fabricaríeis": "fabricar",
    "fabricas": "fabricar",
    "fabricasse": "fabricar",
    "fabricassem": "fabricar",
    "fabricasses": "fabricar",
    "fabricaste": "fabricar",
    "fabricastes": "fabricar",
    "fabricava": "fabricar",
    "fabricavam": "fabricar",
    "fabricavas": "fabricar",
    "fabricações": "fabricação",
    "fabrico": "fabricar",
    "fabricos": "fabrico",
    "fabricou": "fabricar",
    "fabricá": "fabricar",
    "fabricámo": "fabricar",
    "fabricámos": "fabricar",
    "fabricáramo": "fabricar",
    "fabricáramos": "fabricar",
    "fabricárei": "fabricar",
    "fabricáreis": "fabricar",
    "fabricásseis": "fabricar",
    "fabricássemos": "fabricar",
    "fabricávamo": "fabricar",
    "fabricávamos": "fabricar",
    "fabricávei": "fabricar",
    "fabricáveis": "fabricável",
    "fabriformes": "fabriforme",
    "fabrique": "fabricar",
    "fabriquei": "fabricar",
    "fabriqueira": "fabriqueiro",
    "fabriqueiras": "fabriqueiro",
    "fabriqueiros": "fabriqueiro",
    "fabriqueis": "fabricar",
    "fabriquem": "fabricar",
    "fabriquemo": "fabricar",
    "fabriquemos": "fabricar",
    "fabriques": "fabricar",
    "fabriquetas": "fabriqueta",
    "fabris": "fabril",
    "fabula": "fabular",
    "fabulada": "fabular",
    "fabuladas": "fabular",
    "fabulado": "fabular",
    "fabuladora": "fabulador",
    "fabuladoras": "fabulador",
    "fabuladores": "fabulador",
    "fabulados": "fabular",
    "fabulai": "fabular",
    "fabulais": "fabular",
    "fabulam": "fabular",
    "fabulamo": "fabular",
    "fabulamos": "fabular",
    "fabulando": "fabular",
    "fabulara": "fabular",
    "fabularam": "fabular",
    "fabularas": "fabular",
    "fabularde": "fabular",
    "fabulardes": "fabular",
    "fabulare": "fabular",
    "fabularei": "fabular",
    "fabulareis": "fabular",
    "fabularem": "fabular",
    "fabularemos": "fabular",
    "fabulares": "fabular",
    "fabularia": "fabular",
    "fabulariam": "fabular",
    "fabularias": "fabular",
    "fabularmo": "fabular",
    "fabularmos": "fabular",
    "fabulará": "fabular",
    "fabularás": "fabular",
    "fabularão": "fabular",
    "fabularíamos": "fabular",
    "fabularíeis": "fabular",
    "fabulas": "fabular",
    "fabulasse": "fabular",
    "fabulassem": "fabular",
    "fabulasses": "fabular",
    "fabulaste": "fabular",
    "fabulastes": "fabular",
    "fabulava": "fabular",
    "fabulavam": "fabular",
    "fabulavas": "fabular",
    "fabule": "fabular",
    "fabulei": "fabular",
    "fabuleis": "fabular",
    "fabulem": "fabular",
    "fabulemo": "fabular",
    "fabulemos": "fabular",
    "fabules": "fabular",
    "fabulistas": "fabulista",
    "fabuliza": "fabulizar",
    "fabulizada": "fabulizar",
    "fabulizadas": "fabulizar",
    "fabulizado": "fabulizar",
    "fabulizados": "fabulizar",
    "fabulizai": "fabulizar",
    "fabulizais": "fabulizar",
    "fabulizam": "fabulizar",
    "fabulizamo": "fabulizar",
    "fabulizamos": "fabulizar",
    "fabulizando": "fabulizar",
    "fabulizara": "fabulizar",
    "fabulizaram": "fabulizar",
    "fabulizaras": "fabulizar",
    "fabulizarde": "fabulizar",
    "fabulizardes": "fabulizar",
    "fabulizare": "fabulizar",
    "fabulizarei": "fabulizar",
    "fabulizareis": "fabulizar",
    "fabulizarem": "fabulizar",
    "fabulizaremos": "fabulizar",
    "fabulizares": "fabulizar",
    "fabulizaria": "fabulizar",
    "fabulizariam": "fabulizar",
    "fabulizarias": "fabulizar",
    "fabulizarmo": "fabulizar",
    "fabulizarmos": "fabulizar",
    "fabulizará": "fabulizar",
    "fabulizarás": "fabulizar",
    "fabulizarão": "fabulizar",
    "fabulizaríamos": "fabulizar",
    "fabulizaríeis": "fabulizar",
    "fabulizas": "fabulizar",
    "fabulizasse": "fabulizar",
    "fabulizassem": "fabulizar",
    "fabulizasses": "fabulizar",
    "fabulizaste": "fabulizar",
    "fabulizastes": "fabulizar",
    "fabulizava": "fabulizar",
    "fabulizavam": "fabulizar",
    "fabulizavas": "fabulizar",
    "fabulize": "fabulizar",
    "fabulizei": "fabulizar",
    "fabulizeis": "fabulizar",
    "fabulizem": "fabulizar",
    "fabulizemo": "fabulizar",
    "fabulizemos": "fabulizar",
    "fabulizes": "fabulizar",
    "fabulizo": "fabulizar",
    "fabulizou": "fabulizar",
    "fabulizá": "fabulizar",
    "fabulizámo": "fabulizar",
    "fabulizámos": "fabulizar",
    "fabulizáramo": "fabulizar",
    "fabulizáramos": "fabulizar",
    "fabulizárei": "fabulizar",
    "fabulizáreis": "fabulizar",
    "fabulizásseis": "fabulizar",
    "fabulizássemos": "fabulizar",
    "fabulizávamo": "fabulizar",
    "fabulizávamos": "fabulizar",
    "fabulizávei": "fabulizar",
    "fabulizáveis": "fabulizar",
    "fabulo": "fabular",
    "fabulosa": "fabuloso",
    "fabulosas": "fabuloso",
    "fabulosos": "fabuloso",
    "fabulou": "fabular",
    "fabulá": "fabular",
    "fabulámo": "fabular",
    "fabulámos": "fabular",
    "fabuláramo": "fabular",
    "fabuláramos": "fabular",
    "fabulárei": "fabular",
    "fabuláreis": "fabular",
    "fabulários": "fabulário",
    "fabulásseis": "fabular",
    "fabulássemos": "fabular",
    "fabulávamo": "fabular",
    "fabulávamos": "fabular",
    "fabulávei": "fabular",
    "fabuláveis": "fabular",
    "facadas": "facada",
    "facadinha": "facada",
    "facadinhas": "facada",
    "facadita": "facada",
    "facaditas": "facada",
    "facalhazes": "facalhaz",
    "facalhões": "facalhão",
    "facaneias": "facaneia",
    "facas": "faca",
    "facazinha": "faca",
    "facazinhas": "faca",
    "facazita": "faca",
    "facazitas": "faca",
    "facciona": "faccionar",
    "faccionada": "faccionar",
    "faccionadas": "faccionar",
    "faccionado": "faccionar",
    "faccionados": "faccionar",
    "faccionai": "faccionar",
    "faccionais": "faccionar",
    "faccionam": "faccionar",
    "faccionamo": "faccionar",
    "faccionamos": "faccionar",
    "faccionando": "faccionar",
    "faccionara": "faccionar",
    "faccionaram": "faccionar",
    "faccionaras": "faccionar",
    "faccionarde": "faccionar",
    "faccionardes": "faccionar",
    "faccionare": "faccionar",
    "faccionarei": "faccionar",
    "faccionareis": "faccionar",
    "faccionarem": "faccionar",
    "faccionaremos": "faccionar",
    "faccionares": "faccionar",
    "faccionaria": "faccionar",
    "faccionariam": "faccionar",
    "faccionarias": "faccionar",
    "faccionarmo": "faccionar",
    "faccionarmos": "faccionar",
    "faccionará": "faccionar",
    "faccionarás": "faccionar",
    "faccionarão": "faccionar",
    "faccionaríamos": "faccionar",
    "faccionaríeis": "faccionar",
    "faccionas": "faccionar",
    "faccionasse": "faccionar",
    "faccionassem": "faccionar",
    "faccionasses": "faccionar",
    "faccionaste": "faccionar",
    "faccionastes": "faccionar",
    "faccionava": "faccionar",
    "faccionavam": "faccionar",
    "faccionavas": "faccionar",
    "faccione": "faccionar",
    "faccionei": "faccionar",
    "faccioneis": "faccionar",
    "faccionem": "faccionar",
    "faccionemo": "faccionar",
    "faccionemos": "faccionar",
    "facciones": "faccionar",
    "facciono": "faccionar",
    "faccionou": "faccionar",
    "faccioná": "faccionar",
    "faccionámo": "faccionar",
    "faccionámos": "faccionar",
    "faccionáramo": "faccionar",
    "faccionáramos": "faccionar",
    "faccionárei": "faccionar",
    "faccionáreis": "faccionar",
    "faccionária": "faccionário",
    "faccionárias": "faccionário",
    "faccionários": "faccionário",
    "faccionásseis": "faccionar",
    "faccionássemos": "faccionar",
    "faccionávamo": "faccionar",
    "faccionávamos": "faccionar",
    "faccionávei": "faccionar",
    "faccionáveis": "faccionar",
    "facciosa": "faccioso",
    "facciosas": "faccioso",
    "facciosidades": "facciosidade",
    "facciosismos": "facciosismo",
    "facciosos": "faccioso",
    "faceada": "facear",
    "faceadas": "facear",
    "faceado": "facear",
    "faceados": "facear",
    "faceai": "facear",
    "faceais": "facear",
    "faceamo": "facear",
    "faceamos": "facear",
    "faceando": "facear",
    "faceara": "facear",
    "facearam": "facear",
    "facearas": "facear",
    "facearde": "facear",
    "faceardes": "facear",
    "faceare": "facear",
    "facearei": "facear",
    "faceareis": "facear",
    "facearem": "facear",
    "facearemos": "facear",
    "faceares": "facear",
    "facearia": "facear",
    "faceariam": "facear",
    "facearias": "facear",
    "facearmo": "facear",
    "facearmos": "facear",
    "faceará": "facear",
    "facearás": "facear",
    "facearão": "facear",
    "facearíamos": "facear",
    "facearíeis": "facear",
    "faceasse": "facear",
    "faceassem": "facear",
    "faceasses": "facear",
    "faceaste": "facear",
    "faceastes": "facear",
    "faceava": "facear",
    "faceavam": "facear",
    "faceavas": "facear",
    "faceciosa": "facecioso",
    "faceciosas": "facecioso",
    "faceciosos": "facecioso",
    "faceei": "facear",
    "faceeis": "facear",
    "faceemo": "facear",
    "faceemos": "facear",
    "faceia": "facear",
    "faceiam": "facear",
    "faceias": "facear",
    "faceie": "facear",
    "faceiem": "facear",
    "faceies": "facear",
    "faceio": "facear",
    "faceira": "faceiro",
    "faceirada": "faceirar",
    "faceiradas": "faceirar",
    "faceirado": "faceirar",
    "faceirados": "faceirar",
    "faceirai": "faceirar",
    "faceirais": "faceirar",
    "faceiram": "faceirar",
    "faceiramo": "faceirar",
    "faceiramos": "faceirar",
    "faceirando": "faceirar",
    "faceirara": "faceirar",
    "faceiraram": "faceirar",
    "faceiraras": "faceirar",
    "faceirardes": "faceirar",
    "faceirarei": "faceirar",
    "faceirareis": "faceirar",
    "faceirarem": "faceirar",
    "faceiraremos": "faceirar",
    "faceirares": "faceirar",
    "faceiraria": "faceirar",
    "faceirariam": "faceirar",
    "faceirarias": "faceirar",
    "faceirarmo": "faceirar",
    "faceirarmos": "faceirar",
    "faceirará": "faceirar",
    "faceirarás": "faceirar",
    "faceirarão": "faceirar",
    "faceiraríamos": "faceirar",
    "faceiraríeis": "faceirar",
    "faceiras": "faceiro",
    "faceirasse": "faceirar",
    "faceirassem": "faceirar",
    "faceirasses": "faceirar",
    "faceiraste": "faceirar",
    "faceirastes": "faceirar",
    "faceirava": "faceirar",
    "faceiravam": "faceirar",
    "faceiravas": "faceirar",
    "faceire": "faceirar",
    "faceirei": "faceirar",
    "faceireis": "faceirar",
    "faceirem": "faceirar",
    "faceiremo": "faceirar",
    "faceiremos": "faceirar",
    "faceires": "faceirar",
    "faceirices": "faceirice",
    "faceiro": "faceirar",
    "faceiros": "faceiro",
    "faceirou": "faceirar",
    "faceirámo": "faceirar",
    "faceirámos": "faceirar",
    "faceiráramo": "faceirar",
    "faceiráramos": "faceirar",
    "faceiráreis": "faceirar",
    "faceirásseis": "faceirar",
    "faceirássemos": "faceirar",
    "faceirávamo": "faceirar",
    "faceirávamos": "faceirar",
    "faceiráveis": "faceirar",
    "faceja": "facejar",
    "facejada": "facejar",
    "facejadas": "facejar",
    "facejado": "facejar",
    "facejados": "facejar",
    "facejai": "facejar",
    "facejais": "facejar",
    "facejam": "facejar",
    "facejamo": "facejar",
    "facejamos": "facejar",
    "facejando": "facejar",
    "facejara": "facejar",
    "facejaram": "facejar",
    "facejaras": "facejar",
    "facejarde": "facejar",
    "facejardes": "facejar",
    "facejare": "facejar",
    "facejarei": "facejar",
    "facejareis": "facejar",
    "facejarem": "facejar",
    "facejaremos": "facejar",
    "facejares": "facejar",
    "facejaria": "facejar",
    "facejariam": "facejar",
    "facejarias": "facejar",
    "facejarmo": "facejar",
    "facejarmos": "facejar",
    "facejará": "facejar",
    "facejarás": "facejar",
    "facejarão": "facejar",
    "facejaríamos": "facejar",
    "facejaríeis": "facejar",
    "facejas": "facejar",
    "facejasse": "facejar",
    "facejassem": "facejar",
    "facejasses": "facejar",
    "facejaste": "facejar",
    "facejastes": "facejar",
    "facejava": "facejar",
    "facejavam": "facejar",
    "facejavas": "facejar",
    "faceje": "facejar",
    "facejei": "facejar",
    "facejeis": "facejar",
    "facejem": "facejar",
    "facejemo": "facejar",
    "facejemos": "facejar",
    "facejes": "facejar",
    "facejo": "facejar",
    "facejou": "facejar",
    "facejá": "facejar",
    "facejámo": "facejar",
    "facejámos": "facejar",
    "facejáramo": "facejar",
    "facejáramos": "facejar",
    "facejárei": "facejar",
    "facejáreis": "facejar",
    "facejásseis": "facejar",
    "facejássemos": "facejar",
    "facejávamo": "facejar",
    "facejávamos": "facejar",
    "facejávei": "facejar",
    "facejáveis": "facejar",
    "faceou": "facear",
    "faces": "face",
    "faceta": "faceto",
    "facetada": "facetado",
    "facetadas": "facetado",
    "facetados": "facetado",
    "facetas": "faceto",
    "faceteada": "facetear",
    "faceteadas": "facetear",
    "faceteado": "facetear",
    "faceteados": "facetear",
    "faceteai": "facetear",
    "faceteais": "facetear",
    "faceteamo": "facetear",
    "faceteamos": "facetear",
    "faceteando": "facetear",
    "faceteara": "facetear",
    "facetearam": "facetear",
    "facetearas": "facetear",
    "faceteardes": "facetear",
    "facetearei": "facetear",
    "faceteareis": "facetear",
    "facetearem": "facetear",
    "facetearemos": "facetear",
    "faceteares": "facetear",
    "facetearia": "facetear",
    "faceteariam": "facetear",
    "facetearias": "facetear",
    "facetearmo": "facetear",
    "facetearmos": "facetear",
    "faceteará": "facetear",
    "facetearás": "facetear",
    "facetearão": "facetear",
    "facetearíamos": "facetear",
    "facetearíeis": "facetear",
    "faceteasse": "facetear",
    "faceteassem": "facetear",
    "faceteasses": "facetear",
    "faceteaste": "facetear",
    "faceteastes": "facetear",
    "faceteava": "facetear",
    "faceteavam": "facetear",
    "faceteavas": "facetear",
    "faceteei": "facetear",
    "faceteeis": "facetear",
    "faceteemo": "facetear",
    "faceteemos": "facetear",
    "faceteia": "facetear",
    "faceteiam": "facetear",
    "faceteias": "facetear",
    "faceteie": "facetear",
    "faceteiem": "facetear",
    "faceteies": "facetear",
    "faceteio": "facetear",
    "faceteou": "facetear",
    "faceteámo": "facetear",
    "faceteámos": "facetear",
    "faceteáramo": "facetear",
    "faceteáramos": "facetear",
    "faceteáreis": "facetear",
    "faceteásseis": "facetear",
    "faceteássemos": "facetear",
    "faceteávamo": "facetear",
    "faceteávamos": "facetear",
    "faceteáveis": "facetear",
    "facetos": "faceto",
    "facezinha": "face",
    "facezinhas": "face",
    "facezita": "face",
    "facezitas": "face",
    "faceá": "facear",
    "faceámo": "facear",
    "faceámos": "facear",
    "faceáramo": "facear",
    "faceáramos": "facear",
    "faceárei": "facear",
    "faceáreis": "facear",
    "faceásseis": "facear",
    "faceássemos": "facear",
    "faceávamo": "facear",
    "faceávamos": "facear",
    "faceávei": "facear",
    "faceáveis": "facear",
    "facha": "facho",
    "fachadas": "fachada",
    "fachas": "facho",
    "facheada": "fachear",
    "facheadas": "fachear",
    "facheado": "fachear",
    "facheados": "fachear",
    "facheai": "fachear",
    "facheais": "fachear",
    "facheamo": "fachear",
    "facheamos": "fachear",
    "facheando": "fachear",
    "facheara": "fachear",
    "fachearam": "fachear",
    "fachearas": "fachear",
    "fachearde": "fachear",
    "facheardes": "fachear",
    "facheare": "fachear",
    "fachearei": "fachear",
    "facheareis": "fachear",
    "fachearem": "fachear",
    "fachearemos": "fachear",
    "facheares": "fachear",
    "fachearia": "fachear",
    "facheariam": "fachear",
    "fachearias": "fachear",
    "fachearmo": "fachear",
    "fachearmos": "fachear",
    "facheará": "fachear",
    "fachearás": "fachear",
    "fachearão": "fachear",
    "fachearíamos": "fachear",
    "fachearíeis": "fachear",
    "facheasse": "fachear",
    "facheassem": "fachear",
    "facheasses": "fachear",
    "facheaste": "fachear",
    "facheastes": "fachear",
    "facheava": "fachear",
    "facheavam": "fachear",
    "facheavas": "fachear",
    "facheei": "fachear",
    "facheeis": "fachear",
    "facheemo": "fachear",
    "facheemos": "fachear",
    "facheia": "fachear",
    "facheiam": "fachear",
    "facheias": "fachear",
    "facheie": "fachear",
    "facheiem": "fachear",
    "facheies": "fachear",
    "facheio": "fachear",
    "facheira": "facheiro",
    "facheiras": "facheiro",
    "facheiros": "facheiro",
    "facheou": "fachear",
    "facheá": "fachear",
    "facheámo": "fachear",
    "facheámos": "fachear",
    "facheáramo": "fachear",
    "facheáramos": "fachear",
    "facheárei": "fachear",
    "facheáreis": "fachear",
    "facheásseis": "fachear",
    "facheássemos": "fachear",
    "facheávamo": "fachear",
    "facheávamos": "fachear",
    "facheávei": "fachear",
    "facheáveis": "fachear",
    "fachocas": "fachoca",
    "fachoqueira": "fachoqueiro",
    "fachoqueiras": "fachoqueiro",
    "fachoqueiros": "fachoqueiro",
    "fachos": "facho",
    "fachuda": "fachudo",
    "fachudas": "fachudo",
    "fachudos": "fachudo",
    "faciais": "facial",
    "faciendas": "facienda",
    "facilidades": "facilidade",
    "facilita": "facilitar",
    "facilitada": "facilitar",
    "facilitadas": "facilitar",
    "facilitado": "facilitar",
    "facilitadora": "facilitador",
    "facilitadoras": "facilitador",
    "facilitadores": "facilitador",
    "facilitados": "facilitar",
    "facilitai": "facilitar",
    "facilitais": "facilitar",
    "facilitam": "facilitar",
    "facilitamo": "facilitar",
    "facilitamos": "facilitar",
    "facilitando": "facilitar",
    "facilitara": "facilitar",
    "facilitaram": "facilitar",
    "facilitaras": "facilitar",
    "facilitarde": "facilitar",
    "facilitardes": "facilitar",
    "facilitare": "facilitar",
    "facilitarei": "facilitar",
    "facilitareis": "facilitar",
    "facilitarem": "facilitar",
    "facilitaremos": "facilitar",
    "facilitares": "facilitar",
    "facilitaria": "facilitar",
    "facilitariam": "facilitar",
    "facilitarias": "facilitar",
    "facilitarmo": "facilitar",
    "facilitarmos": "facilitar",
    "facilitará": "facilitar",
    "facilitarás": "facilitar",
    "facilitarão": "facilitar",
    "facilitaríamos": "facilitar",
    "facilitaríeis": "facilitar",
    "facilitas": "facilitar",
    "facilitasse": "facilitar",
    "facilitassem": "facilitar",
    "facilitasses": "facilitar",
    "facilitaste": "facilitar",
    "facilitastes": "facilitar",
    "facilitava": "facilitar",
    "facilitavam": "facilitar",
    "facilitavas": "facilitar",
    "facilitações": "facilitação",
    "facilite": "facilitar",
    "facilitei": "facilitar",
    "faciliteis": "facilitar",
    "facilitem": "facilitar",
    "facilitemo": "facilitar",
    "facilitemos": "facilitar",
    "facilites": "facilitar",
    "facilitismos": "facilitismo",
    "facilito": "facilitar",
    "facilitou": "facilitar",
    "facilitá": "facilitar",
    "facilitámo": "facilitar",
    "facilitámos": "facilitar",
    "facilitáramo": "facilitar",
    "facilitáramos": "facilitar",
    "facilitárei": "facilitar",
    "facilitáreis": "facilitar",
    "facilitásseis": "facilitar",
    "facilitássemos": "facilitar",
    "facilitávamo": "facilitar",
    "facilitávamos": "facilitar",
    "facilitávei": "facilitar",
    "facilitáveis": "facilitar",
    "facinorosa": "facinoroso",
    "facinorosas": "facinoroso",
    "facinorosos": "facinoroso",
    "facistóis": "facistol",
    "facometrias": "facometria",
    "facométrica": "facométrico",
    "facométricas": "facométrico",
    "facométricos": "facométrico",
    "facosclerótica": "facosclerótico",
    "facoscleróticas": "facosclerótico",
    "facoscleróticos": "facosclerótico",
    "facoscopias": "facoscopia",
    "facoscópica": "facoscópico",
    "facoscópicas": "facoscópico",
    "facoscópicos": "facoscópico",
    "facosteroses": "facosterose",
    "facotes": "facote",
    "facsimilada": "facsimilado",
    "facsimiladas": "facsimilado",
    "facsimilados": "facsimilado",
    "facticidades": "facticidade",
    "factitiva": "factitivo",
    "factitivas": "factitivo",
    "factitivos": "factitivo",
    "factores": "factor",
    "factoriais": "factorial",
    "factoriza": "factorizar",
    "factorizada": "factorizar",
    "factorizadas": "factorizar",
    "factorizado": "factorizar",
    "factorizados": "factorizar",
    "factorizai": "factorizar",
    "factorizais": "factorizar",
    "factorizam": "factorizar",
    "factorizamo": "factorizar",
    "factorizamos": "factorizar",
    "factorizando": "factorizar",
    "factorizara": "factorizar",
    "factorizaram": "factorizar",
    "factorizaras": "factorizar",
    "factorizarde": "factorizar",
    "factorizardes": "factorizar",
    "factorizare": "factorizar",
    "factorizarei": "factorizar",
    "factorizareis": "factorizar",
    "factorizarem": "factorizar",
    "factorizaremos": "factorizar",
    "factorizares": "factorizar",
    "factorizaria": "factorizar",
    "factorizariam": "factorizar",
    "factorizarias": "factorizar",
    "factorizarmo": "factorizar",
    "factorizarmos": "factorizar",
    "factorizará": "factorizar",
    "factorizarás": "factorizar",
    "factorizarão": "factorizar",
    "factorizaríamos": "factorizar",
    "factorizaríeis": "factorizar",
    "factorizas": "factorizar",
    "factorizasse": "factorizar",
    "factorizassem": "factorizar",
    "factorizasses": "factorizar",
    "factorizaste": "factorizar",
    "factorizastes": "factorizar",
    "factorizava": "factorizar",
    "factorizavam": "factorizar",
    "factorizavas": "factorizar",
    "factorize": "factorizar",
    "factorizei": "factorizar",
    "factorizeis": "factorizar",
    "factorizem": "factorizar",
    "factorizemo": "factorizar",
    "factorizemos": "factorizar",
    "factorizes": "factorizar",
    "factorizo": "factorizar",
    "factorizou": "factorizar",
    "factorizá": "factorizar",
    "factorizámo": "factorizar",
    "factorizámos": "factorizar",
    "factorizáramo": "factorizar",
    "factorizáramos": "factorizar",
    "factorizárei": "factorizar",
    "factorizáreis": "factorizar",
    "factorizásseis": "factorizar",
    "factorizássemos": "factorizar",
    "factorizávamo": "factorizar",
    "factorizávamos": "factorizar",
    "factorizávei": "factorizar",
    "factorizáveis": "factorizável",
    "factos": "facto",
    "factotos": "factoto",
    "factuais": "factual",
    "factura": "facturar",
    "facturada": "facturar",
    "facturadas": "facturar",
    "facturado": "facturar",
    "facturados": "facturar",
    "facturai": "facturar",
    "facturais": "facturar",
    "facturam": "facturar",
    "facturamo": "facturar",
    "facturamos": "facturar",
    "facturando": "facturar",
    "facturara": "facturar",
    "facturaram": "facturar",
    "facturaras": "facturar",
    "facturarde": "facturar",
    "facturardes": "facturar",
    "facturare": "facturar",
    "facturarei": "facturar",
    "facturareis": "facturar",
    "facturarem": "facturar",
    "facturaremos": "facturar",
    "facturares": "facturar",
    "facturaria": "facturar",
    "facturariam": "facturar",
    "facturarias": "facturar",
    "facturarmo": "facturar",
    "facturarmos": "facturar",
    "facturará": "facturar",
    "facturarás": "facturar",
    "facturarão": "facturar",
    "facturaríamos": "facturar",
    "facturaríeis": "facturar",
    "facturas": "facturar",
    "facturasse": "facturar",
    "facturassem": "facturar",
    "facturasses": "facturar",
    "facturaste": "facturar",
    "facturastes": "facturar",
    "facturava": "facturar",
    "facturavam": "facturar",
    "facturavas": "facturar",
    "facturações": "facturação",
    "facture": "facturar",
    "facturei": "facturar",
    "factureis": "facturar",
    "facturem": "facturar",
    "facturemo": "facturar",
    "facturemos": "facturar",
    "factures": "facturar",
    "facturo": "facturar",
    "facturou": "facturar",
    "facturá": "facturar",
    "facturámo": "facturar",
    "facturámos": "facturar",
    "facturáramo": "facturar",
    "facturáramos": "facturar",
    "facturárei": "facturar",
    "facturáreis": "facturar",
    "facturásseis": "facturar",
    "facturássemos": "facturar",
    "facturávamo": "facturar",
    "facturávamos": "facturar",
    "facturávei": "facturar",
    "facturáveis": "facturável",
    "factícia": "factício",
    "factícias": "factício",
    "factícios": "factício",
    "factíveis": "factível",
    "factótuns": "factótum",
    "faculdades": "faculdade",
    "faculta": "facultar",
    "facultada": "facultar",
    "facultadas": "facultar",
    "facultado": "facultar",
    "facultados": "facultar",
    "facultai": "facultar",
    "facultais": "facultar",
    "facultam": "facultar",
    "facultamo": "facultar",
    "facultamos": "facultar",
    "facultando": "facultar",
    "facultara": "facultar",
    "facultaram": "facultar",
    "facultaras": "facultar",
    "facultarde": "facultar",
    "facultardes": "facultar",
    "facultare": "facultar",
    "facultarei": "facultar",
    "facultareis": "facultar",
    "facultarem": "facultar",
    "facultaremos": "facultar",
    "facultares": "facultar",
    "facultaria": "facultar",
    "facultariam": "facultar",
    "facultarias": "facultar",
    "facultarmo": "facultar",
    "facultarmos": "facultar",
    "facultará": "facultar",
    "facultarás": "facultar",
    "facultarão": "facultar",
    "facultaríamos": "facultar",
    "facultaríeis": "facultar",
    "facultas": "facultar",
    "facultasse": "facultar",
    "facultassem": "facultar",
    "facultasses": "facultar",
    "facultaste": "facultar",
    "facultastes": "facultar",
    "facultativa": "facultativo",
    "facultativas": "facultativo",
    "facultativos": "facultativo",
    "facultava": "facultar",
    "facultavam": "facultar",
    "facultavas": "facultar",
    "faculte": "facultar",
    "facultei": "facultar",
    "faculteis": "facultar",
    "facultem": "facultar",
    "facultemo": "facultar",
    "facultemos": "facultar",
    "facultes": "facultar",
    "faculto": "facultar",
    "facultosa": "facultoso",
    "facultosas": "facultoso",
    "facultosos": "facultoso",
    "facultou": "facultar",
    "facultá": "facultar",
    "facultámo": "facultar",
    "facultámos": "facultar",
    "facultáramo": "facultar",
    "facultáramos": "facultar",
    "facultárei": "facultar",
    "facultáreis": "facultar",
    "facultásseis": "facultar",
    "facultássemos": "facultar",
    "facultávamo": "facultar",
    "facultávamos": "facultar",
    "facultávei": "facultar",
    "facultáveis": "facultável",
    "facunda": "facundo",
    "facundas": "facundo",
    "facundidades": "facundidade",
    "facundos": "facundo",
    "facções": "facção",
    "facécias": "facécia",
    "facílima": "fácil",
    "facílimas": "fácil",
    "facílimo": "fácil",
    "facílimos": "fácil",
    "facínoras": "facínora",
    "facóides": "facóide",
    "facólitos": "facólito",
    "facómetros": "facómetro",
    "facões": "facão",
    "facúndia": "facúndio",
    "facúndias": "facúndio",
    "facúndios": "facúndio",
    "fada": "fadar",
    "fadada": "fadar",
    "fadadas": "fadar",
    "fadado": "fadar",
    "fadados": "fadar",
    "fadai": "fadar",
    "fadais": "fadar",
    "fadam": "fadar",
    "fadamo": "fadar",
    "fadamos": "fadar",
    "fadando": "fadar",
    "fadara": "fadar",
    "fadaram": "fadar",
    "fadaras": "fadar",
    "fadarde": "fadar",
    "fadardes": "fadar",
    "fadare": "fadar",
    "fadarei": "fadar",
    "fadareis": "fadar",
    "fadarem": "fadar",
    "fadaremos": "fadar",
    "fadares": "fadar",
    "fadaria": "fadar",
    "fadariam": "fadar",
    "fadarias": "fadar",
    "fadarmo": "fadar",
    "fadarmos": "fadar",
    "fadará": "fadar",
    "fadarás": "fadar",
    "fadarão": "fadar",
    "fadaríamos": "fadar",
    "fadaríeis": "fadar",
    "fadas": "fadar",
    "fadasse": "fadar",
    "fadassem": "fadar",
    "fadasses": "fadar",
    "fadaste": "fadar",
    "fadastes": "fadar",
    "fadava": "fadar",
    "fadavam": "fadar",
    "fadavas": "fadar",
    "fade": "fadar",
    "fadei": "fadar",
    "fadeis": "fadar",
    "fadeja": "fadejar",
    "fadejada": "fadejar",
    "fadejadas": "fadejar",
    "fadejado": "fadejar",
    "fadejados": "fadejar",
    "fadejai": "fadejar",
    "fadejais": "fadejar",
    "fadejam": "fadejar",
    "fadejamo": "fadejar",
    "fadejamos": "fadejar",
    "fadejando": "fadejar",
    "fadejara": "fadejar",
    "fadejaram": "fadejar",
    "fadejaras": "fadejar",
    "fadejardes": "fadejar",
    "fadejarei": "fadejar",
    "fadejareis": "fadejar",
    "fadejarem": "fadejar",
    "fadejaremos": "fadejar",
    "fadejares": "fadejar",
    "fadejaria": "fadejar",
    "fadejariam": "fadejar",
    "fadejarias": "fadejar",
    "fadejarmo": "fadejar",
    "fadejarmos": "fadejar",
    "fadejará": "fadejar",
    "fadejarás": "fadejar",
    "fadejarão": "fadejar",
    "fadejaríamos": "fadejar",
    "fadejaríeis": "fadejar",
    "fadejas": "fadejar",
    "fadejasse": "fadejar",
    "fadejassem": "fadejar",
    "fadejasses": "fadejar",
    "fadejaste": "fadejar",
    "fadejastes": "fadejar",
    "fadejava": "fadejar",
    "fadejavam": "fadejar",
    "fadejavas": "fadejar",
    "fadeje": "fadejar",
    "fadejei": "fadejar",
    "fadejeis": "fadejar",
    "fadejem": "fadejar",
    "fadejemo": "fadejar",
    "fadejemos": "fadejar",
    "fadejes": "fadejar",
    "fadejo": "fadejar",
    "fadejou": "fadejar",
    "fadejámo": "fadejar",
    "fadejámos": "fadejar",
    "fadejáramo": "fadejar",
    "fadejáramos": "fadejar",
    "fadejáreis": "fadejar",
    "fadejásseis": "fadejar",
    "fadejássemos": "fadejar",
    "fadejávamo": "fadejar",
    "fadejávamos": "fadejar",
    "fadejáveis": "fadejar",
    "fadem": "fadar",
    "fademo": "fadar",
    "fademos": "fadar",
    "fades": "fadar",
    "fadiga": "fadigar",
    "fadigada": "fadigar",
    "fadigadas": "fadigar",
    "fadigado": "fadigar",
    "fadigados": "fadigar",
    "fadigai": "fadigar",
    "fadigais": "fadigar",
    "fadigam": "fadigar",
    "fadigamo": "fadigar",
    "fadigamos": "fadigar",
    "fadigando": "fadigar",
    "fadigara": "fadigar",
    "fadigaram": "fadigar",
    "fadigaras": "fadigar",
    "fadigarde": "fadigar",
    "fadigardes": "fadigar",
    "fadigare": "fadigar",
    "fadigarei": "fadigar",
    "fadigareis": "fadigar",
    "fadigarem": "fadigar",
    "fadigaremos": "fadigar",
    "fadigares": "fadigar",
    "fadigaria": "fadigar",
    "fadigariam": "fadigar",
    "fadigarias": "fadigar",
    "fadigarmo": "fadigar",
    "fadigarmos": "fadigar",
    "fadigará": "fadigar",
    "fadigarás": "fadigar",
    "fadigarão": "fadigar",
    "fadigaríamos": "fadigar",
    "fadigaríeis": "fadigar",
    "fadigas": "fadigar",
    "fadigasse": "fadigar",
    "fadigassem": "fadigar",
    "fadigasses": "fadigar",
    "fadigaste": "fadigar",
    "fadigastes": "fadigar",
    "fadigava": "fadigar",
    "fadigavam": "fadigar",
    "fadigavas": "fadigar",
    "fadigo": "fadigar",
    "fadigosa": "fadigoso",
    "fadigosas": "fadigoso",
    "fadigosos": "fadigoso",
    "fadigou": "fadigar",
    "fadigue": "fadigar",
    "fadiguei": "fadigar",
    "fadigueis": "fadigar",
    "fadiguem": "fadigar",
    "fadiguemo": "fadigar",
    "fadiguemos": "fadigar",
    "fadigues": "fadigar",
    "fadigá": "fadigar",
    "fadigámo": "fadigar",
    "fadigámos": "fadigar",
    "fadigáramo": "fadigar",
    "fadigáramos": "fadigar",
    "fadigárei": "fadigar",
    "fadigáreis": "fadigar",
    "fadigásseis": "fadigar",
    "fadigássemos": "fadigar",
    "fadigávamo": "fadigar",
    "fadigávamos": "fadigar",
    "fadigávei": "fadigar",
    "fadigáveis": "fadigar",
    "fadinho": "fado",
    "fadinhos": "fado",
    "fadista": "fadistar",
    "fadistada": "fadistar",
    "fadistadas": "fadistar",
    "fadistado": "fadistar",
    "fadistados": "fadistar",
    "fadistagens": "fadistagem",
    "fadistai": "fadistar",
    "fadistais": "fadistar",
    "fadistam": "fadistar",
    "fadistamo": "fadistar",
    "fadistamos": "fadistar",
    "fadistando": "fadistar",
    "fadistara": "fadistar",
    "fadistaram": "fadistar",
    "fadistaras": "fadistar",
    "fadistardes": "fadistar",
    "fadistarei": "fadistar",
    "fadistareis": "fadistar",
    "fadistarem": "fadistar",
    "fadistaremos": "fadistar",
    "fadistares": "fadistar",
    "fadistaria": "fadistar",
    "fadistariam": "fadistar",
    "fadistarias": "fadistar",
    "fadistarmo": "fadistar",
    "fadistarmos": "fadistar",
    "fadistará": "fadistar",
    "fadistarás": "fadistar",
    "fadistarão": "fadistar",
    "fadistaríamos": "fadistar",
    "fadistaríeis": "fadistar",
    "fadistas": "fadistar",
    "fadistasse": "fadistar",
    "fadistassem": "fadistar",
    "fadistasses": "fadistar",
    "fadistaste": "fadistar",
    "fadistastes": "fadistar",
    "fadistava": "fadistar",
    "fadistavam": "fadistar",
    "fadistavas": "fadistar",
    "fadiste": "fadistar",
    "fadistei": "fadistar",
    "fadisteis": "fadistar",
    "fadistem": "fadistar",
    "fadistemo": "fadistar",
    "fadistemos": "fadistar",
    "fadistes": "fadistar",
    "fadistices": "fadistice",
    "fadisto": "fadistar",
    "fadistou": "fadistar",
    "fadistámo": "fadistar",
    "fadistámos": "fadistar",
    "fadistáramo": "fadistar",
    "fadistáramos": "fadistar",
    "fadistáreis": "fadistar",
    "fadistásseis": "fadistar",
    "fadistássemos": "fadistar",
    "fadistávamo": "fadistar",
    "fadistávamos": "fadistar",
    "fadistáveis": "fadistar",
    "fadistões": "fadistão",
    "fadito": "fado",
    "faditos": "fado",
    "fado": "fadar",
    "fados": "fado",
    "fadou": "fadar",
    "fadá": "fadar",
    "fadámo": "fadar",
    "fadámos": "fadar",
    "fadáramo": "fadar",
    "fadáramos": "fadar",
    "fadárei": "fadar",
    "fadáreis": "fadar",
    "fadários": "fadário",
    "fadásseis": "fadar",
    "fadássemos": "fadar",
    "fadávamo": "fadar",
    "fadávamos": "fadar",
    "fadávei": "fadar",
    "fadáveis": "fadar",
    "faetontes": "faetonte",
    "fagedenas": "fagedena",
    "fagedenismos": "fagedenismo",
    "fagedénica": "fagedénico",
    "fagedénicas": "fagedénico",
    "fagedénicos": "fagedénico",
    "fagocitoses": "fagocitose",
    "fagocitósica": "fagocitósico",
    "fagocitósicas": "fagocitósico",
    "fagocitósicos": "fagocitósico",
    "fagocitótica": "fagocitótico",
    "fagocitóticas": "fagocitótico",
    "fagocitóticos": "fagocitótico",
    "fagomanias": "fagomania",
    "fagomaníaca": "fagomaníaco",
    "fagomaníacas": "fagomaníaco",
    "fagomaníacos": "fagomaníaco",
    "fagoterapeutas": "fagoterapeuta",
    "fagoterapias": "fagoterapia",
    "fagoterapêutica": "fagoterapêutico",
    "fagoterapêuticas": "fagoterapêutico",
    "fagoterapêuticos": "fagoterapêutico",
    "fagoterápica": "fagoterápico",
    "fagoterápicas": "fagoterápico",
    "fagoterápicos": "fagoterápico",
    "fagotes": "fagote",
    "fagotistas": "fagotista",
    "fagueira": "fagueiro",
    "fagueiras": "fagueiro",
    "fagueiros": "fagueiro",
    "faguices": "faguice",
    "fagulha": "fagulhar",
    "fagulhada": "fagulhar",
    "fagulhadas": "fagulhar",
    "fagulhado": "fagulhar",
    "fagulhados": "fagulhar",
    "fagulhai": "fagulhar",
    "fagulhais": "fagulhar",
    "fagulham": "fagulhar",
    "fagulhamo": "fagulhar",
    "fagulhamos": "fagulhar",
    "fagulhando": "fagulhar",
    "fagulhara": "fagulhar",
    "fagulharam": "fagulhar",
    "fagulharas": "fagulhar",
    "fagulhardes": "fagulhar",
    "fagulharei": "fagulhar",
    "fagulhareis": "fagulhar",
    "fagulharem": "fagulhar",
    "fagulharemos": "fagulhar",
    "fagulhares": "fagulhar",
    "fagulharia": "fagulhar",
    "fagulhariam": "fagulhar",
    "fagulharias": "fagulharia",
    "fagulharmo": "fagulhar",
    "fagulharmos": "fagulhar",
    "fagulhará": "fagulhar",
    "fagulharás": "fagulhar",
    "fagulharão": "fagulhar",
    "fagulharíamos": "fagulhar",
    "fagulharíeis": "fagulhar",
    "fagulhas": "fagulhar",
    "fagulhasse": "fagulhar",
    "fagulhassem": "fagulhar",
    "fagulhasses": "fagulhar",
    "fagulhaste": "fagulhar",
    "fagulhastes": "fagulhar",
    "fagulhava": "fagulhar",
    "fagulhavam": "fagulhar",
    "fagulhavas": "fagulhar",
    "fagulhações": "fagulhação",
    "fagulhe": "fagulhar",
    "fagulhei": "fagulhar",
    "fagulheis": "fagulhar",
    "fagulhem": "fagulhar",
    "fagulhemo": "fagulhar",
    "fagulhemos": "fagulhar",
    "fagulhenta": "fagulhento",
    "fagulhentas": "fagulhento",
    "fagulhentos": "fagulhento",
    "fagulhes": "fagulhar",
    "fagulho": "fagulhar",
    "fagulhou": "fagulhar",
    "fagulhámo": "fagulhar",
    "fagulhámos": "fagulhar",
    "fagulháramo": "fagulhar",
    "fagulháramos": "fagulhar",
    "fagulháreis": "fagulhar",
    "fagulhásseis": "fagulhar",
    "fagulhássemos": "fagulhar",
    "fagulhávamo": "fagulhar",
    "fagulhávamos": "fagulhar",
    "fagulháveis": "fagulhar",
    "fagácea": "fagáceo",
    "fagáceas": "fagáceo",
    "fagáceos": "fagáceo",
    "fagícolas": "fagícola",
    "fagócitos": "fagócito",
    "faia": "faiar",
    "faiada": "faiar",
    "faiadas": "faiar",
    "faiado": "faiar",
    "faiados": "faiar",
    "faiai": "faiar",
    "faiais": "faiar",
    "faialenses": "faialense",
    "faialites": "faialite",
    "faiam": "faiar",
    "faiamo": "faiar",
    "faiamos": "faiar",
    "faiando": "faiar",
    "faiantes": "faiante",
    "faianças": "faiança",
    "faiara": "faiar",
    "faiaram": "faiar",
    "faiaras": "faiar",
    "faiardes": "faiar",
    "faiarei": "faiar",
    "faiareis": "faiar",
    "faiarem": "faiar",
    "faiaremos": "faiar",
    "faiares": "faiar",
    "faiaria": "faiar",
    "faiariam": "faiar",
    "faiarias": "faiar",
    "faiarmo": "faiar",
    "faiarmos": "faiar",
    "faiará": "faiar",
    "faiarás": "faiar",
    "faiarão": "faiar",
    "faiaríamos": "faiar",
    "faiaríeis": "faiar",
    "faias": "faiar",
    "faiasse": "faiar",
    "faiassem": "faiar",
    "faiasses": "faiar",
    "faiaste": "faiar",
    "faiastes": "faiar",
    "faiava": "faiar",
    "faiavam": "faiar",
    "faiavas": "faiar",
    "faie": "faiar",
    "faiei": "faiar",
    "faieis": "faiar",
    "faiem": "faiar",
    "faiemo": "faiar",
    "faiemos": "faiar",
    "faies": "faiar",
    "fainas": "faina",
    "fains": "faim",
    "faio": "faiar",
    "faiou": "faiar",
    "faisca": "faiscar",
    "faiscada": "faiscar",
    "faiscadas": "faiscar",
    "faiscado": "faiscar",
    "faiscadora": "faiscador",
    "faiscadoras": "faiscador",
    "faiscadores": "faiscador",
    "faiscados": "faiscar",
    "faiscais": "faiscar",
    "faiscam": "faiscar",
    "faiscamo": "faiscar",
    "faiscamos": "faiscar",
    "faiscando": "faiscar",
    "faiscantes": "faiscante",
    "faiscara": "faiscar",
    "faiscaram": "faiscar",
    "faiscaras": "faiscar",
    "faiscardes": "faiscar",
    "faiscarei": "faiscar",
    "faiscareis": "faiscar",
    "faiscarem": "faiscar",
    "faiscaremos": "faiscar",
    "faiscares": "faiscar",
    "faiscaria": "faiscar",
    "faiscariam": "faiscar",
    "faiscarias": "faiscar",
    "faiscarmo": "faiscar",
    "faiscarmos": "faiscar",
    "faiscará": "faiscar",
    "faiscarás": "faiscar",
    "faiscarão": "faiscar",
    "faiscaríamos": "faiscar",
    "faiscaríeis": "faiscar",
    "faiscas": "faiscar",
    "faiscasse": "faiscar",
    "faiscassem": "faiscar",
    "faiscasses": "faiscar",
    "faiscaste": "faiscar",
    "faiscastes": "faiscar",
    "faiscava": "faiscar",
    "faiscavam": "faiscar",
    "faiscavas": "faiscar",
    "faiscações": "faiscação",
    "faisco": "faiscar",
    "faiscos": "faisco",
    "faiscou": "faiscar",
    "faiscámo": "faiscar",
    "faiscámos": "faiscar",
    "faiscáramo": "faiscar",
    "faiscáramos": "faiscar",
    "faiscáreis": "faiscar",
    "faiscásseis": "faiscar",
    "faiscássemos": "faiscar",
    "faiscávamo": "faiscar",
    "faiscávamos": "faiscar",
    "faiscáveis": "faiscar",
    "faiscâncias": "faiscância",
    "faisoa": "faisão",
    "faisoas": "faisão",
    "faisque": "faiscar",
    "faisquei": "faiscar",
    "faisqueiras": "faisqueira",
    "faisqueiros": "faisqueiro",
    "faisqueis": "faiscar",
    "faisquem": "faiscar",
    "faisquemos": "faiscar",
    "faisques": "faiscar",
    "faisões": "faisão",
    "faixa": "faixar",
    "faixada": "faixar",
    "faixadas": "faixar",
    "faixado": "faixar",
    "faixados": "faixar",
    "faixai": "faixar",
    "faixais": "faixar",
    "faixam": "faixar",
    "faixamo": "faixar",
    "faixamos": "faixar",
    "faixando": "faixar",
    "faixara": "faixar",
    "faixaram": "faixar",
    "faixaras": "faixar",
    "faixarde": "faixar",
    "faixardes": "faixar",
    "faixare": "faixar",
    "faixarei": "faixar",
    "faixareis": "faixar",
    "faixarem": "faixar",
    "faixaremos": "faixar",
    "faixares": "faixar",
    "faixaria": "faixar",
    "faixariam": "faixar",
    "faixarias": "faixar",
    "faixarmo": "faixar",
    "faixarmos": "faixar",
    "faixará": "faixar",
    "faixarás": "faixar",
    "faixarão": "faixar",
    "faixaríamos": "faixar",
    "faixaríeis": "faixar",
    "faixas": "faixar",
    "faixasse": "faixar",
    "faixassem": "faixar",
    "faixasses": "faixar",
    "faixaste": "faixar",
    "faixastes": "faixar",
    "faixava": "faixar",
    "faixavam": "faixar",
    "faixavas": "faixar",
    "faixe": "faixar",
    "faixei": "faixar",
    "faixeiros": "faixeiro",
    "faixeis": "faixar",
    "faixem": "faixar",
    "faixemo": "faixar",
    "faixemos": "faixar",
    "faixes": "faixar",
    "faixo": "faixar",
    "faixou": "faixar",
    "faixá": "faixar",
    "faixámo": "faixar",
    "faixámos": "faixar",
    "faixáramo": "faixar",
    "faixáramos": "faixar",
    "faixárei": "faixar",
    "faixáreis": "faixar",
    "faixásseis": "faixar",
    "faixássemos": "faixar",
    "faixávamo": "faixar",
    "faixávamos": "faixar",
    "faixávei": "faixar",
    "faixáveis": "faixar",
    "faiámo": "faiar",
    "faiámos": "faiar",
    "faiáramo": "faiar",
    "faiáramos": "faiar",
    "faiáreis": "faiar",
    "faiásseis": "faiar",
    "faiássemos": "faiar",
    "faiávamo": "faiar",
    "faiávamos": "faiar",
    "faiáveis": "faiar",
    "fajarda": "fajardo",
    "fajardas": "fajardo",
    "fajardices": "fajardice",
    "fajardismos": "fajardismo",
    "fajardos": "fajardo",
    "fala": "falir",
    "falacas": "falaca",
    "falace": "falaçar",
    "falacei": "falaçar",
    "falaceis": "falaçar",
    "falacem": "falaçar",
    "falacemo": "falaçar",
    "falacemos": "falaçar",
    "falaces": "falace",
    "falachas": "falacha",
    "falacia": "falaciar",
    "falaciada": "falaciar",
    "falaciadas": "falaciar",
    "falaciado": "falaciar",
    "falaciados": "falaciar",
    "falaciai": "falaciar",
    "falaciais": "falaciar",
    "falaciam": "falaciar",
    "falaciamo": "falaciar",
    "falaciamos": "falaciar",
    "falaciando": "falaciar",
    "falaciara": "falaciar",
    "falaciaram": "falaciar",
    "falaciaras": "falaciar",
    "falaciardes": "falaciar",
    "falaciarei": "falaciar",
    "falaciareis": "falaciar",
    "falaciarem": "falaciar",
    "falaciaremos": "falaciar",
    "falaciares": "falaciar",
    "falaciaria": "falaciar",
    "falaciariam": "falaciar",
    "falaciarias": "falaciar",
    "falaciarmo": "falaciar",
    "falaciarmos": "falaciar",
    "falaciará": "falaciar",
    "falaciarás": "falaciar",
    "falaciarão": "falaciar",
    "falaciaríamos": "falaciar",
    "falaciaríeis": "falaciar",
    "falacias": "falaciar",
    "falaciasse": "falaciar",
    "falaciassem": "falaciar",
    "falaciasses": "falaciar",
    "falaciaste": "falaciar",
    "falaciastes": "falaciar",
    "falaciava": "falaciar",
    "falaciavam": "falaciar",
    "falaciavas": "falaciar",
    "falacie": "falaciar",
    "falaciei": "falaciar",
    "falacieis": "falaciar",
    "falaciem": "falaciar",
    "falaciemo": "falaciar",
    "falaciemos": "falaciar",
    "falacies": "falaciar",
    "falacio": "falaciar",
    "falaciosa": "falacioso",
    "falaciosas": "falacioso",
    "falaciosos": "falacioso",
    "falaciou": "falaciar",
    "falaciámo": "falaciar",
    "falaciámos": "falaciar",
    "falaciáramo": "falaciar",
    "falaciáramos": "falaciar",
    "falaciáreis": "falaciar",
    "falaciásseis": "falaciar",
    "falaciássemos": "falaciar",
    "falaciávamo": "falaciar",
    "falaciávamos": "falaciar",
    "falaciáveis": "falaciar",
    "falacrocoracía": "falacrocoracío",
    "falacrocoracías": "falacrocoracío",
    "falacrocoracídeos": "falacrocoracídeo",
    "falacrocoracíos": "falacrocoracío",
    "falacrocorácea": "falacrocoráceo",
    "falacrocoráceas": "falacrocoráceo",
    "falacrocoráceos": "falacrocoráceo",
    "falacrocorácidas": "falacrocorácida",
    "falada": "falar",
    "faladas": "falar",
    "falado": "falar",
    "faladora": "falador",
    "faladoras": "falador",
    "faladores": "falador",
    "falados": "falar",
    "falai": "falar",
    "falais": "falir",
    "falam": "falir",
    "falamo": "falir",
    "falamos": "falir",
    "falando": "falar",
    "falangeais": "falangeal",
    "falangeana": "falangeano",
    "falangeanas": "falangeano",
    "falangeanos": "falangeano",
    "falanges": "falange",
    "falangetas": "falangeta",
    "falanginhas": "falanginha",
    "falangiodes": "falangiode",
    "falangistas": "falangista",
    "falangiídea": "falangiídeo",
    "falangiídeas": "falangiídeo",
    "falangiídeos": "falangiídeo",
    "falangíidas": "falangíida",
    "falansteriana": "falansteriano",
    "falansterianas": "falansteriano",
    "falansterianismos": "falansterianismo",
    "falansterianistas": "falansterianista",
    "falansterianos": "falansteriano",
    "falanstérios": "falanstério",
    "falantes": "falante",
    "falara": "falar",
    "falaram": "falar",
    "falaras": "falar",
    "falarde": "falar",
    "falardes": "falar",
    "falare": "falar",
    "falarei": "falar",
    "falareis": "falar",
    "falarem": "falar",
    "falaremos": "falar",
    "falares": "falar",
    "falaria": "falar",
    "falariam": "falar",
    "falarias": "falar",
    "falarios": "falario",
    "falarmo": "falar",
    "falarmos": "falar",
    "falará": "falar",
    "falarás": "falar",
    "falarão": "falar",
    "falaríamos": "falar",
    "falaríeis": "falar",
    "falas": "falir",
    "falasse": "falar",
    "falassem": "falar",
    "falasses": "falar",
    "falaste": "falar",
    "falastes": "falar",
    "falatórios": "falatório",
    "falava": "falar",
    "falavam": "falar",
    "falavas": "falar",
    "falazes": "falaz",
    "falaça": "falaçar",
    "falaçada": "falaçar",
    "falaçadas": "falaçar",
    "falaçado": "falaçar",
    "falaçados": "falaçar",
    "falaçai": "falaçar",
    "falaçais": "falaçar",
    "falaçam": "falaçar",
    "falaçamo": "falaçar",
    "falaçamos": "falaçar",
    "falaçando": "falaçar",
    "falaçara": "falaçar",
    "falaçaram": "falaçar",
    "falaçaras": "falaçar",
    "falaçardes": "falaçar",
    "falaçarei": "falaçar",
    "falaçareis": "falaçar",
    "falaçarem": "falaçar",
    "falaçaremos": "falaçar",
    "falaçares": "falaçar",
    "falaçaria": "falaçar",
    "falaçariam": "falaçar",
    "falaçarias": "falaçar",
    "falaçarmo": "falaçar",
    "falaçarmos": "falaçar",
    "falaçará": "falaçar",
    "falaçarás": "falaçar",
    "falaçarão": "falaçar",
    "falaçaríamos": "falaçar",
    "falaçaríeis": "falaçar",
    "falaças": "falaçar",
    "falaçasse": "falaçar",
    "falaçassem": "falaçar",
    "falaçasses": "falaçar",
    "falaçaste": "falaçar",
    "falaçastes": "falaçar",
    "falaçava": "falaçar",
    "falaçavam": "falaçar",
    "falaçavas": "falaçar",
    "falaço": "falaçar",
    "falaçou": "falaçar",
    "falaçámo": "falaçar",
    "falaçámos": "falaçar",
    "falaçáramo": "falaçar",
    "falaçáramos": "falaçar",
    "falaçáreis": "falaçar",
    "falaçásseis": "falaçar",
    "falaçássemos": "falaçar",
    "falaçávamo": "falaçar",
    "falaçávamos": "falaçar",
    "falaçáveis": "falaçar",
    "falcace": "falcaçar",
    "falcacei": "falcaçar",
    "falcaceis": "falcaçar",
    "falcacem": "falcaçar",
    "falcacemo": "falcaçar",
    "falcacemos": "falcaçar",
    "falcaces": "falcaçar",
    "falcada": "falcado",
    "falcadas": "falcado",
    "falcados": "falcado",
    "falcatas": "falcata",
    "falcatroeiros": "falcatroeiro",
    "falcatroices": "falcatroice",
    "falcatrua": "falcatruar",
    "falcatruada": "falcatruar",
    "falcatruadas": "falcatruar",
    "falcatruado": "falcatruar",
    "falcatruados": "falcatruar",
    "falcatruai": "falcatruar",
    "falcatruais": "falcatruar",
    "falcatruam": "falcatruar",
    "falcatruamo": "falcatruar",
    "falcatruamos": "falcatruar",
    "falcatruando": "falcatruar",
    "falcatruara": "falcatruar",
    "falcatruaram": "falcatruar",
    "falcatruaras": "falcatruar",
    "falcatruarde": "falcatruar",
    "falcatruardes": "falcatruar",
    "falcatruare": "falcatruar",
    "falcatruarei": "falcatruar",
    "falcatruareis": "falcatruar",
    "falcatruarem": "falcatruar",
    "falcatruaremos": "falcatruar",
    "falcatruares": "falcatruar",
    "falcatruaria": "falcatruar",
    "falcatruariam": "falcatruar",
    "falcatruarias": "falcatruar",
    "falcatruarmo": "falcatruar",
    "falcatruarmos": "falcatruar",
    "falcatruará": "falcatruar",
    "falcatruarás": "falcatruar",
    "falcatruarão": "falcatruar",
    "falcatruaríamos": "falcatruar",
    "falcatruaríeis": "falcatruar",
    "falcatruas": "falcatruar",
    "falcatruasse": "falcatruar",
    "falcatruassem": "falcatruar",
    "falcatruasses": "falcatruar",
    "falcatruaste": "falcatruar",
    "falcatruastes": "falcatruar",
    "falcatruava": "falcatruar",
    "falcatruavam": "falcatruar",
    "falcatruavas": "falcatruar",
    "falcatrue": "falcatruar",
    "falcatruei": "falcatruar",
    "falcatrueira": "falcatrueiro",
    "falcatrueiras": "falcatrueiro",
    "falcatrueiros": "falcatrueiro",
    "falcatrueis": "falcatruar",
    "falcatruem": "falcatruar",
    "falcatruemo": "falcatruar",
    "falcatruemos": "falcatruar",
    "falcatrues": "falcatruar",
    "falcatruo": "falcatruar",
    "falcatruou": "falcatruar",
    "falcatruá": "falcatruar",
    "falcatruámo": "falcatruar",
    "falcatruámos": "falcatruar",
    "falcatruáramo": "falcatruar",
    "falcatruáramos": "falcatruar",
    "falcatruárei": "falcatruar",
    "falcatruáreis": "falcatruar",
    "falcatruásseis": "falcatruar",
    "falcatruássemos": "falcatruar",
    "falcatruávamo": "falcatruar",
    "falcatruávamos": "falcatruar",
    "falcatruávei": "falcatruar",
    "falcatruáveis": "falcatruar",
    "falcaça": "falcaçar",
    "falcaçada": "falcaçar",
    "falcaçadas": "falcaçar",
    "falcaçado": "falcaçar",
    "falcaçados": "falcaçar",
    "falcaçai": "falcaçar",
    "falcaçais": "falcaçar",
    "falcaçam": "falcaçar",
    "falcaçamo": "falcaçar",
    "falcaçamos": "falcaçar",
    "falcaçando": "falcaçar",
    "falcaçara": "falcaçar",
    "falcaçaram": "falcaçar",
    "falcaçaras": "falcaçar",
    "falcaçarde": "falcaçar",
    "falcaçardes": "falcaçar",
    "falcaçare": "falcaçar",
    "falcaçarei": "falcaçar",
    "falcaçareis": "falcaçar",
    "falcaçarem": "falcaçar",
    "falcaçaremos": "falcaçar",
    "falcaçares": "falcaçar",
    "falcaçaria": "falcaçar",
    "falcaçariam": "falcaçar",
    "falcaçarias": "falcaçar",
    "falcaçarmo": "falcaçar",
    "falcaçarmos": "falcaçar",
    "falcaçará": "falcaçar",
    "falcaçarás": "falcaçar",
    "falcaçarão": "falcaçar",
    "falcaçaríamos": "falcaçar",
    "falcaçaríeis": "falcaçar",
    "falcaças": "falcaçar",
    "falcaçasse": "falcaçar",
    "falcaçassem": "falcaçar",
    "falcaçasses": "falcaçar",
    "falcaçaste": "falcaçar",
    "falcaçastes": "falcaçar",
    "falcaçava": "falcaçar",
    "falcaçavam": "falcaçar",
    "falcaçavas": "falcaçar",
    "falcaço": "falcaçar",
    "falcaçou": "falcaçar",
    "falcaçá": "falcaçar",
    "falcaçámo": "falcaçar",
    "falcaçámos": "falcaçar",
    "falcaçáramo": "falcaçar",
    "falcaçáramos": "falcaçar",
    "falcaçárei": "falcaçar",
    "falcaçáreis": "falcaçar",
    "falcaçásseis": "falcaçar",
    "falcaçássemos": "falcaçar",
    "falcaçávamo": "falcaçar",
    "falcaçávamos": "falcaçar",
    "falcaçávei": "falcaçar",
    "falcaçáveis": "falcaçar",
    "falcifoliada": "falcifoliado",
    "falcifoliadas": "falcifoliado",
    "falcifoliados": "falcifoliado",
    "falciformes": "falciforme",
    "falcoa": "falcoar",
    "falcoada": "falcoar",
    "falcoadas": "falcoar",
    "falcoado": "falcoar",
    "falcoados": "falcoar",
    "falcoai": "falcoar",
    "falcoais": "falcoar",
    "falcoam": "falcoar",
    "falcoamo": "falcoar",
    "falcoamos": "falcoar",
    "falcoando": "falcoar",
    "falcoara": "falcoar",
    "falcoaram": "falcoar",
    "falcoaras": "falcoar",
    "falcoarde": "falcoar",
    "falcoardes": "falcoar",
    "falcoare": "falcoar",
    "falcoarei": "falcoar",
    "falcoareis": "falcoar",
    "falcoarem": "falcoar",
    "falcoaremos": "falcoar",
    "falcoares": "falcoar",
    "falcoaria": "falcoar",
    "falcoariam": "falcoar",
    "falcoarias": "falcoaria",
    "falcoarmo": "falcoar",
    "falcoarmos": "falcoar",
    "falcoará": "falcoar",
    "falcoarás": "falcoar",
    "falcoarão": "falcoar",
    "falcoaríamos": "falcoar",
    "falcoaríeis": "falcoar",
    "falcoas": "falcoar",
    "falcoasse": "falcoar",
    "falcoassem": "falcoar",
    "falcoasses": "falcoar",
    "falcoaste": "falcoar",
    "falcoastes": "falcoar",
    "falcoava": "falcoar",
    "falcoavam": "falcoar",
    "falcoavas": "falcoar",
    "falcoe": "falcoar",
    "falcoei": "falcoar",
    "falcoeiras": "falcoeira",
    "falcoeiros": "falcoeiro",
    "falcoeis": "falcoar",
    "falcoem": "falcoar",
    "falcoemo": "falcoar",
    "falcoemos": "falcoar",
    "falcoes": "falcoar",
    "falcolares": "falcolar",
    "falconetes": "falconete",
    "falconídea": "falconídeo",
    "falconídeas": "falconídeo",
    "falconídeos": "falconídeo",
    "falcoo": "falcoar",
    "falcoou": "falcoar",
    "falcoá": "falcoar",
    "falcoámo": "falcoar",
    "falcoámos": "falcoar",
    "falcoáramo": "falcoar",
    "falcoáramos": "falcoar",
    "falcoárei": "falcoar",
    "falcoáreis": "falcoar",
    "falcoásseis": "falcoar",
    "falcoássemos": "falcoar",
    "falcoávamo": "falcoar",
    "falcoávamos": "falcoar",
    "falcoávei": "falcoar",
    "falcoáveis": "falcoar",
    "falcífera": "falcífero",
    "falcíferas": "falcífero",
    "falcíferos": "falcífero",
    "falcípedes": "falcípede",
    "falcónidas": "falcónida",
    "falcões": "falcão",
    "faldas": "falda",
    "faldistórios": "faldistório",
    "fale": "falir",
    "falece": "falecer",
    "falecei": "falecer",
    "faleceis": "falecer",
    "falecem": "falecer",
    "falecemo": "falecer",
    "falecemos": "falecer",
    "falecendo": "falecer",
    "falecera": "falecer",
    "faleceram": "falecer",
    "faleceras": "falecer",
    "falecerdes": "falecer",
    "falecerei": "falecer",
    "falecereis": "falecer",
    "falecerem": "falecer",
    "faleceremos": "falecer",
    "faleceres": "falecer",
    "faleceria": "falecer",
    "faleceriam": "falecer",
    "falecerias": "falecer",
    "falecermo": "falecer",
    "falecermos": "falecer",
    "falecerá": "falecer",
    "falecerás": "falecer",
    "falecerão": "falecer",
    "faleceríamos": "falecer",
    "faleceríeis": "falecer",
    "faleces": "falecer",
    "falecesse": "falecer",
    "falecessem": "falecer",
    "falecesses": "falecer",
    "faleceste": "falecer",
    "falecestes": "falecer",
    "faleceu": "falecer",
    "faleci": "falecer",
    "falecia": "falecer",
    "faleciam": "falecer",
    "falecias": "falecer",
    "falecida": "falecido",
    "falecidas": "falecido",
    "falecido": "falecer",
    "falecidos": "falecido",
    "falecimentos": "falecimento",
    "falecêramo": "falecer",
    "falecêramos": "falecer",
    "falecêreis": "falecer",
    "falecêsseis": "falecer",
    "falecêssemos": "falecer",
    "falecíamo": "falecer",
    "falecíamos": "falecer",
    "falecíeis": "falecer",
    "falei": "falar",
    "faleis": "falar",
    "falem": "falir",
    "falemo": "falar",
    "falemos": "falar",
    "falenas": "falena",
    "falerna": "falerno",
    "falernas": "falerno",
    "falernos": "falerno",
    "fales": "falir",
    "faleça": "falecer",
    "faleçais": "falecer",
    "faleçam": "falecer",
    "faleçamo": "falecer",
    "faleçamos": "falecer",
    "faleças": "falecer",
    "faleço": "falecer",
    "falha": "falho",
    "falhada": "falhar",
    "falhadas": "falhar",
    "falhado": "falhar",
    "falhados": "falhar",
    "falhaduras": "falhadura",
    "falhai": "falhar",
    "falhais": "falhar",
    "falham": "falhar",
    "falhamo": "falhar",
    "falhamos": "falhar",
    "falhando": "falhar",
    "falhanços": "falhanço",
    "falhara": "falhar",
    "falharam": "falhar",
    "falharas": "falhar",
    "falharde": "falhar",
    "falhardes": "falhar",
    "falhare": "falhar",
    "falharei": "falhar",
    "falhareis": "falhar",
    "falharem": "falhar",
    "falharemos": "falhar",
    "falhares": "falhar",
    "falharia": "falhar",
    "falhariam": "falhar",
    "falharias": "falhar",
    "falharmo": "falhar",
    "falharmos": "falhar",
    "falhará": "falhar",
    "falharás": "falhar",
    "falharão": "falhar",
    "falharíamos": "falhar",
    "falharíeis": "falhar",
    "falhas": "falho",
    "falhasse": "falhar",
    "falhassem": "falhar",
    "falhasses": "falhar",
    "falhaste": "falhar",
    "falhastes": "falhar",
    "falhava": "falhar",
    "falhavam": "falhar",
    "falhavas": "falhar",
    "falhe": "falhar",
    "falhei": "falhar",
    "falheira": "falheiro",
    "falheiras": "falheiro",
    "falheiros": "falheiro",
    "falheis": "falhar",
    "falhem": "falhar",
    "falhemo": "falhar",
    "falhemos": "falhar",
    "falhes": "falhar",
    "falhipos": "falhipo",
    "falho": "falhar",
    "falhos": "falho",
    "falhou": "falhar",
    "falhuda": "falhudo",
    "falhudas": "falhudo",
    "falhudos": "falhudo",
    "falhá": "falhar",
    "falhámo": "falhar",
    "falhámos": "falhar",
    "falháramo": "falhar",
    "falháramos": "falhar",
    "falhárei": "falhar",
    "falháreis": "falhar",
    "falhásseis": "falhar",
    "falhássemos": "falhar",
    "falhávamo": "falhar",
    "falhávamos": "falhar",
    "falhávei": "falhar",
    "falháveis": "falhar",
    "falhões": "falhão",
    "fali": "falir",
    "falia": "falir",
    "faliam": "falir",
    "falias": "falir",
    "falibilidades": "falibilidade",
    "falicismos": "falicismo",
    "falida": "falir",
    "falidas": "falir",
    "falido": "falir",
    "falidos": "falir",
    "falimentos": "falimento",
    "falimo": "falir",
    "falimos": "falir",
    "falindo": "falir",
    "falinha": "fala",
    "falinhas": "fala",
    "falira": "falir",
    "faliram": "falir",
    "faliras": "falir",
    "falirdes": "falir",
    "falirei": "falir",
    "falireis": "falir",
    "falirem": "falir",
    "faliremos": "falir",
    "falires": "falir",
    "faliria": "falir",
    "faliriam": "falir",
    "falirias": "falir",
    "falirmo": "falir",
    "falirmos": "falir",
    "falirá": "falir",
    "falirás": "falir",
    "falirão": "falir",
    "faliríamos": "falir",
    "faliríeis": "falir",
    "falis": "falir",
    "faliscos": "falisco",
    "falisse": "falir",
    "falissem": "falir",
    "falisses": "falir",
    "faliste": "falir",
    "falistes": "falir",
    "falita": "fala",
    "falitas": "fala",
    "faliu": "falir",
    "falo": "falir",
    "faloas": "faloa",
    "falodinias": "falodinia",
    "falofória": "falofório",
    "falofórias": "falofório",
    "falofórios": "falofório",
    "falos": "falo",
    "falou": "falar",
    "falperras": "falperra",
    "falperristas": "falperrista",
    "falporria": "falporriar",
    "falporriada": "falporriar",
    "falporriadas": "falporriar",
    "falporriado": "falporriar",
    "falporriados": "falporriar",
    "falporriai": "falporriar",
    "falporriais": "falporriar",
    "falporriam": "falporriar",
    "falporriamo": "falporriar",
    "falporriamos": "falporriar",
    "falporriando": "falporriar",
    "falporriara": "falporriar",
    "falporriaram": "falporriar",
    "falporriaras": "falporriar",
    "falporriardes": "falporriar",
    "falporriarei": "falporriar",
    "falporriareis": "falporriar",
    "falporriarem": "falporriar",
    "falporriaremos": "falporriar",
    "falporriares": "falporriar",
    "falporriaria": "falporriar",
    "falporriariam": "falporriar",
    "falporriarias": "falporriar",
    "falporriarmo": "falporriar",
    "falporriarmos": "falporriar",
    "falporriará": "falporriar",
    "falporriarás": "falporriar",
    "falporriarão": "falporriar",
    "falporriaríamos": "falporriar",
    "falporriaríeis": "falporriar",
    "falporrias": "falporriar",
    "falporriasse": "falporriar",
    "falporriassem": "falporriar",
    "falporriasses": "falporriar",
    "falporriaste": "falporriar",
    "falporriastes": "falporriar",
    "falporriava": "falporriar",
    "falporriavam": "falporriar",
    "falporriavas": "falporriar",
    "falporrices": "falporrice",
    "falporrie": "falporriar",
    "falporriei": "falporriar",
    "falporrieis": "falporriar",
    "falporriem": "falporriar",
    "falporriemo": "falporriar",
    "falporriemos": "falporriar",
    "falporries": "falporriar",
    "falporrio": "falporriar",
    "falporriou": "falporriar",
    "falporriámo": "falporriar",
    "falporriámos": "falporriar",
    "falporriáramo": "falporriar",
    "falporriáramos": "falporriar",
    "falporriáreis": "falporriar",
    "falporriásseis": "falporriar",
    "falporriássemos": "falporriar",
    "falporriávamo": "falporriar",
    "falporriávamos": "falporriar",
    "falporriáveis": "falporriar",
    "falpórrias": "falpórria",
    "falqueada": "falquear",
    "falqueadas": "falquear",
    "falqueado": "falquear",
    "falqueadora": "falqueador",
    "falqueadoras": "falqueador",
    "falqueadores": "falqueador",
    "falqueados": "falquear",
    "falqueaduras": "falqueadura",
    "falqueai": "falquear",
    "falqueais": "falquear",
    "falqueamo": "falquear",
    "falqueamos": "falquear",
    "falqueando": "falquear",
    "falqueara": "falquear",
    "falquearam": "falquear",
    "falquearas": "falquear",
    "falquearde": "falquear",
    "falqueardes": "falquear",
    "falqueare": "falquear",
    "falquearei": "falquear",
    "falqueareis": "falquear",
    "falquearem": "falquear",
    "falquearemos": "falquear",
    "falqueares": "falquear",
    "falquearia": "falquear",
    "falqueariam": "falquear",
    "falquearias": "falquear",
    "falquearmo": "falquear",
    "falquearmos": "falquear",
    "falqueará": "falquear",
    "falquearás": "falquear",
    "falquearão": "falquear",
    "falquearíamos": "falquear",
    "falquearíeis": "falquear",
    "falqueasse": "falquear",
    "falqueassem": "falquear",
    "falqueasses": "falquear",
    "falqueaste": "falquear",
    "falqueastes": "falquear",
    "falqueava": "falquear",
    "falqueavam": "falquear",
    "falqueavas": "falquear",
    "falqueei": "falquear",
    "falqueeis": "falquear",
    "falqueemo": "falquear",
    "falqueemos": "falquear",
    "falqueia": "falquear",
    "falqueiam": "falquear",
    "falqueias": "falquear",
    "falqueie": "falquear",
    "falqueiem": "falquear",
    "falqueies": "falquear",
    "falqueio": "falquear",
    "falqueja": "falquejar",
    "falquejada": "falquejar",
    "falquejadas": "falquejar",
    "falquejado": "falquejar",
    "falquejados": "falquejar",
    "falquejaduras": "falquejadura",
    "falquejai": "falquejar",
    "falquejais": "falquejar",
    "falquejam": "falquejar",
    "falquejamentos": "falquejamento",
    "falquejamo": "falquejar",
    "falquejamos": "falquejar",
    "falquejando": "falquejar",
    "falquejara": "falquejar",
    "falquejaram": "falquejar",
    "falquejaras": "falquejar",
    "falquejarde": "falquejar",
    "falquejardes": "falquejar",
    "falquejare": "falquejar",
    "falquejarei": "falquejar",
    "falquejareis": "falquejar",
    "falquejarem": "falquejar",
    "falquejaremos": "falquejar",
    "falquejares": "falquejar",
    "falquejaria": "falquejar",
    "falquejariam": "falquejar",
    "falquejarias": "falquejar",
    "falquejarmo": "falquejar",
    "falquejarmos": "falquejar",
    "falquejará": "falquejar",
    "falquejarás": "falquejar",
    "falquejarão": "falquejar",
    "falquejaríamos": "falquejar",
    "falquejaríeis": "falquejar",
    "falquejas": "falquejar",
    "falquejasse": "falquejar",
    "falquejassem": "falquejar",
    "falquejasses": "falquejar",
    "falquejaste": "falquejar",
    "falquejastes": "falquejar",
    "falquejava": "falquejar",
    "falquejavam": "falquejar",
    "falquejavas": "falquejar",
    "falqueje": "falquejar",
    "falquejei": "falquejar",
    "falquejeis": "falquejar",
    "falquejem": "falquejar",
    "falquejemo": "falquejar",
    "falquejemos": "falquejar",
    "falquejes": "falquejar",
    "falquejo": "falquejar",
    "falquejos": "falquejo",
    "falquejou": "falquejar",
    "falquejá": "falquejar",
    "falquejámo": "falquejar",
    "falquejámos": "falquejar",
    "falquejáramo": "falquejar",
    "falquejáramos": "falquejar",
    "falquejárei": "falquejar",
    "falquejáreis": "falquejar",
    "falquejásseis": "falquejar",
    "falquejássemos": "falquejar",
    "falquejávamo": "falquejar",
    "falquejávamos": "falquejar",
    "falquejávei": "falquejar",
    "falquejáveis": "falquejar",
    "falqueou": "falquear",
    "falquetas": "falqueta",
    "falqueá": "falquear",
    "falqueámo": "falquear",
    "falqueámos": "falquear",
    "falqueáramo": "falquear",
    "falqueáramos": "falquear",
    "falqueárei": "falquear",
    "falqueáreis": "falquear",
    "falqueásseis": "falquear",
    "falqueássemos": "falquear",
    "falqueávamo": "falquear",
    "falqueávamos": "falquear",
    "falqueávei": "falquear",
    "falqueáveis": "falquear",
    "falsa": "falso",
    "falsada": "falsar",
    "falsadas": "falsar",
    "falsado": "falsar",
    "falsadora": "falsador",
    "falsadoras": "falsador",
    "falsadores": "falsador",
    "falsados": "falsar",
    "falsai": "falsar",
    "falsais": "falsar",
    "falsam": "falsar",
    "falsamo": "falsar",
    "falsamos": "falsar",
    "falsando": "falsar",
    "falsara": "falsar",
    "falsaram": "falsar",
    "falsaras": "falsar",
    "falsarde": "falsar",
    "falsardes": "falsar",
    "falsare": "falsar",
    "falsarei": "falsar",
    "falsareis": "falsar",
    "falsarem": "falsar",
    "falsaremos": "falsar",
    "falsares": "falsar",
    "falsaria": "falsar",
    "falsariam": "falsar",
    "falsarias": "falsar",
    "falsarmo": "falsar",
    "falsarmos": "falsar",
    "falsará": "falsar",
    "falsarás": "falsar",
    "falsarão": "falsar",
    "falsaríamos": "falsar",
    "falsaríeis": "falsar",
    "falsas": "falso",
    "falsasse": "falsar",
    "falsassem": "falsar",
    "falsasses": "falsar",
    "falsaste": "falsar",
    "falsastes": "falsar",
    "falsava": "falsar",
    "falsavam": "falsar",
    "falsavas": "falsar",
    "false": "falsar",
    "falseada": "falsear",
    "falseadas": "falsear",
    "falseado": "falsear",
    "falseadora": "falseador",
    "falseadoras": "falseador",
    "falseadores": "falseador",
    "falseados": "falsear",
    "falseai": "falsear",
    "falseais": "falsear",
    "falseamentos": "falseamento",
    "falseamo": "falsear",
    "falseamos": "falsear",
    "falseando": "falsear",
    "falseara": "falsear",
    "falsearam": "falsear",
    "falsearas": "falsear",
    "falsearde": "falsear",
    "falseardes": "falsear",
    "falseare": "falsear",
    "falsearei": "falsear",
    "falseareis": "falsear",
    "falsearem": "falsear",
    "falsearemos": "falsear",
    "falseares": "falsear",
    "falsearia": "falsear",
    "falseariam": "falsear",
    "falsearias": "falsear",
    "falsearmo": "falsear",
    "falsearmos": "falsear",
    "falseará": "falsear",
    "falsearás": "falsear",
    "falsearão": "falsear",
    "falsearíamos": "falsear",
    "falsearíeis": "falsear",
    "falseasse": "falsear",
    "falseassem": "falsear",
    "falseasses": "falsear",
    "falseaste": "falsear",
    "falseastes": "falsear",
    "falseava": "falsear",
    "falseavam": "falsear",
    "falseavas": "falsear",
    "falseei": "falsear",
    "falseeis": "falsear",
    "falseemo": "falsear",
    "falseemos": "falsear",
    "falsei": "falsar",
    "falseia": "falsear",
    "falseiam": "falsear",
    "falseias": "falsear",
    "falseie": "falsear",
    "falseiem": "falsear",
    "falseies": "falsear",
    "falseio": "falsear",
    "falseis": "falsar",
    "falsem": "falsar",
    "falsemo": "falsar",
    "falsemos": "falsar",
    "falseou": "falsear",
    "falses": "falsar",
    "falseteada": "falsetear",
    "falseteadas": "falsetear",
    "falseteado": "falsetear",
    "falseteados": "falsetear",
    "falseteai": "falsetear",
    "falseteais": "falsetear",
    "falseteamo": "falsetear",
    "falseteamos": "falsetear",
    "falseteando": "falsetear",
    "falseteara": "falsetear",
    "falsetearam": "falsetear",
    "falsetearas": "falsetear",
    "falsetearde": "falsetear",
    "falseteardes": "falsetear",
    "falseteare": "falsetear",
    "falsetearei": "falsetear",
    "falseteareis": "falsetear",
    "falsetearem": "falsetear",
    "falsetearemos": "falsetear",
    "falseteares": "falsetear",
    "falsetearia": "falsetear",
    "falseteariam": "falsetear",
    "falsetearias": "falsetear",
    "falsetearmo": "falsetear",
    "falsetearmos": "falsetear",
    "falseteará": "falsetear",
    "falsetearás": "falsetear",
    "falsetearão": "falsetear",
    "falsetearíamos": "falsetear",
    "falsetearíeis": "falsetear",
    "falseteasse": "falsetear",
    "falseteassem": "falsetear",
    "falseteasses": "falsetear",
    "falseteaste": "falsetear",
    "falseteastes": "falsetear",
    "falseteava": "falsetear",
    "falseteavam": "falsetear",
    "falseteavas": "falsetear",
    "falseteei": "falsetear",
    "falseteeis": "falsetear",
    "falseteemo": "falsetear",
    "falseteemos": "falsetear",
    "falseteia": "falsetear",
    "falseteiam": "falsetear",
    "falseteias": "falsetear",
    "falseteie": "falsetear",
    "falseteiem": "falsetear",
    "falseteies": "falsetear",
    "falseteio": "falsetear",
    "falseteou": "falsetear",
    "falsetes": "falsete",
    "falseteá": "falsetear",
    "falseteámo": "falsetear",
    "falseteámos": "falsetear",
    "falseteáramo": "falsetear",
    "falseteáramos": "falsetear",
    "falseteárei": "falsetear",
    "falseteáreis": "falsetear",
    "falseteásseis": "falsetear",
    "falseteássemos": "falsetear",
    "falseteávamo": "falsetear",
    "falseteávamos": "falsetear",
    "falseteávei": "falsetear",
    "falseteáveis": "falsetear",
    "falseá": "falsear",
    "falseámo": "falsear",
    "falseámos": "falsear",
    "falseáramo": "falsear",
    "falseáramos": "falsear",
    "falseárei": "falsear",
    "falseáreis": "falsear",
    "falseásseis": "falsear",
    "falseássemos": "falsear",
    "falseávamo": "falsear",
    "falseávamos": "falsear",
    "falseávei": "falsear",
    "falseáveis": "falseável",
    "falsidades": "falsidade",
    "falsifica": "falsificar",
    "falsificada": "falsificar",
    "falsificadas": "falsificar",
    "falsificado": "falsificar",
    "falsificadora": "falsificador",
    "falsificadoras": "falsificador",
    "falsificadores": "falsificador",
    "falsificados": "falsificar",
    "falsificai": "falsificar",
    "falsificais": "falsificar",
    "falsificam": "falsificar",
    "falsificamo": "falsificar",
    "falsificamos": "falsificar",
    "falsificando": "falsificar",
    "falsificara": "falsificar",
    "falsificaram": "falsificar",
    "falsificaras": "falsificar",
    "falsificarde": "falsificar",
    "falsificardes": "falsificar",
    "falsificare": "falsificar",
    "falsificarei": "falsificar",
    "falsificareis": "falsificar",
    "falsificarem": "falsificar",
    "falsificaremos": "falsificar",
    "falsificares": "falsificar",
    "falsificaria": "falsificar",
    "falsificariam": "falsificar",
    "falsificarias": "falsificar",
    "falsificarmo": "falsificar",
    "falsificarmos": "falsificar",
    "falsificará": "falsificar",
    "falsificarás": "falsificar",
    "falsificarão": "falsificar",
    "falsificaríamos": "falsificar",
    "falsificaríeis": "falsificar",
    "falsificas": "falsificar",
    "falsificasse": "falsificar",
    "falsificassem": "falsificar",
    "falsificasses": "falsificar",
    "falsificaste": "falsificar",
    "falsificastes": "falsificar",
    "falsificava": "falsificar",
    "falsificavam": "falsificar",
    "falsificavas": "falsificar",
    "falsificações": "falsificação",
    "falsifico": "falsificar",
    "falsificou": "falsificar",
    "falsificá": "falsificar",
    "falsificámo": "falsificar",
    "falsificámos": "falsificar",
    "falsificáramo": "falsificar",
    "falsificáramos": "falsificar",
    "falsificárei": "falsificar",
    "falsificáreis": "falsificar",
    "falsificásseis": "falsificar",
    "falsificássemos": "falsificar",
    "falsificávamo": "falsificar",
    "falsificávamos": "falsificar",
    "falsificávei": "falsificar",
    "falsificáveis": "falsificável",
    "falsifique": "falsificar",
    "falsifiquei": "falsificar",
    "falsifiqueis": "falsificar",
    "falsifiquem": "falsificar",
    "falsifiquemo": "falsificar",
    "falsifiquemos": "falsificar",
    "falsifiques": "falsificar",
    "falsinérvea": "falsinérveo",
    "falsinérveas": "falsinérveo",
    "falsinérveos": "falsinérveo",
    "falso": "falsar",
    "falsos": "falso",
    "falsou": "falsar",
    "falsá": "falsar",
    "falsámo": "falsar",
    "falsámos": "falsar",
    "falsáramo": "falsar",
    "falsáramos": "falsar",
    "falsárei": "falsar",
    "falsáreis": "falsar",
    "falsária": "falsário",
    "falsárias": "falsário",
    "falsários": "falsário",
    "falsásseis": "falsar",
    "falsássemos": "falsar",
    "falsávamo": "falsar",
    "falsávamos": "falsar",
    "falsávei": "falsar",
    "falsáveis": "falsar",
    "falsídias": "falsídia",
    "falsídica": "falsídico",
    "falsídicas": "falsídico",
    "falsídicos": "falsídico",
    "falsífica": "falsífico",
    "falsíficas": "falsífico",
    "falsíficos": "falsífico",
    "falta": "falto",
    "faltada": "faltar",
    "faltadas": "faltar",
    "faltado": "faltar",
    "faltados": "faltar",
    "faltai": "faltar",
    "faltais": "faltar",
    "faltam": "faltar",
    "faltamo": "faltar",
    "faltamos": "faltar",
    "faltando": "faltar",
    "faltara": "faltar",
    "faltaram": "faltar",
    "faltaras": "faltar",
    "faltardes": "faltar",
    "faltarei": "faltar",
    "faltareis": "faltar",
    "faltarem": "faltar",
    "faltaremos": "faltar",
    "faltares": "faltar",
    "faltaria": "faltar",
    "faltariam": "faltar",
    "faltarias": "faltar",
    "faltarmo": "faltar",
    "faltarmos": "faltar",
    "faltará": "faltar",
    "faltarás": "faltar",
    "faltarão": "faltar",
    "faltaríamos": "faltar",
    "faltaríeis": "faltar",
    "faltas": "falto",
    "faltasse": "faltar",
    "faltassem": "faltar",
    "faltasses": "faltar",
    "faltaste": "faltar",
    "faltastes": "faltar",
    "faltava": "faltar",
    "faltavam": "faltar",
    "faltavas": "faltar",
    "faltaças": "faltaça",
    "falte": "faltar",
    "faltei": "faltar",
    "falteis": "faltar",
    "faltem": "faltar",
    "faltemo": "faltar",
    "faltemos": "faltar",
    "faltes": "faltar",
    "falto": "faltar",
    "faltos": "falto",
    "faltosa": "faltoso",
    "faltosas": "faltoso",
    "faltosos": "faltoso",
    "faltou": "faltar",
    "faltámo": "faltar",
    "faltámos": "faltar",
    "faltáramo": "faltar",
    "faltáramos": "faltar",
    "faltáreis": "faltar",
    "faltásseis": "faltar",
    "faltássemos": "faltar",
    "faltávamo": "faltar",
    "faltávamos": "faltar",
    "faltáveis": "faltar",
    "faluas": "falua",
    "falucas": "faluca",
    "faluchos": "falucho",
    "falueiros": "falueiro",
    "falá": "falar",
    "falácias": "falácia",
    "falámo": "falar",
    "falámos": "falar",
    "faláramo": "falar",
    "faláramos": "falar",
    "falárei": "falar",
    "faláreis": "falar",
    "faláricas": "falárica",
    "falásseis": "falar",
    "falássemos": "falar",
    "falávamo": "falar",
    "falávamos": "falar",
    "falávei": "falar",
    "faláveis": "falar",
    "falângica": "falângico",
    "falângicas": "falângico",
    "falângicos": "falângico",
    "falécia": "falécio",
    "falécias": "falécio",
    "falécios": "falécio",
    "falésias": "falésia",
    "falências": "falência",
    "falíamo": "falir",
    "falíamos": "falir",
    "falíeis": "falir",
    "falíramo": "falir",
    "falíramos": "falir",
    "falíreis": "falir",
    "falísseis": "falir",
    "falíssemos": "falir",
    "falíveis": "falível",
    "falóforos": "falóforo",
    "famalicenses": "famalicense",
    "famanazes": "famanaz",
    "famas": "fama",
    "famelga": "famelgo",
    "famelgas": "famelgo",
    "famelgos": "famelgo",
    "famenianos": "fameniano",
    "famigerada": "famigerado",
    "famigeradas": "famigerado",
    "famigeradora": "famigerador",
    "famigeradoras": "famigerador",
    "famigeradores": "famigerador",
    "famigerados": "famigerado",
    "familiares": "familiar",
    "familiaridades": "familiaridade",
    "familiariza": "familiarizar",
    "familiarizada": "familiarizar",
    "familiarizadas": "familiarizar",
    "familiarizado": "familiarizar",
    "familiarizados": "familiarizar",
    "familiarizai": "familiarizar",
    "familiarizais": "familiarizar",
    "familiarizam": "familiarizar",
    "familiarizamo": "familiarizar",
    "familiarizamos": "familiarizar",
    "familiarizando": "familiarizar",
    "familiarizara": "familiarizar",
    "familiarizaram": "familiarizar",
    "familiarizaras": "familiarizar",
    "familiarizarde": "familiarizar",
    "familiarizardes": "familiarizar",
    "familiarizare": "familiarizar",
    "familiarizarei": "familiarizar",
    "familiarizareis": "familiarizar",
    "familiarizarem": "familiarizar",
    "familiarizaremos": "familiarizar",
    "familiarizares": "familiarizar",
    "familiarizaria": "familiarizar",
    "familiarizariam": "familiarizar",
    "familiarizarias": "familiarizar",
    "familiarizarmo": "familiarizar",
    "familiarizarmos": "familiarizar",
    "familiarizará": "familiarizar",
    "familiarizarás": "familiarizar",
    "familiarizarão": "familiarizar",
    "familiarizaríamos": "familiarizar",
    "familiarizaríeis": "familiarizar",
    "familiarizas": "familiarizar",
    "familiarizasse": "familiarizar",
    "familiarizassem": "familiarizar",
    "familiarizasses": "familiarizar",
    "familiarizaste": "familiarizar",
    "familiarizastes": "familiarizar",
    "familiarizava": "familiarizar",
    "familiarizavam": "familiarizar",
    "familiarizavas": "familiarizar",
    "familiarizações": "familiarização",
    "familiarize": "familiarizar",
    "familiarizei": "familiarizar",
    "familiarizeis": "familiarizar",
    "familiarizem": "familiarizar",
    "familiarizemo": "familiarizar",
    "familiarizemos": "familiarizar",
    "familiarizes": "familiarizar",
    "familiarizo": "familiarizar",
    "familiarizou": "familiarizar",
    "familiarizá": "familiarizar",
    "familiarizámo": "familiarizar",
    "familiarizámos": "familiarizar",
    "familiarizáramo": "familiarizar",
    "familiarizáramos": "familiarizar",
    "familiarizárei": "familiarizar",
    "familiarizáreis": "familiarizar",
    "familiarizásseis": "familiarizar",
    "familiarizássemos": "familiarizar",
    "familiarizávamo": "familiarizar",
    "familiarizávamos": "familiarizar",
    "familiarizávei": "familiarizar",
    "familiarizáveis": "familiarizar",
    "familistérios": "familistério",
    "familórias": "familória",
    "faminta": "faminto",
    "famintas": "faminto",
    "famintos": "faminto",
    "famosa": "famoso",
    "famosas": "famoso",
    "famosos": "famoso",
    "famosíssima": "famoso",
    "famosíssimas": "famoso",
    "famosíssimo": "famoso",
    "famosíssimos": "famoso",
    "famula": "famular",
    "famulada": "famular",
    "famuladas": "famular",
    "famulado": "famular",
    "famulados": "famular",
    "famulagens": "famulagem",
    "famulai": "famular",
    "famulais": "famular",
    "famulam": "famular",
    "famulamo": "famular",
    "famulamos": "famular",
    "famulando": "famular",
    "famulara": "famular",
    "famularam": "famular",
    "famularas": "famular",
    "famularde": "famular",
    "famulardes": "famular",
    "famulare": "famular",
    "famularei": "famular",
    "famulareis": "famular",
    "famularem": "famular",
    "famularemos": "famular",
    "famulares": "famular",
    "famularia": "famular",
    "famulariam": "famular",
    "famularias": "famular",
    "famularmo": "famular",
    "famularmos": "famular",
    "famulará": "famular",
    "famularás": "famular",
    "famularão": "famular",
    "famularíamos": "famular",
    "famularíeis": "famular",
    "famulas": "famular",
    "famulasse": "famular",
    "famulassem": "famular",
    "famulasses": "famular",
    "famulaste": "famular",
    "famulastes": "famular",
    "famulatos": "famulato",
    "famulatícia": "famulatício",
    "famulatícias": "famulatício",
    "famulatícios": "famulatício",
    "famulatória": "famulatório",
    "famulatórias": "famulatório",
    "famulatórios": "famulatório",
    "famulava": "famular",
    "famulavam": "famular",
    "famulavas": "famular",
    "famule": "famular",
    "famulei": "famular",
    "famuleis": "famular",
    "famulem": "famular",
    "famulemo": "famular",
    "famulemos": "famular",
    "famulenta": "famulento",
    "famulentas": "famulento",
    "famulentos": "famulento",
    "famules": "famular",
    "famulo": "famular",
    "famulou": "famular",
    "famulá": "famular",
    "famulámo": "famular",
    "famulámos": "famular",
    "famuláramo": "famular",
    "famuláramos": "famular",
    "famulárei": "famular",
    "famuláreis": "famular",
    "famulásseis": "famular",
    "famulássemos": "famular",
    "famulávamo": "famular",
    "famulávamos": "famular",
    "famulávei": "famular",
    "famuláveis": "famular",
    "famélica": "famélico",
    "famélicas": "famélico",
    "famélicos": "famélico",
    "famígera": "famígero",
    "famígeras": "famígero",
    "famígeros": "famígero",
    "famílias": "família",
    "fan": "fã",
    "fana": "fanar",
    "fanada": "fanar",
    "fanadas": "fanar",
    "fanado": "fanar",
    "fanados": "fanar",
    "fanai": "fanar",
    "fanais": "fanar",
    "fanam": "fanar",
    "fanamentos": "fanamento",
    "fanamo": "fanar",
    "fanamos": "fanar",
    "fanando": "fanar",
    "fanara": "fanar",
    "fanaram": "fanar",
    "fanaras": "fanar",
    "fanarde": "fanar",
    "fanardes": "fanar",
    "fanare": "fanar",
    "fanarei": "fanar",
    "fanareis": "fanar",
    "fanarem": "fanar",
    "fanaremos": "fanar",
    "fanares": "fanar",
    "fanaria": "fanar",
    "fanariam": "fanar",
    "fanarias": "fanar",
    "fanarmo": "fanar",
    "fanarmos": "fanar",
    "fanará": "fanar",
    "fanarás": "fanar",
    "fanarão": "fanar",
    "fanaríamos": "fanar",
    "fanaríeis": "fanar",
    "fanas": "fanar",
    "fanasse": "fanar",
    "fanassem": "fanar",
    "fanasses": "fanar",
    "fanaste": "fanar",
    "fanastes": "fanar",
    "fanatismos": "fanatismo",
    "fanatiza": "fanatizar",
    "fanatizada": "fanatizar",
    "fanatizadas": "fanatizar",
    "fanatizado": "fanatizar",
    "fanatizadora": "fanatizador",
    "fanatizadoras": "fanatizador",
    "fanatizadores": "fanatizador",
    "fanatizados": "fanatizar",
    "fanatizai": "fanatizar",
    "fanatizais": "fanatizar",
    "fanatizam": "fanatizar",
    "fanatizamo": "fanatizar",
    "fanatizamos": "fanatizar",
    "fanatizando": "fanatizar",
    "fanatizara": "fanatizar",
    "fanatizaram": "fanatizar",
    "fanatizaras": "fanatizar",
    "fanatizarde": "fanatizar",
    "fanatizardes": "fanatizar",
    "fanatizare": "fanatizar",
    "fanatizarei": "fanatizar",
    "fanatizareis": "fanatizar",
    "fanatizarem": "fanatizar",
    "fanatizaremos": "fanatizar",
    "fanatizares": "fanatizar",
    "fanatizaria": "fanatizar",
    "fanatizariam": "fanatizar",
    "fanatizarias": "fanatizar",
    "fanatizarmo": "fanatizar",
    "fanatizarmos": "fanatizar",
    "fanatizará": "fanatizar",
    "fanatizarás": "fanatizar",
    "fanatizarão": "fanatizar",
    "fanatizaríamos": "fanatizar",
    "fanatizaríeis": "fanatizar",
    "fanatizas": "fanatizar",
    "fanatizasse": "fanatizar",
    "fanatizassem": "fanatizar",
    "fanatizasses": "fanatizar",
    "fanatizaste": "fanatizar",
    "fanatizastes": "fanatizar",
    "fanatizava": "fanatizar",
    "fanatizavam": "fanatizar",
    "fanatizavas": "fanatizar",
    "fanatize": "fanatizar",
    "fanatizei": "fanatizar",
    "fanatizeis": "fanatizar",
    "fanatizem": "fanatizar",
    "fanatizemo": "fanatizar",
    "fanatizemos": "fanatizar",
    "fanatizes": "fanatizar",
    "fanatizo": "fanatizar",
    "fanatizou": "fanatizar",
    "fanatizá": "fanatizar",
    "fanatizámo": "fanatizar",
    "fanatizámos": "fanatizar",
    "fanatizáramo": "fanatizar",
    "fanatizáramos": "fanatizar",
    "fanatizárei": "fanatizar",
    "fanatizáreis": "fanatizar",
    "fanatizásseis": "fanatizar",
    "fanatizássemos": "fanatizar",
    "fanatizávamo": "fanatizar",
    "fanatizávamos": "fanatizar",
    "fanatizávei": "fanatizar",
    "fanatizáveis": "fanatizar",
    "fanava": "fanar",
    "fanavam": "fanar",
    "fanavas": "fanar",
    "fanações": "fanação",
    "fancaias": "fancaia",
    "fancarias": "fancaria",
    "fancas": "fanca",
    "fanchona": "fanchão",
    "fanchonas": "fanchão",
    "fanchonaça": "fanchonaço",
    "fanchonaças": "fanchonaço",
    "fanchonaços": "fanchonaço",
    "fanchões": "fanchão",
    "fandanga": "fandango",
    "fandangada": "fandangar",
    "fandangadas": "fandangar",
    "fandangado": "fandangar",
    "fandangados": "fandangar",
    "fandangagens": "fandangagem",
    "fandangai": "fandangar",
    "fandangais": "fandangar",
    "fandangam": "fandangar",
    "fandangamo": "fandangar",
    "fandangamos": "fandangar",
    "fandangando": "fandangar",
    "fandangara": "fandangar",
    "fandangaram": "fandangar",
    "fandangaras": "fandangar",
    "fandangardes": "fandangar",
    "fandangarei": "fandangar",
    "fandangareis": "fandangar",
    "fandangarem": "fandangar",
    "fandangaremos": "fandangar",
    "fandangares": "fandangar",
    "fandangaria": "fandangar",
    "fandangariam": "fandangar",
    "fandangarias": "fandangar",
    "fandangarmo": "fandangar",
    "fandangarmos": "fandangar",
    "fandangará": "fandangar",
    "fandangarás": "fandangar",
    "fandangarão": "fandangar",
    "fandangaríamos": "fandangar",
    "fandangaríeis": "fandangar",
    "fandangas": "fandango",
    "fandangasse": "fandangar",
    "fandangassem": "fandangar",
    "fandangasses": "fandangar",
    "fandangaste": "fandangar",
    "fandangastes": "fandangar",
    "fandangava": "fandangar",
    "fandangavam": "fandangar",
    "fandangavas": "fandangar",
    "fandango": "fandangar",
    "fandangos": "fandango",
    "fandangou": "fandangar",
    "fandangue": "fandangar",
    "fandangueada": "fandanguear",
    "fandangueadas": "fandanguear",
    "fandangueado": "fandanguear",
    "fandangueados": "fandanguear",
    "fandangueai": "fandanguear",
    "fandangueais": "fandanguear",
    "fandangueamo": "fandanguear",
    "fandangueamos": "fandanguear",
    "fandangueando": "fandanguear",
    "fandangueara": "fandanguear",
    "fandanguearam": "fandanguear",
    "fandanguearas": "fandanguear",
    "fandangueardes": "fandanguear",
    "fandanguearei": "fandanguear",
    "fandangueareis": "fandanguear",
    "fandanguearem": "fandanguear",
    "fandanguearemos": "fandanguear",
    "fandangueares": "fandanguear",
    "fandanguearia": "fandanguear",
    "fandangueariam": "fandanguear",
    "fandanguearias": "fandanguear",
    "fandanguearmo": "fandanguear",
    "fandanguearmos": "fandanguear",
    "fandangueará": "fandanguear",
    "fandanguearás": "fandanguear",
    "fandanguearão": "fandanguear",
    "fandanguearíamos": "fandanguear",
    "fandanguearíeis": "fandanguear",
    "fandangueasse": "fandanguear",
    "fandangueassem": "fandanguear",
    "fandangueasses": "fandanguear",
    "fandangueaste": "fandanguear",
    "fandangueastes": "fandanguear",
    "fandangueava": "fandanguear",
    "fandangueavam": "fandanguear",
    "fandangueavas": "fandanguear",
    "fandangueei": "fandanguear",
    "fandangueeis": "fandanguear",
    "fandangueemo": "fandanguear",
    "fandangueemos": "fandanguear",
    "fandanguei": "fandangar",
    "fandangueia": "fandanguear",
    "fandangueiam": "fandanguear",
    "fandangueias": "fandanguear",
    "fandangueie": "fandanguear",
    "fandangueiem": "fandanguear",
    "fandangueies": "fandanguear",
    "fandangueio": "fandanguear",
    "fandangueira": "fandangueiro",
    "fandangueiras": "fandangueiro",
    "fandangueiros": "fandangueiro",
    "fandangueis": "fandangar",
    "fandanguem": "fandangar",
    "fandanguemo": "fandangar",
    "fandanguemos": "fandangar",
    "fandangueou": "fandanguear",
    "fandangues": "fandangar",
    "fandangueámo": "fandanguear",
    "fandangueámos": "fandanguear",
    "fandangueáramo": "fandanguear",
    "fandangueáramos": "fandanguear",
    "fandangueáreis": "fandanguear",
    "fandangueásseis": "fandanguear",
    "fandangueássemos": "fandanguear",
    "fandangueávamo": "fandanguear",
    "fandangueávamos": "fandanguear",
    "fandangueáveis": "fandanguear",
    "fandanguistas": "fandanguista",
    "fandangámo": "fandangar",
    "fandangámos": "fandangar",
    "fandangáramo": "fandangar",
    "fandangáramos": "fandangar",
    "fandangáreis": "fandangar",
    "fandangásseis": "fandangar",
    "fandangássemos": "fandangar",
    "fandangávamo": "fandangar",
    "fandangávamos": "fandangar",
    "fandangáveis": "fandangar",
    "fane": "fanar",
    "faneca": "faneco",
    "fanecas": "faneco",
    "fanecos": "faneco",
    "fanecões": "fanecão",
    "fanegas": "fanega",
    "fanei": "fanar",
    "faneis": "fanar",
    "fanem": "fanar",
    "fanemo": "fanar",
    "fanemos": "fanar",
    "fanerocristais": "fanerocristal",
    "fanerogamias": "fanerogamia",
    "fanerogâmica": "fanerogâmico",
    "fanerogâmicas": "fanerogâmico",
    "fanerogâmicos": "fanerogâmico",
    "fanerítica": "fanerítico",
    "faneríticas": "fanerítico",
    "faneríticos": "fanerítico",
    "fanerógama": "fanerógamo",
    "fanerógamas": "fanerógamo",
    "fanerógamos": "fanerógamo",
    "fanes": "fanar",
    "fanfa": "fanfar",
    "fanfada": "fanfar",
    "fanfadas": "fanfar",
    "fanfado": "fanfar",
    "fanfados": "fanfar",
    "fanfai": "fanfar",
    "fanfais": "fanfar",
    "fanfam": "fanfar",
    "fanfamo": "fanfar",
    "fanfamos": "fanfar",
    "fanfando": "fanfar",
    "fanfara": "fanfar",
    "fanfaram": "fanfar",
    "fanfaras": "fanfar",
    "fanfardes": "fanfar",
    "fanfarei": "fanfar",
    "fanfareis": "fanfar",
    "fanfarem": "fanfar",
    "fanfaremos": "fanfar",
    "fanfares": "fanfar",
    "fanfaria": "fanfar",
    "fanfariam": "fanfar",
    "fanfarias": "fanfar",
    "fanfarmo": "fanfar",
    "fanfarmos": "fanfar",
    "fanfarradas": "fanfarrada",
    "fanfarrarias": "fanfarraria",
    "fanfarras": "fanfarra",
    "fanfarreada": "fanfarrear",
    "fanfarreadas": "fanfarrear",
    "fanfarreado": "fanfarrear",
    "fanfarreados": "fanfarrear",
    "fanfarreai": "fanfarrear",
    "fanfarreais": "fanfarrear",
    "fanfarreamo": "fanfarrear",
    "fanfarreamos": "fanfarrear",
    "fanfarreando": "fanfarrear",
    "fanfarreara": "fanfarrear",
    "fanfarrearam": "fanfarrear",
    "fanfarrearas": "fanfarrear",
    "fanfarreardes": "fanfarrear",
    "fanfarrearei": "fanfarrear",
    "fanfarreareis": "fanfarrear",
    "fanfarrearem": "fanfarrear",
    "fanfarrearemos": "fanfarrear",
    "fanfarreares": "fanfarrear",
    "fanfarrearia": "fanfarrear",
    "fanfarreariam": "fanfarrear",
    "fanfarrearias": "fanfarrear",
    "fanfarrearmo": "fanfarrear",
    "fanfarrearmos": "fanfarrear",
    "fanfarreará": "fanfarrear",
    "fanfarrearás": "fanfarrear",
    "fanfarrearão": "fanfarrear",
    "fanfarrearíamos": "fanfarrear",
    "fanfarrearíeis": "fanfarrear",
    "fanfarreasse": "fanfarrear",
    "fanfarreassem": "fanfarrear",
    "fanfarreasses": "fanfarrear",
    "fanfarreaste": "fanfarrear",
    "fanfarreastes": "fanfarrear",
    "fanfarreava": "fanfarrear",
    "fanfarreavam": "fanfarrear",
    "fanfarreavas": "fanfarrear",
    "fanfarreei": "fanfarrear",
    "fanfarreeis": "fanfarrear",
    "fanfarreemo": "fanfarrear",
    "fanfarreemos": "fanfarrear",
    "fanfarreia": "fanfarrear",
    "fanfarreiam": "fanfarrear",
    "fanfarreias": "fanfarrear",
    "fanfarreie": "fanfarrear",
    "fanfarreiem": "fanfarrear",
    "fanfarreies": "fanfarrear",
    "fanfarreio": "fanfarrear",
    "fanfarreou": "fanfarrear",
    "fanfarreámo": "fanfarrear",
    "fanfarreámos": "fanfarrear",
    "fanfarreáramo": "fanfarrear",
    "fanfarreáramos": "fanfarrear",
    "fanfarreáreis": "fanfarrear",
    "fanfarreásseis": "fanfarrear",
    "fanfarreássemos": "fanfarrear",
    "fanfarreávamo": "fanfarrear",
    "fanfarreávamos": "fanfarrear",
    "fanfarreáveis": "fanfarrear",
    "fanfarrias": "fanfarria",
    "fanfarrices": "fanfarrice",
    "fanfarrona": "fanfarronar",
    "fanfarronada": "fanfarronar",
    "fanfarronadas": "fanfarronar",
    "fanfarronado": "fanfarronar",
    "fanfarronados": "fanfarronar",
    "fanfarronai": "fanfarronar",
    "fanfarronais": "fanfarronar",
    "fanfarronam": "fanfarronar",
    "fanfarronamo": "fanfarronar",
    "fanfarronamos": "fanfarronar",
    "fanfarronando": "fanfarronar",
    "fanfarronara": "fanfarronar",
    "fanfarronaram": "fanfarronar",
    "fanfarronaras": "fanfarronar",
    "fanfarronardes": "fanfarronar",
    "fanfarronarei": "fanfarronar",
    "fanfarronareis": "fanfarronar",
    "fanfarronarem": "fanfarronar",
    "fanfarronaremos": "fanfarronar",
    "fanfarronares": "fanfarronar",
    "fanfarronaria": "fanfarronar",
    "fanfarronariam": "fanfarronar",
    "fanfarronarias": "fanfarronar",
    "fanfarronarmo": "fanfarronar",
    "fanfarronarmos": "fanfarronar",
    "fanfarronará": "fanfarronar",
    "fanfarronarás": "fanfarronar",
    "fanfarronarão": "fanfarronar",
    "fanfarronaríamos": "fanfarronar",
    "fanfarronaríeis": "fanfarronar",
    "fanfarronas": "fanfarronar",
    "fanfarronasse": "fanfarronar",
    "fanfarronassem": "fanfarronar",
    "fanfarronasses": "fanfarronar",
    "fanfarronaste": "fanfarronar",
    "fanfarronastes": "fanfarronar",
    "fanfarronava": "fanfarronar",
    "fanfarronavam": "fanfarronar",
    "fanfarronavas": "fanfarronar",
    "fanfarrone": "fanfarronar",
    "fanfarronei": "fanfarronar",
    "fanfarroneis": "fanfarronar",
    "fanfarronem": "fanfarronar",
    "fanfarronemo": "fanfarronar",
    "fanfarronemos": "fanfarronar",
    "fanfarrones": "fanfarronar",
    "fanfarronices": "fanfarronice",
    "fanfarrono": "fanfarronar",
    "fanfarronou": "fanfarronar",
    "fanfarronámo": "fanfarronar",
    "fanfarronámos": "fanfarronar",
    "fanfarronáramo": "fanfarronar",
    "fanfarronáramos": "fanfarronar",
    "fanfarronáreis": "fanfarronar",
    "fanfarronásseis": "fanfarronar",
    "fanfarronássemos": "fanfarronar",
    "fanfarronávamo": "fanfarronar",
    "fanfarronávamos": "fanfarronar",
    "fanfarronáveis": "fanfarronar",
    "fanfarrónica": "fanfarrónico",
    "fanfarrónicas": "fanfarrónico",
    "fanfarrónicos": "fanfarrónico",
    "fanfarrões": "fanfarrão",
    "fanfará": "fanfar",
    "fanfarás": "fanfar",
    "fanfarão": "fanfar",
    "fanfaríamos": "fanfar",
    "fanfaríeis": "fanfar",
    "fanfas": "fanfar",
    "fanfasse": "fanfar",
    "fanfassem": "fanfar",
    "fanfasses": "fanfar",
    "fanfaste": "fanfar",
    "fanfastes": "fanfar",
    "fanfava": "fanfar",
    "fanfavam": "fanfar",
    "fanfavas": "fanfar",
    "fanfe": "fanfar",
    "fanfei": "fanfar",
    "fanfeis": "fanfar",
    "fanfem": "fanfar",
    "fanfemo": "fanfar",
    "fanfemos": "fanfar",
    "fanfes": "fanfar",
    "fanfo": "fanfar",
    "fanfou": "fanfar",
    "fanfreluches": "fanfreluche",
    "fanfurrices": "fanfurrice",
    "fanfámo": "fanfar",
    "fanfámos": "fanfar",
    "fanfáramo": "fanfar",
    "fanfáramos": "fanfar",
    "fanfáreis": "fanfar",
    "fanfásseis": "fanfar",
    "fanfássemos": "fanfar",
    "fanfávamo": "fanfar",
    "fanfávamos": "fanfar",
    "fanfáveis": "fanfar",
    "fanfãs": "fanfã",
    "fanfúrrias": "fanfúrria",
    "fangas": "fanga",
    "fanglomerados": "fanglomerado",
    "fangueira": "fangueiro",
    "fangueiradas": "fangueirada",
    "fangueiras": "fangueiro",
    "fangueiros": "fangueiro",
    "fanhas": "fanha",
    "fanhosa": "fanhoso",
    "fanhosas": "fanhoso",
    "fanhoseada": "fanhosear",
    "fanhoseadas": "fanhosear",
    "fanhoseado": "fanhosear",
    "fanhoseados": "fanhosear",
    "fanhoseai": "fanhosear",
    "fanhoseais": "fanhosear",
    "fanhoseamo": "fanhosear",
    "fanhoseamos": "fanhosear",
    "fanhoseando": "fanhosear",
    "fanhoseara": "fanhosear",
    "fanhosearam": "fanhosear",
    "fanhosearas": "fanhosear",
    "fanhoseardes": "fanhosear",
    "fanhosearei": "fanhosear",
    "fanhoseareis": "fanhosear",
    "fanhosearem": "fanhosear",
    "fanhosearemos": "fanhosear",
    "fanhoseares": "fanhosear",
    "fanhosearia": "fanhosear",
    "fanhoseariam": "fanhosear",
    "fanhosearias": "fanhosear",
    "fanhosearmo": "fanhosear",
    "fanhosearmos": "fanhosear",
    "fanhoseará": "fanhosear",
    "fanhosearás": "fanhosear",
    "fanhosearão": "fanhosear",
    "fanhosearíamos": "fanhosear",
    "fanhosearíeis": "fanhosear",
    "fanhoseasse": "fanhosear",
    "fanhoseassem": "fanhosear",
    "fanhoseasses": "fanhosear",
    "fanhoseaste": "fanhosear",
    "fanhoseastes": "fanhosear",
    "fanhoseava": "fanhosear",
    "fanhoseavam": "fanhosear",
    "fanhoseavas": "fanhosear",
    "fanhoseei": "fanhosear",
    "fanhoseeis": "fanhosear",
    "fanhoseemo": "fanhosear",
    "fanhoseemos": "fanhosear",
    "fanhoseia": "fanhosear",
    "fanhoseiam": "fanhosear",
    "fanhoseias": "fanhosear",
    "fanhoseie": "fanhosear",
    "fanhoseiem": "fanhosear",
    "fanhoseies": "fanhosear",
    "fanhoseio": "fanhosear",
    "fanhoseou": "fanhosear",
    "fanhoseámo": "fanhosear",
    "fanhoseámos": "fanhosear",
    "fanhoseáramo": "fanhosear",
    "fanhoseáramos": "fanhosear",
    "fanhoseáreis": "fanhosear",
    "fanhoseásseis": "fanhosear",
    "fanhoseássemos": "fanhosear",
    "fanhoseávamo": "fanhosear",
    "fanhoseávamos": "fanhosear",
    "fanhoseáveis": "fanhosear",
    "fanhosos": "fanhoso",
    "fanica": "fanicar",
    "fanicada": "fanicar",
    "fanicadas": "fanicar",
    "fanicado": "fanicar",
    "fanicados": "fanicar",
    "fanicais": "fanicar",
    "fanicam": "fanicar",
    "fanicamo": "fanicar",
    "fanicamos": "fanicar",
    "fanicando": "fanicar",
    "fanicara": "fanicar",
    "fanicaram": "fanicar",
    "fanicaras": "fanicar",
    "fanicardes": "fanicar",
    "fanicarei": "fanicar",
    "fanicareis": "fanicar",
    "fanicarem": "fanicar",
    "fanicaremos": "fanicar",
    "fanicares": "fanicar",
    "fanicaria": "fanicar",
    "fanicariam": "fanicar",
    "fanicarias": "fanicar",
    "fanicarmo": "fanicar",
    "fanicarmos": "fanicar",
    "fanicará": "fanicar",
    "fanicarás": "fanicar",
    "fanicarão": "fanicar",
    "fanicaríamos": "fanicar",
    "fanicaríeis": "fanicar",
    "fanicas": "fanicar",
    "fanicasse": "fanicar",
    "fanicassem": "fanicar",
    "fanicasses": "fanicar",
    "fanicaste": "fanicar",
    "fanicastes": "fanicar",
    "fanicava": "fanicar",
    "fanicavam": "fanicar",
    "fanicavas": "fanicar",
    "fanico": "fanicar",
    "fanicos": "fanico",
    "fanicou": "fanicar",
    "fanicámo": "fanicar",
    "fanicámos": "fanicar",
    "fanicáramo": "fanicar",
    "fanicáramos": "fanicar",
    "fanicáreis": "fanicar",
    "fanicásseis": "fanicar",
    "fanicássemos": "fanicar",
    "fanicávamo": "fanicar",
    "fanicávamos": "fanicar",
    "fanicáveis": "fanicar",
    "fanique": "fanicar",
    "faniquei": "fanicar",
    "faniqueira": "faniqueiro",
    "faniqueiras": "faniqueiro",
    "faniqueiros": "faniqueiro",
    "faniqueis": "fanicar",
    "faniquem": "fanicar",
    "faniquemos": "fanicar",
    "faniquenta": "faniquento",
    "faniquentas": "faniquento",
    "faniquentos": "faniquento",
    "faniques": "fanicar",
    "fano": "fanar",
    "fanou": "fanar",
    "fanqueiros": "fanqueiro",
    "fans": "fã",
    "fantarelos": "fantarelo",
    "fantascópica": "fantascópico",
    "fantascópicas": "fantascópico",
    "fantascópicos": "fantascópico",
    "fantascópios": "fantascópio",
    "fantasia": "fantasiar",
    "fantasiada": "fantasiar",
    "fantasiadas": "fantasiar",
    "fantasiado": "fantasiar",
    "fantasiadora": "fantasiador",
    "fantasiadoras": "fantasiador",
    "fantasiadores": "fantasiador",
    "fantasiados": "fantasiar",
    "fantasiai": "fantasiar",
    "fantasiais": "fantasiar",
    "fantasiam": "fantasiar",
    "fantasiamo": "fantasiar",
    "fantasiamos": "fantasiar",
    "fantasiando": "fantasiar",
    "fantasiara": "fantasiar",
    "fantasiaram": "fantasiar",
    "fantasiaras": "fantasiar",
    "fantasiarde": "fantasiar",
    "fantasiardes": "fantasiar",
    "fantasiare": "fantasiar",
    "fantasiarei": "fantasiar",
    "fantasiareis": "fantasiar",
    "fantasiarem": "fantasiar",
    "fantasiaremos": "fantasiar",
    "fantasiares": "fantasiar",
    "fantasiaria": "fantasiar",
    "fantasiariam": "fantasiar",
    "fantasiarias": "fantasiar",
    "fantasiarmo": "fantasiar",
    "fantasiarmos": "fantasiar",
    "fantasiará": "fantasiar",
    "fantasiarás": "fantasiar",
    "fantasiarão": "fantasiar",
    "fantasiaríamos": "fantasiar",
    "fantasiaríeis": "fantasiar",
    "fantasias": "fantasiar",
    "fantasiasse": "fantasiar",
    "fantasiassem": "fantasiar",
    "fantasiasses": "fantasiar",
    "fantasiaste": "fantasiar",
    "fantasiastes": "fantasiar",
    "fantasiava": "fantasiar",
    "fantasiavam": "fantasiar",
    "fantasiavas": "fantasiar",
    "fantasie": "fantasiar",
    "fantasiei": "fantasiar",
    "fantasieis": "fantasiar",
    "fantasiem": "fantasiar",
    "fantasiemo": "fantasiar",
    "fantasiemos": "fantasiar",
    "fantasies": "fantasiar",
    "fantasio": "fantasiar",
    "fantasiosa": "fantasioso",
    "fantasiosas": "fantasioso",
    "fantasiosos": "fantasioso",
    "fantasiou": "fantasiar",
    "fantasistas": "fantasista",
    "fantasiá": "fantasiar",
    "fantasiámo": "fantasiar",
    "fantasiámos": "fantasiar",
    "fantasiáramo": "fantasiar",
    "fantasiáramos": "fantasiar",
    "fantasiárei": "fantasiar",
    "fantasiáreis": "fantasiar",
    "fantasiásseis": "fantasiar",
    "fantasiássemos": "fantasiar",
    "fantasiávamo": "fantasiar",
    "fantasiávamos": "fantasiar",
    "fantasiávei": "fantasiar",
    "fantasiáveis": "fantasiar",
    "fantasmagorias": "fantasmagoria",
    "fantasmagoriza": "fantasmagorizar",
    "fantasmagorizada": "fantasmagorizar",
    "fantasmagorizadas": "fantasmagorizar",
    "fantasmagorizado": "fantasmagorizar",
    "fantasmagorizados": "fantasmagorizar",
    "fantasmagorizai": "fantasmagorizar",
    "fantasmagorizais": "fantasmagorizar",
    "fantasmagorizam": "fantasmagorizar",
    "fantasmagorizamo": "fantasmagorizar",
    "fantasmagorizamos": "fantasmagorizar",
    "fantasmagorizando": "fantasmagorizar",
    "fantasmagorizara": "fantasmagorizar",
    "fantasmagorizaram": "fantasmagorizar",
    "fantasmagorizaras": "fantasmagorizar",
    "fantasmagorizarde": "fantasmagorizar",
    "fantasmagorizardes": "fantasmagorizar",
    "fantasmagorizare": "fantasmagorizar",
    "fantasmagorizarei": "fantasmagorizar",
    "fantasmagorizareis": "fantasmagorizar",
    "fantasmagorizarem": "fantasmagorizar",
    "fantasmagorizaremos": "fantasmagorizar",
    "fantasmagorizares": "fantasmagorizar",
    "fantasmagorizaria": "fantasmagorizar",
    "fantasmagorizariam": "fantasmagorizar",
    "fantasmagorizarias": "fantasmagorizar",
    "fantasmagorizarmo": "fantasmagorizar",
    "fantasmagorizarmos": "fantasmagorizar",
    "fantasmagorizará": "fantasmagorizar",
    "fantasmagorizarás": "fantasmagorizar",
    "fantasmagorizarão": "fantasmagorizar",
    "fantasmagorizaríamos": "fantasmagorizar",
    "fantasmagorizaríeis": "fantasmagorizar",
    "fantasmagorizas": "fantasmagorizar",
    "fantasmagorizasse": "fantasmagorizar",
    "fantasmagorizassem": "fantasmagorizar",
    "fantasmagorizasses": "fantasmagorizar",
    "fantasmagorizaste": "fantasmagorizar",
    "fantasmagorizastes": "fantasmagorizar",
    "fantasmagorizava": "fantasmagorizar",
    "fantasmagorizavam": "fantasmagorizar",
    "fantasmagorizavas": "fantasmagorizar",
    "fantasmagorize": "fantasmagorizar",
    "fantasmagorizei": "fantasmagorizar",
    "fantasmagorizeis": "fantasmagorizar",
    "fantasmagorizem": "fantasmagorizar",
    "fantasmagorizemo": "fantasmagorizar",
    "fantasmagorizemos": "fantasmagorizar",
    "fantasmagorizes": "fantasmagorizar",
    "fantasmagorizo": "fantasmagorizar",
    "fantasmagorizou": "fantasmagorizar",
    "fantasmagorizá": "fantasmagorizar",
    "fantasmagorizámo": "fantasmagorizar",
    "fantasmagorizámos": "fantasmagorizar",
    "fantasmagorizáramo": "fantasmagorizar",
    "fantasmagorizáramos": "fantasmagorizar",
    "fantasmagorizárei": "fantasmagorizar",
    "fantasmagorizáreis": "fantasmagorizar",
    "fantasmagorizásseis": "fantasmagorizar",
    "fantasmagorizássemos": "fantasmagorizar",
    "fantasmagorizávamo": "fantasmagorizar",
    "fantasmagorizávamos": "fantasmagorizar",
    "fantasmagorizávei": "fantasmagorizar",
    "fantasmagorizáveis": "fantasmagorizar",
    "fantasmagórica": "fantasmagórico",
    "fantasmagóricas": "fantasmagórico",
    "fantasmagóricos": "fantasmagórico",
    "fantasmais": "fantasmal",
    "fantasmas": "fantasma",
    "fantasmazinho": "fantasma",
    "fantasmazinhos": "fantasma",
    "fantasmazito": "fantasma",
    "fantasmazitos": "fantasma",
    "fantasminha": "fantasma",
    "fantasminhas": "fantasma",
    "fantasmita": "fantasma",
    "fantasmitas": "fantasma",
    "fantasmática": "fantasmático",
    "fantasmáticas": "fantasmático",
    "fantasmáticos": "fantasmático",
    "fantastiquices": "fantastiquice",
    "fantis": "fantil",
    "fantocha": "fantochar",
    "fantochada": "fantochar",
    "fantochadas": "fantochar",
    "fantochado": "fantochar",
    "fantochados": "fantochar",
    "fantochai": "fantochar",
    "fantochais": "fantochar",
    "fantocham": "fantochar",
    "fantochamo": "fantochar",
    "fantochamos": "fantochar",
    "fantochando": "fantochar",
    "fantochara": "fantochar",
    "fantocharam": "fantochar",
    "fantocharas": "fantochar",
    "fantochardes": "fantochar",
    "fantocharei": "fantochar",
    "fantochareis": "fantochar",
    "fantocharem": "fantochar",
    "fantocharemos": "fantochar",
    "fantochares": "fantochar",
    "fantocharia": "fantochar",
    "fantochariam": "fantochar",
    "fantocharias": "fantochar",
    "fantocharmo": "fantochar",
    "fantocharmos": "fantochar",
    "fantochará": "fantochar",
    "fantocharás": "fantochar",
    "fantocharão": "fantochar",
    "fantocharíamos": "fantochar",
    "fantocharíeis": "fantochar",
    "fantochas": "fantochar",
    "fantochasse": "fantochar",
    "fantochassem": "fantochar",
    "fantochasses": "fantochar",
    "fantochaste": "fantochar",
    "fantochastes": "fantochar",
    "fantochava": "fantochar",
    "fantochavam": "fantochar",
    "fantochavas": "fantochar",
    "fantoche": "fantochar",
    "fantochei": "fantochar",
    "fantocheis": "fantochar",
    "fantochem": "fantochar",
    "fantochemo": "fantochar",
    "fantochemos": "fantochar",
    "fantoches": "fantoche",
    "fantocho": "fantochar",
    "fantochou": "fantochar",
    "fantochámo": "fantochar",
    "fantochámos": "fantochar",
    "fantocháramo": "fantochar",
    "fantocháramos": "fantochar",
    "fantocháreis": "fantochar",
    "fantochásseis": "fantochar",
    "fantochássemos": "fantochar",
    "fantochávamo": "fantochar",
    "fantochávamos": "fantochar",
    "fantocháveis": "fantochar",
    "fantástica": "fantástico",
    "fantásticas": "fantástico",
    "fantásticos": "fantástico",
    "fantãs": "fantã",
    "faná": "fanar",
    "fanámo": "fanar",
    "fanámos": "fanar",
    "fanáramo": "fanar",
    "fanáramos": "fanar",
    "fanárei": "fanar",
    "fanáreis": "fanar",
    "fanásseis": "fanar",
    "fanássemos": "fanar",
    "fanática": "fanático",
    "fanáticas": "fanático",
    "fanáticos": "fanático",
    "fanávamo": "fanar",
    "fanávamos": "fanar",
    "fanávei": "fanar",
    "fanáveis": "fanável",
    "fanões": "fanão",
    "faqueiros": "faqueiro",
    "faquinha": "faca",
    "faquinhas": "faca",
    "faquinos": "faquino",
    "faquires": "faquir",
    "faquirismos": "faquirismo",
    "faquistas": "faquista",
    "faquita": "faca",
    "faquitas": "faca",
    "fara": "farar",
    "farada": "farar",
    "faradas": "farar",
    "faradays": "faraday",
    "faradismos": "faradismo",
    "faradiza": "faradizar",
    "faradizada": "faradizar",
    "faradizadas": "faradizar",
    "faradizado": "faradizar",
    "faradizados": "faradizar",
    "faradizai": "faradizar",
    "faradizais": "faradizar",
    "faradizam": "faradizar",
    "faradizamo": "faradizar",
    "faradizamos": "faradizar",
    "faradizando": "faradizar",
    "faradizara": "faradizar",
    "faradizaram": "faradizar",
    "faradizaras": "faradizar",
    "faradizarde": "faradizar",
    "faradizardes": "faradizar",
    "faradizare": "faradizar",
    "faradizarei": "faradizar",
    "faradizareis": "faradizar",
    "faradizarem": "faradizar",
    "faradizaremos": "faradizar",
    "faradizares": "faradizar",
    "faradizaria": "faradizar",
    "faradizariam": "faradizar",
    "faradizarias": "faradizar",
    "faradizarmo": "faradizar",
    "faradizarmos": "faradizar",
    "faradizará": "faradizar",
    "faradizarás": "faradizar",
    "faradizarão": "faradizar",
    "faradizaríamos": "faradizar",
    "faradizaríeis": "faradizar",
    "faradizas": "faradizar",
    "faradizasse": "faradizar",
    "faradizassem": "faradizar",
    "faradizasses": "faradizar",
    "faradizaste": "faradizar",
    "faradizastes": "faradizar",
    "faradizava": "faradizar",
    "faradizavam": "faradizar",
    "faradizavas": "faradizar",
    "faradizações": "faradização",
    "faradize": "faradizar",
    "faradizei": "faradizar",
    "faradizeis": "faradizar",
    "faradizem": "faradizar",
    "faradizemo": "faradizar",
    "faradizemos": "faradizar",
    "faradizes": "faradizar",
    "faradizo": "faradizar",
    "faradizou": "faradizar",
    "faradizá": "faradizar",
    "faradizámo": "faradizar",
    "faradizámos": "faradizar",
    "faradizáramo": "faradizar",
    "faradizáramos": "faradizar",
    "faradizárei": "faradizar",
    "faradizáreis": "faradizar",
    "faradizásseis": "faradizar",
    "faradizássemos": "faradizar",
    "faradizávamo": "faradizar",
    "faradizávamos": "faradizar",
    "faradizávei": "faradizar",
    "faradizáveis": "faradizar",
    "farado": "farar",
    "farados": "farar",
    "farads": "farad",
    "farai": "farar",
    "farais": "farar",
    "faram": "farar",
    "faramalhas": "faramalha",
    "faramalheira": "faramalheiro",
    "faramalheiras": "faramalheiro",
    "faramalheiros": "faramalheiro",
    "faramelhices": "faramelhice",
    "faramo": "farar",
    "faramos": "farar",
    "farando": "farar",
    "farandolagens": "farandolagem",
    "farantas": "faranta",
    "farantes": "farante",
    "farara": "farar",
    "fararam": "farar",
    "fararas": "farar",
    "fararde": "farar",
    "farardes": "farar",
    "farare": "farar",
    "fararei": "farar",
    "farareis": "farar",
    "fararem": "farar",
    "fararemos": "farar",
    "farares": "farar",
    "fararia": "farar",
    "farariam": "farar",
    "fararias": "farar",
    "fararmo": "farar",
    "fararmos": "farar",
    "farará": "farar",
    "fararás": "farar",
    "fararão": "farar",
    "fararíamos": "farar",
    "fararíeis": "farar",
    "faras": "farar",
    "farasse": "farar",
    "farassem": "farar",
    "farasses": "farar",
    "faraste": "farar",
    "farastes": "farar",
    "farautes": "faraute",
    "farava": "farar",
    "faravam": "farar",
    "faravas": "farar",
    "faraónica": "faraónico",
    "faraónicas": "faraónico",
    "faraónicos": "faraónico",
    "faraós": "faraó",
    "farcinos": "farcino",
    "farda": "fardar",
    "fardada": "fardar",
    "fardadas": "fardar",
    "fardado": "fardar",
    "fardados": "fardar",
    "fardagens": "fardagem",
    "fardai": "fardar",
    "fardais": "fardar",
    "fardalhões": "fardalhão",
    "fardam": "fardar",
    "fardamentas": "fardamenta",
    "fardamentos": "fardamento",
    "fardamo": "fardar",
    "fardamos": "fardar",
    "fardando": "fardar",
    "fardara": "fardar",
    "fardaram": "fardar",
    "fardaras": "fardar",
    "fardarde": "fardar",
    "fardardes": "fardar",
    "fardare": "fardar",
    "fardarei": "fardar",
    "fardareis": "fardar",
    "fardarem": "fardar",
    "fardaremos": "fardar",
    "fardares": "fardar",
    "fardaria": "fardar",
    "fardariam": "fardar",
    "fardarias": "fardar",
    "fardarmo": "fardar",
    "fardarmos": "fardar",
    "fardará": "fardar",
    "fardarás": "fardar",
    "fardarão": "fardar",
    "fardaríamos": "fardar",
    "fardaríeis": "fardar",
    "fardas": "fardar",
    "fardasse": "fardar",
    "fardassem": "fardar",
    "fardasses": "fardar",
    "fardaste": "fardar",
    "fardastes": "fardar",
    "fardava": "fardar",
    "fardavam": "fardar",
    "fardavas": "fardar",
    "farde": "fardar",
    "fardei": "fardar",
    "fardeis": "fardel",
    "fardelagens": "fardelagem",
    "fardem": "fardar",
    "fardemo": "fardar",
    "fardemos": "fardar",
    "fardes": "fardar",
    "fardetas": "fardeta",
    "fardetes": "fardete",
    "fardo": "fardar",
    "fardos": "fardo",
    "fardou": "fardar",
    "fardá": "fardar",
    "fardámo": "fardar",
    "fardámos": "fardar",
    "fardáramo": "fardar",
    "fardáramos": "fardar",
    "fardárei": "fardar",
    "fardáreis": "fardar",
    "fardásseis": "fardar",
    "fardássemos": "fardar",
    "fardávamo": "fardar",
    "fardávamos": "fardar",
    "fardávei": "fardar",
    "fardáveis": "fardar",
    "fare": "farar",
    "farei": "fazer",
    "fareis": "fazer",
    "fareja": "farejar",
    "farejada": "farejar",
    "farejadas": "farejar",
    "farejado": "farejar",
    "farejadora": "farejador",
    "farejadoras": "farejador",
    "farejadores": "farejador",
    "farejados": "farejar",
    "farejai": "farejar",
    "farejais": "farejar",
    "farejam": "farejar",
    "farejamo": "farejar",
    "farejamos": "farejar",
    "farejando": "farejar",
    "farejara": "farejar",
    "farejaram": "farejar",
    "farejaras": "farejar",
    "farejarde": "farejar",
    "farejardes": "farejar",
    "farejare": "farejar",
    "farejarei": "farejar",
    "farejareis": "farejar",
    "farejarem": "farejar",
    "farejaremos": "farejar",
    "farejares": "farejar",
    "farejaria": "farejar",
    "farejariam": "farejar",
    "farejarias": "farejar",
    "farejarmo": "farejar",
    "farejarmos": "farejar",
    "farejará": "farejar",
    "farejarás": "farejar",
    "farejarão": "farejar",
    "farejaríamos": "farejar",
    "farejaríeis": "farejar",
    "farejas": "farejar",
    "farejasse": "farejar",
    "farejassem": "farejar",
    "farejasses": "farejar",
    "farejaste": "farejar",
    "farejastes": "farejar",
    "farejava": "farejar",
    "farejavam": "farejar",
    "farejavas": "farejar",
    "fareje": "farejar",
    "farejei": "farejar",
    "farejeis": "farejar",
    "farejem": "farejar",
    "farejemo": "farejar",
    "farejemos": "farejar",
    "farejes": "farejar",
    "farejo": "farejar",
    "farejos": "farejo",
    "farejou": "farejar",
    "farejá": "farejar",
    "farejámo": "farejar",
    "farejámos": "farejar",
    "farejáramo": "farejar",
    "farejáramos": "farejar",
    "farejárei": "farejar",
    "farejáreis": "farejar",
    "farejásseis": "farejar",
    "farejássemos": "farejar",
    "farejávamo": "farejar",
    "farejávamos": "farejar",
    "farejávei": "farejar",
    "farejáveis": "farejar",
    "farela": "farelar",
    "farelada": "farelar",
    "fareladas": "farelar",
    "farelado": "farelar",
    "farelados": "farelar",
    "farelagens": "farelagem",
    "farelai": "farelar",
    "farelais": "farelar",
    "farelam": "farelar",
    "farelamo": "farelar",
    "farelamos": "farelar",
    "farelando": "farelar",
    "farelara": "farelar",
    "farelaram": "farelar",
    "farelaras": "farelar",
    "farelardes": "farelar",
    "farelarei": "farelar",
    "farelareis": "farelar",
    "farelarem": "farelar",
    "farelaremos": "farelar",
    "farelares": "farelar",
    "farelaria": "farelar",
    "farelariam": "farelar",
    "farelarias": "farelar",
    "farelarmo": "farelar",
    "farelarmos": "farelar",
    "farelará": "farelar",
    "farelarás": "farelar",
    "farelarão": "farelar",
    "farelaríamos": "farelar",
    "farelaríeis": "farelar",
    "farelas": "farelar",
    "farelasse": "farelar",
    "farelassem": "farelar",
    "farelasses": "farelar",
    "farelaste": "farelar",
    "farelastes": "farelar",
    "farelava": "farelar",
    "farelavam": "farelar",
    "farelavas": "farelar",
    "farele": "farelar",
    "farelei": "farelar",
    "fareleira": "fareleiro",
    "fareleiras": "fareleiro",
    "fareleiros": "fareleiro",
    "fareleis": "farelar",
    "farelem": "farelar",
    "farelemo": "farelar",
    "farelemos": "farelar",
    "farelenta": "farelento",
    "farelentas": "farelento",
    "farelentos": "farelento",
    "fareles": "farelar",
    "farelhões": "farelhão",
    "farelices": "farelice",
    "farelo": "farelar",
    "farelos": "farelo",
    "farelou": "farelar",
    "farelácea": "fareláceo",
    "fareláceas": "fareláceo",
    "fareláceos": "fareláceo",
    "farelámo": "farelar",
    "farelámos": "farelar",
    "fareláramo": "farelar",
    "fareláramos": "farelar",
    "fareláreis": "farelar",
    "farelásseis": "farelar",
    "farelássemos": "farelar",
    "farelávamo": "farelar",
    "farelávamos": "farelar",
    "fareláveis": "farelar",
    "farelórios": "farelório",
    "farem": "farar",
    "faremo": "farar",
    "faremos": "fazer",
    "farenses": "farense",
    "fares": "farar",
    "farfalha": "farfalhar",
    "farfalhada": "farfalhar",
    "farfalhadas": "farfalhar",
    "farfalhado": "farfalhar",
    "farfalhadora": "farfalhador",
    "farfalhadoras": "farfalhador",
    "farfalhadores": "farfalhador",
    "farfalhados": "farfalhar",
    "farfalhai": "farfalhar",
    "farfalhais": "farfalhar",
    "farfalham": "farfalhar",
    "farfalhamo": "farfalhar",
    "farfalhamos": "farfalhar",
    "farfalhando": "farfalhar",
    "farfalhantes": "farfalhante",
    "farfalhara": "farfalhar",
    "farfalharam": "farfalhar",
    "farfalharas": "farfalhar",
    "farfalhardes": "farfalhar",
    "farfalharei": "farfalhar",
    "farfalhareis": "farfalhar",
    "farfalharem": "farfalhar",
    "farfalharemos": "farfalhar",
    "farfalhares": "farfalhar",
    "farfalharia": "farfalhar",
    "farfalhariam": "farfalhar",
    "farfalharias": "farfalharia",
    "farfalharmo": "farfalhar",
    "farfalharmos": "farfalhar",
    "farfalhará": "farfalhar",
    "farfalharás": "farfalhar",
    "farfalharão": "farfalhar",
    "farfalharíamos": "farfalhar",
    "farfalharíeis": "farfalhar",
    "farfalhas": "farfalhar",
    "farfalhasse": "farfalhar",
    "farfalhassem": "farfalhar",
    "farfalhasses": "farfalhar",
    "farfalhaste": "farfalhar",
    "farfalhastes": "farfalhar",
    "farfalhava": "farfalhar",
    "farfalhavam": "farfalhar",
    "farfalhavas": "farfalhar",
    "farfalhe": "farfalhar",
    "farfalhei": "farfalhar",
    "farfalheira": "farfalheiro",
    "farfalheiras": "farfalheiro",
    "farfalheiros": "farfalheiro",
    "farfalheis": "farfalhar",
    "farfalhem": "farfalhar",
    "farfalhemo": "farfalhar",
    "farfalhemos": "farfalhar",
    "farfalhenta": "farfalhento",
    "farfalhentas": "farfalhento",
    "farfalhentos": "farfalhento",
    "farfalhes": "farfalhar",
    "farfalhices": "farfalhice",
    "farfalho": "farfalhar",
    "farfalhona": "farfalhão",
    "farfalhonas": "farfalhão",
    "farfalhos": "farfalho",
    "farfalhosa": "farfalhoso",
    "farfalhosas": "farfalhoso",
    "farfalhosos": "farfalhoso",
    "farfalhou": "farfalhar",
    "farfalhuda": "farfalhudo",
    "farfalhudas": "farfalhudo",
    "farfalhudos": "farfalhudo",
    "farfalhámo": "farfalhar",
    "farfalhámos": "farfalhar",
    "farfalháramo": "farfalhar",
    "farfalháramos": "farfalhar",
    "farfalháreis": "farfalhar",
    "farfalhásseis": "farfalhar",
    "farfalhássemos": "farfalhar",
    "farfalhávamo": "farfalhar",
    "farfalhávamos": "farfalhar",
    "farfalháveis": "farfalhar",
    "farfalhões": "farfalhão",
    "farfanteada": "farfantear",
    "farfanteadas": "farfantear",
    "farfanteado": "farfantear",
    "farfanteados": "farfantear",
    "farfanteai": "farfantear",
    "farfanteais": "farfantear",
    "farfanteamo": "farfantear",
    "farfanteamos": "farfantear",
    "farfanteando": "farfantear",
    "farfanteara": "farfantear",
    "farfantearam": "farfantear",
    "farfantearas": "farfantear",
    "farfanteardes": "farfantear",
    "farfantearei": "farfantear",
    "farfanteareis": "farfantear",
    "farfantearem": "farfantear",
    "farfantearemos": "farfantear",
    "farfanteares": "farfantear",
    "farfantearia": "farfantear",
    "farfanteariam": "farfantear",
    "farfantearias": "farfantear",
    "farfantearmo": "farfantear",
    "farfantearmos": "farfantear",
    "farfanteará": "farfantear",
    "farfantearás": "farfantear",
    "farfantearão": "farfantear",
    "farfantearíamos": "farfantear",
    "farfantearíeis": "farfantear",
    "farfanteasse": "farfantear",
    "farfanteassem": "farfantear",
    "farfanteasses": "farfantear",
    "farfanteaste": "farfantear",
    "farfanteastes": "farfantear",
    "farfanteava": "farfantear",
    "farfanteavam": "farfantear",
    "farfanteavas": "farfantear",
    "farfanteei": "farfantear",
    "farfanteeis": "farfantear",
    "farfanteemo": "farfantear",
    "farfanteemos": "farfantear",
    "farfanteia": "farfantear",
    "farfanteiam": "farfantear",
    "farfanteias": "farfantear",
    "farfanteie": "farfantear",
    "farfanteiem": "farfantear",
    "farfanteies": "farfantear",
    "farfanteio": "farfantear",
    "farfanteou": "farfantear",
    "farfantes": "farfante",
    "farfanteámo": "farfantear",
    "farfanteámos": "farfantear",
    "farfanteáramo": "farfantear",
    "farfanteáramos": "farfantear",
    "farfanteáreis": "farfantear",
    "farfanteásseis": "farfantear",
    "farfanteássemos": "farfantear",
    "farfanteávamo": "farfantear",
    "farfanteávamos": "farfantear",
    "farfanteáveis": "farfantear",
    "farfantona": "farfantão",
    "farfantonas": "farfantão",
    "farfantões": "farfantão",
    "farfâncias": "farfância",
    "faria": "fazer",
    "fariam": "fazer",
    "farias": "fazer",
    "farigectómica": "farigectómico",
    "farigectómicas": "farigectómico",
    "farigectómicos": "farigectómico",
    "farilhões": "farilhão",
    "farina": "farinar",
    "farinada": "farinar",
    "farinadas": "farinar",
    "farinado": "farinar",
    "farinados": "farinar",
    "farinai": "farinar",
    "farinais": "farinar",
    "farinam": "farinar",
    "farinamo": "farinar",
    "farinamos": "farinar",
    "farinando": "farinar",
    "farinara": "farinar",
    "farinaram": "farinar",
    "farinaras": "farinar",
    "farinarde": "farinar",
    "farinardes": "farinar",
    "farinare": "farinar",
    "farinarei": "farinar",
    "farinareis": "farinar",
    "farinarem": "farinar",
    "farinaremos": "farinar",
    "farinares": "farinar",
    "farinaria": "farinar",
    "farinariam": "farinar",
    "farinarias": "farinar",
    "farinarmo": "farinar",
    "farinarmos": "farinar",
    "farinará": "farinar",
    "farinarás": "farinar",
    "farinarão": "farinar",
    "farinaríamos": "farinar",
    "farinaríeis": "farinar",
    "farinas": "farinar",
    "farinasse": "farinar",
    "farinassem": "farinar",
    "farinasses": "farinar",
    "farinaste": "farinar",
    "farinastes": "farinar",
    "farinava": "farinar",
    "farinavam": "farinar",
    "farinavas": "farinar",
    "farinações": "farinação",
    "farine": "farinar",
    "farinei": "farinar",
    "farineis": "farinar",
    "farinem": "farinar",
    "farinemo": "farinar",
    "farinemos": "farinar",
    "farines": "farinar",
    "faringes": "faringe",
    "faringites": "faringite",
    "faringolaringites": "faringolaringite",
    "faringolaringítica": "faringolaringítico",
    "faringolaringíticas": "faringolaringítico",
    "faringolaringíticos": "faringolaringítico",
    "faringoscopias": "faringoscopia",
    "faringoscópica": "faringoscópico",
    "faringoscópicas": "faringoscópico",
    "faringoscópicos": "faringoscópico",
    "faringoscópios": "faringoscópio",
    "faringotomias": "faringotomia",
    "faringotómica": "faringotómico",
    "faringotómicas": "faringotómico",
    "faringotómicos": "faringotómico",
    "faringítica": "faringítico",
    "faringíticas": "faringítico",
    "faringíticos": "faringítico",
    "farinhadas": "farinhada",
    "farinhas": "farinha",
    "farinhatas": "farinhata",
    "farinhatos": "farinhato",
    "farinheira": "farinheiro",
    "farinheiras": "farinheiro",
    "farinheiros": "farinheiro",
    "farinhenta": "farinhento",
    "farinhentas": "farinhento",
    "farinhentos": "farinhento",
    "farinhosa": "farinhoso",
    "farinhosas": "farinhoso",
    "farinhosos": "farinhoso",
    "farinhotas": "farinhota",
    "farinhuda": "farinhudo",
    "farinhudas": "farinhudo",
    "farinhudos": "farinhudo",
    "farino": "farinar",
    "farinográfica": "farinográfico",
    "farinográficas": "farinográfico",
    "farinográficos": "farinográfico",
    "farinosas": "farinosa",
    "farinou": "farinar",
    "fariná": "farinar",
    "farinácea": "farináceo",
    "farináceas": "farináceo",
    "farináceos": "farináceo",
    "farinámo": "farinar",
    "farinámos": "farinar",
    "farináramo": "farinar",
    "farináramos": "farinar",
    "farinárei": "farinar",
    "farináreis": "farinar",
    "farinásseis": "farinar",
    "farinássemos": "farinar",
    "farinávamo": "farinar",
    "farinávamos": "farinar",
    "farinávei": "farinar",
    "farináveis": "farinar",
    "farisaica": "farisaico",
    "farisaicas": "farisaico",
    "farisaicos": "farisaico",
    "farisca": "fariscar",
    "fariscada": "fariscar",
    "fariscadas": "fariscar",
    "fariscado": "fariscar",
    "fariscadora": "fariscador",
    "fariscadoras": "fariscador",
    "fariscadores": "fariscador",
    "fariscados": "fariscar",
    "fariscai": "fariscar",
    "fariscais": "fariscar",
    "fariscam": "fariscar",
    "fariscamo": "fariscar",
    "fariscamos": "fariscar",
    "fariscando": "fariscar",
    "fariscantes": "fariscante",
    "fariscara": "fariscar",
    "fariscaram": "fariscar",
    "fariscaras": "fariscar",
    "fariscarde": "fariscar",
    "fariscardes": "fariscar",
    "fariscare": "fariscar",
    "fariscarei": "fariscar",
    "fariscareis": "fariscar",
    "fariscarem": "fariscar",
    "fariscaremos": "fariscar",
    "fariscares": "fariscar",
    "fariscaria": "fariscar",
    "fariscariam": "fariscar",
    "fariscarias": "fariscar",
    "fariscarmo": "fariscar",
    "fariscarmos": "fariscar",
    "fariscará": "fariscar",
    "fariscarás": "fariscar",
    "fariscarão": "fariscar",
    "fariscaríamos": "fariscar",
    "fariscaríeis": "fariscar",
    "fariscas": "fariscar",
    "fariscasse": "fariscar",
    "fariscassem": "fariscar",
    "fariscasses": "fariscar",
    "fariscaste": "fariscar",
    "fariscastes": "fariscar",
    "fariscava": "fariscar",
    "fariscavam": "fariscar",
    "fariscavas": "fariscar",
    "farisco": "fariscar",
    "fariscos": "farisco",
    "fariscou": "fariscar",
    "fariscá": "fariscar",
    "fariscámo": "fariscar",
    "fariscámos": "fariscar",
    "fariscáramo": "fariscar",
    "fariscáramos": "fariscar",
    "fariscárei": "fariscar",
    "fariscáreis": "fariscar",
    "fariscásseis": "fariscar",
    "fariscássemos": "fariscar",
    "fariscávamo": "fariscar",
    "fariscávamos": "fariscar",
    "fariscávei": "fariscar",
    "fariscáveis": "fariscar",
    "fariseia": "fariseu",
    "fariseias": "fariseu",
    "fariseus": "fariseu",
    "fariseísmos": "fariseísmo",
    "farisque": "fariscar",
    "farisquei": "fariscar",
    "farisqueis": "fariscar",
    "farisquem": "fariscar",
    "farisquemo": "fariscar",
    "farisquemos": "fariscar",
    "farisques": "fariscar",
    "farmacodinâmica": "farmacodinâmico",
    "farmacodinâmicas": "farmacodinâmico",
    "farmacodinâmicos": "farmacodinâmico",
    "farmacognósica": "farmacognósico",
    "farmacognósicas": "farmacognósico",
    "farmacognósicos": "farmacognósico",
    "farmacognóstica": "farmacognóstico",
    "farmacognósticas": "farmacognóstico",
    "farmacognósticos": "farmacognóstico",
    "farmacologias": "farmacologia",
    "farmacologistas": "farmacologista",
    "farmacológica": "farmacológico",
    "farmacológicas": "farmacológico",
    "farmacológicos": "farmacológico",
    "farmacopeias": "farmacopeia",
    "farmacopolas": "farmacopola",
    "farmacopálica": "farmacopálico",
    "farmacopálicas": "farmacopálico",
    "farmacopálicos": "farmacopálico",
    "farmacopólica": "farmacopólico",
    "farmacopólicas": "farmacopólico",
    "farmacopólicos": "farmacopólico",
    "farmacotecnias": "farmacotecnia",
    "farmacotécnica": "farmacotécnico",
    "farmacotécnicas": "farmacotécnico",
    "farmacotécnicos": "farmacotécnico",
    "farmacêutica": "farmacêutico",
    "farmacêuticas": "farmacêutico",
    "farmacêuticos": "farmacêutico",
    "farmocognosias": "farmocognosia",
    "farmácias": "farmácia",
    "farneiros": "farneiro",
    "farnentos": "farnento",
    "farnicoques": "farnicoque",
    "farnéis": "farnel",
    "faro": "farar",
    "faroestes": "faroeste",
    "farofas": "farofa",
    "farofeira": "farofeiro",
    "farofeiras": "farofeiro",
    "farofeiros": "farofeiro",
    "farola": "farolar",
    "farolada": "farolar",
    "faroladas": "farolar",
    "farolado": "farolar",
    "farolados": "farolar",
    "farolagens": "farolagem",
    "farolai": "farolar",
    "farolais": "farolar",
    "farolam": "farolar",
    "farolamo": "farolar",
    "farolamos": "farolar",
    "farolando": "farolar",
    "farolara": "farolar",
    "farolaram": "farolar",
    "farolaras": "farolar",
    "farolarde": "farolar",
    "farolardes": "farolar",
    "farolare": "farolar",
    "farolarei": "farolar",
    "farolareis": "farolar",
    "farolarem": "farolar",
    "farolaremos": "farolar",
    "farolares": "farolar",
    "farolaria": "farolar",
    "farolariam": "farolar",
    "farolarias": "farolar",
    "farolarmo": "farolar",
    "farolarmos": "farolar",
    "farolará": "farolar",
    "farolarás": "farolar",
    "farolarão": "farolar",
    "farolaríamos": "farolar",
    "farolaríeis": "farolar",
    "farolas": "farolar",
    "farolasse": "farolar",
    "farolassem": "farolar",
    "farolasses": "farolar",
    "farolaste": "farolar",
    "farolastes": "farolar",
    "farolava": "farolar",
    "farolavam": "farolar",
    "farolavas": "farolar",
    "farole": "farolar",
    "farolei": "farolar",
    "faroleira": "faroleiro",
    "faroleiras": "faroleiro",
    "faroleiros": "faroleiro",
    "faroleis": "farolar",
    "farolem": "farolar",
    "farolemo": "farolar",
    "farolemos": "farolar",
    "faroles": "farolar",
    "faroletes": "farolete",
    "farolices": "farolice",
    "farolins": "farolim",
    "faroliza": "farolizar",
    "farolizada": "farolizar",
    "farolizadas": "farolizar",
    "farolizado": "farolizar",
    "farolizados": "farolizar",
    "farolizai": "farolizar",
    "farolizais": "farolizar",
    "farolizam": "farolizar",
    "farolizamo": "farolizar",
    "farolizamos": "farolizar",
    "farolizando": "farolizar",
    "farolizara": "farolizar",
    "farolizaram": "farolizar",
    "farolizaras": "farolizar",
    "farolizarde": "farolizar",
    "farolizardes": "farolizar",
    "farolizare": "farolizar",
    "farolizarei": "farolizar",
    "farolizareis": "farolizar",
    "farolizarem": "farolizar",
    "farolizaremos": "farolizar",
    "farolizares": "farolizar",
    "farolizaria": "farolizar",
    "farolizariam": "farolizar",
    "farolizarias": "farolizar",
    "farolizarmo": "farolizar",
    "farolizarmos": "farolizar",
    "farolizará": "farolizar",
    "farolizarás": "farolizar",
    "farolizarão": "farolizar",
    "farolizaríamos": "farolizar",
    "farolizaríeis": "farolizar",
    "farolizas": "farolizar",
    "farolizasse": "farolizar",
    "farolizassem": "farolizar",
    "farolizasses": "farolizar",
    "farolizaste": "farolizar",
    "farolizastes": "farolizar",
    "farolizava": "farolizar",
    "farolizavam": "farolizar",
    "farolizavas": "farolizar",
    "farolizações": "farolização",
    "farolize": "farolizar",
    "farolizei": "farolizar",
    "farolizeis": "farolizar",
    "farolizem": "farolizar",
    "farolizemo": "farolizar",
    "farolizemos": "farolizar",
    "farolizes": "farolizar",
    "farolizo": "farolizar",
    "farolizou": "farolizar",
    "farolizá": "farolizar",
    "farolizámo": "farolizar",
    "farolizámos": "farolizar",
    "farolizáramo": "farolizar",
    "farolizáramos": "farolizar",
    "farolizárei": "farolizar",
    "farolizáreis": "farolizar",
    "farolizásseis": "farolizar",
    "farolizássemos": "farolizar",
    "farolizávamo": "farolizar",
    "farolizávamos": "farolizar",
    "farolizávei": "farolizar",
    "farolizáveis": "farolizar",
    "farolo": "farolar",
    "farolou": "farolar",
    "farolá": "farolar",
    "farolámo": "farolar",
    "farolámos": "farolar",
    "faroláramo": "farolar",
    "faroláramos": "farolar",
    "farolárei": "farolar",
    "faroláreis": "farolar",
    "farolásseis": "farolar",
    "farolássemos": "farolar",
    "farolávamo": "farolar",
    "farolávamos": "farolar",
    "farolávei": "farolar",
    "faroláveis": "farolar",
    "faros": "faro",
    "farou": "farar",
    "farpa": "farpar",
    "farpada": "farpar",
    "farpadas": "farpar",
    "farpado": "farpar",
    "farpados": "farpar",
    "farpai": "farpar",
    "farpais": "farpar",
    "farpam": "farpar",
    "farpamo": "farpar",
    "farpamos": "farpar",
    "farpando": "farpar",
    "farpantes": "farpante",
    "farpara": "farpar",
    "farparam": "farpar",
    "farparas": "farpar",
    "farparde": "farpar",
    "farpardes": "farpar",
    "farpare": "farpar",
    "farparei": "farpar",
    "farpareis": "farpar",
    "farparem": "farpar",
    "farparemos": "farpar",
    "farpares": "farpar",
    "farparia": "farpar",
    "farpariam": "farpar",
    "farparias": "farpar",
    "farparmo": "farpar",
    "farparmos": "farpar",
    "farpará": "farpar",
    "farparás": "farpar",
    "farparão": "farpar",
    "farparíamos": "farpar",
    "farparíeis": "farpar",
    "farpas": "farpar",
    "farpasse": "farpar",
    "farpassem": "farpar",
    "farpasses": "farpar",
    "farpaste": "farpar",
    "farpastes": "farpar",
    "farpava": "farpar",
    "farpavam": "farpar",
    "farpavas": "farpar",
    "farpe": "farpar",
    "farpeada": "farpear",
    "farpeadas": "farpear",
    "farpeado": "farpear",
    "farpeados": "farpear",
    "farpeai": "farpear",
    "farpeais": "farpear",
    "farpeamo": "farpear",
    "farpeamos": "farpear",
    "farpeando": "farpear",
    "farpeara": "farpear",
    "farpearam": "farpear",
    "farpearas": "farpear",
    "farpearde": "farpear",
    "farpeardes": "farpear",
    "farpeare": "farpear",
    "farpearei": "farpear",
    "farpeareis": "farpear",
    "farpearem": "farpear",
    "farpearemos": "farpear",
    "farpeares": "farpear",
    "farpearia": "farpear",
    "farpeariam": "farpear",
    "farpearias": "farpear",
    "farpearmo": "farpear",
    "farpearmos": "farpear",
    "farpeará": "farpear",
    "farpearás": "farpear",
    "farpearão": "farpear",
    "farpearíamos": "farpear",
    "farpearíeis": "farpear",
    "farpeasse": "farpear",
    "farpeassem": "farpear",
    "farpeasses": "farpear",
    "farpeaste": "farpear",
    "farpeastes": "farpear",
    "farpeava": "farpear",
    "farpeavam": "farpear",
    "farpeavas": "farpear",
    "farpeei": "farpear",
    "farpeeis": "farpear",
    "farpeemo": "farpear",
    "farpeemos": "farpear",
    "farpei": "farpar",
    "farpeia": "farpear",
    "farpeiam": "farpear",
    "farpeias": "farpear",
    "farpeie": "farpear",
    "farpeiem": "farpear",
    "farpeies": "farpear",
    "farpeio": "farpear",
    "farpeis": "farpar",
    "farpelas": "farpela",
    "farpem": "farpar",
    "farpemo": "farpar",
    "farpemos": "farpar",
    "farpeou": "farpear",
    "farpes": "farpar",
    "farpeá": "farpear",
    "farpeámo": "farpear",
    "farpeámos": "farpear",
    "farpeáramo": "farpear",
    "farpeáramos": "farpear",
    "farpeárei": "farpear",
    "farpeáreis": "farpear",
    "farpeásseis": "farpear",
    "farpeássemos": "farpear",
    "farpeávamo": "farpear",
    "farpeávamos": "farpear",
    "farpeávei": "farpear",
    "farpeáveis": "farpear",
    "farpinhas": "farpinha",
    "farpo": "farpar",
    "farpou": "farpar",
    "farpá": "farpar",
    "farpámo": "farpar",
    "farpámos": "farpar",
    "farpáramo": "farpar",
    "farpáramos": "farpar",
    "farpárei": "farpar",
    "farpáreis": "farpar",
    "farpásseis": "farpar",
    "farpássemos": "farpar",
    "farpávamo": "farpar",
    "farpávamos": "farpar",
    "farpávei": "farpar",
    "farpáveis": "farpar",
    "farpões": "farpão",
    "farrachos": "farracho",
    "farragens": "farragem",
    "farragoulos": "farragoulo",
    "farrajais": "farrajal",
    "farranchas": "farrancha",
    "farranchos": "farrancho",
    "farrapa": "farrapar",
    "farrapada": "farrapar",
    "farrapadas": "farrapar",
    "farrapado": "farrapar",
    "farrapados": "farrapar",
    "farrapagens": "farrapagem",
    "farrapai": "farrapar",
    "farrapais": "farrapar",
    "farrapam": "farrapar",
    "farrapamo": "farrapar",
    "farrapamos": "farrapar",
    "farrapando": "farrapar",
    "farrapara": "farrapar",
    "farraparam": "farrapar",
    "farraparas": "farrapar",
    "farraparde": "farrapar",
    "farrapardes": "farrapar",
    "farrapare": "farrapar",
    "farraparei": "farrapar",
    "farrapareis": "farrapar",
    "farraparem": "farrapar",
    "farraparemos": "farrapar",
    "farrapares": "farrapar",
    "farraparia": "farrapar",
    "farrapariam": "farrapar",
    "farraparias": "farraparia",
    "farraparmo": "farrapar",
    "farraparmos": "farrapar",
    "farrapará": "farrapar",
    "farraparás": "farrapar",
    "farraparão": "farrapar",
    "farraparíamos": "farrapar",
    "farraparíeis": "farrapar",
    "farrapas": "farrapar",
    "farrapasse": "farrapar",
    "farrapassem": "farrapar",
    "farrapasses": "farrapar",
    "farrapaste": "farrapar",
    "farrapastes": "farrapar",
    "farrapava": "farrapar",
    "farrapavam": "farrapar",
    "farrapavas": "farrapar",
    "farrape": "farrapar",
    "farrapei": "farrapar",
    "farrapeira": "farrapeiro",
    "farrapeiras": "farrapeiro",
    "farrapeiros": "farrapeiro",
    "farrapeis": "farrapar",
    "farrapem": "farrapar",
    "farrapemo": "farrapar",
    "farrapemos": "farrapar",
    "farrapenta": "farrapento",
    "farrapentas": "farrapento",
    "farrapentos": "farrapento",
    "farrapes": "farrapar",
    "farrapilhas": "farrapilha",
    "farrapinho": "farrapo",
    "farrapinhos": "farrapo",
    "farrapito": "farrapo",
    "farrapitos": "farrapo",
    "farrapo": "farrapar",
    "farrapona": "farrapão",
    "farraponas": "farrapão",
    "farrapos": "farrapo",
    "farrapou": "farrapar",
    "farrapozinho": "farrapo",
    "farrapozinhos": "farrapo",
    "farrapozito": "farrapo",
    "farrapozitos": "farrapo",
    "farrapá": "farrapar",
    "farrapámo": "farrapar",
    "farrapámos": "farrapar",
    "farrapáramo": "farrapar",
    "farrapáramos": "farrapar",
    "farrapárei": "farrapar",
    "farrapáreis": "farrapar",
    "farrapásseis": "farrapar",
    "farrapássemos": "farrapar",
    "farrapávamo": "farrapar",
    "farrapávamos": "farrapar",
    "farrapávei": "farrapar",
    "farrapáveis": "farrapar",
    "farrapões": "farrapão",
    "farras": "farra",
    "farreada": "farrear",
    "farreadas": "farrear",
    "farreado": "farrear",
    "farreados": "farrear",
    "farreai": "farrear",
    "farreais": "farrear",
    "farreamo": "farrear",
    "farreamos": "farrear",
    "farreando": "farrear",
    "farreara": "farrear",
    "farrearam": "farrear",
    "farrearas": "farrear",
    "farreardes": "farrear",
    "farrearei": "farrear",
    "farreareis": "farrear",
    "farrearem": "farrear",
    "farrearemos": "farrear",
    "farreares": "farrear",
    "farrearia": "farrear",
    "farreariam": "farrear",
    "farrearias": "farrear",
    "farrearmo": "farrear",
    "farrearmos": "farrear",
    "farreará": "farrear",
    "farrearás": "farrear",
    "farrearão": "farrear",
    "farrearíamos": "farrear",
    "farrearíeis": "farrear",
    "farreasse": "farrear",
    "farreassem": "farrear",
    "farreasses": "farrear",
    "farreaste": "farrear",
    "farreastes": "farrear",
    "farreava": "farrear",
    "farreavam": "farrear",
    "farreavas": "farrear",
    "farreei": "farrear",
    "farreeis": "farrear",
    "farreemo": "farrear",
    "farreemos": "farrear",
    "farreia": "farrear",
    "farreiam": "farrear",
    "farreias": "farrear",
    "farreie": "farrear",
    "farreiem": "farrear",
    "farreies": "farrear",
    "farreio": "farrear",
    "farreou": "farrear",
    "farreámo": "farrear",
    "farreámos": "farrear",
    "farreáramo": "farrear",
    "farreáramos": "farrear",
    "farreáreis": "farrear",
    "farreásseis": "farrear",
    "farreássemos": "farrear",
    "farreávamo": "farrear",
    "farreávamos": "farrear",
    "farreáveis": "farrear",
    "farricocos": "farricoco",
    "farripas": "farripa",
    "farripinha": "farripa",
    "farripinhas": "farripa",
    "farripita": "farripa",
    "farripitas": "farripa",
    "farristas": "farrista",
    "farrobas": "farroba",
    "farrobeiras": "farrobeira",
    "farrombas": "farromba",
    "farroncas": "farronca",
    "farronfeada": "farronfear",
    "farronfeadas": "farronfear",
    "farronfeado": "farronfear",
    "farronfeados": "farronfear",
    "farronfeai": "farronfear",
    "farronfeais": "farronfear",
    "farronfeamo": "farronfear",
    "farronfeamos": "farronfear",
    "farronfeando": "farronfear",
    "farronfeara": "farronfear",
    "farronfearam": "farronfear",
    "farronfearas": "farronfear",
    "farronfeardes": "farronfear",
    "farronfearei": "farronfear",
    "farronfeareis": "farronfear",
    "farronfearem": "farronfear",
    "farronfearemos": "farronfear",
    "farronfeares": "farronfear",
    "farronfearia": "farronfear",
    "farronfeariam": "farronfear",
    "farronfearias": "farronfear",
    "farronfearmo": "farronfear",
    "farronfearmos": "farronfear",
    "farronfeará": "farronfear",
    "farronfearás": "farronfear",
    "farronfearão": "farronfear",
    "farronfearíamos": "farronfear",
    "farronfearíeis": "farronfear",
    "farronfeasse": "farronfear",
    "farronfeassem": "farronfear",
    "farronfeasses": "farronfear",
    "farronfeaste": "farronfear",
    "farronfeastes": "farronfear",
    "farronfeava": "farronfear",
    "farronfeavam": "farronfear",
    "farronfeavas": "farronfear",
    "farronfeei": "farronfear",
    "farronfeeis": "farronfear",
    "farronfeemo": "farronfear",
    "farronfeemos": "farronfear",
    "farronfeia": "farronfear",
    "farronfeiam": "farronfear",
    "farronfeias": "farronfear",
    "farronfeie": "farronfear",
    "farronfeiem": "farronfear",
    "farronfeies": "farronfear",
    "farronfeio": "farronfear",
    "farronfeou": "farronfear",
    "farronfeámo": "farronfear",
    "farronfeámos": "farronfear",
    "farronfeáramo": "farronfear",
    "farronfeáramos": "farronfear",
    "farronfeáreis": "farronfear",
    "farronfeásseis": "farronfear",
    "farronfeássemos": "farronfear",
    "farronfeávamo": "farronfear",
    "farronfeávamos": "farronfear",
    "farronfeáveis": "farronfear",
    "farronqueira": "farronqueiro",
    "farronqueiras": "farronqueiro",
    "farronqueiros": "farronqueiro",
    "farros": "farro",
    "farroupas": "farroupa",
    "farroupilhas": "farroupilha",
    "farroupinhos": "farroupinho",
    "farroupos": "farroupo",
    "farrusca": "farrusco",
    "farruscas": "farrusco",
    "farruscos": "farrusco",
    "farrões": "farrão",
    "farsadas": "farsada",
    "farsalhões": "farsalhão",
    "farsanteada": "farsantear",
    "farsanteadas": "farsantear",
    "farsanteado": "farsantear",
    "farsanteados": "farsantear",
    "farsanteai": "farsantear",
    "farsanteais": "farsantear",
    "farsanteamo": "farsantear",
    "farsanteamos": "farsantear",
    "farsanteando": "farsantear",
    "farsanteara": "farsantear",
    "farsantearam": "farsantear",
    "farsantearas": "farsantear",
    "farsanteardes": "farsantear",
    "farsantearei": "farsantear",
    "farsanteareis": "farsantear",
    "farsantearem": "farsantear",
    "farsantearemos": "farsantear",
    "farsanteares": "farsantear",
    "farsantearia": "farsantear",
    "farsanteariam": "farsantear",
    "farsantearias": "farsantear",
    "farsantearmo": "farsantear",
    "farsantearmos": "farsantear",
    "farsanteará": "farsantear",
    "farsantearás": "farsantear",
    "farsantearão": "farsantear",
    "farsantearíamos": "farsantear",
    "farsantearíeis": "farsantear",
    "farsanteasse": "farsantear",
    "farsanteassem": "farsantear",
    "farsanteasses": "farsantear",
    "farsanteaste": "farsantear",
    "farsanteastes": "farsantear",
    "farsanteava": "farsantear",
    "farsanteavam": "farsantear",
    "farsanteavas": "farsantear",
    "farsanteei": "farsantear",
    "farsanteeis": "farsantear",
    "farsanteemo": "farsantear",
    "farsanteemos": "farsantear",
    "farsanteia": "farsantear",
    "farsanteiam": "farsantear",
    "farsanteias": "farsantear",
    "farsanteie": "farsantear",
    "farsanteiem": "farsantear",
    "farsanteies": "farsantear",
    "farsanteio": "farsantear",
    "farsanteou": "farsantear",
    "farsantes": "farsante",
    "farsanteámo": "farsantear",
    "farsanteámos": "farsantear",
    "farsanteáramo": "farsantear",
    "farsanteáramos": "farsantear",
    "farsanteáreis": "farsantear",
    "farsanteásseis": "farsantear",
    "farsanteássemos": "farsantear",
    "farsanteávamo": "farsantear",
    "farsanteávamos": "farsantear",
    "farsanteáveis": "farsantear",
    "farsas": "farsa",
    "farsilhões": "farsilhão",
    "farsistas": "farsista",
    "farsola": "farsolar",
    "farsolada": "farsolar",
    "farsoladas": "farsolar",
    "farsolado": "farsolar",
    "farsolados": "farsolar",
    "farsolai": "farsolar",
    "farsolais": "farsolar",
    "farsolam": "farsolar",
    "farsolamo": "farsolar",
    "farsolamos": "farsolar",
    "farsolando": "farsolar",
    "farsolara": "farsolar",
    "farsolaram": "farsolar",
    "farsolaras": "farsolar",
    "farsolardes": "farsolar",
    "farsolarei": "farsolar",
    "farsolareis": "farsolar",
    "farsolarem": "farsolar",
    "farsolaremos": "farsolar",
    "farsolares": "farsolar",
    "farsolaria": "farsolar",
    "farsolariam": "farsolar",
    "farsolarias": "farsolar",
    "farsolarmo": "farsolar",
    "farsolarmos": "farsolar",
    "farsolará": "farsolar",
    "farsolarás": "farsolar",
    "farsolarão": "farsolar",
    "farsolaríamos": "farsolar",
    "farsolaríeis": "farsolar",
    "farsolas": "farsolar",
    "farsolasse": "farsolar",
    "farsolassem": "farsolar",
    "farsolasses": "farsolar",
    "farsolaste": "farsolar",
    "farsolastes": "farsolar",
    "farsolava": "farsolar",
    "farsolavam": "farsolar",
    "farsolavas": "farsolar",
    "farsole": "farsolar",
    "farsolei": "farsolar",
    "farsoleis": "farsolar",
    "farsolem": "farsolar",
    "farsolemo": "farsolar",
    "farsolemos": "farsolar",
    "farsoles": "farsolar",
    "farsolices": "farsolice",
    "farsolo": "farsolar",
    "farsolou": "farsolar",
    "farsolámo": "farsolar",
    "farsolámos": "farsolar",
    "farsoláramo": "farsolar",
    "farsoláramos": "farsolar",
    "farsoláreis": "farsolar",
    "farsolásseis": "farsolar",
    "farsolássemos": "farsolar",
    "farsolávamo": "farsolar",
    "farsolávamos": "farsolar",
    "farsoláveis": "farsolar",
    "farta": "farto",
    "fartada": "fartar",
    "fartadas": "fartar",
    "fartadelas": "fartadela",
    "fartado": "fartar",
    "fartados": "fartar",
    "fartai": "fartar",
    "fartais": "fartar",
    "fartalejos": "fartalejo",
    "fartam": "fartar",
    "fartamo": "fartar",
    "fartamos": "fartar",
    "fartando": "fartar",
    "fartanças": "fartança",
    "fartara": "fartar",
    "fartaram": "fartar",
    "fartaras": "fartar",
    "fartarde": "fartar",
    "fartardes": "fartar",
    "fartare": "fartar",
    "fartarei": "fartar",
    "fartareis": "fartar",
    "fartarem": "fartar",
    "fartaremos": "fartar",
    "fartares": "fartar",
    "fartaria": "fartar",
    "fartariam": "fartar",
    "fartarias": "fartar",
    "fartarmo": "fartar",
    "fartarmos": "fartar",
    "fartará": "fartar",
    "fartarás": "fartar",
    "fartarão": "fartar",
    "fartaríamos": "fartar",
    "fartaríeis": "fartar",
    "fartas": "farto",
    "fartasse": "fartar",
    "fartassem": "fartar",
    "fartasses": "fartar",
    "fartaste": "fartar",
    "fartastes": "fartar",
    "fartava": "fartar",
    "fartavam": "fartar",
    "fartavas": "fartar",
    "fartações": "fartação",
    "farte": "fartar",
    "fartei": "fartar",
    "farteis": "fartar",
    "fartem": "fartar",
    "fartemo": "fartar",
    "fartemos": "fartar",
    "fartens": "fartem",
    "fartes": "farte",
    "farto": "fartar",
    "fartos": "farto",
    "fartotes": "fartote",
    "fartou": "fartar",
    "fartuns": "fartum",
    "farturas": "fartura",
    "farturinha": "fartura",
    "farturinhas": "fartura",
    "farturita": "fartura",
    "farturitas": "fartura",
    "fartá": "fartar",
    "fartámo": "fartar",
    "fartámos": "fartar",
    "fartáramo": "fartar",
    "fartáramos": "fartar",
    "fartárei": "fartar",
    "fartáreis": "fartar",
    "fartásseis": "fartar",
    "fartássemos": "fartar",
    "fartávamo": "fartar",
    "fartávamos": "fartar",
    "fartávei": "fartar",
    "fartáveis": "fartável",
    "fará": "fazer",
    "farádica": "farádico",
    "farádicas": "farádico",
    "farádicos": "farádico",
    "farádios": "farádio",
    "farámo": "farar",
    "farámos": "farar",
    "faráramo": "farar",
    "faráramos": "farar",
    "farárei": "farar",
    "faráreis": "farar",
    "farás": "fazer",
    "farásseis": "farar",
    "farássemos": "farar",
    "farávamo": "farar",
    "farávamos": "farar",
    "farávei": "farar",
    "faráveis": "farar",
    "farândolas": "farândola",
    "farão": "fazer",
    "faríamos": "fazer",
    "faríeis": "fazer",
    "faríngea": "faríngeo",
    "faríngeas": "faríngeo",
    "faríngeos": "faríngeo",
    "faríngica": "faríngico",
    "faríngicas": "faríngico",
    "faríngicos": "faríngico",
    "farófias": "farófia",
    "faróis": "farol",
    "fascais": "fascal",
    "fascas": "fasca",
    "fasciculada": "fasciculado",
    "fasciculadas": "fasciculado",
    "fasciculados": "fasciculado",
    "fasciculares": "fascicular",
    "fascina": "fascinar",
    "fascinada": "fascinar",
    "fascinadas": "fascinar",
    "fascinado": "fascinar",
    "fascinadora": "fascinador",
    "fascinadoras": "fascinador",
    "fascinadores": "fascinador",
    "fascinados": "fascinar",
    "fascinai": "fascinar",
    "fascinais": "fascinar",
    "fascinam": "fascinar",
    "fascinamo": "fascinar",
    "fascinamos": "fascinar",
    "fascinando": "fascinar",
    "fascinantes": "fascinante",
    "fascinara": "fascinar",
    "fascinaram": "fascinar",
    "fascinaras": "fascinar",
    "fascinarde": "fascinar",
    "fascinardes": "fascinar",
    "fascinare": "fascinar",
    "fascinarei": "fascinar",
    "fascinareis": "fascinar",
    "fascinarem": "fascinar",
    "fascinaremos": "fascinar",
    "fascinares": "fascinar",
    "fascinaria": "fascinar",
    "fascinariam": "fascinar",
    "fascinarias": "fascinar",
    "fascinarmo": "fascinar",
    "fascinarmos": "fascinar",
    "fascinará": "fascinar",
    "fascinarás": "fascinar",
    "fascinarão": "fascinar",
    "fascinaríamos": "fascinar",
    "fascinaríeis": "fascinar",
    "fascinas": "fascinar",
    "fascinasse": "fascinar",
    "fascinassem": "fascinar",
    "fascinasses": "fascinar",
    "fascinaste": "fascinar",
    "fascinastes": "fascinar",
    "fascinava": "fascinar",
    "fascinavam": "fascinar",
    "fascinavas": "fascinar",
    "fascinações": "fascinação",
    "fascine": "fascinar",
    "fascinei": "fascinar",
    "fascineis": "fascinar",
    "fascinem": "fascinar",
    "fascinemo": "fascinar",
    "fascinemos": "fascinar",
    "fascines": "fascinar",
    "fascino": "fascinar",
    "fascinou": "fascinar",
    "fasciná": "fascinar",
    "fascinámo": "fascinar",
    "fascinámos": "fascinar",
    "fascináramo": "fascinar",
    "fascináramos": "fascinar",
    "fascinárei": "fascinar",
    "fascináreis": "fascinar",
    "fascinásseis": "fascinar",
    "fascinássemos": "fascinar",
    "fascinávamo": "fascinar",
    "fascinávamos": "fascinar",
    "fascinávei": "fascinar",
    "fascináveis": "fascinar",
    "fasciolares": "fasciolar",
    "fascismos": "fascismo",
    "fascistas": "fascista",
    "fascizantes": "fascizante",
    "fascículos": "fascículo",
    "fascínios": "fascínio",
    "fascíolas": "fascíola",
    "faseada": "fasear",
    "faseadas": "fasear",
    "faseado": "fasear",
    "faseados": "fasear",
    "faseai": "fasear",
    "faseais": "fasear",
    "faseamentos": "faseamento",
    "faseamo": "fasear",
    "faseamos": "fasear",
    "faseando": "fasear",
    "faseanídea": "faseanídeo",
    "faseanídeas": "faseanídeo",
    "faseanídeos": "faseanídeo",
    "faseara": "fasear",
    "fasearam": "fasear",
    "fasearas": "fasear",
    "fasearde": "fasear",
    "faseardes": "fasear",
    "faseare": "fasear",
    "fasearei": "fasear",
    "faseareis": "fasear",
    "fasearem": "fasear",
    "fasearemos": "fasear",
    "faseares": "fasear",
    "fasearia": "fasear",
    "faseariam": "fasear",
    "fasearias": "fasear",
    "fasearmo": "fasear",
    "fasearmos": "fasear",
    "faseará": "fasear",
    "fasearás": "fasear",
    "fasearão": "fasear",
    "fasearíamos": "fasear",
    "fasearíeis": "fasear",
    "faseasse": "fasear",
    "faseassem": "fasear",
    "faseasses": "fasear",
    "faseaste": "fasear",
    "faseastes": "fasear",
    "faseava": "fasear",
    "faseavam": "fasear",
    "faseavas": "fasear",
    "faseei": "fasear",
    "faseeis": "fasear",
    "faseemo": "fasear",
    "faseemos": "fasear",
    "faseia": "fasear",
    "faseiam": "fasear",
    "faseias": "fasear",
    "faseie": "fasear",
    "faseiem": "fasear",
    "faseies": "fasear",
    "faseio": "fasear",
    "faseolares": "faseolar",
    "faseolinas": "faseolina",
    "faseolácea": "faseoláceo",
    "faseoláceas": "faseoláceo",
    "faseoláceos": "faseoláceo",
    "faseou": "fasear",
    "fases": "fase",
    "faseá": "fasear",
    "faseámo": "fasear",
    "faseámos": "fasear",
    "faseáramo": "fasear",
    "faseáramos": "fasear",
    "faseárei": "fasear",
    "faseáreis": "fasear",
    "faseásseis": "fasear",
    "faseássemos": "fasear",
    "faseávamo": "fasear",
    "faseávamos": "fasear",
    "faseávei": "fasear",
    "faseáveis": "fasear",
    "faseânidas": "faseânida",
    "faseóleas": "faseólea",
    "fasianídeos": "fasianídeo",
    "fasimétrica": "fasimétrico",
    "fasimétricas": "fasimétrico",
    "fasimétricos": "fasimétrico",
    "fasitrónica": "fasitrónico",
    "fasitrónicas": "fasitrónico",
    "fasitrónicos": "fasitrónico",
    "fasitrões": "fasitrão",
    "fasiânidas": "fasiânida",
    "fasquia": "fasquiar",
    "fasquiada": "fasquiar",
    "fasquiadas": "fasquiar",
    "fasquiado": "fasquiar",
    "fasquiados": "fasquiar",
    "fasquiai": "fasquiar",
    "fasquiais": "fasquiar",
    "fasquiam": "fasquiar",
    "fasquiamo": "fasquiar",
    "fasquiamos": "fasquiar",
    "fasquiando": "fasquiar",
    "fasquiara": "fasquiar",
    "fasquiaram": "fasquiar",
    "fasquiaras": "fasquiar",
    "fasquiarde": "fasquiar",
    "fasquiardes": "fasquiar",
    "fasquiare": "fasquiar",
    "fasquiarei": "fasquiar",
    "fasquiareis": "fasquiar",
    "fasquiarem": "fasquiar",
    "fasquiaremos": "fasquiar",
    "fasquiares": "fasquiar",
    "fasquiaria": "fasquiar",
    "fasquiariam": "fasquiar",
    "fasquiarias": "fasquiar",
    "fasquiarmo": "fasquiar",
    "fasquiarmos": "fasquiar",
    "fasquiará": "fasquiar",
    "fasquiarás": "fasquiar",
    "fasquiarão": "fasquiar",
    "fasquiaríamos": "fasquiar",
    "fasquiaríeis": "fasquiar",
    "fasquias": "fasquiar",
    "fasquiasse": "fasquiar",
    "fasquiassem": "fasquiar",
    "fasquiasses": "fasquiar",
    "fasquiaste": "fasquiar",
    "fasquiastes": "fasquiar",
    "fasquiava": "fasquiar",
    "fasquiavam": "fasquiar",
    "fasquiavas": "fasquiar",
    "fasquie": "fasquiar",
    "fasquiei": "fasquiar",
    "fasquieiros": "fasquieiro",
    "fasquieis": "fasquiar",
    "fasquiem": "fasquiar",
    "fasquiemo": "fasquiar",
    "fasquiemos": "fasquiar",
    "fasquies": "fasquiar",
    "fasquio": "fasquiar",
    "fasquiou": "fasquiar",
    "fasquiá": "fasquiar",
    "fasquiámo": "fasquiar",
    "fasquiámos": "fasquiar",
    "fasquiáramo": "fasquiar",
    "fasquiáramos": "fasquiar",
    "fasquiárei": "fasquiar",
    "fasquiáreis": "fasquiar",
    "fasquiásseis": "fasquiar",
    "fasquiássemos": "fasquiar",
    "fasquiávamo": "fasquiar",
    "fasquiávamos": "fasquiar",
    "fasquiávei": "fasquiar",
    "fasquiáveis": "fasquiar",
    "fasta": "fasto",
    "fastas": "fasto",
    "fastidiosa": "fastidioso",
    "fastidiosas": "fastidioso",
    "fastidiosos": "fastidioso",
    "fastienta": "fastiento",
    "fastientas": "fastiento",
    "fastientos": "fastiento",
    "fastigiada": "fastigiado",
    "fastigiadas": "fastigiado",
    "fastigiados": "fastigiado",
    "fastigiosa": "fastigioso",
    "fastigiosas": "fastigioso",
    "fastigiosos": "fastigioso",
    "fastios": "fastio",
    "fastiosa": "fastioso",
    "fastiosas": "fastioso",
    "fastiosos": "fastioso",
    "fastos": "fasto",
    "fastosa": "fastoso",
    "fastosas": "fastoso",
    "fastosos": "fastoso",
    "fastuosa": "fastuoso",
    "fastuosas": "fastuoso",
    "fastuosos": "fastuoso",
    "fastígios": "fastígio",
    "fasímetros": "fasímetro",
    "fasólea": "fasóleo",
    "fasóleas": "fasóleo",
    "fasóleos": "fasóleo",
    "fatacazes": "fatacaz",
    "fatadas": "fatada",
    "fatageada": "fatagear",
    "fatageadas": "fatagear",
    "fatageado": "fatagear",
    "fatageados": "fatagear",
    "fatageai": "fatagear",
    "fatageais": "fatagear",
    "fatageamo": "fatagear",
    "fatageamos": "fatagear",
    "fatageando": "fatagear",
    "fatageara": "fatagear",
    "fatagearam": "fatagear",
    "fatagearas": "fatagear",
    "fatageardes": "fatagear",
    "fatagearei": "fatagear",
    "fatageareis": "fatagear",
    "fatagearem": "fatagear",
    "fatagearemos": "fatagear",
    "fatageares": "fatagear",
    "fatagearia": "fatagear",
    "fatageariam": "fatagear",
    "fatagearias": "fatagear",
    "fatagearmo": "fatagear",
    "fatagearmos": "fatagear",
    "fatageará": "fatagear",
    "fatagearás": "fatagear",
    "fatagearão": "fatagear",
    "fatagearíamos": "fatagear",
    "fatagearíeis": "fatagear",
    "fatageasse": "fatagear",
    "fatageassem": "fatagear",
    "fatageasses": "fatagear",
    "fatageaste": "fatagear",
    "fatageastes": "fatagear",
    "fatageava": "fatagear",
    "fatageavam": "fatagear",
    "fatageavas": "fatagear",
    "fatageei": "fatagear",
    "fatageeis": "fatagear",
    "fatageemo": "fatagear",
    "fatageemos": "fatagear",
    "fatageia": "fatagear",
    "fatageiam": "fatagear",
    "fatageias": "fatagear",
    "fatageie": "fatagear",
    "fatageiem": "fatagear",
    "fatageies": "fatagear",
    "fatageio": "fatagear",
    "fatagens": "fatagem",
    "fatageou": "fatagear",
    "fatageámo": "fatagear",
    "fatageámos": "fatagear",
    "fatageáramo": "fatagear",
    "fatageáramos": "fatagear",
    "fatageáreis": "fatagear",
    "fatageásseis": "fatagear",
    "fatageássemos": "fatagear",
    "fatageávamo": "fatagear",
    "fatageávamos": "fatagear",
    "fatageáveis": "fatagear",
    "fatais": "fatal",
    "fatalidades": "fatalidade",
    "fatalismos": "fatalismo",
    "fatalistas": "fatalista",
    "fatanas": "fatana",
    "fataniscas": "fatanisca",
    "fataças": "fataça",
    "fateira": "fateiro",
    "fateiras": "fateiro",
    "fateiros": "fateiro",
    "fateixa": "fateixar",
    "fateixada": "fateixar",
    "fateixadas": "fateixar",
    "fateixado": "fateixar",
    "fateixados": "fateixar",
    "fateixai": "fateixar",
    "fateixais": "fateixar",
    "fateixam": "fateixar",
    "fateixamo": "fateixar",
    "fateixamos": "fateixar",
    "fateixando": "fateixar",
    "fateixara": "fateixar",
    "fateixaram": "fateixar",
    "fateixaras": "fateixar",
    "fateixarde": "fateixar",
    "fateixardes": "fateixar",
    "fateixare": "fateixar",
    "fateixarei": "fateixar",
    "fateixareis": "fateixar",
    "fateixarem": "fateixar",
    "fateixaremos": "fateixar",
    "fateixares": "fateixar",
    "fateixaria": "fateixar",
    "fateixariam": "fateixar",
    "fateixarias": "fateixar",
    "fateixarmo": "fateixar",
    "fateixarmos": "fateixar",
    "fateixará": "fateixar",
    "fateixarás": "fateixar",
    "fateixarão": "fateixar",
    "fateixaríamos": "fateixar",
    "fateixaríeis": "fateixar",
    "fateixas": "fateixar",
    "fateixasse": "fateixar",
    "fateixassem": "fateixar",
    "fateixasses": "fateixar",
    "fateixaste": "fateixar",
    "fateixastes": "fateixar",
    "fateixava": "fateixar",
    "fateixavam": "fateixar",
    "fateixavas": "fateixar",
    "fateixe": "fateixar",
    "fateixei": "fateixar",
    "fateixeis": "fateixar",
    "fateixem": "fateixar",
    "fateixemo": "fateixar",
    "fateixemos": "fateixar",
    "fateixes": "fateixar",
    "fateixo": "fateixar",
    "fateixou": "fateixar",
    "fateixá": "fateixar",
    "fateixámo": "fateixar",
    "fateixámos": "fateixar",
    "fateixáramo": "fateixar",
    "fateixáramos": "fateixar",
    "fateixárei": "fateixar",
    "fateixáreis": "fateixar",
    "fateixásseis": "fateixar",
    "fateixássemos": "fateixar",
    "fateixávamo": "fateixar",
    "fateixávamos": "fateixar",
    "fateixávei": "fateixar",
    "fateixáveis": "fateixar",
    "fateusins": "fateusim",
    "fatia": "fatiar",
    "fatiada": "fatiar",
    "fatiadas": "fatiar",
    "fatiado": "fatiar",
    "fatiados": "fatiar",
    "fatiai": "fatiar",
    "fatiais": "fatiar",
    "fatiam": "fatiar",
    "fatiamo": "fatiar",
    "fatiamos": "fatiar",
    "fatiando": "fatiar",
    "fatiara": "fatiar",
    "fatiaram": "fatiar",
    "fatiaras": "fatiar",
    "fatiarde": "fatiar",
    "fatiardes": "fatiar",
    "fatiare": "fatiar",
    "fatiarei": "fatiar",
    "fatiareis": "fatiar",
    "fatiarem": "fatiar",
    "fatiaremos": "fatiar",
    "fatiares": "fatiar",
    "fatiaria": "fatiar",
    "fatiariam": "fatiar",
    "fatiarias": "fatiar",
    "fatiarmo": "fatiar",
    "fatiarmos": "fatiar",
    "fatiará": "fatiar",
    "fatiarás": "fatiar",
    "fatiarão": "fatiar",
    "fatiaríamos": "fatiar",
    "fatiaríeis": "fatiar",
    "fatias": "fatiar",
    "fatiasse": "fatiar",
    "fatiassem": "fatiar",
    "fatiasses": "fatiar",
    "fatiaste": "fatiar",
    "fatiastes": "fatiar",
    "fatiava": "fatiar",
    "fatiavam": "fatiar",
    "fatiavas": "fatiar",
    "fatiazinha": "fatia",
    "fatiazinhas": "fatia",
    "fatiazita": "fatia",
    "fatiazitas": "fatia",
    "faticana": "faticano",
    "faticanas": "faticano",
    "faticanos": "faticano",
    "faticeiras": "faticeira",
    "fatie": "fatiar",
    "fatiei": "fatiar",
    "fatieis": "fatiar",
    "fatiem": "fatiar",
    "fatiemo": "fatiar",
    "fatiemos": "fatiar",
    "faties": "fatiar",
    "fatiga": "fatigar",
    "fatigada": "fatigar",
    "fatigadas": "fatigar",
    "fatigado": "fatigar",
    "fatigadora": "fatigador",
    "fatigadoras": "fatigador",
    "fatigadores": "fatigador",
    "fatigados": "fatigar",
    "fatigadíssima": "fatigado",
    "fatigadíssimas": "fatigado",
    "fatigadíssimo": "fatigado",
    "fatigadíssimos": "fatigado",
    "fatigai": "fatigar",
    "fatigais": "fatigar",
    "fatigam": "fatigar",
    "fatigamentos": "fatigamento",
    "fatigamo": "fatigar",
    "fatigamos": "fatigar",
    "fatigando": "fatigar",
    "fatigantes": "fatigante",
    "fatigara": "fatigar",
    "fatigaram": "fatigar",
    "fatigaras": "fatigar",
    "fatigarde": "fatigar",
    "fatigardes": "fatigar",
    "fatigare": "fatigar",
    "fatigarei": "fatigar",
    "fatigareis": "fatigar",
    "fatigarem": "fatigar",
    "fatigaremos": "fatigar",
    "fatigares": "fatigar",
    "fatigaria": "fatigar",
    "fatigariam": "fatigar",
    "fatigarias": "fatigar",
    "fatigarmo": "fatigar",
    "fatigarmos": "fatigar",
    "fatigará": "fatigar",
    "fatigarás": "fatigar",
    "fatigarão": "fatigar",
    "fatigaríamos": "fatigar",
    "fatigaríeis": "fatigar",
    "fatigas": "fatigar",
    "fatigasse": "fatigar",
    "fatigassem": "fatigar",
    "fatigasses": "fatigar",
    "fatigaste": "fatigar",
    "fatigastes": "fatigar",
    "fatigava": "fatigar",
    "fatigavam": "fatigar",
    "fatigavas": "fatigar",
    "fatigo": "fatigar",
    "fatigou": "fatigar",
    "fatigue": "fatigar",
    "fatiguei": "fatigar",
    "fatigueis": "fatigar",
    "fatiguem": "fatigar",
    "fatiguemo": "fatigar",
    "fatiguemos": "fatigar",
    "fatigues": "fatigar",
    "fatigá": "fatigar",
    "fatigámo": "fatigar",
    "fatigámos": "fatigar",
    "fatigáramo": "fatigar",
    "fatigáramos": "fatigar",
    "fatigárei": "fatigar",
    "fatigáreis": "fatigar",
    "fatigásseis": "fatigar",
    "fatigássemos": "fatigar",
    "fatigávamo": "fatigar",
    "fatigávamos": "fatigar",
    "fatigávei": "fatigar",
    "fatigáveis": "fatigar",
    "fatiloquentes": "fatiloquente",
    "fatinho": "fato",
    "fatinhos": "fato",
    "fatio": "fatiar",
    "fatiotas": "fatiota",
    "fatiou": "fatiar",
    "fatito": "fato",
    "fatitos": "fato",
    "fatiá": "fatiar",
    "fatiámo": "fatiar",
    "fatiámos": "fatiar",
    "fatiáramo": "fatiar",
    "fatiáramos": "fatiar",
    "fatiárei": "fatiar",
    "fatiáreis": "fatiar",
    "fatiásseis": "fatiar",
    "fatiássemos": "fatiar",
    "fatiávamo": "fatiar",
    "fatiávamos": "fatiar",
    "fatiávei": "fatiar",
    "fatiáveis": "fatiar",
    "fatos": "fato",
    "fatuidades": "fatuidade",
    "fatãozeiros": "fatãozeiro",
    "fatídica": "fatídico",
    "fatídicas": "fatídico",
    "fatídicos": "fatídico",
    "fatífera": "fatífero",
    "fatíferas": "fatífero",
    "fatíferos": "fatífero",
    "fatíloqua": "fatíloquo",
    "fatíloquas": "fatíloquo",
    "fatíloquos": "fatíloquo",
    "fatões": "fatão",
    "faucais": "faucal",
    "fauces": "fauce",
    "faula": "faular",
    "faulada": "faular",
    "fauladas": "faular",
    "faulado": "faular",
    "faulados": "faular",
    "faulai": "faular",
    "faulais": "faular",
    "faulam": "faular",
    "faulamo": "faular",
    "faulamos": "faular",
    "faulando": "faular",
    "faulantes": "faulante",
    "faulara": "faular",
    "faularam": "faular",
    "faularas": "faular",
    "faulardes": "faular",
    "faularei": "faular",
    "faulareis": "faular",
    "faularem": "faular",
    "faularemos": "faular",
    "faulares": "faular",
    "faularia": "faular",
    "faulariam": "faular",
    "faularias": "faular",
    "faularmo": "faular",
    "faularmos": "faular",
    "faulará": "faular",
    "faularás": "faular",
    "faularão": "faular",
    "faularíamos": "faular",
    "faularíeis": "faular",
    "faulas": "faular",
    "faulasse": "faular",
    "faulassem": "faular",
    "faulasses": "faular",
    "faulaste": "faular",
    "faulastes": "faular",
    "faulava": "faular",
    "faulavam": "faular",
    "faulavas": "faular",
    "faule": "faular",
    "faulei": "faular",
    "fauleis": "faular",
    "faulem": "faular",
    "faulemo": "faular",
    "faulemos": "faular",
    "faules": "faular",
    "faulha": "faulhar",
    "faulhada": "faulhar",
    "faulhadas": "faulhar",
    "faulhado": "faulhar",
    "faulhados": "faulhar",
    "faulhai": "faulhar",
    "faulhais": "faulhar",
    "faulham": "faulhar",
    "faulhamo": "faulhar",
    "faulhamos": "faulhar",
    "faulhando": "faulhar",
    "faulhara": "faulhar",
    "faulharam": "faulhar",
    "faulharas": "faulhar",
    "faulhardes": "faulhar",
    "faulharei": "faulhar",
    "faulhareis": "faulhar",
    "faulharem": "faulhar",
    "faulharemos": "faulhar",
    "faulhares": "faulhar",
    "faulharia": "faulhar",
    "faulhariam": "faulhar",
    "faulharias": "faulhar",
    "faulharmo": "faulhar",
    "faulharmos": "faulhar",
    "faulhará": "faulhar",
    "faulharás": "faulhar",
    "faulharão": "faulhar",
    "faulharíamos": "faulhar",
    "faulharíeis": "faulhar",
    "faulhas": "faulhar",
    "faulhasse": "faulhar",
    "faulhassem": "faulhar",
    "faulhasses": "faulhar",
    "faulhaste": "faulhar",
    "faulhastes": "faulhar",
    "faulhava": "faulhar",
    "faulhavam": "faulhar",
    "faulhavas": "faulhar",
    "faulhe": "faulhar",
    "faulhei": "faulhar",
    "faulheis": "faulhar",
    "faulhem": "faulhar",
    "faulhemo": "faulhar",
    "faulhemos": "faulhar",
    "faulhenta": "faulhento",
    "faulhentas": "faulhento",
    "faulhentos": "faulhento",
    "faulhes": "faulhar",
    "faulho": "faulhar",
    "faulhou": "faulhar",
    "faulhámo": "faulhar",
    "faulhámos": "faulhar",
    "faulháramo": "faulhar",
    "faulháramos": "faulhar",
    "faulháreis": "faulhar",
    "faulhásseis": "faulhar",
    "faulhássemos": "faulhar",
    "faulhávamo": "faulhar",
    "faulhávamos": "faulhar",
    "faulháveis": "faulhar",
    "faulo": "faular",
    "faulou": "faular",
    "faulámo": "faular",
    "faulámos": "faular",
    "fauláramo": "faular",
    "fauláramos": "faular",
    "fauláreis": "faular",
    "faulásseis": "faular",
    "faulássemos": "faular",
    "faulávamo": "faular",
    "faulávamos": "faular",
    "fauláveis": "faular",
    "faunas": "fauna",
    "fauniana": "fauniano",
    "faunianas": "fauniano",
    "faunianos": "fauniano",
    "faunos": "fauno",
    "faunígenas": "faunígena",
    "faunística": "faunístico",
    "faunísticas": "faunístico",
    "faunísticos": "faunístico",
    "fausta": "fausto",
    "faustas": "fausto",
    "faustiana": "faustiano",
    "faustianas": "faustiano",
    "faustianos": "faustiano",
    "faustos": "fausto",
    "faustosa": "faustoso",
    "faustosas": "faustoso",
    "faustosos": "faustoso",
    "faustuosa": "faustuoso",
    "faustuosas": "faustuoso",
    "faustuosos": "faustuoso",
    "fautores": "fautor",
    "fautorias": "fautoria",
    "fautoriza": "fautorizar",
    "fautorizada": "fautorizar",
    "fautorizadas": "fautorizar",
    "fautorizado": "fautorizar",
    "fautorizados": "fautorizar",
    "fautorizai": "fautorizar",
    "fautorizais": "fautorizar",
    "fautorizam": "fautorizar",
    "fautorizamo": "fautorizar",
    "fautorizamos": "fautorizar",
    "fautorizando": "fautorizar",
    "fautorizara": "fautorizar",
    "fautorizaram": "fautorizar",
    "fautorizaras": "fautorizar",
    "fautorizarde": "fautorizar",
    "fautorizardes": "fautorizar",
    "fautorizare": "fautorizar",
    "fautorizarei": "fautorizar",
    "fautorizareis": "fautorizar",
    "fautorizarem": "fautorizar",
    "fautorizaremos": "fautorizar",
    "fautorizares": "fautorizar",
    "fautorizaria": "fautorizar",
    "fautorizariam": "fautorizar",
    "fautorizarias": "fautorizar",
    "fautorizarmo": "fautorizar",
    "fautorizarmos": "fautorizar",
    "fautorizará": "fautorizar",
    "fautorizarás": "fautorizar",
    "fautorizarão": "fautorizar",
    "fautorizaríamos": "fautorizar",
    "fautorizaríeis": "fautorizar",
    "fautorizas": "fautorizar",
    "fautorizasse": "fautorizar",
    "fautorizassem": "fautorizar",
    "fautorizasses": "fautorizar",
    "fautorizaste": "fautorizar",
    "fautorizastes": "fautorizar",
    "fautorizava": "fautorizar",
    "fautorizavam": "fautorizar",
    "fautorizavas": "fautorizar",
    "fautorize": "fautorizar",
    "fautorizei": "fautorizar",
    "fautorizeis": "fautorizar",
    "fautorizem": "fautorizar",
    "fautorizemo": "fautorizar",
    "fautorizemos": "fautorizar",
    "fautorizes": "fautorizar",
    "fautorizo": "fautorizar",
    "fautorizou": "fautorizar",
    "fautorizá": "fautorizar",
    "fautorizámo": "fautorizar",
    "fautorizámos": "fautorizar",
    "fautorizáramo": "fautorizar",
    "fautorizáramos": "fautorizar",
    "fautorizárei": "fautorizar",
    "fautorizáreis": "fautorizar",
    "fautorizásseis": "fautorizar",
    "fautorizássemos": "fautorizar",
    "fautorizávamo": "fautorizar",
    "fautorizávamos": "fautorizar",
    "fautorizávei": "fautorizar",
    "fautorizáveis": "fautorizar",
    "fautous": "fautou",
    "fautriz": "fautor",
    "fautrizes": "fautor",
    "fauvismos": "fauvismo",
    "fauvistas": "fauvista",
    "favais": "faval",
    "favarias": "favaria",
    "favas": "fava",
    "favecas": "faveca",
    "faveiras": "faveira",
    "faveiros": "faveiro",
    "favelas": "favela",
    "faviformes": "faviforme",
    "favilas": "favila",
    "favinha": "fava",
    "favinhas": "fava",
    "favita": "fava",
    "favitas": "fava",
    "favonia": "favoniar",
    "favoniada": "favoniar",
    "favoniadas": "favoniar",
    "favoniado": "favoniar",
    "favoniados": "favoniar",
    "favoniai": "favoniar",
    "favoniais": "favoniar",
    "favoniam": "favoniar",
    "favoniamo": "favoniar",
    "favoniamos": "favoniar",
    "favoniando": "favoniar",
    "favoniara": "favoniar",
    "favoniaram": "favoniar",
    "favoniaras": "favoniar",
    "favoniarde": "favoniar",
    "favoniardes": "favoniar",
    "favoniare": "favoniar",
    "favoniarei": "favoniar",
    "favoniareis": "favoniar",
    "favoniarem": "favoniar",
    "favoniaremos": "favoniar",
    "favoniares": "favoniar",
    "favoniaria": "favoniar",
    "favoniariam": "favoniar",
    "favoniarias": "favoniar",
    "favoniarmo": "favoniar",
    "favoniarmos": "favoniar",
    "favoniará": "favoniar",
    "favoniarás": "favoniar",
    "favoniarão": "favoniar",
    "favoniaríamos": "favoniar",
    "favoniaríeis": "favoniar",
    "favonias": "favoniar",
    "favoniasse": "favoniar",
    "favoniassem": "favoniar",
    "favoniasses": "favoniar",
    "favoniaste": "favoniar",
    "favoniastes": "favoniar",
    "favoniava": "favoniar",
    "favoniavam": "favoniar",
    "favoniavas": "favoniar",
    "favonie": "favoniar",
    "favoniei": "favoniar",
    "favonieis": "favoniar",
    "favoniem": "favoniar",
    "favoniemo": "favoniar",
    "favoniemos": "favoniar",
    "favonies": "favoniar",
    "favonio": "favoniar",
    "favoniou": "favoniar",
    "favoniá": "favoniar",
    "favoniámo": "favoniar",
    "favoniámos": "favoniar",
    "favoniáramo": "favoniar",
    "favoniáramos": "favoniar",
    "favoniárei": "favoniar",
    "favoniáreis": "favoniar",
    "favoniásseis": "favoniar",
    "favoniássemos": "favoniar",
    "favoniávamo": "favoniar",
    "favoniávamos": "favoniar",
    "favoniávei": "favoniar",
    "favoniáveis": "favoniar",
    "favorece": "favorecer",
    "favorecedora": "favorecedor",
    "favorecedoras": "favorecedor",
    "favorecedores": "favorecedor",
    "favorecei": "favorecer",
    "favoreceis": "favorecer",
    "favorecem": "favorecer",
    "favorecemo": "favorecer",
    "favorecemos": "favorecer",
    "favorecendo": "favorecer",
    "favorecera": "favorecer",
    "favoreceram": "favorecer",
    "favoreceras": "favorecer",
    "favorecerde": "favorecer",
    "favorecerdes": "favorecer",
    "favorecere": "favorecer",
    "favorecerei": "favorecer",
    "favorecereis": "favorecer",
    "favorecerem": "favorecer",
    "favoreceremos": "favorecer",
    "favoreceres": "favorecer",
    "favoreceria": "favorecer",
    "favoreceriam": "favorecer",
    "favorecerias": "favorecer",
    "favorecermo": "favorecer",
    "favorecermos": "favorecer",
    "favorecerá": "favorecer",
    "favorecerás": "favorecer",
    "favorecerão": "favorecer",
    "favoreceríamos": "favorecer",
    "favoreceríeis": "favorecer",
    "favoreces": "favorecer",
    "favorecesse": "favorecer",
    "favorecessem": "favorecer",
    "favorecesses": "favorecer",
    "favoreceste": "favorecer",
    "favorecestes": "favorecer",
    "favoreceu": "favorecer",
    "favoreci": "favorecer",
    "favorecia": "favorecer",
    "favoreciam": "favorecer",
    "favorecias": "favorecer",
    "favorecida": "favorecido",
    "favorecidas": "favorecido",
    "favorecido": "favorecer",
    "favorecidos": "favorecido",
    "favorecidíssima": "favorecido",
    "favorecidíssimas": "favorecido",
    "favorecidíssimo": "favorecido",
    "favorecidíssimos": "favorecido",
    "favorecimentos": "favorecimento",
    "favorecê": "favorecer",
    "favorecêramo": "favorecer",
    "favorecêramos": "favorecer",
    "favorecêrei": "favorecer",
    "favorecêreis": "favorecer",
    "favorecêsseis": "favorecer",
    "favorecêssemos": "favorecer",
    "favorecíamo": "favorecer",
    "favorecíamos": "favorecer",
    "favorecíei": "favorecer",
    "favorecíeis": "favorecer",
    "favores": "favor",
    "favoreça": "favorecer",
    "favoreçais": "favorecer",
    "favoreçam": "favorecer",
    "favoreçamo": "favorecer",
    "favoreçamos": "favorecer",
    "favoreças": "favorecer",
    "favoreço": "favorecer",
    "favorita": "favorito",
    "favoritas": "favorito",
    "favoritismos": "favoritismo",
    "favoritos": "favorito",
    "favoriza": "favorizar",
    "favorizada": "favorizar",
    "favorizadas": "favorizar",
    "favorizado": "favorizar",
    "favorizados": "favorizar",
    "favorizai": "favorizar",
    "favorizais": "favorizar",
    "favorizam": "favorizar",
    "favorizamo": "favorizar",
    "favorizamos": "favorizar",
    "favorizando": "favorizar",
    "favorizara": "favorizar",
    "favorizaram": "favorizar",
    "favorizaras": "favorizar",
    "favorizarde": "favorizar",
    "favorizardes": "favorizar",
    "favorizare": "favorizar",
    "favorizarei": "favorizar",
    "favorizareis": "favorizar",
    "favorizarem": "favorizar",
    "favorizaremos": "favorizar",
    "favorizares": "favorizar",
    "favorizaria": "favorizar",
    "favorizariam": "favorizar",
    "favorizarias": "favorizar",
    "favorizarmo": "favorizar",
    "favorizarmos": "favorizar",
    "favorizará": "favorizar",
    "favorizarás": "favorizar",
    "favorizarão": "favorizar",
    "favorizaríamos": "favorizar",
    "favorizaríeis": "favorizar",
    "favorizas": "favorizar",
    "favorizasse": "favorizar",
    "favorizassem": "favorizar",
    "favorizasses": "favorizar",
    "favorizaste": "favorizar",
    "favorizastes": "favorizar",
    "favorizava": "favorizar",
    "favorizavam": "favorizar",
    "favorizavas": "favorizar",
    "favorize": "favorizar",
    "favorizei": "favorizar",
    "favorizeis": "favorizar",
    "favorizem": "favorizar",
    "favorizemo": "favorizar",
    "favorizemos": "favorizar",
    "favorizes": "favorizar",
    "favorizo": "favorizar",
    "favorizou": "favorizar",
    "favorizá": "favorizar",
    "favorizámo": "favorizar",
    "favorizámos": "favorizar",
    "favorizáramo": "favorizar",
    "favorizáramos": "favorizar",
    "favorizárei": "favorizar",
    "favorizáreis": "favorizar",
    "favorizásseis": "favorizar",
    "favorizássemos": "favorizar",
    "favorizávamo": "favorizar",
    "favorizávamos": "favorizar",
    "favorizávei": "favorizar",
    "favorizáveis": "favorizar",
    "favorzinho": "favor",
    "favorzinhos": "favor",
    "favorzito": "favor",
    "favorzitos": "favor",
    "favoráveis": "favorável",
    "favos": "favo",
    "favosa": "favoso",
    "favosas": "favoso",
    "favosos": "favoso",
    "favónia": "favónio",
    "favónias": "favónio",
    "favónios": "favónio",
    "faxes": "fax",
    "faxina": "faxinar",
    "faxinada": "faxinar",
    "faxinadas": "faxinar",
    "faxinado": "faxinar",
    "faxinados": "faxinar",
    "faxinagens": "faxinagem",
    "faxinai": "faxinar",
    "faxinais": "faxinar",
    "faxinam": "faxinar",
    "faxinamo": "faxinar",
    "faxinamos": "faxinar",
    "faxinando": "faxinar",
    "faxinara": "faxinar",
    "faxinaram": "faxinar",
    "faxinaras": "faxinar",
    "faxinardes": "faxinar",
    "faxinarei": "faxinar",
    "faxinareis": "faxinar",
    "faxinarem": "faxinar",
    "faxinaremos": "faxinar",
    "faxinares": "faxinar",
    "faxinaria": "faxinar",
    "faxinariam": "faxinar",
    "faxinarias": "faxinar",
    "faxinarmo": "faxinar",
    "faxinarmos": "faxinar",
    "faxinará": "faxinar",
    "faxinarás": "faxinar",
    "faxinarão": "faxinar",
    "faxinaríamos": "faxinar",
    "faxinaríeis": "faxinar",
    "faxinas": "faxinar",
    "faxinasse": "faxinar",
    "faxinassem": "faxinar",
    "faxinasses": "faxinar",
    "faxinaste": "faxinar",
    "faxinastes": "faxinar",
    "faxinava": "faxinar",
    "faxinavam": "faxinar",
    "faxinavas": "faxinar",
    "faxine": "faxinar",
    "faxinei": "faxinar",
    "faxineis": "faxinar",
    "faxinem": "faxinar",
    "faxinemo": "faxinar",
    "faxinemos": "faxinar",
    "faxines": "faxinar",
    "faxino": "faxinar",
    "faxinou": "faxinar",
    "faxinámo": "faxinar",
    "faxinámos": "faxinar",
    "faxináramo": "faxinar",
    "faxináramos": "faxinar",
    "faxináreis": "faxinar",
    "faxinásseis": "faxinar",
    "faxinássemos": "faxinar",
    "faxinávamo": "faxinar",
    "faxinávamos": "faxinar",
    "faxináveis": "faxinar",
    "faz": "fazer",
    "faze": "fazer",
    "fazedora": "fazedor",
    "fazedoras": "fazedor",
    "fazedores": "fazedor",
    "fazeduras": "fazedura",
    "fazei": "fazer",
    "fazeis": "fazer",
    "fazem": "fazer",
    "fazemo": "fazer",
    "fazemos": "fazer",
    "fazendas": "fazenda",
    "fazendeira": "fazendeiro",
    "fazendeiras": "fazendeiro",
    "fazendeiros": "fazendeiro",
    "fazendistas": "fazendista",
    "fazendo": "fazer",
    "fazendária": "fazendário",
    "fazendárias": "fazendário",
    "fazendários": "fazendário",
    "fazerde": "fazer",
    "fazerdes": "fazer",
    "fazere": "fazer",
    "fazerem": "fazer",
    "fazeres": "fazer",
    "fazermo": "fazer",
    "fazermos": "fazer",
    "fazes": "fazer",
    "fazia": "fazer",
    "faziam": "fazer",
    "fazias": "fazer",
    "fazê": "fazer",
    "fazêndulas": "fazêndula",
    "fazíamo": "fazer",
    "fazíamos": "fazer",
    "fazíei": "fazer",
    "fazíeis": "fazer",
    "fazíveis": "fazível",
    "faça": "fazer",
    "façais": "fazer",
    "façalva": "façalvo",
    "façalvas": "façalvo",
    "façalvos": "façalvo",
    "façam": "fazer",
    "façamo": "fazer",
    "façamos": "fazer",
    "façanhas": "façanha",
    "façanheira": "façanheiro",
    "façanheiras": "façanheiro",
    "façanheiros": "façanheiro",
    "façanhices": "façanhice",
    "façanhosa": "façanhoso",
    "façanhosas": "façanhoso",
    "façanhosos": "façanhoso",
    "façanhuda": "façanhudo",
    "façanhudas": "façanhudo",
    "façanhudos": "façanhudo",
    "faças": "fazer",
    "faço": "fazer",
    "façoilas": "façoila",
    "façuda": "façudo",
    "façudas": "façudo",
    "façudos": "façudo",
    "faétons": "faéton",
    "faíscas": "faísca",
    "faúlas": "faúla",
    "faúlhas": "faúlha",
    "fealdades": "fealdade",
    "feanchona": "feanchão",
    "feanchonas": "feanchão",
    "feanchões": "feanchão",
    "febeia": "febeu",
    "febeias": "febeu",
    "febeus": "febeu",
    "febras": "febra",
    "febres": "febre",
    "febrezinha": "febre",
    "febrezinhas": "febre",
    "febrezita": "febre",
    "febrezitas": "febre",
    "febricita": "febricitar",
    "febricitada": "febricitar",
    "febricitadas": "febricitar",
    "febricitado": "febricitar",
    "febricitados": "febricitar",
    "febricitai": "febricitar",
    "febricitais": "febricitar",
    "febricitam": "febricitar",
    "febricitamo": "febricitar",
    "febricitamos": "febricitar",
    "febricitando": "febricitar",
    "febricitantes": "febricitante",
    "febricitara": "febricitar",
    "febricitaram": "febricitar",
    "febricitaras": "febricitar",
    "febricitardes": "febricitar",
    "febricitarei": "febricitar",
    "febricitareis": "febricitar",
    "febricitarem": "febricitar",
    "febricitaremos": "febricitar",
    "febricitares": "febricitar",
    "febricitaria": "febricitar",
    "febricitariam": "febricitar",
    "febricitarias": "febricitar",
    "febricitarmo": "febricitar",
    "febricitarmos": "febricitar",
    "febricitará": "febricitar",
    "febricitarás": "febricitar",
    "febricitarão": "febricitar",
    "febricitaríamos": "febricitar",
    "febricitaríeis": "febricitar",
    "febricitas": "febricitar",
    "febricitasse": "febricitar",
    "febricitassem": "febricitar",
    "febricitasses": "febricitar",
    "febricitaste": "febricitar",
    "febricitastes": "febricitar",
    "febricitava": "febricitar",
    "febricitavam": "febricitar",
    "febricitavas": "febricitar",
    "febricitações": "febricitação",
    "febricite": "febricitar",
    "febricitei": "febricitar",
    "febriciteis": "febricitar",
    "febricitem": "febricitar",
    "febricitemo": "febricitar",
    "febricitemos": "febricitar",
    "febricites": "febricitar",
    "febricito": "febricitar",
    "febricitou": "febricitar",
    "febricitámo": "febricitar",
    "febricitámos": "febricitar",
    "febricitáramo": "febricitar",
    "febricitáramos": "febricitar",
    "febricitáreis": "febricitar",
    "febricitásseis": "febricitar",
    "febricitássemos": "febricitar",
    "febricitávamo": "febricitar",
    "febricitávamos": "febricitar",
    "febricitáveis": "febricitar",
    "febriculosa": "febriculoso",
    "febriculosas": "febriculoso",
    "febriculosos": "febriculoso",
    "febrinha": "febre",
    "febrinhas": "febre",
    "febriologias": "febriologia",
    "febris": "febril",
    "febrita": "febre",
    "febritas": "febre",
    "febrosa": "febroso",
    "febrosas": "febroso",
    "febrosos": "febroso",
    "febrículas": "febrícula",
    "febrífuga": "febrífugo",
    "febrífugas": "febrífugo",
    "febrífugos": "febrífugo",
    "febrígena": "febrígeno",
    "febrígenas": "febrígeno",
    "febrígenos": "febrígeno",
    "febrões": "febrão",
    "fecais": "fecal",
    "fecalóides": "fecalóide",
    "fecha": "fechar",
    "fechada": "fechar",
    "fechadas": "fechar",
    "fechadinha": "fechado",
    "fechadinhas": "fechado",
    "fechadinho": "fechado",
    "fechadinhos": "fechado",
    "fechadita": "fechado",
    "fechaditas": "fechado",
    "fechadito": "fechado",
    "fechaditos": "fechado",
    "fechado": "fechar",
    "fechados": "fechar",
    "fechaduras": "fechadura",
    "fechadíssima": "fechado",
    "fechadíssimas": "fechado",
    "fechadíssimo": "fechado",
    "fechadíssimos": "fechado",
    "fechai": "fechar",
    "fechais": "fechar",
    "fecham": "fechar",
    "fechamentos": "fechamento",
    "fechamo": "fechar",
    "fechamos": "fechar",
    "fechando": "fechar",
    "fechara": "fechar",
    "fecharam": "fechar",
    "fecharas": "fechar",
    "fecharde": "fechar",
    "fechardes": "fechar",
    "fechare": "fechar",
    "fecharei": "fechar",
    "fechareis": "fechar",
    "fecharem": "fechar",
    "fecharemos": "fechar",
    "fechares": "fechar",
    "fecharia": "fechar",
    "fechariam": "fechar",
    "fecharias": "fecharia",
    "fecharmo": "fechar",
    "fecharmos": "fechar",
    "fechará": "fechar",
    "fecharás": "fechar",
    "fecharão": "fechar",
    "fecharíamos": "fechar",
    "fecharíeis": "fechar",
    "fechas": "fechar",
    "fechasse": "fechar",
    "fechassem": "fechar",
    "fechasses": "fechar",
    "fechaste": "fechar",
    "fechastes": "fechar",
    "fechava": "fechar",
    "fechavam": "fechar",
    "fechavas": "fechar",
    "feche": "fechar",
    "fechei": "fechar",
    "fecheis": "fechar",
    "fechem": "fechar",
    "fechemo": "fechar",
    "fechemos": "fechar",
    "feches": "fechar",
    "fecho": "fechar",
    "fechos": "fecho",
    "fechou": "fechar",
    "fechá": "fechar",
    "fechámo": "fechar",
    "fechámos": "fechar",
    "fecháramo": "fechar",
    "fecháramos": "fechar",
    "fechárei": "fechar",
    "fecháreis": "fechar",
    "fechásseis": "fechar",
    "fechássemos": "fechar",
    "fechávamo": "fechar",
    "fechávamos": "fechar",
    "fechávei": "fechar",
    "fecháveis": "fechável",
    "feciais": "fecial",
    "feculenta": "feculento",
    "feculentas": "feculento",
    "feculentos": "feculento",
    "feculistas": "feculista",
    "feculometrias": "feculometria",
    "feculométrica": "feculométrico",
    "feculométricas": "feculométrico",
    "feculométricos": "feculométrico",
    "feculosa": "feculoso",
    "feculosas": "feculoso",
    "feculosos": "feculoso",
    "feculências": "feculência",
    "feculóides": "feculóide",
    "feculómetros": "feculómetro",
    "fecunda": "fecundo",
    "fecundada": "fecundar",
    "fecundadas": "fecundar",
    "fecundado": "fecundar",
    "fecundadora": "fecundador",
    "fecundadoras": "fecundador",
    "fecundadores": "fecundador",
    "fecundados": "fecundar",
    "fecundai": "fecundar",
    "fecundais": "fecundar",
    "fecundam": "fecundar",
    "fecundamo": "fecundar",
    "fecundamos": "fecundar",
    "fecundando": "fecundar",
    "fecundantes": "fecundante",
    "fecundara": "fecundar",
    "fecundaram": "fecundar",
    "fecundaras": "fecundar",
    "fecundarde": "fecundar",
    "fecundardes": "fecundar",
    "fecundare": "fecundar",
    "fecundarei": "fecundar",
    "fecundareis": "fecundar",
    "fecundarem": "fecundar",
    "fecundaremos": "fecundar",
    "fecundares": "fecundar",
    "fecundaria": "fecundar",
    "fecundariam": "fecundar",
    "fecundarias": "fecundar",
    "fecundarmo": "fecundar",
    "fecundarmos": "fecundar",
    "fecundará": "fecundar",
    "fecundarás": "fecundar",
    "fecundarão": "fecundar",
    "fecundaríamos": "fecundar",
    "fecundaríeis": "fecundar",
    "fecundas": "fecundo",
    "fecundasse": "fecundar",
    "fecundassem": "fecundar",
    "fecundasses": "fecundar",
    "fecundaste": "fecundar",
    "fecundastes": "fecundar",
    "fecundativa": "fecundativo",
    "fecundativas": "fecundativo",
    "fecundativos": "fecundativo",
    "fecundava": "fecundar",
    "fecundavam": "fecundar",
    "fecundavas": "fecundar",
    "fecundações": "fecundação",
    "fecunde": "fecundar",
    "fecundei": "fecundar",
    "fecundeis": "fecundar",
    "fecundem": "fecundar",
    "fecundemo": "fecundar",
    "fecundemos": "fecundar",
    "fecundes": "fecundar",
    "fecundidades": "fecundidade",
    "fecundiza": "fecundizar",
    "fecundizada": "fecundizar",
    "fecundizadas": "fecundizar",
    "fecundizado": "fecundizar",
    "fecundizados": "fecundizar",
    "fecundizai": "fecundizar",
    "fecundizais": "fecundizar",
    "fecundizam": "fecundizar",
    "fecundizamo": "fecundizar",
    "fecundizamos": "fecundizar",
    "fecundizando": "fecundizar",
    "fecundizantes": "fecundizante",
    "fecundizara": "fecundizar",
    "fecundizaram": "fecundizar",
    "fecundizaras": "fecundizar",
    "fecundizarde": "fecundizar",
    "fecundizardes": "fecundizar",
    "fecundizare": "fecundizar",
    "fecundizarei": "fecundizar",
    "fecundizareis": "fecundizar",
    "fecundizarem": "fecundizar",
    "fecundizaremos": "fecundizar",
    "fecundizares": "fecundizar",
    "fecundizaria": "fecundizar",
    "fecundizariam": "fecundizar",
    "fecundizarias": "fecundizar",
    "fecundizarmo": "fecundizar",
    "fecundizarmos": "fecundizar",
    "fecundizará": "fecundizar",
    "fecundizarás": "fecundizar",
    "fecundizarão": "fecundizar",
    "fecundizaríamos": "fecundizar",
    "fecundizaríeis": "fecundizar",
    "fecundizas": "fecundizar",
    "fecundizasse": "fecundizar",
    "fecundizassem": "fecundizar",
    "fecundizasses": "fecundizar",
    "fecundizaste": "fecundizar",
    "fecundizastes": "fecundizar",
    "fecundizava": "fecundizar",
    "fecundizavam": "fecundizar",
    "fecundizavas": "fecundizar",
    "fecundize": "fecundizar",
    "fecundizei": "fecundizar",
    "fecundizeis": "fecundizar",
    "fecundizem": "fecundizar",
    "fecundizemo": "fecundizar",
    "fecundizemos": "fecundizar",
    "fecundizes": "fecundizar",
    "fecundizo": "fecundizar",
    "fecundizou": "fecundizar",
    "fecundizá": "fecundizar",
    "fecundizámo": "fecundizar",
    "fecundizámos": "fecundizar",
    "fecundizáramo": "fecundizar",
    "fecundizáramos": "fecundizar",
    "fecundizárei": "fecundizar",
    "fecundizáreis": "fecundizar",
    "fecundizásseis": "fecundizar",
    "fecundizássemos": "fecundizar",
    "fecundizávamo": "fecundizar",
    "fecundizávamos": "fecundizar",
    "fecundizávei": "fecundizar",
    "fecundizáveis": "fecundizar",
    "fecundo": "fecundar",
    "fecundos": "fecundo",
    "fecundou": "fecundar",
    "fecundá": "fecundar",
    "fecundámo": "fecundar",
    "fecundámos": "fecundar",
    "fecundáramo": "fecundar",
    "fecundáramos": "fecundar",
    "fecundárei": "fecundar",
    "fecundáreis": "fecundar",
    "fecundásseis": "fecundar",
    "fecundássemos": "fecundar",
    "fecundávamo": "fecundar",
    "fecundávamos": "fecundar",
    "fecundávei": "fecundar",
    "fecundáveis": "fecundável",
    "fecundíssima": "fecundo",
    "fecundíssimas": "fecundo",
    "fecundíssimo": "fecundo",
    "fecundíssimos": "fecundo",
    "fecúndias": "fecúndia",
    "feda": "feder",
    "fedais": "feder",
    "fedam": "feder",
    "fedamo": "feder",
    "fedamos": "feder",
    "fedas": "feder",
    "fedavelhas": "fedavelha",
    "fede": "feder",
    "fedegas": "fedega",
    "fedegosa": "fedegoso",
    "fedegosas": "fedegoso",
    "fedegosos": "fedegoso",
    "fedei": "feder",
    "fedeis": "feder",
    "fedelha": "fedelho",
    "fedelhas": "fedelho",
    "fedelhices": "fedelhice",
    "fedelhos": "fedelho",
    "fedelhota": "fedelhote",
    "fedelhotas": "fedelhote",
    "fedelhotes": "fedelhote",
    "fedem": "feder",
    "fedemo": "feder",
    "fedemos": "feder",
    "fedendo": "feder",
    "fedentinas": "fedentina",
    "fedentinosa": "fedentinoso",
    "fedentinosas": "fedentinoso",
    "fedentinosos": "fedentinoso",
    "federa": "federar",
    "federada": "federar",
    "federadas": "federar",
    "federado": "federar",
    "federados": "federar",
    "federai": "federar",
    "federais": "federar",
    "federalismos": "federalismo",
    "federalistas": "federalista",
    "federaliza": "federalizar",
    "federalizada": "federalizar",
    "federalizadas": "federalizar",
    "federalizado": "federalizar",
    "federalizados": "federalizar",
    "federalizai": "federalizar",
    "federalizais": "federalizar",
    "federalizam": "federalizar",
    "federalizamo": "federalizar",
    "federalizamos": "federalizar",
    "federalizando": "federalizar",
    "federalizara": "federalizar",
    "federalizaram": "federalizar",
    "federalizaras": "federalizar",
    "federalizarde": "federalizar",
    "federalizardes": "federalizar",
    "federalizare": "federalizar",
    "federalizarei": "federalizar",
    "federalizareis": "federalizar",
    "federalizarem": "federalizar",
    "federalizaremos": "federalizar",
    "federalizares": "federalizar",
    "federalizaria": "federalizar",
    "federalizariam": "federalizar",
    "federalizarias": "federalizar",
    "federalizarmo": "federalizar",
    "federalizarmos": "federalizar",
    "federalizará": "federalizar",
    "federalizarás": "federalizar",
    "federalizarão": "federalizar",
    "federalizaríamos": "federalizar",
    "federalizaríeis": "federalizar",
    "federalizas": "federalizar",
    "federalizasse": "federalizar",
    "federalizassem": "federalizar",
    "federalizasses": "federalizar",
    "federalizaste": "federalizar",
    "federalizastes": "federalizar",
    "federalizava": "federalizar",
    "federalizavam": "federalizar",
    "federalizavas": "federalizar",
    "federalizações": "federalização",
    "federalize": "federalizar",
    "federalizei": "federalizar",
    "federalizeis": "federalizar",
    "federalizem": "federalizar",
    "federalizemo": "federalizar",
    "federalizemos": "federalizar",
    "federalizes": "federalizar",
    "federalizo": "federalizar",
    "federalizou": "federalizar",
    "federalizá": "federalizar",
    "federalizámo": "federalizar",
    "federalizámos": "federalizar",
    "federalizáramo": "federalizar",
    "federalizáramos": "federalizar",
    "federalizárei": "federalizar",
    "federalizáreis": "federalizar",
    "federalizásseis": "federalizar",
    "federalizássemos": "federalizar",
    "federalizávamo": "federalizar",
    "federalizávamos": "federalizar",
    "federalizávei": "federalizar",
    "federalizáveis": "federalizável",
    "federam": "federar",
    "federamo": "federar",
    "federamos": "federar",
    "federando": "federar",
    "federara": "federar",
    "federaram": "federar",
    "federaras": "federar",
    "federarde": "federar",
    "federardes": "federar",
    "federare": "federar",
    "federarei": "federar",
    "federareis": "federar",
    "federarem": "federar",
    "federaremos": "federar",
    "federares": "federar",
    "federaria": "federar",
    "federariam": "federar",
    "federarias": "federar",
    "federarmo": "federar",
    "federarmos": "federar",
    "federará": "federar",
    "federarás": "federar",
    "federarão": "federar",
    "federaríamos": "federar",
    "federaríeis": "federar",
    "federas": "federar",
    "federasse": "federar",
    "federassem": "federar",
    "federasses": "federar",
    "federaste": "federar",
    "federastes": "federar",
    "federativa": "federativo",
    "federativas": "federativo",
    "federativos": "federativo",
    "federava": "federar",
    "federavam": "federar",
    "federavas": "federar",
    "federações": "federação",
    "federdes": "feder",
    "federe": "federar",
    "federei": "federar",
    "federeis": "federar",
    "federem": "federar",
    "federemo": "federar",
    "federemos": "federar",
    "federes": "federar",
    "federia": "feder",
    "federiam": "feder",
    "federias": "feder",
    "federmo": "feder",
    "federmos": "feder",
    "federo": "federar",
    "federou": "federar",
    "federá": "federar",
    "federámo": "federar",
    "federámos": "federar",
    "federáramo": "federar",
    "federáramos": "federar",
    "federárei": "federar",
    "federáreis": "federar",
    "federás": "feder",
    "federásseis": "federar",
    "federássemos": "federar",
    "federávamo": "federar",
    "federávamos": "federar",
    "federávei": "federar",
    "federáveis": "federar",
    "federão": "feder",
    "federíamos": "feder",
    "federíeis": "feder",
    "fedes": "feder",
    "fedesse": "feder",
    "fedessem": "feder",
    "fedesses": "feder",
    "fedeste": "feder",
    "fedestes": "feder",
    "fedeu": "feder",
    "fedevelhas": "fedevelha",
    "fedi": "feder",
    "fedia": "feder",
    "fediam": "feder",
    "fedias": "feder",
    "fedida": "feder",
    "fedidas": "feder",
    "fedido": "feder",
    "fedidos": "feder",
    "fedincha": "fedinchar",
    "fedinchada": "fedinchar",
    "fedinchadas": "fedinchar",
    "fedinchado": "fedinchar",
    "fedinchados": "fedinchar",
    "fedinchai": "fedinchar",
    "fedinchais": "fedinchar",
    "fedincham": "fedinchar",
    "fedinchamo": "fedinchar",
    "fedinchamos": "fedinchar",
    "fedinchando": "fedinchar",
    "fedinchara": "fedinchar",
    "fedincharam": "fedinchar",
    "fedincharas": "fedinchar",
    "fedinchardes": "fedinchar",
    "fedincharei": "fedinchar",
    "fedinchareis": "fedinchar",
    "fedincharem": "fedinchar",
    "fedincharemos": "fedinchar",
    "fedinchares": "fedinchar",
    "fedincharia": "fedinchar",
    "fedinchariam": "fedinchar",
    "fedincharias": "fedinchar",
    "fedincharmo": "fedinchar",
    "fedincharmos": "fedinchar",
    "fedinchará": "fedinchar",
    "fedincharás": "fedinchar",
    "fedincharão": "fedinchar",
    "fedincharíamos": "fedinchar",
    "fedincharíeis": "fedinchar",
    "fedinchas": "fedinchar",
    "fedinchasse": "fedinchar",
    "fedinchassem": "fedinchar",
    "fedinchasses": "fedinchar",
    "fedinchaste": "fedinchar",
    "fedinchastes": "fedinchar",
    "fedinchava": "fedinchar",
    "fedinchavam": "fedinchar",
    "fedinchavas": "fedinchar",
    "fedinche": "fedinchar",
    "fedinchei": "fedinchar",
    "fedincheis": "fedinchar",
    "fedinchem": "fedinchar",
    "fedinchemo": "fedinchar",
    "fedinchemos": "fedinchar",
    "fedinches": "fedinchar",
    "fedincho": "fedinchar",
    "fedinchou": "fedinchar",
    "fedinchámo": "fedinchar",
    "fedinchámos": "fedinchar",
    "fedincháramo": "fedinchar",
    "fedincháramos": "fedinchar",
    "fedincháreis": "fedinchar",
    "fedinchásseis": "fedinchar",
    "fedinchássemos": "fedinchar",
    "fedinchávamo": "fedinchar",
    "fedinchávamos": "fedinchar",
    "fedincháveis": "fedinchar",
    "fedo": "feder",
    "fedocas": "fedoca",
    "fedorenta": "fedorento",
    "fedorentas": "fedorento",
    "fedorentinas": "fedorentina",
    "fedorentos": "fedorento",
    "fedores": "fedor",
    "fedêramo": "feder",
    "fedêramos": "feder",
    "fedêreis": "feder",
    "fedêsseis": "feder",
    "fedêssemos": "feder",
    "fedíamo": "feder",
    "fedíamos": "feder",
    "fedíeis": "feder",
    "fedífraga": "fedífrago",
    "fedífragas": "fedífrago",
    "fedífragos": "fedífrago",
    "fedúcias": "fedúcia",
    "fedúncias": "fedúncia",
    "feerias": "feeria",
    "feia": "feio",
    "feiarrona": "feiarrão",
    "feiarronas": "feiarrão",
    "feiarrões": "feiarrão",
    "feias": "feio",
    "feiinha": "feio",
    "feiinhas": "feio",
    "feiinho": "feio",
    "feiinhos": "feio",
    "feiita": "feio",
    "feiitas": "feio",
    "feiito": "feio",
    "feiitos": "feio",
    "feijoadas": "feijoada",
    "feijoais": "feijoal",
    "feijoas": "feijoa",
    "feijocas": "feijoca",
    "feijoeiros": "feijoeiro",
    "feijões": "feijão",
    "feilas": "feila",
    "feios": "feio",
    "feira": "feirar",
    "feirada": "feirar",
    "feiradas": "feirar",
    "feirado": "feirar",
    "feirados": "feirar",
    "feirai": "feirar",
    "feirais": "feirar",
    "feiram": "feirar",
    "feiramo": "feirar",
    "feiramos": "feirar",
    "feirando": "feirar",
    "feirantes": "feirante",
    "feirara": "feirar",
    "feiraram": "feirar",
    "feiraras": "feirar",
    "feirardes": "feirar",
    "feirarei": "feirar",
    "feirareis": "feirar",
    "feirarem": "feirar",
    "feiraremos": "feirar",
    "feirares": "feirar",
    "feiraria": "feirar",
    "feirariam": "feirar",
    "feirarias": "feirar",
    "feirarmo": "feirar",
    "feirarmos": "feirar",
    "feirará": "feirar",
    "feirarás": "feirar",
    "feirarão": "feirar",
    "feiraríamos": "feirar",
    "feiraríeis": "feirar",
    "feiras": "feirar",
    "feirasse": "feirar",
    "feirassem": "feirar",
    "feirasses": "feirar",
    "feiraste": "feirar",
    "feirastes": "feirar",
    "feirava": "feirar",
    "feiravam": "feirar",
    "feiravas": "feirar",
    "feire": "feirar",
    "feirei": "feirar",
    "feireira": "feireiro",
    "feireiras": "feireiro",
    "feireiros": "feireiro",
    "feireis": "feirar",
    "feirem": "feirar",
    "feiremo": "feirar",
    "feiremos": "feirar",
    "feires": "feirar",
    "feirinha": "feira",
    "feirinhas": "feira",
    "feirita": "feira",
    "feiritas": "feira",
    "feiro": "feirar",
    "feirotos": "feiroto",
    "feirou": "feirar",
    "feirámo": "feirar",
    "feirámos": "feirar",
    "feiráramo": "feirar",
    "feiráramos": "feirar",
    "feiráreis": "feirar",
    "feirásseis": "feirar",
    "feirássemos": "feirar",
    "feirávamo": "feirar",
    "feirávamos": "feirar",
    "feiráveis": "feirar",
    "feirões": "feirão",
    "feita": "feito",
    "feitais": "feital",
    "feitas": "feito",
    "feiteiras": "feiteira",
    "feitia": "feitiar",
    "feitiada": "feitiar",
    "feitiadas": "feitiar",
    "feitiado": "feitiar",
    "feitiados": "feitiar",
    "feitiai": "feitiar",
    "feitiais": "feitiar",
    "feitiam": "feitiar",
    "feitiamo": "feitiar",
    "feitiamos": "feitiar",
    "feitiando": "feitiar",
    "feitiara": "feitiar",
    "feitiaram": "feitiar",
    "feitiaras": "feitiar",
    "feitiarde": "feitiar",
    "feitiardes": "feitiar",
    "feitiare": "feitiar",
    "feitiarei": "feitiar",
    "feitiareis": "feitiar",
    "feitiarem": "feitiar",
    "feitiaremos": "feitiar",
    "feitiares": "feitiar",
    "feitiaria": "feitiar",
    "feitiariam": "feitiar",
    "feitiarias": "feitiar",
    "feitiarmo": "feitiar",
    "feitiarmos": "feitiar",
    "feitiará": "feitiar",
    "feitiarás": "feitiar",
    "feitiarão": "feitiar",
    "feitiaríamos": "feitiar",
    "feitiaríeis": "feitiar",
    "feitias": "feitiar",
    "feitiasse": "feitiar",
    "feitiassem": "feitiar",
    "feitiasses": "feitiar",
    "feitiaste": "feitiar",
    "feitiastes": "feitiar",
    "feitiava": "feitiar",
    "feitiavam": "feitiar",
    "feitiavas": "feitiar",
    "feiticeira": "feiticeiro",
    "feiticeiras": "feiticeiro",
    "feiticeiresca": "feiticeiresco",
    "feiticeirescas": "feiticeiresco",
    "feiticeirescos": "feiticeiresco",
    "feiticeiros": "feiticeiro",
    "feiticismos": "feiticismo",
    "feiticistas": "feiticista",
    "feitie": "feitiar",
    "feitiei": "feitiar",
    "feitieis": "feitiar",
    "feitiem": "feitiar",
    "feitiemo": "feitiar",
    "feitiemos": "feitiar",
    "feities": "feitiar",
    "feitinha": "feito",
    "feitinhas": "feito",
    "feitinho": "feito",
    "feitinhos": "feito",
    "feitio": "feitiar",
    "feitios": "feitio",
    "feitiou": "feitiar",
    "feitita": "feito",
    "feititas": "feito",
    "feitito": "feito",
    "feititos": "feito",
    "feitiá": "feitiar",
    "feitiámo": "feitiar",
    "feitiámos": "feitiar",
    "feitiáramo": "feitiar",
    "feitiáramos": "feitiar",
    "feitiárei": "feitiar",
    "feitiáreis": "feitiar",
    "feitiásseis": "feitiar",
    "feitiássemos": "feitiar",
    "feitiávamo": "feitiar",
    "feitiávamos": "feitiar",
    "feitiávei": "feitiar",
    "feitiáveis": "feitiar",
    "feitiça": "feitiço",
    "feitiçarias": "feitiçaria",
    "feitiças": "feitiço",
    "feitiços": "feitiço",
    "feito": "fazer",
    "feitora": "feitorar",
    "feitorada": "feitorar",
    "feitoradas": "feitorar",
    "feitorado": "feitorar",
    "feitorados": "feitorar",
    "feitorai": "feitorar",
    "feitorais": "feitorar",
    "feitoram": "feitorar",
    "feitoramo": "feitorar",
    "feitoramos": "feitorar",
    "feitorando": "feitorar",
    "feitorara": "feitorar",
    "feitoraram": "feitorar",
    "feitoraras": "feitorar",
    "feitorarde": "feitorar",
    "feitorardes": "feitorar",
    "feitorare": "feitorar",
    "feitorarei": "feitorar",
    "feitorareis": "feitorar",
    "feitorarem": "feitorar",
    "feitoraremos": "feitorar",
    "feitorares": "feitorar",
    "feitoraria": "feitorar",
    "feitorariam": "feitorar",
    "feitorarias": "feitorar",
    "feitorarmo": "feitorar",
    "feitorarmos": "feitorar",
    "feitorará": "feitorar",
    "feitorarás": "feitorar",
    "feitorarão": "feitorar",
    "feitoraríamos": "feitorar",
    "feitoraríeis": "feitorar",
    "feitoras": "feitorar",
    "feitorasse": "feitorar",
    "feitorassem": "feitorar",
    "feitorasses": "feitorar",
    "feitoraste": "feitorar",
    "feitorastes": "feitorar",
    "feitorava": "feitorar",
    "feitoravam": "feitorar",
    "feitoravas": "feitorar",
    "feitore": "feitorar",
    "feitorei": "feitorar",
    "feitoreis": "feitorar",
    "feitorem": "feitorar",
    "feitoremo": "feitorar",
    "feitoremos": "feitorar",
    "feitores": "feitorar",
    "feitorias": "feitoria",
    "feitoriza": "feitorizar",
    "feitorizada": "feitorizar",
    "feitorizadas": "feitorizar",
    "feitorizado": "feitorizar",
    "feitorizados": "feitorizar",
    "feitorizai": "feitorizar",
    "feitorizais": "feitorizar",
    "feitorizam": "feitorizar",
    "feitorizamo": "feitorizar",
    "feitorizamos": "feitorizar",
    "feitorizando": "feitorizar",
    "feitorizara": "feitorizar",
    "feitorizaram": "feitorizar",
    "feitorizaras": "feitorizar",
    "feitorizarde": "feitorizar",
    "feitorizardes": "feitorizar",
    "feitorizare": "feitorizar",
    "feitorizarei": "feitorizar",
    "feitorizareis": "feitorizar",
    "feitorizarem": "feitorizar",
    "feitorizaremos": "feitorizar",
    "feitorizares": "feitorizar",
    "feitorizaria": "feitorizar",
    "feitorizariam": "feitorizar",
    "feitorizarias": "feitorizar",
    "feitorizarmo": "feitorizar",
    "feitorizarmos": "feitorizar",
    "feitorizará": "feitorizar",
    "feitorizarás": "feitorizar",
    "feitorizarão": "feitorizar",
    "feitorizaríamos": "feitorizar",
    "feitorizaríeis": "feitorizar",
    "feitorizas": "feitorizar",
    "feitorizasse": "feitorizar",
    "feitorizassem": "feitorizar",
    "feitorizasses": "feitorizar",
    "feitorizaste": "feitorizar",
    "feitorizastes": "feitorizar",
    "feitorizava": "feitorizar",
    "feitorizavam": "feitorizar",
    "feitorizavas": "feitorizar",
    "feitorizações": "feitorização",
    "feitorize": "feitorizar",
    "feitorizei": "feitorizar",
    "feitorizeis": "feitorizar",
    "feitorizem": "feitorizar",
    "feitorizemo": "feitorizar",
    "feitorizemos": "feitorizar",
    "feitorizes": "feitorizar",
    "feitorizo": "feitorizar",
    "feitorizou": "feitorizar",
    "feitorizá": "feitorizar",
    "feitorizámo": "feitorizar",
    "feitorizámos": "feitorizar",
    "feitorizáramo": "feitorizar",
    "feitorizáramos": "feitorizar",
    "feitorizárei": "feitorizar",
    "feitorizáreis": "feitorizar",
    "feitorizásseis": "feitorizar",
    "feitorizássemos": "feitorizar",
    "feitorizávamo": "feitorizar",
    "feitorizávamos": "feitorizar",
    "feitorizávei": "feitorizar",
    "feitorizáveis": "feitorizar",
    "feitoro": "feitorar",
    "feitorou": "feitorar",
    "feitorá": "feitorar",
    "feitorámo": "feitorar",
    "feitorámos": "feitorar",
    "feitoráramo": "feitorar",
    "feitoráramos": "feitorar",
    "feitorárei": "feitorar",
    "feitoráreis": "feitorar",
    "feitorásseis": "feitorar",
    "feitorássemos": "feitorar",
    "feitorávamo": "feitorar",
    "feitorávamos": "feitorar",
    "feitorávei": "feitorar",
    "feitoráveis": "feitorar",
    "feitos": "feito",
    "feituras": "feitura",
    "feitureira": "feitureiro",
    "feitureiras": "feitureiro",
    "feitureiros": "feitureiro",
    "feixes": "feixe",
    "feixotas": "feixota",
    "feições": "feição",
    "feiíssima": "feio",
    "feiíssimas": "feio",
    "feiíssimo": "feio",
    "feiíssimos": "feio",
    "feiúras": "feiúra",
    "felandeiros": "felandeiro",
    "felações": "felação",
    "felcites": "felcite",
    "felcitos": "felcito",
    "feldspatos": "feldspato",
    "feldspatóides": "feldspatóide",
    "felemas": "felema",
    "feles": "fel",
    "felguda": "felgudo",
    "felgudas": "felgudo",
    "felgudos": "felgudo",
    "felicidades": "felicidade",
    "felicita": "felicitar",
    "felicitada": "felicitar",
    "felicitadas": "felicitar",
    "felicitado": "felicitar",
    "felicitadora": "felicitador",
    "felicitadoras": "felicitador",
    "felicitadores": "felicitador",
    "felicitados": "felicitar",
    "felicitai": "felicitar",
    "felicitais": "felicitar",
    "felicitam": "felicitar",
    "felicitamo": "felicitar",
    "felicitamos": "felicitar",
    "felicitando": "felicitar",
    "felicitara": "felicitar",
    "felicitaram": "felicitar",
    "felicitaras": "felicitar",
    "felicitarde": "felicitar",
    "felicitardes": "felicitar",
    "felicitare": "felicitar",
    "felicitarei": "felicitar",
    "felicitareis": "felicitar",
    "felicitarem": "felicitar",
    "felicitaremos": "felicitar",
    "felicitares": "felicitar",
    "felicitaria": "felicitar",
    "felicitariam": "felicitar",
    "felicitarias": "felicitar",
    "felicitarmo": "felicitar",
    "felicitarmos": "felicitar",
    "felicitará": "felicitar",
    "felicitarás": "felicitar",
    "felicitarão": "felicitar",
    "felicitaríamos": "felicitar",
    "felicitaríeis": "felicitar",
    "felicitas": "felicitar",
    "felicitasse": "felicitar",
    "felicitassem": "felicitar",
    "felicitasses": "felicitar",
    "felicitaste": "felicitar",
    "felicitastes": "felicitar",
    "felicitava": "felicitar",
    "felicitavam": "felicitar",
    "felicitavas": "felicitar",
    "felicitações": "felicitação",
    "felicite": "felicitar",
    "felicitei": "felicitar",
    "feliciteis": "felicitar",
    "felicitem": "felicitar",
    "felicitemo": "felicitar",
    "felicitemos": "felicitar",
    "felicites": "felicitar",
    "felicito": "felicitar",
    "felicitou": "felicitar",
    "felicitá": "felicitar",
    "felicitámo": "felicitar",
    "felicitámos": "felicitar",
    "felicitáramo": "felicitar",
    "felicitáramos": "felicitar",
    "felicitárei": "felicitar",
    "felicitáreis": "felicitar",
    "felicitásseis": "felicitar",
    "felicitássemos": "felicitar",
    "felicitávamo": "felicitar",
    "felicitávamos": "felicitar",
    "felicitávei": "felicitar",
    "felicitáveis": "felicitar",
    "felicíssima": "feliz",
    "felicíssimas": "feliz",
    "felicíssimo": "feliz",
    "felicíssimos": "feliz",
    "felina": "felino",
    "felinas": "felino",
    "felinos": "felino",
    "felistrecas": "felistreca",
    "felizarda": "felizardo",
    "felizardas": "felizardo",
    "felizardos": "felizardo",
    "felizes": "feliz",
    "felochas": "felocha",
    "felodermas": "feloderma",
    "felodermes": "feloderme",
    "felogénios": "felogénio",
    "felonias": "felonia",
    "felonoplastica": "felonoplastico",
    "felonoplasticas": "felonoplastico",
    "felonoplasticos": "felonoplastico",
    "feloplástica": "feloplástico",
    "feloplásticas": "feloplástico",
    "feloplásticos": "feloplástico",
    "felosas": "felosa",
    "feloses": "felose",
    "felpa": "felpar",
    "felpada": "felpar",
    "felpadas": "felpar",
    "felpado": "felpar",
    "felpados": "felpar",
    "felpai": "felpar",
    "felpais": "felpar",
    "felpam": "felpar",
    "felpamo": "felpar",
    "felpamos": "felpar",
    "felpando": "felpar",
    "felpara": "felpar",
    "felparam": "felpar",
    "felparas": "felpar",
    "felpardes": "felpar",
    "felparei": "felpar",
    "felpareis": "felpar",
    "felparem": "felpar",
    "felparemos": "felpar",
    "felpares": "felpar",
    "felparia": "felpar",
    "felpariam": "felpar",
    "felparias": "felpar",
    "felparmo": "felpar",
    "felparmos": "felpar",
    "felpará": "felpar",
    "felparás": "felpar",
    "felparão": "felpar",
    "felparíamos": "felpar",
    "felparíeis": "felpar",
    "felpas": "felpar",
    "felpasse": "felpar",
    "felpassem": "felpar",
    "felpasses": "felpar",
    "felpaste": "felpar",
    "felpastes": "felpar",
    "felpava": "felpar",
    "felpavam": "felpar",
    "felpavas": "felpar",
    "felpe": "felpar",
    "felpei": "felpar",
    "felpeis": "felpar",
    "felpem": "felpar",
    "felpemo": "felpar",
    "felpemos": "felpar",
    "felpes": "felpar",
    "felpo": "felpar",
    "felpos": "felpo",
    "felpou": "felpar",
    "felpuda": "felpudo",
    "felpudas": "felpudo",
    "felpudos": "felpudo",
    "felpámo": "felpar",
    "felpámos": "felpar",
    "felpáramo": "felpar",
    "felpáramos": "felpar",
    "felpáreis": "felpar",
    "felpásseis": "felpar",
    "felpássemos": "felpar",
    "felpávamo": "felpar",
    "felpávamos": "felpar",
    "felpáveis": "felpar",
    "felsítica": "felsítico",
    "felsíticas": "felsítico",
    "felsíticos": "felsítico",
    "felsófiros": "felsófiro",
    "feltra": "feltrar",
    "feltrada": "feltrar",
    "feltradas": "feltrar",
    "feltradeiras": "feltradeira",
    "feltrado": "feltrar",
    "feltrados": "feltrar",
    "feltragens": "feltragem",
    "feltrai": "feltrar",
    "feltrais": "feltrar",
    "feltram": "feltrar",
    "feltramo": "feltrar",
    "feltramos": "feltrar",
    "feltrando": "feltrar",
    "feltrara": "feltrar",
    "feltraram": "feltrar",
    "feltraras": "feltrar",
    "feltrarde": "feltrar",
    "feltrardes": "feltrar",
    "feltrare": "feltrar",
    "feltrarei": "feltrar",
    "feltrareis": "feltrar",
    "feltrarem": "feltrar",
    "feltraremos": "feltrar",
    "feltrares": "feltrar",
    "feltraria": "feltrar",
    "feltrariam": "feltrar",
    "feltrarias": "feltrar",
    "feltrarmo": "feltrar",
    "feltrarmos": "feltrar",
    "feltrará": "feltrar",
    "feltrarás": "feltrar",
    "feltrarão": "feltrar",
    "feltraríamos": "feltrar",
    "feltraríeis": "feltrar",
    "feltras": "feltrar",
    "feltrasse": "feltrar",
    "feltrassem": "feltrar",
    "feltrasses": "feltrar",
    "feltraste": "feltrar",
    "feltrastes": "feltrar",
    "feltrava": "feltrar",
    "feltravam": "feltrar",
    "feltravas": "feltrar",
    "feltre": "feltrar",
    "feltrei": "feltrar",
    "feltreira": "feltreiro",
    "feltreiras": "feltreiro",
    "feltreiros": "feltreiro",
    "feltreis": "feltrar",
    "feltrem": "feltrar",
    "feltremo": "feltrar",
    "feltremos": "feltrar",
    "feltres": "feltrar",
    "feltro": "feltrar",
    "feltros": "feltro",
    "feltrosa": "feltroso",
    "feltrosas": "feltroso",
    "feltrosos": "feltroso",
    "feltrou": "feltrar",
    "feltruda": "feltrudo",
    "feltrudas": "feltrudo",
    "feltrudos": "feltrudo",
    "feltrá": "feltrar",
    "feltrámo": "feltrar",
    "feltrámos": "feltrar",
    "feltráramo": "feltrar",
    "feltráramos": "feltrar",
    "feltrárei": "feltrar",
    "feltráreis": "feltrar",
    "feltrásseis": "feltrar",
    "feltrássemos": "feltrar",
    "feltrávamo": "feltrar",
    "feltrávamos": "feltrar",
    "feltrávei": "feltrar",
    "feltráveis": "feltrar",
    "felugens": "felugem",
    "felugenta": "felugento",
    "felugentas": "felugento",
    "felugentos": "felugento",
    "felupes": "felupe",
    "felupos": "felupo",
    "felustrias": "felustria",
    "felás": "felá",
    "felândria": "felândrio",
    "felândrias": "felândrio",
    "felândrica": "felândrico",
    "felândricas": "felândrico",
    "felândricos": "felândrico",
    "felândrios": "felândrio",
    "felícias": "felícia",
    "felídea": "felídeo",
    "felídeas": "felídeo",
    "felídeos": "felídeo",
    "felónica": "felónico",
    "felónicas": "felónico",
    "felónicos": "felónico",
    "femeaços": "femeaço",
    "femeeira": "femeeiro",
    "femeeiras": "femeeiro",
    "femeeiros": "femeeiro",
    "fementida": "fementido",
    "fementidas": "fementido",
    "fementidos": "fementido",
    "feminais": "feminal",
    "feminações": "feminação",
    "feminidades": "feminidade",
    "feminiflora": "feminifloro",
    "feminifloras": "feminifloro",
    "feminifloros": "feminifloro",
    "feminiformes": "feminiforme",
    "feminilidades": "feminilidade",
    "feminina": "feminino",
    "femininas": "feminino",
    "femininos": "feminino",
    "feminis": "feminil",
    "feminismos": "feminismo",
    "feministas": "feminista",
    "feminiza": "feminizar",
    "feminizada": "feminizar",
    "feminizadas": "feminizar",
    "feminizado": "feminizar",
    "feminizados": "feminizar",
    "feminizai": "feminizar",
    "feminizais": "feminizar",
    "feminizam": "feminizar",
    "feminizamo": "feminizar",
    "feminizamos": "feminizar",
    "feminizando": "feminizar",
    "feminizara": "feminizar",
    "feminizaram": "feminizar",
    "feminizaras": "feminizar",
    "feminizarde": "feminizar",
    "feminizardes": "feminizar",
    "feminizare": "feminizar",
    "feminizarei": "feminizar",
    "feminizareis": "feminizar",
    "feminizarem": "feminizar",
    "feminizaremos": "feminizar",
    "feminizares": "feminizar",
    "feminizaria": "feminizar",
    "feminizariam": "feminizar",
    "feminizarias": "feminizar",
    "feminizarmo": "feminizar",
    "feminizarmos": "feminizar",
    "feminizará": "feminizar",
    "feminizarás": "feminizar",
    "feminizarão": "feminizar",
    "feminizaríamos": "feminizar",
    "feminizaríeis": "feminizar",
    "feminizas": "feminizar",
    "feminizasse": "feminizar",
    "feminizassem": "feminizar",
    "feminizasses": "feminizar",
    "feminizaste": "feminizar",
    "feminizastes": "feminizar",
    "feminizava": "feminizar",
    "feminizavam": "feminizar",
    "feminizavas": "feminizar",
    "feminizações": "feminização",
    "feminize": "feminizar",
    "feminizei": "feminizar",
    "feminizeis": "feminizar",
    "feminizem": "feminizar",
    "feminizemo": "feminizar",
    "feminizemos": "feminizar",
    "feminizes": "feminizar",
    "feminizo": "feminizar",
    "feminizou": "feminizar",
    "feminizá": "feminizar",
    "feminizámo": "feminizar",
    "feminizámos": "feminizar",
    "feminizáramo": "feminizar",
    "feminizáramos": "feminizar",
    "feminizárei": "feminizar",
    "feminizáreis": "feminizar",
    "feminizásseis": "feminizar",
    "feminizássemos": "feminizar",
    "feminizávamo": "feminizar",
    "feminizávamos": "feminizar",
    "feminizávei": "feminizar",
    "feminizáveis": "feminizar",
    "femurais": "femural",
    "femínea": "femíneo",
    "femíneas": "femíneo",
    "femíneos": "femíneo",
    "fenacetinas": "fenacetina",
    "fenantrenos": "fenantreno",
    "fenas": "fena",
    "fenatos": "fenato",
    "fenações": "fenação",
    "fenda": "fender",
    "fendais": "fender",
    "fendam": "fender",
    "fendamo": "fender",
    "fendamos": "fender",
    "fendas": "fender",
    "fende": "fender",
    "fendedora": "fendedor",
    "fendedoras": "fendedor",
    "fendedores": "fendedor",
    "fendei": "fender",
    "fendeis": "fender",
    "fendeleiras": "fendeleira",
    "fendem": "fender",
    "fendemo": "fender",
    "fendemos": "fender",
    "fendendo": "fender",
    "fendentes": "fendente",
    "fendera": "fender",
    "fenderam": "fender",
    "fenderas": "fender",
    "fenderde": "fender",
    "fenderdes": "fender",
    "fendere": "fender",
    "fenderei": "fender",
    "fendereis": "fender",
    "fenderem": "fender",
    "fenderemos": "fender",
    "fenderes": "fender",
    "fenderia": "fender",
    "fenderiam": "fender",
    "fenderias": "fender",
    "fendermo": "fender",
    "fendermos": "fender",
    "fenderá": "fender",
    "fenderás": "fender",
    "fenderão": "fender",
    "fenderíamos": "fender",
    "fenderíeis": "fender",
    "fendes": "fender",
    "fendesse": "fender",
    "fendessem": "fender",
    "fendesses": "fender",
    "fendeste": "fender",
    "fendestes": "fender",
    "fendeu": "fender",
    "fendi": "fender",
    "fendia": "fender",
    "fendiam": "fender",
    "fendias": "fender",
    "fendida": "fendido",
    "fendidas": "fendido",
    "fendido": "fender",
    "fendidos": "fendido",
    "fendilha": "fendilhar",
    "fendilhada": "fendilhar",
    "fendilhadas": "fendilhar",
    "fendilhado": "fendilhar",
    "fendilhados": "fendilhar",
    "fendilhai": "fendilhar",
    "fendilhais": "fendilhar",
    "fendilham": "fendilhar",
    "fendilhamo": "fendilhar",
    "fendilhamos": "fendilhar",
    "fendilhando": "fendilhar",
    "fendilhara": "fendilhar",
    "fendilharam": "fendilhar",
    "fendilharas": "fendilhar",
    "fendilharde": "fendilhar",
    "fendilhardes": "fendilhar",
    "fendilhare": "fendilhar",
    "fendilharei": "fendilhar",
    "fendilhareis": "fendilhar",
    "fendilharem": "fendilhar",
    "fendilharemos": "fendilhar",
    "fendilhares": "fendilhar",
    "fendilharia": "fendilhar",
    "fendilhariam": "fendilhar",
    "fendilharias": "fendilhar",
    "fendilharmo": "fendilhar",
    "fendilharmos": "fendilhar",
    "fendilhará": "fendilhar",
    "fendilharás": "fendilhar",
    "fendilharão": "fendilhar",
    "fendilharíamos": "fendilhar",
    "fendilharíeis": "fendilhar",
    "fendilhas": "fendilhar",
    "fendilhasse": "fendilhar",
    "fendilhassem": "fendilhar",
    "fendilhasses": "fendilhar",
    "fendilhaste": "fendilhar",
    "fendilhastes": "fendilhar",
    "fendilhava": "fendilhar",
    "fendilhavam": "fendilhar",
    "fendilhavas": "fendilhar",
    "fendilhe": "fendilhar",
    "fendilhei": "fendilhar",
    "fendilheis": "fendilhar",
    "fendilhem": "fendilhar",
    "fendilhemo": "fendilhar",
    "fendilhemos": "fendilhar",
    "fendilhes": "fendilhar",
    "fendilho": "fendilhar",
    "fendilhou": "fendilhar",
    "fendilhá": "fendilhar",
    "fendilhámo": "fendilhar",
    "fendilhámos": "fendilhar",
    "fendilháramo": "fendilhar",
    "fendilháramos": "fendilhar",
    "fendilhárei": "fendilhar",
    "fendilháreis": "fendilhar",
    "fendilhásseis": "fendilhar",
    "fendilhássemos": "fendilhar",
    "fendilhávamo": "fendilhar",
    "fendilhávamos": "fendilhar",
    "fendilhávei": "fendilhar",
    "fendilháveis": "fendilhar",
    "fendimentos": "fendimento",
    "fendinha": "fenda",
    "fendinhas": "fenda",
    "fendita": "fenda",
    "fenditas": "fenda",
    "fendo": "fender",
    "fendrelha": "fendrelhar",
    "fendrelhada": "fendrelhar",
    "fendrelhadas": "fendrelhar",
    "fendrelhado": "fendrelhar",
    "fendrelhados": "fendrelhar",
    "fendrelhai": "fendrelhar",
    "fendrelhais": "fendrelhar",
    "fendrelham": "fendrelhar",
    "fendrelhamo": "fendrelhar",
    "fendrelhamos": "fendrelhar",
    "fendrelhando": "fendrelhar",
    "fendrelhara": "fendrelhar",
    "fendrelharam": "fendrelhar",
    "fendrelharas": "fendrelhar",
    "fendrelharde": "fendrelhar",
    "fendrelhardes": "fendrelhar",
    "fendrelhare": "fendrelhar",
    "fendrelharei": "fendrelhar",
    "fendrelhareis": "fendrelhar",
    "fendrelharem": "fendrelhar",
    "fendrelharemos": "fendrelhar",
    "fendrelhares": "fendrelhar",
    "fendrelharia": "fendrelhar",
    "fendrelhariam": "fendrelhar",
    "fendrelharias": "fendrelhar",
    "fendrelharmo": "fendrelhar",
    "fendrelharmos": "fendrelhar",
    "fendrelhará": "fendrelhar",
    "fendrelharás": "fendrelhar",
    "fendrelharão": "fendrelhar",
    "fendrelharíamos": "fendrelhar",
    "fendrelharíeis": "fendrelhar",
    "fendrelhas": "fendrelhar",
    "fendrelhasse": "fendrelhar",
    "fendrelhassem": "fendrelhar",
    "fendrelhasses": "fendrelhar",
    "fendrelhaste": "fendrelhar",
    "fendrelhastes": "fendrelhar",
    "fendrelhava": "fendrelhar",
    "fendrelhavam": "fendrelhar",
    "fendrelhavas": "fendrelhar",
    "fendrelhe": "fendrelhar",
    "fendrelhei": "fendrelhar",
    "fendrelheiras": "fendrelheira",
    "fendrelheis": "fendrelhar",
    "fendrelhem": "fendrelhar",
    "fendrelhemo": "fendrelhar",
    "fendrelhemos": "fendrelhar",
    "fendrelhes": "fendrelhar",
    "fendrelho": "fendrelhar",
    "fendrelhos": "fendrelho",
    "fendrelhou": "fendrelhar",
    "fendrelhá": "fendrelhar",
    "fendrelhámo": "fendrelhar",
    "fendrelhámos": "fendrelhar",
    "fendrelháramo": "fendrelhar",
    "fendrelháramos": "fendrelhar",
    "fendrelhárei": "fendrelhar",
    "fendrelháreis": "fendrelhar",
    "fendrelhásseis": "fendrelhar",
    "fendrelhássemos": "fendrelhar",
    "fendrelhávamo": "fendrelhar",
    "fendrelhávamos": "fendrelhar",
    "fendrelhávei": "fendrelhar",
    "fendrelháveis": "fendrelhar",
    "fendê": "fender",
    "fendêramo": "fender",
    "fendêramos": "fender",
    "fendêrei": "fender",
    "fendêreis": "fender",
    "fendêsseis": "fender",
    "fendêssemos": "fender",
    "fendíamo": "fender",
    "fendíamos": "fender",
    "fendíei": "fender",
    "fendíeis": "fender",
    "fendíveis": "fendível",
    "fenece": "fenecer",
    "fenecei": "fenecer",
    "feneceis": "fenecer",
    "fenecem": "fenecer",
    "fenecemo": "fenecer",
    "fenecemos": "fenecer",
    "fenecendo": "fenecer",
    "fenecentes": "fenecente",
    "fenecera": "fenecer",
    "feneceram": "fenecer",
    "feneceras": "fenecer",
    "fenecerdes": "fenecer",
    "fenecerei": "fenecer",
    "fenecereis": "fenecer",
    "fenecerem": "fenecer",
    "feneceremos": "fenecer",
    "feneceres": "fenecer",
    "feneceria": "fenecer",
    "feneceriam": "fenecer",
    "fenecerias": "fenecer",
    "fenecermo": "fenecer",
    "fenecermos": "fenecer",
    "fenecerá": "fenecer",
    "fenecerás": "fenecer",
    "fenecerão": "fenecer",
    "feneceríamos": "fenecer",
    "feneceríeis": "fenecer",
    "feneces": "fenecer",
    "fenecesse": "fenecer",
    "fenecessem": "fenecer",
    "fenecesses": "fenecer",
    "feneceste": "fenecer",
    "fenecestes": "fenecer",
    "feneceu": "fenecer",
    "feneci": "fenecer",
    "fenecia": "fenecer",
    "feneciam": "fenecer",
    "fenecias": "fenecer",
    "fenecida": "fenecido",
    "fenecidas": "fenecido",
    "fenecido": "fenecer",
    "fenecidos": "fenecido",
    "fenecimentos": "fenecimento",
    "fenecêramo": "fenecer",
    "fenecêramos": "fenecer",
    "fenecêreis": "fenecer",
    "fenecêsseis": "fenecer",
    "fenecêssemos": "fenecer",
    "fenecíamo": "fenecer",
    "fenecíamos": "fenecer",
    "fenecíeis": "fenecer",
    "feneiros": "feneiro",
    "fenestrada": "fenestrado",
    "fenestradas": "fenestrado",
    "fenestrados": "fenestrado",
    "fenestrais": "fenestral",
    "fenestrações": "fenestração",
    "feneça": "fenecer",
    "feneçais": "fenecer",
    "feneçam": "fenecer",
    "feneçamo": "fenecer",
    "feneçamos": "fenecer",
    "feneças": "fenecer",
    "feneço": "fenecer",
    "fenge": "fengir",
    "fengem": "fengir",
    "fenges": "fengir",
    "fengi": "fengir",
    "fengia": "fengir",
    "fengiam": "fengir",
    "fengias": "fengir",
    "fengida": "fengir",
    "fengidas": "fengir",
    "fengido": "fengir",
    "fengidos": "fengir",
    "fengimo": "fengir",
    "fengimos": "fengir",
    "fengindo": "fengir",
    "fengira": "fengir",
    "fengiram": "fengir",
    "fengiras": "fengir",
    "fengirde": "fengir",
    "fengirdes": "fengir",
    "fengire": "fengir",
    "fengirei": "fengir",
    "fengireis": "fengir",
    "fengirem": "fengir",
    "fengiremos": "fengir",
    "fengires": "fengir",
    "fengiria": "fengir",
    "fengiriam": "fengir",
    "fengirias": "fengir",
    "fengirmo": "fengir",
    "fengirmos": "fengir",
    "fengirá": "fengir",
    "fengirás": "fengir",
    "fengirão": "fengir",
    "fengiríamos": "fengir",
    "fengiríeis": "fengir",
    "fengis": "fengir",
    "fengisse": "fengir",
    "fengissem": "fengir",
    "fengisses": "fengir",
    "fengiste": "fengir",
    "fengistes": "fengir",
    "fengiu": "fengir",
    "fengíamo": "fengir",
    "fengíamos": "fengir",
    "fengíei": "fengir",
    "fengíeis": "fengir",
    "fengíramo": "fengir",
    "fengíramos": "fengir",
    "fengírei": "fengir",
    "fengíreis": "fengir",
    "fengísseis": "fengir",
    "fengíssemos": "fengir",
    "feniana": "feniano",
    "fenianas": "feniano",
    "fenianismos": "fenianismo",
    "fenianos": "feniano",
    "fenicada": "fenicado",
    "fenicadas": "fenicado",
    "fenicados": "fenicado",
    "fenicoptorídeos": "fenicoptorídeo",
    "fenicoptéridas": "fenicoptérida",
    "fenigmas": "fenigma",
    "fenins": "fenim",
    "fenja": "fengir",
    "fenjais": "fengir",
    "fenjam": "fengir",
    "fenjamo": "fengir",
    "fenjamos": "fengir",
    "fenjas": "fengir",
    "fenjo": "fengir",
    "fenocristais": "fenocristal",
    "fenolftaleínas": "fenolftaleína",
    "fenologias": "fenologia",
    "fenolsulfónica": "fenolsulfónico",
    "fenolsulfónicas": "fenolsulfónico",
    "fenolsulfónicos": "fenolsulfónico",
    "fenológica": "fenológico",
    "fenológicas": "fenológico",
    "fenológicos": "fenológico",
    "fenomenais": "fenomenal",
    "fenomenalidades": "fenomenalidade",
    "fenomenalismos": "fenomenalismo",
    "fenomenalistas": "fenomenalista",
    "fenomenismos": "fenomenismo",
    "fenomenistas": "fenomenista",
    "fenomenologias": "fenomenologia",
    "fenomenologistas": "fenomenologista",
    "fenomenológica": "fenomenológico",
    "fenomenológicas": "fenomenológico",
    "fenomenológicos": "fenomenológico",
    "fenomenóloga": "fenomenólogo",
    "fenomenólogas": "fenomenólogo",
    "fenomenólogos": "fenomenólogo",
    "fenos": "feno",
    "fenotípica": "fenotípico",
    "fenotípicas": "fenotípico",
    "fenotípicos": "fenotípico",
    "fentanhas": "fentanha",
    "fentelhas": "fentelha",
    "fentilhos": "fentilho",
    "fenícia": "fenício",
    "fenícias": "fenício",
    "fenícios": "fenício",
    "fenígena": "fenígeno",
    "fenígenas": "fenígeno",
    "fenígenos": "fenígeno",
    "fenóis": "fenol",
    "fenómenos": "fenómeno",
    "fenótipos": "fenótipo",
    "feodária": "feodário",
    "feodárias": "feodário",
    "feodários": "feodário",
    "feofíceas": "feofícea",
    "feofícia": "feofício",
    "feofícias": "feofício",
    "feofícios": "feofício",
    "fera": "fero",
    "feracidades": "feracidade",
    "ferais": "feral",
    "feraminas": "feramina",
    "feras": "fero",
    "ferazes": "feraz",
    "ferberites": "ferberite",
    "fere": "ferir",
    "ferem": "ferir",
    "feres": "ferir",
    "ferezas": "fereza",
    "feri": "ferir",
    "feria": "ferir",
    "feriada": "feriar",
    "feriadas": "feriar",
    "feriado": "feriar",
    "feriados": "feriar",
    "feriai": "feriar",
    "feriais": "feriar",
    "feriam": "ferir",
    "feriamo": "feriar",
    "feriamos": "feriar",
    "feriando": "feriar",
    "feriara": "feriar",
    "feriaram": "feriar",
    "feriaras": "feriar",
    "feriardes": "feriar",
    "feriarei": "feriar",
    "feriareis": "feriar",
    "feriarem": "feriar",
    "feriaremos": "feriar",
    "feriares": "feriar",
    "feriaria": "feriar",
    "feriariam": "feriar",
    "feriarias": "feriar",
    "feriarmo": "feriar",
    "feriarmos": "feriar",
    "feriará": "feriar",
    "feriarás": "feriar",
    "feriarão": "feriar",
    "feriaríamos": "feriar",
    "feriaríeis": "feriar",
    "ferias": "ferir",
    "feriasse": "feriar",
    "feriassem": "feriar",
    "feriasses": "feriar",
    "feriaste": "feriar",
    "feriastes": "feriar",
    "feriava": "feriar",
    "feriavam": "feriar",
    "feriavas": "feriar",
    "ferida": "ferir",
    "feridades": "feridade",
    "feridas": "ferir",
    "ferido": "ferir",
    "feridora": "feridor",
    "feridoras": "feridor",
    "feridores": "feridor",
    "feridos": "ferir",
    "ferie": "feriar",
    "feriei": "feriar",
    "ferieis": "feriar",
    "feriem": "feriar",
    "feriemo": "feriar",
    "feriemos": "feriar",
    "feries": "feriar",
    "ferifolhas": "ferifolha",
    "ferimentos": "ferimento",
    "ferimo": "ferir",
    "ferimos": "ferir",
    "ferina": "ferino",
    "ferinas": "ferino",
    "ferindo": "ferir",
    "ferinos": "ferino",
    "ferio": "feriar",
    "feriou": "feriar",
    "ferira": "ferir",
    "feriram": "ferir",
    "feriras": "ferir",
    "ferirde": "ferir",
    "ferirdes": "ferir",
    "ferire": "ferir",
    "ferirei": "ferir",
    "ferireis": "ferir",
    "ferirem": "ferir",
    "feriremos": "ferir",
    "ferires": "ferir",
    "feriria": "ferir",
    "feririam": "ferir",
    "feririas": "ferir",
    "ferirmo": "ferir",
    "ferirmos": "ferir",
    "ferirá": "ferir",
    "ferirás": "ferir",
    "ferirão": "ferir",
    "feriríamos": "ferir",
    "feriríeis": "ferir",
    "feris": "ferir",
    "ferisse": "ferir",
    "ferissem": "ferir",
    "ferisses": "ferir",
    "feriste": "ferir",
    "feristes": "ferir",
    "feriu": "ferir",
    "feriámo": "feriar",
    "feriámos": "feriar",
    "feriáramo": "feriar",
    "feriáramos": "feriar",
    "feriáreis": "feriar",
    "feriásseis": "feriar",
    "feriássemos": "feriar",
    "feriávamo": "feriar",
    "feriávamos": "feriar",
    "feriáveis": "feriável",
    "fermatas": "fermata",
    "fermenta": "fermentar",
    "fermentada": "fermentar",
    "fermentadas": "fermentar",
    "fermentado": "fermentar",
    "fermentadora": "fermentador",
    "fermentadoras": "fermentador",
    "fermentadores": "fermentador",
    "fermentados": "fermentar",
    "fermentai": "fermentar",
    "fermentais": "fermentar",
    "fermentam": "fermentar",
    "fermentamo": "fermentar",
    "fermentamos": "fermentar",
    "fermentando": "fermentar",
    "fermentantes": "fermentante",
    "fermentara": "fermentar",
    "fermentaram": "fermentar",
    "fermentaras": "fermentar",
    "fermentarde": "fermentar",
    "fermentardes": "fermentar",
    "fermentare": "fermentar",
    "fermentarei": "fermentar",
    "fermentareis": "fermentar",
    "fermentarem": "fermentar",
    "fermentaremos": "fermentar",
    "fermentares": "fermentar",
    "fermentaria": "fermentar",
    "fermentariam": "fermentar",
    "fermentarias": "fermentar",
    "fermentarmo": "fermentar",
    "fermentarmos": "fermentar",
    "fermentará": "fermentar",
    "fermentarás": "fermentar",
    "fermentarão": "fermentar",
    "fermentaríamos": "fermentar",
    "fermentaríeis": "fermentar",
    "fermentas": "fermentar",
    "fermentasse": "fermentar",
    "fermentassem": "fermentar",
    "fermentasses": "fermentar",
    "fermentaste": "fermentar",
    "fermentastes": "fermentar",
    "fermentativa": "fermentativo",
    "fermentativas": "fermentativo",
    "fermentativos": "fermentativo",
    "fermentava": "fermentar",
    "fermentavam": "fermentar",
    "fermentavas": "fermentar",
    "fermentações": "fermentação",
    "fermente": "fermentar",
    "fermentei": "fermentar",
    "fermenteis": "fermentar",
    "fermentem": "fermentar",
    "fermentemo": "fermentar",
    "fermentemos": "fermentar",
    "fermentes": "fermentar",
    "fermentescentes": "fermentescente",
    "fermentescibilidades": "fermentescibilidade",
    "fermentescíveis": "fermentescível",
    "fermento": "fermentar",
    "fermentos": "fermento",
    "fermentosa": "fermentoso",
    "fermentosas": "fermentoso",
    "fermentosos": "fermentoso",
    "fermentou": "fermentar",
    "fermentá": "fermentar",
    "fermentácea": "fermentáceo",
    "fermentáceas": "fermentáceo",
    "fermentáceos": "fermentáceo",
    "fermentámo": "fermentar",
    "fermentámos": "fermentar",
    "fermentáramo": "fermentar",
    "fermentáramos": "fermentar",
    "fermentárei": "fermentar",
    "fermentáreis": "fermentar",
    "fermentásseis": "fermentar",
    "fermentássemos": "fermentar",
    "fermentávamo": "fermentar",
    "fermentávamos": "fermentar",
    "fermentávei": "fermentar",
    "fermentáveis": "fermentável",
    "fermis": "fermi",
    "fernandina": "fernandino",
    "fernandinas": "fernandino",
    "fernandinos": "fernandino",
    "ferocidades": "ferocidade",
    "ferocíssima": "feroz",
    "ferocíssimas": "feroz",
    "ferocíssimo": "feroz",
    "ferocíssimos": "feroz",
    "feros": "fero",
    "ferozes": "feroz",
    "ferra": "ferrar",
    "ferrabráses": "ferrabrás",
    "ferrada": "ferrar",
    "ferradas": "ferrar",
    "ferradelas": "ferradela",
    "ferrado": "ferrar",
    "ferradores": "ferrador",
    "ferradorias": "ferradoria",
    "ferrados": "ferrar",
    "ferraduras": "ferradura",
    "ferradurinas": "ferradurina",
    "ferrageira": "ferrageiro",
    "ferrageiras": "ferrageiro",
    "ferrageiros": "ferrageiro",
    "ferragens": "ferragem",
    "ferragiais": "ferragial",
    "ferragistas": "ferragista",
    "ferragoilos": "ferragoilo",
    "ferragoulos": "ferragoulo",
    "ferragusos": "ferraguso",
    "ferrai": "ferrar",
    "ferrais": "ferrar",
    "ferrajarias": "ferrajaria",
    "ferram": "ferrar",
    "ferramentais": "ferramental",
    "ferramentarias": "ferramentaria",
    "ferramentas": "ferramenta",
    "ferramenteira": "ferramenteiro",
    "ferramenteiras": "ferramenteiro",
    "ferramenteiros": "ferramenteiro",
    "ferramo": "ferrar",
    "ferramos": "ferrar",
    "ferranchos": "ferrancho",
    "ferranchões": "ferranchão",
    "ferrando": "ferrar",
    "ferranhas": "ferranha",
    "ferranhos": "ferranho",
    "ferrara": "ferrar",
    "ferraram": "ferrar",
    "ferraras": "ferrar",
    "ferrarde": "ferrar",
    "ferrardes": "ferrar",
    "ferrare": "ferrar",
    "ferrarei": "ferrar",
    "ferrareis": "ferrar",
    "ferrarem": "ferrar",
    "ferraremos": "ferrar",
    "ferrares": "ferrar",
    "ferraria": "ferrar",
    "ferrariam": "ferrar",
    "ferrarias": "ferraria",
    "ferrarmo": "ferrar",
    "ferrarmos": "ferrar",
    "ferrará": "ferrar",
    "ferrarás": "ferrar",
    "ferrarão": "ferrar",
    "ferraríamos": "ferrar",
    "ferraríeis": "ferrar",
    "ferras": "ferrar",
    "ferrasse": "ferrar",
    "ferrassem": "ferrar",
    "ferrasses": "ferrar",
    "ferraste": "ferrar",
    "ferrastes": "ferrar",
    "ferratos": "ferrato",
    "ferrava": "ferrar",
    "ferravam": "ferrar",
    "ferravas": "ferrar",
    "ferraças": "ferraça",
    "ferrações": "ferração",
    "ferre": "ferrar",
    "ferregiais": "ferregial",
    "ferrei": "ferrar",
    "ferreira": "ferreiro",
    "ferreiras": "ferreiro",
    "ferreirinhas": "ferreirinha",
    "ferreirinhos": "ferreirinho",
    "ferreiros": "ferreiro",
    "ferreis": "ferrar",
    "ferreja": "ferrejar",
    "ferrejada": "ferrejar",
    "ferrejadas": "ferrejar",
    "ferrejado": "ferrejar",
    "ferrejados": "ferrejar",
    "ferrejai": "ferrejar",
    "ferrejais": "ferrejar",
    "ferrejam": "ferrejar",
    "ferrejamo": "ferrejar",
    "ferrejamos": "ferrejar",
    "ferrejando": "ferrejar",
    "ferrejara": "ferrejar",
    "ferrejaram": "ferrejar",
    "ferrejaras": "ferrejar",
    "ferrejarde": "ferrejar",
    "ferrejardes": "ferrejar",
    "ferrejare": "ferrejar",
    "ferrejarei": "ferrejar",
    "ferrejareis": "ferrejar",
    "ferrejarem": "ferrejar",
    "ferrejaremos": "ferrejar",
    "ferrejares": "ferrejar",
    "ferrejaria": "ferrejar",
    "ferrejariam": "ferrejar",
    "ferrejarias": "ferrejar",
    "ferrejarmo": "ferrejar",
    "ferrejarmos": "ferrejar",
    "ferrejará": "ferrejar",
    "ferrejarás": "ferrejar",
    "ferrejarão": "ferrejar",
    "ferrejaríamos": "ferrejar",
    "ferrejaríeis": "ferrejar",
    "ferrejas": "ferrejar",
    "ferrejasse": "ferrejar",
    "ferrejassem": "ferrejar",
    "ferrejasses": "ferrejar",
    "ferrejaste": "ferrejar",
    "ferrejastes": "ferrejar",
    "ferrejava": "ferrejar",
    "ferrejavam": "ferrejar",
    "ferrejavas": "ferrejar",
    "ferreje": "ferrejar",
    "ferrejei": "ferrejar",
    "ferrejeis": "ferrejar",
    "ferrejem": "ferrejar",
    "ferrejemo": "ferrejar",
    "ferrejemos": "ferrejar",
    "ferrejes": "ferrejar",
    "ferrejo": "ferrejar",
    "ferrejos": "ferrejo",
    "ferrejou": "ferrejar",
    "ferrejá": "ferrejar",
    "ferrejámo": "ferrejar",
    "ferrejámos": "ferrejar",
    "ferrejáramo": "ferrejar",
    "ferrejáramos": "ferrejar",
    "ferrejárei": "ferrejar",
    "ferrejáreis": "ferrejar",
    "ferrejásseis": "ferrejar",
    "ferrejássemos": "ferrejar",
    "ferrejávamo": "ferrejar",
    "ferrejávamos": "ferrejar",
    "ferrejávei": "ferrejar",
    "ferrejáveis": "ferrejar",
    "ferrelectricidades": "ferrelectricidade",
    "ferrelhas": "ferrelha",
    "ferrem": "ferrar",
    "ferremo": "ferrar",
    "ferremos": "ferrar",
    "ferrenha": "ferrenho",
    "ferrenhas": "ferrenho",
    "ferrenhos": "ferrenho",
    "ferres": "ferrar",
    "ferreta": "ferretar",
    "ferretada": "ferretar",
    "ferretadas": "ferretar",
    "ferretado": "ferretar",
    "ferretados": "ferretar",
    "ferretai": "ferretar",
    "ferretais": "ferretar",
    "ferretam": "ferretar",
    "ferretamo": "ferretar",
    "ferretamos": "ferretar",
    "ferretando": "ferretar",
    "ferretara": "ferretar",
    "ferretaram": "ferretar",
    "ferretaras": "ferretar",
    "ferretarde": "ferretar",
    "ferretardes": "ferretar",
    "ferretare": "ferretar",
    "ferretarei": "ferretar",
    "ferretareis": "ferretar",
    "ferretarem": "ferretar",
    "ferretaremos": "ferretar",
    "ferretares": "ferretar",
    "ferretaria": "ferretar",
    "ferretariam": "ferretar",
    "ferretarias": "ferretar",
    "ferretarmo": "ferretar",
    "ferretarmos": "ferretar",
    "ferretará": "ferretar",
    "ferretarás": "ferretar",
    "ferretarão": "ferretar",
    "ferretaríamos": "ferretar",
    "ferretaríeis": "ferretar",
    "ferretas": "ferretar",
    "ferretasse": "ferretar",
    "ferretassem": "ferretar",
    "ferretasses": "ferretar",
    "ferretaste": "ferretar",
    "ferretastes": "ferretar",
    "ferretava": "ferretar",
    "ferretavam": "ferretar",
    "ferretavas": "ferretar",
    "ferrete": "ferretar",
    "ferreteada": "ferretear",
    "ferreteadas": "ferretear",
    "ferreteado": "ferretear",
    "ferreteados": "ferretear",
    "ferreteai": "ferretear",
    "ferreteais": "ferretear",
    "ferreteamo": "ferretear",
    "ferreteamos": "ferretear",
    "ferreteando": "ferretear",
    "ferreteara": "ferretear",
    "ferretearam": "ferretear",
    "ferretearas": "ferretear",
    "ferretearde": "ferretear",
    "ferreteardes": "ferretear",
    "ferreteare": "ferretear",
    "ferretearei": "ferretear",
    "ferreteareis": "ferretear",
    "ferretearem": "ferretear",
    "ferretearemos": "ferretear",
    "ferreteares": "ferretear",
    "ferretearia": "ferretear",
    "ferreteariam": "ferretear",
    "ferretearias": "ferretear",
    "ferretearmo": "ferretear",
    "ferretearmos": "ferretear",
    "ferreteará": "ferretear",
    "ferretearás": "ferretear",
    "ferretearão": "ferretear",
    "ferretearíamos": "ferretear",
    "ferretearíeis": "ferretear",
    "ferreteasse": "ferretear",
    "ferreteassem": "ferretear",
    "ferreteasses": "ferretear",
    "ferreteaste": "ferretear",
    "ferreteastes": "ferretear",
    "ferreteava": "ferretear",
    "ferreteavam": "ferretear",
    "ferreteavas": "ferretear",
    "ferreteei": "ferretear",
    "ferreteeis": "ferretear",
    "ferreteemo": "ferretear",
    "ferreteemos": "ferretear",
    "ferretei": "ferretar",
    "ferreteia": "ferretear",
    "ferreteiam": "ferretear",
    "ferreteias": "ferretear",
    "ferreteie": "ferretear",
    "ferreteiem": "ferretear",
    "ferreteies": "ferretear",
    "ferreteio": "ferretear",
    "ferreteis": "ferretar",
    "ferretem": "ferretar",
    "ferretemo": "ferretar",
    "ferretemos": "ferretar",
    "ferreteou": "ferretear",
    "ferretes": "ferrete",
    "ferreteá": "ferretear",
    "ferreteámo": "ferretear",
    "ferreteámos": "ferretear",
    "ferreteáramo": "ferretear",
    "ferreteáramos": "ferretear",
    "ferreteárei": "ferretear",
    "ferreteáreis": "ferretear",
    "ferreteásseis": "ferretear",
    "ferreteássemos": "ferretear",
    "ferreteávamo": "ferretear",
    "ferreteávamos": "ferretear",
    "ferreteávei": "ferretear",
    "ferreteáveis": "ferretear",
    "ferreto": "ferretar",
    "ferretoa": "ferretoar",
    "ferretoada": "ferretoar",
    "ferretoadas": "ferretoar",
    "ferretoado": "ferretoar",
    "ferretoados": "ferretoar",
    "ferretoai": "ferretoar",
    "ferretoais": "ferretoar",
    "ferretoam": "ferretoar",
    "ferretoamo": "ferretoar",
    "ferretoamos": "ferretoar",
    "ferretoando": "ferretoar",
    "ferretoara": "ferretoar",
    "ferretoaram": "ferretoar",
    "ferretoaras": "ferretoar",
    "ferretoarde": "ferretoar",
    "ferretoardes": "ferretoar",
    "ferretoare": "ferretoar",
    "ferretoarei": "ferretoar",
    "ferretoareis": "ferretoar",
    "ferretoarem": "ferretoar",
    "ferretoaremos": "ferretoar",
    "ferretoares": "ferretoar",
    "ferretoaria": "ferretoar",
    "ferretoariam": "ferretoar",
    "ferretoarias": "ferretoar",
    "ferretoarmo": "ferretoar",
    "ferretoarmos": "ferretoar",
    "ferretoará": "ferretoar",
    "ferretoarás": "ferretoar",
    "ferretoarão": "ferretoar",
    "ferretoaríamos": "ferretoar",
    "ferretoaríeis": "ferretoar",
    "ferretoas": "ferretoar",
    "ferretoasse": "ferretoar",
    "ferretoassem": "ferretoar",
    "ferretoasses": "ferretoar",
    "ferretoaste": "ferretoar",
    "ferretoastes": "ferretoar",
    "ferretoava": "ferretoar",
    "ferretoavam": "ferretoar",
    "ferretoavas": "ferretoar",
    "ferretoe": "ferretoar",
    "ferretoei": "ferretoar",
    "ferretoeis": "ferretoar",
    "ferretoem": "ferretoar",
    "ferretoemo": "ferretoar",
    "ferretoemos": "ferretoar",
    "ferretoes": "ferretoar",
    "ferretoo": "ferretoar",
    "ferretoou": "ferretoar",
    "ferretou": "ferretar",
    "ferretoá": "ferretoar",
    "ferretoámo": "ferretoar",
    "ferretoámos": "ferretoar",
    "ferretoáramo": "ferretoar",
    "ferretoáramos": "ferretoar",
    "ferretoárei": "ferretoar",
    "ferretoáreis": "ferretoar",
    "ferretoásseis": "ferretoar",
    "ferretoássemos": "ferretoar",
    "ferretoávamo": "ferretoar",
    "ferretoávamos": "ferretoar",
    "ferretoávei": "ferretoar",
    "ferretoáveis": "ferretoar",
    "ferretá": "ferretar",
    "ferretámo": "ferretar",
    "ferretámos": "ferretar",
    "ferretáramo": "ferretar",
    "ferretáramos": "ferretar",
    "ferretárei": "ferretar",
    "ferretáreis": "ferretar",
    "ferretásseis": "ferretar",
    "ferretássemos": "ferretar",
    "ferretávamo": "ferretar",
    "ferretávamos": "ferretar",
    "ferretávei": "ferretar",
    "ferretáveis": "ferretar",
    "ferrieléctrica": "ferrieléctrico",
    "ferrieléctricas": "ferrieléctrico",
    "ferrieléctricos": "ferrieléctrico",
    "ferries": "ferry",
    "ferrificações": "ferrificação",
    "ferrimagnetismos": "ferrimagnetismo",
    "ferrimagnética": "ferrimagnético",
    "ferrimagnéticas": "ferrimagnético",
    "ferrimagnéticos": "ferrimagnético",
    "ferrites": "ferrite",
    "ferro": "ferrar",
    "ferroa": "ferroar",
    "ferroada": "ferroar",
    "ferroadas": "ferroar",
    "ferroadelas": "ferroadela",
    "ferroado": "ferroar",
    "ferroados": "ferroar",
    "ferroai": "ferroar",
    "ferroais": "ferroar",
    "ferroam": "ferroar",
    "ferroamo": "ferroar",
    "ferroamos": "ferroar",
    "ferroando": "ferroar",
    "ferroara": "ferroar",
    "ferroaram": "ferroar",
    "ferroaras": "ferroar",
    "ferroarde": "ferroar",
    "ferroardes": "ferroar",
    "ferroare": "ferroar",
    "ferroarei": "ferroar",
    "ferroareis": "ferroar",
    "ferroarem": "ferroar",
    "ferroaremos": "ferroar",
    "ferroares": "ferroar",
    "ferroaria": "ferroar",
    "ferroariam": "ferroar",
    "ferroarias": "ferroar",
    "ferroarmo": "ferroar",
    "ferroarmos": "ferroar",
    "ferroará": "ferroar",
    "ferroarás": "ferroar",
    "ferroarão": "ferroar",
    "ferroaríamos": "ferroar",
    "ferroaríeis": "ferroar",
    "ferroas": "ferroar",
    "ferroasse": "ferroar",
    "ferroassem": "ferroar",
    "ferroasses": "ferroar",
    "ferroaste": "ferroar",
    "ferroastes": "ferroar",
    "ferroava": "ferroar",
    "ferroavam": "ferroar",
    "ferroavas": "ferroar",
    "ferrocarbónica": "ferrocarbónico",
    "ferrocarbónicas": "ferrocarbónico",
    "ferrocarbónicos": "ferrocarbónico",
    "ferrocrómica": "ferrocrómico",
    "ferrocrómicas": "ferrocrómico",
    "ferrocrómicos": "ferrocrómico",
    "ferrocrómios": "ferrocrómio",
    "ferroe": "ferroar",
    "ferroei": "ferroar",
    "ferroeis": "ferroar",
    "ferroelectricidades": "ferroelectricidade",
    "ferroeléctrica": "ferroeléctrico",
    "ferroeléctricas": "ferroeléctrico",
    "ferroeléctricos": "ferroeléctrico",
    "ferroem": "ferroar",
    "ferroemo": "ferroar",
    "ferroemos": "ferroar",
    "ferroes": "ferroar",
    "ferrolha": "ferrolhar",
    "ferrolhada": "ferrolhar",
    "ferrolhadas": "ferrolhar",
    "ferrolhado": "ferrolhar",
    "ferrolhados": "ferrolhar",
    "ferrolhai": "ferrolhar",
    "ferrolhais": "ferrolhar",
    "ferrolham": "ferrolhar",
    "ferrolhamo": "ferrolhar",
    "ferrolhamos": "ferrolhar",
    "ferrolhando": "ferrolhar",
    "ferrolhara": "ferrolhar",
    "ferrolharam": "ferrolhar",
    "ferrolharas": "ferrolhar",
    "ferrolharde": "ferrolhar",
    "ferrolhardes": "ferrolhar",
    "ferrolhare": "ferrolhar",
    "ferrolharei": "ferrolhar",
    "ferrolhareis": "ferrolhar",
    "ferrolharem": "ferrolhar",
    "ferrolharemos": "ferrolhar",
    "ferrolhares": "ferrolhar",
    "ferrolharia": "ferrolhar",
    "ferrolhariam": "ferrolhar",
    "ferrolharias": "ferrolhar",
    "ferrolharmo": "ferrolhar",
    "ferrolharmos": "ferrolhar",
    "ferrolhará": "ferrolhar",
    "ferrolharás": "ferrolhar",
    "ferrolharão": "ferrolhar",
    "ferrolharíamos": "ferrolhar",
    "ferrolharíeis": "ferrolhar",
    "ferrolhas": "ferrolhar",
    "ferrolhasse": "ferrolhar",
    "ferrolhassem": "ferrolhar",
    "ferrolhasses": "ferrolhar",
    "ferrolhaste": "ferrolhar",
    "ferrolhastes": "ferrolhar",
    "ferrolhava": "ferrolhar",
    "ferrolhavam": "ferrolhar",
    "ferrolhavas": "ferrolhar",
    "ferrolhe": "ferrolhar",
    "ferrolhei": "ferrolhar",
    "ferrolheis": "ferrolhar",
    "ferrolhem": "ferrolhar",
    "ferrolhemo": "ferrolhar",
    "ferrolhemos": "ferrolhar",
    "ferrolhes": "ferrolhar",
    "ferrolho": "ferrolhar",
    "ferrolhos": "ferrolho",
    "ferrolhou": "ferrolhar",
    "ferrolhá": "ferrolhar",
    "ferrolhámo": "ferrolhar",
    "ferrolhámos": "ferrolhar",
    "ferrolháramo": "ferrolhar",
    "ferrolháramos": "ferrolhar",
    "ferrolhárei": "ferrolhar",
    "ferrolháreis": "ferrolhar",
    "ferrolhásseis": "ferrolhar",
    "ferrolhássemos": "ferrolhar",
    "ferrolhávamo": "ferrolhar",
    "ferrolhávamos": "ferrolhar",
    "ferrolhávei": "ferrolhar",
    "ferrolháveis": "ferrolhar",
    "ferromagnetismos": "ferromagnetismo",
    "ferromagnética": "ferromagnético",
    "ferromagnéticas": "ferromagnético",
    "ferromagnéticos": "ferromagnético",
    "ferroo": "ferroar",
    "ferroou": "ferroar",
    "ferropeada": "ferropear",
    "ferropeadas": "ferropear",
    "ferropeado": "ferropear",
    "ferropeados": "ferropear",
    "ferropeai": "ferropear",
    "ferropeais": "ferropear",
    "ferropeamo": "ferropear",
    "ferropeamos": "ferropear",
    "ferropeando": "ferropear",
    "ferropeara": "ferropear",
    "ferropearam": "ferropear",
    "ferropearas": "ferropear",
    "ferropearde": "ferropear",
    "ferropeardes": "ferropear",
    "ferropeare": "ferropear",
    "ferropearei": "ferropear",
    "ferropeareis": "ferropear",
    "ferropearem": "ferropear",
    "ferropearemos": "ferropear",
    "ferropeares": "ferropear",
    "ferropearia": "ferropear",
    "ferropeariam": "ferropear",
    "ferropearias": "ferropear",
    "ferropearmo": "ferropear",
    "ferropearmos": "ferropear",
    "ferropeará": "ferropear",
    "ferropearás": "ferropear",
    "ferropearão": "ferropear",
    "ferropearíamos": "ferropear",
    "ferropearíeis": "ferropear",
    "ferropeasse": "ferropear",
    "ferropeassem": "ferropear",
    "ferropeasses": "ferropear",
    "ferropeaste": "ferropear",
    "ferropeastes": "ferropear",
    "ferropeava": "ferropear",
    "ferropeavam": "ferropear",
    "ferropeavas": "ferropear",
    "ferropeei": "ferropear",
    "ferropeeis": "ferropear",
    "ferropeemo": "ferropear",
    "ferropeemos": "ferropear",
    "ferropeia": "ferropear",
    "ferropeiam": "ferropear",
    "ferropeias": "ferropeia",
    "ferropeie": "ferropear",
    "ferropeiem": "ferropear",
    "ferropeies": "ferropear",
    "ferropeio": "ferropear",
    "ferropeou": "ferropear",
    "ferropeá": "ferropear",
    "ferropeámo": "ferropear",
    "ferropeámos": "ferropear",
    "ferropeáramo": "ferropear",
    "ferropeáramos": "ferropear",
    "ferropeárei": "ferropear",
    "ferropeáreis": "ferropear",
    "ferropeásseis": "ferropear",
    "ferropeássemos": "ferropear",
    "ferropeávamo": "ferropear",
    "ferropeávamos": "ferropear",
    "ferropeávei": "ferropear",
    "ferropeáveis": "ferropear",
    "ferros": "ferro",
    "ferrosa": "ferroso",
    "ferrosas": "ferroso",
    "ferrosos": "ferroso",
    "ferrou": "ferrar",
    "ferroviais": "ferrovial",
    "ferrovias": "ferrovia",
    "ferroviária": "ferroviário",
    "ferroviárias": "ferroviário",
    "ferroviários": "ferroviário",
    "ferroá": "ferroar",
    "ferroámo": "ferroar",
    "ferroámos": "ferroar",
    "ferroáramo": "ferroar",
    "ferroáramos": "ferroar",
    "ferroárei": "ferroar",
    "ferroáreis": "ferroar",
    "ferroásseis": "ferroar",
    "ferroássemos": "ferroar",
    "ferroávamo": "ferroar",
    "ferroávamos": "ferroar",
    "ferroávei": "ferroar",
    "ferroáveis": "ferroar",
    "ferrreteamentos": "ferrreteamento",
    "ferrugens": "ferrugem",
    "ferrugenta": "ferrugento",
    "ferrugentas": "ferrugento",
    "ferrugentos": "ferrugento",
    "ferruginosa": "ferruginoso",
    "ferruginosas": "ferruginoso",
    "ferruginosidades": "ferruginosidade",
    "ferruginosos": "ferruginoso",
    "ferrugínia": "ferrugínio",
    "ferrugínias": "ferrugínio",
    "ferrugínios": "ferrugínio",
    "ferrunchos": "ferruncho",
    "ferruscos": "ferrusco",
    "ferrá": "ferrar",
    "ferrámo": "ferrar",
    "ferrámos": "ferrar",
    "ferráramo": "ferrar",
    "ferráramos": "ferrar",
    "ferrárei": "ferrar",
    "ferráreis": "ferrar",
    "ferrásseis": "ferrar",
    "ferrássemos": "ferrar",
    "ferrávamo": "ferrar",
    "ferrávamos": "ferrar",
    "ferrávei": "ferrar",
    "ferráveis": "ferrar",
    "ferrãs": "ferrã",
    "ferrífera": "ferrífero",
    "ferríferas": "ferrífero",
    "ferríferos": "ferrífero",
    "ferrões": "ferrão",
    "fertilidades": "fertilidade",
    "fertiliza": "fertilizar",
    "fertilizada": "fertilizar",
    "fertilizadas": "fertilizar",
    "fertilizado": "fertilizar",
    "fertilizadora": "fertilizador",
    "fertilizadoras": "fertilizador",
    "fertilizadores": "fertilizador",
    "fertilizados": "fertilizar",
    "fertilizai": "fertilizar",
    "fertilizais": "fertilizar",
    "fertilizam": "fertilizar",
    "fertilizamo": "fertilizar",
    "fertilizamos": "fertilizar",
    "fertilizando": "fertilizar",
    "fertilizantes": "fertilizante",
    "fertilizara": "fertilizar",
    "fertilizaram": "fertilizar",
    "fertilizaras": "fertilizar",
    "fertilizarde": "fertilizar",
    "fertilizardes": "fertilizar",
    "fertilizare": "fertilizar",
    "fertilizarei": "fertilizar",
    "fertilizareis": "fertilizar",
    "fertilizarem": "fertilizar",
    "fertilizaremos": "fertilizar",
    "fertilizares": "fertilizar",
    "fertilizaria": "fertilizar",
    "fertilizariam": "fertilizar",
    "fertilizarias": "fertilizar",
    "fertilizarmo": "fertilizar",
    "fertilizarmos": "fertilizar",
    "fertilizará": "fertilizar",
    "fertilizarás": "fertilizar",
    "fertilizarão": "fertilizar",
    "fertilizaríamos": "fertilizar",
    "fertilizaríeis": "fertilizar",
    "fertilizas": "fertilizar",
    "fertilizasse": "fertilizar",
    "fertilizassem": "fertilizar",
    "fertilizasses": "fertilizar",
    "fertilizaste": "fertilizar",
    "fertilizastes": "fertilizar",
    "fertilizava": "fertilizar",
    "fertilizavam": "fertilizar",
    "fertilizavas": "fertilizar",
    "fertilizações": "fertilização",
    "fertilize": "fertilizar",
    "fertilizei": "fertilizar",
    "fertilizeis": "fertilizar",
    "fertilizem": "fertilizar",
    "fertilizemo": "fertilizar",
    "fertilizemos": "fertilizar",
    "fertilizes": "fertilizar",
    "fertilizo": "fertilizar",
    "fertilizou": "fertilizar",
    "fertilizá": "fertilizar",
    "fertilizámo": "fertilizar",
    "fertilizámos": "fertilizar",
    "fertilizáramo": "fertilizar",
    "fertilizáramos": "fertilizar",
    "fertilizárei": "fertilizar",
    "fertilizáreis": "fertilizar",
    "fertilizásseis": "fertilizar",
    "fertilizássemos": "fertilizar",
    "fertilizávamo": "fertilizar",
    "fertilizávamos": "fertilizar",
    "fertilizávei": "fertilizar",
    "fertilizáveis": "fertilizável",
    "ferulácea": "feruláceo",
    "feruláceas": "feruláceo",
    "feruláceos": "feruláceo",
    "ferva": "ferver",
    "fervais": "ferver",
    "fervam": "ferver",
    "fervamo": "ferver",
    "fervamos": "ferver",
    "fervas": "ferver",
    "ferve": "ferver",
    "fervedoiros": "fervedoiro",
    "fervedores": "fervedor",
    "fervedouros": "fervedouro",
    "ferveduras": "fervedura",
    "fervei": "ferver",
    "ferveis": "ferver",
    "fervem": "ferver",
    "fervemo": "ferver",
    "fervemos": "ferver",
    "fervendo": "ferver",
    "ferventa": "ferventar",
    "ferventada": "ferventar",
    "ferventadas": "ferventar",
    "ferventado": "ferventar",
    "ferventados": "ferventar",
    "ferventai": "ferventar",
    "ferventais": "ferventar",
    "ferventam": "ferventar",
    "ferventamo": "ferventar",
    "ferventamos": "ferventar",
    "ferventando": "ferventar",
    "ferventara": "ferventar",
    "ferventaram": "ferventar",
    "ferventaras": "ferventar",
    "ferventarde": "ferventar",
    "ferventardes": "ferventar",
    "ferventare": "ferventar",
    "ferventarei": "ferventar",
    "ferventareis": "ferventar",
    "ferventarem": "ferventar",
    "ferventaremos": "ferventar",
    "ferventares": "ferventar",
    "ferventaria": "ferventar",
    "ferventariam": "ferventar",
    "ferventarias": "ferventar",
    "ferventarmo": "ferventar",
    "ferventarmos": "ferventar",
    "ferventará": "ferventar",
    "ferventarás": "ferventar",
    "ferventarão": "ferventar",
    "ferventaríamos": "ferventar",
    "ferventaríeis": "ferventar",
    "ferventas": "ferventar",
    "ferventasse": "ferventar",
    "ferventassem": "ferventar",
    "ferventasses": "ferventar",
    "ferventaste": "ferventar",
    "ferventastes": "ferventar",
    "ferventava": "ferventar",
    "ferventavam": "ferventar",
    "ferventavas": "ferventar",
    "fervente": "ferventar",
    "ferventei": "ferventar",
    "ferventeis": "ferventar",
    "ferventem": "ferventar",
    "ferventemo": "ferventar",
    "ferventemos": "ferventar",
    "ferventes": "fervente",
    "fervento": "ferventar",
    "ferventou": "ferventar",
    "ferventá": "ferventar",
    "ferventámo": "ferventar",
    "ferventámos": "ferventar",
    "ferventáramo": "ferventar",
    "ferventáramos": "ferventar",
    "ferventárei": "ferventar",
    "ferventáreis": "ferventar",
    "ferventásseis": "ferventar",
    "ferventássemos": "ferventar",
    "ferventávamo": "ferventar",
    "ferventávamos": "ferventar",
    "ferventávei": "ferventar",
    "ferventáveis": "ferventar",
    "fervenças": "fervença",
    "fervera": "ferver",
    "ferveram": "ferver",
    "ferveras": "ferver",
    "ferverdes": "ferver",
    "ferverei": "ferver",
    "fervereis": "ferver",
    "ferverem": "ferver",
    "ferveremos": "ferver",
    "ferveres": "ferver",
    "ferveria": "ferver",
    "ferveriam": "ferver",
    "ferverias": "ferver",
    "fervermo": "ferver",
    "fervermos": "ferver",
    "ferverá": "ferver",
    "ferverás": "ferver",
    "ferverão": "ferver",
    "ferveríamos": "ferver",
    "ferveríeis": "ferver",
    "ferves": "ferver",
    "fervesse": "ferver",
    "fervessem": "ferver",
    "fervesses": "ferver",
    "ferveste": "ferver",
    "fervestes": "ferver",
    "ferveu": "ferver",
    "fervi": "ferver",
    "fervia": "ferver",
    "ferviam": "ferver",
    "fervias": "ferver",
    "fervida": "fervido",
    "fervidas": "fervido",
    "fervido": "ferver",
    "fervidos": "fervido",
    "fervilha": "fervilhar",
    "fervilhada": "fervilhar",
    "fervilhadas": "fervilhar",
    "fervilhado": "fervilhar",
    "fervilhados": "fervilhar",
    "fervilhai": "fervilhar",
    "fervilhais": "fervilhar",
    "fervilham": "fervilhar",
    "fervilhamentos": "fervilhamento",
    "fervilhamo": "fervilhar",
    "fervilhamos": "fervilhar",
    "fervilhando": "fervilhar",
    "fervilhantes": "fervilhante",
    "fervilhara": "fervilhar",
    "fervilharam": "fervilhar",
    "fervilharas": "fervilhar",
    "fervilharde": "fervilhar",
    "fervilhardes": "fervilhar",
    "fervilhare": "fervilhar",
    "fervilharei": "fervilhar",
    "fervilhareis": "fervilhar",
    "fervilharem": "fervilhar",
    "fervilharemos": "fervilhar",
    "fervilhares": "fervilhar",
    "fervilharia": "fervilhar",
    "fervilhariam": "fervilhar",
    "fervilharias": "fervilhar",
    "fervilharmo": "fervilhar",
    "fervilharmos": "fervilhar",
    "fervilhará": "fervilhar",
    "fervilharás": "fervilhar",
    "fervilharão": "fervilhar",
    "fervilharíamos": "fervilhar",
    "fervilharíeis": "fervilhar",
    "fervilhas": "fervilhar",
    "fervilhasse": "fervilhar",
    "fervilhassem": "fervilhar",
    "fervilhasses": "fervilhar",
    "fervilhaste": "fervilhar",
    "fervilhastes": "fervilhar",
    "fervilhava": "fervilhar",
    "fervilhavam": "fervilhar",
    "fervilhavas": "fervilhar",
    "fervilhe": "fervilhar",
    "fervilhei": "fervilhar",
    "fervilheis": "fervilhar",
    "fervilhem": "fervilhar",
    "fervilhemo": "fervilhar",
    "fervilhemos": "fervilhar",
    "fervilhes": "fervilhar",
    "fervilho": "fervilhar",
    "fervilhos": "fervilho",
    "fervilhou": "fervilhar",
    "fervilhá": "fervilhar",
    "fervilhámo": "fervilhar",
    "fervilhámos": "fervilhar",
    "fervilháramo": "fervilhar",
    "fervilháramos": "fervilhar",
    "fervilhárei": "fervilhar",
    "fervilháreis": "fervilhar",
    "fervilhásseis": "fervilhar",
    "fervilhássemos": "fervilhar",
    "fervilhávamo": "fervilhar",
    "fervilhávamos": "fervilhar",
    "fervilhávei": "fervilhar",
    "fervilháveis": "fervilhar",
    "fervo": "ferver",
    "fervora": "fervorar",
    "fervorada": "fervorar",
    "fervoradas": "fervorar",
    "fervorado": "fervorar",
    "fervorados": "fervorar",
    "fervorai": "fervorar",
    "fervorais": "fervorar",
    "fervoram": "fervorar",
    "fervoramo": "fervorar",
    "fervoramos": "fervorar",
    "fervorando": "fervorar",
    "fervorara": "fervorar",
    "fervoraram": "fervorar",
    "fervoraras": "fervorar",
    "fervorarde": "fervorar",
    "fervorardes": "fervorar",
    "fervorare": "fervorar",
    "fervorarei": "fervorar",
    "fervorareis": "fervorar",
    "fervorarem": "fervorar",
    "fervoraremos": "fervorar",
    "fervorares": "fervorar",
    "fervoraria": "fervorar",
    "fervorariam": "fervorar",
    "fervorarias": "fervorar",
    "fervorarmo": "fervorar",
    "fervorarmos": "fervorar",
    "fervorará": "fervorar",
    "fervorarás": "fervorar",
    "fervorarão": "fervorar",
    "fervoraríamos": "fervorar",
    "fervoraríeis": "fervorar",
    "fervoras": "fervorar",
    "fervorasse": "fervorar",
    "fervorassem": "fervorar",
    "fervorasses": "fervorar",
    "fervoraste": "fervorar",
    "fervorastes": "fervorar",
    "fervorava": "fervorar",
    "fervoravam": "fervorar",
    "fervoravas": "fervorar",
    "fervore": "fervorar",
    "fervorei": "fervorar",
    "fervoreis": "fervorar",
    "fervorem": "fervorar",
    "fervoremo": "fervorar",
    "fervoremos": "fervorar",
    "fervores": "fervorar",
    "fervoro": "fervorar",
    "fervorosa": "fervoroso",
    "fervorosas": "fervoroso",
    "fervorosos": "fervoroso",
    "fervorou": "fervorar",
    "fervorá": "fervorar",
    "fervorámo": "fervorar",
    "fervorámos": "fervorar",
    "fervoráramo": "fervorar",
    "fervoráramos": "fervorar",
    "fervorárei": "fervorar",
    "fervoráreis": "fervorar",
    "fervorásseis": "fervorar",
    "fervorássemos": "fervorar",
    "fervorávamo": "fervorar",
    "fervorávamos": "fervorar",
    "fervorávei": "fervorar",
    "fervoráveis": "fervorar",
    "fervuras": "fervura",
    "fervências": "fervência",
    "fervêramo": "ferver",
    "fervêramos": "ferver",
    "fervêreis": "ferver",
    "fervêsseis": "ferver",
    "fervêssemos": "ferver",
    "fervíamo": "ferver",
    "fervíamos": "ferver",
    "fervíeis": "ferver",
    "feríamo": "ferir",
    "feríamos": "ferir",
    "feríei": "ferir",
    "feríeis": "ferir",
    "feríramo": "ferir",
    "feríramos": "ferir",
    "ferírei": "ferir",
    "feríreis": "ferir",
    "ferísseis": "ferir",
    "feríssemos": "ferir",
    "ferócias": "ferócia",
    "fescenina": "fescenino",
    "fesceninas": "fescenino",
    "fesceninos": "fescenino",
    "festadas": "festada",
    "festangas": "festanga",
    "festanças": "festança",
    "festarolas": "festarola",
    "festas": "festa",
    "festeira": "festeiro",
    "festeiras": "festeiro",
    "festeiros": "festeiro",
    "festeja": "festejar",
    "festejada": "festejar",
    "festejadas": "festejar",
    "festejado": "festejar",
    "festejadora": "festejador",
    "festejadoras": "festejador",
    "festejadores": "festejador",
    "festejados": "festejar",
    "festejai": "festejar",
    "festejais": "festejar",
    "festejam": "festejar",
    "festejamo": "festejar",
    "festejamos": "festejar",
    "festejando": "festejar",
    "festejara": "festejar",
    "festejaram": "festejar",
    "festejaras": "festejar",
    "festejarde": "festejar",
    "festejardes": "festejar",
    "festejare": "festejar",
    "festejarei": "festejar",
    "festejareis": "festejar",
    "festejarem": "festejar",
    "festejaremos": "festejar",
    "festejares": "festejar",
    "festejaria": "festejar",
    "festejariam": "festejar",
    "festejarias": "festejar",
    "festejarmo": "festejar",
    "festejarmos": "festejar",
    "festejará": "festejar",
    "festejarás": "festejar",
    "festejarão": "festejar",
    "festejaríamos": "festejar",
    "festejaríeis": "festejar",
    "festejas": "festejar",
    "festejasse": "festejar",
    "festejassem": "festejar",
    "festejasses": "festejar",
    "festejaste": "festejar",
    "festejastes": "festejar",
    "festejava": "festejar",
    "festejavam": "festejar",
    "festejavas": "festejar",
    "festeje": "festejar",
    "festejei": "festejar",
    "festejeis": "festejar",
    "festejem": "festejar",
    "festejemo": "festejar",
    "festejemos": "festejar",
    "festejes": "festejar",
    "festejo": "festejar",
    "festejos": "festejo",
    "festejou": "festejar",
    "festejá": "festejar",
    "festejámo": "festejar",
    "festejámos": "festejar",
    "festejáramo": "festejar",
    "festejáramos": "festejar",
    "festejárei": "festejar",
    "festejáreis": "festejar",
    "festejásseis": "festejar",
    "festejássemos": "festejar",
    "festejávamo": "festejar",
    "festejávamos": "festejar",
    "festejávei": "festejar",
    "festejáveis": "festejável",
    "festinações": "festinação",
    "festinha": "festa",
    "festinhas": "festa",
    "festins": "festim",
    "festita": "festa",
    "festitas": "festa",
    "festiva": "festivo",
    "festivais": "festival",
    "festivas": "festivo",
    "festividades": "festividade",
    "festivos": "festivo",
    "festoa": "festoar",
    "festoada": "festoar",
    "festoadas": "festoar",
    "festoado": "festoar",
    "festoados": "festoar",
    "festoai": "festoar",
    "festoais": "festoar",
    "festoam": "festoar",
    "festoamo": "festoar",
    "festoamos": "festoar",
    "festoando": "festoar",
    "festoara": "festoar",
    "festoaram": "festoar",
    "festoaras": "festoar",
    "festoarde": "festoar",
    "festoardes": "festoar",
    "festoare": "festoar",
    "festoarei": "festoar",
    "festoareis": "festoar",
    "festoarem": "festoar",
    "festoaremos": "festoar",
    "festoares": "festoar",
    "festoaria": "festoar",
    "festoariam": "festoar",
    "festoarias": "festoar",
    "festoarmo": "festoar",
    "festoarmos": "festoar",
    "festoará": "festoar",
    "festoarás": "festoar",
    "festoarão": "festoar",
    "festoaríamos": "festoar",
    "festoaríeis": "festoar",
    "festoas": "festoar",
    "festoasse": "festoar",
    "festoassem": "festoar",
    "festoasses": "festoar",
    "festoaste": "festoar",
    "festoastes": "festoar",
    "festoava": "festoar",
    "festoavam": "festoar",
    "festoavas": "festoar",
    "festoe": "festoar",
    "festoei": "festoar",
    "festoeis": "festoar",
    "festoem": "festoar",
    "festoemo": "festoar",
    "festoemos": "festoar",
    "festoes": "festoar",
    "festona": "festonar",
    "festonada": "festonar",
    "festonadas": "festonar",
    "festonado": "festonar",
    "festonados": "festonar",
    "festonai": "festonar",
    "festonais": "festonar",
    "festonam": "festonar",
    "festonamo": "festonar",
    "festonamos": "festonar",
    "festonando": "festonar",
    "festonara": "festonar",
    "festonaram": "festonar",
    "festonaras": "festonar",
    "festonarde": "festonar",
    "festonardes": "festonar",
    "festonare": "festonar",
    "festonarei": "festonar",
    "festonareis": "festonar",
    "festonarem": "festonar",
    "festonaremos": "festonar",
    "festonares": "festonar",
    "festonaria": "festonar",
    "festonariam": "festonar",
    "festonarias": "festonar",
    "festonarmo": "festonar",
    "festonarmos": "festonar",
    "festonará": "festonar",
    "festonarás": "festonar",
    "festonarão": "festonar",
    "festonaríamos": "festonar",
    "festonaríeis": "festonar",
    "festonas": "festonar",
    "festonasse": "festonar",
    "festonassem": "festonar",
    "festonasses": "festonar",
    "festonaste": "festonar",
    "festonastes": "festonar",
    "festonava": "festonar",
    "festonavam": "festonar",
    "festonavas": "festonar",
    "festone": "festonar",
    "festonei": "festonar",
    "festoneis": "festonar",
    "festonem": "festonar",
    "festonemo": "festonar",
    "festonemos": "festonar",
    "festones": "festonar",
    "festono": "festonar",
    "festonou": "festonar",
    "festoná": "festonar",
    "festonámo": "festonar",
    "festonámos": "festonar",
    "festonáramo": "festonar",
    "festonáramos": "festonar",
    "festonárei": "festonar",
    "festonáreis": "festonar",
    "festonásseis": "festonar",
    "festonássemos": "festonar",
    "festonávamo": "festonar",
    "festonávamos": "festonar",
    "festonávei": "festonar",
    "festonáveis": "festonar",
    "festoo": "festoar",
    "festoou": "festoar",
    "festos": "festo",
    "festoá": "festoar",
    "festoámo": "festoar",
    "festoámos": "festoar",
    "festoáramo": "festoar",
    "festoáramos": "festoar",
    "festoárei": "festoar",
    "festoáreis": "festoar",
    "festoásseis": "festoar",
    "festoássemos": "festoar",
    "festoávamo": "festoar",
    "festoávamos": "festoar",
    "festoávei": "festoar",
    "festoáveis": "festoar",
    "festucas": "festuca",
    "festões": "festão",
    "festúcea": "festúceo",
    "festúceas": "festúceo",
    "festúceos": "festúceo",
    "fetais": "fetal",
    "fetalismos": "fetalismo",
    "fetações": "fetação",
    "feteiras": "feteira",
    "fetiches": "fetiche",
    "fetichismos": "fetichismo",
    "fetichistas": "fetichista",
    "feticidas": "feticida",
    "feticídios": "feticídio",
    "fetos": "feto",
    "fetácea": "fetáceo",
    "fetáceas": "fetáceo",
    "fetáceos": "fetáceo",
    "feudais": "feudal",
    "feudalidades": "feudalidade",
    "feudalismos": "feudalismo",
    "feudalistas": "feudalista",
    "feudatária": "feudatário",
    "feudatárias": "feudatário",
    "feudatários": "feudatário",
    "feudistas": "feudista",
    "feudos": "feudo",
    "fevescentes": "fevescente",
    "fevras": "fevra",
    "fevrosa": "fevroso",
    "fevrosas": "fevroso",
    "fevrosos": "fevroso",
    "fez": "fazer",
    "fezadas": "fezada",
    "fezes": "fez",
    "feérica": "feérico",
    "feéricas": "feérico",
    "feéricos": "feérico",
    "ff": "f",
    "fi": "fazer",
    "fia": "fiar",
    "fiabilidades": "fiabilidade",
    "fiacres": "fiacre",
    "fiada": "fiar",
    "fiadas": "fiar",
    "fiadeira": "fiadeiro",
    "fiadeiras": "fiadeiro",
    "fiadeiros": "fiadeiro",
    "fiadilhos": "fiadilho",
    "fiado": "fiar",
    "fiadoiros": "fiadoiro",
    "fiadora": "fiador",
    "fiadoras": "fiador",
    "fiadores": "fiador",
    "fiadorias": "fiadoria",
    "fiados": "fiar",
    "fiadouros": "fiadouro",
    "fiaduras": "fiadura",
    "fiai": "fiar",
    "fiais": "fiar",
    "fialhos": "fialho",
    "fiam": "fiar",
    "fiambreiras": "fiambreira",
    "fiambreiros": "fiambreiro",
    "fiambres": "fiambre",
    "fiamo": "fiar",
    "fiamos": "fiar",
    "fiandeira": "fiandeiro",
    "fiandeiras": "fiandeiro",
    "fiandeiros": "fiandeiro",
    "fiando": "fiar",
    "fianças": "fiança",
    "fiapagens": "fiapagem",
    "fiaparias": "fiaparia",
    "fiapos": "fiapo",
    "fiara": "fiar",
    "fiaram": "fiar",
    "fiaras": "fiar",
    "fiarde": "fiar",
    "fiardes": "fiar",
    "fiare": "fiar",
    "fiarei": "fiar",
    "fiareis": "fiar",
    "fiarem": "fiar",
    "fiaremos": "fiar",
    "fiares": "fiar",
    "fiaria": "fiar",
    "fiariam": "fiar",
    "fiarias": "fiar",
    "fiarmo": "fiar",
    "fiarmos": "fiar",
    "fiará": "fiar",
    "fiarás": "fiar",
    "fiarão": "fiar",
    "fiaríamos": "fiar",
    "fiaríeis": "fiar",
    "fias": "fiar",
    "fiascos": "fiasco",
    "fiasse": "fiar",
    "fiassem": "fiar",
    "fiasses": "fiar",
    "fiaste": "fiar",
    "fiastes": "fiar",
    "fiava": "fiar",
    "fiavam": "fiar",
    "fiavas": "fiar",
    "fiações": "fiação",
    "fibras": "fibra",
    "fibrilares": "fibrilar",
    "fibrilas": "fibrila",
    "fibrilações": "fibrilação",
    "fibrilhas": "fibrilha",
    "fibrilhações": "fibrilhação",
    "fibrilosa": "fibriloso",
    "fibrilosas": "fibriloso",
    "fibrilosos": "fibriloso",
    "fibrilífera": "fibrilífero",
    "fibrilíferas": "fibrilífero",
    "fibrilíferos": "fibrilífero",
    "fibrina": "fibrino",
    "fibrinas": "fibrino",
    "fibrinogénia": "fibrinogénio",
    "fibrinogénias": "fibrinogénio",
    "fibrinogénios": "fibrinogénio",
    "fibrinos": "fibrino",
    "fibrinosa": "fibrinoso",
    "fibrinosas": "fibrinoso",
    "fibrinosos": "fibrinoso",
    "fibrocartilagens": "fibrocartilagem",
    "fibrocartilaginosa": "fibrocartilaginoso",
    "fibrocartilaginosas": "fibrocartilaginoso",
    "fibrocartilaginosos": "fibrocartilaginoso",
    "fibrocartilagínea": "fibrocartilagíneo",
    "fibrocartilagíneas": "fibrocartilagíneo",
    "fibrocartilagíneos": "fibrocartilagíneo",
    "fibrocelulares": "fibrocelular",
    "fibrocimentos": "fibrocimento",
    "fibrolites": "fibrolite",
    "fibrolítica": "fibrolítico",
    "fibrolíticas": "fibrolítico",
    "fibrolíticos": "fibrolítico",
    "fibromas": "fibroma",
    "fibromusculares": "fibromuscular",
    "fibrosa": "fibroso",
    "fibrosas": "fibroso",
    "fibroses": "fibrose",
    "fibrosos": "fibroso",
    "fibrovasculares": "fibrovascular",
    "fibrílias": "fibrília",
    "fibróides": "fibróide",
    "fibrólitos": "fibrólito",
    "fibulações": "fibulação",
    "fica": "ficar",
    "ficada": "ficar",
    "ficadas": "ficar",
    "ficado": "ficar",
    "ficados": "ficar",
    "ficais": "ficar",
    "ficam": "ficar",
    "ficamo": "ficar",
    "ficamos": "ficar",
    "ficando": "ficar",
    "ficara": "ficar",
    "ficaram": "ficar",
    "ficaras": "ficar",
    "ficardes": "ficar",
    "ficarei": "ficar",
    "ficareis": "ficar",
    "ficarem": "ficar",
    "ficaremos": "ficar",
    "ficares": "ficar",
    "ficaria": "ficar",
    "ficariam": "ficar",
    "ficarias": "ficar",
    "ficarmo": "ficar",
    "ficarmos": "ficar",
    "ficará": "ficar",
    "ficarás": "ficar",
    "ficarão": "ficar",
    "ficaríamos": "ficar",
    "ficaríeis": "ficar",
    "ficas": "ficar",
    "ficasse": "ficar",
    "ficassem": "ficar",
    "ficasses": "ficar",
    "ficaste": "ficar",
    "ficastes": "ficar",
    "ficava": "ficar",
    "ficavam": "ficar",
    "ficavas": "ficar",
    "ficciona": "ficcionar",
    "ficcionada": "ficcionar",
    "ficcionadas": "ficcionar",
    "ficcionado": "ficcionar",
    "ficcionados": "ficcionar",
    "ficcionai": "ficcionar",
    "ficcionais": "ficcionar",
    "ficcionam": "ficcionar",
    "ficcionamo": "ficcionar",
    "ficcionamos": "ficcionar",
    "ficcionando": "ficcionar",
    "ficcionara": "ficcionar",
    "ficcionaram": "ficcionar",
    "ficcionaras": "ficcionar",
    "ficcionarde": "ficcionar",
    "ficcionardes": "ficcionar",
    "ficcionare": "ficcionar",
    "ficcionarei": "ficcionar",
    "ficcionareis": "ficcionar",
    "ficcionarem": "ficcionar",
    "ficcionaremos": "ficcionar",
    "ficcionares": "ficcionar",
    "ficcionaria": "ficcionar",
    "ficcionariam": "ficcionar",
    "ficcionarias": "ficcionar",
    "ficcionarmo": "ficcionar",
    "ficcionarmos": "ficcionar",
    "ficcionará": "ficcionar",
    "ficcionarás": "ficcionar",
    "ficcionarão": "ficcionar",
    "ficcionaríamos": "ficcionar",
    "ficcionaríeis": "ficcionar",
    "ficcionas": "ficcionar",
    "ficcionasse": "ficcionar",
    "ficcionassem": "ficcionar",
    "ficcionasses": "ficcionar",
    "ficcionaste": "ficcionar",
    "ficcionastes": "ficcionar",
    "ficcionava": "ficcionar",
    "ficcionavam": "ficcionar",
    "ficcionavas": "ficcionar",
    "ficcione": "ficcionar",
    "ficcionei": "ficcionar",
    "ficcioneis": "ficcionar",
    "ficcionem": "ficcionar",
    "ficcionemo": "ficcionar",
    "ficcionemos": "ficcionar",
    "ficciones": "ficcionar",
    "ficcionismos": "ficcionismo",
    "ficcionistas": "ficcionista",
    "ficciono": "ficcionar",
    "ficcionou": "ficcionar",
    "ficcioná": "ficcionar",
    "ficcionámo": "ficcionar",
    "ficcionámos": "ficcionar",
    "ficcionáramo": "ficcionar",
    "ficcionáramos": "ficcionar",
    "ficcionárei": "ficcionar",
    "ficcionáreis": "ficcionar",
    "ficcionásseis": "ficcionar",
    "ficcionássemos": "ficcionar",
    "ficcionávamo": "ficcionar",
    "ficcionávamos": "ficcionar",
    "ficcionávei": "ficcionar",
    "ficcionáveis": "ficcionar",
    "ficha": "fichar",
    "fichada": "fichar",
    "fichadas": "fichar",
    "fichado": "fichar",
    "fichados": "fichar",
    "fichai": "fichar",
    "fichais": "fichar",
    "ficham": "fichar",
    "fichamo": "fichar",
    "fichamos": "fichar",
    "fichando": "fichar",
    "fichara": "fichar",
    "ficharam": "fichar",
    "ficharas": "fichar",
    "ficharde": "fichar",
    "fichardes": "fichar",
    "fichare": "fichar",
    "ficharei": "fichar",
    "fichareis": "fichar",
    "ficharem": "fichar",
    "ficharemos": "fichar",
    "fichares": "fichar",
    "ficharia": "fichar",
    "fichariam": "fichar",
    "ficharias": "fichar",
    "ficharmo": "fichar",
    "ficharmos": "fichar",
    "fichará": "fichar",
    "ficharás": "fichar",
    "ficharão": "fichar",
    "ficharíamos": "fichar",
    "ficharíeis": "fichar",
    "fichas": "fichar",
    "fichasse": "fichar",
    "fichassem": "fichar",
    "fichasses": "fichar",
    "fichaste": "fichar",
    "fichastes": "fichar",
    "fichava": "fichar",
    "fichavam": "fichar",
    "fichavas": "fichar",
    "fiche": "fichar",
    "fichei": "fichar",
    "ficheiros": "ficheiro",
    "ficheis": "fichar",
    "fichem": "fichar",
    "fichemo": "fichar",
    "fichemos": "fichar",
    "fiches": "fichar",
    "ficho": "fichar",
    "fichou": "fichar",
    "fichá": "fichar",
    "fichámo": "fichar",
    "fichámos": "fichar",
    "ficháramo": "fichar",
    "ficháramos": "fichar",
    "fichárei": "fichar",
    "ficháreis": "fichar",
    "fichásseis": "fichar",
    "fichássemos": "fichar",
    "fichávamo": "fichar",
    "fichávamos": "fichar",
    "fichávei": "fichar",
    "ficháveis": "fichar",
    "ficiformes": "ficiforme",
    "fico": "ficar",
    "ficocianina": "ficocianino",
    "ficocianinas": "ficocianino",
    "ficocianinos": "ficocianino",
    "ficoeritrina": "ficoeritrino",
    "ficoeritrinas": "ficoeritrino",
    "ficoeritrinos": "ficoeritrino",
    "ficofeínas": "ficofeína",
    "ficofeínica": "ficofeínico",
    "ficofeínicas": "ficofeínico",
    "ficofeínicos": "ficofeínico",
    "ficologias": "ficologia",
    "ficologistas": "ficologista",
    "ficológica": "ficológico",
    "ficológicas": "ficológico",
    "ficológicos": "ficológico",
    "ficomicetos": "ficomiceto",
    "ficomicética": "ficomicético",
    "ficomicéticas": "ficomicético",
    "ficomicéticos": "ficomicético",
    "ficou": "ficar",
    "fictícia": "fictício",
    "fictícias": "fictício",
    "fictícios": "fictício",
    "ficácea": "ficáceo",
    "ficáceas": "ficáceo",
    "ficáceos": "ficáceo",
    "ficámo": "ficar",
    "ficámos": "ficar",
    "ficáramo": "ficar",
    "ficáramos": "ficar",
    "ficáreis": "ficar",
    "ficária": "ficário",
    "ficárias": "ficário",
    "ficários": "ficário",
    "ficásseis": "ficar",
    "ficássemos": "ficar",
    "ficávamo": "ficar",
    "ficávamos": "ficar",
    "ficáveis": "ficar",
    "ficções": "ficção",
    "ficóloga": "ficólogo",
    "ficólogas": "ficólogo",
    "ficólogos": "ficólogo",
    "fida": "fido",
    "fidalga": "fidalgo",
    "fidalgais": "fidalgal",
    "fidalgarias": "fidalgaria",
    "fidalgarrona": "fidalgarrão",
    "fidalgarronas": "fidalgarrão",
    "fidalgarrões": "fidalgarrão",
    "fidalgas": "fidalgo",
    "fidalgazinha": "fidalgo",
    "fidalgazinhas": "fidalgo",
    "fidalgazita": "fidalgo",
    "fidalgazitas": "fidalgo",
    "fidalgaça": "fidalgaço",
    "fidalgaças": "fidalgaço",
    "fidalgaços": "fidalgaço",
    "fidalgos": "fidalgo",
    "fidalgosa": "fidalgoso",
    "fidalgosas": "fidalgoso",
    "fidalgosos": "fidalgoso",
    "fidalgota": "fidalgote",
    "fidalgotas": "fidalgote",
    "fidalgotes": "fidalgote",
    "fidalgozinho": "fidalgo",
    "fidalgozinhos": "fidalgo",
    "fidalgozito": "fidalgo",
    "fidalgozitos": "fidalgo",
    "fidalgueira": "fidalgueiro",
    "fidalgueiras": "fidalgueiro",
    "fidalgueiros": "fidalgueiro",
    "fidalguelha": "fidalguelho",
    "fidalguelhas": "fidalguelho",
    "fidalguelhos": "fidalguelho",
    "fidalguesca": "fidalguesco",
    "fidalguescas": "fidalguesco",
    "fidalguescos": "fidalguesco",
    "fidalgueta": "fidalguete",
    "fidalguetas": "fidalguete",
    "fidalguetes": "fidalguete",
    "fidalguias": "fidalguia",
    "fidalguices": "fidalguice",
    "fidalguinha": "fidalgo",
    "fidalguinhas": "fidalgo",
    "fidalguinho": "fidalgo",
    "fidalguinhos": "fidalgo",
    "fidalguita": "fidalgo",
    "fidalguitas": "fidalgo",
    "fidalguito": "fidalgo",
    "fidalguitos": "fidalgo",
    "fidalguéria": "fidalguério",
    "fidalguérias": "fidalguério",
    "fidalguérios": "fidalguério",
    "fidas": "fido",
    "fidecomissários": "fidecomissário",
    "fidedigna": "fidedigno",
    "fidedignas": "fidedigno",
    "fidedignidades": "fidedignidade",
    "fidedignos": "fidedigno",
    "fideicomissos": "fideicomisso",
    "fidejussória": "fidejussório",
    "fidejussórias": "fidejussório",
    "fidejussórios": "fidejussório",
    "fidelidades": "fidelidade",
    "fidelistas": "fidelista",
    "fidelíssima": "fiel",
    "fidelíssimas": "fiel",
    "fidelíssimo": "fiel",
    "fidelíssimos": "fiel",
    "fideísmos": "fideísmo",
    "fideístas": "fideísta",
    "fidiesca": "fidiesco",
    "fidiescas": "fidiesco",
    "fidiescos": "fidiesco",
    "fidos": "fido",
    "fiduciais": "fiducial",
    "fiduciária": "fiduciário",
    "fiduciárias": "fiduciário",
    "fiduciários": "fiduciário",
    "fidúcias": "fidúcia",
    "fie": "fiar",
    "fiei": "fiar",
    "fieiras": "fieira",
    "fieiros": "fieiro",
    "fieis": "fiar",
    "fieiteiras": "fieiteira",
    "fieitos": "fieito",
    "fiem": "fiar",
    "fiemo": "fiar",
    "fiemos": "fiar",
    "fies": "fiar",
    "fifis": "fifi",
    "figadais": "figadal",
    "figadeiras": "figadeira",
    "figas": "figa",
    "figles": "figle",
    "figos": "figo",
    "figueirais": "figueiral",
    "figueiras": "figueira",
    "figueirenses": "figueirense",
    "figueirinha": "figueira",
    "figueirinhas": "figueira",
    "figueirita": "figueira",
    "figueiritas": "figueira",
    "figueiroas": "figueiroa",
    "figueitais": "figueital",
    "figueiteiras": "figueiteira",
    "figueitos": "figueito",
    "figulina": "figulino",
    "figulinas": "figulino",
    "figulinos": "figulino",
    "figura": "figurar",
    "figurabilidades": "figurabilidade",
    "figurada": "figurar",
    "figuradas": "figurar",
    "figurado": "figurar",
    "figurados": "figurar",
    "figurai": "figurar",
    "figurais": "figurar",
    "figuralidades": "figuralidade",
    "figuram": "figurar",
    "figuramo": "figurar",
    "figuramos": "figurar",
    "figurando": "figurar",
    "figurantes": "figurante",
    "figurara": "figurar",
    "figuraram": "figurar",
    "figuraras": "figurar",
    "figurarde": "figurar",
    "figurardes": "figurar",
    "figurare": "figurar",
    "figurarei": "figurar",
    "figurareis": "figurar",
    "figurarem": "figurar",
    "figuraremos": "figurar",
    "figurares": "figurar",
    "figuraria": "figurar",
    "figurariam": "figurar",
    "figurarias": "figuraria",
    "figurarmo": "figurar",
    "figurarmos": "figurar",
    "figurará": "figurar",
    "figurarás": "figurar",
    "figurarão": "figurar",
    "figuraríamos": "figurar",
    "figuraríeis": "figurar",
    "figuras": "figurar",
    "figurasse": "figurar",
    "figurassem": "figurar",
    "figurasses": "figurar",
    "figuraste": "figurar",
    "figurastes": "figurar",
    "figurativa": "figurativo",
    "figurativas": "figurativo",
    "figurativos": "figurativo",
    "figurava": "figurar",
    "figuravam": "figurar",
    "figuravas": "figurar",
    "figuraça": "figuraço",
    "figuraças": "figuraço",
    "figuraços": "figuraço",
    "figurações": "figuração",
    "figure": "figurar",
    "figurei": "figurar",
    "figureis": "figurar",
    "figurem": "figurar",
    "figuremo": "figurar",
    "figuremos": "figurar",
    "figures": "figurar",
    "figurilhas": "figurilha",
    "figurinha": "figura",
    "figurinhas": "figura",
    "figurinistas": "figurinista",
    "figurinos": "figurino",
    "figurismos": "figurismo",
    "figuristas": "figurista",
    "figurita": "figura",
    "figuritas": "figura",
    "figuro": "figurar",
    "figurona": "figurão",
    "figuronas": "figurão",
    "figuros": "figuro",
    "figurou": "figurar",
    "figurá": "figurar",
    "figurámo": "figurar",
    "figurámos": "figurar",
    "figuráramo": "figurar",
    "figuráramos": "figurar",
    "figurárei": "figurar",
    "figuráreis": "figurar",
    "figurásseis": "figurar",
    "figurássemos": "figurar",
    "figurávamo": "figurar",
    "figurávamos": "figurar",
    "figurávei": "figurar",
    "figuráveis": "figurável",
    "figurões": "figurão",
    "fila": "filar",
    "filactéria": "filactério",
    "filactérias": "filactério",
    "filactérios": "filactério",
    "filada": "filar",
    "filadas": "filar",
    "filadelfa": "filadelfo",
    "filadelfas": "filadelfo",
    "filadelfena": "filadelfeno",
    "filadelfenas": "filadelfeno",
    "filadelfenos": "filadelfeno",
    "filadelfenses": "filadelfense",
    "filadelfiana": "filadelfiano",
    "filadelfianas": "filadelfiano",
    "filadelfianos": "filadelfiano",
    "filadelfos": "filadelfo",
    "filadenfienses": "filadenfiense",
    "filado": "filar",
    "filados": "filar",
    "filai": "filar",
    "filais": "filar",
    "filam": "filar",
    "filamentares": "filamentar",
    "filamentos": "filamento",
    "filamentosa": "filamentoso",
    "filamentosas": "filamentoso",
    "filamentosos": "filamentoso",
    "filames": "filame",
    "filamo": "filar",
    "filamos": "filar",
    "filandeiras": "filandeira",
    "filando": "filar",
    "filandrosa": "filandroso",
    "filandrosas": "filandroso",
    "filandrosos": "filandroso",
    "filantes": "filante",
    "filantropa": "filantropo",
    "filantropas": "filantropo",
    "filantropias": "filantropia",
    "filantropismos": "filantropismo",
    "filantropos": "filantropo",
    "filantrópica": "filantrópico",
    "filantrópicas": "filantrópico",
    "filantrópicos": "filantrópico",
    "filara": "filar",
    "filaram": "filar",
    "filaras": "filar",
    "filarde": "filar",
    "filardes": "filar",
    "filare": "filar",
    "filarei": "filar",
    "filareis": "filar",
    "filarem": "filar",
    "filaremos": "filar",
    "filares": "filar",
    "filaria": "filar",
    "filariam": "filar",
    "filarias": "filar",
    "filarioses": "filariose",
    "filariídea": "filariídeo",
    "filariídeas": "filariídeo",
    "filariídeos": "filariídeo",
    "filarmnias": "filarmnia",
    "filarmo": "filar",
    "filarmos": "filar",
    "filarmónica": "filarmónico",
    "filarmónicas": "filarmónico",
    "filarmónicos": "filarmónico",
    "filará": "filar",
    "filarás": "filar",
    "filarão": "filar",
    "filaríamos": "filar",
    "filaríases": "filaríase",
    "filarídeos": "filarídeo",
    "filaríeis": "filar",
    "filaríidas": "filaríida",
    "filas": "filar",
    "filasse": "filar",
    "filassem": "filar",
    "filasses": "filar",
    "filaste": "filar",
    "filastes": "filar",
    "filatelias": "filatelia",
    "filatelismos": "filatelismo",
    "filatelistas": "filatelista",
    "filatélica": "filatélico",
    "filatélicas": "filatélico",
    "filatélicos": "filatélico",
    "filatória": "filatório",
    "filatórias": "filatório",
    "filatórios": "filatório",
    "filauciosa": "filaucioso",
    "filauciosas": "filaucioso",
    "filauciosos": "filaucioso",
    "filava": "filar",
    "filavam": "filar",
    "filavas": "filar",
    "filaças": "filaça",
    "file": "filar",
    "filei": "filar",
    "fileiras": "fileira",
    "fileis": "filar",
    "fileles": "filele",
    "filem": "filar",
    "filemo": "filar",
    "filemos": "filar",
    "fileretes": "filerete",
    "files": "filar",
    "fileta": "filetar",
    "filetada": "filetar",
    "filetadas": "filetar",
    "filetado": "filetar",
    "filetados": "filetar",
    "filetagens": "filetagem",
    "filetai": "filetar",
    "filetais": "filetar",
    "filetam": "filetar",
    "filetamo": "filetar",
    "filetamos": "filetar",
    "filetando": "filetar",
    "filetara": "filetar",
    "filetaram": "filetar",
    "filetaras": "filetar",
    "filetarde": "filetar",
    "filetardes": "filetar",
    "filetare": "filetar",
    "filetarei": "filetar",
    "filetareis": "filetar",
    "filetarem": "filetar",
    "filetaremos": "filetar",
    "filetares": "filetar",
    "filetaria": "filetar",
    "filetariam": "filetar",
    "filetarias": "filetar",
    "filetarmo": "filetar",
    "filetarmos": "filetar",
    "filetará": "filetar",
    "filetarás": "filetar",
    "filetarão": "filetar",
    "filetaríamos": "filetar",
    "filetaríeis": "filetar",
    "filetas": "filetar",
    "filetasse": "filetar",
    "filetassem": "filetar",
    "filetasses": "filetar",
    "filetaste": "filetar",
    "filetastes": "filetar",
    "filetava": "filetar",
    "filetavam": "filetar",
    "filetavas": "filetar",
    "filete": "filetar",
    "filetei": "filetar",
    "fileteis": "filetar",
    "filetem": "filetar",
    "filetemo": "filetar",
    "filetemos": "filetar",
    "filetes": "filete",
    "filetezinho": "filete",
    "filetezinhos": "filete",
    "filetezito": "filete",
    "filetezitos": "filete",
    "fileto": "filetar",
    "filetou": "filetar",
    "filetá": "filetar",
    "filetámo": "filetar",
    "filetámos": "filetar",
    "filetáramo": "filetar",
    "filetáramos": "filetar",
    "filetárei": "filetar",
    "filetáreis": "filetar",
    "filetásseis": "filetar",
    "filetássemos": "filetar",
    "filetávamo": "filetar",
    "filetávamos": "filetar",
    "filetávei": "filetar",
    "filetáveis": "filetar",
    "filha": "filho",
    "filhada": "filhar",
    "filhadas": "filhar",
    "filhado": "filhar",
    "filhadora": "filhador",
    "filhadoras": "filhador",
    "filhadores": "filhador",
    "filhados": "filhar",
    "filhai": "filhar",
    "filhais": "filhar",
    "filham": "filhar",
    "filhamentos": "filhamento",
    "filhamo": "filhar",
    "filhamos": "filhar",
    "filhando": "filhar",
    "filhara": "filharar",
    "filharada": "filharar",
    "filharadas": "filharar",
    "filharado": "filharar",
    "filharados": "filharar",
    "filharai": "filharar",
    "filharais": "filharar",
    "filharam": "filharar",
    "filharamo": "filharar",
    "filharamos": "filharar",
    "filharando": "filharar",
    "filharara": "filharar",
    "filhararam": "filharar",
    "filhararas": "filharar",
    "filharardes": "filharar",
    "filhararei": "filharar",
    "filharareis": "filharar",
    "filhararem": "filharar",
    "filhararemos": "filharar",
    "filharares": "filharar",
    "filhararia": "filharar",
    "filharariam": "filharar",
    "filhararias": "filharar",
    "filhararmo": "filharar",
    "filhararmos": "filharar",
    "filharará": "filharar",
    "filhararás": "filharar",
    "filhararão": "filharar",
    "filhararíamos": "filharar",
    "filhararíeis": "filharar",
    "filharas": "filharar",
    "filharascos": "filharasco",
    "filharasse": "filharar",
    "filharassem": "filharar",
    "filharasses": "filharar",
    "filharaste": "filharar",
    "filharastes": "filharar",
    "filharava": "filharar",
    "filharavam": "filharar",
    "filharavas": "filharar",
    "filharde": "filhar",
    "filhardes": "filhar",
    "filhare": "filharar",
    "filharei": "filharar",
    "filhareis": "filharar",
    "filharem": "filharar",
    "filharemo": "filharar",
    "filharemos": "filharar",
    "filhares": "filharar",
    "filharia": "filhar",
    "filhariam": "filhar",
    "filharias": "filhar",
    "filharmo": "filhar",
    "filharmos": "filhar",
    "filharo": "filharar",
    "filharou": "filharar",
    "filhará": "filhar",
    "filharámo": "filharar",
    "filharámos": "filharar",
    "filharáramo": "filharar",
    "filharáramos": "filharar",
    "filharáreis": "filharar",
    "filharás": "filhar",
    "filharásseis": "filharar",
    "filharássemos": "filharar",
    "filharávamo": "filharar",
    "filharávamos": "filharar",
    "filharáveis": "filharar",
    "filharão": "filhar",
    "filharíamos": "filhar",
    "filharíeis": "filhar",
    "filhas": "filho",
    "filhasse": "filhar",
    "filhassem": "filhar",
    "filhasses": "filhar",
    "filhaste": "filhar",
    "filhastes": "filhar",
    "filhastros": "filhastro",
    "filhava": "filhar",
    "filhavam": "filhar",
    "filhavas": "filhar",
    "filhações": "filhação",
    "filhe": "filhar",
    "filhei": "filhar",
    "filheira": "filheiro",
    "filheiras": "filheiro",
    "filheiros": "filheiro",
    "filheis": "filhar",
    "filhem": "filhar",
    "filhemo": "filhar",
    "filhemos": "filhar",
    "filhenta": "filhento",
    "filhentas": "filhento",
    "filhentos": "filhento",
    "filhes": "filhar",
    "filhinha": "filho",
    "filhinhas": "filho",
    "filhinho": "filho",
    "filhinhos": "filho",
    "filhita": "filho",
    "filhitas": "filho",
    "filhito": "filho",
    "filhitos": "filho",
    "filho": "filhar",
    "filhos": "filho",
    "filhoses": "filhós",
    "filhota": "filhote",
    "filhotas": "filhote",
    "filhotes": "filhote",
    "filhou": "filhar",
    "filhá": "filhar",
    "filhámo": "filhar",
    "filhámos": "filhar",
    "filháramo": "filhar",
    "filháramos": "filhar",
    "filhárei": "filhar",
    "filháreis": "filhar",
    "filhásseis": "filhar",
    "filhássemos": "filhar",
    "filhávamo": "filhar",
    "filhávamos": "filhar",
    "filhávei": "filhar",
    "filháveis": "filhar",
    "filhós": "filhó",
    "filia": "filiar",
    "filiada": "filiar",
    "filiadas": "filiar",
    "filiado": "filiar",
    "filiados": "filiar",
    "filiai": "filiar",
    "filiais": "filiar",
    "filiam": "filiar",
    "filiamo": "filiar",
    "filiamos": "filiar",
    "filiando": "filiar",
    "filiara": "filiar",
    "filiaram": "filiar",
    "filiaras": "filiar",
    "filiarde": "filiar",
    "filiardes": "filiar",
    "filiare": "filiar",
    "filiarei": "filiar",
    "filiareis": "filiar",
    "filiarem": "filiar",
    "filiaremos": "filiar",
    "filiares": "filiar",
    "filiaria": "filiar",
    "filiariam": "filiar",
    "filiarias": "filiar",
    "filiarmo": "filiar",
    "filiarmos": "filiar",
    "filiará": "filiar",
    "filiarás": "filiar",
    "filiarão": "filiar",
    "filiaríamos": "filiar",
    "filiaríeis": "filiar",
    "filiarítica": "filiarítico",
    "filiaríticas": "filiarítico",
    "filiaríticos": "filiarítico",
    "filias": "filiar",
    "filiasse": "filiar",
    "filiassem": "filiar",
    "filiasses": "filiar",
    "filiaste": "filiar",
    "filiastes": "filiar",
    "filiava": "filiar",
    "filiavam": "filiar",
    "filiavas": "filiar",
    "filiações": "filiação",
    "filicidas": "filicida",
    "filicídios": "filicídio",
    "filicífera": "filicífero",
    "filicíferas": "filicífero",
    "filicíferos": "filicífero",
    "filie": "filiar",
    "filiei": "filiar",
    "filieis": "filiar",
    "filiem": "filiar",
    "filiemo": "filiar",
    "filiemos": "filiar",
    "filies": "filiar",
    "filifolhas": "filifolha",
    "filifoliada": "filifoliado",
    "filifoliadas": "filifoliado",
    "filifoliados": "filifoliado",
    "filiformes": "filiforme",
    "filigrana": "filigranar",
    "filigranada": "filigranar",
    "filigranadas": "filigranar",
    "filigranado": "filigranar",
    "filigranados": "filigranar",
    "filigranagens": "filigranagem",
    "filigranai": "filigranar",
    "filigranais": "filigranar",
    "filigranam": "filigranar",
    "filigranamo": "filigranar",
    "filigranamos": "filigranar",
    "filigranando": "filigranar",
    "filigranara": "filigranar",
    "filigranaram": "filigranar",
    "filigranaras": "filigranar",
    "filigranarde": "filigranar",
    "filigranardes": "filigranar",
    "filigranare": "filigranar",
    "filigranarei": "filigranar",
    "filigranareis": "filigranar",
    "filigranarem": "filigranar",
    "filigranaremos": "filigranar",
    "filigranares": "filigranar",
    "filigranaria": "filigranar",
    "filigranariam": "filigranar",
    "filigranarias": "filigranar",
    "filigranarmo": "filigranar",
    "filigranarmos": "filigranar",
    "filigranará": "filigranar",
    "filigranarás": "filigranar",
    "filigranarão": "filigranar",
    "filigranaríamos": "filigranar",
    "filigranaríeis": "filigranar",
    "filigranas": "filigranar",
    "filigranasse": "filigranar",
    "filigranassem": "filigranar",
    "filigranasses": "filigranar",
    "filigranaste": "filigranar",
    "filigranastes": "filigranar",
    "filigranava": "filigranar",
    "filigranavam": "filigranar",
    "filigranavas": "filigranar",
    "filigrane": "filigranar",
    "filigranei": "filigranar",
    "filigraneiros": "filigraneiro",
    "filigraneis": "filigranar",
    "filigranem": "filigranar",
    "filigranemo": "filigranar",
    "filigranemos": "filigranar",
    "filigranes": "filigranar",
    "filigranistas": "filigranista",
    "filigrano": "filigranar",
    "filigranou": "filigranar",
    "filigraná": "filigranar",
    "filigranámo": "filigranar",
    "filigranámos": "filigranar",
    "filigranáramo": "filigranar",
    "filigranáramos": "filigranar",
    "filigranárei": "filigranar",
    "filigranáreis": "filigranar",
    "filigranásseis": "filigranar",
    "filigranássemos": "filigranar",
    "filigranávamo": "filigranar",
    "filigranávamos": "filigranar",
    "filigranávei": "filigranar",
    "filigranáveis": "filigranar",
    "filintina": "filintino",
    "filintinas": "filintino",
    "filintinos": "filintino",
    "filintismos": "filintismo",
    "filintistas": "filintista",
    "filio": "filiar",
    "filiou": "filiar",
    "filipendulária": "filipendulário",
    "filipendulárias": "filipendulário",
    "filipendulários": "filipendulário",
    "filipina": "filipino",
    "filipinas": "filipino",
    "filipinos": "filipino",
    "filipistas": "filipista",
    "filiplumas": "filipluma",
    "filipsitas": "filipsita",
    "filirrostra": "filirrostro",
    "filirrostras": "filirrostro",
    "filirrostros": "filirrostro",
    "filisteia": "filisteu",
    "filisteias": "filisteu",
    "filisteus": "filisteu",
    "filistina": "filistino",
    "filistinas": "filistino",
    "filistinismos": "filistinismo",
    "filistinos": "filistino",
    "filistria": "filistriar",
    "filistriada": "filistriar",
    "filistriadas": "filistriar",
    "filistriado": "filistriar",
    "filistriados": "filistriar",
    "filistriai": "filistriar",
    "filistriais": "filistriar",
    "filistriam": "filistriar",
    "filistriamo": "filistriar",
    "filistriamos": "filistriar",
    "filistriando": "filistriar",
    "filistriara": "filistriar",
    "filistriaram": "filistriar",
    "filistriaras": "filistriar",
    "filistriardes": "filistriar",
    "filistriarei": "filistriar",
    "filistriareis": "filistriar",
    "filistriarem": "filistriar",
    "filistriaremos": "filistriar",
    "filistriares": "filistriar",
    "filistriaria": "filistriar",
    "filistriariam": "filistriar",
    "filistriarias": "filistriar",
    "filistriarmo": "filistriar",
    "filistriarmos": "filistriar",
    "filistriará": "filistriar",
    "filistriarás": "filistriar",
    "filistriarão": "filistriar",
    "filistriaríamos": "filistriar",
    "filistriaríeis": "filistriar",
    "filistrias": "filistriar",
    "filistriasse": "filistriar",
    "filistriassem": "filistriar",
    "filistriasses": "filistriar",
    "filistriaste": "filistriar",
    "filistriastes": "filistriar",
    "filistriava": "filistriar",
    "filistriavam": "filistriar",
    "filistriavas": "filistriar",
    "filistrie": "filistriar",
    "filistriei": "filistriar",
    "filistrieis": "filistriar",
    "filistriem": "filistriar",
    "filistriemo": "filistriar",
    "filistriemos": "filistriar",
    "filistries": "filistriar",
    "filistrio": "filistriar",
    "filistriou": "filistriar",
    "filistriámo": "filistriar",
    "filistriámos": "filistriar",
    "filistriáramo": "filistriar",
    "filistriáramos": "filistriar",
    "filistriáreis": "filistriar",
    "filistriásseis": "filistriar",
    "filistriássemos": "filistriar",
    "filistriávamo": "filistriar",
    "filistriávamos": "filistriar",
    "filistriáveis": "filistriar",
    "filites": "filite",
    "filitos": "filito",
    "filiá": "filiar",
    "filiámo": "filiar",
    "filiámos": "filiar",
    "filiáramo": "filiar",
    "filiáramos": "filiar",
    "filiárei": "filiar",
    "filiáreis": "filiar",
    "filiásseis": "filiar",
    "filiássemos": "filiar",
    "filiávamo": "filiar",
    "filiávamos": "filiar",
    "filiávei": "filiar",
    "filiáveis": "filiar",
    "filma": "filmar",
    "filmada": "filmar",
    "filmadas": "filmar",
    "filmado": "filmar",
    "filmados": "filmar",
    "filmagens": "filmagem",
    "filmai": "filmar",
    "filmais": "filmar",
    "filmam": "filmar",
    "filmamo": "filmar",
    "filmamos": "filmar",
    "filmando": "filmar",
    "filmara": "filmar",
    "filmaram": "filmar",
    "filmaras": "filmar",
    "filmarde": "filmar",
    "filmardes": "filmar",
    "filmare": "filmar",
    "filmarei": "filmar",
    "filmareis": "filmar",
    "filmarem": "filmar",
    "filmaremos": "filmar",
    "filmares": "filmar",
    "filmaria": "filmar",
    "filmariam": "filmar",
    "filmarias": "filmar",
    "filmarmo": "filmar",
    "filmarmos": "filmar",
    "filmará": "filmar",
    "filmarás": "filmar",
    "filmarão": "filmar",
    "filmaríamos": "filmar",
    "filmaríeis": "filmar",
    "filmas": "filmar",
    "filmasse": "filmar",
    "filmassem": "filmar",
    "filmasses": "filmar",
    "filmaste": "filmar",
    "filmastes": "filmar",
    "filmava": "filmar",
    "filmavam": "filmar",
    "filmavas": "filmar",
    "filme": "filmar",
    "filmei": "filmar",
    "filmeis": "filmar",
    "filmem": "filmar",
    "filmemo": "filmar",
    "filmemos": "filmar",
    "filmes": "filme",
    "filmezinho": "filme",
    "filmezinhos": "filme",
    "filmezito": "filme",
    "filmezitos": "filme",
    "filmo": "filmar",
    "filmografias": "filmografia",
    "filmologias": "filmologia",
    "filmologistas": "filmologista",
    "filmotecas": "filmoteca",
    "filmou": "filmar",
    "filmá": "filmar",
    "filmámo": "filmar",
    "filmámos": "filmar",
    "filmáramo": "filmar",
    "filmáramos": "filmar",
    "filmárei": "filmar",
    "filmáreis": "filmar",
    "filmásseis": "filmar",
    "filmássemos": "filmar",
    "filmávamo": "filmar",
    "filmávamos": "filmar",
    "filmávei": "filmar",
    "filmáveis": "filmável",
    "filmóloga": "filmólogo",
    "filmólogas": "filmólogo",
    "filmólogos": "filmólogo",
    "filo": "filar",
    "filocládios": "filocládio",
    "filodendros": "filodendro",
    "filodermes": "filoderme",
    "filodinastas": "filodinasta",
    "filodinástica": "filodinástico",
    "filodinásticas": "filodinástico",
    "filodinásticos": "filodinástico",
    "filodérmica": "filodérmico",
    "filodérmicas": "filodérmico",
    "filodérmicos": "filodérmico",
    "filodêndrica": "filodêndrico",
    "filodêndricas": "filodêndrico",
    "filodêndricos": "filodêndrico",
    "filogenesias": "filogenesia",
    "filogenias": "filogenia",
    "filogenituras": "filogenitura",
    "filogenésica": "filogenésico",
    "filogenésicas": "filogenésico",
    "filogenésicos": "filogenésico",
    "filogenética": "filogenético",
    "filogenéticas": "filogenético",
    "filogenéticos": "filogenético",
    "filoginias": "filoginia",
    "filogéneses": "filogénese",
    "filogénica": "filogénico",
    "filogénicas": "filogénico",
    "filogénicos": "filogénico",
    "filogínica": "filogínico",
    "filogínicas": "filogínico",
    "filogínicos": "filogínico",
    "filologias": "filologia",
    "filologistas": "filologista",
    "filológica": "filológico",
    "filológicas": "filológico",
    "filológicos": "filológico",
    "filomas": "filoma",
    "filomatias": "filomatia",
    "filomelas": "filomela",
    "filomática": "filomático",
    "filomáticas": "filomático",
    "filomáticos": "filomático",
    "filoneísmos": "filoneísmo",
    "filoniana": "filoniano",
    "filonianas": "filoniano",
    "filonianos": "filoniano",
    "filoptosias": "filoptosia",
    "filoptósica": "filoptósico",
    "filoptósicas": "filoptósico",
    "filoptósicos": "filoptósico",
    "filos": "filo",
    "filosofa": "filosofar",
    "filosofada": "filosofar",
    "filosofadas": "filosofar",
    "filosofado": "filosofar",
    "filosofados": "filosofar",
    "filosofai": "filosofar",
    "filosofais": "filosofar",
    "filosofam": "filosofar",
    "filosofamo": "filosofar",
    "filosofamos": "filosofar",
    "filosofando": "filosofar",
    "filosofantes": "filosofante",
    "filosofara": "filosofar",
    "filosofaram": "filosofar",
    "filosofaras": "filosofar",
    "filosofarde": "filosofar",
    "filosofardes": "filosofar",
    "filosofare": "filosofar",
    "filosofarei": "filosofar",
    "filosofareis": "filosofar",
    "filosofarem": "filosofar",
    "filosofaremos": "filosofar",
    "filosofares": "filosofar",
    "filosofaria": "filosofar",
    "filosofariam": "filosofar",
    "filosofarias": "filosofar",
    "filosofarmo": "filosofar",
    "filosofarmos": "filosofar",
    "filosofará": "filosofar",
    "filosofarás": "filosofar",
    "filosofarão": "filosofar",
    "filosofaríamos": "filosofar",
    "filosofaríeis": "filosofar",
    "filosofas": "filosofar",
    "filosofasse": "filosofar",
    "filosofassem": "filosofar",
    "filosofasses": "filosofar",
    "filosofaste": "filosofar",
    "filosofastes": "filosofar",
    "filosofava": "filosofar",
    "filosofavam": "filosofar",
    "filosofavas": "filosofar",
    "filosofe": "filosofar",
    "filosofei": "filosofar",
    "filosofeis": "filosofar",
    "filosofem": "filosofar",
    "filosofemas": "filosofema",
    "filosofemo": "filosofar",
    "filosofemos": "filosofar",
    "filosofes": "filosofar",
    "filosofias": "filosofia",
    "filosofices": "filosofice",
    "filosofismos": "filosofismo",
    "filosofo": "filosofar",
    "filosofou": "filosofar",
    "filosofá": "filosofar",
    "filosofámo": "filosofar",
    "filosofámos": "filosofar",
    "filosofáramo": "filosofar",
    "filosofáramos": "filosofar",
    "filosofárei": "filosofar",
    "filosofáreis": "filosofar",
    "filosofásseis": "filosofar",
    "filosofássemos": "filosofar",
    "filosofávamo": "filosofar",
    "filosofávamos": "filosofar",
    "filosofávei": "filosofar",
    "filosofáveis": "filosofar",
    "filosófica": "filosófico",
    "filosóficas": "filosófico",
    "filosóficos": "filosófico",
    "filotaxias": "filotaxia",
    "filotecnias": "filotecnia",
    "filotimias": "filotimia",
    "filotraqueias": "filotraqueia",
    "filotraqueica": "filotraqueico",
    "filotraqueicas": "filotraqueico",
    "filotraqueicos": "filotraqueico",
    "filotáxica": "filotáxico",
    "filotáxicas": "filotáxico",
    "filotáxicos": "filotáxico",
    "filotécnica": "filotécnico",
    "filotécnicas": "filotécnico",
    "filotécnicos": "filotécnico",
    "filotímica": "filotímico",
    "filotímicas": "filotímico",
    "filotímicos": "filotímico",
    "filou": "filar",
    "filoxantina": "filoxantino",
    "filoxantinas": "filoxantino",
    "filoxantinos": "filoxantino",
    "filoxera": "filoxerar",
    "filoxerada": "filoxerar",
    "filoxeradas": "filoxerar",
    "filoxerado": "filoxerar",
    "filoxerados": "filoxerar",
    "filoxerai": "filoxerar",
    "filoxerais": "filoxerar",
    "filoxeram": "filoxerar",
    "filoxeramo": "filoxerar",
    "filoxeramos": "filoxerar",
    "filoxerando": "filoxerar",
    "filoxerara": "filoxerar",
    "filoxeraram": "filoxerar",
    "filoxeraras": "filoxerar",
    "filoxerardes": "filoxerar",
    "filoxerarei": "filoxerar",
    "filoxerareis": "filoxerar",
    "filoxerarem": "filoxerar",
    "filoxeraremos": "filoxerar",
    "filoxerares": "filoxerar",
    "filoxeraria": "filoxerar",
    "filoxerariam": "filoxerar",
    "filoxerarias": "filoxerar",
    "filoxerarmo": "filoxerar",
    "filoxerarmos": "filoxerar",
    "filoxerará": "filoxerar",
    "filoxerarás": "filoxerar",
    "filoxerarão": "filoxerar",
    "filoxeraríamos": "filoxerar",
    "filoxeraríeis": "filoxerar",
    "filoxeras": "filoxerar",
    "filoxerasse": "filoxerar",
    "filoxerassem": "filoxerar",
    "filoxerasses": "filoxerar",
    "filoxeraste": "filoxerar",
    "filoxerastes": "filoxerar",
    "filoxerava": "filoxerar",
    "filoxeravam": "filoxerar",
    "filoxeravas": "filoxerar",
    "filoxere": "filoxerar",
    "filoxerei": "filoxerar",
    "filoxereis": "filoxerar",
    "filoxerem": "filoxerar",
    "filoxeremo": "filoxerar",
    "filoxeremos": "filoxerar",
    "filoxeres": "filoxerar",
    "filoxericidas": "filoxericida",
    "filoxero": "filoxerar",
    "filoxerou": "filoxerar",
    "filoxerámo": "filoxerar",
    "filoxerámos": "filoxerar",
    "filoxeráramo": "filoxerar",
    "filoxeráramos": "filoxerar",
    "filoxeráreis": "filoxerar",
    "filoxerásseis": "filoxerar",
    "filoxerássemos": "filoxerar",
    "filoxerávamo": "filoxerar",
    "filoxerávamos": "filoxerar",
    "filoxeráveis": "filoxerar",
    "filoxérica": "filoxérico",
    "filoxéricas": "filoxérico",
    "filoxéricos": "filoxérico",
    "filtra": "filtrar",
    "filtrada": "filtrar",
    "filtradas": "filtrar",
    "filtrado": "filtrar",
    "filtradora": "filtrador",
    "filtradoras": "filtrador",
    "filtradores": "filtrador",
    "filtrados": "filtrar",
    "filtragens": "filtragem",
    "filtrai": "filtrar",
    "filtrais": "filtrar",
    "filtram": "filtrar",
    "filtramentos": "filtramento",
    "filtramo": "filtrar",
    "filtramos": "filtrar",
    "filtrando": "filtrar",
    "filtrara": "filtrar",
    "filtraram": "filtrar",
    "filtraras": "filtrar",
    "filtrarde": "filtrar",
    "filtrardes": "filtrar",
    "filtrare": "filtrar",
    "filtrarei": "filtrar",
    "filtrareis": "filtrar",
    "filtrarem": "filtrar",
    "filtraremos": "filtrar",
    "filtrares": "filtrar",
    "filtraria": "filtrar",
    "filtrariam": "filtrar",
    "filtrarias": "filtrar",
    "filtrarmo": "filtrar",
    "filtrarmos": "filtrar",
    "filtrará": "filtrar",
    "filtrarás": "filtrar",
    "filtrarão": "filtrar",
    "filtraríamos": "filtrar",
    "filtraríeis": "filtrar",
    "filtras": "filtrar",
    "filtrasse": "filtrar",
    "filtrassem": "filtrar",
    "filtrasses": "filtrar",
    "filtraste": "filtrar",
    "filtrastes": "filtrar",
    "filtrava": "filtrar",
    "filtravam": "filtrar",
    "filtravas": "filtrar",
    "filtrações": "filtração",
    "filtre": "filtrar",
    "filtrei": "filtrar",
    "filtreiros": "filtreiro",
    "filtreis": "filtrar",
    "filtrem": "filtrar",
    "filtremo": "filtrar",
    "filtremos": "filtrar",
    "filtres": "filtrar",
    "filtro": "filtrar",
    "filtros": "filtro",
    "filtrou": "filtrar",
    "filtrá": "filtrar",
    "filtrámo": "filtrar",
    "filtrámos": "filtrar",
    "filtráramo": "filtrar",
    "filtráramos": "filtrar",
    "filtrárei": "filtrar",
    "filtráreis": "filtrar",
    "filtrásseis": "filtrar",
    "filtrássemos": "filtrar",
    "filtrávamo": "filtrar",
    "filtrávamos": "filtrar",
    "filtrávei": "filtrar",
    "filtráveis": "filtrável",
    "filá": "filar",
    "filádios": "filádio",
    "filámo": "filar",
    "filámos": "filar",
    "filáramo": "filar",
    "filáramos": "filar",
    "filárei": "filar",
    "filáreis": "filar",
    "filárias": "filária",
    "filásseis": "filar",
    "filássemos": "filar",
    "filásticas": "filástica",
    "filáucias": "filáucia",
    "filávamo": "filar",
    "filávamos": "filar",
    "filávei": "filar",
    "filáveis": "filar",
    "filândrica": "filândrico",
    "filândricas": "filândrico",
    "filândricos": "filândrico",
    "filés": "filé",
    "filética": "filético",
    "filéticas": "filético",
    "filéticos": "filético",
    "filípicas": "filípica",
    "filódios": "filódio",
    "filófaga": "filófago",
    "filófagas": "filófago",
    "filófagos": "filófago",
    "filógina": "filógino",
    "filóginas": "filógino",
    "filóginos": "filógino",
    "filóides": "filóide",
    "filóloga": "filólogo",
    "filólogas": "filólogo",
    "filólogos": "filólogo",
    "filónios": "filónio",
    "filópodes": "filópode",
    "filós": "filó",
    "filósofa": "filósofo",
    "filósofas": "filósofo",
    "filósofos": "filósofo",
    "filões": "filão",
    "fimbos": "fimbo",
    "fimbriada": "fimbriado",
    "fimbriadas": "fimbriado",
    "fimbriados": "fimbriado",
    "fimoses": "fimose",
    "fimícolas": "fimícola",
    "fina": "fino",
    "finacistas": "finacista",
    "finada": "finar",
    "finadas": "finar",
    "finado": "finar",
    "finados": "finar",
    "finai": "finar",
    "finais": "finar",
    "finaizinhas": "final",
    "finaizinhos": "final",
    "finaizitas": "final",
    "finaizitos": "final",
    "finalidades": "finalidade",
    "finalismos": "finalismo",
    "finalistas": "finalista",
    "finaliza": "finalizar",
    "finalizada": "finalizar",
    "finalizadas": "finalizar",
    "finalizado": "finalizar",
    "finalizados": "finalizar",
    "finalizai": "finalizar",
    "finalizais": "finalizar",
    "finalizam": "finalizar",
    "finalizamo": "finalizar",
    "finalizamos": "finalizar",
    "finalizando": "finalizar",
    "finalizara": "finalizar",
    "finalizaram": "finalizar",
    "finalizaras": "finalizar",
    "finalizarde": "finalizar",
    "finalizardes": "finalizar",
    "finalizare": "finalizar",
    "finalizarei": "finalizar",
    "finalizareis": "finalizar",
    "finalizarem": "finalizar",
    "finalizaremos": "finalizar",
    "finalizares": "finalizar",
    "finalizaria": "finalizar",
    "finalizariam": "finalizar",
    "finalizarias": "finalizar",
    "finalizarmo": "finalizar",
    "finalizarmos": "finalizar",
    "finalizará": "finalizar",
    "finalizarás": "finalizar",
    "finalizarão": "finalizar",
    "finalizaríamos": "finalizar",
    "finalizaríeis": "finalizar",
    "finalizas": "finalizar",
    "finalizasse": "finalizar",
    "finalizassem": "finalizar",
    "finalizasses": "finalizar",
    "finalizaste": "finalizar",
    "finalizastes": "finalizar",
    "finalizava": "finalizar",
    "finalizavam": "finalizar",
    "finalizavas": "finalizar",
    "finalizações": "finalização",
    "finalize": "finalizar",
    "finalizei": "finalizar",
    "finalizeis": "finalizar",
    "finalizem": "finalizar",
    "finalizemo": "finalizar",
    "finalizemos": "finalizar",
    "finalizes": "finalizar",
    "finalizo": "finalizar",
    "finalizou": "finalizar",
    "finalizá": "finalizar",
    "finalizámo": "finalizar",
    "finalizámos": "finalizar",
    "finalizáramo": "finalizar",
    "finalizáramos": "finalizar",
    "finalizárei": "finalizar",
    "finalizáreis": "finalizar",
    "finalizásseis": "finalizar",
    "finalizássemos": "finalizar",
    "finalizávamo": "finalizar",
    "finalizávamos": "finalizar",
    "finalizávei": "finalizar",
    "finalizáveis": "finalizar",
    "finalzinha": "final",
    "finalzinho": "final",
    "finalzita": "final",
    "finalzito": "final",
    "finalíssimas": "finalíssima",
    "finam": "finar",
    "finamentos": "finamento",
    "finamo": "finar",
    "finamos": "finar",
    "financeira": "financeiro",
    "financeiras": "financeiro",
    "financeiros": "financeiro",
    "financia": "financiar",
    "financiada": "financiar",
    "financiadas": "financiar",
    "financiado": "financiar",
    "financiadora": "financiador",
    "financiadoras": "financiador",
    "financiadores": "financiador",
    "financiados": "financiar",
    "financiai": "financiar",
    "financiais": "financiar",
    "financiam": "financiar",
    "financiamentos": "financiamento",
    "financiamo": "financiar",
    "financiamos": "financiar",
    "financiando": "financiar",
    "financiara": "financiar",
    "financiaram": "financiar",
    "financiaras": "financiar",
    "financiarde": "financiar",
    "financiardes": "financiar",
    "financiare": "financiar",
    "financiarei": "financiar",
    "financiareis": "financiar",
    "financiarem": "financiar",
    "financiaremos": "financiar",
    "financiares": "financiar",
    "financiaria": "financiar",
    "financiariam": "financiar",
    "financiarias": "financiar",
    "financiarmo": "financiar",
    "financiarmos": "financiar",
    "financiará": "financiar",
    "financiarás": "financiar",
    "financiarão": "financiar",
    "financiaríamos": "financiar",
    "financiaríeis": "financiar",
    "financias": "financiar",
    "financiasse": "financiar",
    "financiassem": "financiar",
    "financiasses": "financiar",
    "financiaste": "financiar",
    "financiastes": "financiar",
    "financiava": "financiar",
    "financiavam": "financiar",
    "financiavas": "financiar",
    "financie": "financiar",
    "financiei": "financiar",
    "financieis": "financiar",
    "financiem": "financiar",
    "financiemo": "financiar",
    "financiemos": "financiar",
    "financies": "financiar",
    "financio": "financiar",
    "financiou": "financiar",
    "financistas": "financista",
    "financiá": "financiar",
    "financiámo": "financiar",
    "financiámos": "financiar",
    "financiáramo": "financiar",
    "financiáramos": "financiar",
    "financiárei": "financiar",
    "financiáreis": "financiar",
    "financiásseis": "financiar",
    "financiássemos": "financiar",
    "financiávamo": "financiar",
    "financiávamos": "financiar",
    "financiávei": "financiar",
    "financiáveis": "financiável",
    "finando": "finar",
    "finara": "finar",
    "finaram": "finar",
    "finaras": "finar",
    "finardes": "finar",
    "finarei": "finar",
    "finareis": "finar",
    "finarem": "finar",
    "finaremos": "finar",
    "finares": "finar",
    "finaria": "finar",
    "finariam": "finar",
    "finarias": "finar",
    "finarmo": "finar",
    "finarmos": "finar",
    "finará": "finar",
    "finarás": "finar",
    "finarão": "finar",
    "finaríamos": "finar",
    "finaríeis": "finar",
    "finas": "fino",
    "finasse": "finar",
    "finassem": "finar",
    "finasses": "finar",
    "finaste": "finar",
    "finastes": "finar",
    "finava": "finar",
    "finavam": "finar",
    "finavas": "finar",
    "finazinha": "fino",
    "finazinhas": "fino",
    "finazita": "fino",
    "finazitas": "fino",
    "finca": "fincar",
    "fincada": "fincar",
    "fincadas": "fincar",
    "fincado": "fincar",
    "fincados": "fincar",
    "fincai": "fincar",
    "fincais": "fincar",
    "fincam": "fincar",
    "fincamentos": "fincamento",
    "fincamo": "fincar",
    "fincamos": "fincar",
    "fincando": "fincar",
    "fincara": "fincar",
    "fincaram": "fincar",
    "fincaras": "fincar",
    "fincarde": "fincar",
    "fincardes": "fincar",
    "fincare": "fincar",
    "fincarei": "fincar",
    "fincareis": "fincar",
    "fincarem": "fincar",
    "fincaremos": "fincar",
    "fincares": "fincar",
    "fincaria": "fincar",
    "fincariam": "fincar",
    "fincarias": "fincar",
    "fincarmo": "fincar",
    "fincarmos": "fincar",
    "fincará": "fincar",
    "fincarás": "fincar",
    "fincarão": "fincar",
    "fincaríamos": "fincar",
    "fincaríeis": "fincar",
    "fincas": "fincar",
    "fincasse": "fincar",
    "fincassem": "fincar",
    "fincasses": "fincar",
    "fincaste": "fincar",
    "fincastes": "fincar",
    "fincava": "fincar",
    "fincavam": "fincar",
    "fincavas": "fincar",
    "finco": "fincar",
    "fincou": "fincar",
    "fincá": "fincar",
    "fincámo": "fincar",
    "fincámos": "fincar",
    "fincáramo": "fincar",
    "fincáramos": "fincar",
    "fincárei": "fincar",
    "fincáreis": "fincar",
    "fincásseis": "fincar",
    "fincássemos": "fincar",
    "fincávamo": "fincar",
    "fincávamos": "fincar",
    "fincávei": "fincar",
    "fincáveis": "fincar",
    "fincões": "fincão",
    "finda": "findo",
    "findada": "findar",
    "findadas": "findar",
    "findado": "findar",
    "findadora": "findador",
    "findadoras": "findador",
    "findadores": "findador",
    "findados": "findar",
    "findai": "findar",
    "findais": "findar",
    "findam": "findar",
    "findamo": "findar",
    "findamos": "findar",
    "findando": "findar",
    "findara": "findar",
    "findaram": "findar",
    "findaras": "findar",
    "findarde": "findar",
    "findardes": "findar",
    "findare": "findar",
    "findarei": "findar",
    "findareis": "findar",
    "findarem": "findar",
    "findaremos": "findar",
    "findares": "findar",
    "findaria": "findar",
    "findariam": "findar",
    "findarias": "findar",
    "findarmo": "findar",
    "findarmos": "findar",
    "findará": "findar",
    "findarás": "findar",
    "findarão": "findar",
    "findaríamos": "findar",
    "findaríeis": "findar",
    "findas": "findo",
    "findasse": "findar",
    "findassem": "findar",
    "findasses": "findar",
    "findaste": "findar",
    "findastes": "findar",
    "findava": "findar",
    "findavam": "findar",
    "findavas": "findar",
    "finde": "findar",
    "findei": "findar",
    "findeis": "findar",
    "findem": "findar",
    "findemo": "findar",
    "findemos": "findar",
    "findes": "findar",
    "findo": "findar",
    "findos": "findo",
    "findou": "findar",
    "findá": "findar",
    "findámo": "findar",
    "findámos": "findar",
    "findáramo": "findar",
    "findáramos": "findar",
    "findárei": "findar",
    "findáreis": "findar",
    "findásseis": "findar",
    "findássemos": "findar",
    "findávamo": "findar",
    "findávamos": "findar",
    "findávei": "findar",
    "findáveis": "findável",
    "fine": "finar",
    "finei": "finar",
    "fineis": "finar",
    "finem": "finar",
    "finemo": "finar",
    "finemos": "finar",
    "fines": "finar",
    "finesa": "finês",
    "finesas": "finês",
    "fineses": "finês",
    "finezas": "fineza",
    "finfa": "finfar",
    "finfada": "finfar",
    "finfadas": "finfar",
    "finfado": "finfar",
    "finfados": "finfar",
    "finfai": "finfar",
    "finfais": "finfar",
    "finfam": "finfar",
    "finfamo": "finfar",
    "finfamos": "finfar",
    "finfando": "finfar",
    "finfara": "finfar",
    "finfaram": "finfar",
    "finfaras": "finfar",
    "finfarde": "finfar",
    "finfardes": "finfar",
    "finfare": "finfar",
    "finfarei": "finfar",
    "finfareis": "finfar",
    "finfarem": "finfar",
    "finfaremos": "finfar",
    "finfares": "finfar",
    "finfaria": "finfar",
    "finfariam": "finfar",
    "finfarias": "finfar",
    "finfarmo": "finfar",
    "finfarmos": "finfar",
    "finfará": "finfar",
    "finfarás": "finfar",
    "finfarão": "finfar",
    "finfaríamos": "finfar",
    "finfaríeis": "finfar",
    "finfas": "finfar",
    "finfasse": "finfar",
    "finfassem": "finfar",
    "finfasses": "finfar",
    "finfaste": "finfar",
    "finfastes": "finfar",
    "finfava": "finfar",
    "finfavam": "finfar",
    "finfavas": "finfar",
    "finfe": "finfar",
    "finfei": "finfar",
    "finfeis": "finfar",
    "finfem": "finfar",
    "finfemo": "finfar",
    "finfemos": "finfar",
    "finfes": "finfar",
    "finfo": "finfar",
    "finfou": "finfar",
    "finfá": "finfar",
    "finfámo": "finfar",
    "finfámos": "finfar",
    "finfáramo": "finfar",
    "finfáramos": "finfar",
    "finfárei": "finfar",
    "finfáreis": "finfar",
    "finfásseis": "finfar",
    "finfássemos": "finfar",
    "finfávamo": "finfar",
    "finfávamos": "finfar",
    "finfávei": "finfar",
    "finfáveis": "finfar",
    "finge": "fingir",
    "fingem": "fingir",
    "finges": "fingir",
    "fingi": "fingir",
    "fingia": "fingir",
    "fingiam": "fingir",
    "fingias": "fingir",
    "fingida": "fingir",
    "fingidas": "fingir",
    "fingidiça": "fingidiço",
    "fingidiças": "fingidiço",
    "fingidiços": "fingidiço",
    "fingido": "fingir",
    "fingidora": "fingidor",
    "fingidoras": "fingidor",
    "fingidores": "fingidor",
    "fingidos": "fingir",
    "fingimentos": "fingimento",
    "fingimo": "fingir",
    "fingimos": "fingir",
    "fingindo": "fingir",
    "fingira": "fingir",
    "fingiram": "fingir",
    "fingiras": "fingir",
    "fingirde": "fingir",
    "fingirdes": "fingir",
    "fingire": "fingir",
    "fingirei": "fingir",
    "fingireis": "fingir",
    "fingirem": "fingir",
    "fingiremos": "fingir",
    "fingires": "fingir",
    "fingiria": "fingir",
    "fingiriam": "fingir",
    "fingirias": "fingir",
    "fingirmo": "fingir",
    "fingirmos": "fingir",
    "fingirá": "fingir",
    "fingirás": "fingir",
    "fingirão": "fingir",
    "fingiríamos": "fingir",
    "fingiríeis": "fingir",
    "fingis": "fingir",
    "fingisse": "fingir",
    "fingissem": "fingir",
    "fingisses": "fingir",
    "fingiste": "fingir",
    "fingistes": "fingir",
    "fingiu": "fingir",
    "fingíamo": "fingir",
    "fingíamos": "fingir",
    "fingíei": "fingir",
    "fingíeis": "fingir",
    "fingíramo": "fingir",
    "fingíramos": "fingir",
    "fingírei": "fingir",
    "fingíreis": "fingir",
    "fingísseis": "fingir",
    "fingíssemos": "fingir",
    "fingíveis": "fingível",
    "finidades": "finidade",
    "fininha": "fino",
    "fininhas": "fino",
    "fininho": "fino",
    "fininhos": "fino",
    "finisterras": "finisterra",
    "finita": "fino",
    "finitas": "fino",
    "finito": "fino",
    "finitos": "fino",
    "finitudes": "finitude",
    "finja": "fingir",
    "finjais": "fingir",
    "finjam": "fingir",
    "finjamo": "fingir",
    "finjamos": "fingir",
    "finjas": "fingir",
    "finjo": "fingir",
    "finlandesa": "finlandês",
    "finlandesas": "finlandês",
    "finlandeses": "finlandês",
    "fino": "finar",
    "finos": "fino",
    "finou": "finar",
    "finozinho": "fino",
    "finozinhos": "fino",
    "finozito": "fino",
    "finozitos": "fino",
    "finque": "fincar",
    "finquei": "fincar",
    "finqueis": "fincar",
    "finquem": "fincar",
    "finquemo": "fincar",
    "finquemos": "fincar",
    "finques": "fincar",
    "fins": "fim",
    "finta": "finto",
    "fintada": "fintar",
    "fintadas": "fintar",
    "fintado": "fintar",
    "fintados": "fintar",
    "fintai": "fintar",
    "fintais": "fintar",
    "fintam": "fintar",
    "fintamo": "fintar",
    "fintamos": "fintar",
    "fintando": "fintar",
    "fintara": "fintar",
    "fintaram": "fintar",
    "fintaras": "fintar",
    "fintarde": "fintar",
    "fintardes": "fintar",
    "fintare": "fintar",
    "fintarei": "fintar",
    "fintareis": "fintar",
    "fintarem": "fintar",
    "fintaremos": "fintar",
    "fintares": "fintar",
    "fintaria": "fintar",
    "fintariam": "fintar",
    "fintarias": "fintar",
    "fintarmo": "fintar",
    "fintarmos": "fintar",
    "fintará": "fintar",
    "fintarás": "fintar",
    "fintarão": "fintar",
    "fintaríamos": "fintar",
    "fintaríeis": "fintar",
    "fintas": "finto",
    "fintasse": "fintar",
    "fintassem": "fintar",
    "fintasses": "fintar",
    "fintaste": "fintar",
    "fintastes": "fintar",
    "fintava": "fintar",
    "fintavam": "fintar",
    "fintavas": "fintar",
    "finte": "fintar",
    "fintei": "fintar",
    "finteis": "fintar",
    "fintem": "fintar",
    "fintemo": "fintar",
    "fintemos": "fintar",
    "fintes": "fintar",
    "finto": "fintar",
    "fintos": "finto",
    "fintou": "fintar",
    "fintá": "fintar",
    "fintámo": "fintar",
    "fintámos": "fintar",
    "fintáramo": "fintar",
    "fintáramos": "fintar",
    "fintárei": "fintar",
    "fintáreis": "fintar",
    "fintásseis": "fintar",
    "fintássemos": "fintar",
    "fintávamo": "fintar",
    "fintávamos": "fintar",
    "fintávei": "fintar",
    "fintáveis": "fintar",
    "finuras": "finura",
    "finámo": "finar",
    "finámos": "finar",
    "fináramo": "finar",
    "fináramos": "finar",
    "fináreis": "finar",
    "finásseis": "finar",
    "finássemos": "finar",
    "finávamo": "finar",
    "finávamos": "finar",
    "fináveis": "finar",
    "finíssima": "fino",
    "finíssimas": "fino",
    "finíssimo": "fino",
    "finíssimos": "fino",
    "finítima": "finítimo",
    "finítimas": "finítimo",
    "finítimos": "finítimo",
    "finória": "finório",
    "finórias": "finório",
    "finórios": "finório",
    "fio": "fiar",
    "fiolhais": "fiolhal",
    "fiolhos": "fiolho",
    "fiomeles": "fiomel",
    "fiordes": "fiorde",
    "fiorites": "fiorite",
    "fiorítica": "fiorítico",
    "fioríticas": "fiorítico",
    "fioríticos": "fiorítico",
    "fios": "fio",
    "fiou": "fiar",
    "fiozinho": "fio",
    "fiozinhos": "fio",
    "fiozito": "fio",
    "fiozitos": "fio",
    "fipêndulas": "fipêndula",
    "fique": "ficar",
    "fiquei": "ficar",
    "fiqueis": "ficar",
    "fiquem": "ficar",
    "fiquemos": "ficar",
    "fiques": "ficar",
    "fira": "ferir",
    "firais": "ferir",
    "firam": "ferir",
    "firamo": "ferir",
    "firamos": "ferir",
    "firas": "ferir",
    "firma": "firmar",
    "firmada": "firmar",
    "firmadas": "firmar",
    "firmado": "firmar",
    "firmadora": "firmador",
    "firmadoras": "firmador",
    "firmadores": "firmador",
    "firmados": "firmar",
    "firmai": "firmar",
    "firmais": "firmar",
    "firmam": "firmar",
    "firmamentaa": "firmamentao",
    "firmamentaas": "firmamentao",
    "firmamentaos": "firmamentao",
    "firmamentos": "firmamento",
    "firmamo": "firmar",
    "firmamos": "firmar",
    "firmando": "firmar",
    "firmara": "firmar",
    "firmaram": "firmar",
    "firmaras": "firmar",
    "firmarde": "firmar",
    "firmardes": "firmar",
    "firmare": "firmar",
    "firmarei": "firmar",
    "firmareis": "firmar",
    "firmarem": "firmar",
    "firmaremos": "firmar",
    "firmares": "firmar",
    "firmaria": "firmar",
    "firmariam": "firmar",
    "firmarias": "firmar",
    "firmarmo": "firmar",
    "firmarmos": "firmar",
    "firmará": "firmar",
    "firmarás": "firmar",
    "firmarão": "firmar",
    "firmaríamos": "firmar",
    "firmaríeis": "firmar",
    "firmas": "firmar",
    "firmasse": "firmar",
    "firmassem": "firmar",
    "firmasses": "firmar",
    "firmaste": "firmar",
    "firmastes": "firmar",
    "firmava": "firmar",
    "firmavam": "firmar",
    "firmavas": "firmar",
    "firmações": "firmação",
    "firme": "firmar",
    "firmei": "firmar",
    "firmeis": "firmar",
    "firmem": "firmar",
    "firmemo": "firmar",
    "firmemos": "firmar",
    "firmes": "firme",
    "firmezas": "firmeza",
    "firmidões": "firmidão",
    "firmo": "firmar",
    "firmou": "firmar",
    "firmá": "firmar",
    "firmámo": "firmar",
    "firmámos": "firmar",
    "firmáramo": "firmar",
    "firmáramos": "firmar",
    "firmárei": "firmar",
    "firmáreis": "firmar",
    "firmásseis": "firmar",
    "firmássemos": "firmar",
    "firmávamo": "firmar",
    "firmávamos": "firmar",
    "firmávei": "firmar",
    "firmáveis": "firmar",
    "firmãs": "firmã",
    "firmões": "firmão",
    "firo": "ferir",
    "fiscais": "fiscal",
    "fiscalidades": "fiscalidade",
    "fiscalistas": "fiscalista",
    "fiscaliza": "fiscalizar",
    "fiscalizada": "fiscalizar",
    "fiscalizadas": "fiscalizar",
    "fiscalizado": "fiscalizar",
    "fiscalizadora": "fiscalizador",
    "fiscalizadoras": "fiscalizador",
    "fiscalizadores": "fiscalizador",
    "fiscalizados": "fiscalizar",
    "fiscalizai": "fiscalizar",
    "fiscalizais": "fiscalizar",
    "fiscalizam": "fiscalizar",
    "fiscalizamo": "fiscalizar",
    "fiscalizamos": "fiscalizar",
    "fiscalizando": "fiscalizar",
    "fiscalizara": "fiscalizar",
    "fiscalizaram": "fiscalizar",
    "fiscalizaras": "fiscalizar",
    "fiscalizarde": "fiscalizar",
    "fiscalizardes": "fiscalizar",
    "fiscalizare": "fiscalizar",
    "fiscalizarei": "fiscalizar",
    "fiscalizareis": "fiscalizar",
    "fiscalizarem": "fiscalizar",
    "fiscalizaremos": "fiscalizar",
    "fiscalizares": "fiscalizar",
    "fiscalizaria": "fiscalizar",
    "fiscalizariam": "fiscalizar",
    "fiscalizarias": "fiscalizar",
    "fiscalizarmo": "fiscalizar",
    "fiscalizarmos": "fiscalizar",
    "fiscalizará": "fiscalizar",
    "fiscalizarás": "fiscalizar",
    "fiscalizarão": "fiscalizar",
    "fiscalizaríamos": "fiscalizar",
    "fiscalizaríeis": "fiscalizar",
    "fiscalizas": "fiscalizar",
    "fiscalizasse": "fiscalizar",
    "fiscalizassem": "fiscalizar",
    "fiscalizasses": "fiscalizar",
    "fiscalizaste": "fiscalizar",
    "fiscalizastes": "fiscalizar",
    "fiscalizava": "fiscalizar",
    "fiscalizavam": "fiscalizar",
    "fiscalizavas": "fiscalizar",
    "fiscalizações": "fiscalização",
    "fiscalize": "fiscalizar",
    "fiscalizei": "fiscalizar",
    "fiscalizeis": "fiscalizar",
    "fiscalizem": "fiscalizar",
    "fiscalizemo": "fiscalizar",
    "fiscalizemos": "fiscalizar",
    "fiscalizes": "fiscalizar",
    "fiscalizo": "fiscalizar",
    "fiscalizou": "fiscalizar",
    "fiscalizá": "fiscalizar",
    "fiscalizámo": "fiscalizar",
    "fiscalizámos": "fiscalizar",
    "fiscalizáramo": "fiscalizar",
    "fiscalizáramos": "fiscalizar",
    "fiscalizárei": "fiscalizar",
    "fiscalizáreis": "fiscalizar",
    "fiscalizásseis": "fiscalizar",
    "fiscalizássemos": "fiscalizar",
    "fiscalizávamo": "fiscalizar",
    "fiscalizávamos": "fiscalizar",
    "fiscalizávei": "fiscalizar",
    "fiscalizáveis": "fiscalizável",
    "fiscelas": "fiscela",
    "fisemas": "fisema",
    "fisga": "fisgar",
    "fisgada": "fisgar",
    "fisgadas": "fisgar",
    "fisgadelas": "fisgadela",
    "fisgado": "fisgar",
    "fisgadora": "fisgador",
    "fisgadoras": "fisgador",
    "fisgadores": "fisgador",
    "fisgados": "fisgar",
    "fisgai": "fisgar",
    "fisgais": "fisgar",
    "fisgam": "fisgar",
    "fisgamo": "fisgar",
    "fisgamos": "fisgar",
    "fisgando": "fisgar",
    "fisgara": "fisgar",
    "fisgaram": "fisgar",
    "fisgaras": "fisgar",
    "fisgarde": "fisgar",
    "fisgardes": "fisgar",
    "fisgare": "fisgar",
    "fisgarei": "fisgar",
    "fisgareis": "fisgar",
    "fisgarem": "fisgar",
    "fisgaremos": "fisgar",
    "fisgares": "fisgar",
    "fisgaria": "fisgar",
    "fisgariam": "fisgar",
    "fisgarias": "fisgar",
    "fisgarmo": "fisgar",
    "fisgarmos": "fisgar",
    "fisgará": "fisgar",
    "fisgarás": "fisgar",
    "fisgarão": "fisgar",
    "fisgaríamos": "fisgar",
    "fisgaríeis": "fisgar",
    "fisgas": "fisgar",
    "fisgasse": "fisgar",
    "fisgassem": "fisgar",
    "fisgasses": "fisgar",
    "fisgaste": "fisgar",
    "fisgastes": "fisgar",
    "fisgava": "fisgar",
    "fisgavam": "fisgar",
    "fisgavas": "fisgar",
    "fisgo": "fisgar",
    "fisgou": "fisgar",
    "fisgue": "fisgar",
    "fisguei": "fisgar",
    "fisgueis": "fisgar",
    "fisguem": "fisgar",
    "fisguemo": "fisgar",
    "fisguemos": "fisgar",
    "fisgues": "fisgar",
    "fisgá": "fisgar",
    "fisgámo": "fisgar",
    "fisgámos": "fisgar",
    "fisgáramo": "fisgar",
    "fisgáramos": "fisgar",
    "fisgárei": "fisgar",
    "fisgáreis": "fisgar",
    "fisgásseis": "fisgar",
    "fisgássemos": "fisgar",
    "fisgávamo": "fisgar",
    "fisgávamos": "fisgar",
    "fisgávei": "fisgar",
    "fisgáveis": "fisgar",
    "fisiatras": "fisiatra",
    "fisicalidades": "fisicalidade",
    "fisicalismos": "fisicalismo",
    "fisicalistas": "fisicalista",
    "fisicismos": "fisicismo",
    "fisicistas": "fisicista",
    "fisicoterapêutica": "fisicoterapêutico",
    "fisicoterapêuticas": "fisicoterapêutico",
    "fisicoterapêuticos": "fisicoterapêutico",
    "fisicoterápica": "fisicoterápico",
    "fisicoterápicas": "fisicoterápico",
    "fisicoterápicos": "fisicoterápico",
    "fisidáctilos": "fisidáctilo",
    "fisiocracias": "fisiocracia",
    "fisiocratas": "fisiocrata",
    "fisiocratismos": "fisiocratismo",
    "fisiocrática": "fisiocrático",
    "fisiocráticas": "fisiocrático",
    "fisiocráticos": "fisiocrático",
    "fisiogenesias": "fisiogenesia",
    "fisiogenias": "fisiogenia",
    "fisiogenésica": "fisiogenésico",
    "fisiogenésicas": "fisiogenésico",
    "fisiogenésicos": "fisiogenésico",
    "fisiogenética": "fisiogenético",
    "fisiogenéticas": "fisiogenético",
    "fisiogenéticos": "fisiogenético",
    "fisioginias": "fisioginia",
    "fisiognomonias": "fisiognomonia",
    "fisiognomonistas": "fisiognomonista",
    "fisiografias": "fisiografia",
    "fisiográfica": "fisiográfico",
    "fisiográficas": "fisiográfico",
    "fisiográficos": "fisiográfico",
    "fisiogéneses": "fisiogénese",
    "fisiogénica": "fisiogénico",
    "fisiogénicas": "fisiogénico",
    "fisiogénicos": "fisiogénico",
    "fisiogínica": "fisiogínico",
    "fisiogínicas": "fisiogínico",
    "fisiogínicos": "fisiogínico",
    "fisiogónica": "fisiogónico",
    "fisiogónicas": "fisiogónico",
    "fisiogónicos": "fisiogónico",
    "fisiologias": "fisiologia",
    "fisiologistas": "fisiologista",
    "fisiológica": "fisiológico",
    "fisiológicas": "fisiológico",
    "fisiológicos": "fisiológico",
    "fisionomias": "fisionomia",
    "fisionomistas": "fisionomista",
    "fisionómica": "fisionómico",
    "fisionómicas": "fisionómico",
    "fisionómicos": "fisionómico",
    "fisiopatias": "fisiopatia",
    "fisiopatologias": "fisiopatologia",
    "fisiopatologistas": "fisiopatologista",
    "fisiopatológica": "fisiopatológico",
    "fisiopatológicas": "fisiopatológico",
    "fisiopatológicos": "fisiopatológico",
    "fisioplastas": "fisioplasta",
    "fisioplastias": "fisioplastia",
    "fisiopsicologias": "fisiopsicologia",
    "fisiopsicologistas": "fisiopsicologista",
    "fisiopsicológica": "fisiopsicológico",
    "fisiopsicológicas": "fisiopsicológico",
    "fisiopsicológicos": "fisiopsicológico",
    "fisiopática": "fisiopático",
    "fisiopáticas": "fisiopático",
    "fisiopáticos": "fisiopático",
    "fisioterapeutas": "fisioterapeuta",
    "fisioterapias": "fisioterapia",
    "fisioterapistas": "fisioterapista",
    "fisioterapêutica": "fisioterapêutico",
    "fisioterapêuticas": "fisioterapêutico",
    "fisioterapêuticos": "fisioterapêutico",
    "fisioterápica": "fisioterápico",
    "fisioterápicas": "fisioterápico",
    "fisioterápicos": "fisioterápico",
    "fisióloga": "fisiólogo",
    "fisiólogas": "fisiólogo",
    "fisiólogos": "fisiólogo",
    "fisoplástica": "fisoplástico",
    "fisoplásticas": "fisoplástico",
    "fisoplásticos": "fisoplástico",
    "fissibilidades": "fissibilidade",
    "fissidentáceas": "fissidentácea",
    "fissidáctila": "fissidáctilo",
    "fissidáctilas": "fissidáctilo",
    "fissidáctilos": "fissidáctilo",
    "fissiflora": "fissifloro",
    "fissifloras": "fissifloro",
    "fissifloros": "fissifloro",
    "fissiformes": "fissiforme",
    "fissilingues": "fissilingue",
    "fissiparidades": "fissiparidade",
    "fissipenes": "fissipene",
    "fissirrostra": "fissirrostro",
    "fissirrostras": "fissirrostro",
    "fissirrostros": "fissirrostro",
    "fissura": "fissurar",
    "fissurada": "fissurar",
    "fissuradas": "fissurar",
    "fissurado": "fissurar",
    "fissurados": "fissurar",
    "fissurai": "fissurar",
    "fissurais": "fissurar",
    "fissuram": "fissurar",
    "fissuramentos": "fissuramento",
    "fissuramo": "fissurar",
    "fissuramos": "fissurar",
    "fissurando": "fissurar",
    "fissurara": "fissurar",
    "fissuraram": "fissurar",
    "fissuraras": "fissurar",
    "fissurarde": "fissurar",
    "fissurardes": "fissurar",
    "fissurare": "fissurar",
    "fissurarei": "fissurar",
    "fissurareis": "fissurar",
    "fissurarem": "fissurar",
    "fissuraremos": "fissurar",
    "fissurares": "fissurar",
    "fissuraria": "fissurar",
    "fissurariam": "fissurar",
    "fissurarias": "fissurar",
    "fissurarmo": "fissurar",
    "fissurarmos": "fissurar",
    "fissurará": "fissurar",
    "fissurarás": "fissurar",
    "fissurarão": "fissurar",
    "fissuraríamos": "fissurar",
    "fissuraríeis": "fissurar",
    "fissuras": "fissurar",
    "fissurasse": "fissurar",
    "fissurassem": "fissurar",
    "fissurasses": "fissurar",
    "fissuraste": "fissurar",
    "fissurastes": "fissurar",
    "fissurava": "fissurar",
    "fissuravam": "fissurar",
    "fissuravas": "fissurar",
    "fissurações": "fissuração",
    "fissure": "fissurar",
    "fissurei": "fissurar",
    "fissureis": "fissurar",
    "fissurem": "fissurar",
    "fissuremo": "fissurar",
    "fissuremos": "fissurar",
    "fissures": "fissurar",
    "fissuro": "fissurar",
    "fissurou": "fissurar",
    "fissurá": "fissurar",
    "fissurámo": "fissurar",
    "fissurámos": "fissurar",
    "fissuráramo": "fissurar",
    "fissuráramos": "fissurar",
    "fissurárei": "fissurar",
    "fissuráreis": "fissurar",
    "fissurásseis": "fissurar",
    "fissurássemos": "fissurar",
    "fissurávamo": "fissurar",
    "fissurávamos": "fissurar",
    "fissurávei": "fissurar",
    "fissuráveis": "fissurável",
    "fissípara": "fissíparo",
    "fissíparas": "fissíparo",
    "fissíparos": "fissíparo",
    "fissípedes": "fissípede",
    "fissírrostros": "fissírrostro",
    "fissíveis": "fissível",
    "fissões": "fissão",
    "fistora": "fistor",
    "fistoras": "fistor",
    "fistores": "fistor",
    "fistula": "fistular",
    "fistulada": "fistular",
    "fistuladas": "fistular",
    "fistulado": "fistular",
    "fistulados": "fistular",
    "fistulai": "fistular",
    "fistulais": "fistular",
    "fistulam": "fistular",
    "fistulamo": "fistular",
    "fistulamos": "fistular",
    "fistulando": "fistular",
    "fistulara": "fistular",
    "fistularam": "fistular",
    "fistularas": "fistular",
    "fistulardes": "fistular",
    "fistularei": "fistular",
    "fistulareis": "fistular",
    "fistularem": "fistular",
    "fistularemos": "fistular",
    "fistulares": "fistular",
    "fistularia": "fistular",
    "fistulariam": "fistular",
    "fistularias": "fistular",
    "fistularmo": "fistular",
    "fistularmos": "fistular",
    "fistulará": "fistular",
    "fistularás": "fistular",
    "fistularão": "fistular",
    "fistularíamos": "fistular",
    "fistularíeis": "fistular",
    "fistulas": "fistular",
    "fistulasse": "fistular",
    "fistulassem": "fistular",
    "fistulasses": "fistular",
    "fistulaste": "fistular",
    "fistulastes": "fistular",
    "fistulava": "fistular",
    "fistulavam": "fistular",
    "fistulavas": "fistular",
    "fistule": "fistular",
    "fistulei": "fistular",
    "fistuleis": "fistular",
    "fistulem": "fistular",
    "fistulemo": "fistular",
    "fistulemos": "fistular",
    "fistules": "fistular",
    "fistulices": "fistulice",
    "fistulizações": "fistulização",
    "fistulo": "fistular",
    "fistulosa": "fistuloso",
    "fistulosas": "fistuloso",
    "fistulosos": "fistuloso",
    "fistulou": "fistular",
    "fistulámo": "fistular",
    "fistulámos": "fistular",
    "fistuláramo": "fistular",
    "fistuláramos": "fistular",
    "fistuláreis": "fistular",
    "fistulásseis": "fistular",
    "fistulássemos": "fistular",
    "fistulávamo": "fistular",
    "fistulávamos": "fistular",
    "fistuláveis": "fistular",
    "fita": "fito",
    "fitada": "fitar",
    "fitadas": "fitar",
    "fitado": "fitar",
    "fitados": "fitar",
    "fitai": "fitar",
    "fitais": "fitar",
    "fitam": "fitar",
    "fitamo": "fitar",
    "fitamos": "fitar",
    "fitando": "fitar",
    "fitara": "fitar",
    "fitaram": "fitar",
    "fitaras": "fitar",
    "fitarde": "fitar",
    "fitardes": "fitar",
    "fitare": "fitar",
    "fitarei": "fitar",
    "fitareis": "fitar",
    "fitarem": "fitar",
    "fitaremos": "fitar",
    "fitares": "fitar",
    "fitaria": "fitar",
    "fitariam": "fitar",
    "fitarias": "fitaria",
    "fitarmo": "fitar",
    "fitarmos": "fitar",
    "fitará": "fitar",
    "fitarás": "fitar",
    "fitarão": "fitar",
    "fitaríamos": "fitar",
    "fitaríeis": "fitar",
    "fitas": "fito",
    "fitasse": "fitar",
    "fitassem": "fitar",
    "fitasses": "fitar",
    "fitaste": "fitar",
    "fitastes": "fitar",
    "fitava": "fitar",
    "fitavam": "fitar",
    "fitavas": "fitar",
    "fite": "fitar",
    "fitei": "fitar",
    "fiteira": "fiteiro",
    "fiteiras": "fiteiro",
    "fiteiros": "fiteiro",
    "fiteis": "fitar",
    "fitem": "fitar",
    "fitemo": "fitar",
    "fitemos": "fitar",
    "fites": "fitar",
    "fitilhas": "fitilha",
    "fitilhos": "fitilho",
    "fitinas": "fitina",
    "fitinha": "fita",
    "fitinhas": "fita",
    "fitita": "fita",
    "fititas": "fita",
    "fito": "fitar",
    "fitobiologias": "fitobiologia",
    "fitobiologistas": "fitobiologista",
    "fitobiológica": "fitobiológico",
    "fitobiológicas": "fitobiológico",
    "fitobiológicos": "fitobiológico",
    "fitobióloga": "fitobiólogo",
    "fitobiólogas": "fitobiólogo",
    "fitobiólogos": "fitobiólogo",
    "fitocecídia": "fitocecídio",
    "fitocecídias": "fitocecídio",
    "fitocecídios": "fitocecídio",
    "fitoclorinas": "fitoclorina",
    "fitoclorínica": "fitoclorínico",
    "fitoclorínicas": "fitoclorínico",
    "fitoclorínicos": "fitoclorínico",
    "fitofágica": "fitofágico",
    "fitofágicas": "fitofágico",
    "fitofágicos": "fitofágico",
    "fitogenias": "fitogenia",
    "fitogenésica": "fitogenésico",
    "fitogenésicas": "fitogenésico",
    "fitogenésicos": "fitogenésico",
    "fitogenética": "fitogenético",
    "fitogenéticas": "fitogenético",
    "fitogenéticos": "fitogenético",
    "fitogeografias": "fitogeografia",
    "fitogeográfica": "fitogeográfico",
    "fitogeográficas": "fitogeográfico",
    "fitogeográficos": "fitogeográfico",
    "fitogeógrafa": "fitogeógrafo",
    "fitogeógrafas": "fitogeógrafo",
    "fitogeógrafos": "fitogeógrafo",
    "fitografias": "fitografia",
    "fitográfica": "fitográfico",
    "fitográficas": "fitográfico",
    "fitográficos": "fitográfico",
    "fitogénea": "fitogéneo",
    "fitogéneas": "fitogéneo",
    "fitogéneos": "fitogéneo",
    "fitogénica": "fitogénico",
    "fitogénicas": "fitogénico",
    "fitogénicos": "fitogénico",
    "fitogínica": "fitogínico",
    "fitogínicas": "fitogínico",
    "fitogínicos": "fitogínico",
    "fitolacácea": "fitolacáceo",
    "fitolacáceas": "fitolacáceo",
    "fitolacáceos": "fitolacáceo",
    "fitologias": "fitologia",
    "fitologistas": "fitologista",
    "fitológica": "fitológico",
    "fitológicas": "fitológico",
    "fitológicos": "fitológico",
    "fitonomias": "fitonomia",
    "fitonomistas": "fitonomista",
    "fitonoses": "fitonose",
    "fitonímias": "fitonímia",
    "fitonímica": "fitonímico",
    "fitonímicas": "fitonímico",
    "fitonímicos": "fitonímico",
    "fitonótica": "fitonótico",
    "fitonóticas": "fitonótico",
    "fitonóticos": "fitonótico",
    "fitoparasitas": "fitoparasita",
    "fitoparasitismos": "fitoparasitismo",
    "fitoparasitos": "fitoparasito",
    "fitoparasitária": "fitoparasitário",
    "fitoparasitárias": "fitoparasitário",
    "fitoparasitários": "fitoparasitário",
    "fitopatologias": "fitopatologia",
    "fitopatologistas": "fitopatologista",
    "fitopatológica": "fitopatológico",
    "fitopatológicas": "fitopatológico",
    "fitopatológicos": "fitopatológico",
    "fitoquímica": "fitoquímico",
    "fitoquímicas": "fitoquímico",
    "fitoquímicos": "fitoquímico",
    "fitos": "fito",
    "fitotaxias": "fitotaxia",
    "fitotecas": "fitoteca",
    "fitotecnias": "fitotecnia",
    "fitotomias": "fitotomia",
    "fitotáxica": "fitotáxico",
    "fitotáxicas": "fitotáxico",
    "fitotáxicos": "fitotáxico",
    "fitotécnica": "fitotécnico",
    "fitotécnicas": "fitotécnico",
    "fitotécnicos": "fitotécnico",
    "fitotómica": "fitotómico",
    "fitotómicas": "fitotómico",
    "fitotómicos": "fitotómico",
    "fitou": "fitar",
    "fitozoária": "fitozoário",
    "fitozoárias": "fitozoário",
    "fitozoárica": "fitozoárico",
    "fitozoáricas": "fitozoárico",
    "fitozoáricos": "fitozoárico",
    "fitozoários": "fitozoário",
    "fitá": "fitar",
    "fitácea": "fitáceo",
    "fitáceas": "fitáceo",
    "fitáceos": "fitáceo",
    "fitámo": "fitar",
    "fitámos": "fitar",
    "fitáramo": "fitar",
    "fitáramos": "fitar",
    "fitárei": "fitar",
    "fitáreis": "fitar",
    "fitásseis": "fitar",
    "fitássemos": "fitar",
    "fitávamo": "fitar",
    "fitávamos": "fitar",
    "fitávei": "fitar",
    "fitáveis": "fitar",
    "fitínica": "fitínico",
    "fitínicas": "fitínico",
    "fitínicos": "fitínico",
    "fitófaga": "fitófago",
    "fitófagas": "fitófago",
    "fitófagos": "fitófago",
    "fitógrafa": "fitógrafo",
    "fitógrafas": "fitógrafo",
    "fitógrafos": "fitógrafo",
    "fitóides": "fitóide",
    "fitólitos": "fitólito",
    "fitóloga": "fitólogo",
    "fitólogas": "fitólogo",
    "fitólogos": "fitólogo",
    "fitónima": "fitónimo",
    "fitónimas": "fitónimo",
    "fitónimos": "fitónimo",
    "fiuncos": "fiunco",
    "fivelas": "fivela",
    "fiveletas": "fiveleta",
    "fivelinha": "fivela",
    "fivelinhas": "fivela",
    "fivelita": "fivela",
    "fivelitas": "fivela",
    "fixa": "fixo",
    "fixada": "fixar",
    "fixadas": "fixar",
    "fixado": "fixar",
    "fixadora": "fixador",
    "fixadoras": "fixador",
    "fixadores": "fixador",
    "fixados": "fixar",
    "fixagens": "fixagem",
    "fixai": "fixar",
    "fixais": "fixar",
    "fixam": "fixar",
    "fixamo": "fixar",
    "fixamos": "fixar",
    "fixando": "fixar",
    "fixantes": "fixante",
    "fixara": "fixar",
    "fixaram": "fixar",
    "fixaras": "fixar",
    "fixarde": "fixar",
    "fixardes": "fixar",
    "fixare": "fixar",
    "fixarei": "fixar",
    "fixareis": "fixar",
    "fixarem": "fixar",
    "fixaremos": "fixar",
    "fixares": "fixar",
    "fixaria": "fixar",
    "fixariam": "fixar",
    "fixarias": "fixar",
    "fixarmo": "fixar",
    "fixarmos": "fixar",
    "fixará": "fixar",
    "fixarás": "fixar",
    "fixarão": "fixar",
    "fixaríamos": "fixar",
    "fixaríeis": "fixar",
    "fixas": "fixo",
    "fixasse": "fixar",
    "fixassem": "fixar",
    "fixasses": "fixar",
    "fixaste": "fixar",
    "fixastes": "fixar",
    "fixativa": "fixativo",
    "fixativas": "fixativo",
    "fixativos": "fixativo",
    "fixava": "fixar",
    "fixavam": "fixar",
    "fixavas": "fixar",
    "fixações": "fixação",
    "fixe": "fixar",
    "fixei": "fixar",
    "fixeis": "fixar",
    "fixem": "fixar",
    "fixemo": "fixar",
    "fixemos": "fixar",
    "fixes": "fixe",
    "fixidades": "fixidade",
    "fixismos": "fixismo",
    "fixistas": "fixista",
    "fixo": "fixar",
    "fixos": "fixo",
    "fixou": "fixar",
    "fixuras": "fixura",
    "fixá": "fixar",
    "fixámo": "fixar",
    "fixámos": "fixar",
    "fixáramo": "fixar",
    "fixáramos": "fixar",
    "fixárei": "fixar",
    "fixáreis": "fixar",
    "fixásseis": "fixar",
    "fixássemos": "fixar",
    "fixávamo": "fixar",
    "fixávamos": "fixar",
    "fixávei": "fixar",
    "fixáveis": "fixar",
    "fiz": "fazer",
    "fizemo": "fazer",
    "fizemos": "fazer",
    "fizer": "fazer",
    "fizera": "fazer",
    "fizeram": "fazer",
    "fizeras": "fazer",
    "fizerdes": "fazer",
    "fizerem": "fazer",
    "fizeres": "fazer",
    "fizermos": "fazer",
    "fizesse": "fazer",
    "fizessem": "fazer",
    "fizesses": "fazer",
    "fizeste": "fazer",
    "fizestes": "fazer",
    "fizéramo": "fazer",
    "fizéramos": "fazer",
    "fizérei": "fazer",
    "fizéreis": "fazer",
    "fizésseis": "fazer",
    "fizéssemos": "fazer",
    "fiá": "fiar",
    "fiámo": "fiar",
    "fiámos": "fiar",
    "fiáramo": "fiar",
    "fiáramos": "fiar",
    "fiárei": "fiar",
    "fiáreis": "fiar",
    "fiásseis": "fiar",
    "fiássemos": "fiar",
    "fiávamo": "fiar",
    "fiávamos": "fiar",
    "fiávei": "fiar",
    "fiáveis": "fiável",
    "fiãs": "fiã",
    "fiéis": "fiel",
    "fiótica": "fiótico",
    "fióticas": "fiótico",
    "fióticos": "fiótico",
    "fiúza": "fiúzo",
    "fiúzas": "fiúzo",
    "fiúzos": "fiúzo",
    "flabela": "flabelar",
    "flabelada": "flabelar",
    "flabeladas": "flabelar",
    "flabelado": "flabelar",
    "flabelados": "flabelar",
    "flabelai": "flabelar",
    "flabelais": "flabelar",
    "flabelam": "flabelar",
    "flabelamo": "flabelar",
    "flabelamos": "flabelar",
    "flabelando": "flabelar",
    "flabelara": "flabelar",
    "flabelaram": "flabelar",
    "flabelaras": "flabelar",
    "flabelardes": "flabelar",
    "flabelarei": "flabelar",
    "flabelareis": "flabelar",
    "flabelarem": "flabelar",
    "flabelaremos": "flabelar",
    "flabelares": "flabelar",
    "flabelaria": "flabelar",
    "flabelariam": "flabelar",
    "flabelarias": "flabelar",
    "flabelarmo": "flabelar",
    "flabelarmos": "flabelar",
    "flabelará": "flabelar",
    "flabelarás": "flabelar",
    "flabelarão": "flabelar",
    "flabelaríamos": "flabelar",
    "flabelaríeis": "flabelar",
    "flabelas": "flabelar",
    "flabelasse": "flabelar",
    "flabelassem": "flabelar",
    "flabelasses": "flabelar",
    "flabelaste": "flabelar",
    "flabelastes": "flabelar",
    "flabelava": "flabelar",
    "flabelavam": "flabelar",
    "flabelavas": "flabelar",
    "flabelações": "flabelação",
    "flabele": "flabelar",
    "flabelei": "flabelar",
    "flabeleis": "flabelar",
    "flabelem": "flabelar",
    "flabelemo": "flabelar",
    "flabelemos": "flabelar",
    "flabeles": "flabelar",
    "flabelifoliada": "flabelifoliado",
    "flabelifoliadas": "flabelifoliado",
    "flabelifoliados": "flabelifoliado",
    "flabeliformes": "flabeliforme",
    "flabelo": "flabelar",
    "flabelos": "flabelo",
    "flabelou": "flabelar",
    "flabelámo": "flabelar",
    "flabelámos": "flabelar",
    "flabeláramo": "flabelar",
    "flabeláramos": "flabelar",
    "flabeláreis": "flabelar",
    "flabelásseis": "flabelar",
    "flabelássemos": "flabelar",
    "flabelávamo": "flabelar",
    "flabelávamos": "flabelar",
    "flabeláveis": "flabelar",
    "flabelífera": "flabelífero",
    "flabelíferas": "flabelífero",
    "flabelíferos": "flabelífero",
    "flabelípedes": "flabelípede",
    "flagela": "flagelar",
    "flagelada": "flagelar",
    "flageladas": "flagelar",
    "flagelado": "flagelar",
    "flagelados": "flagelar",
    "flagelai": "flagelar",
    "flagelais": "flagelar",
    "flagelam": "flagelar",
    "flagelamentos": "flagelamento",
    "flagelamo": "flagelar",
    "flagelamos": "flagelar",
    "flagelando": "flagelar",
    "flagelantes": "flagelante",
    "flagelara": "flagelar",
    "flagelaram": "flagelar",
    "flagelaras": "flagelar",
    "flagelarde": "flagelar",
    "flagelardes": "flagelar",
    "flagelare": "flagelar",
    "flagelarei": "flagelar",
    "flagelareis": "flagelar",
    "flagelarem": "flagelar",
    "flagelaremos": "flagelar",
    "flagelares": "flagelar",
    "flagelaria": "flagelar",
    "flagelariam": "flagelar",
    "flagelarias": "flagelar",
    "flagelarmo": "flagelar",
    "flagelarmos": "flagelar",
    "flagelará": "flagelar",
    "flagelarás": "flagelar",
    "flagelarão": "flagelar",
    "flagelaríamos": "flagelar",
    "flagelaríeis": "flagelar",
    "flagelas": "flagelar",
    "flagelasse": "flagelar",
    "flagelassem": "flagelar",
    "flagelasses": "flagelar",
    "flagelaste": "flagelar",
    "flagelastes": "flagelar",
    "flagelativa": "flagelativo",
    "flagelativas": "flagelativo",
    "flagelativos": "flagelativo",
    "flagelava": "flagelar",
    "flagelavam": "flagelar",
    "flagelavas": "flagelar",
    "flagelações": "flagelação",
    "flagele": "flagelar",
    "flagelei": "flagelar",
    "flageleis": "flagelar",
    "flagelem": "flagelar",
    "flagelemo": "flagelar",
    "flagelemos": "flagelar",
    "flageles": "flagelar",
    "flageliformes": "flageliforme",
    "flagelo": "flagelar",
    "flagelos": "flagelo",
    "flagelou": "flagelar",
    "flagelá": "flagelar",
    "flagelámo": "flagelar",
    "flagelámos": "flagelar",
    "flageláramo": "flagelar",
    "flageláramos": "flagelar",
    "flagelárei": "flagelar",
    "flageláreis": "flagelar",
    "flagelásseis": "flagelar",
    "flagelássemos": "flagelar",
    "flagelávamo": "flagelar",
    "flagelávamos": "flagelar",
    "flagelávei": "flagelar",
    "flageláveis": "flagelar",
    "flagelífera": "flagelífero",
    "flagelíferas": "flagelífero",
    "flagelíferos": "flagelífero",
    "flagiciosa": "flagicioso",
    "flagiciosas": "flagicioso",
    "flagiciosos": "flagicioso",
    "flagra": "flagrar",
    "flagrada": "flagrar",
    "flagradas": "flagrar",
    "flagrado": "flagrar",
    "flagrados": "flagrar",
    "flagrai": "flagrar",
    "flagrais": "flagrar",
    "flagram": "flagrar",
    "flagramo": "flagrar",
    "flagramos": "flagrar",
    "flagrando": "flagrar",
    "flagrantes": "flagrante",
    "flagrara": "flagrar",
    "flagraram": "flagrar",
    "flagraras": "flagrar",
    "flagrardes": "flagrar",
    "flagrarei": "flagrar",
    "flagrareis": "flagrar",
    "flagrarem": "flagrar",
    "flagraremos": "flagrar",
    "flagrares": "flagrar",
    "flagraria": "flagrar",
    "flagrariam": "flagrar",
    "flagrarias": "flagrar",
    "flagrarmo": "flagrar",
    "flagrarmos": "flagrar",
    "flagrará": "flagrar",
    "flagrarás": "flagrar",
    "flagrarão": "flagrar",
    "flagraríamos": "flagrar",
    "flagraríeis": "flagrar",
    "flagras": "flagrar",
    "flagrasse": "flagrar",
    "flagrassem": "flagrar",
    "flagrasses": "flagrar",
    "flagraste": "flagrar",
    "flagrastes": "flagrar",
    "flagrava": "flagrar",
    "flagravam": "flagrar",
    "flagravas": "flagrar",
    "flagre": "flagrar",
    "flagrei": "flagrar",
    "flagreis": "flagrar",
    "flagrem": "flagrar",
    "flagremo": "flagrar",
    "flagremos": "flagrar",
    "flagres": "flagrar",
    "flagro": "flagrar",
    "flagrou": "flagrar",
    "flagrámo": "flagrar",
    "flagrámos": "flagrar",
    "flagráramo": "flagrar",
    "flagráramos": "flagrar",
    "flagráreis": "flagrar",
    "flagrásseis": "flagrar",
    "flagrássemos": "flagrar",
    "flagrávamo": "flagrar",
    "flagrávamos": "flagrar",
    "flagráveis": "flagrar",
    "flagrâncias": "flagrância",
    "flagícios": "flagício",
    "flaina": "flainar",
    "flainada": "flainar",
    "flainadas": "flainar",
    "flainado": "flainar",
    "flainados": "flainar",
    "flainai": "flainar",
    "flainais": "flainar",
    "flainam": "flainar",
    "flainamo": "flainar",
    "flainamos": "flainar",
    "flainando": "flainar",
    "flainara": "flainar",
    "flainaram": "flainar",
    "flainaras": "flainar",
    "flainardes": "flainar",
    "flainarei": "flainar",
    "flainareis": "flainar",
    "flainarem": "flainar",
    "flainaremos": "flainar",
    "flainares": "flainar",
    "flainaria": "flainar",
    "flainariam": "flainar",
    "flainarias": "flainar",
    "flainarmo": "flainar",
    "flainarmos": "flainar",
    "flainará": "flainar",
    "flainarás": "flainar",
    "flainarão": "flainar",
    "flainaríamos": "flainar",
    "flainaríeis": "flainar",
    "flainas": "flainar",
    "flainasse": "flainar",
    "flainassem": "flainar",
    "flainasses": "flainar",
    "flainaste": "flainar",
    "flainastes": "flainar",
    "flainava": "flainar",
    "flainavam": "flainar",
    "flainavas": "flainar",
    "flaine": "flainar",
    "flainei": "flainar",
    "flaineis": "flainar",
    "flainem": "flainar",
    "flainemo": "flainar",
    "flainemos": "flainar",
    "flaines": "flainar",
    "flaino": "flainar",
    "flainos": "flaino",
    "flainou": "flainar",
    "flainámo": "flainar",
    "flainámos": "flainar",
    "flaináramo": "flainar",
    "flaináramos": "flainar",
    "flaináreis": "flainar",
    "flainásseis": "flainar",
    "flainássemos": "flainar",
    "flainávamo": "flainar",
    "flainávamos": "flainar",
    "flaináveis": "flainar",
    "flamantes": "flamante",
    "flamas": "flama",
    "flameada": "flamear",
    "flameadas": "flamear",
    "flameado": "flamear",
    "flameados": "flamear",
    "flameai": "flamear",
    "flameais": "flamear",
    "flameamo": "flamear",
    "flameamos": "flamear",
    "flameando": "flamear",
    "flameara": "flamear",
    "flamearam": "flamear",
    "flamearas": "flamear",
    "flameardes": "flamear",
    "flamearei": "flamear",
    "flameareis": "flamear",
    "flamearem": "flamear",
    "flamearemos": "flamear",
    "flameares": "flamear",
    "flamearia": "flamear",
    "flameariam": "flamear",
    "flamearias": "flamear",
    "flamearmo": "flamear",
    "flamearmos": "flamear",
    "flameará": "flamear",
    "flamearás": "flamear",
    "flamearão": "flamear",
    "flamearíamos": "flamear",
    "flamearíeis": "flamear",
    "flameasse": "flamear",
    "flameassem": "flamear",
    "flameasses": "flamear",
    "flameaste": "flamear",
    "flameastes": "flamear",
    "flameava": "flamear",
    "flameavam": "flamear",
    "flameavas": "flamear",
    "flameei": "flamear",
    "flameeis": "flamear",
    "flameemo": "flamear",
    "flameemos": "flamear",
    "flameia": "flamear",
    "flameiam": "flamear",
    "flameias": "flamear",
    "flameie": "flamear",
    "flameiem": "flamear",
    "flameies": "flamear",
    "flameio": "flamear",
    "flameja": "flamejar",
    "flamejada": "flamejar",
    "flamejadas": "flamejar",
    "flamejado": "flamejar",
    "flamejados": "flamejar",
    "flamejai": "flamejar",
    "flamejais": "flamejar",
    "flamejam": "flamejar",
    "flamejamentos": "flamejamento",
    "flamejamo": "flamejar",
    "flamejamos": "flamejar",
    "flamejando": "flamejar",
    "flamejantes": "flamejante",
    "flamejara": "flamejar",
    "flamejaram": "flamejar",
    "flamejaras": "flamejar",
    "flamejardes": "flamejar",
    "flamejarei": "flamejar",
    "flamejareis": "flamejar",
    "flamejarem": "flamejar",
    "flamejaremos": "flamejar",
    "flamejares": "flamejar",
    "flamejaria": "flamejar",
    "flamejariam": "flamejar",
    "flamejarias": "flamejar",
    "flamejarmo": "flamejar",
    "flamejarmos": "flamejar",
    "flamejará": "flamejar",
    "flamejarás": "flamejar",
    "flamejarão": "flamejar",
    "flamejaríamos": "flamejar",
    "flamejaríeis": "flamejar",
    "flamejas": "flamejar",
    "flamejasse": "flamejar",
    "flamejassem": "flamejar",
    "flamejasses": "flamejar",
    "flamejaste": "flamejar",
    "flamejastes": "flamejar",
    "flamejava": "flamejar",
    "flamejavam": "flamejar",
    "flamejavas": "flamejar",
    "flameje": "flamejar",
    "flamejei": "flamejar",
    "flamejeis": "flamejar",
    "flamejem": "flamejar",
    "flamejemo": "flamejar",
    "flamejemos": "flamejar",
    "flamejes": "flamejar",
    "flamejo": "flamejar",
    "flamejou": "flamejar",
    "flamejámo": "flamejar",
    "flamejámos": "flamejar",
    "flamejáramo": "flamejar",
    "flamejáramos": "flamejar",
    "flamejáreis": "flamejar",
    "flamejásseis": "flamejar",
    "flamejássemos": "flamejar",
    "flamejávamo": "flamejar",
    "flamejávamos": "flamejar",
    "flamejáveis": "flamejar",
    "flamencos": "flamenco",
    "flamenga": "flamengo",
    "flamengas": "flamengo",
    "flamengos": "flamengo",
    "flameou": "flamear",
    "flames": "flame",
    "flameámo": "flamear",
    "flameámos": "flamear",
    "flameáramo": "flamear",
    "flameáramos": "flamear",
    "flameáreis": "flamear",
    "flameásseis": "flamear",
    "flameássemos": "flamear",
    "flameávamo": "flamear",
    "flameávamos": "flamear",
    "flameáveis": "flamear",
    "flamiferventes": "flamifervente",
    "flaminatos": "flaminato",
    "flamingos": "flamingo",
    "flamipotentes": "flamipotente",
    "flamispirantes": "flamispirante",
    "flamâncias": "flamância",
    "flamífera": "flamífero",
    "flamíferas": "flamífero",
    "flamíferos": "flamífero",
    "flamígera": "flamígero",
    "flamígeras": "flamígero",
    "flamígeros": "flamígero",
    "flamínia": "flamínio",
    "flamínias": "flamínio",
    "flamínicas": "flamínica",
    "flamínios": "flamínio",
    "flamívola": "flamívolo",
    "flamívolas": "flamívolo",
    "flamívolos": "flamívolo",
    "flamívoma": "flamívomo",
    "flamívomas": "flamívomo",
    "flamívomos": "flamívomo",
    "flamões": "flamão",
    "flana": "flanar",
    "flanada": "flanar",
    "flanadas": "flanar",
    "flanado": "flanar",
    "flanadora": "flanador",
    "flanadoras": "flanador",
    "flanadores": "flanador",
    "flanados": "flanar",
    "flanai": "flanar",
    "flanais": "flanar",
    "flanam": "flanar",
    "flanamo": "flanar",
    "flanamos": "flanar",
    "flanando": "flanar",
    "flanara": "flanar",
    "flanaram": "flanar",
    "flanaras": "flanar",
    "flanardes": "flanar",
    "flanarei": "flanar",
    "flanareis": "flanar",
    "flanarem": "flanar",
    "flanaremos": "flanar",
    "flanares": "flanar",
    "flanaria": "flanar",
    "flanariam": "flanar",
    "flanarias": "flanar",
    "flanarmo": "flanar",
    "flanarmos": "flanar",
    "flanará": "flanar",
    "flanarás": "flanar",
    "flanarão": "flanar",
    "flanaríamos": "flanar",
    "flanaríeis": "flanar",
    "flanas": "flanar",
    "flanasse": "flanar",
    "flanassem": "flanar",
    "flanasses": "flanar",
    "flanaste": "flanar",
    "flanastes": "flanar",
    "flanava": "flanar",
    "flanavam": "flanar",
    "flanavas": "flanar",
    "flancos": "flanco",
    "flandriana": "flandriano",
    "flandrianas": "flandriano",
    "flandrianos": "flandriano",
    "flandrina": "flandrino",
    "flandrinas": "flandrino",
    "flandrinos": "flandrino",
    "flandrisca": "flandrisco",
    "flandriscas": "flandrisco",
    "flandriscos": "flandrisco",
    "flane": "flanar",
    "flanei": "flanar",
    "flaneis": "flanar",
    "flanelas": "flanela",
    "flanelógrafos": "flanelógrafo",
    "flanem": "flanar",
    "flanemo": "flanar",
    "flanemos": "flanar",
    "flanes": "flanar",
    "flano": "flanar",
    "flanou": "flanar",
    "flanqueada": "flanquear",
    "flanqueadas": "flanquear",
    "flanqueado": "flanquear",
    "flanqueadora": "flanqueador",
    "flanqueadoras": "flanqueador",
    "flanqueadores": "flanqueador",
    "flanqueados": "flanquear",
    "flanqueai": "flanquear",
    "flanqueais": "flanquear",
    "flanqueamo": "flanquear",
    "flanqueamos": "flanquear",
    "flanqueando": "flanquear",
    "flanqueara": "flanquear",
    "flanquearam": "flanquear",
    "flanquearas": "flanquear",
    "flanquearde": "flanquear",
    "flanqueardes": "flanquear",
    "flanqueare": "flanquear",
    "flanquearei": "flanquear",
    "flanqueareis": "flanquear",
    "flanquearem": "flanquear",
    "flanquearemos": "flanquear",
    "flanqueares": "flanquear",
    "flanquearia": "flanquear",
    "flanqueariam": "flanquear",
    "flanquearias": "flanquear",
    "flanquearmo": "flanquear",
    "flanquearmos": "flanquear",
    "flanqueará": "flanquear",
    "flanquearás": "flanquear",
    "flanquearão": "flanquear",
    "flanquearíamos": "flanquear",
    "flanquearíeis": "flanquear",
    "flanqueasse": "flanquear",
    "flanqueassem": "flanquear",
    "flanqueasses": "flanquear",
    "flanqueaste": "flanquear",
    "flanqueastes": "flanquear",
    "flanqueava": "flanquear",
    "flanqueavam": "flanquear",
    "flanqueavas": "flanquear",
    "flanqueei": "flanquear",
    "flanqueeis": "flanquear",
    "flanqueemo": "flanquear",
    "flanqueemos": "flanquear",
    "flanqueia": "flanquear",
    "flanqueiam": "flanquear",
    "flanqueias": "flanquear",
    "flanqueie": "flanquear",
    "flanqueiem": "flanquear",
    "flanqueies": "flanquear",
    "flanqueio": "flanquear",
    "flanqueou": "flanquear",
    "flanqueá": "flanquear",
    "flanqueámo": "flanquear",
    "flanqueámos": "flanquear",
    "flanqueáramo": "flanquear",
    "flanqueáramos": "flanquear",
    "flanqueárei": "flanquear",
    "flanqueáreis": "flanquear",
    "flanqueásseis": "flanquear",
    "flanqueássemos": "flanquear",
    "flanqueávamo": "flanquear",
    "flanqueávamos": "flanquear",
    "flanqueávei": "flanquear",
    "flanqueáveis": "flanquear",
    "flans": "flan",
    "flanámo": "flanar",
    "flanámos": "flanar",
    "flanáramo": "flanar",
    "flanáramos": "flanar",
    "flanáreis": "flanar",
    "flanásseis": "flanar",
    "flanássemos": "flanar",
    "flanávamo": "flanar",
    "flanávamos": "flanar",
    "flanáveis": "flanar",
    "flashbacks": "flashback",
    "flashes": "flash",
    "flatos": "flato",
    "flatosa": "flatoso",
    "flatosas": "flatoso",
    "flatosos": "flatoso",
    "flatulenta": "flatulento",
    "flatulentas": "flatulento",
    "flatulentos": "flatulento",
    "flatulosa": "flatuloso",
    "flatulosas": "flatuloso",
    "flatulosos": "flatuloso",
    "flatulências": "flatulência",
    "flatuosa": "flatuoso",
    "flatuosas": "flatuoso",
    "flatuosidades": "flatuosidade",
    "flatuosos": "flatuoso",
    "flausina": "flausino",
    "flausinas": "flausino",
    "flausinos": "flausino",
    "flauta": "flautar",
    "flautada": "flautar",
    "flautadas": "flautar",
    "flautado": "flautar",
    "flautados": "flautar",
    "flautai": "flautar",
    "flautais": "flautar",
    "flautam": "flautar",
    "flautamo": "flautar",
    "flautamos": "flautar",
    "flautando": "flautar",
    "flautara": "flautar",
    "flautaram": "flautar",
    "flautaras": "flautar",
    "flautardes": "flautar",
    "flautarei": "flautar",
    "flautareis": "flautar",
    "flautarem": "flautar",
    "flautaremos": "flautar",
    "flautares": "flautar",
    "flautaria": "flautar",
    "flautariam": "flautar",
    "flautarias": "flautar",
    "flautarmo": "flautar",
    "flautarmos": "flautar",
    "flautará": "flautar",
    "flautarás": "flautar",
    "flautarão": "flautar",
    "flautaríamos": "flautar",
    "flautaríeis": "flautar",
    "flautas": "flautar",
    "flautasse": "flautar",
    "flautassem": "flautar",
    "flautasses": "flautar",
    "flautaste": "flautar",
    "flautastes": "flautar",
    "flautava": "flautar",
    "flautavam": "flautar",
    "flautavas": "flautar",
    "flaute": "flautar",
    "flauteada": "flautear",
    "flauteadas": "flautear",
    "flauteado": "flautear",
    "flauteadoa": "flauteadoo",
    "flauteadoas": "flauteadoo",
    "flauteadoos": "flauteadoo",
    "flauteados": "flautear",
    "flauteai": "flautear",
    "flauteais": "flautear",
    "flauteamo": "flautear",
    "flauteamos": "flautear",
    "flauteando": "flautear",
    "flauteara": "flautear",
    "flautearam": "flautear",
    "flautearas": "flautear",
    "flauteardes": "flautear",
    "flautearei": "flautear",
    "flauteareis": "flautear",
    "flautearem": "flautear",
    "flautearemos": "flautear",
    "flauteares": "flautear",
    "flautearia": "flautear",
    "flauteariam": "flautear",
    "flautearias": "flautear",
    "flautearmo": "flautear",
    "flautearmos": "flautear",
    "flauteará": "flautear",
    "flautearás": "flautear",
    "flautearão": "flautear",
    "flautearíamos": "flautear",
    "flautearíeis": "flautear",
    "flauteasse": "flautear",
    "flauteassem": "flautear",
    "flauteasses": "flautear",
    "flauteaste": "flautear",
    "flauteastes": "flautear",
    "flauteava": "flautear",
    "flauteavam": "flautear",
    "flauteavas": "flautear",
    "flauteei": "flautear",
    "flauteeis": "flautear",
    "flauteemo": "flautear",
    "flauteemos": "flautear",
    "flautei": "flautar",
    "flauteia": "flautear",
    "flauteiam": "flautear",
    "flauteias": "flautear",
    "flauteie": "flautear",
    "flauteiem": "flautear",
    "flauteies": "flautear",
    "flauteio": "flautear",
    "flauteios": "flauteio",
    "flauteira": "flauteiro",
    "flauteiras": "flauteiro",
    "flauteiros": "flauteiro",
    "flauteis": "flautar",
    "flautem": "flautar",
    "flautemo": "flautar",
    "flautemos": "flautar",
    "flauteou": "flautear",
    "flautes": "flautar",
    "flauteámo": "flautear",
    "flauteámos": "flautear",
    "flauteáramo": "flautear",
    "flauteáramos": "flautear",
    "flauteáreis": "flautear",
    "flauteásseis": "flautear",
    "flauteássemos": "flautear",
    "flauteávamo": "flautear",
    "flauteávamos": "flautear",
    "flauteáveis": "flautear",
    "flautins": "flautim",
    "flautistas": "flautista",
    "flauto": "flautar",
    "flautou": "flautar",
    "flautámo": "flautar",
    "flautámos": "flautar",
    "flautáramo": "flautar",
    "flautáramos": "flautar",
    "flautáreis": "flautar",
    "flautásseis": "flautar",
    "flautássemos": "flautar",
    "flautávamo": "flautar",
    "flautávamos": "flautar",
    "flautáveis": "flautar",
    "flava": "flavo",
    "flavas": "flavo",
    "flavesce": "flavescer",
    "flavescei": "flavescer",
    "flavesceis": "flavescer",
    "flavescem": "flavescer",
    "flavescemo": "flavescer",
    "flavescemos": "flavescer",
    "flavescendo": "flavescer",
    "flavescentes": "flavescente",
    "flavescera": "flavescer",
    "flavesceram": "flavescer",
    "flavesceras": "flavescer",
    "flavescerdes": "flavescer",
    "flavescerei": "flavescer",
    "flavescereis": "flavescer",
    "flavescerem": "flavescer",
    "flavesceremos": "flavescer",
    "flavesceres": "flavescer",
    "flavesceria": "flavescer",
    "flavesceriam": "flavescer",
    "flavescerias": "flavescer",
    "flavescermo": "flavescer",
    "flavescermos": "flavescer",
    "flavescerá": "flavescer",
    "flavescerás": "flavescer",
    "flavescerão": "flavescer",
    "flavesceríamos": "flavescer",
    "flavesceríeis": "flavescer",
    "flavesces": "flavescer",
    "flavescesse": "flavescer",
    "flavescessem": "flavescer",
    "flavescesses": "flavescer",
    "flavesceste": "flavescer",
    "flavescestes": "flavescer",
    "flavesceu": "flavescer",
    "flavesci": "flavescer",
    "flavescia": "flavescer",
    "flavesciam": "flavescer",
    "flavescias": "flavescer",
    "flavescida": "flavescer",
    "flavescidas": "flavescer",
    "flavescido": "flavescer",
    "flavescidos": "flavescer",
    "flavescências": "flavescência",
    "flavescêramo": "flavescer",
    "flavescêramos": "flavescer",
    "flavescêreis": "flavescer",
    "flavescêsseis": "flavescer",
    "flavescêssemos": "flavescer",
    "flavescíamo": "flavescer",
    "flavescíamos": "flavescer",
    "flavescíeis": "flavescer",
    "flavesça": "flavescer",
    "flavesçais": "flavescer",
    "flavesçam": "flavescer",
    "flavesçamo": "flavescer",
    "flavesçamos": "flavescer",
    "flavesças": "flavescer",
    "flavesço": "flavescer",
    "flavienses": "flaviense",
    "flavores": "flavor",
    "flavos": "flavo",
    "flavíflua": "flavífluo",
    "flavífluas": "flavífluo",
    "flavífluos": "flavífluo",
    "flavípedes": "flavípede",
    "flebites": "flebite",
    "flebografias": "flebografia",
    "flebográfica": "flebográfico",
    "flebográficas": "flebográfico",
    "flebográficos": "flebográfico",
    "flebologias": "flebologia",
    "flebologistas": "flebologista",
    "flebolítica": "flebolítico",
    "flebolíticas": "flebolítico",
    "flebolíticos": "flebolítico",
    "flebológica": "flebológico",
    "flebológicas": "flebológico",
    "flebológicos": "flebológico",
    "fleborreica": "fleborreico",
    "fleborreicas": "fleborreico",
    "fleborreicos": "fleborreico",
    "fleborrágica": "fleborrágico",
    "fleborrágicas": "fleborrágico",
    "fleborrágicos": "fleborrágico",
    "fleboscleroses": "flebosclerose",
    "flebosclerótica": "flebosclerótico",
    "fleboscleróticas": "flebosclerótico",
    "fleboscleróticos": "flebosclerótico",
    "flebotomias": "flebotomia",
    "flebotómica": "flebotómico",
    "flebotómicas": "flebotómico",
    "flebotómicos": "flebotómico",
    "flebítica": "flebítico",
    "flebíticas": "flebítico",
    "flebíticos": "flebítico",
    "flebólitos": "flebólito",
    "flebótomos": "flebótomo",
    "flecha": "flechar",
    "flechada": "flechar",
    "flechadas": "flechar",
    "flechado": "flechar",
    "flechados": "flechar",
    "flechai": "flechar",
    "flechais": "flechar",
    "flecham": "flechar",
    "flechamo": "flechar",
    "flechamos": "flechar",
    "flechando": "flechar",
    "flechara": "flechar",
    "flecharam": "flechar",
    "flecharas": "flechar",
    "flecharde": "flechar",
    "flechardes": "flechar",
    "flechare": "flechar",
    "flecharei": "flechar",
    "flechareis": "flechar",
    "flecharem": "flechar",
    "flecharemos": "flechar",
    "flechares": "flechar",
    "flecharia": "flechar",
    "flechariam": "flechar",
    "flecharias": "flechar",
    "flecharmo": "flechar",
    "flecharmos": "flechar",
    "flechará": "flechar",
    "flecharás": "flechar",
    "flecharão": "flechar",
    "flecharíamos": "flechar",
    "flecharíeis": "flechar",
    "flechas": "flechar",
    "flechasse": "flechar",
    "flechassem": "flechar",
    "flechasses": "flechar",
    "flechaste": "flechar",
    "flechastes": "flechar",
    "flechava": "flechar",
    "flechavam": "flechar",
    "flechavas": "flechar",
    "fleche": "flechar",
    "flechei": "flechar",
    "flecheira": "flecheiro",
    "flecheiras": "flecheiro",
    "flecheiros": "flecheiro",
    "flecheis": "flechar",
    "flechem": "flechar",
    "flechemo": "flechar",
    "flechemos": "flechar",
    "fleches": "flechar",
    "flecho": "flechar",
    "flechou": "flechar",
    "flechá": "flechar",
    "flechámo": "flechar",
    "flechámos": "flechar",
    "flecháramo": "flechar",
    "flecháramos": "flechar",
    "flechárei": "flechar",
    "flecháreis": "flechar",
    "flechásseis": "flechar",
    "flechássemos": "flechar",
    "flechávamo": "flechar",
    "flechávamos": "flechar",
    "flechávei": "flechar",
    "flecháveis": "flechar",
    "flecte": "flectir",
    "flectem": "flectir",
    "flectes": "flectir",
    "flecti": "flectir",
    "flectia": "flectir",
    "flectiam": "flectir",
    "flectias": "flectir",
    "flectida": "flectir",
    "flectidas": "flectir",
    "flectido": "flectir",
    "flectidos": "flectir",
    "flectimo": "flectir",
    "flectimos": "flectir",
    "flectindo": "flectir",
    "flectira": "flectir",
    "flectiram": "flectir",
    "flectiras": "flectir",
    "flectirde": "flectir",
    "flectirdes": "flectir",
    "flectire": "flectir",
    "flectirei": "flectir",
    "flectireis": "flectir",
    "flectirem": "flectir",
    "flectiremos": "flectir",
    "flectires": "flectir",
    "flectiria": "flectir",
    "flectiriam": "flectir",
    "flectirias": "flectir",
    "flectirmo": "flectir",
    "flectirmos": "flectir",
    "flectirá": "flectir",
    "flectirás": "flectir",
    "flectirão": "flectir",
    "flectiríamos": "flectir",
    "flectiríeis": "flectir",
    "flectis": "flectir",
    "flectisse": "flectir",
    "flectissem": "flectir",
    "flectisses": "flectir",
    "flectiste": "flectir",
    "flectistes": "flectir",
    "flectiu": "flectir",
    "flectíamo": "flectir",
    "flectíamos": "flectir",
    "flectíei": "flectir",
    "flectíeis": "flectir",
    "flectíramo": "flectir",
    "flectíramos": "flectir",
    "flectírei": "flectir",
    "flectíreis": "flectir",
    "flectísseis": "flectir",
    "flectíssemos": "flectir",
    "flegmas": "flegma",
    "flegmasias": "flegmasia",
    "flegmásica": "flegmásico",
    "flegmásicas": "flegmásico",
    "flegmásicos": "flegmásico",
    "flegmática": "flegmático",
    "flegmáticas": "flegmático",
    "flegmáticos": "flegmático",
    "flegmões": "flegmão",
    "fleimas": "fleima",
    "fleimosa": "fleimoso",
    "fleimosas": "fleimoso",
    "fleimosos": "fleimoso",
    "fleimões": "fleimão",
    "flemes": "fleme",
    "flentes": "flente",
    "fleumagoga": "fleumagogo",
    "fleumagogas": "fleumagogo",
    "fleumagogos": "fleumagogo",
    "fleumas": "fleuma",
    "fleumática": "fleumático",
    "fleumáticas": "fleumático",
    "fleumáticos": "fleumático",
    "fleumões": "fleumão",
    "flexibilidades": "flexibilidade",
    "flexibiliza": "flexibilizar",
    "flexibilizada": "flexibilizar",
    "flexibilizadas": "flexibilizar",
    "flexibilizado": "flexibilizar",
    "flexibilizados": "flexibilizar",
    "flexibilizai": "flexibilizar",
    "flexibilizais": "flexibilizar",
    "flexibilizam": "flexibilizar",
    "flexibilizamo": "flexibilizar",
    "flexibilizamos": "flexibilizar",
    "flexibilizando": "flexibilizar",
    "flexibilizara": "flexibilizar",
    "flexibilizaram": "flexibilizar",
    "flexibilizaras": "flexibilizar",
    "flexibilizarde": "flexibilizar",
    "flexibilizardes": "flexibilizar",
    "flexibilizare": "flexibilizar",
    "flexibilizarei": "flexibilizar",
    "flexibilizareis": "flexibilizar",
    "flexibilizarem": "flexibilizar",
    "flexibilizaremos": "flexibilizar",
    "flexibilizares": "flexibilizar",
    "flexibilizaria": "flexibilizar",
    "flexibilizariam": "flexibilizar",
    "flexibilizarias": "flexibilizar",
    "flexibilizarmo": "flexibilizar",
    "flexibilizarmos": "flexibilizar",
    "flexibilizará": "flexibilizar",
    "flexibilizarás": "flexibilizar",
    "flexibilizarão": "flexibilizar",
    "flexibilizaríamos": "flexibilizar",
    "flexibilizaríeis": "flexibilizar",
    "flexibilizas": "flexibilizar",
    "flexibilizasse": "flexibilizar",
    "flexibilizassem": "flexibilizar",
    "flexibilizasses": "flexibilizar",
    "flexibilizaste": "flexibilizar",
    "flexibilizastes": "flexibilizar",
    "flexibilizava": "flexibilizar",
    "flexibilizavam": "flexibilizar",
    "flexibilizavas": "flexibilizar",
    "flexibilizações": "flexibilização",
    "flexibilize": "flexibilizar",
    "flexibilizei": "flexibilizar",
    "flexibilizeis": "flexibilizar",
    "flexibilizem": "flexibilizar",
    "flexibilizemo": "flexibilizar",
    "flexibilizemos": "flexibilizar",
    "flexibilizes": "flexibilizar",
    "flexibilizo": "flexibilizar",
    "flexibilizou": "flexibilizar",
    "flexibilizá": "flexibilizar",
    "flexibilizámo": "flexibilizar",
    "flexibilizámos": "flexibilizar",
    "flexibilizáramo": "flexibilizar",
    "flexibilizáramos": "flexibilizar",
    "flexibilizárei": "flexibilizar",
    "flexibilizáreis": "flexibilizar",
    "flexibilizásseis": "flexibilizar",
    "flexibilizássemos": "flexibilizar",
    "flexibilizávamo": "flexibilizar",
    "flexibilizávamos": "flexibilizar",
    "flexibilizávei": "flexibilizar",
    "flexibilizáveis": "flexibilizável",
    "flexiologias": "flexiologia",
    "flexiologistas": "flexiologista",
    "flexiológica": "flexiológico",
    "flexiológicas": "flexiológico",
    "flexiológicos": "flexiológico",
    "flexiona": "flexionar",
    "flexionada": "flexionar",
    "flexionadas": "flexionar",
    "flexionado": "flexionar",
    "flexionados": "flexionar",
    "flexionai": "flexionar",
    "flexionais": "flexionar",
    "flexionam": "flexionar",
    "flexionamo": "flexionar",
    "flexionamos": "flexionar",
    "flexionando": "flexionar",
    "flexionara": "flexionar",
    "flexionaram": "flexionar",
    "flexionaras": "flexionar",
    "flexionarde": "flexionar",
    "flexionardes": "flexionar",
    "flexionare": "flexionar",
    "flexionarei": "flexionar",
    "flexionareis": "flexionar",
    "flexionarem": "flexionar",
    "flexionaremos": "flexionar",
    "flexionares": "flexionar",
    "flexionaria": "flexionar",
    "flexionariam": "flexionar",
    "flexionarias": "flexionar",
    "flexionarmo": "flexionar",
    "flexionarmos": "flexionar",
    "flexionará": "flexionar",
    "flexionarás": "flexionar",
    "flexionarão": "flexionar",
    "flexionaríamos": "flexionar",
    "flexionaríeis": "flexionar",
    "flexionas": "flexionar",
    "flexionasse": "flexionar",
    "flexionassem": "flexionar",
    "flexionasses": "flexionar",
    "flexionaste": "flexionar",
    "flexionastes": "flexionar",
    "flexionava": "flexionar",
    "flexionavam": "flexionar",
    "flexionavas": "flexionar",
    "flexione": "flexionar",
    "flexionei": "flexionar",
    "flexioneis": "flexionar",
    "flexionem": "flexionar",
    "flexionemo": "flexionar",
    "flexionemos": "flexionar",
    "flexiones": "flexionar",
    "flexionismos": "flexionismo",
    "flexiono": "flexionar",
    "flexionou": "flexionar",
    "flexioná": "flexionar",
    "flexionámo": "flexionar",
    "flexionámos": "flexionar",
    "flexionáramo": "flexionar",
    "flexionáramos": "flexionar",
    "flexionárei": "flexionar",
    "flexionáreis": "flexionar",
    "flexionásseis": "flexionar",
    "flexionássemos": "flexionar",
    "flexionávamo": "flexionar",
    "flexionávamos": "flexionar",
    "flexionávei": "flexionar",
    "flexionáveis": "flexionável",
    "flexionística": "flexionístico",
    "flexionísticas": "flexionístico",
    "flexionísticos": "flexionístico",
    "flexiosidades": "flexiosidade",
    "flexiva": "flexivo",
    "flexivas": "flexivo",
    "flexivos": "flexivo",
    "flexióloga": "flexiólogo",
    "flexiólogas": "flexiólogo",
    "flexiólogos": "flexiólogo",
    "flexora": "flexor",
    "flexoras": "flexor",
    "flexores": "flexor",
    "flexuosa": "flexuoso",
    "flexuosas": "flexuoso",
    "flexuosos": "flexuoso",
    "flexuras": "flexura",
    "flexíloqua": "flexíloquo",
    "flexíloquas": "flexíloquo",
    "flexíloquos": "flexíloquo",
    "flexípedes": "flexípede",
    "flexíveis": "flexível",
    "flexória": "flexório",
    "flexórias": "flexório",
    "flexórios": "flexório",
    "flexões": "flexão",
    "flibusteira": "flibusteiro",
    "flibusteiras": "flibusteiro",
    "flibusteiros": "flibusteiro",
    "flicta": "flectir",
    "flictais": "flectir",
    "flictam": "flectir",
    "flictamo": "flectir",
    "flictamos": "flectir",
    "flictas": "flectir",
    "flicto": "flectir",
    "flintes": "flint",
    "flirta": "flirtar",
    "flirtada": "flirtar",
    "flirtadas": "flirtar",
    "flirtado": "flirtar",
    "flirtados": "flirtar",
    "flirtai": "flirtar",
    "flirtais": "flirtar",
    "flirtam": "flirtar",
    "flirtamo": "flirtar",
    "flirtamos": "flirtar",
    "flirtando": "flirtar",
    "flirtara": "flirtar",
    "flirtaram": "flirtar",
    "flirtaras": "flirtar",
    "flirtardes": "flirtar",
    "flirtarei": "flirtar",
    "flirtareis": "flirtar",
    "flirtarem": "flirtar",
    "flirtaremos": "flirtar",
    "flirtares": "flirtar",
    "flirtaria": "flirtar",
    "flirtariam": "flirtar",
    "flirtarias": "flirtar",
    "flirtarmo": "flirtar",
    "flirtarmos": "flirtar",
    "flirtará": "flirtar",
    "flirtarás": "flirtar",
    "flirtarão": "flirtar",
    "flirtaríamos": "flirtar",
    "flirtaríeis": "flirtar",
    "flirtas": "flirtar",
    "flirtasse": "flirtar",
    "flirtassem": "flirtar",
    "flirtasses": "flirtar",
    "flirtaste": "flirtar",
    "flirtastes": "flirtar",
    "flirtava": "flirtar",
    "flirtavam": "flirtar",
    "flirtavas": "flirtar",
    "flirtações": "flirtação",
    "flirte": "flirtar",
    "flirtei": "flirtar",
    "flirteis": "flirtar",
    "flirtem": "flirtar",
    "flirtemo": "flirtar",
    "flirtemos": "flirtar",
    "flirtes": "flirtar",
    "flirto": "flirtar",
    "flirtou": "flirtar",
    "flirtámo": "flirtar",
    "flirtámos": "flirtar",
    "flirtáramo": "flirtar",
    "flirtáramos": "flirtar",
    "flirtáreis": "flirtar",
    "flirtásseis": "flirtar",
    "flirtássemos": "flirtar",
    "flirtávamo": "flirtar",
    "flirtávamos": "flirtar",
    "flirtáveis": "flirtar",
    "flocada": "flocado",
    "flocadas": "flocado",
    "flocados": "flocado",
    "flocona": "floconar",
    "floconada": "floconar",
    "floconadas": "floconar",
    "floconado": "floconar",
    "floconados": "floconar",
    "floconai": "floconar",
    "floconais": "floconar",
    "floconam": "floconar",
    "floconamo": "floconar",
    "floconamos": "floconar",
    "floconando": "floconar",
    "floconara": "floconar",
    "floconaram": "floconar",
    "floconaras": "floconar",
    "floconardes": "floconar",
    "floconarei": "floconar",
    "floconareis": "floconar",
    "floconarem": "floconar",
    "floconaremos": "floconar",
    "floconares": "floconar",
    "floconaria": "floconar",
    "floconariam": "floconar",
    "floconarias": "floconar",
    "floconarmo": "floconar",
    "floconarmos": "floconar",
    "floconará": "floconar",
    "floconarás": "floconar",
    "floconarão": "floconar",
    "floconaríamos": "floconar",
    "floconaríeis": "floconar",
    "floconas": "floconar",
    "floconasse": "floconar",
    "floconassem": "floconar",
    "floconasses": "floconar",
    "floconaste": "floconar",
    "floconastes": "floconar",
    "floconava": "floconar",
    "floconavam": "floconar",
    "floconavas": "floconar",
    "flocone": "floconar",
    "floconei": "floconar",
    "floconeis": "floconar",
    "floconem": "floconar",
    "floconemo": "floconar",
    "floconemos": "floconar",
    "flocones": "floconar",
    "flocono": "floconar",
    "floconou": "floconar",
    "floconámo": "floconar",
    "floconámos": "floconar",
    "floconáramo": "floconar",
    "floconáramos": "floconar",
    "floconáreis": "floconar",
    "floconásseis": "floconar",
    "floconássemos": "floconar",
    "floconávamo": "floconar",
    "floconávamos": "floconar",
    "floconáveis": "floconar",
    "flocos": "floco",
    "flocosa": "flocoso",
    "flocosas": "flocoso",
    "flocosidades": "flocosidade",
    "flocosos": "flocoso",
    "floculada": "floculado",
    "floculadas": "floculado",
    "floculados": "floculado",
    "floculações": "floculação",
    "floemas": "floema",
    "flogistos": "flogisto",
    "flogopites": "flogopite",
    "flogopítica": "flogopítico",
    "flogopíticas": "flogopítico",
    "flogopíticos": "flogopítico",
    "flogoses": "flogose",
    "flogística": "flogístico",
    "flogísticas": "flogístico",
    "flogísticos": "flogístico",
    "flogótica": "flogótico",
    "flogóticas": "flogótico",
    "flogóticos": "flogótico",
    "flora": "florir",
    "floradas": "florada",
    "florais": "florir",
    "floram": "florir",
    "floramo": "florir",
    "floramos": "florir",
    "floras": "florir",
    "florações": "floração",
    "flore": "florir",
    "floreada": "florear",
    "floreadas": "florear",
    "floreado": "florear",
    "floreados": "florear",
    "floreai": "florear",
    "floreais": "florear",
    "floreamo": "florear",
    "floreamos": "florear",
    "floreando": "florear",
    "floreara": "florear",
    "florearam": "florear",
    "florearas": "florear",
    "florearde": "florear",
    "floreardes": "florear",
    "floreare": "florear",
    "florearei": "florear",
    "floreareis": "florear",
    "florearem": "florear",
    "florearemos": "florear",
    "floreares": "florear",
    "florearia": "florear",
    "floreariam": "florear",
    "florearias": "florear",
    "florearmo": "florear",
    "florearmos": "florear",
    "floreará": "florear",
    "florearás": "florear",
    "florearão": "florear",
    "florearíamos": "florear",
    "florearíeis": "florear",
    "floreasse": "florear",
    "floreassem": "florear",
    "floreasses": "florear",
    "floreaste": "florear",
    "floreastes": "florear",
    "floreava": "florear",
    "floreavam": "florear",
    "floreavas": "florear",
    "floreei": "florear",
    "floreeis": "florear",
    "floreemo": "florear",
    "floreemos": "florear",
    "floreia": "florear",
    "floreiam": "florear",
    "floreias": "florear",
    "floreie": "florear",
    "floreiem": "florear",
    "floreies": "florear",
    "floreio": "florear",
    "floreios": "floreio",
    "floreira": "floreiro",
    "floreiras": "floreiro",
    "floreiros": "floreiro",
    "floreja": "florejar",
    "florejada": "florejar",
    "florejadas": "florejar",
    "florejado": "florejar",
    "florejados": "florejar",
    "florejai": "florejar",
    "florejais": "florejar",
    "florejam": "florejar",
    "florejamo": "florejar",
    "florejamos": "florejar",
    "florejando": "florejar",
    "florejantes": "florejante",
    "florejara": "florejar",
    "florejaram": "florejar",
    "florejaras": "florejar",
    "florejarde": "florejar",
    "florejardes": "florejar",
    "florejare": "florejar",
    "florejarei": "florejar",
    "florejareis": "florejar",
    "florejarem": "florejar",
    "florejaremos": "florejar",
    "florejares": "florejar",
    "florejaria": "florejar",
    "florejariam": "florejar",
    "florejarias": "florejar",
    "florejarmo": "florejar",
    "florejarmos": "florejar",
    "florejará": "florejar",
    "florejarás": "florejar",
    "florejarão": "florejar",
    "florejaríamos": "florejar",
    "florejaríeis": "florejar",
    "florejas": "florejar",
    "florejasse": "florejar",
    "florejassem": "florejar",
    "florejasses": "florejar",
    "florejaste": "florejar",
    "florejastes": "florejar",
    "florejava": "florejar",
    "florejavam": "florejar",
    "florejavas": "florejar",
    "floreje": "florejar",
    "florejei": "florejar",
    "florejeis": "florejar",
    "florejem": "florejar",
    "florejemo": "florejar",
    "florejemos": "florejar",
    "florejes": "florejar",
    "florejo": "florejar",
    "florejou": "florejar",
    "florejá": "florejar",
    "florejámo": "florejar",
    "florejámos": "florejar",
    "florejáramo": "florejar",
    "florejáramos": "florejar",
    "florejárei": "florejar",
    "florejáreis": "florejar",
    "florejásseis": "florejar",
    "florejássemos": "florejar",
    "florejávamo": "florejar",
    "florejávamos": "florejar",
    "florejávei": "florejar",
    "florejáveis": "florejar",
    "florem": "florir",
    "florenciada": "florenciado",
    "florenciadas": "florenciado",
    "florenciados": "florenciado",
    "florentes": "florente",
    "florentina": "florentino",
    "florentinas": "florentino",
    "florentinos": "florentino",
    "florenças": "florença",
    "floreou": "florear",
    "flores": "florir",
    "floresce": "florescer",
    "florescei": "florescer",
    "floresceis": "florescer",
    "florescem": "florescer",
    "florescemo": "florescer",
    "florescemos": "florescer",
    "florescendo": "florescer",
    "florescentes": "florescente",
    "florescera": "florescer",
    "floresceram": "florescer",
    "floresceras": "florescer",
    "florescerdes": "florescer",
    "florescerei": "florescer",
    "florescereis": "florescer",
    "florescerem": "florescer",
    "floresceremos": "florescer",
    "floresceres": "florescer",
    "floresceria": "florescer",
    "floresceriam": "florescer",
    "florescerias": "florescer",
    "florescermo": "florescer",
    "florescermos": "florescer",
    "florescerá": "florescer",
    "florescerás": "florescer",
    "florescerão": "florescer",
    "floresceríamos": "florescer",
    "floresceríeis": "florescer",
    "floresces": "florescer",
    "florescesse": "florescer",
    "florescessem": "florescer",
    "florescesses": "florescer",
    "floresceste": "florescer",
    "florescestes": "florescer",
    "floresceu": "florescer",
    "floresci": "florescer",
    "florescia": "florescer",
    "floresciam": "florescer",
    "florescias": "florescer",
    "florescida": "florescer",
    "florescidas": "florescer",
    "florescido": "florescer",
    "florescidos": "florescer",
    "florescimentos": "florescimento",
    "florescências": "florescência",
    "florescêramo": "florescer",
    "florescêramos": "florescer",
    "florescêreis": "florescer",
    "florescêsseis": "florescer",
    "florescêssemos": "florescer",
    "florescíamo": "florescer",
    "florescíamos": "florescer",
    "florescíeis": "florescer",
    "floresta": "florestar",
    "florestada": "florestar",
    "florestadas": "florestar",
    "florestado": "florestar",
    "florestados": "florestar",
    "florestai": "florestar",
    "florestais": "florestar",
    "florestam": "florestar",
    "florestamo": "florestar",
    "florestamos": "florestar",
    "florestando": "florestar",
    "florestara": "florestar",
    "florestaram": "florestar",
    "florestaras": "florestar",
    "florestarde": "florestar",
    "florestardes": "florestar",
    "florestare": "florestar",
    "florestarei": "florestar",
    "florestareis": "florestar",
    "florestarem": "florestar",
    "florestaremos": "florestar",
    "florestares": "florestar",
    "florestaria": "florestar",
    "florestariam": "florestar",
    "florestarias": "florestar",
    "florestarmo": "florestar",
    "florestarmos": "florestar",
    "florestará": "florestar",
    "florestarás": "florestar",
    "florestarão": "florestar",
    "florestaríamos": "florestar",
    "florestaríeis": "florestar",
    "florestas": "florestar",
    "florestasse": "florestar",
    "florestassem": "florestar",
    "florestasses": "florestar",
    "florestaste": "florestar",
    "florestastes": "florestar",
    "florestava": "florestar",
    "florestavam": "florestar",
    "florestavas": "florestar",
    "florestações": "florestação",
    "floreste": "florestar",
    "florestei": "florestar",
    "floresteis": "florestar",
    "florestem": "florestar",
    "florestemo": "florestar",
    "florestemos": "florestar",
    "florestes": "florestar",
    "floresto": "florestar",
    "florestou": "florestar",
    "florestá": "florestar",
    "florestámo": "florestar",
    "florestámos": "florestar",
    "florestáramo": "florestar",
    "florestáramos": "florestar",
    "florestárei": "florestar",
    "florestáreis": "florestar",
    "florestásseis": "florestar",
    "florestássemos": "florestar",
    "florestávamo": "florestar",
    "florestávamos": "florestar",
    "florestávei": "florestar",
    "florestáveis": "florestar",
    "floresça": "florescer",
    "floresçais": "florescer",
    "floresçam": "florescer",
    "floresçamo": "florescer",
    "floresçamos": "florescer",
    "floresças": "florescer",
    "floresço": "florescer",
    "floretada": "floretado",
    "floretadas": "floretado",
    "floretados": "floretado",
    "floretas": "floreta",
    "floreteada": "floretear",
    "floreteadas": "floretear",
    "floreteado": "floretear",
    "floreteados": "floretear",
    "floreteai": "floretear",
    "floreteais": "floretear",
    "floreteamo": "floretear",
    "floreteamos": "floretear",
    "floreteando": "floretear",
    "floreteara": "floretear",
    "floretearam": "floretear",
    "floretearas": "floretear",
    "floreteardes": "floretear",
    "floretearei": "floretear",
    "floreteareis": "floretear",
    "floretearem": "floretear",
    "floretearemos": "floretear",
    "floreteares": "floretear",
    "floretearia": "floretear",
    "floreteariam": "floretear",
    "floretearias": "floretear",
    "floretearmo": "floretear",
    "floretearmos": "floretear",
    "floreteará": "floretear",
    "floretearás": "floretear",
    "floretearão": "floretear",
    "floretearíamos": "floretear",
    "floretearíeis": "floretear",
    "floreteasse": "floretear",
    "floreteassem": "floretear",
    "floreteasses": "floretear",
    "floreteaste": "floretear",
    "floreteastes": "floretear",
    "floreteava": "floretear",
    "floreteavam": "floretear",
    "floreteavas": "floretear",
    "floreteei": "floretear",
    "floreteeis": "floretear",
    "floreteemo": "floretear",
    "floreteemos": "floretear",
    "floreteia": "floretear",
    "floreteiam": "floretear",
    "floreteias": "floretear",
    "floreteie": "floretear",
    "floreteiem": "floretear",
    "floreteies": "floretear",
    "floreteio": "floretear",
    "floreteou": "floretear",
    "floretes": "florete",
    "floreteámo": "floretear",
    "floreteámos": "floretear",
    "floreteáramo": "floretear",
    "floreteáramos": "floretear",
    "floreteáreis": "floretear",
    "floreteásseis": "floretear",
    "floreteássemos": "floretear",
    "floreteávamo": "floretear",
    "floreteávamos": "floretear",
    "floreteáveis": "floretear",
    "floretistas": "floretista",
    "floreá": "florear",
    "floreámo": "florear",
    "floreámos": "florear",
    "floreáramo": "florear",
    "floreáramos": "florear",
    "floreárei": "florear",
    "floreáreis": "florear",
    "floreásseis": "florear",
    "floreássemos": "florear",
    "floreávamo": "florear",
    "floreávamos": "florear",
    "floreávei": "florear",
    "floreáveis": "florear",
    "flori": "florir",
    "floria": "florir",
    "floriam": "florir",
    "florias": "florir",
    "floricultora": "floricultor",
    "floricultoras": "floricultor",
    "floricultores": "floricultor",
    "floriculturas": "floricultura",
    "florida": "florir",
    "floridas": "florir",
    "florido": "florir",
    "floridos": "florir",
    "florilégios": "florilégio",
    "florimo": "florir",
    "florimos": "florir",
    "florindo": "florir",
    "florinha": "flor",
    "florinhas": "flor",
    "florins": "florim",
    "florira": "florir",
    "floriram": "florir",
    "floriras": "florir",
    "florirdes": "florir",
    "florirei": "florir",
    "florireis": "florir",
    "florirem": "florir",
    "floriremos": "florir",
    "florires": "florir",
    "floriria": "florir",
    "floririam": "florir",
    "floririas": "florir",
    "florirmo": "florir",
    "florirmos": "florir",
    "florirá": "florir",
    "florirás": "florir",
    "florirão": "florir",
    "floriríamos": "florir",
    "floriríeis": "florir",
    "floris": "florir",
    "florisse": "florir",
    "florissem": "florir",
    "florisses": "florir",
    "floristas": "florista",
    "floriste": "florir",
    "floristes": "florir",
    "florita": "flor",
    "floritas": "flor",
    "floriu": "florir",
    "floro": "florir",
    "floromanias": "floromania",
    "floromaníaca": "floromaníaco",
    "floromaníacas": "floromaníaco",
    "floromaníacos": "floromaníaco",
    "florzinha": "flor",
    "florzinhas": "flor",
    "florzita": "flor",
    "florzitas": "flor",
    "florências": "florência",
    "floríamo": "florir",
    "floríamos": "florir",
    "florícolas": "florícola",
    "florículos": "florículo",
    "florídeas": "florídea",
    "floríeis": "florir",
    "florífaga": "florífago",
    "florífagas": "florífago",
    "florífagos": "florífago",
    "florípara": "floríparo",
    "floríparas": "floríparo",
    "floríparos": "floríparo",
    "floríramo": "florir",
    "floríramos": "florir",
    "floríreis": "florir",
    "florísseis": "florir",
    "floríssemos": "florir",
    "florística": "florístico",
    "florísticas": "florístico",
    "florísticos": "florístico",
    "florívora": "florívoro",
    "florívoras": "florívoro",
    "florívoros": "florívoro",
    "florões": "florão",
    "flosas": "flosa",
    "flosculosa": "flosculoso",
    "flosculosas": "flosculoso",
    "flosculosos": "flosculoso",
    "flostria": "flostriar",
    "flostriada": "flostriar",
    "flostriadas": "flostriar",
    "flostriado": "flostriar",
    "flostriados": "flostriar",
    "flostriai": "flostriar",
    "flostriais": "flostriar",
    "flostriam": "flostriar",
    "flostriamo": "flostriar",
    "flostriamos": "flostriar",
    "flostriando": "flostriar",
    "flostriara": "flostriar",
    "flostriaram": "flostriar",
    "flostriaras": "flostriar",
    "flostriardes": "flostriar",
    "flostriarei": "flostriar",
    "flostriareis": "flostriar",
    "flostriarem": "flostriar",
    "flostriaremos": "flostriar",
    "flostriares": "flostriar",
    "flostriaria": "flostriar",
    "flostriariam": "flostriar",
    "flostriarias": "flostriar",
    "flostriarmo": "flostriar",
    "flostriarmos": "flostriar",
    "flostriará": "flostriar",
    "flostriarás": "flostriar",
    "flostriarão": "flostriar",
    "flostriaríamos": "flostriar",
    "flostriaríeis": "flostriar",
    "flostrias": "flostriar",
    "flostriasse": "flostriar",
    "flostriassem": "flostriar",
    "flostriasses": "flostriar",
    "flostriaste": "flostriar",
    "flostriastes": "flostriar",
    "flostriava": "flostriar",
    "flostriavam": "flostriar",
    "flostriavas": "flostriar",
    "flostrie": "flostriar",
    "flostriei": "flostriar",
    "flostrieis": "flostriar",
    "flostriem": "flostriar",
    "flostriemo": "flostriar",
    "flostriemos": "flostriar",
    "flostries": "flostriar",
    "flostrio": "flostriar",
    "flostriou": "flostriar",
    "flostriámo": "flostriar",
    "flostriámos": "flostriar",
    "flostriáramo": "flostriar",
    "flostriáramos": "flostriar",
    "flostriáreis": "flostriar",
    "flostriásseis": "flostriar",
    "flostriássemos": "flostriar",
    "flostriávamo": "flostriar",
    "flostriávamos": "flostriar",
    "flostriáveis": "flostriar",
    "flotilhas": "flotilha",
    "flua": "fluir",
    "fluais": "fluir",
    "fluam": "fluir",
    "fluamo": "fluir",
    "fluamos": "fluir",
    "fluas": "fluir",
    "flucticolora": "flucticolor",
    "flucticoloras": "flucticolor",
    "flucticolores": "flucticolor",
    "fluctícolas": "fluctícola",
    "fluctígena": "fluctígeno",
    "fluctígenas": "fluctígeno",
    "fluctígenos": "fluctígeno",
    "fluctíssona": "fluctíssono",
    "fluctíssonas": "fluctíssono",
    "fluctíssonos": "fluctíssono",
    "fluctívaga": "fluctívago",
    "fluctívagas": "fluctívago",
    "fluctívagos": "fluctívago",
    "fluem": "fluir",
    "fluentes": "fluente",
    "flui": "fluir",
    "fluida": "fluido",
    "fluidais": "fluidal",
    "fluidas": "fluido",
    "fluidificada": "fluidificado",
    "fluidificadas": "fluidificado",
    "fluidificados": "fluidificado",
    "fluidificantes": "fluidificante",
    "fluidificações": "fluidificação",
    "fluidificáveis": "fluidificável",
    "fluidos": "fluido",
    "fluindo": "fluir",
    "fluirdes": "fluir",
    "fluirei": "fluir",
    "fluireis": "fluir",
    "fluiremos": "fluir",
    "fluiria": "fluir",
    "fluiriam": "fluir",
    "fluirias": "fluir",
    "fluirmo": "fluir",
    "fluirmos": "fluir",
    "fluirá": "fluir",
    "fluirás": "fluir",
    "fluirão": "fluir",
    "fluiríamos": "fluir",
    "fluiríeis": "fluir",
    "fluis": "fluir",
    "fluiu": "fluir",
    "flumes": "flume",
    "fluminenses": "fluminense",
    "flumínea": "flumíneo",
    "flumíneas": "flumíneo",
    "flumíneos": "flumíneo",
    "fluo": "fluir",
    "fluorada": "fluorado",
    "fluoradas": "fluorado",
    "fluorados": "fluorado",
    "fluores": "fluor",
    "fluorescentes": "fluorescente",
    "fluorescências": "fluorescência",
    "fluoretos": "fluoreto",
    "fluoridratos": "fluoridrato",
    "fluorimetrias": "fluorimetria",
    "fluorimétrica": "fluorimétrico",
    "fluorimétricas": "fluorimétrico",
    "fluorimétricos": "fluorimétrico",
    "fluorina": "fluorino",
    "fluorinas": "fluorino",
    "fluorinos": "fluorino",
    "fluorites": "fluorite",
    "fluorografias": "fluorografia",
    "fluorográfica": "fluorográfico",
    "fluorográficas": "fluorográfico",
    "fluorográficos": "fluorográfico",
    "fluorométrica": "fluorométrico",
    "fluorométricas": "fluorométrico",
    "fluorométricos": "fluorométrico",
    "fluoroscopias": "fluoroscopia",
    "fluoroscópica": "fluoroscópico",
    "fluoroscópicas": "fluoroscópico",
    "fluoroscópicos": "fluoroscópico",
    "fluoroscópios": "fluoroscópio",
    "fluorídrica": "fluorídrico",
    "fluorídricas": "fluorídrico",
    "fluorídricos": "fluorídrico",
    "fluorímetros": "fluorímetro",
    "fluorítica": "fluorítico",
    "fluoríticas": "fluorítico",
    "fluoríticos": "fluorítico",
    "fluoróforos": "fluoróforo",
    "fluoxetinas": "fluoxetina",
    "flutissonantes": "flutissonante",
    "flutua": "flutuar",
    "flutuabilidades": "flutuabilidade",
    "flutuada": "flutuar",
    "flutuadas": "flutuar",
    "flutuado": "flutuar",
    "flutuadora": "flutuador",
    "flutuadoras": "flutuador",
    "flutuadores": "flutuador",
    "flutuados": "flutuar",
    "flutuai": "flutuar",
    "flutuais": "flutuar",
    "flutuam": "flutuar",
    "flutuamo": "flutuar",
    "flutuamos": "flutuar",
    "flutuando": "flutuar",
    "flutuantes": "flutuante",
    "flutuara": "flutuar",
    "flutuaram": "flutuar",
    "flutuaras": "flutuar",
    "flutuardes": "flutuar",
    "flutuarei": "flutuar",
    "flutuareis": "flutuar",
    "flutuarem": "flutuar",
    "flutuaremos": "flutuar",
    "flutuares": "flutuar",
    "flutuaria": "flutuar",
    "flutuariam": "flutuar",
    "flutuarias": "flutuar",
    "flutuarmo": "flutuar",
    "flutuarmos": "flutuar",
    "flutuará": "flutuar",
    "flutuarás": "flutuar",
    "flutuarão": "flutuar",
    "flutuaríamos": "flutuar",
    "flutuaríeis": "flutuar",
    "flutuas": "flutuar",
    "flutuasse": "flutuar",
    "flutuassem": "flutuar",
    "flutuasses": "flutuar",
    "flutuaste": "flutuar",
    "flutuastes": "flutuar",
    "flutuava": "flutuar",
    "flutuavam": "flutuar",
    "flutuavas": "flutuar",
    "flutuações": "flutuação",
    "flutue": "flutuar",
    "flutuei": "flutuar",
    "flutueis": "flutuar",
    "flutuem": "flutuar",
    "flutuemo": "flutuar",
    "flutuemos": "flutuar",
    "flutues": "flutuar",
    "flutuo": "flutuar",
    "flutuosa": "flutuoso",
    "flutuosas": "flutuoso",
    "flutuosidades": "flutuosidade",
    "flutuosos": "flutuoso",
    "flutuou": "flutuar",
    "flutuámo": "flutuar",
    "flutuámos": "flutuar",
    "flutuáramo": "flutuar",
    "flutuáramos": "flutuar",
    "flutuáreis": "flutuar",
    "flutuásseis": "flutuar",
    "flutuássemos": "flutuar",
    "flutuávamo": "flutuar",
    "flutuávamos": "flutuar",
    "flutuáveis": "flutuável",
    "fluviais": "fluvial",
    "fluviglaciária": "fluviglaciário",
    "fluviglaciárias": "fluviglaciário",
    "fluviglaciários": "fluviglaciário",
    "fluvioglaciais": "fluvioglacial",
    "fluviomarés": "fluviomaré",
    "fluviometrias": "fluviometria",
    "fluviométrica": "fluviométrico",
    "fluviométricas": "fluviométrico",
    "fluviométricos": "fluviométrico",
    "fluviáteis": "fluviátil",
    "fluviómetros": "fluviómetro",
    "fluvícolas": "fluvícola",
    "fluxa": "fluxo",
    "fluxas": "fluxo",
    "fluxibilidades": "fluxibilidade",
    "fluximetrias": "fluximetria",
    "fluximétrica": "fluximétrico",
    "fluximétricas": "fluximétrico",
    "fluximétricos": "fluximétrico",
    "fluxionária": "fluxionário",
    "fluxionárias": "fluxionário",
    "fluxionários": "fluxionário",
    "fluxogramas": "fluxograma",
    "fluxos": "fluxo",
    "fluxímetros": "fluxímetro",
    "fluxíveis": "fluxível",
    "fluxões": "fluxão",
    "fluências": "fluência",
    "fluí": "fluir",
    "fluía": "fluir",
    "fluíam": "fluir",
    "fluíamo": "fluir",
    "fluíamos": "fluir",
    "fluías": "fluir",
    "fluída": "fluir",
    "fluídas": "fluir",
    "fluídica": "fluídico",
    "fluídicas": "fluídico",
    "fluídicos": "fluídico",
    "fluído": "fluir",
    "fluídos": "fluir",
    "fluíeis": "fluir",
    "fluímo": "fluir",
    "fluímos": "fluir",
    "fluíra": "fluir",
    "fluíram": "fluir",
    "fluíramo": "fluir",
    "fluíramos": "fluir",
    "fluíras": "fluir",
    "fluíreis": "fluir",
    "fluírem": "fluir",
    "fluíres": "fluir",
    "fluís": "fluir",
    "fluísse": "fluir",
    "fluísseis": "fluir",
    "fluíssem": "fluir",
    "fluíssemos": "fluir",
    "fluísses": "fluir",
    "fluíste": "fluir",
    "fluístes": "fluir",
    "flácida": "flácido",
    "flácidas": "flácido",
    "flácidos": "flácido",
    "flâmea": "flâmeo",
    "flâmeas": "flâmeo",
    "flâmeos": "flâmeo",
    "flâmines": "flâmine",
    "flâmula": "flâmulo",
    "flâmulas": "flâmulo",
    "flâmulos": "flâmulo",
    "flébeis": "flébil",
    "flébica": "flébico",
    "flébicas": "flébico",
    "flébicos": "flébico",
    "fléxeis": "fléxil",
    "fléxiles": "fléxil",
    "flóculos": "flóculo",
    "flórea": "flóreo",
    "flóreas": "flóreo",
    "flóreos": "flóreo",
    "flórida": "flórido",
    "flóridas": "flórido",
    "flóridos": "flórido",
    "flórulas": "flórula",
    "flósculos": "flósculo",
    "flúmenes": "flúmen",
    "flúores": "flúor",
    "fobias": "fobia",
    "fobocas": "foboca",
    "fobofobias": "fobofobia",
    "fobofóbica": "fobofóbico",
    "fobofóbicas": "fobofóbico",
    "fobofóbicos": "fobofóbico",
    "fobófoba": "fobófobo",
    "fobófobas": "fobófobo",
    "fobófobos": "fobófobo",
    "foca": "focar",
    "focada": "focar",
    "focadas": "focar",
    "focado": "focar",
    "focados": "focar",
    "focagens": "focagem",
    "focai": "focar",
    "focais": "focar",
    "focaliza": "focalizar",
    "focalizada": "focalizar",
    "focalizadas": "focalizar",
    "focalizado": "focalizar",
    "focalizados": "focalizar",
    "focalizai": "focalizar",
    "focalizais": "focalizar",
    "focalizam": "focalizar",
    "focalizamo": "focalizar",
    "focalizamos": "focalizar",
    "focalizando": "focalizar",
    "focalizara": "focalizar",
    "focalizaram": "focalizar",
    "focalizaras": "focalizar",
    "focalizarde": "focalizar",
    "focalizardes": "focalizar",
    "focalizare": "focalizar",
    "focalizarei": "focalizar",
    "focalizareis": "focalizar",
    "focalizarem": "focalizar",
    "focalizaremos": "focalizar",
    "focalizares": "focalizar",
    "focalizaria": "focalizar",
    "focalizariam": "focalizar",
    "focalizarias": "focalizar",
    "focalizarmo": "focalizar",
    "focalizarmos": "focalizar",
    "focalizará": "focalizar",
    "focalizarás": "focalizar",
    "focalizarão": "focalizar",
    "focalizaríamos": "focalizar",
    "focalizaríeis": "focalizar",
    "focalizas": "focalizar",
    "focalizasse": "focalizar",
    "focalizassem": "focalizar",
    "focalizasses": "focalizar",
    "focalizaste": "focalizar",
    "focalizastes": "focalizar",
    "focalizava": "focalizar",
    "focalizavam": "focalizar",
    "focalizavas": "focalizar",
    "focalizações": "focalização",
    "focalize": "focalizar",
    "focalizei": "focalizar",
    "focalizeis": "focalizar",
    "focalizem": "focalizar",
    "focalizemo": "focalizar",
    "focalizemos": "focalizar",
    "focalizes": "focalizar",
    "focalizo": "focalizar",
    "focalizou": "focalizar",
    "focalizá": "focalizar",
    "focalizámo": "focalizar",
    "focalizámos": "focalizar",
    "focalizáramo": "focalizar",
    "focalizáramos": "focalizar",
    "focalizárei": "focalizar",
    "focalizáreis": "focalizar",
    "focalizásseis": "focalizar",
    "focalizássemos": "focalizar",
    "focalizávamo": "focalizar",
    "focalizávamos": "focalizar",
    "focalizávei": "focalizar",
    "focalizáveis": "focalizar",
    "focam": "focar",
    "focamo": "focar",
    "focamos": "focar",
    "focando": "focar",
    "focara": "focar",
    "focaram": "focar",
    "focaras": "focar",
    "focarde": "focar",
    "focardes": "focar",
    "focare": "focar",
    "focarei": "focar",
    "focareis": "focar",
    "focarem": "focar",
    "focaremos": "focar",
    "focares": "focar",
    "focaria": "focar",
    "focariam": "focar",
    "focarias": "focar",
    "focarmo": "focar",
    "focarmos": "focar",
    "focará": "focar",
    "focarás": "focar",
    "focarão": "focar",
    "focaríamos": "focar",
    "focaríeis": "focar",
    "focas": "focar",
    "focasse": "focar",
    "focassem": "focar",
    "focasses": "focar",
    "focaste": "focar",
    "focastes": "focar",
    "focava": "focar",
    "focavam": "focar",
    "focavas": "focar",
    "foce": "foçar",
    "focei": "foçar",
    "foceis": "foçar",
    "focem": "foçar",
    "focemo": "foçar",
    "focemos": "foçar",
    "foces": "foçar",
    "focinha": "focinhar",
    "focinhada": "focinhar",
    "focinhadas": "focinhar",
    "focinhado": "focinhar",
    "focinhados": "focinhar",
    "focinhai": "focinhar",
    "focinhais": "focinhar",
    "focinham": "focinhar",
    "focinhamo": "focinhar",
    "focinhamos": "focinhar",
    "focinhando": "focinhar",
    "focinhantes": "focinhante",
    "focinhara": "focinhar",
    "focinharam": "focinhar",
    "focinharas": "focinhar",
    "focinharde": "focinhar",
    "focinhardes": "focinhar",
    "focinhare": "focinhar",
    "focinharei": "focinhar",
    "focinhareis": "focinhar",
    "focinharem": "focinhar",
    "focinharemos": "focinhar",
    "focinhares": "focinhar",
    "focinharia": "focinhar",
    "focinhariam": "focinhar",
    "focinharias": "focinhar",
    "focinharmo": "focinhar",
    "focinharmos": "focinhar",
    "focinhará": "focinhar",
    "focinharás": "focinhar",
    "focinharão": "focinhar",
    "focinharíamos": "focinhar",
    "focinharíeis": "focinhar",
    "focinhas": "focinhar",
    "focinhasse": "focinhar",
    "focinhassem": "focinhar",
    "focinhasses": "focinhar",
    "focinhaste": "focinhar",
    "focinhastes": "focinhar",
    "focinhava": "focinhar",
    "focinhavam": "focinhar",
    "focinhavas": "focinhar",
    "focinhe": "focinhar",
    "focinhei": "focinhar",
    "focinheiras": "focinheira",
    "focinheis": "focinhar",
    "focinhem": "focinhar",
    "focinhemo": "focinhar",
    "focinhemos": "focinhar",
    "focinhes": "focinhar",
    "focinho": "focinhar",
    "focinhos": "focinho",
    "focinhou": "focinhar",
    "focinhuda": "focinhudo",
    "focinhudas": "focinhudo",
    "focinhudos": "focinhudo",
    "focinhá": "focinhar",
    "focinhámo": "focinhar",
    "focinhámos": "focinhar",
    "focinháramo": "focinhar",
    "focinháramos": "focinhar",
    "focinhárei": "focinhar",
    "focinháreis": "focinhar",
    "focinhásseis": "focinhar",
    "focinhássemos": "focinhar",
    "focinhávamo": "focinhar",
    "focinhávamos": "focinhar",
    "focinhávei": "focinhar",
    "focinháveis": "focinhar",
    "foco": "focar",
    "focometrias": "focometria",
    "focométrica": "focométrico",
    "focométricas": "focométrico",
    "focométricos": "focométrico",
    "focos": "foco",
    "focou": "focar",
    "focá": "focar",
    "focámo": "focar",
    "focámos": "focar",
    "focáramo": "focar",
    "focáramos": "focar",
    "focárei": "focar",
    "focáreis": "focar",
    "focásseis": "focar",
    "focássemos": "focar",
    "focávamo": "focar",
    "focávamos": "focar",
    "focávei": "focar",
    "focáveis": "focar",
    "focómetros": "focómetro",
    "foda": "foder",
    "fodais": "foder",
    "fodam": "foder",
    "fodamo": "foder",
    "fodamos": "foder",
    "fodas": "foder",
    "fode": "foder",
    "fodei": "foder",
    "fodeis": "foder",
    "fodem": "foder",
    "fodemo": "foder",
    "fodemos": "foder",
    "fodendo": "foder",
    "fodera": "foder",
    "foderam": "foder",
    "foderas": "foder",
    "foderde": "foder",
    "foderdes": "foder",
    "fodere": "foder",
    "foderei": "foder",
    "fodereis": "foder",
    "foderem": "foder",
    "foderemos": "foder",
    "foderes": "foder",
    "foderia": "foder",
    "foderiam": "foder",
    "foderias": "foder",
    "fodermo": "foder",
    "fodermos": "foder",
    "foderá": "foder",
    "foderás": "foder",
    "foderão": "foder",
    "foderíamos": "foder",
    "foderíeis": "foder",
    "fodes": "foder",
    "fodesse": "foder",
    "fodessem": "foder",
    "fodesses": "foder",
    "fodeste": "foder",
    "fodestes": "foder",
    "fodeu": "foder",
    "fodi": "foder",
    "fodia": "foder",
    "fodiam": "foder",
    "fodias": "foder",
    "fodida": "foder",
    "fodidas": "foder",
    "fodido": "foder",
    "fodidos": "foder",
    "fodo": "foder",
    "fodê": "foder",
    "fodêramo": "foder",
    "fodêramos": "foder",
    "fodêrei": "foder",
    "fodêreis": "foder",
    "fodêsseis": "foder",
    "fodêssemos": "foder",
    "fodíamo": "foder",
    "fodíamos": "foder",
    "fodíei": "foder",
    "fodíeis": "foder",
    "fofa": "fofo",
    "fofada": "fofar",
    "fofadas": "fofar",
    "fofado": "fofar",
    "fofados": "fofar",
    "fofai": "fofar",
    "fofais": "fofar",
    "fofam": "fofar",
    "fofamo": "fofar",
    "fofamos": "fofar",
    "fofando": "fofar",
    "fofara": "fofar",
    "fofaram": "fofar",
    "fofaras": "fofar",
    "fofarde": "fofar",
    "fofardes": "fofar",
    "fofare": "fofar",
    "fofarei": "fofar",
    "fofareis": "fofar",
    "fofarem": "fofar",
    "fofaremos": "fofar",
    "fofares": "fofar",
    "fofaria": "fofar",
    "fofariam": "fofar",
    "fofarias": "fofar",
    "fofarmo": "fofar",
    "fofarmos": "fofar",
    "fofará": "fofar",
    "fofarás": "fofar",
    "fofarão": "fofar",
    "fofaríamos": "fofar",
    "fofaríeis": "fofar",
    "fofas": "fofo",
    "fofasse": "fofar",
    "fofassem": "fofar",
    "fofasses": "fofar",
    "fofaste": "fofar",
    "fofastes": "fofar",
    "fofava": "fofar",
    "fofavam": "fofar",
    "fofavas": "fofar",
    "fofazinha": "fofo",
    "fofazinhas": "fofo",
    "fofazita": "fofo",
    "fofazitas": "fofo",
    "fofe": "fofar",
    "fofei": "fofar",
    "fofeis": "fofar",
    "fofem": "fofar",
    "fofemo": "fofar",
    "fofemos": "fofar",
    "fofes": "fofar",
    "fofices": "fofice",
    "fofinha": "fofo",
    "fofinhas": "fofo",
    "fofinho": "fofo",
    "fofinhos": "fofo",
    "fofita": "fofo",
    "fofitas": "fofo",
    "fofito": "fofo",
    "fofitos": "fofo",
    "fofo": "fofar",
    "fofocas": "fofoca",
    "fofona": "fofão",
    "fofonas": "fofão",
    "fofoqueira": "fofoqueiro",
    "fofoqueiras": "fofoqueiro",
    "fofoqueiros": "fofoqueiro",
    "fofoquices": "fofoquice",
    "fofos": "fofo",
    "fofou": "fofar",
    "fofozinho": "fofo",
    "fofozinhos": "fofo",
    "fofozito": "fofo",
    "fofozitos": "fofo",
    "fofá": "fofar",
    "fofámo": "fofar",
    "fofámos": "fofar",
    "fofáramo": "fofar",
    "fofáramos": "fofar",
    "fofárei": "fofar",
    "fofáreis": "fofar",
    "fofásseis": "fofar",
    "fofássemos": "fofar",
    "fofávamo": "fofar",
    "fofávamos": "fofar",
    "fofávei": "fofar",
    "fofáveis": "fofar",
    "fofões": "fofão",
    "fogaceiras": "fogaceira",
    "fogacha": "fogachar",
    "fogachada": "fogachar",
    "fogachadas": "fogachar",
    "fogachado": "fogachar",
    "fogachados": "fogachar",
    "fogachai": "fogachar",
    "fogachais": "fogachar",
    "fogacham": "fogachar",
    "fogachamo": "fogachar",
    "fogachamos": "fogachar",
    "fogachando": "fogachar",
    "fogachara": "fogachar",
    "fogacharam": "fogachar",
    "fogacharas": "fogachar",
    "fogacharde": "fogachar",
    "fogachardes": "fogachar",
    "fogachare": "fogachar",
    "fogacharei": "fogachar",
    "fogachareis": "fogachar",
    "fogacharem": "fogachar",
    "fogacharemos": "fogachar",
    "fogachares": "fogachar",
    "fogacharia": "fogachar",
    "fogachariam": "fogachar",
    "fogacharias": "fogachar",
    "fogacharmo": "fogachar",
    "fogacharmos": "fogachar",
    "fogachará": "fogachar",
    "fogacharás": "fogachar",
    "fogacharão": "fogachar",
    "fogacharíamos": "fogachar",
    "fogacharíeis": "fogachar",
    "fogachas": "fogachar",
    "fogachasse": "fogachar",
    "fogachassem": "fogachar",
    "fogachasses": "fogachar",
    "fogachaste": "fogachar",
    "fogachastes": "fogachar",
    "fogachava": "fogachar",
    "fogachavam": "fogachar",
    "fogachavas": "fogachar",
    "fogache": "fogachar",
    "fogachei": "fogachar",
    "fogacheis": "fogachar",
    "fogachem": "fogachar",
    "fogachemo": "fogachar",
    "fogachemos": "fogachar",
    "fogaches": "fogachar",
    "fogacho": "fogachar",
    "fogachos": "fogacho",
    "fogachou": "fogachar",
    "fogachá": "fogachar",
    "fogachámo": "fogachar",
    "fogachámos": "fogachar",
    "fogacháramo": "fogachar",
    "fogacháramos": "fogachar",
    "fogachárei": "fogachar",
    "fogacháreis": "fogachar",
    "fogachásseis": "fogachar",
    "fogachássemos": "fogachar",
    "fogachávamo": "fogachar",
    "fogachávamos": "fogachar",
    "fogachávei": "fogachar",
    "fogacháveis": "fogachar",
    "fogagens": "fogagem",
    "fogaleiras": "fogaleira",
    "fogalhas": "fogalha",
    "fogarachos": "fogaracho",
    "fogareiros": "fogareiro",
    "fogaréus": "fogaréu",
    "fogaças": "fogaça",
    "foge": "fugir",
    "fogem": "fugir",
    "foges": "fugir",
    "fogos": "fogo",
    "fogosa": "fogoso",
    "fogosas": "fogoso",
    "fogosidades": "fogosidade",
    "fogosos": "fogoso",
    "fogueada": "foguear",
    "fogueadas": "foguear",
    "fogueado": "foguear",
    "fogueados": "foguear",
    "fogueai": "foguear",
    "fogueais": "foguear",
    "fogueamo": "foguear",
    "fogueamos": "foguear",
    "fogueando": "foguear",
    "fogueara": "foguear",
    "foguearam": "foguear",
    "foguearas": "foguear",
    "fogueardes": "foguear",
    "foguearei": "foguear",
    "fogueareis": "foguear",
    "foguearem": "foguear",
    "foguearemos": "foguear",
    "fogueares": "foguear",
    "foguearia": "foguear",
    "fogueariam": "foguear",
    "foguearias": "foguear",
    "foguearmo": "foguear",
    "foguearmos": "foguear",
    "fogueará": "foguear",
    "foguearás": "foguear",
    "foguearão": "foguear",
    "foguearíamos": "foguear",
    "foguearíeis": "foguear",
    "fogueasse": "foguear",
    "fogueassem": "foguear",
    "fogueasses": "foguear",
    "fogueaste": "foguear",
    "fogueastes": "foguear",
    "fogueava": "foguear",
    "fogueavam": "foguear",
    "fogueavas": "foguear",
    "fogueei": "foguear",
    "fogueeis": "foguear",
    "fogueemo": "foguear",
    "fogueemos": "foguear",
    "fogueia": "foguear",
    "fogueiam": "foguear",
    "fogueias": "foguear",
    "fogueie": "foguear",
    "fogueiem": "foguear",
    "fogueies": "foguear",
    "fogueio": "foguear",
    "fogueiras": "fogueira",
    "fogueiros": "fogueiro",
    "fogueou": "foguear",
    "foguetadas": "foguetada",
    "foguetarias": "foguetaria",
    "fogueteada": "foguetear",
    "fogueteadas": "foguetear",
    "fogueteado": "foguetear",
    "fogueteados": "foguetear",
    "fogueteai": "foguetear",
    "fogueteais": "foguetear",
    "fogueteamo": "foguetear",
    "fogueteamos": "foguetear",
    "fogueteando": "foguetear",
    "fogueteara": "foguetear",
    "foguetearam": "foguetear",
    "foguetearas": "foguetear",
    "fogueteardes": "foguetear",
    "foguetearei": "foguetear",
    "fogueteareis": "foguetear",
    "foguetearem": "foguetear",
    "foguetearemos": "foguetear",
    "fogueteares": "foguetear",
    "foguetearia": "foguetear",
    "fogueteariam": "foguetear",
    "foguetearias": "foguetear",
    "foguetearmo": "foguetear",
    "foguetearmos": "foguetear",
    "fogueteará": "foguetear",
    "foguetearás": "foguetear",
    "foguetearão": "foguetear",
    "foguetearíamos": "foguetear",
    "foguetearíeis": "foguetear",
    "fogueteasse": "foguetear",
    "fogueteassem": "foguetear",
    "fogueteasses": "foguetear",
    "fogueteaste": "foguetear",
    "fogueteastes": "foguetear",
    "fogueteava": "foguetear",
    "fogueteavam": "foguetear",
    "fogueteavas": "foguetear",
    "fogueteei": "foguetear",
    "fogueteeis": "foguetear",
    "fogueteemo": "foguetear",
    "fogueteemos": "foguetear",
    "fogueteia": "foguetear",
    "fogueteiam": "foguetear",
    "fogueteias": "foguetear",
    "fogueteie": "foguetear",
    "fogueteiem": "foguetear",
    "fogueteies": "foguetear",
    "fogueteio": "foguetear",
    "fogueteiros": "fogueteiro",
    "fogueteou": "foguetear",
    "foguetes": "foguete",
    "fogueteámo": "foguetear",
    "fogueteámos": "foguetear",
    "fogueteáramo": "foguetear",
    "fogueteáramos": "foguetear",
    "fogueteáreis": "foguetear",
    "fogueteásseis": "foguetear",
    "fogueteássemos": "foguetear",
    "fogueteávamo": "foguetear",
    "fogueteávamos": "foguetear",
    "fogueteáveis": "foguetear",
    "foguetórios": "foguetório",
    "foguetões": "foguetão",
    "fogueámo": "foguear",
    "fogueámos": "foguear",
    "fogueáramo": "foguear",
    "fogueáramos": "foguear",
    "fogueáreis": "foguear",
    "fogueásseis": "foguear",
    "fogueássemos": "foguear",
    "fogueávamo": "foguear",
    "fogueávamos": "foguear",
    "fogueáveis": "foguear",
    "foguistas": "foguista",
    "fogões": "fogão",
    "foi": "ser",
    "foiaítes": "foiaíte",
    "foiaítica": "foiaítico",
    "foiaíticas": "foiaítico",
    "foiaíticos": "foiaítico",
    "foice": "foiçar",
    "foiceada": "foicear",
    "foiceadas": "foicear",
    "foiceado": "foicear",
    "foiceados": "foicear",
    "foiceai": "foicear",
    "foiceais": "foicear",
    "foiceamo": "foicear",
    "foiceamos": "foicear",
    "foiceando": "foicear",
    "foiceara": "foicear",
    "foicearam": "foicear",
    "foicearas": "foicear",
    "foicearde": "foicear",
    "foiceardes": "foicear",
    "foiceare": "foicear",
    "foicearei": "foicear",
    "foiceareis": "foicear",
    "foicearem": "foicear",
    "foicearemos": "foicear",
    "foiceares": "foicear",
    "foicearia": "foicear",
    "foiceariam": "foicear",
    "foicearias": "foicear",
    "foicearmo": "foicear",
    "foicearmos": "foicear",
    "foiceará": "foicear",
    "foicearás": "foicear",
    "foicearão": "foicear",
    "foicearíamos": "foicear",
    "foicearíeis": "foicear",
    "foiceasse": "foicear",
    "foiceassem": "foicear",
    "foiceasses": "foicear",
    "foiceaste": "foicear",
    "foiceastes": "foicear",
    "foiceava": "foicear",
    "foiceavam": "foicear",
    "foiceavas": "foicear",
    "foiceei": "foicear",
    "foiceeis": "foicear",
    "foiceemo": "foicear",
    "foiceemos": "foicear",
    "foicei": "foiçar",
    "foiceia": "foicear",
    "foiceiam": "foicear",
    "foiceias": "foicear",
    "foiceie": "foicear",
    "foiceiem": "foicear",
    "foiceies": "foicear",
    "foiceio": "foicear",
    "foiceis": "foiçar",
    "foicem": "foiçar",
    "foicemo": "foiçar",
    "foicemos": "foiçar",
    "foiceou": "foicear",
    "foices": "foice",
    "foiceá": "foicear",
    "foiceámo": "foicear",
    "foiceámos": "foicear",
    "foiceáramo": "foicear",
    "foiceáramos": "foicear",
    "foiceárei": "foicear",
    "foiceáreis": "foicear",
    "foiceásseis": "foicear",
    "foiceássemos": "foicear",
    "foiceávamo": "foicear",
    "foiceávamos": "foicear",
    "foiceávei": "foicear",
    "foiceáveis": "foicear",
    "foiciformes": "foiciforme",
    "foicinhas": "foicinha",
    "foicinhões": "foicinhão",
    "foilas": "foila",
    "foinas": "foina",
    "foios": "foio",
    "foita": "foito",
    "foitas": "foito",
    "foitezas": "foiteza",
    "foitos": "foito",
    "foiça": "foiçar",
    "foiçada": "foiçar",
    "foiçadas": "foiçar",
    "foiçado": "foiçar",
    "foiçados": "foiçar",
    "foiçai": "foiçar",
    "foiçais": "foiçar",
    "foiçam": "foiçar",
    "foiçamo": "foiçar",
    "foiçamos": "foiçar",
    "foiçando": "foiçar",
    "foiçara": "foiçar",
    "foiçaram": "foiçar",
    "foiçaras": "foiçar",
    "foiçarde": "foiçar",
    "foiçardes": "foiçar",
    "foiçare": "foiçar",
    "foiçarei": "foiçar",
    "foiçareis": "foiçar",
    "foiçarem": "foiçar",
    "foiçaremos": "foiçar",
    "foiçares": "foiçar",
    "foiçaria": "foiçar",
    "foiçariam": "foiçar",
    "foiçarias": "foiçar",
    "foiçarmo": "foiçar",
    "foiçarmos": "foiçar",
    "foiçará": "foiçar",
    "foiçarás": "foiçar",
    "foiçarão": "foiçar",
    "foiçaríamos": "foiçar",
    "foiçaríeis": "foiçar",
    "foiças": "foiçar",
    "foiçasse": "foiçar",
    "foiçassem": "foiçar",
    "foiçasses": "foiçar",
    "foiçaste": "foiçar",
    "foiçastes": "foiçar",
    "foiçava": "foiçar",
    "foiçavam": "foiçar",
    "foiçavas": "foiçar",
    "foiço": "foiçar",
    "foiçou": "foiçar",
    "foiçá": "foiçar",
    "foiçámo": "foiçar",
    "foiçámos": "foiçar",
    "foiçáramo": "foiçar",
    "foiçáramos": "foiçar",
    "foiçárei": "foiçar",
    "foiçáreis": "foiçar",
    "foiçásseis": "foiçar",
    "foiçássemos": "foiçar",
    "foiçávamo": "foiçar",
    "foiçávamos": "foiçar",
    "foiçávei": "foiçar",
    "foiçáveis": "foiçar",
    "foições": "foição",
    "fojos": "fojo",
    "folachos": "folacho",
    "folares": "folar",
    "folas": "fola",
    "folclores": "folclore",
    "folclorismos": "folclorismo",
    "folcloristas": "folclorista",
    "folclórica": "folclórico",
    "folclóricas": "folclórico",
    "folclóricos": "folclórico",
    "foleca": "folecar",
    "folecada": "folecar",
    "folecadas": "folecar",
    "folecado": "folecar",
    "folecados": "folecar",
    "folecais": "folecar",
    "folecam": "folecar",
    "folecamo": "folecar",
    "folecamos": "folecar",
    "folecando": "folecar",
    "folecara": "folecar",
    "folecaram": "folecar",
    "folecaras": "folecar",
    "folecardes": "folecar",
    "folecarei": "folecar",
    "folecareis": "folecar",
    "folecarem": "folecar",
    "folecaremos": "folecar",
    "folecares": "folecar",
    "folecaria": "folecar",
    "folecariam": "folecar",
    "folecarias": "folecar",
    "folecarmo": "folecar",
    "folecarmos": "folecar",
    "folecará": "folecar",
    "folecarás": "folecar",
    "folecarão": "folecar",
    "folecaríamos": "folecar",
    "folecaríeis": "folecar",
    "folecas": "folecar",
    "folecasse": "folecar",
    "folecassem": "folecar",
    "folecasses": "folecar",
    "folecaste": "folecar",
    "folecastes": "folecar",
    "folecava": "folecar",
    "folecavam": "folecar",
    "folecavas": "folecar",
    "folechas": "folecha",
    "folechos": "folecho",
    "foleco": "folecar",
    "folecos": "foleco",
    "folecou": "folecar",
    "folecámo": "folecar",
    "folecámos": "folecar",
    "folecáramo": "folecar",
    "folecáramos": "folecar",
    "folecáreis": "folecar",
    "folecásseis": "folecar",
    "folecássemos": "folecar",
    "folecávamo": "folecar",
    "folecávamos": "folecar",
    "folecáveis": "folecar",
    "foleira": "foleiro",
    "foleiras": "foleiro",
    "foleirazinha": "foleiro",
    "foleirazinhas": "foleiro",
    "foleirazita": "foleiro",
    "foleirazitas": "foleiro",
    "foleirinha": "foleiro",
    "foleirinhas": "foleiro",
    "foleirinho": "foleiro",
    "foleirinhos": "foleiro",
    "foleirita": "foleiro",
    "foleiritas": "foleiro",
    "foleirito": "foleiro",
    "foleiritos": "foleiro",
    "foleirona": "foleirão",
    "foleironas": "foleirão",
    "foleiros": "foleiro",
    "foleirozinho": "foleiro",
    "foleirozinhos": "foleiro",
    "foleirozito": "foleiro",
    "foleirozitos": "foleiro",
    "foleirões": "foleirão",
    "foleque": "folecar",
    "folequei": "folecar",
    "folequeis": "folecar",
    "folequem": "folecar",
    "folequemos": "folecar",
    "foleques": "folecar",
    "foles": "fole",
    "folga": "folgar",
    "folgada": "folgar",
    "folgadas": "folgar",
    "folgado": "folgar",
    "folgadora": "folgador",
    "folgadoras": "folgador",
    "folgadores": "folgador",
    "folgados": "folgar",
    "folgai": "folgar",
    "folgais": "folgar",
    "folgam": "folgar",
    "folgamo": "folgar",
    "folgamos": "folgar",
    "folgando": "folgar",
    "folgantes": "folgante",
    "folganças": "folgança",
    "folgara": "folgar",
    "folgaram": "folgar",
    "folgaras": "folgar",
    "folgarde": "folgar",
    "folgardes": "folgar",
    "folgare": "folgar",
    "folgarei": "folgar",
    "folgareis": "folgar",
    "folgarem": "folgar",
    "folgaremos": "folgar",
    "folgares": "folgar",
    "folgaria": "folgar",
    "folgariam": "folgar",
    "folgarias": "folgar",
    "folgarmo": "folgar",
    "folgarmos": "folgar",
    "folgará": "folgar",
    "folgarás": "folgar",
    "folgarão": "folgar",
    "folgaríamos": "folgar",
    "folgaríeis": "folgar",
    "folgas": "folgar",
    "folgasse": "folgar",
    "folgassem": "folgar",
    "folgasses": "folgar",
    "folgaste": "folgar",
    "folgastes": "folgar",
    "folgativa": "folgativo",
    "folgativas": "folgativo",
    "folgativos": "folgativo",
    "folgava": "folgar",
    "folgavam": "folgar",
    "folgavas": "folgar",
    "folgaza": "folgazar",
    "folgazada": "folgazar",
    "folgazadas": "folgazar",
    "folgazado": "folgazar",
    "folgazados": "folgazar",
    "folgazai": "folgazar",
    "folgazais": "folgazar",
    "folgazam": "folgazar",
    "folgazamo": "folgazar",
    "folgazamos": "folgazar",
    "folgazando": "folgazar",
    "folgazara": "folgazar",
    "folgazaram": "folgazar",
    "folgazaras": "folgazar",
    "folgazardes": "folgazar",
    "folgazarei": "folgazar",
    "folgazareis": "folgazar",
    "folgazarem": "folgazar",
    "folgazaremos": "folgazar",
    "folgazares": "folgazar",
    "folgazaria": "folgazar",
    "folgazariam": "folgazar",
    "folgazarias": "folgazar",
    "folgazarmo": "folgazar",
    "folgazarmos": "folgazar",
    "folgazará": "folgazar",
    "folgazarás": "folgazar",
    "folgazarão": "folgazar",
    "folgazaríamos": "folgazar",
    "folgazaríeis": "folgazar",
    "folgazas": "folgazar",
    "folgazasse": "folgazar",
    "folgazassem": "folgazar",
    "folgazasses": "folgazar",
    "folgazaste": "folgazar",
    "folgazastes": "folgazar",
    "folgazava": "folgazar",
    "folgazavam": "folgazar",
    "folgazavas": "folgazar",
    "folgaze": "folgazar",
    "folgazei": "folgazar",
    "folgazeis": "folgazar",
    "folgazem": "folgazar",
    "folgazemo": "folgazar",
    "folgazemos": "folgazar",
    "folgazes": "folgazar",
    "folgazo": "folgazar",
    "folgazou": "folgazar",
    "folgazámo": "folgazar",
    "folgazámos": "folgazar",
    "folgazáramo": "folgazar",
    "folgazáramos": "folgazar",
    "folgazáreis": "folgazar",
    "folgazásseis": "folgazar",
    "folgazássemos": "folgazar",
    "folgazávamo": "folgazar",
    "folgazávamos": "folgazar",
    "folgazáveis": "folgazar",
    "folgazã": "folgazão",
    "folgazãs": "folgazão",
    "folgazões": "folgazão",
    "folgo": "folgar",
    "folgos": "folgo",
    "folgou": "folgar",
    "folgozinhos": "folgozinho",
    "folgozona": "folgozão",
    "folgozonas": "folgozão",
    "folgozões": "folgozão",
    "folgue": "folgar",
    "folguedos": "folguedo",
    "folguei": "folgar",
    "folgueis": "folgar",
    "folguem": "folgar",
    "folguemo": "folgar",
    "folguemos": "folgar",
    "folgues": "folgar",
    "folgá": "folgar",
    "folgámo": "folgar",
    "folgámos": "folgar",
    "folgáramo": "folgar",
    "folgáramos": "folgar",
    "folgárei": "folgar",
    "folgáreis": "folgar",
    "folgásseis": "folgar",
    "folgássemos": "folgar",
    "folgávamo": "folgar",
    "folgávamos": "folgar",
    "folgávei": "folgar",
    "folgáveis": "folgar",
    "folha": "folhar",
    "folhada": "folhar",
    "folhadas": "folhar",
    "folhado": "folhar",
    "folhados": "folhar",
    "folhagens": "folhagem",
    "folhai": "folhar",
    "folhais": "folhar",
    "folham": "folhar",
    "folhames": "folhame",
    "folhamo": "folhar",
    "folhamos": "folhar",
    "folhando": "folhar",
    "folhara": "folhar",
    "folharam": "folhar",
    "folharas": "folhar",
    "folharde": "folhar",
    "folhardes": "folhar",
    "folhare": "folhar",
    "folharei": "folhar",
    "folhareis": "folhar",
    "folharem": "folhar",
    "folharemos": "folhar",
    "folhares": "folhar",
    "folharia": "folhar",
    "folhariam": "folhar",
    "folharias": "folharia",
    "folharmo": "folhar",
    "folharmos": "folhar",
    "folhará": "folhar",
    "folharás": "folhar",
    "folharão": "folhar",
    "folharíamos": "folhar",
    "folharíeis": "folhar",
    "folhas": "folhar",
    "folhasse": "folhar",
    "folhassem": "folhar",
    "folhasses": "folhar",
    "folhaste": "folhar",
    "folhastes": "folhar",
    "folhatos": "folhato",
    "folhava": "folhar",
    "folhavam": "folhar",
    "folhavas": "folhar",
    "folhe": "folhar",
    "folheada": "folhear",
    "folheadas": "folhear",
    "folheado": "folhear",
    "folheadora": "folheador",
    "folheadoras": "folheador",
    "folheadores": "folheador",
    "folheados": "folhear",
    "folheai": "folhear",
    "folheais": "folhear",
    "folheamentos": "folheamento",
    "folheamo": "folhear",
    "folheamos": "folhear",
    "folheando": "folhear",
    "folheara": "folhear",
    "folhearam": "folhear",
    "folhearas": "folhear",
    "folhearde": "folhear",
    "folheardes": "folhear",
    "folheare": "folhear",
    "folhearei": "folhear",
    "folheareis": "folhear",
    "folhearem": "folhear",
    "folhearemos": "folhear",
    "folheares": "folhear",
    "folhearia": "folhear",
    "folheariam": "folhear",
    "folhearias": "folhear",
    "folhearmo": "folhear",
    "folhearmos": "folhear",
    "folheará": "folhear",
    "folhearás": "folhear",
    "folhearão": "folhear",
    "folhearíamos": "folhear",
    "folhearíeis": "folhear",
    "folheasse": "folhear",
    "folheassem": "folhear",
    "folheasses": "folhear",
    "folheaste": "folhear",
    "folheastes": "folhear",
    "folheaturas": "folheatura",
    "folheava": "folhear",
    "folheavam": "folhear",
    "folheavas": "folhear",
    "folheações": "folheação",
    "folheca": "folhecar",
    "folhecada": "folhecar",
    "folhecadas": "folhecar",
    "folhecado": "folhecar",
    "folhecados": "folhecar",
    "folhecais": "folhecar",
    "folhecam": "folhecar",
    "folhecamo": "folhecar",
    "folhecamos": "folhecar",
    "folhecando": "folhecar",
    "folhecara": "folhecar",
    "folhecaram": "folhecar",
    "folhecaras": "folhecar",
    "folhecardes": "folhecar",
    "folhecarei": "folhecar",
    "folhecareis": "folhecar",
    "folhecarem": "folhecar",
    "folhecaremos": "folhecar",
    "folhecares": "folhecar",
    "folhecaria": "folhecar",
    "folhecariam": "folhecar",
    "folhecarias": "folhecar",
    "folhecarmo": "folhecar",
    "folhecarmos": "folhecar",
    "folhecará": "folhecar",
    "folhecarás": "folhecar",
    "folhecarão": "folhecar",
    "folhecaríamos": "folhecar",
    "folhecaríeis": "folhecar",
    "folhecas": "folhecar",
    "folhecasse": "folhecar",
    "folhecassem": "folhecar",
    "folhecasses": "folhecar",
    "folhecaste": "folhecar",
    "folhecastes": "folhecar",
    "folhecava": "folhecar",
    "folhecavam": "folhecar",
    "folhecavas": "folhecar",
    "folheco": "folhecar",
    "folhecou": "folhecar",
    "folhecámo": "folhecar",
    "folhecámos": "folhecar",
    "folhecáramo": "folhecar",
    "folhecáramos": "folhecar",
    "folhecáreis": "folhecar",
    "folhecásseis": "folhecar",
    "folhecássemos": "folhecar",
    "folhecávamo": "folhecar",
    "folhecávamos": "folhecar",
    "folhecáveis": "folhecável",
    "folhedos": "folhedo",
    "folheei": "folhear",
    "folheeis": "folhear",
    "folheemo": "folhear",
    "folheemos": "folhear",
    "folhei": "folhar",
    "folheia": "folhear",
    "folheiam": "folhear",
    "folheias": "folhear",
    "folheie": "folhear",
    "folheiem": "folhear",
    "folheies": "folhear",
    "folheio": "folhear",
    "folheios": "folheio",
    "folheira": "folheiro",
    "folheiras": "folheiro",
    "folheiros": "folheiro",
    "folheis": "folhar",
    "folhelhos": "folhelho",
    "folhem": "folhar",
    "folhemo": "folhar",
    "folhemos": "folhar",
    "folhenta": "folhento",
    "folhentas": "folhento",
    "folhentos": "folhento",
    "folheou": "folhear",
    "folhepos": "folhepo",
    "folheque": "folhecar",
    "folhequei": "folhecar",
    "folhequeis": "folhecar",
    "folhequem": "folhecar",
    "folhequemos": "folhecar",
    "folheques": "folhecar",
    "folhes": "folhar",
    "folhetarias": "folhetaria",
    "folhetas": "folheta",
    "folheteada": "folhetear",
    "folheteadas": "folhetear",
    "folheteado": "folhetear",
    "folheteados": "folhetear",
    "folheteai": "folhetear",
    "folheteais": "folhetear",
    "folheteamo": "folhetear",
    "folheteamos": "folhetear",
    "folheteando": "folhetear",
    "folheteara": "folhetear",
    "folhetearam": "folhetear",
    "folhetearas": "folhetear",
    "folhetearde": "folhetear",
    "folheteardes": "folhetear",
    "folheteare": "folhetear",
    "folhetearei": "folhetear",
    "folheteareis": "folhetear",
    "folhetearem": "folhetear",
    "folhetearemos": "folhetear",
    "folheteares": "folhetear",
    "folhetearia": "folhetear",
    "folheteariam": "folhetear",
    "folhetearias": "folhetear",
    "folhetearmo": "folhetear",
    "folhetearmos": "folhetear",
    "folheteará": "folhetear",
    "folhetearás": "folhetear",
    "folhetearão": "folhetear",
    "folhetearíamos": "folhetear",
    "folhetearíeis": "folhetear",
    "folheteasse": "folhetear",
    "folheteassem": "folhetear",
    "folheteasses": "folhetear",
    "folheteaste": "folhetear",
    "folheteastes": "folhetear",
    "folheteava": "folhetear",
    "folheteavam": "folhetear",
    "folheteavas": "folhetear",
    "folheteei": "folhetear",
    "folheteeis": "folhetear",
    "folheteemo": "folhetear",
    "folheteemos": "folhetear",
    "folheteia": "folhetear",
    "folheteiam": "folhetear",
    "folheteias": "folhetear",
    "folheteie": "folhetear",
    "folheteiem": "folhetear",
    "folheteies": "folhetear",
    "folheteio": "folhetear",
    "folheteira": "folheteiro",
    "folheteiras": "folheteiro",
    "folheteiros": "folheteiro",
    "folheteou": "folhetear",
    "folheteá": "folhetear",
    "folheteámo": "folhetear",
    "folheteámos": "folhetear",
    "folheteáramo": "folhetear",
    "folheteáramos": "folhetear",
    "folheteárei": "folhetear",
    "folheteáreis": "folhetear",
    "folheteásseis": "folhetear",
    "folheteássemos": "folhetear",
    "folheteávamo": "folhetear",
    "folheteávamos": "folhetear",
    "folheteávei": "folhetear",
    "folheteáveis": "folheteável",
    "folhetinesca": "folhetinesco",
    "folhetinescas": "folhetinesco",
    "folhetinescos": "folhetinesco",
    "folhetinistas": "folhetinista",
    "folhetiniza": "folhetinizar",
    "folhetinizada": "folhetinizar",
    "folhetinizadas": "folhetinizar",
    "folhetinizado": "folhetinizar",
    "folhetinizados": "folhetinizar",
    "folhetinizai": "folhetinizar",
    "folhetinizais": "folhetinizar",
    "folhetinizam": "folhetinizar",
    "folhetinizamo": "folhetinizar",
    "folhetinizamos": "folhetinizar",
    "folhetinizando": "folhetinizar",
    "folhetinizara": "folhetinizar",
    "folhetinizaram": "folhetinizar",
    "folhetinizaras": "folhetinizar",
    "folhetinizarde": "folhetinizar",
    "folhetinizardes": "folhetinizar",
    "folhetinizare": "folhetinizar",
    "folhetinizarei": "folhetinizar",
    "folhetinizareis": "folhetinizar",
    "folhetinizarem": "folhetinizar",
    "folhetinizaremos": "folhetinizar",
    "folhetinizares": "folhetinizar",
    "folhetinizaria": "folhetinizar",
    "folhetinizariam": "folhetinizar",
    "folhetinizarias": "folhetinizar",
    "folhetinizarmo": "folhetinizar",
    "folhetinizarmos": "folhetinizar",
    "folhetinizará": "folhetinizar",
    "folhetinizarás": "folhetinizar",
    "folhetinizarão": "folhetinizar",
    "folhetinizaríamos": "folhetinizar",
    "folhetinizaríeis": "folhetinizar",
    "folhetinizas": "folhetinizar",
    "folhetinizasse": "folhetinizar",
    "folhetinizassem": "folhetinizar",
    "folhetinizasses": "folhetinizar",
    "folhetinizaste": "folhetinizar",
    "folhetinizastes": "folhetinizar",
    "folhetinizava": "folhetinizar",
    "folhetinizavam": "folhetinizar",
    "folhetinizavas": "folhetinizar",
    "folhetinize": "folhetinizar",
    "folhetinizei": "folhetinizar",
    "folhetinizeis": "folhetinizar",
    "folhetinizem": "folhetinizar",
    "folhetinizemo": "folhetinizar",
    "folhetinizemos": "folhetinizar",
    "folhetinizes": "folhetinizar",
    "folhetinizo": "folhetinizar",
    "folhetinizou": "folhetinizar",
    "folhetinizá": "folhetinizar",
    "folhetinizámo": "folhetinizar",
    "folhetinizámos": "folhetinizar",
    "folhetinizáramo": "folhetinizar",
    "folhetinizáramos": "folhetinizar",
    "folhetinizárei": "folhetinizar",
    "folhetinizáreis": "folhetinizar",
    "folhetinizásseis": "folhetinizar",
    "folhetinizássemos": "folhetinizar",
    "folhetinizávamo": "folhetinizar",
    "folhetinizávamos": "folhetinizar",
    "folhetinizávei": "folhetinizar",
    "folhetinizáveis": "folhetinizar",
    "folhetins": "folhetim",
    "folhetinzinho": "folhetim",
    "folhetinzinhos": "folhetim",
    "folhetinzito": "folhetim",
    "folhetinzitos": "folhetim",
    "folhetinística": "folhetinístico",
    "folhetinísticas": "folhetinístico",
    "folhetinísticos": "folhetinístico",
    "folhetos": "folheto",
    "folheá": "folhear",
    "folheámo": "folhear",
    "folheámos": "folhear",
    "folheáramo": "folhear",
    "folheáramos": "folhear",
    "folheárei": "folhear",
    "folheáreis": "folhear",
    "folheásseis": "folhear",
    "folheássemos": "folhear",
    "folheávamo": "folhear",
    "folheávamos": "folhear",
    "folheávei": "folhear",
    "folheáveis": "folheável",
    "folhinha": "folha",
    "folhinhas": "folhinha",
    "folhita": "folha",
    "folhitas": "folha",
    "folho": "folhar",
    "folhos": "folho",
    "folhosa": "folhoso",
    "folhosas": "folhoso",
    "folhosos": "folhoso",
    "folhou": "folhar",
    "folhuda": "folhudo",
    "folhudas": "folhudo",
    "folhudos": "folhudo",
    "folhá": "folhar",
    "folhámo": "folhar",
    "folhámos": "folhar",
    "folháramo": "folhar",
    "folháramos": "folhar",
    "folhárei": "folhar",
    "folháreis": "folhar",
    "folhásseis": "folhar",
    "folhássemos": "folhar",
    "folhávamo": "folhar",
    "folhávamos": "folhar",
    "folhávei": "folhar",
    "folháveis": "folhar",
    "folhões": "folhão",
    "folia": "foliar",
    "foliada": "foliar",
    "foliadas": "foliar",
    "foliado": "foliar",
    "foliadora": "foliador",
    "foliadoras": "foliador",
    "foliadores": "foliador",
    "foliados": "foliar",
    "foliaguda": "foliagudo",
    "foliagudas": "foliagudo",
    "foliagudos": "foliagudo",
    "foliai": "foliar",
    "foliais": "foliar",
    "foliam": "foliar",
    "foliamo": "foliar",
    "foliamos": "foliar",
    "foliando": "foliar",
    "foliara": "foliar",
    "foliaram": "foliar",
    "foliaras": "foliar",
    "foliardes": "foliar",
    "foliarei": "foliar",
    "foliareis": "foliar",
    "foliarem": "foliar",
    "foliaremos": "foliar",
    "foliares": "foliar",
    "foliaria": "foliar",
    "foliariam": "foliar",
    "foliarias": "foliar",
    "foliarmo": "foliar",
    "foliarmos": "foliar",
    "foliará": "foliar",
    "foliarás": "foliar",
    "foliarão": "foliar",
    "foliaríamos": "foliar",
    "foliaríeis": "foliar",
    "folias": "foliar",
    "foliasse": "foliar",
    "foliassem": "foliar",
    "foliasses": "foliar",
    "foliaste": "foliar",
    "foliastes": "foliar",
    "foliava": "foliar",
    "foliavam": "foliar",
    "foliavas": "foliar",
    "foliações": "foliação",
    "foliculares": "folicular",
    "foliculinas": "foliculina",
    "foliculomas": "foliculoma",
    "foliculosa": "foliculoso",
    "foliculosas": "foliculoso",
    "foliculosos": "foliculoso",
    "foliculários": "foliculário",
    "foliculínica": "foliculínico",
    "foliculínicas": "foliculínico",
    "foliculínicos": "foliculínico",
    "foliculítica": "foliculítico",
    "foliculíticas": "foliculítico",
    "foliculíticos": "foliculítico",
    "folie": "foliar",
    "foliei": "foliar",
    "folieis": "foliar",
    "foliem": "foliar",
    "foliemo": "foliar",
    "foliemos": "foliar",
    "folienta": "foliento",
    "folientas": "foliento",
    "folientos": "foliento",
    "folies": "foliar",
    "foliformes": "foliforme",
    "folio": "foliar",
    "foliolada": "foliolado",
    "folioladas": "foliolado",
    "foliolados": "foliolado",
    "foliona": "folião",
    "folionas": "folião",
    "foliosa": "folioso",
    "foliosas": "folioso",
    "foliosos": "folioso",
    "foliou": "foliar",
    "folipas": "folipa",
    "folipos": "folipo",
    "foliácea": "foliáceo",
    "foliáceas": "foliáceo",
    "foliáceos": "foliáceo",
    "foliámo": "foliar",
    "foliámos": "foliar",
    "foliáramo": "foliar",
    "foliáramos": "foliar",
    "foliáreis": "foliar",
    "foliásseis": "foliar",
    "foliássemos": "foliar",
    "foliávamo": "foliar",
    "foliávamos": "foliar",
    "foliáveis": "foliar",
    "foliões": "folião",
    "folosas": "folosa",
    "folosinhos": "folosinho",
    "folícolas": "folícola",
    "folículos": "folículo",
    "folífaga": "folífago",
    "folífagas": "folífago",
    "folífagos": "folífago",
    "folífera": "folífero",
    "folíferas": "folífero",
    "folíferos": "folífero",
    "folíolos": "folíolo",
    "folípaga": "folípago",
    "folípagas": "folípago",
    "folípagos": "folípago",
    "folípara": "folíparo",
    "folíparas": "folíparo",
    "folíparos": "folíparo",
    "fomecas": "fomeca",
    "fomenicas": "fomenica",
    "fomenta": "fomentar",
    "fomentada": "fomentar",
    "fomentadas": "fomentar",
    "fomentado": "fomentar",
    "fomentadora": "fomentador",
    "fomentadoras": "fomentador",
    "fomentadores": "fomentador",
    "fomentados": "fomentar",
    "fomentai": "fomentar",
    "fomentais": "fomentar",
    "fomentam": "fomentar",
    "fomentamo": "fomentar",
    "fomentamos": "fomentar",
    "fomentando": "fomentar",
    "fomentara": "fomentar",
    "fomentaram": "fomentar",
    "fomentaras": "fomentar",
    "fomentarde": "fomentar",
    "fomentardes": "fomentar",
    "fomentare": "fomentar",
    "fomentarei": "fomentar",
    "fomentareis": "fomentar",
    "fomentarem": "fomentar",
    "fomentaremos": "fomentar",
    "fomentares": "fomentar",
    "fomentaria": "fomentar",
    "fomentariam": "fomentar",
    "fomentarias": "fomentar",
    "fomentarmo": "fomentar",
    "fomentarmos": "fomentar",
    "fomentará": "fomentar",
    "fomentarás": "fomentar",
    "fomentarão": "fomentar",
    "fomentaríamos": "fomentar",
    "fomentaríeis": "fomentar",
    "fomentas": "fomentar",
    "fomentasse": "fomentar",
    "fomentassem": "fomentar",
    "fomentasses": "fomentar",
    "fomentaste": "fomentar",
    "fomentastes": "fomentar",
    "fomentativa": "fomentativo",
    "fomentativas": "fomentativo",
    "fomentativos": "fomentativo",
    "fomentava": "fomentar",
    "fomentavam": "fomentar",
    "fomentavas": "fomentar",
    "fomentações": "fomentação",
    "fomente": "fomentar",
    "fomentei": "fomentar",
    "fomenteis": "fomentar",
    "fomentem": "fomentar",
    "fomentemo": "fomentar",
    "fomentemos": "fomentar",
    "fomentes": "fomentar",
    "fomentistas": "fomentista",
    "fomento": "fomentar",
    "fomentos": "fomento",
    "fomentou": "fomentar",
    "fomentá": "fomentar",
    "fomentámo": "fomentar",
    "fomentámos": "fomentar",
    "fomentáramo": "fomentar",
    "fomentáramos": "fomentar",
    "fomentárei": "fomentar",
    "fomentáreis": "fomentar",
    "fomentásseis": "fomentar",
    "fomentássemos": "fomentar",
    "fomentávamo": "fomentar",
    "fomentávamos": "fomentar",
    "fomentávei": "fomentar",
    "fomentáveis": "fomentável",
    "fomes": "fome",
    "fominha": "fome",
    "fominhas": "fome",
    "fomita": "fome",
    "fomitas": "fome",
    "fomo": "ser",
    "fomos": "ser",
    "fonadora": "fonador",
    "fonadoras": "fonador",
    "fonadores": "fonador",
    "fonalidades": "fonalidade",
    "fonas": "fona",
    "fonascias": "fonascia",
    "fonascos": "fonasco",
    "fonastenias": "fonastenia",
    "fonasténica": "fonasténico",
    "fonasténicas": "fonasténico",
    "fonasténicos": "fonasténico",
    "fonações": "fonação",
    "fonemas": "fonema",
    "fonemática": "fonemático",
    "fonemáticas": "fonemático",
    "fonemáticos": "fonemático",
    "fonendoscopias": "fonendoscopia",
    "fonendoscópica": "fonendoscópico",
    "fonendoscópicas": "fonendoscópico",
    "fonendoscópicos": "fonendoscópico",
    "fonendoscópios": "fonendoscópio",
    "fones": "fone",
    "foneticismos": "foneticismo",
    "foneticistas": "foneticista",
    "fonetismos": "fonetismo",
    "fonetistas": "fonetista",
    "fonias": "fonia",
    "foniatras": "foniatra",
    "foniatrias": "foniatria",
    "fonidoscópica": "fonidoscópico",
    "fonidoscópicas": "fonidoscópico",
    "fonidoscópicos": "fonidoscópico",
    "fonidoscópios": "fonidoscópio",
    "foniátrica": "foniátrico",
    "foniátricas": "foniátrico",
    "foniátricos": "foniátrico",
    "fonocardiogramas": "fonocardiograma",
    "fonocardiogramática": "fonocardiogramático",
    "fonocardiogramáticas": "fonocardiogramático",
    "fonocardiogramáticos": "fonocardiogramático",
    "fonocardiográfica": "fonocardiográfico",
    "fonocardiográficas": "fonocardiográfico",
    "fonocardiográficos": "fonocardiográfico",
    "fonocinematografias": "fonocinematografia",
    "fonocinematográfica": "fonocinematográfico",
    "fonocinematográficas": "fonocinematográfico",
    "fonocinematográficos": "fonocinematográfico",
    "fonocâmptica": "fonocâmptico",
    "fonocâmpticas": "fonocâmptico",
    "fonocâmpticos": "fonocâmptico",
    "fonodoscópica": "fonodoscópico",
    "fonodoscópicas": "fonodoscópico",
    "fonodoscópicos": "fonodoscópico",
    "fonofilmagens": "fonofilmagem",
    "fonofilmes": "fonofilme",
    "fonofobias": "fonofobia",
    "fonofílmica": "fonofílmico",
    "fonofílmicas": "fonofílmico",
    "fonofílmicos": "fonofílmico",
    "fonofóbica": "fonofóbico",
    "fonofóbicas": "fonofóbico",
    "fonofóbicos": "fonofóbico",
    "fonografias": "fonografia",
    "fonogramas": "fonograma",
    "fonográfica": "fonográfico",
    "fonográficas": "fonográfico",
    "fonográficos": "fonográfico",
    "fonoidoscópios": "fonoidoscópio",
    "fonologias": "fonologia",
    "fonologistas": "fonologista",
    "fonolítica": "fonolítico",
    "fonolíticas": "fonolítico",
    "fonolíticos": "fonolítico",
    "fonológica": "fonológico",
    "fonológicas": "fonológico",
    "fonológicos": "fonológico",
    "fonometrias": "fonometria",
    "fonométrica": "fonométrico",
    "fonométricas": "fonométrico",
    "fonométricos": "fonométrico",
    "fonospsias": "fonospsia",
    "fonospásmica": "fonospásmico",
    "fonospásmicas": "fonospásmico",
    "fonospásmicos": "fonospásmico",
    "fonotecas": "fonoteca",
    "fontais": "fontal",
    "fontana": "fontano",
    "fontanais": "fontanal",
    "fontanas": "fontano",
    "fontanelas": "fontanela",
    "fontanos": "fontano",
    "fontanários": "fontanário",
    "fontaínhas": "fontaínha",
    "fontecas": "fonteca",
    "fonteiras": "fonteira",
    "fontelas": "fontela",
    "fontenários": "fontenário",
    "fontes": "fonte",
    "fontículas": "fontícula",
    "fontículos": "fontículo",
    "fonémica": "fonémico",
    "fonémicas": "fonémico",
    "fonémicos": "fonémico",
    "fonética": "fonético",
    "fonéticas": "fonético",
    "fonéticos": "fonético",
    "fonófoba": "fonófobo",
    "fonófobas": "fonófobo",
    "fonófobos": "fonófobo",
    "fonógrafos": "fonógrafo",
    "fonólitos": "fonólito",
    "fonóloga": "fonólogo",
    "fonólogas": "fonólogo",
    "fonólogos": "fonólogo",
    "fonómetros": "fonómetro",
    "fonões": "fonão",
    "fopas": "fopa",
    "foque": "focar",
    "foquei": "focar",
    "foqueis": "focar",
    "foquem": "focar",
    "foquemo": "focar",
    "foquemos": "focar",
    "foques": "focar",
    "for": "ser",
    "fora": "ser",
    "forage": "foragir",
    "foragem": "foragir",
    "forages": "foragir",
    "foragi": "foragir",
    "foragia": "foragir",
    "foragiam": "foragir",
    "foragias": "foragir",
    "foragida": "foragir",
    "foragidas": "foragir",
    "foragido": "foragir",
    "foragidos": "foragir",
    "foragimo": "foragir",
    "foragimos": "foragir",
    "foragindo": "foragir",
    "foragira": "foragir",
    "foragiram": "foragir",
    "foragiras": "foragir",
    "foragirde": "foragir",
    "foragirdes": "foragir",
    "foragire": "foragir",
    "foragirei": "foragir",
    "foragireis": "foragir",
    "foragirem": "foragir",
    "foragiremos": "foragir",
    "foragires": "foragir",
    "foragiria": "foragir",
    "foragiriam": "foragir",
    "foragirias": "foragir",
    "foragirmo": "foragir",
    "foragirmos": "foragir",
    "foragirá": "foragir",
    "foragirás": "foragir",
    "foragirão": "foragir",
    "foragiríamos": "foragir",
    "foragiríeis": "foragir",
    "foragis": "foragir",
    "foragisse": "foragir",
    "foragissem": "foragir",
    "foragisses": "foragir",
    "foragiste": "foragir",
    "foragistes": "foragir",
    "foragiu": "foragir",
    "foragíamo": "foragir",
    "foragíamos": "foragir",
    "foragíei": "foragir",
    "foragíeis": "foragir",
    "foragíramo": "foragir",
    "foragíramos": "foragir",
    "foragírei": "foragir",
    "foragíreis": "foragir",
    "foragísseis": "foragir",
    "foragíssemos": "foragir",
    "forais": "foral",
    "foraja": "foragir",
    "forajais": "foragir",
    "forajam": "foragir",
    "forajamo": "foragir",
    "forajamos": "foragir",
    "forajas": "foragir",
    "forajo": "foragir",
    "foraleira": "foraleiro",
    "foraleiras": "foraleiro",
    "foraleiros": "foraleiro",
    "foralenga": "foralengo",
    "foralengas": "foralengo",
    "foralengos": "foralengo",
    "foram": "ser",
    "forames": "forame",
    "foraminosa": "foraminoso",
    "foraminosas": "foraminoso",
    "foraminosos": "foraminoso",
    "foraminífera": "foraminífero",
    "foraminíferas": "foraminífero",
    "foraminíferos": "foraminífero",
    "foramontana": "foramontano",
    "foramontanas": "foramontano",
    "foramontanos": "foramontano",
    "foramontã": "foramontão",
    "foramontãos": "foramontão",
    "foramontãs": "foramontão",
    "forana": "forano",
    "foranas": "forano",
    "foranos": "forano",
    "foras": "ser",
    "forasteira": "forasteiro",
    "forasteiras": "forasteiro",
    "forasteiros": "forasteiro",
    "foratas": "forata",
    "forca": "forcar",
    "forcachas": "forcacha",
    "forcada": "forcar",
    "forcadas": "forcar",
    "forcadelas": "forcadela",
    "forcado": "forcar",
    "forcados": "forcar",
    "forcaduras": "forcadura",
    "forcai": "forcar",
    "forcais": "forcar",
    "forcalhas": "forcalha",
    "forcam": "forcar",
    "forcamo": "forcar",
    "forcamos": "forcar",
    "forcando": "forcar",
    "forcara": "forcar",
    "forcaram": "forcar",
    "forcaras": "forcar",
    "forcarde": "forcar",
    "forcardes": "forcar",
    "forcare": "forcar",
    "forcarei": "forcar",
    "forcareis": "forcar",
    "forcarem": "forcar",
    "forcaremos": "forcar",
    "forcares": "forcar",
    "forcaria": "forcar",
    "forcariam": "forcar",
    "forcarias": "forcar",
    "forcarmo": "forcar",
    "forcarmos": "forcar",
    "forcará": "forcar",
    "forcarás": "forcar",
    "forcarão": "forcar",
    "forcaríamos": "forcar",
    "forcaríeis": "forcar",
    "forcas": "forcar",
    "forcasse": "forcar",
    "forcassem": "forcar",
    "forcasses": "forcar",
    "forcaste": "forcar",
    "forcastes": "forcar",
    "forcava": "forcar",
    "forcavam": "forcar",
    "forcavas": "forcar",
    "forcazes": "forcaz",
    "force": "forçar",
    "forcei": "forçar",
    "forceis": "forçar",
    "forceja": "forcejar",
    "forcejada": "forcejar",
    "forcejadas": "forcejar",
    "forcejado": "forcejar",
    "forcejados": "forcejar",
    "forcejai": "forcejar",
    "forcejais": "forcejar",
    "forcejam": "forcejar",
    "forcejamo": "forcejar",
    "forcejamos": "forcejar",
    "forcejando": "forcejar",
    "forcejara": "forcejar",
    "forcejaram": "forcejar",
    "forcejaras": "forcejar",
    "forcejardes": "forcejar",
    "forcejarei": "forcejar",
    "forcejareis": "forcejar",
    "forcejarem": "forcejar",
    "forcejaremos": "forcejar",
    "forcejares": "forcejar",
    "forcejaria": "forcejar",
    "forcejariam": "forcejar",
    "forcejarias": "forcejar",
    "forcejarmo": "forcejar",
    "forcejarmos": "forcejar",
    "forcejará": "forcejar",
    "forcejarás": "forcejar",
    "forcejarão": "forcejar",
    "forcejaríamos": "forcejar",
    "forcejaríeis": "forcejar",
    "forcejas": "forcejar",
    "forcejasse": "forcejar",
    "forcejassem": "forcejar",
    "forcejasses": "forcejar",
    "forcejaste": "forcejar",
    "forcejastes": "forcejar",
    "forcejava": "forcejar",
    "forcejavam": "forcejar",
    "forcejavas": "forcejar",
    "forceje": "forcejar",
    "forcejei": "forcejar",
    "forcejeis": "forcejar",
    "forcejem": "forcejar",
    "forcejemo": "forcejar",
    "forcejemos": "forcejar",
    "forcejes": "forcejar",
    "forcejo": "forcejar",
    "forcejos": "forcejo",
    "forcejou": "forcejar",
    "forcejámo": "forcejar",
    "forcejámos": "forcejar",
    "forcejáramo": "forcejar",
    "forcejáramos": "forcejar",
    "forcejáreis": "forcejar",
    "forcejásseis": "forcejar",
    "forcejássemos": "forcejar",
    "forcejávamo": "forcejar",
    "forcejávamos": "forcejar",
    "forcejáveis": "forcejar",
    "forcem": "forçar",
    "forcemo": "forçar",
    "forcemos": "forçar",
    "forces": "forçar",
    "forcinha": "força",
    "forcinhas": "força",
    "forcipressões": "forcipressão",
    "forcita": "força",
    "forcitas": "força",
    "forco": "forcar",
    "forcou": "forcar",
    "forcá": "forcar",
    "forcámo": "forcar",
    "forcámos": "forcar",
    "forcáramo": "forcar",
    "forcáramos": "forcar",
    "forcárei": "forcar",
    "forcáreis": "forcar",
    "forcásseis": "forcar",
    "forcássemos": "forcar",
    "forcávamo": "forcar",
    "forcávamos": "forcar",
    "forcávei": "forcar",
    "forcáveis": "forcar",
    "forcões": "forcão",
    "forda": "fordo",
    "fordas": "fordo",
    "fordes": "ser",
    "fordos": "fordo",
    "foreira": "foreiro",
    "foreiras": "foreiro",
    "foreiros": "foreiro",
    "forem": "ser",
    "forenses": "forense",
    "fores": "ser",
    "forfalhas": "forfalha",
    "forficulídea": "forficulídeo",
    "forficulídeas": "forficulídeo",
    "forficulídeos": "forficulídeo",
    "forficúlidas": "forficúlida",
    "forja": "forjar",
    "forjada": "forjar",
    "forjadas": "forjar",
    "forjado": "forjar",
    "forjadora": "forjador",
    "forjadoras": "forjador",
    "forjadores": "forjador",
    "forjados": "forjar",
    "forjaduras": "forjadura",
    "forjai": "forjar",
    "forjais": "forjar",
    "forjam": "forjar",
    "forjamentos": "forjamento",
    "forjamo": "forjar",
    "forjamos": "forjar",
    "forjando": "forjar",
    "forjara": "forjar",
    "forjaram": "forjar",
    "forjaras": "forjar",
    "forjarde": "forjar",
    "forjardes": "forjar",
    "forjare": "forjar",
    "forjarei": "forjar",
    "forjareis": "forjar",
    "forjarem": "forjar",
    "forjaremos": "forjar",
    "forjares": "forjar",
    "forjaria": "forjar",
    "forjariam": "forjar",
    "forjarias": "forjar",
    "forjarmo": "forjar",
    "forjarmos": "forjar",
    "forjará": "forjar",
    "forjarás": "forjar",
    "forjarão": "forjar",
    "forjaríamos": "forjar",
    "forjaríeis": "forjar",
    "forjas": "forjar",
    "forjasse": "forjar",
    "forjassem": "forjar",
    "forjasses": "forjar",
    "forjaste": "forjar",
    "forjastes": "forjar",
    "forjava": "forjar",
    "forjavam": "forjar",
    "forjavas": "forjar",
    "forje": "forjar",
    "forjei": "forjar",
    "forjeis": "forjar",
    "forjem": "forjar",
    "forjemo": "forjar",
    "forjemos": "forjar",
    "forjes": "forjar",
    "forjica": "forjicar",
    "forjicada": "forjicar",
    "forjicadas": "forjicar",
    "forjicado": "forjicar",
    "forjicadora": "forjicador",
    "forjicadoras": "forjicador",
    "forjicadores": "forjicador",
    "forjicados": "forjicar",
    "forjicai": "forjicar",
    "forjicais": "forjicar",
    "forjicam": "forjicar",
    "forjicamo": "forjicar",
    "forjicamos": "forjicar",
    "forjicando": "forjicar",
    "forjicara": "forjicar",
    "forjicaram": "forjicar",
    "forjicaras": "forjicar",
    "forjicarde": "forjicar",
    "forjicardes": "forjicar",
    "forjicare": "forjicar",
    "forjicarei": "forjicar",
    "forjicareis": "forjicar",
    "forjicarem": "forjicar",
    "forjicaremos": "forjicar",
    "forjicares": "forjicar",
    "forjicaria": "forjicar",
    "forjicariam": "forjicar",
    "forjicarias": "forjicar",
    "forjicarmo": "forjicar",
    "forjicarmos": "forjicar",
    "forjicará": "forjicar",
    "forjicarás": "forjicar",
    "forjicarão": "forjicar",
    "forjicaríamos": "forjicar",
    "forjicaríeis": "forjicar",
    "forjicas": "forjicar",
    "forjicasse": "forjicar",
    "forjicassem": "forjicar",
    "forjicasses": "forjicar",
    "forjicaste": "forjicar",
    "forjicastes": "forjicar",
    "forjicava": "forjicar",
    "forjicavam": "forjicar",
    "forjicavas": "forjicar",
    "forjico": "forjicar",
    "forjicou": "forjicar",
    "forjicá": "forjicar",
    "forjicámo": "forjicar",
    "forjicámos": "forjicar",
    "forjicáramo": "forjicar",
    "forjicáramos": "forjicar",
    "forjicárei": "forjicar",
    "forjicáreis": "forjicar",
    "forjicásseis": "forjicar",
    "forjicássemos": "forjicar",
    "forjicávamo": "forjicar",
    "forjicávamos": "forjicar",
    "forjicávei": "forjicar",
    "forjicáveis": "forjicar",
    "forjique": "forjicar",
    "forjiquei": "forjicar",
    "forjiqueis": "forjicar",
    "forjiquem": "forjicar",
    "forjiquemo": "forjicar",
    "forjiquemos": "forjicar",
    "forjiques": "forjicar",
    "forjo": "forjar",
    "forjou": "forjar",
    "forjá": "forjar",
    "forjámo": "forjar",
    "forjámos": "forjar",
    "forjáramo": "forjar",
    "forjáramos": "forjar",
    "forjárei": "forjar",
    "forjáreis": "forjar",
    "forjásseis": "forjar",
    "forjássemos": "forjar",
    "forjávamo": "forjar",
    "forjávamos": "forjar",
    "forjávei": "forjar",
    "forjáveis": "forjável",
    "forma": "formar",
    "formada": "formar",
    "formadas": "formar",
    "formado": "formar",
    "formadora": "formador",
    "formadoras": "formador",
    "formadores": "formador",
    "formados": "formar",
    "formaduras": "formadura",
    "formai": "formar",
    "formais": "formar",
    "formaldeídica": "formaldeídico",
    "formaldeídicas": "formaldeídico",
    "formaldeídicos": "formaldeídico",
    "formaldeídos": "formaldeído",
    "formalidades": "formalidade",
    "formalinas": "formalina",
    "formalismos": "formalismo",
    "formalistas": "formalista",
    "formaliza": "formalizar",
    "formalizada": "formalizar",
    "formalizadas": "formalizar",
    "formalizado": "formalizar",
    "formalizados": "formalizar",
    "formalizai": "formalizar",
    "formalizais": "formalizar",
    "formalizam": "formalizar",
    "formalizamo": "formalizar",
    "formalizamos": "formalizar",
    "formalizando": "formalizar",
    "formalizantes": "formalizante",
    "formalizara": "formalizar",
    "formalizaram": "formalizar",
    "formalizaras": "formalizar",
    "formalizarde": "formalizar",
    "formalizardes": "formalizar",
    "formalizare": "formalizar",
    "formalizarei": "formalizar",
    "formalizareis": "formalizar",
    "formalizarem": "formalizar",
    "formalizaremos": "formalizar",
    "formalizares": "formalizar",
    "formalizaria": "formalizar",
    "formalizariam": "formalizar",
    "formalizarias": "formalizar",
    "formalizarmo": "formalizar",
    "formalizarmos": "formalizar",
    "formalizará": "formalizar",
    "formalizarás": "formalizar",
    "formalizarão": "formalizar",
    "formalizaríamos": "formalizar",
    "formalizaríeis": "formalizar",
    "formalizas": "formalizar",
    "formalizasse": "formalizar",
    "formalizassem": "formalizar",
    "formalizasses": "formalizar",
    "formalizaste": "formalizar",
    "formalizastes": "formalizar",
    "formalizava": "formalizar",
    "formalizavam": "formalizar",
    "formalizavas": "formalizar",
    "formalizações": "formalização",
    "formalize": "formalizar",
    "formalizei": "formalizar",
    "formalizeis": "formalizar",
    "formalizem": "formalizar",
    "formalizemo": "formalizar",
    "formalizemos": "formalizar",
    "formalizes": "formalizar",
    "formalizo": "formalizar",
    "formalizou": "formalizar",
    "formalizá": "formalizar",
    "formalizámo": "formalizar",
    "formalizámos": "formalizar",
    "formalizáramo": "formalizar",
    "formalizáramos": "formalizar",
    "formalizárei": "formalizar",
    "formalizáreis": "formalizar",
    "formalizásseis": "formalizar",
    "formalizássemos": "formalizar",
    "formalizávamo": "formalizar",
    "formalizávamos": "formalizar",
    "formalizávei": "formalizar",
    "formalizáveis": "formalizável",
    "formalística": "formalístico",
    "formalísticas": "formalístico",
    "formalísticos": "formalístico",
    "formam": "formar",
    "formamo": "formar",
    "formamos": "formar",
    "formanda": "formando",
    "formandas": "formando",
    "formando": "formar",
    "formandos": "formando",
    "formara": "formar",
    "formaram": "formar",
    "formaras": "formar",
    "formarde": "formar",
    "formardes": "formar",
    "formare": "formar",
    "formarei": "formar",
    "formareis": "formar",
    "formarem": "formar",
    "formaremos": "formar",
    "formares": "formar",
    "formaria": "formar",
    "formariam": "formar",
    "formarias": "formaria",
    "formarmo": "formar",
    "formarmos": "formar",
    "formará": "formar",
    "formarás": "formar",
    "formarão": "formar",
    "formaríamos": "formar",
    "formaríeis": "formar",
    "formas": "formar",
    "formasse": "formar",
    "formassem": "formar",
    "formasses": "formar",
    "formaste": "formar",
    "formastes": "formar",
    "formatada": "formatado",
    "formatadas": "formatado",
    "formatados": "formatado",
    "formatações": "formatação",
    "formativa": "formativo",
    "formativas": "formativo",
    "formativos": "formativo",
    "formatos": "formato",
    "formaturas": "formatura",
    "formava": "formar",
    "formavam": "formar",
    "formavas": "formar",
    "formações": "formação",
    "forme": "formar",
    "formei": "formar",
    "formeiros": "formeiro",
    "formeis": "formar",
    "formem": "formar",
    "formemo": "formar",
    "formemos": "formar",
    "formenos": "formeno",
    "formes": "formar",
    "formeática": "formeático",
    "formeáticas": "formeático",
    "formeáticos": "formeático",
    "formiatos": "formiato",
    "formicantes": "formicante",
    "formicas": "formica",
    "formicações": "formicação",
    "formicidas": "formicida",
    "formiculares": "formicular",
    "formicária": "formicário",
    "formicárias": "formicário",
    "formicários": "formicário",
    "formicídea": "formicídeo",
    "formicídeas": "formicídeo",
    "formicídeos": "formicídeo",
    "formicídios": "formicídio",
    "formicívora": "formicívoro",
    "formicívoras": "formicívoro",
    "formicívoros": "formicívoro",
    "formidanda": "formidando",
    "formidandas": "formidando",
    "formidandos": "formidando",
    "formidolosa": "formidoloso",
    "formidolosas": "formidoloso",
    "formidolosos": "formidoloso",
    "formidáveis": "formidável",
    "formiga": "formigo",
    "formigada": "formigar",
    "formigadas": "formigar",
    "formigado": "formigar",
    "formigados": "formigar",
    "formigai": "formigar",
    "formigais": "formigar",
    "formigam": "formigar",
    "formigamentos": "formigamento",
    "formigames": "formigame",
    "formigamo": "formigar",
    "formigamos": "formigar",
    "formigando": "formigar",
    "formigantes": "formigante",
    "formigara": "formigar",
    "formigaram": "formigar",
    "formigaras": "formigar",
    "formigardes": "formigar",
    "formigarei": "formigar",
    "formigareis": "formigar",
    "formigarem": "formigar",
    "formigaremos": "formigar",
    "formigares": "formigar",
    "formigaria": "formigar",
    "formigariam": "formigar",
    "formigarias": "formigar",
    "formigarmo": "formigar",
    "formigarmos": "formigar",
    "formigará": "formigar",
    "formigarás": "formigar",
    "formigarão": "formigar",
    "formigaríamos": "formigar",
    "formigaríeis": "formigar",
    "formigas": "formigo",
    "formigasse": "formigar",
    "formigassem": "formigar",
    "formigasses": "formigar",
    "formigaste": "formigar",
    "formigastes": "formigar",
    "formigava": "formigar",
    "formigavam": "formigar",
    "formigavas": "formigar",
    "formigo": "formigar",
    "formigona": "formigão",
    "formigonas": "formigão",
    "formigos": "formigo",
    "formigou": "formigar",
    "formigue": "formigar",
    "formiguedos": "formiguedo",
    "formiguei": "formigar",
    "formigueiras": "formigueira",
    "formigueirinhos": "formigueirinho",
    "formigueiros": "formigueiro",
    "formigueis": "formigar",
    "formigueja": "formiguejar",
    "formiguejada": "formiguejar",
    "formiguejadas": "formiguejar",
    "formiguejado": "formiguejar",
    "formiguejados": "formiguejar",
    "formiguejai": "formiguejar",
    "formiguejais": "formiguejar",
    "formiguejam": "formiguejar",
    "formiguejamo": "formiguejar",
    "formiguejamos": "formiguejar",
    "formiguejando": "formiguejar",
    "formiguejara": "formiguejar",
    "formiguejaram": "formiguejar",
    "formiguejaras": "formiguejar",
    "formiguejardes": "formiguejar",
    "formiguejarei": "formiguejar",
    "formiguejareis": "formiguejar",
    "formiguejarem": "formiguejar",
    "formiguejaremos": "formiguejar",
    "formiguejares": "formiguejar",
    "formiguejaria": "formiguejar",
    "formiguejariam": "formiguejar",
    "formiguejarias": "formiguejar",
    "formiguejarmo": "formiguejar",
    "formiguejarmos": "formiguejar",
    "formiguejará": "formiguejar",
    "formiguejarás": "formiguejar",
    "formiguejarão": "formiguejar",
    "formiguejaríamos": "formiguejar",
    "formiguejaríeis": "formiguejar",
    "formiguejas": "formiguejar",
    "formiguejasse": "formiguejar",
    "formiguejassem": "formiguejar",
    "formiguejasses": "formiguejar",
    "formiguejaste": "formiguejar",
    "formiguejastes": "formiguejar",
    "formiguejava": "formiguejar",
    "formiguejavam": "formiguejar",
    "formiguejavas": "formiguejar",
    "formigueje": "formiguejar",
    "formiguejei": "formiguejar",
    "formiguejeis": "formiguejar",
    "formiguejem": "formiguejar",
    "formiguejemo": "formiguejar",
    "formiguejemos": "formiguejar",
    "formiguejes": "formiguejar",
    "formiguejo": "formiguejar",
    "formiguejou": "formiguejar",
    "formiguejámo": "formiguejar",
    "formiguejámos": "formiguejar",
    "formiguejáramo": "formiguejar",
    "formiguejáramos": "formiguejar",
    "formiguejáreis": "formiguejar",
    "formiguejásseis": "formiguejar",
    "formiguejássemos": "formiguejar",
    "formiguejávamo": "formiguejar",
    "formiguejávamos": "formiguejar",
    "formiguejáveis": "formiguejar",
    "formiguem": "formigar",
    "formiguemo": "formigar",
    "formiguemos": "formigar",
    "formigues": "formigar",
    "formiguilhos": "formiguilho",
    "formiguinha": "formiga",
    "formiguinhas": "formiga",
    "formiguita": "formiga",
    "formiguitas": "formiga",
    "formigámo": "formigar",
    "formigámos": "formigar",
    "formigáramo": "formigar",
    "formigáramos": "formigar",
    "formigáreis": "formigar",
    "formigásseis": "formigar",
    "formigássemos": "formigar",
    "formigávamo": "formigar",
    "formigávamos": "formigar",
    "formigáveis": "formigar",
    "formigões": "formigão",
    "formilha": "formilhar",
    "formilhada": "formilhar",
    "formilhadas": "formilhar",
    "formilhado": "formilhar",
    "formilhados": "formilhar",
    "formilhai": "formilhar",
    "formilhais": "formilhar",
    "formilham": "formilhar",
    "formilhamo": "formilhar",
    "formilhamos": "formilhar",
    "formilhando": "formilhar",
    "formilhara": "formilhar",
    "formilharam": "formilhar",
    "formilharas": "formilhar",
    "formilhardes": "formilhar",
    "formilharei": "formilhar",
    "formilhareis": "formilhar",
    "formilharem": "formilhar",
    "formilharemos": "formilhar",
    "formilhares": "formilhar",
    "formilharia": "formilhar",
    "formilhariam": "formilhar",
    "formilharias": "formilhar",
    "formilharmo": "formilhar",
    "formilharmos": "formilhar",
    "formilhará": "formilhar",
    "formilharás": "formilhar",
    "formilharão": "formilhar",
    "formilharíamos": "formilhar",
    "formilharíeis": "formilhar",
    "formilhas": "formilhar",
    "formilhasse": "formilhar",
    "formilhassem": "formilhar",
    "formilhasses": "formilhar",
    "formilhaste": "formilhar",
    "formilhastes": "formilhar",
    "formilhava": "formilhar",
    "formilhavam": "formilhar",
    "formilhavas": "formilhar",
    "formilhe": "formilhar",
    "formilhei": "formilhar",
    "formilheis": "formilhar",
    "formilhem": "formilhar",
    "formilhemo": "formilhar",
    "formilhemos": "formilhar",
    "formilhes": "formilhar",
    "formilho": "formilhar",
    "formilhos": "formilho",
    "formilhou": "formilhar",
    "formilhámo": "formilhar",
    "formilhámos": "formilhar",
    "formilháramo": "formilhar",
    "formilháramos": "formilhar",
    "formilháreis": "formilhar",
    "formilhásseis": "formilhar",
    "formilhássemos": "formilhar",
    "formilhávamo": "formilhar",
    "formilhávamos": "formilhar",
    "formilháveis": "formilhar",
    "formilhões": "formilhão",
    "forminha": "forma",
    "forminhas": "forma",
    "formistas": "formista",
    "formita": "forma",
    "formitas": "forma",
    "formo": "formar",
    "formolizadora": "formolizador",
    "formolizadoras": "formolizador",
    "formolizadores": "formolizador",
    "formos": "ser",
    "formosa": "formoso",
    "formosas": "formoso",
    "formoseada": "formosear",
    "formoseadas": "formosear",
    "formoseado": "formosear",
    "formoseados": "formosear",
    "formoseai": "formosear",
    "formoseais": "formosear",
    "formoseamo": "formosear",
    "formoseamos": "formosear",
    "formoseando": "formosear",
    "formoseara": "formosear",
    "formosearam": "formosear",
    "formosearas": "formosear",
    "formosearde": "formosear",
    "formoseardes": "formosear",
    "formoseare": "formosear",
    "formosearei": "formosear",
    "formoseareis": "formosear",
    "formosearem": "formosear",
    "formosearemos": "formosear",
    "formoseares": "formosear",
    "formosearia": "formosear",
    "formoseariam": "formosear",
    "formosearias": "formosear",
    "formosearmo": "formosear",
    "formosearmos": "formosear",
    "formoseará": "formosear",
    "formosearás": "formosear",
    "formosearão": "formosear",
    "formosearíamos": "formosear",
    "formosearíeis": "formosear",
    "formoseasse": "formosear",
    "formoseassem": "formosear",
    "formoseasses": "formosear",
    "formoseaste": "formosear",
    "formoseastes": "formosear",
    "formoseava": "formosear",
    "formoseavam": "formosear",
    "formoseavas": "formosear",
    "formoseei": "formosear",
    "formoseeis": "formosear",
    "formoseemo": "formosear",
    "formoseemos": "formosear",
    "formoseia": "formosear",
    "formoseiam": "formosear",
    "formoseias": "formosear",
    "formoseie": "formosear",
    "formoseiem": "formosear",
    "formoseies": "formosear",
    "formoseio": "formosear",
    "formosenta": "formosentar",
    "formosentada": "formosentar",
    "formosentadas": "formosentar",
    "formosentado": "formosentar",
    "formosentados": "formosentar",
    "formosentai": "formosentar",
    "formosentais": "formosentar",
    "formosentam": "formosentar",
    "formosentamo": "formosentar",
    "formosentamos": "formosentar",
    "formosentando": "formosentar",
    "formosentara": "formosentar",
    "formosentaram": "formosentar",
    "formosentaras": "formosentar",
    "formosentarde": "formosentar",
    "formosentardes": "formosentar",
    "formosentare": "formosentar",
    "formosentarei": "formosentar",
    "formosentareis": "formosentar",
    "formosentarem": "formosentar",
    "formosentaremos": "formosentar",
    "formosentares": "formosentar",
    "formosentaria": "formosentar",
    "formosentariam": "formosentar",
    "formosentarias": "formosentar",
    "formosentarmo": "formosentar",
    "formosentarmos": "formosentar",
    "formosentará": "formosentar",
    "formosentarás": "formosentar",
    "formosentarão": "formosentar",
    "formosentaríamos": "formosentar",
    "formosentaríeis": "formosentar",
    "formosentas": "formosentar",
    "formosentasse": "formosentar",
    "formosentassem": "formosentar",
    "formosentasses": "formosentar",
    "formosentaste": "formosentar",
    "formosentastes": "formosentar",
    "formosentava": "formosentar",
    "formosentavam": "formosentar",
    "formosentavas": "formosentar",
    "formosente": "formosentar",
    "formosentei": "formosentar",
    "formosenteis": "formosentar",
    "formosentem": "formosentar",
    "formosentemo": "formosentar",
    "formosentemos": "formosentar",
    "formosentes": "formosentar",
    "formosento": "formosentar",
    "formosentou": "formosentar",
    "formosentá": "formosentar",
    "formosentámo": "formosentar",
    "formosentámos": "formosentar",
    "formosentáramo": "formosentar",
    "formosentáramos": "formosentar",
    "formosentárei": "formosentar",
    "formosentáreis": "formosentar",
    "formosentásseis": "formosentar",
    "formosentássemos": "formosentar",
    "formosentávamo": "formosentar",
    "formosentávamos": "formosentar",
    "formosentávei": "formosentar",
    "formosentáveis": "formosentar",
    "formoseou": "formosear",
    "formoseá": "formosear",
    "formoseámo": "formosear",
    "formoseámos": "formosear",
    "formoseáramo": "formosear",
    "formoseáramos": "formosear",
    "formoseárei": "formosear",
    "formoseáreis": "formosear",
    "formoseásseis": "formosear",
    "formoseássemos": "formosear",
    "formoseávamo": "formosear",
    "formoseávamos": "formosear",
    "formoseávei": "formosear",
    "formoseáveis": "formosear",
    "formosos": "formoso",
    "formosuras": "formosura",
    "formosíssima": "formoso",
    "formosíssimas": "formoso",
    "formosíssimo": "formoso",
    "formosíssimos": "formoso",
    "formou": "formar",
    "formula": "formular",
    "formulada": "formular",
    "formuladas": "formular",
    "formulado": "formular",
    "formuladora": "formulador",
    "formuladoras": "formulador",
    "formuladores": "formulador",
    "formulados": "formular",
    "formulai": "formular",
    "formulais": "formular",
    "formulam": "formular",
    "formulamo": "formular",
    "formulamos": "formular",
    "formulando": "formular",
    "formulara": "formular",
    "formularam": "formular",
    "formularas": "formular",
    "formularde": "formular",
    "formulardes": "formular",
    "formulare": "formular",
    "formularei": "formular",
    "formulareis": "formular",
    "formularem": "formular",
    "formularemos": "formular",
    "formulares": "formular",
    "formularia": "formular",
    "formulariam": "formular",
    "formularias": "formular",
    "formularmo": "formular",
    "formularmos": "formular",
    "formulará": "formular",
    "formularás": "formular",
    "formularão": "formular",
    "formularíamos": "formular",
    "formularíeis": "formular",
    "formulas": "formular",
    "formulasse": "formular",
    "formulassem": "formular",
    "formulasses": "formular",
    "formulaste": "formular",
    "formulastes": "formular",
    "formulava": "formular",
    "formulavam": "formular",
    "formulavas": "formular",
    "formulações": "formulação",
    "formule": "formular",
    "formulei": "formular",
    "formuleis": "formular",
    "formulem": "formular",
    "formulemo": "formular",
    "formulemos": "formular",
    "formules": "formular",
    "formulismos": "formulismo",
    "formulistas": "formulista",
    "formulo": "formular",
    "formulou": "formular",
    "formulá": "formular",
    "formulámo": "formular",
    "formulámos": "formular",
    "formuláramo": "formular",
    "formuláramos": "formular",
    "formulárei": "formular",
    "formuláreis": "formular",
    "formulários": "formulário",
    "formulásseis": "formular",
    "formulássemos": "formular",
    "formulávamo": "formular",
    "formulávamos": "formular",
    "formulávei": "formular",
    "formuláveis": "formulável",
    "formulística": "formulístico",
    "formulísticas": "formulístico",
    "formulísticos": "formulístico",
    "formá": "formar",
    "formámo": "formar",
    "formámos": "formar",
    "formáramo": "formar",
    "formáramos": "formar",
    "formárei": "formar",
    "formáreis": "formar",
    "formásseis": "formar",
    "formássemos": "formar",
    "formávamo": "formar",
    "formávamos": "formar",
    "formávei": "formar",
    "formáveis": "formável",
    "forménica": "forménico",
    "forménicas": "forménico",
    "forménicos": "forménico",
    "formícidas": "formícida",
    "formídios": "formídio",
    "formóis": "formol",
    "formões": "formão",
    "forna": "fornir",
    "fornaceira": "fornaceiro",
    "fornaceiras": "fornaceiro",
    "fornaceiros": "fornaceiro",
    "fornadas": "fornada",
    "fornais": "fornir",
    "fornalhas": "fornalha",
    "fornalheira": "fornalheiro",
    "fornalheiras": "fornalheiro",
    "fornalheiros": "fornalheiro",
    "fornam": "fornir",
    "fornamo": "fornir",
    "fornamos": "fornir",
    "fornas": "fornir",
    "fornaças": "fornaça",
    "forne": "fornir",
    "forneada": "fornear",
    "forneadas": "fornear",
    "forneado": "fornear",
    "forneados": "fornear",
    "forneai": "fornear",
    "forneais": "fornear",
    "forneamo": "fornear",
    "forneamos": "fornear",
    "forneando": "fornear",
    "forneara": "fornear",
    "fornearam": "fornear",
    "fornearas": "fornear",
    "forneardes": "fornear",
    "fornearei": "fornear",
    "forneareis": "fornear",
    "fornearem": "fornear",
    "fornearemos": "fornear",
    "forneares": "fornear",
    "fornearia": "fornear",
    "forneariam": "fornear",
    "fornearias": "fornear",
    "fornearmo": "fornear",
    "fornearmos": "fornear",
    "forneará": "fornear",
    "fornearás": "fornear",
    "fornearão": "fornear",
    "fornearíamos": "fornear",
    "fornearíeis": "fornear",
    "forneasse": "fornear",
    "forneassem": "fornear",
    "forneasses": "fornear",
    "forneaste": "fornear",
    "forneastes": "fornear",
    "forneava": "fornear",
    "forneavam": "fornear",
    "forneavas": "fornear",
    "fornece": "fornecer",
    "fornecedora": "fornecedor",
    "fornecedoras": "fornecedor",
    "fornecedores": "fornecedor",
    "fornecei": "fornecer",
    "forneceis": "fornecer",
    "fornecem": "fornecer",
    "fornecemo": "fornecer",
    "fornecemos": "fornecer",
    "fornecendo": "fornecer",
    "fornecera": "fornecer",
    "forneceram": "fornecer",
    "forneceras": "fornecer",
    "fornecerde": "fornecer",
    "fornecerdes": "fornecer",
    "fornecere": "fornecer",
    "fornecerei": "fornecer",
    "fornecereis": "fornecer",
    "fornecerem": "fornecer",
    "forneceremos": "fornecer",
    "forneceres": "fornecer",
    "forneceria": "fornecer",
    "forneceriam": "fornecer",
    "fornecerias": "fornecer",
    "fornecermo": "fornecer",
    "fornecermos": "fornecer",
    "fornecerá": "fornecer",
    "fornecerás": "fornecer",
    "fornecerão": "fornecer",
    "forneceríamos": "fornecer",
    "forneceríeis": "fornecer",
    "forneces": "fornecer",
    "fornecesse": "fornecer",
    "fornecessem": "fornecer",
    "fornecesses": "fornecer",
    "forneceste": "fornecer",
    "fornecestes": "fornecer",
    "forneceu": "fornecer",
    "forneci": "fornecer",
    "fornecia": "fornecer",
    "forneciam": "fornecer",
    "fornecias": "fornecer",
    "fornecida": "fornecido",
    "fornecidas": "fornecido",
    "fornecido": "fornecer",
    "fornecidos": "fornecido",
    "fornecimentos": "fornecimento",
    "fornecos": "forneco",
    "fornecê": "fornecer",
    "fornecêramo": "fornecer",
    "fornecêramos": "fornecer",
    "fornecêrei": "fornecer",
    "fornecêreis": "fornecer",
    "fornecêsseis": "fornecer",
    "fornecêssemos": "fornecer",
    "fornecíamo": "fornecer",
    "fornecíamos": "fornecer",
    "fornecíei": "fornecer",
    "fornecíeis": "fornecer",
    "forneei": "fornear",
    "forneeis": "fornear",
    "forneemo": "fornear",
    "forneemos": "fornear",
    "forneia": "fornear",
    "forneiam": "fornear",
    "forneias": "fornear",
    "forneie": "fornear",
    "forneiem": "fornear",
    "forneies": "fornear",
    "forneio": "fornear",
    "forneira": "forneiro",
    "forneiras": "forneiro",
    "forneirinhas": "forneirinha",
    "forneiros": "forneiro",
    "forneja": "fornejar",
    "fornejada": "fornejar",
    "fornejadas": "fornejar",
    "fornejado": "fornejar",
    "fornejados": "fornejar",
    "fornejai": "fornejar",
    "fornejais": "fornejar",
    "fornejam": "fornejar",
    "fornejamo": "fornejar",
    "fornejamos": "fornejar",
    "fornejando": "fornejar",
    "fornejara": "fornejar",
    "fornejaram": "fornejar",
    "fornejaras": "fornejar",
    "fornejardes": "fornejar",
    "fornejarei": "fornejar",
    "fornejareis": "fornejar",
    "fornejarem": "fornejar",
    "fornejaremos": "fornejar",
    "fornejares": "fornejar",
    "fornejaria": "fornejar",
    "fornejariam": "fornejar",
    "fornejarias": "fornejar",
    "fornejarmo": "fornejar",
    "fornejarmos": "fornejar",
    "fornejará": "fornejar",
    "fornejarás": "fornejar",
    "fornejarão": "fornejar",
    "fornejaríamos": "fornejar",
    "fornejaríeis": "fornejar",
    "fornejas": "fornejar",
    "fornejasse": "fornejar",
    "fornejassem": "fornejar",
    "fornejasses": "fornejar",
    "fornejaste": "fornejar",
    "fornejastes": "fornejar",
    "fornejava": "fornejar",
    "fornejavam": "fornejar",
    "fornejavas": "fornejar",
    "forneje": "fornejar",
    "fornejei": "fornejar",
    "fornejeis": "fornejar",
    "fornejem": "fornejar",
    "fornejemo": "fornejar",
    "fornejemos": "fornejar",
    "fornejes": "fornejar",
    "fornejo": "fornejar",
    "fornejou": "fornejar",
    "fornejámo": "fornejar",
    "fornejámos": "fornejar",
    "fornejáramo": "fornejar",
    "fornejáramos": "fornejar",
    "fornejáreis": "fornejar",
    "fornejásseis": "fornejar",
    "fornejássemos": "fornejar",
    "fornejávamo": "fornejar",
    "fornejávamos": "fornejar",
    "fornejáveis": "fornejar",
    "fornem": "fornir",
    "forneou": "fornear",
    "fornes": "fornir",
    "forneámo": "fornear",
    "forneámos": "fornear",
    "forneáramo": "fornear",
    "forneáramos": "fornear",
    "forneáreis": "fornear",
    "forneásseis": "fornear",
    "forneássemos": "fornear",
    "forneávamo": "fornear",
    "forneávamos": "fornear",
    "forneáveis": "fornear",
    "forneça": "fornecer",
    "forneçais": "fornecer",
    "forneçam": "fornecer",
    "forneçamo": "fornecer",
    "forneçamos": "fornecer",
    "forneças": "fornecer",
    "forneço": "fornecer",
    "forni": "fornir",
    "fornia": "fornir",
    "forniam": "fornir",
    "fornias": "fornir",
    "fornica": "fornicar",
    "fornicada": "fornicar",
    "fornicadas": "fornicar",
    "fornicado": "fornicar",
    "fornicadora": "fornicador",
    "fornicadoras": "fornicador",
    "fornicadores": "fornicador",
    "fornicados": "fornicar",
    "fornicai": "fornicar",
    "fornicais": "fornicar",
    "fornicam": "fornicar",
    "fornicamo": "fornicar",
    "fornicamos": "fornicar",
    "fornicando": "fornicar",
    "fornicara": "fornicar",
    "fornicaram": "fornicar",
    "fornicaras": "fornicar",
    "fornicarde": "fornicar",
    "fornicardes": "fornicar",
    "fornicare": "fornicar",
    "fornicarei": "fornicar",
    "fornicareis": "fornicar",
    "fornicarem": "fornicar",
    "fornicaremos": "fornicar",
    "fornicares": "fornicar",
    "fornicaria": "fornicar",
    "fornicariam": "fornicar",
    "fornicarias": "fornicar",
    "fornicarmo": "fornicar",
    "fornicarmos": "fornicar",
    "fornicará": "fornicar",
    "fornicarás": "fornicar",
    "fornicarão": "fornicar",
    "fornicaríamos": "fornicar",
    "fornicaríeis": "fornicar",
    "fornicas": "fornicar",
    "fornicasse": "fornicar",
    "fornicassem": "fornicar",
    "fornicasses": "fornicar",
    "fornicaste": "fornicar",
    "fornicastes": "fornicar",
    "fornicava": "fornicar",
    "fornicavam": "fornicar",
    "fornicavas": "fornicar",
    "fornicações": "fornicação",
    "fornico": "fornicar",
    "fornicoques": "fornicoque",
    "fornicou": "fornicar",
    "fornicá": "fornicar",
    "fornicámo": "fornicar",
    "fornicámos": "fornicar",
    "fornicáramo": "fornicar",
    "fornicáramos": "fornicar",
    "fornicárei": "fornicar",
    "fornicáreis": "fornicar",
    "fornicásseis": "fornicar",
    "fornicássemos": "fornicar",
    "fornicávamo": "fornicar",
    "fornicávamos": "fornicar",
    "fornicávei": "fornicar",
    "fornicáveis": "fornicar",
    "fornida": "fornir",
    "fornidas": "fornir",
    "fornido": "fornir",
    "fornidos": "fornir",
    "fornilhas": "fornilha",
    "fornilhos": "fornilho",
    "fornimentos": "fornimento",
    "fornimo": "fornir",
    "fornimos": "fornir",
    "fornindo": "fornir",
    "forninho": "forno",
    "forninhos": "forno",
    "fornique": "fornicar",
    "forniquei": "fornicar",
    "forniqueis": "fornicar",
    "forniquem": "fornicar",
    "forniquemo": "fornicar",
    "forniquemos": "fornicar",
    "forniques": "fornicar",
    "fornira": "fornir",
    "forniram": "fornir",
    "forniras": "fornir",
    "fornirde": "fornir",
    "fornirdes": "fornir",
    "fornire": "fornir",
    "fornirei": "fornir",
    "fornireis": "fornir",
    "fornirem": "fornir",
    "forniremos": "fornir",
    "fornires": "fornir",
    "forniria": "fornir",
    "forniriam": "fornir",
    "fornirias": "fornir",
    "fornirmo": "fornir",
    "fornirmos": "fornir",
    "fornirá": "fornir",
    "fornirás": "fornir",
    "fornirão": "fornir",
    "forniríamos": "fornir",
    "forniríeis": "fornir",
    "fornis": "fornir",
    "fornisse": "fornir",
    "fornissem": "fornir",
    "fornisses": "fornir",
    "forniste": "fornir",
    "fornistes": "fornir",
    "fornito": "forno",
    "fornitos": "forno",
    "forniu": "fornir",
    "forno": "fornir",
    "fornos": "forno",
    "forníamo": "fornir",
    "forníamos": "fornir",
    "forníei": "fornir",
    "forníeis": "fornir",
    "forníramo": "fornir",
    "forníramos": "fornir",
    "fornírei": "fornir",
    "forníreis": "fornir",
    "fornísseis": "fornir",
    "forníssemos": "fornir",
    "foronídea": "foronídeo",
    "foronídeas": "foronídeo",
    "foronídeos": "foronídeo",
    "foros": "foro",
    "forque": "forcar",
    "forqueada": "forquear",
    "forqueadas": "forquear",
    "forqueado": "forquear",
    "forqueados": "forquear",
    "forqueaduras": "forqueadura",
    "forqueai": "forquear",
    "forqueais": "forquear",
    "forqueamo": "forquear",
    "forqueamos": "forquear",
    "forqueando": "forquear",
    "forqueara": "forquear",
    "forquearam": "forquear",
    "forquearas": "forquear",
    "forquearde": "forquear",
    "forqueardes": "forquear",
    "forqueare": "forquear",
    "forquearei": "forquear",
    "forqueareis": "forquear",
    "forquearem": "forquear",
    "forquearemos": "forquear",
    "forqueares": "forquear",
    "forquearia": "forquear",
    "forqueariam": "forquear",
    "forquearias": "forquear",
    "forquearmo": "forquear",
    "forquearmos": "forquear",
    "forqueará": "forquear",
    "forquearás": "forquear",
    "forquearão": "forquear",
    "forquearíamos": "forquear",
    "forquearíeis": "forquear",
    "forqueasse": "forquear",
    "forqueassem": "forquear",
    "forqueasses": "forquear",
    "forqueaste": "forquear",
    "forqueastes": "forquear",
    "forqueava": "forquear",
    "forqueavam": "forquear",
    "forqueavas": "forquear",
    "forqueei": "forquear",
    "forqueeis": "forquear",
    "forqueemo": "forquear",
    "forqueemos": "forquear",
    "forquei": "forcar",
    "forqueia": "forquear",
    "forqueiam": "forquear",
    "forqueias": "forquear",
    "forqueie": "forquear",
    "forqueiem": "forquear",
    "forqueies": "forquear",
    "forqueio": "forquear",
    "forqueis": "forcar",
    "forquem": "forcar",
    "forquemo": "forcar",
    "forquemos": "forcar",
    "forqueou": "forquear",
    "forques": "forcar",
    "forquetas": "forqueta",
    "forqueá": "forquear",
    "forqueámo": "forquear",
    "forqueámos": "forquear",
    "forqueáramo": "forquear",
    "forqueáramos": "forquear",
    "forqueárei": "forquear",
    "forqueáreis": "forquear",
    "forqueásseis": "forquear",
    "forqueássemos": "forquear",
    "forqueávamo": "forquear",
    "forqueávamos": "forquear",
    "forqueávei": "forquear",
    "forqueáveis": "forquear",
    "forquilhas": "forquilha",
    "forquilhosa": "forquilhoso",
    "forquilhosas": "forquilhoso",
    "forquilhosos": "forquilhoso",
    "forra": "forro",
    "forrada": "forrar",
    "forradas": "forrar",
    "forrado": "forrar",
    "forradora": "forrador",
    "forradoras": "forrador",
    "forradores": "forrador",
    "forrados": "forrar",
    "forrageada": "forragear",
    "forrageadas": "forragear",
    "forrageado": "forragear",
    "forrageadora": "forrageador",
    "forrageadoras": "forrageador",
    "forrageadores": "forrageador",
    "forrageados": "forragear",
    "forrageai": "forragear",
    "forrageais": "forragear",
    "forrageamo": "forragear",
    "forrageamos": "forragear",
    "forrageando": "forragear",
    "forrageara": "forragear",
    "forragearam": "forragear",
    "forragearas": "forragear",
    "forrageardes": "forragear",
    "forragearei": "forragear",
    "forrageareis": "forragear",
    "forragearem": "forragear",
    "forragearemos": "forragear",
    "forrageares": "forragear",
    "forragearia": "forragear",
    "forrageariam": "forragear",
    "forragearias": "forragear",
    "forragearmo": "forragear",
    "forragearmos": "forragear",
    "forrageará": "forragear",
    "forragearás": "forragear",
    "forragearão": "forragear",
    "forragearíamos": "forragear",
    "forragearíeis": "forragear",
    "forrageasse": "forragear",
    "forrageassem": "forragear",
    "forrageasses": "forragear",
    "forrageaste": "forragear",
    "forrageastes": "forragear",
    "forrageava": "forragear",
    "forrageavam": "forragear",
    "forrageavas": "forragear",
    "forrageei": "forragear",
    "forrageeis": "forragear",
    "forrageemo": "forragear",
    "forrageemos": "forragear",
    "forrageia": "forragear",
    "forrageiam": "forragear",
    "forrageias": "forragear",
    "forrageie": "forragear",
    "forrageiem": "forragear",
    "forrageies": "forragear",
    "forrageio": "forragear",
    "forragens": "forragem",
    "forrageou": "forragear",
    "forrageámo": "forragear",
    "forrageámos": "forragear",
    "forrageáramo": "forragear",
    "forrageáramos": "forragear",
    "forrageáreis": "forragear",
    "forrageásseis": "forragear",
    "forrageássemos": "forragear",
    "forrageávamo": "forragear",
    "forrageávamos": "forragear",
    "forrageáveis": "forragear",
    "forraginosa": "forraginoso",
    "forraginosas": "forraginoso",
    "forraginosos": "forraginoso",
    "forrai": "forrar",
    "forrais": "forrar",
    "forram": "forrar",
    "forramentos": "forramento",
    "forramo": "forrar",
    "forramos": "forrar",
    "forrando": "forrar",
    "forrara": "forrar",
    "forraram": "forrar",
    "forraras": "forrar",
    "forrarde": "forrar",
    "forrardes": "forrar",
    "forrare": "forrar",
    "forrarei": "forrar",
    "forrareis": "forrar",
    "forrarem": "forrar",
    "forraremos": "forrar",
    "forrares": "forrar",
    "forraria": "forrar",
    "forrariam": "forrar",
    "forrarias": "forrar",
    "forrarmo": "forrar",
    "forrarmos": "forrar",
    "forrará": "forrar",
    "forrarás": "forrar",
    "forrarão": "forrar",
    "forraríamos": "forrar",
    "forraríeis": "forrar",
    "forras": "forro",
    "forrasse": "forrar",
    "forrassem": "forrar",
    "forrasses": "forrar",
    "forraste": "forrar",
    "forrastes": "forrar",
    "forrava": "forrar",
    "forravam": "forrar",
    "forravas": "forrar",
    "forrações": "forração",
    "forre": "forrar",
    "forrei": "forrar",
    "forreis": "forrar",
    "forrem": "forrar",
    "forremo": "forrar",
    "forremos": "forrar",
    "forres": "forrar",
    "forretas": "forreta",
    "forretices": "forretice",
    "forrgeira": "forrgeiro",
    "forrgeiras": "forrgeiro",
    "forrgeiros": "forrgeiro",
    "forrica": "forricar",
    "forricada": "forricar",
    "forricadas": "forricar",
    "forricado": "forricar",
    "forricados": "forricar",
    "forricai": "forricar",
    "forricais": "forricar",
    "forricam": "forricar",
    "forricamo": "forricar",
    "forricamos": "forricar",
    "forricando": "forricar",
    "forricara": "forricar",
    "forricaram": "forricar",
    "forricaras": "forricar",
    "forricarde": "forricar",
    "forricardes": "forricar",
    "forricare": "forricar",
    "forricarei": "forricar",
    "forricareis": "forricar",
    "forricarem": "forricar",
    "forricaremos": "forricar",
    "forricares": "forricar",
    "forricaria": "forricar",
    "forricariam": "forricar",
    "forricarias": "forricar",
    "forricarmo": "forricar",
    "forricarmos": "forricar",
    "forricará": "forricar",
    "forricarás": "forricar",
    "forricarão": "forricar",
    "forricaríamos": "forricar",
    "forricaríeis": "forricar",
    "forricas": "forricar",
    "forricasse": "forricar",
    "forricassem": "forricar",
    "forricasses": "forricar",
    "forricaste": "forricar",
    "forricastes": "forricar",
    "forricava": "forricar",
    "forricavam": "forricar",
    "forricavas": "forricar",
    "forrico": "forricar",
    "forricou": "forricar",
    "forricá": "forricar",
    "forricámo": "forricar",
    "forricámos": "forricar",
    "forricáramo": "forricar",
    "forricáramos": "forricar",
    "forricárei": "forricar",
    "forricáreis": "forricar",
    "forricásseis": "forricar",
    "forricássemos": "forricar",
    "forricávamo": "forricar",
    "forricávamos": "forricar",
    "forricávei": "forricar",
    "forricáveis": "forricar",
    "forrique": "forricar",
    "forriquei": "forricar",
    "forriqueis": "forricar",
    "forriquem": "forricar",
    "forriquemo": "forricar",
    "forriquemos": "forricar",
    "forriques": "forricar",
    "forro": "forrar",
    "forrobodós": "forrobodó",
    "forros": "forro",
    "forrou": "forrar",
    "forrá": "forrar",
    "forrámo": "forrar",
    "forrámos": "forrar",
    "forráramo": "forrar",
    "forráramos": "forrar",
    "forrárei": "forrar",
    "forráreis": "forrar",
    "forrásseis": "forrar",
    "forrássemos": "forrar",
    "forrávamo": "forrar",
    "forrávamos": "forrar",
    "forrávei": "forrar",
    "forráveis": "forrar",
    "forrós": "forró",
    "fortalece": "fortalecer",
    "fortalecedora": "fortalecedor",
    "fortalecedoras": "fortalecedor",
    "fortalecedores": "fortalecedor",
    "fortalecei": "fortalecer",
    "fortaleceis": "fortalecer",
    "fortalecem": "fortalecer",
    "fortalecemo": "fortalecer",
    "fortalecemos": "fortalecer",
    "fortalecendo": "fortalecer",
    "fortalecera": "fortalecer",
    "fortaleceram": "fortalecer",
    "fortaleceras": "fortalecer",
    "fortalecerde": "fortalecer",
    "fortalecerdes": "fortalecer",
    "fortalecere": "fortalecer",
    "fortalecerei": "fortalecer",
    "fortalecereis": "fortalecer",
    "fortalecerem": "fortalecer",
    "fortaleceremos": "fortalecer",
    "fortaleceres": "fortalecer",
    "fortaleceria": "fortalecer",
    "fortaleceriam": "fortalecer",
    "fortalecerias": "fortalecer",
    "fortalecermo": "fortalecer",
    "fortalecermos": "fortalecer",
    "fortalecerá": "fortalecer",
    "fortalecerás": "fortalecer",
    "fortalecerão": "fortalecer",
    "fortaleceríamos": "fortalecer",
    "fortaleceríeis": "fortalecer",
    "fortaleces": "fortalecer",
    "fortalecesse": "fortalecer",
    "fortalecessem": "fortalecer",
    "fortalecesses": "fortalecer",
    "fortaleceste": "fortalecer",
    "fortalecestes": "fortalecer",
    "fortaleceu": "fortalecer",
    "fortaleci": "fortalecer",
    "fortalecia": "fortalecer",
    "fortaleciam": "fortalecer",
    "fortalecias": "fortalecer",
    "fortalecida": "fortalecido",
    "fortalecidas": "fortalecido",
    "fortalecido": "fortalecer",
    "fortalecidos": "fortalecido",
    "fortalecimentos": "fortalecimento",
    "fortalecê": "fortalecer",
    "fortalecêramo": "fortalecer",
    "fortalecêramos": "fortalecer",
    "fortalecêrei": "fortalecer",
    "fortalecêreis": "fortalecer",
    "fortalecêsseis": "fortalecer",
    "fortalecêssemos": "fortalecer",
    "fortalecíamo": "fortalecer",
    "fortalecíamos": "fortalecer",
    "fortalecíei": "fortalecer",
    "fortalecíeis": "fortalecer",
    "fortalecíveis": "fortalecível",
    "fortaleza": "fortalezar",
    "fortalezada": "fortalezar",
    "fortalezadas": "fortalezar",
    "fortalezado": "fortalezar",
    "fortalezados": "fortalezar",
    "fortalezai": "fortalezar",
    "fortalezais": "fortalezar",
    "fortalezam": "fortalezar",
    "fortalezamo": "fortalezar",
    "fortalezamos": "fortalezar",
    "fortalezando": "fortalezar",
    "fortalezara": "fortalezar",
    "fortalezaram": "fortalezar",
    "fortalezaras": "fortalezar",
    "fortalezarde": "fortalezar",
    "fortalezardes": "fortalezar",
    "fortalezare": "fortalezar",
    "fortalezarei": "fortalezar",
    "fortalezareis": "fortalezar",
    "fortalezarem": "fortalezar",
    "fortalezaremos": "fortalezar",
    "fortalezares": "fortalezar",
    "fortalezaria": "fortalezar",
    "fortalezariam": "fortalezar",
    "fortalezarias": "fortalezar",
    "fortalezarmo": "fortalezar",
    "fortalezarmos": "fortalezar",
    "fortalezará": "fortalezar",
    "fortalezarás": "fortalezar",
    "fortalezarão": "fortalezar",
    "fortalezaríamos": "fortalezar",
    "fortalezaríeis": "fortalezar",
    "fortalezas": "fortalezar",
    "fortalezasse": "fortalezar",
    "fortalezassem": "fortalezar",
    "fortalezasses": "fortalezar",
    "fortalezaste": "fortalezar",
    "fortalezastes": "fortalezar",
    "fortalezava": "fortalezar",
    "fortalezavam": "fortalezar",
    "fortalezavas": "fortalezar",
    "fortaleze": "fortalezar",
    "fortalezei": "fortalezar",
    "fortalezeis": "fortalezar",
    "fortalezem": "fortalezar",
    "fortalezemo": "fortalezar",
    "fortalezemos": "fortalezar",
    "fortalezes": "fortalezar",
    "fortalezo": "fortalezar",
    "fortalezou": "fortalezar",
    "fortalezá": "fortalezar",
    "fortalezámo": "fortalezar",
    "fortalezámos": "fortalezar",
    "fortalezáramo": "fortalezar",
    "fortalezáramos": "fortalezar",
    "fortalezárei": "fortalezar",
    "fortalezáreis": "fortalezar",
    "fortalezásseis": "fortalezar",
    "fortalezássemos": "fortalezar",
    "fortalezávamo": "fortalezar",
    "fortalezávamos": "fortalezar",
    "fortalezávei": "fortalezar",
    "fortalezáveis": "fortalezar",
    "fortaleça": "fortalecer",
    "fortaleçais": "fortalecer",
    "fortaleçam": "fortalecer",
    "fortaleçamo": "fortalecer",
    "fortaleçamos": "fortalecer",
    "fortaleças": "fortalecer",
    "fortaleço": "fortalecer",
    "fortes": "forte",
    "fortezas": "forteza",
    "fortidões": "fortidão",
    "fortifica": "fortificar",
    "fortificada": "fortificar",
    "fortificadas": "fortificar",
    "fortificado": "fortificar",
    "fortificadora": "fortificador",
    "fortificadoras": "fortificador",
    "fortificadores": "fortificador",
    "fortificados": "fortificar",
    "fortificai": "fortificar",
    "fortificais": "fortificar",
    "fortificam": "fortificar",
    "fortificamo": "fortificar",
    "fortificamos": "fortificar",
    "fortificando": "fortificar",
    "fortificantes": "fortificante",
    "fortificara": "fortificar",
    "fortificaram": "fortificar",
    "fortificaras": "fortificar",
    "fortificarde": "fortificar",
    "fortificardes": "fortificar",
    "fortificare": "fortificar",
    "fortificarei": "fortificar",
    "fortificareis": "fortificar",
    "fortificarem": "fortificar",
    "fortificaremos": "fortificar",
    "fortificares": "fortificar",
    "fortificaria": "fortificar",
    "fortificariam": "fortificar",
    "fortificarias": "fortificar",
    "fortificarmo": "fortificar",
    "fortificarmos": "fortificar",
    "fortificará": "fortificar",
    "fortificarás": "fortificar",
    "fortificarão": "fortificar",
    "fortificaríamos": "fortificar",
    "fortificaríeis": "fortificar",
    "fortificas": "fortificar",
    "fortificasse": "fortificar",
    "fortificassem": "fortificar",
    "fortificasses": "fortificar",
    "fortificaste": "fortificar",
    "fortificastes": "fortificar",
    "fortificava": "fortificar",
    "fortificavam": "fortificar",
    "fortificavas": "fortificar",
    "fortificações": "fortificação",
    "fortifico": "fortificar",
    "fortificou": "fortificar",
    "fortificá": "fortificar",
    "fortificámo": "fortificar",
    "fortificámos": "fortificar",
    "fortificáramo": "fortificar",
    "fortificáramos": "fortificar",
    "fortificárei": "fortificar",
    "fortificáreis": "fortificar",
    "fortificásseis": "fortificar",
    "fortificássemos": "fortificar",
    "fortificávamo": "fortificar",
    "fortificávamos": "fortificar",
    "fortificávei": "fortificar",
    "fortificáveis": "fortificável",
    "fortifique": "fortificar",
    "fortifiquei": "fortificar",
    "fortifiqueis": "fortificar",
    "fortifiquem": "fortificar",
    "fortifiquemo": "fortificar",
    "fortifiquemos": "fortificar",
    "fortifiques": "fortificar",
    "fortins": "fortim",
    "fortuita": "fortuito",
    "fortuitas": "fortuito",
    "fortuitos": "fortuito",
    "fortunas": "fortuna",
    "fortuneada": "fortunear",
    "fortuneadas": "fortunear",
    "fortuneado": "fortunear",
    "fortuneados": "fortunear",
    "fortuneai": "fortunear",
    "fortuneais": "fortunear",
    "fortuneamo": "fortunear",
    "fortuneamos": "fortunear",
    "fortuneando": "fortunear",
    "fortuneara": "fortunear",
    "fortunearam": "fortunear",
    "fortunearas": "fortunear",
    "fortuneardes": "fortunear",
    "fortunearei": "fortunear",
    "fortuneareis": "fortunear",
    "fortunearem": "fortunear",
    "fortunearemos": "fortunear",
    "fortuneares": "fortunear",
    "fortunearia": "fortunear",
    "fortuneariam": "fortunear",
    "fortunearias": "fortunear",
    "fortunearmo": "fortunear",
    "fortunearmos": "fortunear",
    "fortuneará": "fortunear",
    "fortunearás": "fortunear",
    "fortunearão": "fortunear",
    "fortunearíamos": "fortunear",
    "fortunearíeis": "fortunear",
    "fortuneasse": "fortunear",
    "fortuneassem": "fortunear",
    "fortuneasses": "fortunear",
    "fortuneaste": "fortunear",
    "fortuneastes": "fortunear",
    "fortuneava": "fortunear",
    "fortuneavam": "fortunear",
    "fortuneavas": "fortunear",
    "fortuneei": "fortunear",
    "fortuneeis": "fortunear",
    "fortuneemo": "fortunear",
    "fortuneemos": "fortunear",
    "fortuneia": "fortunear",
    "fortuneiam": "fortunear",
    "fortuneias": "fortunear",
    "fortuneie": "fortunear",
    "fortuneiem": "fortunear",
    "fortuneies": "fortunear",
    "fortuneio": "fortunear",
    "fortuneou": "fortunear",
    "fortuneámo": "fortunear",
    "fortuneámos": "fortunear",
    "fortuneáramo": "fortunear",
    "fortuneáramos": "fortunear",
    "fortuneáreis": "fortunear",
    "fortuneásseis": "fortunear",
    "fortuneássemos": "fortunear",
    "fortuneávamo": "fortunear",
    "fortuneávamos": "fortunear",
    "fortuneáveis": "fortunear",
    "fortunitos": "fortunito",
    "fortunosa": "fortunoso",
    "fortunosas": "fortunoso",
    "fortunosos": "fortunoso",
    "fortíssima": "forte",
    "fortíssimas": "forte",
    "fortíssimo": "forte",
    "fortíssimos": "forte",
    "foruns": "forum",
    "forâmenes": "forâmen",
    "forânea": "forâneo",
    "forâneas": "forâneo",
    "forâneos": "forâneo",
    "força": "forçar",
    "forçada": "forçar",
    "forçadas": "forçar",
    "forçado": "forçar",
    "forçadora": "forçador",
    "forçadoras": "forçador",
    "forçadores": "forçador",
    "forçados": "forçar",
    "forçai": "forçar",
    "forçais": "forçar",
    "forçam": "forçar",
    "forçamentos": "forçamento",
    "forçamo": "forçar",
    "forçamos": "forçar",
    "forçando": "forçar",
    "forçara": "forçar",
    "forçaram": "forçar",
    "forçaras": "forçar",
    "forçarde": "forçar",
    "forçardes": "forçar",
    "forçare": "forçar",
    "forçarei": "forçar",
    "forçareis": "forçar",
    "forçarem": "forçar",
    "forçaremos": "forçar",
    "forçares": "forçar",
    "forçaria": "forçar",
    "forçariam": "forçar",
    "forçarias": "forçar",
    "forçarmo": "forçar",
    "forçarmos": "forçar",
    "forçará": "forçar",
    "forçarás": "forçar",
    "forçarão": "forçar",
    "forçaríamos": "forçar",
    "forçaríeis": "forçar",
    "forças": "forçar",
    "forçasse": "forçar",
    "forçassem": "forçar",
    "forçasses": "forçar",
    "forçaste": "forçar",
    "forçastes": "forçar",
    "forçava": "forçar",
    "forçavam": "forçar",
    "forçavas": "forçar",
    "forço": "forçar",
    "forçosa": "forçoso",
    "forçosas": "forçoso",
    "forçosos": "forçoso",
    "forçou": "forçar",
    "forçuda": "forçudo",
    "forçudas": "forçudo",
    "forçudos": "forçudo",
    "forçuras": "forçura",
    "forçá": "forçar",
    "forçámo": "forçar",
    "forçámos": "forçar",
    "forçáramo": "forçar",
    "forçáramos": "forçar",
    "forçárei": "forçar",
    "forçáreis": "forçar",
    "forçásseis": "forçar",
    "forçássemos": "forçar",
    "forçávamo": "forçar",
    "forçávamos": "forçar",
    "forçávei": "forçar",
    "forçáveis": "forçar",
    "forções": "forção",
    "forónidas": "forónida",
    "fosca": "fosco",
    "foscada": "foscar",
    "foscadas": "foscar",
    "foscado": "foscar",
    "foscados": "foscar",
    "foscagens": "foscagem",
    "foscai": "foscar",
    "foscais": "foscar",
    "foscam": "foscar",
    "foscamo": "foscar",
    "foscamos": "foscar",
    "foscando": "foscar",
    "foscara": "foscar",
    "foscaram": "foscar",
    "foscaras": "foscar",
    "foscarde": "foscar",
    "foscardes": "foscar",
    "foscare": "foscar",
    "foscarei": "foscar",
    "foscareis": "foscar",
    "foscarem": "foscar",
    "foscaremos": "foscar",
    "foscares": "foscar",
    "foscaria": "foscar",
    "foscariam": "foscar",
    "foscarias": "foscar",
    "foscarmo": "foscar",
    "foscarmos": "foscar",
    "foscará": "foscar",
    "foscarás": "foscar",
    "foscarão": "foscar",
    "foscaríamos": "foscar",
    "foscaríeis": "foscar",
    "foscas": "fosco",
    "foscasse": "foscar",
    "foscassem": "foscar",
    "foscasses": "foscar",
    "foscaste": "foscar",
    "foscastes": "foscar",
    "foscava": "foscar",
    "foscavam": "foscar",
    "foscavas": "foscar",
    "fosco": "foscar",
    "foscos": "fosco",
    "foscou": "foscar",
    "foscá": "foscar",
    "foscámo": "foscar",
    "foscámos": "foscar",
    "foscáramo": "foscar",
    "foscáramos": "foscar",
    "foscárei": "foscar",
    "foscáreis": "foscar",
    "foscásseis": "foscar",
    "foscássemos": "foscar",
    "foscávamo": "foscar",
    "foscávamos": "foscar",
    "foscávei": "foscar",
    "foscáveis": "foscar",
    "fosfata": "fosfatar",
    "fosfatada": "fosfatar",
    "fosfatadas": "fosfatar",
    "fosfatado": "fosfatar",
    "fosfatados": "fosfatar",
    "fosfatagens": "fosfatagem",
    "fosfatai": "fosfatar",
    "fosfatais": "fosfatar",
    "fosfatam": "fosfatar",
    "fosfatamo": "fosfatar",
    "fosfatamos": "fosfatar",
    "fosfatando": "fosfatar",
    "fosfatara": "fosfatar",
    "fosfataram": "fosfatar",
    "fosfataras": "fosfatar",
    "fosfatarde": "fosfatar",
    "fosfatardes": "fosfatar",
    "fosfatare": "fosfatar",
    "fosfatarei": "fosfatar",
    "fosfatareis": "fosfatar",
    "fosfatarem": "fosfatar",
    "fosfataremos": "fosfatar",
    "fosfatares": "fosfatar",
    "fosfataria": "fosfatar",
    "fosfatariam": "fosfatar",
    "fosfatarias": "fosfatar",
    "fosfatarmo": "fosfatar",
    "fosfatarmos": "fosfatar",
    "fosfatará": "fosfatar",
    "fosfatarás": "fosfatar",
    "fosfatarão": "fosfatar",
    "fosfataríamos": "fosfatar",
    "fosfataríeis": "fosfatar",
    "fosfatas": "fosfatar",
    "fosfatasse": "fosfatar",
    "fosfatassem": "fosfatar",
    "fosfatasses": "fosfatar",
    "fosfataste": "fosfatar",
    "fosfatastes": "fosfatar",
    "fosfatava": "fosfatar",
    "fosfatavam": "fosfatar",
    "fosfatavas": "fosfatar",
    "fosfatações": "fosfatação",
    "fosfate": "fosfatar",
    "fosfatei": "fosfatar",
    "fosfateis": "fosfatar",
    "fosfatem": "fosfatar",
    "fosfatemo": "fosfatar",
    "fosfatemos": "fosfatar",
    "fosfates": "fosfatar",
    "fosfato": "fosfatar",
    "fosfatos": "fosfato",
    "fosfatou": "fosfatar",
    "fosfatá": "fosfatar",
    "fosfatámo": "fosfatar",
    "fosfatámos": "fosfatar",
    "fosfatáramo": "fosfatar",
    "fosfatáramos": "fosfatar",
    "fosfatárei": "fosfatar",
    "fosfatáreis": "fosfatar",
    "fosfatásseis": "fosfatar",
    "fosfatássemos": "fosfatar",
    "fosfatávamo": "fosfatar",
    "fosfatávamos": "fosfatar",
    "fosfatávei": "fosfatar",
    "fosfatáveis": "fosfatável",
    "fosfatúrias": "fosfatúria",
    "fosfatúrica": "fosfatúrico",
    "fosfatúricas": "fosfatúrico",
    "fosfatúricos": "fosfatúrico",
    "fosfenas": "fosfena",
    "fosfenos": "fosfeno",
    "fosfitos": "fosfito",
    "fosfora": "fosforar",
    "fosforada": "fosforar",
    "fosforadas": "fosforar",
    "fosforado": "fosforar",
    "fosforados": "fosforar",
    "fosforai": "fosforar",
    "fosforais": "fosforar",
    "fosforam": "fosforar",
    "fosforamo": "fosforar",
    "fosforamos": "fosforar",
    "fosforando": "fosforar",
    "fosforara": "fosforar",
    "fosforaram": "fosforar",
    "fosforaras": "fosforar",
    "fosforarde": "fosforar",
    "fosforardes": "fosforar",
    "fosforare": "fosforar",
    "fosforarei": "fosforar",
    "fosforareis": "fosforar",
    "fosforarem": "fosforar",
    "fosforaremos": "fosforar",
    "fosforares": "fosforar",
    "fosforaria": "fosforar",
    "fosforariam": "fosforar",
    "fosforarias": "fosforar",
    "fosforarmo": "fosforar",
    "fosforarmos": "fosforar",
    "fosforará": "fosforar",
    "fosforarás": "fosforar",
    "fosforarão": "fosforar",
    "fosforaríamos": "fosforar",
    "fosforaríeis": "fosforar",
    "fosforas": "fosforar",
    "fosforasse": "fosforar",
    "fosforassem": "fosforar",
    "fosforasses": "fosforar",
    "fosforaste": "fosforar",
    "fosforastes": "fosforar",
    "fosforava": "fosforar",
    "fosforavam": "fosforar",
    "fosforavas": "fosforar",
    "fosforações": "fosforação",
    "fosfore": "fosforar",
    "fosforeada": "fosforear",
    "fosforeadas": "fosforear",
    "fosforeado": "fosforear",
    "fosforeados": "fosforear",
    "fosforeai": "fosforear",
    "fosforeais": "fosforear",
    "fosforeamo": "fosforear",
    "fosforeamos": "fosforear",
    "fosforeando": "fosforear",
    "fosforeara": "fosforear",
    "fosforearam": "fosforear",
    "fosforearas": "fosforear",
    "fosforeardes": "fosforear",
    "fosforearei": "fosforear",
    "fosforeareis": "fosforear",
    "fosforearem": "fosforear",
    "fosforearemos": "fosforear",
    "fosforeares": "fosforear",
    "fosforearia": "fosforear",
    "fosforeariam": "fosforear",
    "fosforearias": "fosforear",
    "fosforearmo": "fosforear",
    "fosforearmos": "fosforear",
    "fosforeará": "fosforear",
    "fosforearás": "fosforear",
    "fosforearão": "fosforear",
    "fosforearíamos": "fosforear",
    "fosforearíeis": "fosforear",
    "fosforeasse": "fosforear",
    "fosforeassem": "fosforear",
    "fosforeasses": "fosforear",
    "fosforeaste": "fosforear",
    "fosforeastes": "fosforear",
    "fosforeava": "fosforear",
    "fosforeavam": "fosforear",
    "fosforeavas": "fosforear",
    "fosforeei": "fosforear",
    "fosforeeis": "fosforear",
    "fosforeemo": "fosforear",
    "fosforeemos": "fosforear",
    "fosforei": "fosforar",
    "fosforeia": "fosforear",
    "fosforeiam": "fosforear",
    "fosforeias": "fosforear",
    "fosforeie": "fosforear",
    "fosforeiem": "fosforear",
    "fosforeies": "fosforear",
    "fosforeio": "fosforear",
    "fosforeira": "fosforeiro",
    "fosforeiras": "fosforeiro",
    "fosforeiros": "fosforeiro",
    "fosforeis": "fosforar",
    "fosforeja": "fosforejar",
    "fosforejada": "fosforejar",
    "fosforejadas": "fosforejar",
    "fosforejado": "fosforejar",
    "fosforejados": "fosforejar",
    "fosforejai": "fosforejar",
    "fosforejais": "fosforejar",
    "fosforejam": "fosforejar",
    "fosforejamo": "fosforejar",
    "fosforejamos": "fosforejar",
    "fosforejando": "fosforejar",
    "fosforejantes": "fosforejante",
    "fosforejara": "fosforejar",
    "fosforejaram": "fosforejar",
    "fosforejaras": "fosforejar",
    "fosforejardes": "fosforejar",
    "fosforejarei": "fosforejar",
    "fosforejareis": "fosforejar",
    "fosforejarem": "fosforejar",
    "fosforejaremos": "fosforejar",
    "fosforejares": "fosforejar",
    "fosforejaria": "fosforejar",
    "fosforejariam": "fosforejar",
    "fosforejarias": "fosforejar",
    "fosforejarmo": "fosforejar",
    "fosforejarmos": "fosforejar",
    "fosforejará": "fosforejar",
    "fosforejarás": "fosforejar",
    "fosforejarão": "fosforejar",
    "fosforejaríamos": "fosforejar",
    "fosforejaríeis": "fosforejar",
    "fosforejas": "fosforejar",
    "fosforejasse": "fosforejar",
    "fosforejassem": "fosforejar",
    "fosforejasses": "fosforejar",
    "fosforejaste": "fosforejar",
    "fosforejastes": "fosforejar",
    "fosforejava": "fosforejar",
    "fosforejavam": "fosforejar",
    "fosforejavas": "fosforejar",
    "fosforeje": "fosforejar",
    "fosforejei": "fosforejar",
    "fosforejeis": "fosforejar",
    "fosforejem": "fosforejar",
    "fosforejemo": "fosforejar",
    "fosforejemos": "fosforejar",
    "fosforejes": "fosforejar",
    "fosforejo": "fosforejar",
    "fosforejou": "fosforejar",
    "fosforejámo": "fosforejar",
    "fosforejámos": "fosforejar",
    "fosforejáramo": "fosforejar",
    "fosforejáramos": "fosforejar",
    "fosforejáreis": "fosforejar",
    "fosforejásseis": "fosforejar",
    "fosforejássemos": "fosforejar",
    "fosforejávamo": "fosforejar",
    "fosforejávamos": "fosforejar",
    "fosforejáveis": "fosforejar",
    "fosforem": "fosforar",
    "fosforemo": "fosforar",
    "fosforemos": "fosforar",
    "fosforeou": "fosforear",
    "fosfores": "fosforar",
    "fosforesce": "fosforescer",
    "fosforescei": "fosforescer",
    "fosforesceis": "fosforescer",
    "fosforescem": "fosforescer",
    "fosforescemo": "fosforescer",
    "fosforescemos": "fosforescer",
    "fosforescendo": "fosforescer",
    "fosforescentes": "fosforescente",
    "fosforescera": "fosforescer",
    "fosforesceram": "fosforescer",
    "fosforesceras": "fosforescer",
    "fosforescerdes": "fosforescer",
    "fosforescerei": "fosforescer",
    "fosforescereis": "fosforescer",
    "fosforescerem": "fosforescer",
    "fosforesceremos": "fosforescer",
    "fosforesceres": "fosforescer",
    "fosforesceria": "fosforescer",
    "fosforesceriam": "fosforescer",
    "fosforescerias": "fosforescer",
    "fosforescermo": "fosforescer",
    "fosforescermos": "fosforescer",
    "fosforescerá": "fosforescer",
    "fosforescerás": "fosforescer",
    "fosforescerão": "fosforescer",
    "fosforesceríamos": "fosforescer",
    "fosforesceríeis": "fosforescer",
    "fosforesces": "fosforescer",
    "fosforescesse": "fosforescer",
    "fosforescessem": "fosforescer",
    "fosforescesses": "fosforescer",
    "fosforesceste": "fosforescer",
    "fosforescestes": "fosforescer",
    "fosforesceu": "fosforescer",
    "fosforesci": "fosforescer",
    "fosforescia": "fosforescer",
    "fosforesciam": "fosforescer",
    "fosforescias": "fosforescer",
    "fosforescida": "fosforescer",
    "fosforescidas": "fosforescer",
    "fosforescido": "fosforescer",
    "fosforescidos": "fosforescer",
    "fosforescências": "fosforescência",
    "fosforescêramo": "fosforescer",
    "fosforescêramos": "fosforescer",
    "fosforescêreis": "fosforescer",
    "fosforescêsseis": "fosforescer",
    "fosforescêssemos": "fosforescer",
    "fosforescíamo": "fosforescer",
    "fosforescíamos": "fosforescer",
    "fosforescíeis": "fosforescer",
    "fosforesça": "fosforescer",
    "fosforesçais": "fosforescer",
    "fosforesçam": "fosforescer",
    "fosforesçamo": "fosforescer",
    "fosforesçamos": "fosforescer",
    "fosforesças": "fosforescer",
    "fosforesço": "fosforescer",
    "fosforeta": "fosforetar",
    "fosforetada": "fosforetar",
    "fosforetadas": "fosforetar",
    "fosforetado": "fosforetar",
    "fosforetados": "fosforetar",
    "fosforetai": "fosforetar",
    "fosforetais": "fosforetar",
    "fosforetam": "fosforetar",
    "fosforetamo": "fosforetar",
    "fosforetamos": "fosforetar",
    "fosforetando": "fosforetar",
    "fosforetara": "fosforetar",
    "fosforetaram": "fosforetar",
    "fosforetaras": "fosforetar",
    "fosforetardes": "fosforetar",
    "fosforetarei": "fosforetar",
    "fosforetareis": "fosforetar",
    "fosforetarem": "fosforetar",
    "fosforetaremos": "fosforetar",
    "fosforetares": "fosforetar",
    "fosforetaria": "fosforetar",
    "fosforetariam": "fosforetar",
    "fosforetarias": "fosforetar",
    "fosforetarmo": "fosforetar",
    "fosforetarmos": "fosforetar",
    "fosforetará": "fosforetar",
    "fosforetarás": "fosforetar",
    "fosforetarão": "fosforetar",
    "fosforetaríamos": "fosforetar",
    "fosforetaríeis": "fosforetar",
    "fosforetas": "fosforetar",
    "fosforetasse": "fosforetar",
    "fosforetassem": "fosforetar",
    "fosforetasses": "fosforetar",
    "fosforetaste": "fosforetar",
    "fosforetastes": "fosforetar",
    "fosforetava": "fosforetar",
    "fosforetavam": "fosforetar",
    "fosforetavas": "fosforetar",
    "fosforete": "fosforetar",
    "fosforetei": "fosforetar",
    "fosforeteis": "fosforetar",
    "fosforetem": "fosforetar",
    "fosforetemo": "fosforetar",
    "fosforetemos": "fosforetar",
    "fosforetes": "fosforetar",
    "fosforeto": "fosforetar",
    "fosforetou": "fosforetar",
    "fosforetámo": "fosforetar",
    "fosforetámos": "fosforetar",
    "fosforetáramo": "fosforetar",
    "fosforetáramos": "fosforetar",
    "fosforetáreis": "fosforetar",
    "fosforetásseis": "fosforetar",
    "fosforetássemos": "fosforetar",
    "fosforetávamo": "fosforetar",
    "fosforetávamos": "fosforetar",
    "fosforetáveis": "fosforetar",
    "fosforeámo": "fosforear",
    "fosforeámos": "fosforear",
    "fosforeáramo": "fosforear",
    "fosforeáramos": "fosforear",
    "fosforeáreis": "fosforear",
    "fosforeásseis": "fosforear",
    "fosforeássemos": "fosforear",
    "fosforeávamo": "fosforear",
    "fosforeávamos": "fosforear",
    "fosforeáveis": "fosforear",
    "fosforismos": "fosforismo",
    "fosforistas": "fosforista",
    "fosforites": "fosforite",
    "fosforiza": "fosforizar",
    "fosforizada": "fosforizar",
    "fosforizadas": "fosforizar",
    "fosforizado": "fosforizar",
    "fosforizados": "fosforizar",
    "fosforizai": "fosforizar",
    "fosforizais": "fosforizar",
    "fosforizam": "fosforizar",
    "fosforizamo": "fosforizar",
    "fosforizamos": "fosforizar",
    "fosforizando": "fosforizar",
    "fosforizara": "fosforizar",
    "fosforizaram": "fosforizar",
    "fosforizaras": "fosforizar",
    "fosforizarde": "fosforizar",
    "fosforizardes": "fosforizar",
    "fosforizare": "fosforizar",
    "fosforizarei": "fosforizar",
    "fosforizareis": "fosforizar",
    "fosforizarem": "fosforizar",
    "fosforizaremos": "fosforizar",
    "fosforizares": "fosforizar",
    "fosforizaria": "fosforizar",
    "fosforizariam": "fosforizar",
    "fosforizarias": "fosforizar",
    "fosforizarmo": "fosforizar",
    "fosforizarmos": "fosforizar",
    "fosforizará": "fosforizar",
    "fosforizarás": "fosforizar",
    "fosforizarão": "fosforizar",
    "fosforizaríamos": "fosforizar",
    "fosforizaríeis": "fosforizar",
    "fosforizas": "fosforizar",
    "fosforizasse": "fosforizar",
    "fosforizassem": "fosforizar",
    "fosforizasses": "fosforizar",
    "fosforizaste": "fosforizar",
    "fosforizastes": "fosforizar",
    "fosforizava": "fosforizar",
    "fosforizavam": "fosforizar",
    "fosforizavas": "fosforizar",
    "fosforizações": "fosforização",
    "fosforize": "fosforizar",
    "fosforizei": "fosforizar",
    "fosforizeis": "fosforizar",
    "fosforizem": "fosforizar",
    "fosforizemo": "fosforizar",
    "fosforizemos": "fosforizar",
    "fosforizes": "fosforizar",
    "fosforizo": "fosforizar",
    "fosforizou": "fosforizar",
    "fosforizá": "fosforizar",
    "fosforizámo": "fosforizar",
    "fosforizámos": "fosforizar",
    "fosforizáramo": "fosforizar",
    "fosforizáramos": "fosforizar",
    "fosforizárei": "fosforizar",
    "fosforizáreis": "fosforizar",
    "fosforizásseis": "fosforizar",
    "fosforizássemos": "fosforizar",
    "fosforizávamo": "fosforizar",
    "fosforizávamos": "fosforizar",
    "fosforizávei": "fosforizar",
    "fosforizáveis": "fosforizar",
    "fosforo": "fosforar",
    "fosforogénea": "fosforogéneo",
    "fosforogéneas": "fosforogéneo",
    "fosforogéneos": "fosforogéneo",
    "fosforogénica": "fosforogénico",
    "fosforogénicas": "fosforogénico",
    "fosforogénicos": "fosforogénico",
    "fosforoscópica": "fosforoscópico",
    "fosforoscópicas": "fosforoscópico",
    "fosforoscópicos": "fosforoscópico",
    "fosforoscópios": "fosforoscópio",
    "fosforou": "fosforar",
    "fosforozinho": "fósforo",
    "fosforozinhos": "fósforo",
    "fosforozito": "fósforo",
    "fosforozitos": "fósforo",
    "fosforá": "fosforar",
    "fosforámo": "fosforar",
    "fosforámos": "fosforar",
    "fosforáramo": "fosforar",
    "fosforáramos": "fosforar",
    "fosforárei": "fosforar",
    "fosforáreis": "fosforar",
    "fosforásseis": "fosforar",
    "fosforássemos": "fosforar",
    "fosforávamo": "fosforar",
    "fosforávamos": "fosforar",
    "fosforávei": "fosforar",
    "fosforáveis": "fosforar",
    "fosforífera": "fosforífero",
    "fosforíferas": "fosforífero",
    "fosforíferos": "fosforífero",
    "fosforítica": "fosforítico",
    "fosforíticas": "fosforítico",
    "fosforíticos": "fosforítico",
    "fosfénica": "fosfénico",
    "fosfénicas": "fosfénico",
    "fosfénicos": "fosfénico",
    "fosfítica": "fosfítico",
    "fosfíticas": "fosfítico",
    "fosfíticos": "fosfítico",
    "fosfórea": "fosfóreo",
    "fosfóreas": "fosfóreo",
    "fosfóreos": "fosfóreo",
    "fosfórica": "fosfórico",
    "fosfóricas": "fosfórico",
    "fosfóricos": "fosfórico",
    "fosgas": "fosga",
    "fosgénios": "fosgénio",
    "fosque": "foscar",
    "fosqueamentos": "fosqueamento",
    "fosquei": "foscar",
    "fosqueis": "foscar",
    "fosquem": "foscar",
    "fosquemo": "foscar",
    "fosquemos": "foscar",
    "fosques": "foscar",
    "fosquinhas": "fosquinha",
    "fosquistas": "fosquista",
    "fossa": "fossar",
    "fossada": "fossar",
    "fossadas": "fossar",
    "fossadeiras": "fossadeira",
    "fossado": "fossar",
    "fossadora": "fossador",
    "fossadoras": "fossador",
    "fossadores": "fossador",
    "fossados": "fossar",
    "fossai": "fossar",
    "fossais": "fossar",
    "fossalistas": "fossalista",
    "fossam": "fossar",
    "fossamo": "fossar",
    "fossamos": "fossar",
    "fossando": "fossar",
    "fossara": "fossar",
    "fossaram": "fossar",
    "fossaras": "fossar",
    "fossarde": "fossar",
    "fossardes": "fossar",
    "fossare": "fossar",
    "fossarei": "fossar",
    "fossareis": "fossar",
    "fossarem": "fossar",
    "fossaremos": "fossar",
    "fossares": "fossar",
    "fossaria": "fossar",
    "fossariam": "fossar",
    "fossarias": "fossar",
    "fossarmo": "fossar",
    "fossarmos": "fossar",
    "fossará": "fossar",
    "fossarás": "fossar",
    "fossarão": "fossar",
    "fossaríamos": "fossar",
    "fossaríeis": "fossar",
    "fossas": "fossar",
    "fossasse": "fossar",
    "fossassem": "fossar",
    "fossasses": "fossar",
    "fossaste": "fossar",
    "fossastes": "fossar",
    "fossava": "fossar",
    "fossavam": "fossar",
    "fossavas": "fossar",
    "fosse": "ser",
    "fossei": "fossar",
    "fosseis": "fossar",
    "fossem": "ser",
    "fossemo": "fossar",
    "fossemos": "fossar",
    "fosses": "ser",
    "fossetas": "fosseta",
    "fossetes": "fossete",
    "fossiformes": "fossiforme",
    "fossilismos": "fossilismo",
    "fossilistas": "fossilista",
    "fossiliza": "fossilizar",
    "fossilizada": "fossilizar",
    "fossilizadas": "fossilizar",
    "fossilizado": "fossilizar",
    "fossilizados": "fossilizar",
    "fossilizai": "fossilizar",
    "fossilizais": "fossilizar",
    "fossilizam": "fossilizar",
    "fossilizamo": "fossilizar",
    "fossilizamos": "fossilizar",
    "fossilizando": "fossilizar",
    "fossilizara": "fossilizar",
    "fossilizaram": "fossilizar",
    "fossilizaras": "fossilizar",
    "fossilizarde": "fossilizar",
    "fossilizardes": "fossilizar",
    "fossilizare": "fossilizar",
    "fossilizarei": "fossilizar",
    "fossilizareis": "fossilizar",
    "fossilizarem": "fossilizar",
    "fossilizaremos": "fossilizar",
    "fossilizares": "fossilizar",
    "fossilizaria": "fossilizar",
    "fossilizariam": "fossilizar",
    "fossilizarias": "fossilizar",
    "fossilizarmo": "fossilizar",
    "fossilizarmos": "fossilizar",
    "fossilizará": "fossilizar",
    "fossilizarás": "fossilizar",
    "fossilizarão": "fossilizar",
    "fossilizaríamos": "fossilizar",
    "fossilizaríeis": "fossilizar",
    "fossilizas": "fossilizar",
    "fossilizasse": "fossilizar",
    "fossilizassem": "fossilizar",
    "fossilizasses": "fossilizar",
    "fossilizaste": "fossilizar",
    "fossilizastes": "fossilizar",
    "fossilizava": "fossilizar",
    "fossilizavam": "fossilizar",
    "fossilizavas": "fossilizar",
    "fossilizações": "fossilização",
    "fossilize": "fossilizar",
    "fossilizei": "fossilizar",
    "fossilizeis": "fossilizar",
    "fossilizem": "fossilizar",
    "fossilizemo": "fossilizar",
    "fossilizemos": "fossilizar",
    "fossilizes": "fossilizar",
    "fossilizo": "fossilizar",
    "fossilizou": "fossilizar",
    "fossilizá": "fossilizar",
    "fossilizámo": "fossilizar",
    "fossilizámos": "fossilizar",
    "fossilizáramo": "fossilizar",
    "fossilizáramos": "fossilizar",
    "fossilizárei": "fossilizar",
    "fossilizáreis": "fossilizar",
    "fossilizásseis": "fossilizar",
    "fossilizássemos": "fossilizar",
    "fossilizávamo": "fossilizar",
    "fossilizávamos": "fossilizar",
    "fossilizávei": "fossilizar",
    "fossilizáveis": "fossilizável",
    "fossilífera": "fossilífero",
    "fossilíferas": "fossilífero",
    "fossilíferos": "fossilífero",
    "fosso": "fossar",
    "fossona": "fossão",
    "fossonas": "fossão",
    "fossos": "fosso",
    "fossou": "fossar",
    "fossá": "fossar",
    "fossámo": "fossar",
    "fossámos": "fossar",
    "fossáramo": "fossar",
    "fossáramos": "fossar",
    "fossárei": "fossar",
    "fossáreis": "fossar",
    "fossários": "fossário",
    "fossásseis": "fossar",
    "fossássemos": "fossar",
    "fossávamo": "fossar",
    "fossávamos": "fossar",
    "fossávei": "fossar",
    "fossáveis": "fossar",
    "fossípedes": "fossípede",
    "fossões": "fossão",
    "foste": "ser",
    "fostes": "ser",
    "fotas": "fota",
    "foteada": "fotear",
    "foteadas": "fotear",
    "foteado": "fotear",
    "foteados": "fotear",
    "foteai": "fotear",
    "foteais": "fotear",
    "foteamo": "fotear",
    "foteamos": "fotear",
    "foteando": "fotear",
    "foteara": "fotear",
    "fotearam": "fotear",
    "fotearas": "fotear",
    "fotearde": "fotear",
    "foteardes": "fotear",
    "foteare": "fotear",
    "fotearei": "fotear",
    "foteareis": "fotear",
    "fotearem": "fotear",
    "fotearemos": "fotear",
    "foteares": "fotear",
    "fotearia": "fotear",
    "foteariam": "fotear",
    "fotearias": "fotear",
    "fotearmo": "fotear",
    "fotearmos": "fotear",
    "foteará": "fotear",
    "fotearás": "fotear",
    "fotearão": "fotear",
    "fotearíamos": "fotear",
    "fotearíeis": "fotear",
    "foteasse": "fotear",
    "foteassem": "fotear",
    "foteasses": "fotear",
    "foteaste": "fotear",
    "foteastes": "fotear",
    "foteava": "fotear",
    "foteavam": "fotear",
    "foteavas": "fotear",
    "foteei": "fotear",
    "foteeis": "fotear",
    "foteemo": "fotear",
    "foteemos": "fotear",
    "foteia": "fotear",
    "foteiam": "fotear",
    "foteias": "fotear",
    "foteie": "fotear",
    "foteiem": "fotear",
    "foteies": "fotear",
    "foteio": "fotear",
    "foteléctrica": "foteléctrico",
    "foteléctricas": "foteléctrico",
    "foteléctricos": "foteléctrico",
    "foteou": "fotear",
    "foteá": "fotear",
    "foteámo": "fotear",
    "foteámos": "fotear",
    "foteáramo": "fotear",
    "foteáramos": "fotear",
    "foteárei": "fotear",
    "foteáreis": "fotear",
    "foteásseis": "fotear",
    "foteássemos": "fotear",
    "foteávamo": "fotear",
    "foteávamos": "fotear",
    "foteávei": "fotear",
    "foteáveis": "fotear",
    "fotismos": "fotismo",
    "fotobiografias": "fotobiografia",
    "fotocartas": "fotocarta",
    "fotocartografias": "fotocartografia",
    "fotocartografistas": "fotocartografista",
    "fotocartográfica": "fotocartográfico",
    "fotocartográficas": "fotocartográfico",
    "fotocartográficos": "fotocartográfico",
    "fotocerâmicas": "fotocerâmica",
    "fotocisões": "fotocisão",
    "fotocolografias": "fotocolografia",
    "fotocolografistas": "fotocolografista",
    "fotocolográfica": "fotocolográfico",
    "fotocolográficas": "fotocolográfico",
    "fotocolográficos": "fotocolográfico",
    "fotocolorimetrias": "fotocolorimetria",
    "fotocolorimétrica": "fotocolorimétrico",
    "fotocolorimétricas": "fotocolorimétrico",
    "fotocolorimétricos": "fotocolorimétrico",
    "fotocolorímetros": "fotocolorímetro",
    "fotocomposições": "fotocomposição",
    "fotocondutiva": "fotocondutivo",
    "fotocondutivas": "fotocondutivo",
    "fotocondutividades": "fotocondutividade",
    "fotocondutivos": "fotocondutivo",
    "fotocopia": "fotocopiar",
    "fotocopiada": "fotocopiar",
    "fotocopiadas": "fotocopiar",
    "fotocopiado": "fotocopiar",
    "fotocopiadoras": "fotocopiadora",
    "fotocopiados": "fotocopiar",
    "fotocopiai": "fotocopiar",
    "fotocopiais": "fotocopiar",
    "fotocopiam": "fotocopiar",
    "fotocopiamo": "fotocopiar",
    "fotocopiamos": "fotocopiar",
    "fotocopiando": "fotocopiar",
    "fotocopiara": "fotocopiar",
    "fotocopiaram": "fotocopiar",
    "fotocopiaras": "fotocopiar",
    "fotocopiarde": "fotocopiar",
    "fotocopiardes": "fotocopiar",
    "fotocopiare": "fotocopiar",
    "fotocopiarei": "fotocopiar",
    "fotocopiareis": "fotocopiar",
    "fotocopiarem": "fotocopiar",
    "fotocopiaremos": "fotocopiar",
    "fotocopiares": "fotocopiar",
    "fotocopiaria": "fotocopiar",
    "fotocopiariam": "fotocopiar",
    "fotocopiarias": "fotocopiar",
    "fotocopiarmo": "fotocopiar",
    "fotocopiarmos": "fotocopiar",
    "fotocopiará": "fotocopiar",
    "fotocopiarás": "fotocopiar",
    "fotocopiarão": "fotocopiar",
    "fotocopiaríamos": "fotocopiar",
    "fotocopiaríeis": "fotocopiar",
    "fotocopias": "fotocopiar",
    "fotocopiasse": "fotocopiar",
    "fotocopiassem": "fotocopiar",
    "fotocopiasses": "fotocopiar",
    "fotocopiaste": "fotocopiar",
    "fotocopiastes": "fotocopiar",
    "fotocopiava": "fotocopiar",
    "fotocopiavam": "fotocopiar",
    "fotocopiavas": "fotocopiar",
    "fotocopie": "fotocopiar",
    "fotocopiei": "fotocopiar",
    "fotocopieis": "fotocopiar",
    "fotocopiem": "fotocopiar",
    "fotocopiemo": "fotocopiar",
    "fotocopiemos": "fotocopiar",
    "fotocopies": "fotocopiar",
    "fotocopio": "fotocopiar",
    "fotocopiou": "fotocopiar",
    "fotocopistas": "fotocopista",
    "fotocopiá": "fotocopiar",
    "fotocopiámo": "fotocopiar",
    "fotocopiámos": "fotocopiar",
    "fotocopiáramo": "fotocopiar",
    "fotocopiáramos": "fotocopiar",
    "fotocopiárei": "fotocopiar",
    "fotocopiáreis": "fotocopiar",
    "fotocopiásseis": "fotocopiar",
    "fotocopiássemos": "fotocopiar",
    "fotocopiávamo": "fotocopiar",
    "fotocopiávamos": "fotocopiar",
    "fotocopiávei": "fotocopiar",
    "fotocopiáveis": "fotocopiável",
    "fotocromias": "fotocromia",
    "fotocrómica": "fotocrómico",
    "fotocrómicas": "fotocrómico",
    "fotocrómicos": "fotocrómico",
    "fotocópias": "fotocópia",
    "fotodesintegrada": "fotodesintegrado",
    "fotodesintegradas": "fotodesintegrado",
    "fotodesintegradora": "fotodesintegrador",
    "fotodesintegradoras": "fotodesintegrador",
    "fotodesintegradores": "fotodesintegrador",
    "fotodesintegrados": "fotodesintegrado",
    "fotodesintegrativa": "fotodesintegrativo",
    "fotodesintegrativas": "fotodesintegrativo",
    "fotodesintegrativos": "fotodesintegrativo",
    "fotodesintegrações": "fotodesintegração",
    "fotodieléctrica": "fotodieléctrico",
    "fotodieléctricas": "fotodieléctrico",
    "fotodieléctricos": "fotodieléctrico",
    "fotoelasticidades": "fotoelasticidade",
    "fotoelectrónica": "fotoelectrónico",
    "fotoelectrónicas": "fotoelectrónico",
    "fotoelectrónicos": "fotoelectrónico",
    "fotoelectrões": "fotoelectrão",
    "fotoelástica": "fotoelástico",
    "fotoelásticas": "fotoelástico",
    "fotoelásticos": "fotoelástico",
    "fotoeléctrica": "fotoeléctrico",
    "fotoeléctricas": "fotoeléctrico",
    "fotoeléctricos": "fotoeléctrico",
    "fotoemissora": "fotoemissor",
    "fotoemissoras": "fotoemissor",
    "fotoemissores": "fotoemissor",
    "fotoemissões": "fotoemissão",
    "fotofobias": "fotofobia",
    "fotofóbica": "fotofóbico",
    "fotofóbicas": "fotofóbico",
    "fotofóbicos": "fotofóbico",
    "fotogenias": "fotogenia",
    "fotogenésica": "fotogenésico",
    "fotogenésicas": "fotogenésico",
    "fotogenésicos": "fotogenésico",
    "fotogenética": "fotogenético",
    "fotogenéticas": "fotogenético",
    "fotogenéticos": "fotogenético",
    "fotografa": "fotografar",
    "fotografada": "fotografar",
    "fotografadas": "fotografar",
    "fotografado": "fotografar",
    "fotografados": "fotografar",
    "fotografai": "fotografar",
    "fotografais": "fotografar",
    "fotografam": "fotografar",
    "fotografamo": "fotografar",
    "fotografamos": "fotografar",
    "fotografando": "fotografar",
    "fotografara": "fotografar",
    "fotografaram": "fotografar",
    "fotografaras": "fotografar",
    "fotografarde": "fotografar",
    "fotografardes": "fotografar",
    "fotografare": "fotografar",
    "fotografarei": "fotografar",
    "fotografareis": "fotografar",
    "fotografarem": "fotografar",
    "fotografaremos": "fotografar",
    "fotografares": "fotografar",
    "fotografaria": "fotografar",
    "fotografariam": "fotografar",
    "fotografarias": "fotografar",
    "fotografarmo": "fotografar",
    "fotografarmos": "fotografar",
    "fotografará": "fotografar",
    "fotografarás": "fotografar",
    "fotografarão": "fotografar",
    "fotografaríamos": "fotografar",
    "fotografaríeis": "fotografar",
    "fotografas": "fotografar",
    "fotografasse": "fotografar",
    "fotografassem": "fotografar",
    "fotografasses": "fotografar",
    "fotografaste": "fotografar",
    "fotografastes": "fotografar",
    "fotografava": "fotografar",
    "fotografavam": "fotografar",
    "fotografavas": "fotografar",
    "fotografe": "fotografar",
    "fotografei": "fotografar",
    "fotografeis": "fotografar",
    "fotografem": "fotografar",
    "fotografemo": "fotografar",
    "fotografemos": "fotografar",
    "fotografes": "fotografar",
    "fotografias": "fotografia",
    "fotografo": "fotografar",
    "fotografou": "fotografar",
    "fotografá": "fotografar",
    "fotografámo": "fotografar",
    "fotografámos": "fotografar",
    "fotografáramo": "fotografar",
    "fotografáramos": "fotografar",
    "fotografárei": "fotografar",
    "fotografáreis": "fotografar",
    "fotografásseis": "fotografar",
    "fotografássemos": "fotografar",
    "fotografávamo": "fotografar",
    "fotografávamos": "fotografar",
    "fotografávei": "fotografar",
    "fotografáveis": "fotografável",
    "fotogramas": "fotograma",
    "fotogrametrias": "fotogrametria",
    "fotogramétrica": "fotogramétrico",
    "fotogramétricas": "fotogramétrico",
    "fotogramétricos": "fotogramétrico",
    "fotogravadores": "fotogravador",
    "fotogravuras": "fotogravura",
    "fotográfica": "fotográfico",
    "fotográficas": "fotográfico",
    "fotográficos": "fotográfico",
    "fotogéneses": "fotogénese",
    "fotogénica": "fotogénico",
    "fotogénicas": "fotogénico",
    "fotogénicos": "fotogénico",
    "fotoionizada": "fotoionizado",
    "fotoionizadas": "fotoionizado",
    "fotoionizados": "fotoionizado",
    "fotoionizações": "fotoionização",
    "fotojornalistas": "fotojornalista",
    "fotolitografias": "fotolitografia",
    "fotolitografistas": "fotolitografista",
    "fotolitográfica": "fotolitográfico",
    "fotolitográficas": "fotolitográfico",
    "fotolitográficos": "fotolitográfico",
    "fotolitos": "fotolito",
    "fotologias": "fotologia",
    "fotologistas": "fotologista",
    "fotoluminescentes": "fotoluminescente",
    "fotoluminescências": "fotoluminescência",
    "fotolítica": "fotolítico",
    "fotolíticas": "fotolítico",
    "fotolíticos": "fotolítico",
    "fotológica": "fotológico",
    "fotológicas": "fotológico",
    "fotológicos": "fotológico",
    "fotomagnetismos": "fotomagnetismo",
    "fotomagnética": "fotomagnético",
    "fotomagnéticas": "fotomagnético",
    "fotomagnéticos": "fotomagnético",
    "fotomecânica": "fotomecânico",
    "fotomecânicas": "fotomecânico",
    "fotomecânicos": "fotomecânico",
    "fotomesónica": "fotomesónico",
    "fotomesónicas": "fotomesónico",
    "fotomesónicos": "fotomesónico",
    "fotomesões": "fotomesão",
    "fotometrias": "fotometria",
    "fotometristas": "fotometrista",
    "fotomicrografias": "fotomicrografia",
    "fotomicrográfica": "fotomicrográfico",
    "fotomicrográficas": "fotomicrográfico",
    "fotomicrográficos": "fotomicrográfico",
    "fotominiaturas": "fotominiatura",
    "fotominiaturistas": "fotominiaturista",
    "fotominiaturizada": "fotominiaturizado",
    "fotominiaturizadas": "fotominiaturizado",
    "fotominiaturizados": "fotominiaturizado",
    "fotomontagens": "fotomontagem",
    "fotomultiplicadora": "fotomultiplicador",
    "fotomultiplicadoras": "fotomultiplicador",
    "fotomultiplicadores": "fotomultiplicador",
    "fotométrica": "fotométrico",
    "fotométricas": "fotométrico",
    "fotométricos": "fotométrico",
    "fotoneutrónica": "fotoneutrónico",
    "fotoneutrónicas": "fotoneutrónico",
    "fotoneutrónicos": "fotoneutrónico",
    "fotoneutrões": "fotoneutrão",
    "fotonosias": "fotonosia",
    "fotonovelas": "fotonovela",
    "fotonucleares": "fotonuclear",
    "fotonucleica": "fotonucleico",
    "fotonucleicas": "fotonucleico",
    "fotonucleicos": "fotonucleico",
    "fotonósica": "fotonósico",
    "fotonósicas": "fotonósico",
    "fotonósicos": "fotonósico",
    "fotonótica": "fotonótico",
    "fotonóticas": "fotonótico",
    "fotonóticos": "fotonótico",
    "fotopsias": "fotopsia",
    "fotoquineses": "fotoquinese",
    "fotoquinésica": "fotoquinésico",
    "fotoquinésicas": "fotoquinésico",
    "fotoquinésicos": "fotoquinésico",
    "fotoquinética": "fotoquinético",
    "fotoquinéticas": "fotoquinético",
    "fotoquinéticos": "fotoquinético",
    "fotoquímica": "fotoquímico",
    "fotoquímicas": "fotoquímico",
    "fotoquímicos": "fotoquímico",
    "fotos": "foto",
    "fotosferas": "fotosfera",
    "fotosférica": "fotosférico",
    "fotosféricas": "fotosférico",
    "fotosféricos": "fotosférico",
    "fotossensibilidades": "fotossensibilidade",
    "fotossensíveis": "fotossensível",
    "fotossintésica": "fotossintésico",
    "fotossintésicas": "fotossintésico",
    "fotossintésicos": "fotossintésico",
    "fotossintética": "fotossintético",
    "fotossintéticas": "fotossintético",
    "fotossintéticos": "fotossintético",
    "fotossínteses": "fotossíntese",
    "fototactismos": "fototactismo",
    "fototaxias": "fototaxia",
    "fototecas": "fototeca",
    "fototelegrafias": "fototelegrafia",
    "fototelegráfica": "fototelegráfico",
    "fototelegráficas": "fototelegráfico",
    "fototelegráficos": "fototelegráfico",
    "fototerapeutas": "fototerapeuta",
    "fototerapias": "fototerapia",
    "fototerapistas": "fototerapista",
    "fototerapêutica": "fototerapêutico",
    "fototerapêuticas": "fototerapêutico",
    "fototerapêuticos": "fototerapêutico",
    "fototerápica": "fototerápico",
    "fototerápicas": "fototerápico",
    "fototerápicos": "fototerápico",
    "fototipa": "fototipar",
    "fototipada": "fototipar",
    "fototipadas": "fototipar",
    "fototipado": "fototipar",
    "fototipados": "fototipar",
    "fototipai": "fototipar",
    "fototipais": "fototipar",
    "fototipam": "fototipar",
    "fototipamo": "fototipar",
    "fototipamos": "fototipar",
    "fototipando": "fototipar",
    "fototipara": "fototipar",
    "fototiparam": "fototipar",
    "fototiparas": "fototipar",
    "fototiparde": "fototipar",
    "fototipardes": "fototipar",
    "fototipare": "fototipar",
    "fototiparei": "fototipar",
    "fototipareis": "fototipar",
    "fototiparem": "fototipar",
    "fototiparemos": "fototipar",
    "fototipares": "fototipar",
    "fototiparia": "fototipar",
    "fototipariam": "fototipar",
    "fototiparias": "fototipar",
    "fototiparmo": "fototipar",
    "fototiparmos": "fototipar",
    "fototipará": "fototipar",
    "fototiparás": "fototipar",
    "fototiparão": "fototipar",
    "fototiparíamos": "fototipar",
    "fototiparíeis": "fototipar",
    "fototipas": "fototipar",
    "fototipasse": "fototipar",
    "fototipassem": "fototipar",
    "fototipasses": "fototipar",
    "fototipaste": "fototipar",
    "fototipastes": "fototipar",
    "fototipava": "fototipar",
    "fototipavam": "fototipar",
    "fototipavas": "fototipar",
    "fototipe": "fototipar",
    "fototipei": "fototipar",
    "fototipeis": "fototipar",
    "fototipem": "fototipar",
    "fototipemo": "fototipar",
    "fototipemos": "fototipar",
    "fototipes": "fototipar",
    "fototipia": "fototipiar",
    "fototipiada": "fototipiar",
    "fototipiadas": "fototipiar",
    "fototipiado": "fototipiar",
    "fototipiados": "fototipiar",
    "fototipiai": "fototipiar",
    "fototipiais": "fototipiar",
    "fototipiam": "fototipiar",
    "fototipiamo": "fototipiar",
    "fototipiamos": "fototipiar",
    "fototipiando": "fototipiar",
    "fototipiara": "fototipiar",
    "fototipiaram": "fototipiar",
    "fototipiaras": "fototipiar",
    "fototipiarde": "fototipiar",
    "fototipiardes": "fototipiar",
    "fototipiare": "fototipiar",
    "fototipiarei": "fototipiar",
    "fototipiareis": "fototipiar",
    "fototipiarem": "fototipiar",
    "fototipiaremos": "fototipiar",
    "fototipiares": "fototipiar",
    "fototipiaria": "fototipiar",
    "fototipiariam": "fototipiar",
    "fototipiarias": "fototipiar",
    "fototipiarmo": "fototipiar",
    "fototipiarmos": "fototipiar",
    "fototipiará": "fototipiar",
    "fototipiarás": "fototipiar",
    "fototipiarão": "fototipiar",
    "fototipiaríamos": "fototipiar",
    "fototipiaríeis": "fototipiar",
    "fototipias": "fototipiar",
    "fototipiasse": "fototipiar",
    "fototipiassem": "fototipiar",
    "fototipiasses": "fototipiar",
    "fototipiaste": "fototipiar",
    "fototipiastes": "fototipiar",
    "fototipiava": "fototipiar",
    "fototipiavam": "fototipiar",
    "fototipiavas": "fototipiar",
    "fototipie": "fototipiar",
    "fototipiei": "fototipiar",
    "fototipieis": "fototipiar",
    "fototipiem": "fototipiar",
    "fototipiemo": "fototipiar",
    "fototipiemos": "fototipiar",
    "fototipies": "fototipiar",
    "fototipio": "fototipiar",
    "fototipiou": "fototipiar",
    "fototipiá": "fototipiar",
    "fototipiámo": "fototipiar",
    "fototipiámos": "fototipiar",
    "fototipiáramo": "fototipiar",
    "fototipiáramos": "fototipiar",
    "fototipiárei": "fototipiar",
    "fototipiáreis": "fototipiar",
    "fototipiásseis": "fototipiar",
    "fototipiássemos": "fototipiar",
    "fototipiávamo": "fototipiar",
    "fototipiávamos": "fototipiar",
    "fototipiávei": "fototipiar",
    "fototipiáveis": "fototipiar",
    "fototipo": "fototipar",
    "fototipografias": "fototipografia",
    "fototipografistas": "fototipografista",
    "fototipogravuras": "fototipogravura",
    "fototipográfica": "fototipográfico",
    "fototipográficas": "fototipográfico",
    "fototipográficos": "fototipográfico",
    "fototipou": "fototipar",
    "fototipá": "fototipar",
    "fototipámo": "fototipar",
    "fototipámos": "fototipar",
    "fototipáramo": "fototipar",
    "fototipáramos": "fototipar",
    "fototipárei": "fototipar",
    "fototipáreis": "fototipar",
    "fototipásseis": "fototipar",
    "fototipássemos": "fototipar",
    "fototipávamo": "fototipar",
    "fototipávamos": "fototipar",
    "fototipávei": "fototipar",
    "fototipáveis": "fototipar",
    "fototopografias": "fototopografia",
    "fototopografistas": "fototopografista",
    "fototopográfica": "fototopográfico",
    "fototopográficas": "fototopográfico",
    "fototopográficos": "fototopográfico",
    "fototropismos": "fototropismo",
    "fototrópica": "fototrópico",
    "fototrópicas": "fototrópico",
    "fototrópicos": "fototrópico",
    "fototáctica": "fototáctico",
    "fototácticas": "fototáctico",
    "fototácticos": "fototáctico",
    "fototáxica": "fototáxico",
    "fototáxicas": "fototáxico",
    "fototáxicos": "fototáxico",
    "fototípica": "fototípico",
    "fototípicas": "fototípico",
    "fototípicos": "fototípico",
    "fotovoltaica": "fotovoltaico",
    "fotovoltaicas": "fotovoltaico",
    "fotovoltaicos": "fotovoltaico",
    "fotozincografias": "fotozincografia",
    "fotozincogravuras": "fotozincogravura",
    "fotozincográfica": "fotozincográfico",
    "fotozincográficas": "fotozincográfico",
    "fotozincográficos": "fotozincográfico",
    "fotófoba": "fotófobo",
    "fotófobas": "fotófobo",
    "fotófobos": "fotófobo",
    "fotógrafa": "fotógrafo",
    "fotógrafas": "fotógrafo",
    "fotógrafos": "fotógrafo",
    "fotólises": "fotólise",
    "fotóloga": "fotólogo",
    "fotólogas": "fotólogo",
    "fotólogos": "fotólogo",
    "fotómetros": "fotómetro",
    "fotópsica": "fotópsico",
    "fotópsicas": "fotópsico",
    "fotópsicos": "fotópsico",
    "fotóptica": "fotóptico",
    "fotópticas": "fotóptico",
    "fotópticos": "fotóptico",
    "fotótipos": "fotótipo",
    "fotões": "fotão",
    "fouceada": "foucear",
    "fouceadas": "foucear",
    "fouceado": "foucear",
    "fouceados": "foucear",
    "fouceai": "foucear",
    "fouceais": "foucear",
    "fouceamo": "foucear",
    "fouceamos": "foucear",
    "fouceando": "foucear",
    "fouceara": "foucear",
    "foucearam": "foucear",
    "foucearas": "foucear",
    "foucearde": "foucear",
    "fouceardes": "foucear",
    "fouceare": "foucear",
    "foucearei": "foucear",
    "fouceareis": "foucear",
    "foucearem": "foucear",
    "foucearemos": "foucear",
    "fouceares": "foucear",
    "foucearia": "foucear",
    "fouceariam": "foucear",
    "foucearias": "foucear",
    "foucearmo": "foucear",
    "foucearmos": "foucear",
    "fouceará": "foucear",
    "foucearás": "foucear",
    "foucearão": "foucear",
    "foucearíamos": "foucear",
    "foucearíeis": "foucear",
    "fouceasse": "foucear",
    "fouceassem": "foucear",
    "fouceasses": "foucear",
    "fouceaste": "foucear",
    "fouceastes": "foucear",
    "fouceava": "foucear",
    "fouceavam": "foucear",
    "fouceavas": "foucear",
    "fouceei": "foucear",
    "fouceeis": "foucear",
    "fouceemo": "foucear",
    "fouceemos": "foucear",
    "fouceia": "foucear",
    "fouceiam": "foucear",
    "fouceias": "foucear",
    "fouceie": "foucear",
    "fouceiem": "foucear",
    "fouceies": "foucear",
    "fouceio": "foucear",
    "fouceou": "foucear",
    "fouces": "fouce",
    "fouceá": "foucear",
    "fouceámo": "foucear",
    "fouceámos": "foucear",
    "fouceáramo": "foucear",
    "fouceáramos": "foucear",
    "fouceárei": "foucear",
    "fouceáreis": "foucear",
    "fouceásseis": "foucear",
    "fouceássemos": "foucear",
    "fouceávamo": "foucear",
    "fouceávamos": "foucear",
    "fouceávei": "foucear",
    "fouceáveis": "foucear",
    "fouciformes": "fouciforme",
    "foucinhos": "foucinho",
    "foucinhões": "foucinhão",
    "fouveira": "fouveiro",
    "fouveiras": "fouveiro",
    "fouveiros": "fouveiro",
    "fouçadas": "fouçada",
    "foventes": "fovente",
    "fovismos": "fovismo",
    "fozes": "foz",
    "foça": "foçar",
    "foçada": "foçar",
    "foçadas": "foçar",
    "foçado": "foçar",
    "foçados": "foçar",
    "foçai": "foçar",
    "foçais": "foçar",
    "foçam": "foçar",
    "foçamo": "foçar",
    "foçamos": "foçar",
    "foçando": "foçar",
    "foçara": "foçar",
    "foçaram": "foçar",
    "foçaras": "foçar",
    "foçarde": "foçar",
    "foçardes": "foçar",
    "foçare": "foçar",
    "foçarei": "foçar",
    "foçareis": "foçar",
    "foçarem": "foçar",
    "foçaremos": "foçar",
    "foçares": "foçar",
    "foçaria": "foçar",
    "foçariam": "foçar",
    "foçarias": "foçar",
    "foçarmo": "foçar",
    "foçarmos": "foçar",
    "foçará": "foçar",
    "foçarás": "foçar",
    "foçarão": "foçar",
    "foçaríamos": "foçar",
    "foçaríeis": "foçar",
    "foças": "foçar",
    "foçasse": "foçar",
    "foçassem": "foçar",
    "foçasses": "foçar",
    "foçaste": "foçar",
    "foçastes": "foçar",
    "foçava": "foçar",
    "foçavam": "foçar",
    "foçavas": "foçar",
    "foço": "foçar",
    "foçona": "foção",
    "foçonas": "foção",
    "foçou": "foçar",
    "foçá": "foçar",
    "foçámo": "foçar",
    "foçámos": "foçar",
    "foçáramo": "foçar",
    "foçáramos": "foçar",
    "foçárei": "foçar",
    "foçáreis": "foçar",
    "foçásseis": "foçar",
    "foçássemos": "foçar",
    "foçávamo": "foçar",
    "foçávamos": "foçar",
    "foçávei": "foçar",
    "foçáveis": "foçar",
    "foções": "foção",
    "fraca": "fraco",
    "fracalhona": "fracalhão",
    "fracalhonas": "fracalhão",
    "fracalhota": "fracalhote",
    "fracalhotas": "fracalhote",
    "fracalhotes": "fracalhote",
    "fracalhões": "fracalhão",
    "fracas": "fraco",
    "fracassa": "fracassar",
    "fracassada": "fracassar",
    "fracassadas": "fracassar",
    "fracassado": "fracassar",
    "fracassados": "fracassar",
    "fracassai": "fracassar",
    "fracassais": "fracassar",
    "fracassam": "fracassar",
    "fracassamo": "fracassar",
    "fracassamos": "fracassar",
    "fracassando": "fracassar",
    "fracassara": "fracassar",
    "fracassaram": "fracassar",
    "fracassaras": "fracassar",
    "fracassarde": "fracassar",
    "fracassardes": "fracassar",
    "fracassare": "fracassar",
    "fracassarei": "fracassar",
    "fracassareis": "fracassar",
    "fracassarem": "fracassar",
    "fracassaremos": "fracassar",
    "fracassares": "fracassar",
    "fracassaria": "fracassar",
    "fracassariam": "fracassar",
    "fracassarias": "fracassar",
    "fracassarmo": "fracassar",
    "fracassarmos": "fracassar",
    "fracassará": "fracassar",
    "fracassarás": "fracassar",
    "fracassarão": "fracassar",
    "fracassaríamos": "fracassar",
    "fracassaríeis": "fracassar",
    "fracassas": "fracassar",
    "fracassasse": "fracassar",
    "fracassassem": "fracassar",
    "fracassasses": "fracassar",
    "fracassaste": "fracassar",
    "fracassastes": "fracassar",
    "fracassava": "fracassar",
    "fracassavam": "fracassar",
    "fracassavas": "fracassar",
    "fracasse": "fracassar",
    "fracassei": "fracassar",
    "fracasseis": "fracassar",
    "fracassem": "fracassar",
    "fracassemo": "fracassar",
    "fracassemos": "fracassar",
    "fracasses": "fracassar",
    "fracasso": "fracassar",
    "fracassos": "fracasso",
    "fracassou": "fracassar",
    "fracassá": "fracassar",
    "fracassámo": "fracassar",
    "fracassámos": "fracassar",
    "fracassáramo": "fracassar",
    "fracassáramos": "fracassar",
    "fracassárei": "fracassar",
    "fracassáreis": "fracassar",
    "fracassásseis": "fracassar",
    "fracassássemos": "fracassar",
    "fracassávamo": "fracassar",
    "fracassávamos": "fracassar",
    "fracassávei": "fracassar",
    "fracassáveis": "fracassar",
    "fracciona": "fraccionar",
    "fraccionada": "fraccionar",
    "fraccionadas": "fraccionar",
    "fraccionado": "fraccionar",
    "fraccionados": "fraccionar",
    "fraccionai": "fraccionar",
    "fraccionais": "fraccionar",
    "fraccionam": "fraccionar",
    "fraccionamentos": "fraccionamento",
    "fraccionamo": "fraccionar",
    "fraccionamos": "fraccionar",
    "fraccionando": "fraccionar",
    "fraccionara": "fraccionar",
    "fraccionaram": "fraccionar",
    "fraccionaras": "fraccionar",
    "fraccionarde": "fraccionar",
    "fraccionardes": "fraccionar",
    "fraccionare": "fraccionar",
    "fraccionarei": "fraccionar",
    "fraccionareis": "fraccionar",
    "fraccionarem": "fraccionar",
    "fraccionaremos": "fraccionar",
    "fraccionares": "fraccionar",
    "fraccionaria": "fraccionar",
    "fraccionariam": "fraccionar",
    "fraccionarias": "fraccionar",
    "fraccionarmo": "fraccionar",
    "fraccionarmos": "fraccionar",
    "fraccionará": "fraccionar",
    "fraccionarás": "fraccionar",
    "fraccionarão": "fraccionar",
    "fraccionaríamos": "fraccionar",
    "fraccionaríeis": "fraccionar",
    "fraccionas": "fraccionar",
    "fraccionasse": "fraccionar",
    "fraccionassem": "fraccionar",
    "fraccionasses": "fraccionar",
    "fraccionaste": "fraccionar",
    "fraccionastes": "fraccionar",
    "fraccionava": "fraccionar",
    "fraccionavam": "fraccionar",
    "fraccionavas": "fraccionar",
    "fraccione": "fraccionar",
    "fraccionei": "fraccionar",
    "fraccioneis": "fraccionar",
    "fraccionem": "fraccionar",
    "fraccionemo": "fraccionar",
    "fraccionemos": "fraccionar",
    "fracciones": "fraccionar",
    "fracciono": "fraccionar",
    "fraccionou": "fraccionar",
    "fraccioná": "fraccionar",
    "fraccionámo": "fraccionar",
    "fraccionámos": "fraccionar",
    "fraccionáramo": "fraccionar",
    "fraccionáramos": "fraccionar",
    "fraccionárei": "fraccionar",
    "fraccionáreis": "fraccionar",
    "fraccionária": "fraccionário",
    "fraccionárias": "fraccionário",
    "fraccionários": "fraccionário",
    "fraccionásseis": "fraccionar",
    "fraccionássemos": "fraccionar",
    "fraccionávamo": "fraccionar",
    "fraccionávamos": "fraccionar",
    "fraccionávei": "fraccionar",
    "fraccionáveis": "fraccionável",
    "fracciúnculas": "fracciúncula",
    "fracos": "fraco",
    "fracota": "fracote",
    "fracotas": "fracote",
    "fracotes": "fracote",
    "fractais": "fractal",
    "fractura": "fracturar",
    "fracturada": "fracturar",
    "fracturadas": "fracturar",
    "fracturado": "fracturar",
    "fracturados": "fracturar",
    "fracturai": "fracturar",
    "fracturais": "fracturar",
    "fracturam": "fracturar",
    "fracturamo": "fracturar",
    "fracturamos": "fracturar",
    "fracturando": "fracturar",
    "fracturara": "fracturar",
    "fracturaram": "fracturar",
    "fracturaras": "fracturar",
    "fracturarde": "fracturar",
    "fracturardes": "fracturar",
    "fracturare": "fracturar",
    "fracturarei": "fracturar",
    "fracturareis": "fracturar",
    "fracturarem": "fracturar",
    "fracturaremos": "fracturar",
    "fracturares": "fracturar",
    "fracturaria": "fracturar",
    "fracturariam": "fracturar",
    "fracturarias": "fracturar",
    "fracturarmo": "fracturar",
    "fracturarmos": "fracturar",
    "fracturará": "fracturar",
    "fracturarás": "fracturar",
    "fracturarão": "fracturar",
    "fracturaríamos": "fracturar",
    "fracturaríeis": "fracturar",
    "fracturas": "fracturar",
    "fracturasse": "fracturar",
    "fracturassem": "fracturar",
    "fracturasses": "fracturar",
    "fracturaste": "fracturar",
    "fracturastes": "fracturar",
    "fracturava": "fracturar",
    "fracturavam": "fracturar",
    "fracturavas": "fracturar",
    "fracture": "fracturar",
    "fracturei": "fracturar",
    "fractureis": "fracturar",
    "fracturem": "fracturar",
    "fracturemo": "fracturar",
    "fracturemos": "fracturar",
    "fractures": "fracturar",
    "fracturo": "fracturar",
    "fracturou": "fracturar",
    "fracturá": "fracturar",
    "fracturámo": "fracturar",
    "fracturámos": "fracturar",
    "fracturáramo": "fracturar",
    "fracturáramos": "fracturar",
    "fracturárei": "fracturar",
    "fracturáreis": "fracturar",
    "fracturásseis": "fracturar",
    "fracturássemos": "fracturar",
    "fracturávamo": "fracturar",
    "fracturávamos": "fracturar",
    "fracturávei": "fracturar",
    "fracturáveis": "fracturar",
    "fracções": "fracção",
    "frada": "fradar",
    "fradada": "fradar",
    "fradadas": "fradar",
    "fradado": "fradar",
    "fradados": "fradar",
    "fradai": "fradar",
    "fradais": "fradar",
    "fradalhadas": "fradalhada",
    "fradalhões": "fradalhão",
    "fradam": "fradar",
    "fradamo": "fradar",
    "fradamos": "fradar",
    "fradando": "fradar",
    "fradara": "fradar",
    "fradaram": "fradar",
    "fradaras": "fradar",
    "fradarde": "fradar",
    "fradardes": "fradar",
    "fradare": "fradar",
    "fradarei": "fradar",
    "fradareis": "fradar",
    "fradarem": "fradar",
    "fradaremos": "fradar",
    "fradares": "fradar",
    "fradaria": "fradar",
    "fradariam": "fradar",
    "fradarias": "fradaria",
    "fradarmo": "fradar",
    "fradarmos": "fradar",
    "fradará": "fradar",
    "fradarás": "fradar",
    "fradarão": "fradar",
    "fradaríamos": "fradar",
    "fradaríeis": "fradar",
    "fradas": "fradar",
    "fradasse": "fradar",
    "fradassem": "fradar",
    "fradasses": "fradar",
    "fradaste": "fradar",
    "fradastes": "fradar",
    "fradava": "fradar",
    "fradavam": "fradar",
    "fradavas": "fradar",
    "frade": "fradar",
    "fradecos": "fradeco",
    "fradei": "fradar",
    "fradeira": "fradeiro",
    "fradeiras": "fradeiro",
    "fradeiros": "fradeiro",
    "fradeis": "fradar",
    "fradem": "fradar",
    "frademo": "fradar",
    "frademos": "fradar",
    "frades": "frade",
    "fradesca": "fradesco",
    "fradescas": "fradesco",
    "fradescos": "fradesco",
    "fradetes": "fradete",
    "fradezecos": "fradezeco",
    "fradices": "fradice",
    "fradicidas": "fradicida",
    "fradinhos": "fradinho",
    "fradiscos": "fradisco",
    "frado": "fradar",
    "fradou": "fradar",
    "fraduna": "fraduno",
    "fradunas": "fraduno",
    "fradunos": "fraduno",
    "fradá": "fradar",
    "fradámo": "fradar",
    "fradámos": "fradar",
    "fradáramo": "fradar",
    "fradáramos": "fradar",
    "fradárei": "fradar",
    "fradáreis": "fradar",
    "fradásseis": "fradar",
    "fradássemos": "fradar",
    "fradávamo": "fradar",
    "fradávamos": "fradar",
    "fradávei": "fradar",
    "fradáveis": "fradar",
    "fradépios": "fradépio",
    "fragais": "fragal",
    "fragalheira": "fragalheiro",
    "fragalheiras": "fragalheiro",
    "fragalheiros": "fragalheiro",
    "fragalhos": "fragalho",
    "fragalhoteada": "fragalhotear",
    "fragalhoteadas": "fragalhotear",
    "fragalhoteado": "fragalhotear",
    "fragalhoteados": "fragalhotear",
    "fragalhoteai": "fragalhotear",
    "fragalhoteais": "fragalhotear",
    "fragalhoteamo": "fragalhotear",
    "fragalhoteamos": "fragalhotear",
    "fragalhoteando": "fragalhotear",
    "fragalhoteara": "fragalhotear",
    "fragalhotearam": "fragalhotear",
    "fragalhotearas": "fragalhotear",
    "fragalhoteardes": "fragalhotear",
    "fragalhotearei": "fragalhotear",
    "fragalhoteareis": "fragalhotear",
    "fragalhotearem": "fragalhotear",
    "fragalhotearemos": "fragalhotear",
    "fragalhoteares": "fragalhotear",
    "fragalhotearia": "fragalhotear",
    "fragalhoteariam": "fragalhotear",
    "fragalhotearias": "fragalhotear",
    "fragalhotearmo": "fragalhotear",
    "fragalhotearmos": "fragalhotear",
    "fragalhoteará": "fragalhotear",
    "fragalhotearás": "fragalhotear",
    "fragalhotearão": "fragalhotear",
    "fragalhotearíamos": "fragalhotear",
    "fragalhotearíeis": "fragalhotear",
    "fragalhoteasse": "fragalhotear",
    "fragalhoteassem": "fragalhotear",
    "fragalhoteasses": "fragalhotear",
    "fragalhoteaste": "fragalhotear",
    "fragalhoteastes": "fragalhotear",
    "fragalhoteava": "fragalhotear",
    "fragalhoteavam": "fragalhotear",
    "fragalhoteavas": "fragalhotear",
    "fragalhoteei": "fragalhotear",
    "fragalhoteeis": "fragalhotear",
    "fragalhoteemo": "fragalhotear",
    "fragalhoteemos": "fragalhotear",
    "fragalhoteia": "fragalhotear",
    "fragalhoteiam": "fragalhotear",
    "fragalhoteias": "fragalhotear",
    "fragalhoteie": "fragalhotear",
    "fragalhoteiem": "fragalhotear",
    "fragalhoteies": "fragalhotear",
    "fragalhoteio": "fragalhotear",
    "fragalhoteou": "fragalhotear",
    "fragalhoteámo": "fragalhotear",
    "fragalhoteámos": "fragalhotear",
    "fragalhoteáramo": "fragalhotear",
    "fragalhoteáramos": "fragalhotear",
    "fragalhoteáreis": "fragalhotear",
    "fragalhoteásseis": "fragalhotear",
    "fragalhoteássemos": "fragalhotear",
    "fragalhoteávamo": "fragalhotear",
    "fragalhoteávamos": "fragalhotear",
    "fragalhoteáveis": "fragalhotear",
    "fragaredos": "fragaredo",
    "fragas": "fraga",
    "fragatas": "fragata",
    "fragateada": "fragatear",
    "fragateadas": "fragatear",
    "fragateado": "fragatear",
    "fragateados": "fragatear",
    "fragateai": "fragatear",
    "fragateais": "fragatear",
    "fragateamo": "fragatear",
    "fragateamos": "fragatear",
    "fragateando": "fragatear",
    "fragateara": "fragatear",
    "fragatearam": "fragatear",
    "fragatearas": "fragatear",
    "fragateardes": "fragatear",
    "fragatearei": "fragatear",
    "fragateareis": "fragatear",
    "fragatearem": "fragatear",
    "fragatearemos": "fragatear",
    "fragateares": "fragatear",
    "fragatearia": "fragatear",
    "fragateariam": "fragatear",
    "fragatearias": "fragatear",
    "fragatearmo": "fragatear",
    "fragatearmos": "fragatear",
    "fragateará": "fragatear",
    "fragatearás": "fragatear",
    "fragatearão": "fragatear",
    "fragatearíamos": "fragatear",
    "fragatearíeis": "fragatear",
    "fragateasse": "fragatear",
    "fragateassem": "fragatear",
    "fragateasses": "fragatear",
    "fragateaste": "fragatear",
    "fragateastes": "fragatear",
    "fragateava": "fragatear",
    "fragateavam": "fragatear",
    "fragateavas": "fragatear",
    "fragateei": "fragatear",
    "fragateeis": "fragatear",
    "fragateemo": "fragatear",
    "fragateemos": "fragatear",
    "fragateia": "fragatear",
    "fragateiam": "fragatear",
    "fragateias": "fragatear",
    "fragateie": "fragatear",
    "fragateiem": "fragatear",
    "fragateies": "fragatear",
    "fragateio": "fragatear",
    "fragateira": "fragateiro",
    "fragateiras": "fragateiro",
    "fragateiros": "fragateiro",
    "fragateou": "fragatear",
    "fragateámo": "fragatear",
    "fragateámos": "fragatear",
    "fragateáramo": "fragatear",
    "fragateáramos": "fragatear",
    "fragateáreis": "fragatear",
    "fragateásseis": "fragatear",
    "fragateássemos": "fragatear",
    "fragateávamo": "fragatear",
    "fragateávamos": "fragatear",
    "fragateáveis": "fragatear",
    "fragatins": "fragatim",
    "fragiformes": "fragiforme",
    "fragilidades": "fragilidade",
    "fragiliza": "fragilizar",
    "fragilizada": "fragilizar",
    "fragilizadas": "fragilizar",
    "fragilizado": "fragilizar",
    "fragilizados": "fragilizar",
    "fragilizai": "fragilizar",
    "fragilizais": "fragilizar",
    "fragilizam": "fragilizar",
    "fragilizamo": "fragilizar",
    "fragilizamos": "fragilizar",
    "fragilizando": "fragilizar",
    "fragilizara": "fragilizar",
    "fragilizaram": "fragilizar",
    "fragilizaras": "fragilizar",
    "fragilizarde": "fragilizar",
    "fragilizardes": "fragilizar",
    "fragilizare": "fragilizar",
    "fragilizarei": "fragilizar",
    "fragilizareis": "fragilizar",
    "fragilizarem": "fragilizar",
    "fragilizaremos": "fragilizar",
    "fragilizares": "fragilizar",
    "fragilizaria": "fragilizar",
    "fragilizariam": "fragilizar",
    "fragilizarias": "fragilizar",
    "fragilizarmo": "fragilizar",
    "fragilizarmos": "fragilizar",
    "fragilizará": "fragilizar",
    "fragilizarás": "fragilizar",
    "fragilizarão": "fragilizar",
    "fragilizaríamos": "fragilizar",
    "fragilizaríeis": "fragilizar",
    "fragilizas": "fragilizar",
    "fragilizasse": "fragilizar",
    "fragilizassem": "fragilizar",
    "fragilizasses": "fragilizar",
    "fragilizaste": "fragilizar",
    "fragilizastes": "fragilizar",
    "fragilizava": "fragilizar",
    "fragilizavam": "fragilizar",
    "fragilizavas": "fragilizar",
    "fragilizações": "fragilização",
    "fragilize": "fragilizar",
    "fragilizei": "fragilizar",
    "fragilizeis": "fragilizar",
    "fragilizem": "fragilizar",
    "fragilizemo": "fragilizar",
    "fragilizemos": "fragilizar",
    "fragilizes": "fragilizar",
    "fragilizo": "fragilizar",
    "fragilizou": "fragilizar",
    "fragilizá": "fragilizar",
    "fragilizámo": "fragilizar",
    "fragilizámos": "fragilizar",
    "fragilizáramo": "fragilizar",
    "fragilizáramos": "fragilizar",
    "fragilizárei": "fragilizar",
    "fragilizáreis": "fragilizar",
    "fragilizásseis": "fragilizar",
    "fragilizássemos": "fragilizar",
    "fragilizávamo": "fragilizar",
    "fragilizávamos": "fragilizar",
    "fragilizávei": "fragilizar",
    "fragilizáveis": "fragilizável",
    "fragilíssima": "frágil",
    "fragilíssimas": "frágil",
    "fragilíssimo": "frágil",
    "fragilíssimos": "frágil",
    "fragmenta": "fragmentar",
    "fragmentada": "fragmentar",
    "fragmentadas": "fragmentar",
    "fragmentado": "fragmentar",
    "fragmentados": "fragmentar",
    "fragmentai": "fragmentar",
    "fragmentais": "fragmentar",
    "fragmentam": "fragmentar",
    "fragmentamo": "fragmentar",
    "fragmentamos": "fragmentar",
    "fragmentando": "fragmentar",
    "fragmentara": "fragmentar",
    "fragmentaram": "fragmentar",
    "fragmentaras": "fragmentar",
    "fragmentarde": "fragmentar",
    "fragmentardes": "fragmentar",
    "fragmentare": "fragmentar",
    "fragmentarei": "fragmentar",
    "fragmentareis": "fragmentar",
    "fragmentarem": "fragmentar",
    "fragmentaremos": "fragmentar",
    "fragmentares": "fragmentar",
    "fragmentaria": "fragmentar",
    "fragmentariam": "fragmentar",
    "fragmentarias": "fragmentar",
    "fragmentarmo": "fragmentar",
    "fragmentarmos": "fragmentar",
    "fragmentará": "fragmentar",
    "fragmentarás": "fragmentar",
    "fragmentarão": "fragmentar",
    "fragmentaríamos": "fragmentar",
    "fragmentaríeis": "fragmentar",
    "fragmentas": "fragmentar",
    "fragmentasse": "fragmentar",
    "fragmentassem": "fragmentar",
    "fragmentasses": "fragmentar",
    "fragmentaste": "fragmentar",
    "fragmentastes": "fragmentar",
    "fragmentava": "fragmentar",
    "fragmentavam": "fragmentar",
    "fragmentavas": "fragmentar",
    "fragmentações": "fragmentação",
    "fragmente": "fragmentar",
    "fragmentei": "fragmentar",
    "fragmenteis": "fragmentar",
    "fragmentem": "fragmentar",
    "fragmentemo": "fragmentar",
    "fragmentemos": "fragmentar",
    "fragmentes": "fragmentar",
    "fragmentistas": "fragmentista",
    "fragmento": "fragmentar",
    "fragmentos": "fragmento",
    "fragmentou": "fragmentar",
    "fragmentá": "fragmentar",
    "fragmentámo": "fragmentar",
    "fragmentámos": "fragmentar",
    "fragmentáramo": "fragmentar",
    "fragmentáramos": "fragmentar",
    "fragmentárei": "fragmentar",
    "fragmentáreis": "fragmentar",
    "fragmentária": "fragmentário",
    "fragmentárias": "fragmentário",
    "fragmentários": "fragmentário",
    "fragmentásseis": "fragmentar",
    "fragmentássemos": "fragmentar",
    "fragmentávamo": "fragmentar",
    "fragmentávamos": "fragmentar",
    "fragmentávei": "fragmentar",
    "fragmentáveis": "fragmentável",
    "fragora": "fragorar",
    "fragorada": "fragorar",
    "fragoradas": "fragorar",
    "fragorado": "fragorar",
    "fragorados": "fragorar",
    "fragorai": "fragorar",
    "fragorais": "fragorar",
    "fragoram": "fragorar",
    "fragoramo": "fragorar",
    "fragoramos": "fragorar",
    "fragorando": "fragorar",
    "fragorara": "fragorar",
    "fragoraram": "fragorar",
    "fragoraras": "fragorar",
    "fragorardes": "fragorar",
    "fragorarei": "fragorar",
    "fragorareis": "fragorar",
    "fragorarem": "fragorar",
    "fragoraremos": "fragorar",
    "fragorares": "fragorar",
    "fragoraria": "fragorar",
    "fragorariam": "fragorar",
    "fragorarias": "fragorar",
    "fragorarmo": "fragorar",
    "fragorarmos": "fragorar",
    "fragorará": "fragorar",
    "fragorarás": "fragorar",
    "fragorarão": "fragorar",
    "fragoraríamos": "fragorar",
    "fragoraríeis": "fragorar",
    "fragoras": "fragorar",
    "fragorasse": "fragorar",
    "fragorassem": "fragorar",
    "fragorasses": "fragorar",
    "fragoraste": "fragorar",
    "fragorastes": "fragorar",
    "fragorava": "fragorar",
    "fragoravam": "fragorar",
    "fragoravas": "fragorar",
    "fragore": "fragorar",
    "fragorei": "fragorar",
    "fragoreis": "fragorar",
    "fragorem": "fragorar",
    "fragoremo": "fragorar",
    "fragoremos": "fragorar",
    "fragores": "fragorar",
    "fragoro": "fragorar",
    "fragorou": "fragorar",
    "fragorámo": "fragorar",
    "fragorámos": "fragorar",
    "fragoráramo": "fragorar",
    "fragoráramos": "fragorar",
    "fragoráreis": "fragorar",
    "fragorásseis": "fragorar",
    "fragorássemos": "fragorar",
    "fragorávamo": "fragorar",
    "fragorávamos": "fragorar",
    "fragoráveis": "fragorar",
    "fragos": "frago",
    "fragosa": "fragoso",
    "fragosas": "fragoso",
    "fragosidades": "fragosidade",
    "fragosos": "fragoso",
    "fragosões": "fragosão",
    "fragrantes": "fragrante",
    "fragrâncias": "fragrância",
    "fragua": "fraguar",
    "fraguada": "fraguar",
    "fraguadas": "fraguar",
    "fraguado": "fraguar",
    "fraguados": "fraguar",
    "fraguai": "fraguar",
    "fraguais": "fraguar",
    "fraguam": "fraguar",
    "fraguamo": "fraguar",
    "fraguamos": "fraguar",
    "fraguando": "fraguar",
    "fraguara": "fraguar",
    "fraguaram": "fraguar",
    "fraguaras": "fraguar",
    "fraguarde": "fraguar",
    "fraguardes": "fraguar",
    "fraguare": "fraguar",
    "fraguarei": "fraguar",
    "fraguareis": "fraguar",
    "fraguarem": "fraguar",
    "fraguaremos": "fraguar",
    "fraguares": "fraguar",
    "fraguaria": "fraguar",
    "fraguariam": "fraguar",
    "fraguarias": "fraguar",
    "fraguarmo": "fraguar",
    "fraguarmos": "fraguar",
    "fraguará": "fraguar",
    "fraguarás": "fraguar",
    "fraguarão": "fraguar",
    "fraguaríamos": "fraguar",
    "fraguaríeis": "fraguar",
    "fraguas": "fraguar",
    "fraguasse": "fraguar",
    "fraguassem": "fraguar",
    "fraguasses": "fraguar",
    "fraguaste": "fraguar",
    "fraguastes": "fraguar",
    "fraguava": "fraguar",
    "fraguavam": "fraguar",
    "fraguavas": "fraguar",
    "fragueada": "fraguear",
    "fragueadas": "fraguear",
    "fragueado": "fraguear",
    "fragueados": "fraguear",
    "fragueai": "fraguear",
    "fragueais": "fraguear",
    "fragueamo": "fraguear",
    "fragueamos": "fraguear",
    "fragueando": "fraguear",
    "fragueara": "fraguear",
    "fraguearam": "fraguear",
    "fraguearas": "fraguear",
    "fragueardes": "fraguear",
    "fraguearei": "fraguear",
    "fragueareis": "fraguear",
    "fraguearem": "fraguear",
    "fraguearemos": "fraguear",
    "fragueares": "fraguear",
    "fraguearia": "fraguear",
    "fragueariam": "fraguear",
    "fraguearias": "fraguear",
    "fraguearmo": "fraguear",
    "fraguearmos": "fraguear",
    "fragueará": "fraguear",
    "fraguearás": "fraguear",
    "fraguearão": "fraguear",
    "fraguearíamos": "fraguear",
    "fraguearíeis": "fraguear",
    "fragueasse": "fraguear",
    "fragueassem": "fraguear",
    "fragueasses": "fraguear",
    "fragueaste": "fraguear",
    "fragueastes": "fraguear",
    "fragueava": "fraguear",
    "fragueavam": "fraguear",
    "fragueavas": "fraguear",
    "fraguedos": "fraguedo",
    "fragueei": "fraguear",
    "fragueeis": "fraguear",
    "fragueemo": "fraguear",
    "fragueemos": "fraguear",
    "fraguei": "fraguar",
    "fragueia": "fraguear",
    "fragueiam": "fraguear",
    "fragueias": "fraguear",
    "fragueie": "fraguear",
    "fragueiem": "fraguear",
    "fragueies": "fraguear",
    "fragueio": "fraguear",
    "fragueira": "fragueiro",
    "fragueiras": "fragueiro",
    "fragueirices": "fragueirice",
    "fragueiros": "fragueiro",
    "fragueis": "fraguar",
    "fraguemo": "fraguar",
    "fraguemos": "fraguar",
    "fragueou": "fraguear",
    "fragues": "fraguar",
    "fragueámo": "fraguear",
    "fragueámos": "fraguear",
    "fragueáramo": "fraguear",
    "fragueáramos": "fraguear",
    "fragueáreis": "fraguear",
    "fragueásseis": "fraguear",
    "fragueássemos": "fraguear",
    "fragueávamo": "fraguear",
    "fragueávamos": "fraguear",
    "fragueáveis": "fraguear",
    "fragulhos": "fragulho",
    "fraguo": "fraguar",
    "fraguou": "fraguar",
    "fraguras": "fragura",
    "fragurosa": "fraguroso",
    "fragurosas": "fraguroso",
    "fragurosos": "fraguroso",
    "fraguá": "fraguar",
    "fraguámo": "fraguar",
    "fraguámos": "fraguar",
    "fraguáramo": "fraguar",
    "fraguáramos": "fraguar",
    "fraguárei": "fraguar",
    "fraguáreis": "fraguar",
    "fraguásseis": "fraguar",
    "fraguássemos": "fraguar",
    "fraguávamo": "fraguar",
    "fraguávamos": "fraguar",
    "fraguávei": "fraguar",
    "fraguáveis": "fraguar",
    "fragárias": "fragária",
    "fragâncias": "fragância",
    "fragífera": "fragífero",
    "fragíferas": "fragífero",
    "fragíferos": "fragífero",
    "fragões": "fragão",
    "fragúe": "fraguar",
    "fragúem": "fraguar",
    "fragúes": "fraguar",
    "fralda": "fraldar",
    "fraldada": "fraldar",
    "fraldadas": "fraldar",
    "fraldado": "fraldar",
    "fraldados": "fraldar",
    "fraldai": "fraldar",
    "fraldais": "fraldar",
    "fraldam": "fraldar",
    "fraldamo": "fraldar",
    "fraldamos": "fraldar",
    "fraldando": "fraldar",
    "fraldara": "fraldar",
    "fraldaram": "fraldar",
    "fraldaras": "fraldar",
    "fraldarde": "fraldar",
    "fraldardes": "fraldar",
    "fraldare": "fraldar",
    "fraldarei": "fraldar",
    "fraldareis": "fraldar",
    "fraldarem": "fraldar",
    "fraldaremos": "fraldar",
    "fraldares": "fraldar",
    "fraldaria": "fraldar",
    "fraldariam": "fraldar",
    "fraldarias": "fraldar",
    "fraldarmo": "fraldar",
    "fraldarmos": "fraldar",
    "fraldará": "fraldar",
    "fraldarás": "fraldar",
    "fraldarão": "fraldar",
    "fraldaríamos": "fraldar",
    "fraldaríeis": "fraldar",
    "fraldas": "fraldar",
    "fraldasse": "fraldar",
    "fraldassem": "fraldar",
    "fraldasses": "fraldar",
    "fraldaste": "fraldar",
    "fraldastes": "fraldar",
    "fraldava": "fraldar",
    "fraldavam": "fraldar",
    "fraldavas": "fraldar",
    "fralde": "fraldar",
    "fraldeada": "fraldear",
    "fraldeadas": "fraldear",
    "fraldeado": "fraldear",
    "fraldeados": "fraldear",
    "fraldeai": "fraldear",
    "fraldeais": "fraldear",
    "fraldeamo": "fraldear",
    "fraldeamos": "fraldear",
    "fraldeando": "fraldear",
    "fraldeara": "fraldear",
    "fraldearam": "fraldear",
    "fraldearas": "fraldear",
    "fraldearde": "fraldear",
    "fraldeardes": "fraldear",
    "fraldeare": "fraldear",
    "fraldearei": "fraldear",
    "fraldeareis": "fraldear",
    "fraldearem": "fraldear",
    "fraldearemos": "fraldear",
    "fraldeares": "fraldear",
    "fraldearia": "fraldear",
    "fraldeariam": "fraldear",
    "fraldearias": "fraldear",
    "fraldearmo": "fraldear",
    "fraldearmos": "fraldear",
    "fraldeará": "fraldear",
    "fraldearás": "fraldear",
    "fraldearão": "fraldear",
    "fraldearíamos": "fraldear",
    "fraldearíeis": "fraldear",
    "fraldeasse": "fraldear",
    "fraldeassem": "fraldear",
    "fraldeasses": "fraldear",
    "fraldeaste": "fraldear",
    "fraldeastes": "fraldear",
    "fraldeava": "fraldear",
    "fraldeavam": "fraldear",
    "fraldeavas": "fraldear",
    "fraldeei": "fraldear",
    "fraldeeis": "fraldear",
    "fraldeemo": "fraldear",
    "fraldeemos": "fraldear",
    "fraldei": "fraldar",
    "fraldeia": "fraldear",
    "fraldeiam": "fraldear",
    "fraldeias": "fraldear",
    "fraldeie": "fraldear",
    "fraldeiem": "fraldear",
    "fraldeies": "fraldear",
    "fraldeio": "fraldear",
    "fraldeiros": "fraldeiro",
    "fraldeis": "fraldar",
    "fraldeja": "fraldejar",
    "fraldejada": "fraldejar",
    "fraldejadas": "fraldejar",
    "fraldejado": "fraldejar",
    "fraldejados": "fraldejar",
    "fraldejai": "fraldejar",
    "fraldejais": "fraldejar",
    "fraldejam": "fraldejar",
    "fraldejamo": "fraldejar",
    "fraldejamos": "fraldejar",
    "fraldejando": "fraldejar",
    "fraldejara": "fraldejar",
    "fraldejaram": "fraldejar",
    "fraldejaras": "fraldejar",
    "fraldejardes": "fraldejar",
    "fraldejarei": "fraldejar",
    "fraldejareis": "fraldejar",
    "fraldejarem": "fraldejar",
    "fraldejaremos": "fraldejar",
    "fraldejares": "fraldejar",
    "fraldejaria": "fraldejar",
    "fraldejariam": "fraldejar",
    "fraldejarias": "fraldejar",
    "fraldejarmo": "fraldejar",
    "fraldejarmos": "fraldejar",
    "fraldejará": "fraldejar",
    "fraldejarás": "fraldejar",
    "fraldejarão": "fraldejar",
    "fraldejaríamos": "fraldejar",
    "fraldejaríeis": "fraldejar",
    "fraldejas": "fraldejar",
    "fraldejasse": "fraldejar",
    "fraldejassem": "fraldejar",
    "fraldejasses": "fraldejar",
    "fraldejaste": "fraldejar",
    "fraldejastes": "fraldejar",
    "fraldejava": "fraldejar",
    "fraldejavam": "fraldejar",
    "fraldejavas": "fraldejar",
    "fraldeje": "fraldejar",
    "fraldejei": "fraldejar",
    "fraldejeis": "fraldejar",
    "fraldejem": "fraldejar",
    "fraldejemo": "fraldejar",
    "fraldejemos": "fraldejar",
    "fraldejes": "fraldejar",
    "fraldejo": "fraldejar",
    "fraldejou": "fraldejar",
    "fraldejámo": "fraldejar",
    "fraldejámos": "fraldejar",
    "fraldejáramo": "fraldejar",
    "fraldejáramos": "fraldejar",
    "fraldejáreis": "fraldejar",
    "fraldejásseis": "fraldejar",
    "fraldejássemos": "fraldejar",
    "fraldejávamo": "fraldejar",
    "fraldejávamos": "fraldejar",
    "fraldejáveis": "fraldejar",
    "fraldelins": "fraldelim",
    "fraldem": "fraldar",
    "fraldemo": "fraldar",
    "fraldemos": "fraldar",
    "fraldeou": "fraldear",
    "fraldes": "fraldar",
    "fraldeá": "fraldear",
    "fraldeámo": "fraldear",
    "fraldeámos": "fraldear",
    "fraldeáramo": "fraldear",
    "fraldeáramos": "fraldear",
    "fraldeárei": "fraldear",
    "fraldeáreis": "fraldear",
    "fraldeásseis": "fraldear",
    "fraldeássemos": "fraldear",
    "fraldeávamo": "fraldear",
    "fraldeávamos": "fraldear",
    "fraldeávei": "fraldear",
    "fraldeáveis": "fraldear",
    "fraldilhas": "fraldilha",
    "fraldinha": "fralda",
    "fraldinhas": "fralda",
    "fraldiqueiras": "fraldiqueira",
    "fraldisqueiros": "fraldisqueiro",
    "fraldita": "fralda",
    "fralditas": "fralda",
    "fraldo": "fraldar",
    "fraldou": "fraldar",
    "fraldá": "fraldar",
    "fraldámo": "fraldar",
    "fraldámos": "fraldar",
    "fraldáramo": "fraldar",
    "fraldáramos": "fraldar",
    "fraldárei": "fraldar",
    "fraldáreis": "fraldar",
    "fraldásseis": "fraldar",
    "fraldássemos": "fraldar",
    "fraldávamo": "fraldar",
    "fraldávamos": "fraldar",
    "fraldávei": "fraldar",
    "fraldáveis": "fraldar",
    "fraldões": "fraldão",
    "framboesas": "framboesa",
    "framboeseiras": "framboeseira",
    "framboeseiros": "framboeseiro",
    "franca": "franco",
    "francaletes": "francalete",
    "francas": "franco",
    "franceada": "francear",
    "franceadas": "francear",
    "franceado": "francear",
    "franceados": "francear",
    "franceai": "francear",
    "franceais": "francear",
    "franceamo": "francear",
    "franceamos": "francear",
    "franceando": "francear",
    "franceara": "francear",
    "francearam": "francear",
    "francearas": "francear",
    "francearde": "francear",
    "franceardes": "francear",
    "franceare": "francear",
    "francearei": "francear",
    "franceareis": "francear",
    "francearem": "francear",
    "francearemos": "francear",
    "franceares": "francear",
    "francearia": "francear",
    "franceariam": "francear",
    "francearias": "francear",
    "francearmo": "francear",
    "francearmos": "francear",
    "franceará": "francear",
    "francearás": "francear",
    "francearão": "francear",
    "francearíamos": "francear",
    "francearíeis": "francear",
    "franceasse": "francear",
    "franceassem": "francear",
    "franceasses": "francear",
    "franceaste": "francear",
    "franceastes": "francear",
    "franceava": "francear",
    "franceavam": "francear",
    "franceavas": "francear",
    "franceei": "francear",
    "franceeis": "francear",
    "franceemo": "francear",
    "franceemos": "francear",
    "franceia": "francear",
    "franceiam": "francear",
    "franceias": "francear",
    "franceie": "francear",
    "franceiem": "francear",
    "franceies": "francear",
    "franceio": "francear",
    "francelas": "francela",
    "francelhos": "francelho",
    "francelhota": "francelhote",
    "francelhotas": "francelhote",
    "francelhotes": "francelhote",
    "franceou": "francear",
    "francesa": "francês",
    "francesas": "francês",
    "franceses": "francês",
    "francesia": "francesiar",
    "francesiada": "francesiar",
    "francesiadas": "francesiar",
    "francesiado": "francesiar",
    "francesiados": "francesiar",
    "francesiai": "francesiar",
    "francesiais": "francesiar",
    "francesiam": "francesiar",
    "francesiamo": "francesiar",
    "francesiamos": "francesiar",
    "francesiando": "francesiar",
    "francesiara": "francesiar",
    "francesiaram": "francesiar",
    "francesiaras": "francesiar",
    "francesiardes": "francesiar",
    "francesiarei": "francesiar",
    "francesiareis": "francesiar",
    "francesiarem": "francesiar",
    "francesiaremos": "francesiar",
    "francesiares": "francesiar",
    "francesiaria": "francesiar",
    "francesiariam": "francesiar",
    "francesiarias": "francesiar",
    "francesiarmo": "francesiar",
    "francesiarmos": "francesiar",
    "francesiará": "francesiar",
    "francesiarás": "francesiar",
    "francesiarão": "francesiar",
    "francesiaríamos": "francesiar",
    "francesiaríeis": "francesiar",
    "francesias": "francesiar",
    "francesiasse": "francesiar",
    "francesiassem": "francesiar",
    "francesiasses": "francesiar",
    "francesiaste": "francesiar",
    "francesiastes": "francesiar",
    "francesiava": "francesiar",
    "francesiavam": "francesiar",
    "francesiavas": "francesiar",
    "francesices": "francesice",
    "francesie": "francesiar",
    "francesiei": "francesiar",
    "francesieis": "francesiar",
    "francesiem": "francesiar",
    "francesiemo": "francesiar",
    "francesiemos": "francesiar",
    "francesies": "francesiar",
    "francesio": "francesiar",
    "francesiou": "francesiar",
    "francesismos": "francesismo",
    "francesistas": "francesista",
    "francesiámo": "francesiar",
    "francesiámos": "francesiar",
    "francesiáramo": "francesiar",
    "francesiáramos": "francesiar",
    "francesiáreis": "francesiar",
    "francesiásseis": "francesiar",
    "francesiássemos": "francesiar",
    "francesiávamo": "francesiar",
    "francesiávamos": "francesiar",
    "francesiáveis": "francesiar",
    "franceá": "francear",
    "franceámo": "francear",
    "franceámos": "francear",
    "franceáramo": "francear",
    "franceáramos": "francear",
    "franceárei": "francear",
    "franceáreis": "francear",
    "franceásseis": "francear",
    "franceássemos": "francear",
    "franceávamo": "francear",
    "franceávamos": "francear",
    "franceávei": "francear",
    "franceáveis": "francear",
    "franchada": "franchado",
    "franchadas": "franchado",
    "franchados": "franchado",
    "franchinota": "franchinote",
    "franchinotas": "franchinote",
    "franchinotes": "franchinote",
    "franchinótica": "franchinótico",
    "franchinóticas": "franchinótico",
    "franchinóticos": "franchinótico",
    "franchisada": "franchisado",
    "franchisadas": "franchisado",
    "franchisadora": "franchisador",
    "franchisadoras": "franchisador",
    "franchisadores": "franchisador",
    "franchisados": "franchisado",
    "franchisings": "franchising",
    "francisca": "francisco",
    "franciscana": "franciscano",
    "franciscanadas": "franciscanada",
    "franciscanas": "franciscano",
    "franciscanos": "franciscano",
    "franciscas": "francisco",
    "franciscos": "francisco",
    "francismos": "francismo",
    "francofilias": "francofilia",
    "francofobias": "francofobia",
    "francofonias": "francofonia",
    "francofóbica": "francofóbico",
    "francofóbicas": "francofóbico",
    "francofóbicos": "francofóbico",
    "francos": "franco",
    "francófila": "francófilo",
    "francófilas": "francófilo",
    "francófilos": "francófilo",
    "francófoba": "francófobo",
    "francófobas": "francófobo",
    "francófobos": "francófobo",
    "francófona": "francófono",
    "francófonas": "francófono",
    "francófonos": "francófono",
    "franduleira": "franduleiro",
    "franduleiras": "franduleiro",
    "franduleiros": "franduleiro",
    "franga": "frango",
    "frangainha": "frangainho",
    "frangainhas": "frangainho",
    "frangainhos": "frangainho",
    "frangalha": "frangalhar",
    "frangalhada": "frangalhar",
    "frangalhadas": "frangalhar",
    "frangalhado": "frangalhar",
    "frangalhados": "frangalhar",
    "frangalhai": "frangalhar",
    "frangalhais": "frangalhar",
    "frangalham": "frangalhar",
    "frangalhamo": "frangalhar",
    "frangalhamos": "frangalhar",
    "frangalhando": "frangalhar",
    "frangalhara": "frangalhar",
    "frangalharam": "frangalhar",
    "frangalharas": "frangalhar",
    "frangalharde": "frangalhar",
    "frangalhardes": "frangalhar",
    "frangalhare": "frangalhar",
    "frangalharei": "frangalhar",
    "frangalhareis": "frangalhar",
    "frangalharem": "frangalhar",
    "frangalharemos": "frangalhar",
    "frangalhares": "frangalhar",
    "frangalharia": "frangalhar",
    "frangalhariam": "frangalhar",
    "frangalharias": "frangalhar",
    "frangalharmo": "frangalhar",
    "frangalharmos": "frangalhar",
    "frangalhará": "frangalhar",
    "frangalharás": "frangalhar",
    "frangalharão": "frangalhar",
    "frangalharíamos": "frangalhar",
    "frangalharíeis": "frangalhar",
    "frangalhas": "frangalhar",
    "frangalhasse": "frangalhar",
    "frangalhassem": "frangalhar",
    "frangalhasses": "frangalhar",
    "frangalhaste": "frangalhar",
    "frangalhastes": "frangalhar",
    "frangalhava": "frangalhar",
    "frangalhavam": "frangalhar",
    "frangalhavas": "frangalhar",
    "frangalhe": "frangalhar",
    "frangalhei": "frangalhar",
    "frangalheira": "frangalheiro",
    "frangalheiras": "frangalheiro",
    "frangalheiros": "frangalheiro",
    "frangalheis": "frangalhar",
    "frangalhem": "frangalhar",
    "frangalhemo": "frangalhar",
    "frangalhemos": "frangalhar",
    "frangalhes": "frangalhar",
    "frangalho": "frangalhar",
    "frangalhonas": "frangalhona",
    "frangalhos": "frangalho",
    "frangalhota": "frangalhote",
    "frangalhotas": "frangalhote",
    "frangalhoteada": "frangalhotear",
    "frangalhoteadas": "frangalhotear",
    "frangalhoteado": "frangalhotear",
    "frangalhoteados": "frangalhotear",
    "frangalhoteai": "frangalhotear",
    "frangalhoteais": "frangalhotear",
    "frangalhoteamo": "frangalhotear",
    "frangalhoteamos": "frangalhotear",
    "frangalhoteando": "frangalhotear",
    "frangalhoteara": "frangalhotear",
    "frangalhotearam": "frangalhotear",
    "frangalhotearas": "frangalhotear",
    "frangalhoteardes": "frangalhotear",
    "frangalhotearei": "frangalhotear",
    "frangalhoteareis": "frangalhotear",
    "frangalhotearem": "frangalhotear",
    "frangalhotearemos": "frangalhotear",
    "frangalhoteares": "frangalhotear",
    "frangalhotearia": "frangalhotear",
    "frangalhoteariam": "frangalhotear",
    "frangalhotearias": "frangalhotear",
    "frangalhotearmo": "frangalhotear",
    "frangalhotearmos": "frangalhotear",
    "frangalhoteará": "frangalhotear",
    "frangalhotearás": "frangalhotear",
    "frangalhotearão": "frangalhotear",
    "frangalhotearíamos": "frangalhotear",
    "frangalhotearíeis": "frangalhotear",
    "frangalhoteasse": "frangalhotear",
    "frangalhoteassem": "frangalhotear",
    "frangalhoteasses": "frangalhotear",
    "frangalhoteaste": "frangalhotear",
    "frangalhoteastes": "frangalhotear",
    "frangalhoteava": "frangalhotear",
    "frangalhoteavam": "frangalhotear",
    "frangalhoteavas": "frangalhotear",
    "frangalhoteei": "frangalhotear",
    "frangalhoteeis": "frangalhotear",
    "frangalhoteemo": "frangalhotear",
    "frangalhoteemos": "frangalhotear",
    "frangalhoteia": "frangalhotear",
    "frangalhoteiam": "frangalhotear",
    "frangalhoteias": "frangalhotear",
    "frangalhoteie": "frangalhotear",
    "frangalhoteiem": "frangalhotear",
    "frangalhoteies": "frangalhotear",
    "frangalhoteio": "frangalhotear",
    "frangalhoteou": "frangalhotear",
    "frangalhotes": "frangalhote",
    "frangalhoteámo": "frangalhotear",
    "frangalhoteámos": "frangalhotear",
    "frangalhoteáramo": "frangalhotear",
    "frangalhoteáramos": "frangalhotear",
    "frangalhoteáreis": "frangalhotear",
    "frangalhoteásseis": "frangalhotear",
    "frangalhoteássemos": "frangalhotear",
    "frangalhoteávamo": "frangalhotear",
    "frangalhoteávamos": "frangalhotear",
    "frangalhoteáveis": "frangalhotear",
    "frangalhou": "frangalhar",
    "frangalhá": "frangalhar",
    "frangalhámo": "frangalhar",
    "frangalhámos": "frangalhar",
    "frangalháramo": "frangalhar",
    "frangalháramos": "frangalhar",
    "frangalhárei": "frangalhar",
    "frangalháreis": "frangalhar",
    "frangalhásseis": "frangalhar",
    "frangalhássemos": "frangalhar",
    "frangalhávamo": "frangalhar",
    "frangalhávamos": "frangalhar",
    "frangalhávei": "frangalhar",
    "frangalháveis": "frangalhar",
    "franganadas": "franganada",
    "franganita": "franganito",
    "franganitas": "franganito",
    "franganitos": "franganito",
    "franganota": "franganote",
    "franganotas": "franganote",
    "franganotes": "franganote",
    "frangas": "frango",
    "frangazinha": "frango",
    "frangazinhas": "frango",
    "frangazita": "frango",
    "frangazitas": "frango",
    "frange": "frangir",
    "frangei": "franger",
    "frangeis": "franger",
    "frangelhas": "frangelha",
    "frangem": "frangir",
    "frangemo": "franger",
    "frangemos": "franger",
    "frangendo": "franger",
    "frangera": "franger",
    "frangeram": "franger",
    "frangeras": "franger",
    "frangerde": "franger",
    "frangerdes": "franger",
    "frangere": "franger",
    "frangerei": "franger",
    "frangereis": "franger",
    "frangerem": "franger",
    "frangeremos": "franger",
    "frangeres": "franger",
    "frangeria": "franger",
    "frangeriam": "franger",
    "frangerias": "franger",
    "frangermo": "franger",
    "frangermos": "franger",
    "frangerá": "franger",
    "frangerás": "franger",
    "frangerão": "franger",
    "frangeríamos": "franger",
    "frangeríeis": "franger",
    "franges": "frangir",
    "frangesse": "franger",
    "frangessem": "franger",
    "frangesses": "franger",
    "frangeste": "franger",
    "frangestes": "franger",
    "frangeu": "franger",
    "frangi": "frangir",
    "frangia": "frangir",
    "frangiam": "frangir",
    "frangias": "frangir",
    "frangibilidades": "frangibilidade",
    "frangida": "frangir",
    "frangidas": "frangir",
    "frangido": "frangir",
    "frangidos": "frangir",
    "frangimo": "frangir",
    "frangimos": "frangir",
    "frangindo": "frangir",
    "frangipana": "frangipano",
    "frangipanas": "frangipano",
    "frangipanos": "frangipano",
    "frangira": "frangir",
    "frangiram": "frangir",
    "frangiras": "frangir",
    "frangirde": "frangir",
    "frangirdes": "frangir",
    "frangire": "frangir",
    "frangirei": "frangir",
    "frangireis": "frangir",
    "frangirem": "frangir",
    "frangiremos": "frangir",
    "frangires": "frangir",
    "frangiria": "frangir",
    "frangiriam": "frangir",
    "frangirias": "frangir",
    "frangirmo": "frangir",
    "frangirmos": "frangir",
    "frangirá": "frangir",
    "frangirás": "frangir",
    "frangirão": "frangir",
    "frangiríamos": "frangir",
    "frangiríeis": "frangir",
    "frangis": "frangir",
    "frangisse": "frangir",
    "frangissem": "frangir",
    "frangisses": "frangir",
    "frangiste": "frangir",
    "frangistes": "frangir",
    "frangiu": "frangir",
    "frangolhos": "frangolho",
    "frangos": "frango",
    "frangota": "frangote",
    "frangotas": "frangote",
    "frangotes": "frangote",
    "frangozinho": "frango",
    "frangozinhos": "frango",
    "frangozito": "frango",
    "frangozitos": "frango",
    "frangueta": "franguete",
    "franguetas": "franguete",
    "franguetes": "franguete",
    "franguinha": "frango",
    "franguinhas": "frango",
    "franguinho": "frango",
    "franguinhos": "frango",
    "franguita": "frango",
    "franguitas": "frango",
    "franguito": "frango",
    "franguitos": "frango",
    "frangulinas": "frangulina",
    "frangulínica": "frangulínico",
    "frangulínicas": "frangulínico",
    "frangulínicos": "frangulínico",
    "frangê": "franger",
    "frangêramo": "franger",
    "frangêramos": "franger",
    "frangêrei": "franger",
    "frangêreis": "franger",
    "frangêsseis": "franger",
    "frangêssemos": "franger",
    "frangíamo": "frangir",
    "frangíamos": "frangir",
    "frangíei": "frangir",
    "frangíeis": "frangir",
    "frangíramo": "frangir",
    "frangíramos": "frangir",
    "frangírei": "frangir",
    "frangíreis": "frangir",
    "frangísseis": "frangir",
    "frangíssemos": "frangir",
    "frangíveis": "frangível",
    "frangões": "frangão",
    "franja": "franjar",
    "franjada": "franjar",
    "franjadas": "franjar",
    "franjado": "franjar",
    "franjados": "franjar",
    "franjai": "franjar",
    "franjais": "franjar",
    "franjam": "franjar",
    "franjamentos": "franjamento",
    "franjamo": "franjar",
    "franjamos": "franjar",
    "franjando": "franjar",
    "franjara": "franjar",
    "franjaram": "franjar",
    "franjaras": "franjar",
    "franjarde": "franjar",
    "franjardes": "franjar",
    "franjare": "franjar",
    "franjarei": "franjar",
    "franjareis": "franjar",
    "franjarem": "franjar",
    "franjaremos": "franjar",
    "franjares": "franjar",
    "franjaria": "franjar",
    "franjariam": "franjar",
    "franjarias": "franjar",
    "franjarmo": "franjar",
    "franjarmos": "franjar",
    "franjará": "franjar",
    "franjarás": "franjar",
    "franjarão": "franjar",
    "franjaríamos": "franjar",
    "franjaríeis": "franjar",
    "franjas": "franjar",
    "franjasse": "franjar",
    "franjassem": "franjar",
    "franjasses": "franjar",
    "franjaste": "franjar",
    "franjastes": "franjar",
    "franjava": "franjar",
    "franjavam": "franjar",
    "franjavas": "franjar",
    "franje": "franjar",
    "franjeada": "franjear",
    "franjeadas": "franjear",
    "franjeado": "franjear",
    "franjeados": "franjear",
    "franjeai": "franjear",
    "franjeais": "franjear",
    "franjeamo": "franjear",
    "franjeamos": "franjear",
    "franjeando": "franjear",
    "franjeara": "franjear",
    "franjearam": "franjear",
    "franjearas": "franjear",
    "franjearde": "franjear",
    "franjeardes": "franjear",
    "franjeare": "franjear",
    "franjearei": "franjear",
    "franjeareis": "franjear",
    "franjearem": "franjear",
    "franjearemos": "franjear",
    "franjeares": "franjear",
    "franjearia": "franjear",
    "franjeariam": "franjear",
    "franjearias": "franjear",
    "franjearmo": "franjear",
    "franjearmos": "franjear",
    "franjeará": "franjear",
    "franjearás": "franjear",
    "franjearão": "franjear",
    "franjearíamos": "franjear",
    "franjearíeis": "franjear",
    "franjeasse": "franjear",
    "franjeassem": "franjear",
    "franjeasses": "franjear",
    "franjeaste": "franjear",
    "franjeastes": "franjear",
    "franjeava": "franjear",
    "franjeavam": "franjear",
    "franjeavas": "franjear",
    "franjeei": "franjear",
    "franjeeis": "franjear",
    "franjeemo": "franjear",
    "franjeemos": "franjear",
    "franjei": "franjar",
    "franjeia": "franjear",
    "franjeiam": "franjear",
    "franjeias": "franjear",
    "franjeie": "franjear",
    "franjeiem": "franjear",
    "franjeies": "franjear",
    "franjeio": "franjear",
    "franjeiras": "franjeira",
    "franjeis": "franjar",
    "franjem": "franjar",
    "franjemo": "franjar",
    "franjemos": "franjar",
    "franjeou": "franjear",
    "franjes": "franjar",
    "franjeá": "franjear",
    "franjeámo": "franjear",
    "franjeámos": "franjear",
    "franjeáramo": "franjear",
    "franjeáramos": "franjear",
    "franjeárei": "franjear",
    "franjeáreis": "franjear",
    "franjeásseis": "franjear",
    "franjeássemos": "franjear",
    "franjeávamo": "franjear",
    "franjeávamos": "franjear",
    "franjeávei": "franjear",
    "franjeáveis": "franjear",
    "franjinha": "franja",
    "franjinhas": "franja",
    "franjita": "franja",
    "franjitas": "franja",
    "franjo": "franjar",
    "franjoscas": "franjosca",
    "franjou": "franjar",
    "franjá": "franjar",
    "franjámo": "franjar",
    "franjámos": "franjar",
    "franjáramo": "franjar",
    "franjáramos": "franjar",
    "franjárei": "franjar",
    "franjáreis": "franjar",
    "franjásseis": "franjar",
    "franjássemos": "franjar",
    "franjávamo": "franjar",
    "franjávamos": "franjar",
    "franjávei": "franjar",
    "franjáveis": "franjar",
    "frankliniana": "frankliniano",
    "franklinianas": "frankliniano",
    "franklinianos": "frankliniano",
    "franklins": "franklin",
    "franqueada": "franquear",
    "franqueadas": "franquear",
    "franqueado": "franquear",
    "franqueados": "franquear",
    "franqueai": "franquear",
    "franqueais": "franquear",
    "franqueamo": "franquear",
    "franqueamos": "franquear",
    "franqueando": "franquear",
    "franqueara": "franquear",
    "franquearam": "franquear",
    "franquearas": "franquear",
    "franquearde": "franquear",
    "franqueardes": "franquear",
    "franqueare": "franquear",
    "franquearei": "franquear",
    "franqueareis": "franquear",
    "franquearem": "franquear",
    "franquearemos": "franquear",
    "franqueares": "franquear",
    "franquearia": "franquear",
    "franqueariam": "franquear",
    "franquearias": "franquear",
    "franquearmo": "franquear",
    "franquearmos": "franquear",
    "franqueará": "franquear",
    "franquearás": "franquear",
    "franquearão": "franquear",
    "franquearíamos": "franquear",
    "franquearíeis": "franquear",
    "franqueasse": "franquear",
    "franqueassem": "franquear",
    "franqueasses": "franquear",
    "franqueaste": "franquear",
    "franqueastes": "franquear",
    "franqueava": "franquear",
    "franqueavam": "franquear",
    "franqueavas": "franquear",
    "franqueei": "franquear",
    "franqueeis": "franquear",
    "franqueemo": "franquear",
    "franqueemos": "franquear",
    "franqueia": "franquear",
    "franqueiam": "franquear",
    "franqueias": "franquear",
    "franqueie": "franquear",
    "franqueiem": "franquear",
    "franqueies": "franquear",
    "franqueio": "franquear",
    "franqueniácea": "franqueniáceo",
    "franqueniáceas": "franqueniáceo",
    "franqueniáceos": "franqueniáceo",
    "franqueou": "franquear",
    "franquezas": "franqueza",
    "franqueá": "franquear",
    "franqueámo": "franquear",
    "franqueámos": "franquear",
    "franqueáramo": "franquear",
    "franqueáramos": "franquear",
    "franqueárei": "franquear",
    "franqueáreis": "franquear",
    "franqueásseis": "franquear",
    "franqueássemos": "franquear",
    "franqueávamo": "franquear",
    "franqueávamos": "franquear",
    "franqueávei": "franquear",
    "franqueáveis": "franqueável",
    "franquia": "franquiar",
    "franquiada": "franquiar",
    "franquiadas": "franquiar",
    "franquiado": "franquiar",
    "franquiados": "franquiar",
    "franquiai": "franquiar",
    "franquiais": "franquiar",
    "franquiam": "franquiar",
    "franquiamo": "franquiar",
    "franquiamos": "franquiar",
    "franquiando": "franquiar",
    "franquiara": "franquiar",
    "franquiaram": "franquiar",
    "franquiaras": "franquiar",
    "franquiarde": "franquiar",
    "franquiardes": "franquiar",
    "franquiare": "franquiar",
    "franquiarei": "franquiar",
    "franquiareis": "franquiar",
    "franquiarem": "franquiar",
    "franquiaremos": "franquiar",
    "franquiares": "franquiar",
    "franquiaria": "franquiar",
    "franquiariam": "franquiar",
    "franquiarias": "franquiar",
    "franquiarmo": "franquiar",
    "franquiarmos": "franquiar",
    "franquiará": "franquiar",
    "franquiarás": "franquiar",
    "franquiarão": "franquiar",
    "franquiaríamos": "franquiar",
    "franquiaríeis": "franquiar",
    "franquias": "franquiar",
    "franquiasse": "franquiar",
    "franquiassem": "franquiar",
    "franquiasses": "franquiar",
    "franquiaste": "franquiar",
    "franquiastes": "franquiar",
    "franquiava": "franquiar",
    "franquiavam": "franquiar",
    "franquiavas": "franquiar",
    "franquie": "franquiar",
    "franquiei": "franquiar",
    "franquieis": "franquiar",
    "franquiem": "franquiar",
    "franquiemo": "franquiar",
    "franquiemos": "franquiar",
    "franquies": "franquiar",
    "franquio": "franquiar",
    "franquiou": "franquiar",
    "franquismos": "franquismo",
    "franquisques": "franquisque",
    "franquistas": "franquista",
    "franquiá": "franquiar",
    "franquiámo": "franquiar",
    "franquiámos": "franquiar",
    "franquiáramo": "franquiar",
    "franquiáramos": "franquiar",
    "franquiárei": "franquiar",
    "franquiáreis": "franquiar",
    "franquiásseis": "franquiar",
    "franquiássemos": "franquiar",
    "franquiávamo": "franquiar",
    "franquiávamos": "franquiar",
    "franquiávei": "franquiar",
    "franquiáveis": "franquiar",
    "franquíssima": "franco",
    "franquíssimas": "franco",
    "franquíssimo": "franco",
    "franquíssimos": "franco",
    "franza": "franzir",
    "franzais": "franzir",
    "franzam": "franzir",
    "franzamo": "franzir",
    "franzamos": "franzir",
    "franzas": "franzir",
    "franze": "franzir",
    "franzem": "franzir",
    "franzes": "franzir",
    "franzi": "franzir",
    "franzia": "franzir",
    "franziam": "franzir",
    "franzias": "franzir",
    "franzida": "franzir",
    "franzidas": "franzir",
    "franzido": "franzir",
    "franzidos": "franzir",
    "franzimentos": "franzimento",
    "franzimo": "franzir",
    "franzimos": "franzir",
    "franzina": "franzino",
    "franzinas": "franzino",
    "franzindo": "franzir",
    "franzininha": "franzino",
    "franzininhas": "franzino",
    "franzininho": "franzino",
    "franzininhos": "franzino",
    "franzinita": "franzino",
    "franzinitas": "franzino",
    "franzinito": "franzino",
    "franzinitos": "franzino",
    "franzinos": "franzino",
    "franzinota": "franzinote",
    "franzinotas": "franzinote",
    "franzinotes": "franzinote",
    "franzira": "franzir",
    "franziram": "franzir",
    "franziras": "franzir",
    "franzirde": "franzir",
    "franzirdes": "franzir",
    "franzire": "franzir",
    "franzirei": "franzir",
    "franzireis": "franzir",
    "franzirem": "franzir",
    "franziremos": "franzir",
    "franzires": "franzir",
    "franziria": "franzir",
    "franziriam": "franzir",
    "franzirias": "franzir",
    "franzirmo": "franzir",
    "franzirmos": "franzir",
    "franzirá": "franzir",
    "franzirás": "franzir",
    "franzirão": "franzir",
    "franziríamos": "franzir",
    "franziríeis": "franzir",
    "franzis": "franzir",
    "franzisse": "franzir",
    "franzissem": "franzir",
    "franzisses": "franzir",
    "franziste": "franzir",
    "franzistes": "franzir",
    "franziu": "franzir",
    "franzo": "franzir",
    "franzíamo": "franzir",
    "franzíamos": "franzir",
    "franzíei": "franzir",
    "franzíeis": "franzir",
    "franzíramo": "franzir",
    "franzíramos": "franzir",
    "franzírei": "franzir",
    "franzíreis": "franzir",
    "franzísseis": "franzir",
    "franzíssemos": "franzir",
    "franças": "frança",
    "fraqueada": "fraquear",
    "fraqueadas": "fraquear",
    "fraqueado": "fraquear",
    "fraqueados": "fraquear",
    "fraqueai": "fraquear",
    "fraqueais": "fraquear",
    "fraqueamo": "fraquear",
    "fraqueamos": "fraquear",
    "fraqueando": "fraquear",
    "fraqueara": "fraquear",
    "fraquearam": "fraquear",
    "fraquearas": "fraquear",
    "fraquearde": "fraquear",
    "fraqueardes": "fraquear",
    "fraqueare": "fraquear",
    "fraquearei": "fraquear",
    "fraqueareis": "fraquear",
    "fraquearem": "fraquear",
    "fraquearemos": "fraquear",
    "fraqueares": "fraquear",
    "fraquearia": "fraquear",
    "fraqueariam": "fraquear",
    "fraquearias": "fraquear",
    "fraquearmo": "fraquear",
    "fraquearmos": "fraquear",
    "fraqueará": "fraquear",
    "fraquearás": "fraquear",
    "fraquearão": "fraquear",
    "fraquearíamos": "fraquear",
    "fraquearíeis": "fraquear",
    "fraqueasse": "fraquear",
    "fraqueassem": "fraquear",
    "fraqueasses": "fraquear",
    "fraqueaste": "fraquear",
    "fraqueastes": "fraquear",
    "fraqueava": "fraquear",
    "fraqueavam": "fraquear",
    "fraqueavas": "fraquear",
    "fraqueei": "fraquear",
    "fraqueeis": "fraquear",
    "fraqueemo": "fraquear",
    "fraqueemos": "fraquear",
    "fraqueia": "fraquear",
    "fraqueiam": "fraquear",
    "fraqueias": "fraquear",
    "fraqueie": "fraquear",
    "fraqueiem": "fraquear",
    "fraqueies": "fraquear",
    "fraqueio": "fraquear",
    "fraqueira": "fraqueiro",
    "fraqueiras": "fraqueiro",
    "fraqueiros": "fraqueiro",
    "fraqueja": "fraquejar",
    "fraquejada": "fraquejar",
    "fraquejadas": "fraquejar",
    "fraquejado": "fraquejar",
    "fraquejados": "fraquejar",
    "fraquejai": "fraquejar",
    "fraquejais": "fraquejar",
    "fraquejam": "fraquejar",
    "fraquejamo": "fraquejar",
    "fraquejamos": "fraquejar",
    "fraquejando": "fraquejar",
    "fraquejara": "fraquejar",
    "fraquejaram": "fraquejar",
    "fraquejaras": "fraquejar",
    "fraquejardes": "fraquejar",
    "fraquejarei": "fraquejar",
    "fraquejareis": "fraquejar",
    "fraquejarem": "fraquejar",
    "fraquejaremos": "fraquejar",
    "fraquejares": "fraquejar",
    "fraquejaria": "fraquejar",
    "fraquejariam": "fraquejar",
    "fraquejarias": "fraquejar",
    "fraquejarmo": "fraquejar",
    "fraquejarmos": "fraquejar",
    "fraquejará": "fraquejar",
    "fraquejarás": "fraquejar",
    "fraquejarão": "fraquejar",
    "fraquejaríamos": "fraquejar",
    "fraquejaríeis": "fraquejar",
    "fraquejas": "fraquejar",
    "fraquejasse": "fraquejar",
    "fraquejassem": "fraquejar",
    "fraquejasses": "fraquejar",
    "fraquejaste": "fraquejar",
    "fraquejastes": "fraquejar",
    "fraquejava": "fraquejar",
    "fraquejavam": "fraquejar",
    "fraquejavas": "fraquejar",
    "fraqueje": "fraquejar",
    "fraquejei": "fraquejar",
    "fraquejeis": "fraquejar",
    "fraquejem": "fraquejar",
    "fraquejemo": "fraquejar",
    "fraquejemos": "fraquejar",
    "fraquejes": "fraquejar",
    "fraquejo": "fraquejar",
    "fraquejou": "fraquejar",
    "fraquejámo": "fraquejar",
    "fraquejámos": "fraquejar",
    "fraquejáramo": "fraquejar",
    "fraquejáramos": "fraquejar",
    "fraquejáreis": "fraquejar",
    "fraquejásseis": "fraquejar",
    "fraquejássemos": "fraquejar",
    "fraquejávamo": "fraquejar",
    "fraquejávamos": "fraquejar",
    "fraquejáveis": "fraquejar",
    "fraqueou": "fraquear",
    "fraques": "fraque",
    "fraquetes": "fraquete",
    "fraquezas": "fraqueza",
    "fraqueá": "fraquear",
    "fraqueámo": "fraquear",
    "fraqueámos": "fraquear",
    "fraqueáramo": "fraquear",
    "fraqueáramos": "fraquear",
    "fraqueárei": "fraquear",
    "fraqueáreis": "fraquear",
    "fraqueásseis": "fraquear",
    "fraqueássemos": "fraquear",
    "fraqueávamo": "fraquear",
    "fraqueávamos": "fraquear",
    "fraqueávei": "fraquear",
    "fraqueáveis": "fraquear",
    "fraquinha": "fraco",
    "fraquinhas": "fraco",
    "fraquinho": "fraco",
    "fraquinhos": "fraco",
    "fraquismos": "fraquismo",
    "fraquita": "fraco",
    "fraquitas": "fraco",
    "fraquito": "fraco",
    "fraquitos": "fraco",
    "fraquíssima": "fraco",
    "fraquíssimas": "fraco",
    "fraquíssimo": "fraco",
    "fraquíssimos": "fraco",
    "frascagens": "frascagem",
    "frascais": "frascal",
    "frascarias": "frascaria",
    "frascas": "frasca",
    "frascos": "frasco",
    "frascozinho": "frasco",
    "frascozinhos": "frasco",
    "frascozito": "frasco",
    "frascozitos": "frasco",
    "frascária": "frascário",
    "frascárias": "frascário",
    "frascários": "frascário",
    "fraseada": "frasear",
    "fraseadas": "frasear",
    "fraseado": "frasear",
    "fraseadora": "fraseador",
    "fraseadoras": "fraseador",
    "fraseadores": "fraseador",
    "fraseados": "frasear",
    "fraseai": "frasear",
    "fraseais": "frasear",
    "fraseamo": "frasear",
    "fraseamos": "frasear",
    "fraseando": "frasear",
    "fraseara": "frasear",
    "frasearam": "frasear",
    "frasearas": "frasear",
    "fraseardes": "frasear",
    "frasearei": "frasear",
    "fraseareis": "frasear",
    "frasearem": "frasear",
    "frasearemos": "frasear",
    "fraseares": "frasear",
    "frasearia": "frasear",
    "fraseariam": "frasear",
    "frasearias": "frasear",
    "frasearmo": "frasear",
    "frasearmos": "frasear",
    "fraseará": "frasear",
    "frasearás": "frasear",
    "frasearão": "frasear",
    "frasearíamos": "frasear",
    "frasearíeis": "frasear",
    "fraseasse": "frasear",
    "fraseassem": "frasear",
    "fraseasses": "frasear",
    "fraseaste": "frasear",
    "fraseastes": "frasear",
    "fraseava": "frasear",
    "fraseavam": "frasear",
    "fraseavas": "frasear",
    "fraseei": "frasear",
    "fraseeis": "frasear",
    "fraseemo": "frasear",
    "fraseemos": "frasear",
    "fraseia": "frasear",
    "fraseiam": "frasear",
    "fraseias": "frasear",
    "fraseie": "frasear",
    "fraseiem": "frasear",
    "fraseies": "frasear",
    "fraseio": "frasear",
    "fraseologias": "fraseologia",
    "fraseologistas": "fraseologista",
    "fraseológica": "fraseológico",
    "fraseológicas": "fraseológico",
    "fraseológicos": "fraseológico",
    "fraseomanias": "fraseomania",
    "fraseomaníaca": "fraseomaníaco",
    "fraseomaníacas": "fraseomaníaco",
    "fraseomaníacos": "fraseomaníaco",
    "fraseou": "frasear",
    "frases": "frase",
    "frasezinha": "frase",
    "frasezinhas": "frase",
    "frasezita": "frase",
    "frasezitas": "frase",
    "fraseámo": "frasear",
    "fraseámos": "frasear",
    "fraseáramo": "frasear",
    "fraseáramos": "frasear",
    "fraseáreis": "frasear",
    "fraseásseis": "frasear",
    "fraseássemos": "frasear",
    "fraseávamo": "frasear",
    "fraseávamos": "frasear",
    "fraseáveis": "frasear",
    "fraseóloga": "fraseólogo",
    "fraseólogas": "fraseólogo",
    "fraseólogos": "fraseólogo",
    "fraseómana": "fraseómano",
    "fraseómanas": "fraseómano",
    "fraseómanos": "fraseómano",
    "frasistas": "frasista",
    "frasniana": "frasniano",
    "frasnianas": "frasniano",
    "frasnianos": "frasniano",
    "frasqueiras": "frasqueira",
    "frasqueja": "frasquejar",
    "frasquejada": "frasquejar",
    "frasquejadas": "frasquejar",
    "frasquejado": "frasquejar",
    "frasquejados": "frasquejar",
    "frasquejai": "frasquejar",
    "frasquejais": "frasquejar",
    "frasquejam": "frasquejar",
    "frasquejamo": "frasquejar",
    "frasquejamos": "frasquejar",
    "frasquejando": "frasquejar",
    "frasquejara": "frasquejar",
    "frasquejaram": "frasquejar",
    "frasquejaras": "frasquejar",
    "frasquejardes": "frasquejar",
    "frasquejarei": "frasquejar",
    "frasquejareis": "frasquejar",
    "frasquejarem": "frasquejar",
    "frasquejaremos": "frasquejar",
    "frasquejares": "frasquejar",
    "frasquejaria": "frasquejar",
    "frasquejariam": "frasquejar",
    "frasquejarias": "frasquejar",
    "frasquejarmo": "frasquejar",
    "frasquejarmos": "frasquejar",
    "frasquejará": "frasquejar",
    "frasquejarás": "frasquejar",
    "frasquejarão": "frasquejar",
    "frasquejaríamos": "frasquejar",
    "frasquejaríeis": "frasquejar",
    "frasquejas": "frasquejar",
    "frasquejasse": "frasquejar",
    "frasquejassem": "frasquejar",
    "frasquejasses": "frasquejar",
    "frasquejaste": "frasquejar",
    "frasquejastes": "frasquejar",
    "frasquejava": "frasquejar",
    "frasquejavam": "frasquejar",
    "frasquejavas": "frasquejar",
    "frasqueje": "frasquejar",
    "frasquejei": "frasquejar",
    "frasquejeis": "frasquejar",
    "frasquejem": "frasquejar",
    "frasquejemo": "frasquejar",
    "frasquejemos": "frasquejar",
    "frasquejes": "frasquejar",
    "frasquejo": "frasquejar",
    "frasquejou": "frasquejar",
    "frasquejámo": "frasquejar",
    "frasquejámos": "frasquejar",
    "frasquejáramo": "frasquejar",
    "frasquejáramos": "frasquejar",
    "frasquejáreis": "frasquejar",
    "frasquejásseis": "frasquejar",
    "frasquejássemos": "frasquejar",
    "frasquejávamo": "frasquejar",
    "frasquejávamos": "frasquejar",
    "frasquejáveis": "frasquejar",
    "frasquetas": "frasqueta",
    "frasquinho": "frasco",
    "frasquinhos": "frasco",
    "frasquito": "frasco",
    "frasquitos": "frasco",
    "frateados": "frateado",
    "fraterna": "fraterno",
    "fraternais": "fraternal",
    "fraternas": "fraterno",
    "fraternidades": "fraternidade",
    "fraterniza": "fraternizar",
    "fraternizada": "fraternizar",
    "fraternizadas": "fraternizar",
    "fraternizado": "fraternizar",
    "fraternizados": "fraternizar",
    "fraternizai": "fraternizar",
    "fraternizais": "fraternizar",
    "fraternizam": "fraternizar",
    "fraternizamo": "fraternizar",
    "fraternizamos": "fraternizar",
    "fraternizando": "fraternizar",
    "fraternizara": "fraternizar",
    "fraternizaram": "fraternizar",
    "fraternizaras": "fraternizar",
    "fraternizardes": "fraternizar",
    "fraternizarei": "fraternizar",
    "fraternizareis": "fraternizar",
    "fraternizarem": "fraternizar",
    "fraternizaremos": "fraternizar",
    "fraternizares": "fraternizar",
    "fraternizaria": "fraternizar",
    "fraternizariam": "fraternizar",
    "fraternizarias": "fraternizar",
    "fraternizarmo": "fraternizar",
    "fraternizarmos": "fraternizar",
    "fraternizará": "fraternizar",
    "fraternizarás": "fraternizar",
    "fraternizarão": "fraternizar",
    "fraternizaríamos": "fraternizar",
    "fraternizaríeis": "fraternizar",
    "fraternizas": "fraternizar",
    "fraternizasse": "fraternizar",
    "fraternizassem": "fraternizar",
    "fraternizasses": "fraternizar",
    "fraternizaste": "fraternizar",
    "fraternizastes": "fraternizar",
    "fraternizava": "fraternizar",
    "fraternizavam": "fraternizar",
    "fraternizavas": "fraternizar",
    "fraternizações": "fraternização",
    "fraternize": "fraternizar",
    "fraternizei": "fraternizar",
    "fraternizeis": "fraternizar",
    "fraternizem": "fraternizar",
    "fraternizemo": "fraternizar",
    "fraternizemos": "fraternizar",
    "fraternizes": "fraternizar",
    "fraternizo": "fraternizar",
    "fraternizou": "fraternizar",
    "fraternizámo": "fraternizar",
    "fraternizámos": "fraternizar",
    "fraternizáramo": "fraternizar",
    "fraternizáramos": "fraternizar",
    "fraternizáreis": "fraternizar",
    "fraternizásseis": "fraternizar",
    "fraternizássemos": "fraternizar",
    "fraternizávamo": "fraternizar",
    "fraternizávamos": "fraternizar",
    "fraternizáveis": "fraternizar",
    "fraternos": "fraterno",
    "fratrias": "fratria",
    "fratricidas": "fratricida",
    "fratricídios": "fratricídio",
    "frauda": "fraudar",
    "fraudada": "fraudar",
    "fraudadas": "fraudar",
    "fraudado": "fraudar",
    "fraudadora": "fraudador",
    "fraudadoras": "fraudador",
    "fraudadores": "fraudador",
    "fraudados": "fraudar",
    "fraudai": "fraudar",
    "fraudais": "fraudar",
    "fraudam": "fraudar",
    "fraudamo": "fraudar",
    "fraudamos": "fraudar",
    "fraudando": "fraudar",
    "fraudara": "fraudar",
    "fraudaram": "fraudar",
    "fraudaras": "fraudar",
    "fraudarde": "fraudar",
    "fraudardes": "fraudar",
    "fraudare": "fraudar",
    "fraudarei": "fraudar",
    "fraudareis": "fraudar",
    "fraudarem": "fraudar",
    "fraudaremos": "fraudar",
    "fraudares": "fraudar",
    "fraudaria": "fraudar",
    "fraudariam": "fraudar",
    "fraudarias": "fraudar",
    "fraudarmo": "fraudar",
    "fraudarmos": "fraudar",
    "fraudará": "fraudar",
    "fraudarás": "fraudar",
    "fraudarão": "fraudar",
    "fraudaríamos": "fraudar",
    "fraudaríeis": "fraudar",
    "fraudas": "fraudar",
    "fraudasse": "fraudar",
    "fraudassem": "fraudar",
    "fraudasses": "fraudar",
    "fraudaste": "fraudar",
    "fraudastes": "fraudar",
    "fraudatória": "fraudatório",
    "fraudatórias": "fraudatório",
    "fraudatórios": "fraudatório",
    "fraudava": "fraudar",
    "fraudavam": "fraudar",
    "fraudavas": "fraudar",
    "fraudações": "fraudação",
    "fraude": "fraudar",
    "fraudei": "fraudar",
    "fraudeis": "fraudar",
    "fraudem": "fraudar",
    "fraudemo": "fraudar",
    "fraudemos": "fraudar",
    "fraudes": "fraude",
    "fraudiqueira": "fraudiqueiro",
    "fraudiqueiras": "fraudiqueiro",
    "fraudiqueiros": "fraudiqueiro",
    "fraudisqueira": "fraudisqueiro",
    "fraudisqueiras": "fraudisqueiro",
    "fraudisqueiros": "fraudisqueiro",
    "fraudo": "fraudar",
    "fraudosa": "fraudoso",
    "fraudosas": "fraudoso",
    "fraudosos": "fraudoso",
    "fraudou": "fraudar",
    "fraudulenta": "fraudulento",
    "fraudulentas": "fraudulento",
    "fraudulentos": "fraudulento",
    "fraudulosa": "frauduloso",
    "fraudulosas": "frauduloso",
    "fraudulosos": "frauduloso",
    "fraudulências": "fraudulência",
    "fraudá": "fraudar",
    "fraudámo": "fraudar",
    "fraudámos": "fraudar",
    "fraudáramo": "fraudar",
    "fraudáramos": "fraudar",
    "fraudárei": "fraudar",
    "fraudáreis": "fraudar",
    "fraudásseis": "fraudar",
    "fraudássemos": "fraudar",
    "fraudávamo": "fraudar",
    "fraudávamos": "fraudar",
    "fraudávei": "fraudar",
    "fraudáveis": "fraudável",
    "frautas": "frauta",
    "frauteada": "frautear",
    "frauteadas": "frautear",
    "frauteado": "frautear",
    "frauteados": "frautear",
    "frauteai": "frautear",
    "frauteais": "frautear",
    "frauteamo": "frautear",
    "frauteamos": "frautear",
    "frauteando": "frautear",
    "frauteara": "frautear",
    "frautearam": "frautear",
    "frautearas": "frautear",
    "frautearde": "frautear",
    "frauteardes": "frautear",
    "frauteare": "frautear",
    "frautearei": "frautear",
    "frauteareis": "frautear",
    "frautearem": "frautear",
    "frautearemos": "frautear",
    "frauteares": "frautear",
    "frautearia": "frautear",
    "frauteariam": "frautear",
    "frautearias": "frautear",
    "frautearmo": "frautear",
    "frautearmos": "frautear",
    "frauteará": "frautear",
    "frautearás": "frautear",
    "frautearão": "frautear",
    "frautearíamos": "frautear",
    "frautearíeis": "frautear",
    "frauteasse": "frautear",
    "frauteassem": "frautear",
    "frauteasses": "frautear",
    "frauteaste": "frautear",
    "frauteastes": "frautear",
    "frauteava": "frautear",
    "frauteavam": "frautear",
    "frauteavas": "frautear",
    "frauteei": "frautear",
    "frauteeis": "frautear",
    "frauteemo": "frautear",
    "frauteemos": "frautear",
    "frauteia": "frautear",
    "frauteiam": "frautear",
    "frauteias": "frautear",
    "frauteie": "frautear",
    "frauteiem": "frautear",
    "frauteies": "frautear",
    "frauteio": "frautear",
    "frauteira": "frauteiro",
    "frauteiras": "frauteiro",
    "frauteiros": "frauteiro",
    "frauteou": "frautear",
    "frauteá": "frautear",
    "frauteámo": "frautear",
    "frauteámos": "frautear",
    "frauteáramo": "frautear",
    "frauteáramos": "frautear",
    "frauteárei": "frautear",
    "frauteáreis": "frautear",
    "frauteásseis": "frautear",
    "frauteássemos": "frautear",
    "frauteávamo": "frautear",
    "frauteávamos": "frautear",
    "frauteávei": "frautear",
    "frauteáveis": "frautear",
    "fraxinas": "fraxina",
    "fraxinina": "fraxinino",
    "fraxininas": "fraxinino",
    "fraxininos": "fraxinino",
    "fraxinácea": "fraxináceo",
    "fraxináceas": "fraxináceo",
    "fraxináceos": "fraxináceo",
    "fraxínea": "fraxíneo",
    "fraxíneas": "fraxíneo",
    "fraxíneos": "fraxíneo",
    "fraxínia": "fraxínio",
    "fraxínias": "fraxínio",
    "fraxínios": "fraxínio",
    "frecha": "frechar",
    "frechada": "frechar",
    "frechadas": "frechar",
    "frechado": "frechar",
    "frechados": "frechar",
    "frechai": "frechar",
    "frechais": "frechar",
    "frecham": "frechar",
    "frechamo": "frechar",
    "frechamos": "frechar",
    "frechando": "frechar",
    "frechara": "frechar",
    "frecharam": "frechar",
    "frecharas": "frechar",
    "frecharde": "frechar",
    "frechardes": "frechar",
    "frechare": "frechar",
    "frecharei": "frechar",
    "frechareis": "frechar",
    "frecharem": "frechar",
    "frecharemos": "frechar",
    "frechares": "frechar",
    "frecharia": "frechar",
    "frechariam": "frechar",
    "frecharias": "frecharia",
    "frecharmo": "frechar",
    "frecharmos": "frechar",
    "frechará": "frechar",
    "frecharás": "frechar",
    "frecharão": "frechar",
    "frecharíamos": "frechar",
    "frecharíeis": "frechar",
    "frechas": "frechar",
    "frechasse": "frechar",
    "frechassem": "frechar",
    "frechasses": "frechar",
    "frechaste": "frechar",
    "frechastes": "frechar",
    "frechava": "frechar",
    "frechavam": "frechar",
    "frechavas": "frechar",
    "freche": "frechar",
    "frechei": "frechar",
    "frecheira": "frecheiro",
    "frecheiras": "frecheiro",
    "frecheiros": "frecheiro",
    "frecheis": "frechar",
    "frechem": "frechar",
    "frechemo": "frechar",
    "frechemos": "frechar",
    "freches": "frechar",
    "frecho": "frechar",
    "frechou": "frechar",
    "frechá": "frechar",
    "frechámo": "frechar",
    "frechámos": "frechar",
    "frecháramo": "frechar",
    "frecháramos": "frechar",
    "frechárei": "frechar",
    "frecháreis": "frechar",
    "frechásseis": "frechar",
    "frechássemos": "frechar",
    "frechávamo": "frechar",
    "frechávamos": "frechar",
    "frechávei": "frechar",
    "frecháveis": "frechar",
    "freeira": "freeiro",
    "freeiras": "freeiro",
    "freeiros": "freeiro",
    "frege": "frigir",
    "fregem": "frigir",
    "freges": "frigir",
    "fregonas": "fregona",
    "freguesa": "freguês",
    "freguesas": "freguês",
    "fregueses": "freguês",
    "freguesias": "freguesia",
    "freichas": "freicha",
    "freimas": "freima",
    "freimaços": "freimaço",
    "freimática": "freimático",
    "freimáticas": "freimático",
    "freimáticos": "freimático",
    "freimões": "freimão",
    "freios": "freio",
    "freirais": "freiral",
    "freirarias": "freiraria",
    "freiras": "freira",
    "freires": "freire",
    "freirias": "freiria",
    "freirices": "freirice",
    "freirinhas": "freirinha",
    "freirática": "freirático",
    "freiráticas": "freirático",
    "freiráticos": "freirático",
    "freis": "frei",
    "freixais": "freixal",
    "freixenistas": "freixenista",
    "freixiais": "freixial",
    "freixos": "freixo",
    "freme": "fremir",
    "fremebunda": "fremebundo",
    "fremebundas": "fremebundo",
    "fremebundos": "fremebundo",
    "fremem": "fremir",
    "frementes": "fremente",
    "fremes": "fremir",
    "fremi": "fremir",
    "fremia": "fremir",
    "fremiam": "fremir",
    "fremias": "fremir",
    "fremida": "fremir",
    "fremidas": "fremir",
    "fremido": "fremir",
    "fremidos": "fremir",
    "fremimo": "fremir",
    "fremimos": "fremir",
    "fremindo": "fremir",
    "fremira": "fremir",
    "fremiram": "fremir",
    "fremiras": "fremir",
    "fremirdes": "fremir",
    "fremirei": "fremir",
    "fremireis": "fremir",
    "fremirem": "fremir",
    "fremiremos": "fremir",
    "fremires": "fremir",
    "fremiria": "fremir",
    "fremiriam": "fremir",
    "fremirias": "fremir",
    "fremirmo": "fremir",
    "fremirmos": "fremir",
    "fremirá": "fremir",
    "fremirás": "fremir",
    "fremirão": "fremir",
    "fremiríamos": "fremir",
    "fremiríeis": "fremir",
    "fremis": "fremir",
    "fremisse": "fremir",
    "fremissem": "fremir",
    "fremisses": "fremir",
    "fremiste": "fremir",
    "fremistes": "fremir",
    "fremiu": "fremir",
    "fremências": "fremência",
    "fremíamo": "fremir",
    "fremíamos": "fremir",
    "fremíeis": "fremir",
    "fremíramo": "fremir",
    "fremíramos": "fremir",
    "fremíreis": "fremir",
    "fremísseis": "fremir",
    "fremíssemos": "fremir",
    "frena": "frenar",
    "frenada": "frenar",
    "frenadas": "frenar",
    "frenado": "frenar",
    "frenados": "frenar",
    "frenai": "frenar",
    "frenais": "frenar",
    "frenam": "frenar",
    "frenamo": "frenar",
    "frenamos": "frenar",
    "frenando": "frenar",
    "frenara": "frenar",
    "frenaram": "frenar",
    "frenaras": "frenar",
    "frenarde": "frenar",
    "frenardes": "frenar",
    "frenare": "frenar",
    "frenarei": "frenar",
    "frenareis": "frenar",
    "frenarem": "frenar",
    "frenaremos": "frenar",
    "frenares": "frenar",
    "frenaria": "frenar",
    "frenariam": "frenar",
    "frenarias": "frenar",
    "frenarmo": "frenar",
    "frenarmos": "frenar",
    "frenará": "frenar",
    "frenarás": "frenar",
    "frenarão": "frenar",
    "frenaríamos": "frenar",
    "frenaríeis": "frenar",
    "frenas": "frenar",
    "frenasse": "frenar",
    "frenassem": "frenar",
    "frenasses": "frenar",
    "frenaste": "frenar",
    "frenastes": "frenar",
    "frenava": "frenar",
    "frenavam": "frenar",
    "frenavas": "frenar",
    "frenações": "frenação",
    "frenda": "frender",
    "frendais": "frender",
    "frendam": "frender",
    "frendamo": "frender",
    "frendamos": "frender",
    "frendas": "frender",
    "frende": "frender",
    "frendei": "frender",
    "frendeis": "frender",
    "frendem": "frender",
    "frendemo": "frender",
    "frendemos": "frender",
    "frendendo": "frender",
    "frendentes": "frendente",
    "frendera": "frender",
    "frenderam": "frender",
    "frenderas": "frender",
    "frenderdes": "frender",
    "frenderei": "frender",
    "frendereis": "frender",
    "frenderem": "frender",
    "frenderemos": "frender",
    "frenderes": "frender",
    "frenderia": "frender",
    "frenderiam": "frender",
    "frenderias": "frender",
    "frendermo": "frender",
    "frendermos": "frender",
    "frenderá": "frender",
    "frenderás": "frender",
    "frenderão": "frender",
    "frenderíamos": "frender",
    "frenderíeis": "frender",
    "frendes": "frender",
    "frendesse": "frender",
    "frendessem": "frender",
    "frendesses": "frender",
    "frendeste": "frender",
    "frendestes": "frender",
    "frendeu": "frender",
    "frendi": "frender",
    "frendia": "frender",
    "frendiam": "frender",
    "frendias": "frender",
    "frendida": "frender",
    "frendidas": "frender",
    "frendido": "frender",
    "frendidos": "frender",
    "frendo": "frender",
    "frendores": "frendor",
    "frendêramo": "frender",
    "frendêramos": "frender",
    "frendêreis": "frender",
    "frendêsseis": "frender",
    "frendêssemos": "frender",
    "frendíamo": "frender",
    "frendíamos": "frender",
    "frendíeis": "frender",
    "frene": "frenar",
    "frenei": "frenar",
    "freneis": "frenar",
    "frenem": "frenar",
    "frenemo": "frenar",
    "frenemos": "frenar",
    "frenes": "frenar",
    "frenesins": "frenesim",
    "frenesis": "frenesi",
    "frenites": "frenite",
    "freno": "frenar",
    "frenologias": "frenologia",
    "frenologismos": "frenologismo",
    "frenologistas": "frenologista",
    "frenológica": "frenológico",
    "frenológicas": "frenológico",
    "frenológicos": "frenológico",
    "frenopatas": "frenopata",
    "frenopatias": "frenopatia",
    "frenopática": "frenopático",
    "frenopáticas": "frenopático",
    "frenopáticos": "frenopático",
    "frenou": "frenar",
    "frentes": "frente",
    "frenulados": "frenulado",
    "frená": "frenar",
    "frenámo": "frenar",
    "frenámos": "frenar",
    "frenáramo": "frenar",
    "frenáramos": "frenar",
    "frenárei": "frenar",
    "frenáreis": "frenar",
    "frenásseis": "frenar",
    "frenássemos": "frenar",
    "frenávamo": "frenar",
    "frenávamos": "frenar",
    "frenávei": "frenar",
    "frenáveis": "frenar",
    "frenética": "frenético",
    "frenéticas": "frenético",
    "frenéticos": "frenético",
    "frenítica": "frenítico",
    "freníticas": "frenítico",
    "freníticos": "frenítico",
    "frenóloga": "frenólogo",
    "frenólogas": "frenólogo",
    "frenólogos": "frenólogo",
    "frequencimétrica": "frequencimétrico",
    "frequencimétricas": "frequencimétrico",
    "frequencimétricos": "frequencimétrico",
    "frequencímetros": "frequencímetro",
    "frequenta": "frequentar",
    "frequentada": "frequentar",
    "frequentadas": "frequentar",
    "frequentado": "frequentar",
    "frequentadora": "frequentador",
    "frequentadoras": "frequentador",
    "frequentadores": "frequentador",
    "frequentados": "frequentar",
    "frequentai": "frequentar",
    "frequentais": "frequentar",
    "frequentam": "frequentar",
    "frequentamo": "frequentar",
    "frequentamos": "frequentar",
    "frequentando": "frequentar",
    "frequentara": "frequentar",
    "frequentaram": "frequentar",
    "frequentaras": "frequentar",
    "frequentarde": "frequentar",
    "frequentardes": "frequentar",
    "frequentare": "frequentar",
    "frequentarei": "frequentar",
    "frequentareis": "frequentar",
    "frequentarem": "frequentar",
    "frequentaremos": "frequentar",
    "frequentares": "frequentar",
    "frequentaria": "frequentar",
    "frequentariam": "frequentar",
    "frequentarias": "frequentar",
    "frequentarmo": "frequentar",
    "frequentarmos": "frequentar",
    "frequentará": "frequentar",
    "frequentarás": "frequentar",
    "frequentarão": "frequentar",
    "frequentaríamos": "frequentar",
    "frequentaríeis": "frequentar",
    "frequentas": "frequentar",
    "frequentasse": "frequentar",
    "frequentassem": "frequentar",
    "frequentasses": "frequentar",
    "frequentaste": "frequentar",
    "frequentastes": "frequentar",
    "frequentativa": "frequentativo",
    "frequentativas": "frequentativo",
    "frequentativos": "frequentativo",
    "frequentava": "frequentar",
    "frequentavam": "frequentar",
    "frequentavas": "frequentar",
    "frequentações": "frequentação",
    "frequente": "frequentar",
    "frequentei": "frequentar",
    "frequenteis": "frequentar",
    "frequentem": "frequentar",
    "frequentemo": "frequentar",
    "frequentemos": "frequentar",
    "frequentes": "frequente",
    "frequento": "frequentar",
    "frequentou": "frequentar",
    "frequentá": "frequentar",
    "frequentámo": "frequentar",
    "frequentámos": "frequentar",
    "frequentáramo": "frequentar",
    "frequentáramos": "frequentar",
    "frequentárei": "frequentar",
    "frequentáreis": "frequentar",
    "frequentásseis": "frequentar",
    "frequentássemos": "frequentar",
    "frequentávamo": "frequentar",
    "frequentávamos": "frequentar",
    "frequentávei": "frequentar",
    "frequentáveis": "frequentável",
    "frequências": "frequência",
    "fresa": "fresar",
    "fresada": "fresar",
    "fresadas": "fresar",
    "fresado": "fresar",
    "fresadora": "fresador",
    "fresadoras": "fresadora",
    "fresadores": "fresador",
    "fresados": "fresar",
    "fresagens": "fresagem",
    "fresai": "fresar",
    "fresais": "fresar",
    "fresam": "fresar",
    "fresamo": "fresar",
    "fresamos": "fresar",
    "fresando": "fresar",
    "fresara": "fresar",
    "fresaram": "fresar",
    "fresaras": "fresar",
    "fresarde": "fresar",
    "fresardes": "fresar",
    "fresare": "fresar",
    "fresarei": "fresar",
    "fresareis": "fresar",
    "fresarem": "fresar",
    "fresaremos": "fresar",
    "fresares": "fresar",
    "fresaria": "fresar",
    "fresariam": "fresar",
    "fresarias": "fresar",
    "fresarmo": "fresar",
    "fresarmos": "fresar",
    "fresará": "fresar",
    "fresarás": "fresar",
    "fresarão": "fresar",
    "fresaríamos": "fresar",
    "fresaríeis": "fresar",
    "fresas": "fresar",
    "fresasse": "fresar",
    "fresassem": "fresar",
    "fresasses": "fresar",
    "fresaste": "fresar",
    "fresastes": "fresar",
    "fresava": "fresar",
    "fresavam": "fresar",
    "fresavas": "fresar",
    "fresca": "fresco",
    "frescais": "frescal",
    "frescalhais": "frescalhal",
    "frescalhota": "frescalhote",
    "frescalhotas": "frescalhote",
    "frescalhotes": "frescalhote",
    "frescas": "fresco",
    "frescatas": "frescata",
    "frescores": "frescor",
    "frescos": "fresco",
    "frescuns": "frescum",
    "frescuras": "frescura",
    "frese": "fresar",
    "fresei": "fresar",
    "freseis": "fresar",
    "fresem": "fresar",
    "fresemo": "fresar",
    "fresemos": "fresar",
    "freses": "fresar",
    "freso": "fresar",
    "fresou": "fresar",
    "fresquidões": "fresquidão",
    "fresquinha": "fresco",
    "fresquinhas": "fresco",
    "fresquinho": "fresco",
    "fresquinhos": "fresco",
    "fresquita": "fresco",
    "fresquitas": "fresquita",
    "fresquito": "fresco",
    "fresquitos": "fresco",
    "fresquíssima": "fresco",
    "fresquíssimas": "fresco",
    "fresquíssimo": "fresco",
    "fresquíssimos": "fresco",
    "fressuras": "fressura",
    "fressureira": "fressureiro",
    "fressureiras": "fressureiro",
    "fressureiros": "fressureiro",
    "frestada": "frestado",
    "frestadas": "frestado",
    "frestados": "frestado",
    "frestas": "fresta",
    "frestões": "frestão",
    "fresá": "fresar",
    "fresámo": "fresar",
    "fresámos": "fresar",
    "fresáramo": "fresar",
    "fresáramos": "fresar",
    "fresárei": "fresar",
    "fresáreis": "fresar",
    "fresásseis": "fresar",
    "fresássemos": "fresar",
    "fresávamo": "fresar",
    "fresávamos": "fresar",
    "fresávei": "fresar",
    "fresáveis": "fresar",
    "freta": "fretar",
    "fretada": "fretar",
    "fretadas": "fretar",
    "fretado": "fretar",
    "fretadora": "fretador",
    "fretadoras": "fretador",
    "fretadores": "fretador",
    "fretados": "fretar",
    "fretagens": "fretagem",
    "fretai": "fretar",
    "fretais": "fretar",
    "fretam": "fretar",
    "fretamentos": "fretamento",
    "fretamo": "fretar",
    "fretamos": "fretar",
    "fretando": "fretar",
    "fretara": "fretar",
    "fretaram": "fretar",
    "fretaras": "fretar",
    "fretarde": "fretar",
    "fretardes": "fretar",
    "fretare": "fretar",
    "fretarei": "fretar",
    "fretareis": "fretar",
    "fretarem": "fretar",
    "fretaremos": "fretar",
    "fretares": "fretar",
    "fretaria": "fretar",
    "fretariam": "fretar",
    "fretarias": "fretar",
    "fretarmo": "fretar",
    "fretarmos": "fretar",
    "fretará": "fretar",
    "fretarás": "fretar",
    "fretarão": "fretar",
    "fretaríamos": "fretar",
    "fretaríeis": "fretar",
    "fretas": "fretar",
    "fretasse": "fretar",
    "fretassem": "fretar",
    "fretasses": "fretar",
    "fretaste": "fretar",
    "fretastes": "fretar",
    "fretava": "fretar",
    "fretavam": "fretar",
    "fretavas": "fretar",
    "frete": "fretar",
    "fretei": "fretar",
    "freteis": "fretar",
    "freteja": "fretejar",
    "fretejada": "fretejar",
    "fretejadas": "fretejar",
    "fretejado": "fretejar",
    "fretejadora": "fretejador",
    "fretejadoras": "fretejador",
    "fretejadores": "fretejador",
    "fretejados": "fretejar",
    "fretejai": "fretejar",
    "fretejais": "fretejar",
    "fretejam": "fretejar",
    "fretejamo": "fretejar",
    "fretejamos": "fretejar",
    "fretejando": "fretejar",
    "fretejara": "fretejar",
    "fretejaram": "fretejar",
    "fretejaras": "fretejar",
    "fretejardes": "fretejar",
    "fretejarei": "fretejar",
    "fretejareis": "fretejar",
    "fretejarem": "fretejar",
    "fretejaremos": "fretejar",
    "fretejares": "fretejar",
    "fretejaria": "fretejar",
    "fretejariam": "fretejar",
    "fretejarias": "fretejar",
    "fretejarmo": "fretejar",
    "fretejarmos": "fretejar",
    "fretejará": "fretejar",
    "fretejarás": "fretejar",
    "fretejarão": "fretejar",
    "fretejaríamos": "fretejar",
    "fretejaríeis": "fretejar",
    "fretejas": "fretejar",
    "fretejasse": "fretejar",
    "fretejassem": "fretejar",
    "fretejasses": "fretejar",
    "fretejaste": "fretejar",
    "fretejastes": "fretejar",
    "fretejava": "fretejar",
    "fretejavam": "fretejar",
    "fretejavas": "fretejar",
    "freteje": "fretejar",
    "fretejei": "fretejar",
    "fretejeis": "fretejar",
    "fretejem": "fretejar",
    "fretejemo": "fretejar",
    "fretejemos": "fretejar",
    "fretejes": "fretejar",
    "fretejo": "fretejar",
    "fretejou": "fretejar",
    "fretejámo": "fretejar",
    "fretejámos": "fretejar",
    "fretejáramo": "fretejar",
    "fretejáramos": "fretejar",
    "fretejáreis": "fretejar",
    "fretejásseis": "fretejar",
    "fretejássemos": "fretejar",
    "fretejávamo": "fretejar",
    "fretejávamos": "fretejar",
    "fretejáveis": "fretejar",
    "fretem": "fretar",
    "fretemo": "fretar",
    "fretemos": "fretar",
    "fretena": "fretenir",
    "fretenais": "fretenir",
    "fretenam": "fretenir",
    "fretenamo": "fretenir",
    "fretenamos": "fretenir",
    "fretenas": "fretenir",
    "fretene": "fretenir",
    "fretenem": "fretenir",
    "fretenes": "fretenir",
    "freteni": "fretenir",
    "fretenia": "fretenir",
    "freteniam": "fretenir",
    "fretenias": "fretenir",
    "fretenida": "fretenir",
    "fretenidas": "fretenir",
    "fretenido": "fretenir",
    "fretenidos": "fretenir",
    "fretenimo": "fretenir",
    "fretenimos": "fretenir",
    "fretenindo": "fretenir",
    "fretenira": "fretenir",
    "freteniram": "fretenir",
    "freteniras": "fretenir",
    "fretenirdes": "fretenir",
    "fretenirei": "fretenir",
    "fretenireis": "fretenir",
    "fretenirem": "fretenir",
    "freteniremos": "fretenir",
    "fretenires": "fretenir",
    "freteniria": "fretenir",
    "freteniriam": "fretenir",
    "fretenirias": "fretenir",
    "fretenirmo": "fretenir",
    "fretenirmos": "fretenir",
    "fretenirá": "fretenir",
    "fretenirás": "fretenir",
    "fretenirão": "fretenir",
    "freteniríamos": "fretenir",
    "freteniríeis": "fretenir",
    "fretenis": "fretenir",
    "fretenisse": "fretenir",
    "fretenissem": "fretenir",
    "fretenisses": "fretenir",
    "freteniste": "fretenir",
    "fretenistes": "fretenir",
    "freteniu": "fretenir",
    "freteno": "fretenir",
    "freteníamo": "fretenir",
    "freteníamos": "fretenir",
    "freteníeis": "fretenir",
    "freteníramo": "fretenir",
    "freteníramos": "fretenir",
    "freteníreis": "fretenir",
    "fretenísseis": "fretenir",
    "freteníssemos": "fretenir",
    "fretes": "frete",
    "freto": "fretar",
    "fretou": "fretar",
    "fretá": "fretar",
    "fretámo": "fretar",
    "fretámos": "fretar",
    "fretáramo": "fretar",
    "fretáramos": "fretar",
    "fretárei": "fretar",
    "fretáreis": "fretar",
    "fretásseis": "fretar",
    "fretássemos": "fretar",
    "fretávamo": "fretar",
    "fretávamos": "fretar",
    "fretávei": "fretar",
    "fretáveis": "fretar",
    "freudiana": "freudiano",
    "freudianas": "freudiano",
    "freudianistas": "freudianista",
    "freudianos": "freudiano",
    "freudismos": "freudismo",
    "freática": "freático",
    "freáticas": "freático",
    "freáticos": "freático",
    "fria": "frio",
    "friabilidades": "friabilidade",
    "friacha": "friacho",
    "friachas": "friacho",
    "friachos": "friacho",
    "friagens": "friagem",
    "frialdades": "frialdade",
    "friames": "friame",
    "frias": "frio",
    "fricandós": "fricandó",
    "fricassés": "fricassé",
    "fricativa": "fricativo",
    "fricativas": "fricativo",
    "fricativos": "fricativo",
    "fricciona": "friccionar",
    "friccionada": "friccionar",
    "friccionadas": "friccionar",
    "friccionado": "friccionar",
    "friccionadora": "friccionador",
    "friccionadoras": "friccionador",
    "friccionadores": "friccionador",
    "friccionados": "friccionar",
    "friccionai": "friccionar",
    "friccionais": "friccionar",
    "friccionam": "friccionar",
    "friccionamo": "friccionar",
    "friccionamos": "friccionar",
    "friccionando": "friccionar",
    "friccionara": "friccionar",
    "friccionaram": "friccionar",
    "friccionaras": "friccionar",
    "friccionarde": "friccionar",
    "friccionardes": "friccionar",
    "friccionare": "friccionar",
    "friccionarei": "friccionar",
    "friccionareis": "friccionar",
    "friccionarem": "friccionar",
    "friccionaremos": "friccionar",
    "friccionares": "friccionar",
    "friccionaria": "friccionar",
    "friccionariam": "friccionar",
    "friccionarias": "friccionar",
    "friccionarmo": "friccionar",
    "friccionarmos": "friccionar",
    "friccionará": "friccionar",
    "friccionarás": "friccionar",
    "friccionarão": "friccionar",
    "friccionaríamos": "friccionar",
    "friccionaríeis": "friccionar",
    "friccionas": "friccionar",
    "friccionasse": "friccionar",
    "friccionassem": "friccionar",
    "friccionasses": "friccionar",
    "friccionaste": "friccionar",
    "friccionastes": "friccionar",
    "friccionava": "friccionar",
    "friccionavam": "friccionar",
    "friccionavas": "friccionar",
    "friccione": "friccionar",
    "friccionei": "friccionar",
    "friccioneis": "friccionar",
    "friccionem": "friccionar",
    "friccionemo": "friccionar",
    "friccionemos": "friccionar",
    "fricciones": "friccionar",
    "fricciono": "friccionar",
    "friccionou": "friccionar",
    "friccioná": "friccionar",
    "friccionámo": "friccionar",
    "friccionámos": "friccionar",
    "friccionáramo": "friccionar",
    "friccionáramos": "friccionar",
    "friccionárei": "friccionar",
    "friccionáreis": "friccionar",
    "friccionásseis": "friccionar",
    "friccionássemos": "friccionar",
    "friccionávamo": "friccionar",
    "friccionávamos": "friccionar",
    "friccionávei": "friccionar",
    "friccionáveis": "friccionar",
    "frictores": "frictor",
    "fricções": "fricção",
    "frieiras": "frieira",
    "frieirenta": "frieirento",
    "frieirentas": "frieirento",
    "frieirentos": "frieirento",
    "frieirona": "frieirão",
    "frieironas": "frieirão",
    "frieirões": "frieirão",
    "friestas": "friesta",
    "friezas": "frieza",
    "frigi": "frigir",
    "frigia": "frigir",
    "frigiam": "frigir",
    "frigias": "frigir",
    "frigida": "frigir",
    "frigidas": "frigir",
    "frigideiras": "frigideira",
    "frigideirinha": "frigideira",
    "frigideirinhas": "frigideira",
    "frigideirita": "frigideira",
    "frigideiritas": "frigideira",
    "frigido": "frigir",
    "frigidos": "frigir",
    "frigidíssima": "frio",
    "frigidíssimas": "frio",
    "frigidíssimo": "frio",
    "frigidíssimos": "frio",
    "frigifóbica": "frigifóbico",
    "frigifóbicas": "frigifóbico",
    "frigifóbicos": "frigifóbico",
    "frigimo": "frigir",
    "frigimos": "frigir",
    "friginadas": "friginada",
    "frigindo": "frigir",
    "frigira": "frigir",
    "frigiram": "frigir",
    "frigiras": "frigir",
    "frigirde": "frigir",
    "frigirdes": "frigir",
    "frigire": "frigir",
    "frigirei": "frigir",
    "frigireis": "frigir",
    "frigirem": "frigir",
    "frigiremos": "frigir",
    "frigires": "frigir",
    "frigiria": "frigir",
    "frigiriam": "frigir",
    "frigirias": "frigir",
    "frigirmo": "frigir",
    "frigirmos": "frigir",
    "frigirá": "frigir",
    "frigirás": "frigir",
    "frigirão": "frigir",
    "frigiríamos": "frigir",
    "frigiríeis": "frigir",
    "frigis": "frigir",
    "frigisse": "frigir",
    "frigissem": "frigir",
    "frigisses": "frigir",
    "frigiste": "frigir",
    "frigistes": "frigir",
    "frigiu": "frigir",
    "frigorias": "frigoria",
    "frigorifica": "frigorificar",
    "frigorificada": "frigorificar",
    "frigorificadas": "frigorificar",
    "frigorificado": "frigorificar",
    "frigorificados": "frigorificar",
    "frigorificai": "frigorificar",
    "frigorificais": "frigorificar",
    "frigorificam": "frigorificar",
    "frigorificamo": "frigorificar",
    "frigorificamos": "frigorificar",
    "frigorificando": "frigorificar",
    "frigorificara": "frigorificar",
    "frigorificaram": "frigorificar",
    "frigorificaras": "frigorificar",
    "frigorificarde": "frigorificar",
    "frigorificardes": "frigorificar",
    "frigorificare": "frigorificar",
    "frigorificarei": "frigorificar",
    "frigorificareis": "frigorificar",
    "frigorificarem": "frigorificar",
    "frigorificaremos": "frigorificar",
    "frigorificares": "frigorificar",
    "frigorificaria": "frigorificar",
    "frigorificariam": "frigorificar",
    "frigorificarias": "frigorificar",
    "frigorificarmo": "frigorificar",
    "frigorificarmos": "frigorificar",
    "frigorificará": "frigorificar",
    "frigorificarás": "frigorificar",
    "frigorificarão": "frigorificar",
    "frigorificaríamos": "frigorificar",
    "frigorificaríeis": "frigorificar",
    "frigorificas": "frigorificar",
    "frigorificasse": "frigorificar",
    "frigorificassem": "frigorificar",
    "frigorificasses": "frigorificar",
    "frigorificaste": "frigorificar",
    "frigorificastes": "frigorificar",
    "frigorificava": "frigorificar",
    "frigorificavam": "frigorificar",
    "frigorificavas": "frigorificar",
    "frigorifico": "frigorificar",
    "frigorificou": "frigorificar",
    "frigorificá": "frigorificar",
    "frigorificámo": "frigorificar",
    "frigorificámos": "frigorificar",
    "frigorificáramo": "frigorificar",
    "frigorificáramos": "frigorificar",
    "frigorificárei": "frigorificar",
    "frigorificáreis": "frigorificar",
    "frigorificásseis": "frigorificar",
    "frigorificássemos": "frigorificar",
    "frigorificávamo": "frigorificar",
    "frigorificávamos": "frigorificar",
    "frigorificávei": "frigorificar",
    "frigorificáveis": "frigorificar",
    "frigorifique": "frigorificar",
    "frigorifiquei": "frigorificar",
    "frigorifiqueis": "frigorificar",
    "frigorifiquem": "frigorificar",
    "frigorifiquemo": "frigorificar",
    "frigorifiquemos": "frigorificar",
    "frigorifiques": "frigorificar",
    "frigorífera": "frigorífero",
    "frigoríferas": "frigorífero",
    "frigoríferos": "frigorífero",
    "frigorífica": "frigorífico",
    "frigoríficas": "frigorífico",
    "frigoríficações": "frigoríficação",
    "frigoríficos": "frigorífico",
    "frigorífuga": "frigorífugo",
    "frigorífugas": "frigorífugo",
    "frigorífugos": "frigorífugo",
    "frigoterapeutas": "frigoterapeuta",
    "frigoterapias": "frigoterapia",
    "frigoterapistas": "frigoterapista",
    "frigoterapêutica": "frigoterapêutico",
    "frigoterapêuticas": "frigoterapêutico",
    "frigoterapêuticos": "frigoterapêutico",
    "frigoterápica": "frigoterápico",
    "frigoterápicas": "frigoterápico",
    "frigoterápicos": "frigoterápico",
    "frigíamo": "frigir",
    "frigíamos": "frigir",
    "frigíei": "frigir",
    "frigíeis": "frigir",
    "frigífoba": "frigífobo",
    "frigífobas": "frigífobo",
    "frigífobos": "frigífobo",
    "frigífuga": "frigífugo",
    "frigífugas": "frigífugo",
    "frigífugos": "frigífugo",
    "frigíramo": "frigir",
    "frigíramos": "frigir",
    "frigírei": "frigir",
    "frigíreis": "frigir",
    "frigísseis": "frigir",
    "frigíssemos": "frigir",
    "frija": "frigir",
    "frijais": "frigir",
    "frijam": "frigir",
    "frijamo": "frigir",
    "frijamos": "frigir",
    "frijas": "frigir",
    "frijo": "frigir",
    "frima": "fremir",
    "frimais": "fremir",
    "frimam": "fremir",
    "frimamo": "fremir",
    "frimamos": "fremir",
    "frimas": "fremir",
    "frimo": "fremir",
    "frimária": "frimário",
    "frimárias": "frimário",
    "frimários": "frimário",
    "frinchas": "frincha",
    "frinchosa": "frinchoso",
    "frinchosas": "frinchoso",
    "frinchosos": "frinchoso",
    "fringilídea": "fringilídeo",
    "fringilídeas": "fringilídeo",
    "fringilídeos": "fringilídeo",
    "fringílidas": "fringílida",
    "frioleiras": "frioleira",
    "friolenta": "friolento",
    "friolentas": "friolento",
    "friolentos": "friolento",
    "friorenta": "friorento",
    "friorentas": "friorento",
    "friorentos": "friorento",
    "frios": "frio",
    "frisa": "frisar",
    "frisada": "frisar",
    "frisadas": "frisar",
    "frisado": "frisar",
    "frisadora": "frisador",
    "frisadoras": "frisador",
    "frisadores": "frisador",
    "frisados": "frisar",
    "frisagens": "frisagem",
    "frisai": "frisar",
    "frisais": "frisar",
    "frisam": "frisar",
    "frisamo": "frisar",
    "frisamos": "frisar",
    "frisando": "frisar",
    "frisantes": "frisante",
    "frisara": "frisar",
    "frisaram": "frisar",
    "frisaras": "frisar",
    "frisarde": "frisar",
    "frisardes": "frisar",
    "frisare": "frisar",
    "frisarei": "frisar",
    "frisareis": "frisar",
    "frisarem": "frisar",
    "frisaremos": "frisar",
    "frisares": "frisar",
    "frisaria": "frisar",
    "frisariam": "frisar",
    "frisarias": "frisar",
    "frisarmo": "frisar",
    "frisarmos": "frisar",
    "frisará": "frisar",
    "frisarás": "frisar",
    "frisarão": "frisar",
    "frisaríamos": "frisar",
    "frisaríeis": "frisar",
    "frisas": "frisar",
    "frisasse": "frisar",
    "frisassem": "frisar",
    "frisasses": "frisar",
    "frisaste": "frisar",
    "frisastes": "frisar",
    "frisava": "frisar",
    "frisavam": "frisar",
    "frisavas": "frisar",
    "frise": "frisar",
    "frisei": "frisar",
    "friseis": "frisar",
    "frisem": "frisar",
    "frisemo": "frisar",
    "frisemos": "frisar",
    "frises": "frisar",
    "friso": "frisar",
    "frisos": "friso",
    "frisou": "frisar",
    "frisá": "frisar",
    "frisámo": "frisar",
    "frisámos": "frisar",
    "frisáramo": "frisar",
    "frisáramos": "frisar",
    "frisárei": "frisar",
    "frisáreis": "frisar",
    "frisásseis": "frisar",
    "frisássemos": "frisar",
    "frisávamo": "frisar",
    "frisávamos": "frisar",
    "frisávei": "frisar",
    "frisáveis": "frisável",
    "frisões": "frisão",
    "frita": "frito",
    "fritada": "fritar",
    "fritadas": "fritar",
    "fritadeiras": "fritadeira",
    "fritado": "fritar",
    "fritados": "fritar",
    "fritai": "fritar",
    "fritais": "fritar",
    "fritalhadas": "fritalhada",
    "fritam": "fritar",
    "fritamo": "fritar",
    "fritamos": "fritar",
    "fritando": "fritar",
    "fritangadas": "fritangada",
    "fritara": "fritar",
    "fritaram": "fritar",
    "fritaras": "fritar",
    "fritarde": "fritar",
    "fritardes": "fritar",
    "fritare": "fritar",
    "fritarei": "fritar",
    "fritareis": "fritar",
    "fritarem": "fritar",
    "fritaremos": "fritar",
    "fritares": "fritar",
    "fritaria": "fritar",
    "fritariam": "fritar",
    "fritarias": "fritar",
    "fritarmo": "fritar",
    "fritarmos": "fritar",
    "fritará": "fritar",
    "fritarás": "fritar",
    "fritarão": "fritar",
    "fritaríamos": "fritar",
    "fritaríeis": "fritar",
    "fritas": "frito",
    "fritasse": "fritar",
    "fritassem": "fritar",
    "fritasses": "fritar",
    "fritaste": "fritar",
    "fritastes": "fritar",
    "fritava": "fritar",
    "fritavam": "fritar",
    "fritavas": "fritar",
    "frite": "fritar",
    "fritei": "fritar",
    "friteis": "fritar",
    "fritem": "fritar",
    "fritemo": "fritar",
    "fritemos": "fritar",
    "frites": "fritar",
    "fritilos": "fritilo",
    "frito": "fritar",
    "fritos": "frito",
    "fritou": "fritar",
    "frituras": "fritura",
    "fritá": "fritar",
    "fritámo": "fritar",
    "fritámos": "fritar",
    "fritáramo": "fritar",
    "fritáramos": "fritar",
    "fritárei": "fritar",
    "fritáreis": "fritar",
    "fritásseis": "fritar",
    "fritássemos": "fritar",
    "fritávamo": "fritar",
    "fritávamos": "fritar",
    "fritávei": "fritar",
    "fritáveis": "fritar",
    "frivolidades": "frivolidade",
    "friáveis": "friável",
    "friúras": "friúra",
    "froca": "frocar",
    "frocada": "frocar",
    "frocadas": "frocar",
    "frocado": "frocar",
    "frocados": "frocar",
    "frocaduras": "frocadura",
    "frocai": "frocar",
    "frocais": "frocar",
    "frocam": "frocar",
    "frocamo": "frocar",
    "frocamos": "frocar",
    "frocando": "frocar",
    "frocara": "frocar",
    "frocaram": "frocar",
    "frocaras": "frocar",
    "frocarde": "frocar",
    "frocardes": "frocar",
    "frocare": "frocar",
    "frocarei": "frocar",
    "frocareis": "frocar",
    "frocarem": "frocar",
    "frocaremos": "frocar",
    "frocares": "frocar",
    "frocaria": "frocar",
    "frocariam": "frocar",
    "frocarias": "frocar",
    "frocarmo": "frocar",
    "frocarmos": "frocar",
    "frocará": "frocar",
    "frocarás": "frocar",
    "frocarão": "frocar",
    "frocaríamos": "frocar",
    "frocaríeis": "frocar",
    "frocas": "frocar",
    "frocasse": "frocar",
    "frocassem": "frocar",
    "frocasses": "frocar",
    "frocaste": "frocar",
    "frocastes": "frocar",
    "frocava": "frocar",
    "frocavam": "frocar",
    "frocavas": "frocar",
    "froco": "frocar",
    "frocos": "froco",
    "frocou": "frocar",
    "frocá": "frocar",
    "frocámo": "frocar",
    "frocámos": "frocar",
    "frocáramo": "frocar",
    "frocáramos": "frocar",
    "frocárei": "frocar",
    "frocáreis": "frocar",
    "frocásseis": "frocar",
    "frocássemos": "frocar",
    "frocávamo": "frocar",
    "frocávamos": "frocar",
    "frocávei": "frocar",
    "frocáveis": "frocar",
    "froixa": "froixo",
    "froixada": "froixar",
    "froixadas": "froixar",
    "froixado": "froixar",
    "froixados": "froixar",
    "froixai": "froixar",
    "froixais": "froixar",
    "froixam": "froixar",
    "froixamo": "froixar",
    "froixamos": "froixar",
    "froixando": "froixar",
    "froixara": "froixar",
    "froixaram": "froixar",
    "froixaras": "froixar",
    "froixarde": "froixar",
    "froixardes": "froixar",
    "froixare": "froixar",
    "froixarei": "froixar",
    "froixareis": "froixar",
    "froixarem": "froixar",
    "froixaremos": "froixar",
    "froixares": "froixar",
    "froixaria": "froixar",
    "froixariam": "froixar",
    "froixarias": "froixar",
    "froixarmo": "froixar",
    "froixarmos": "froixar",
    "froixará": "froixar",
    "froixarás": "froixar",
    "froixarão": "froixar",
    "froixaríamos": "froixar",
    "froixaríeis": "froixar",
    "froixas": "froixo",
    "froixasse": "froixar",
    "froixassem": "froixar",
    "froixasses": "froixar",
    "froixaste": "froixar",
    "froixastes": "froixar",
    "froixava": "froixar",
    "froixavam": "froixar",
    "froixavas": "froixar",
    "froixe": "froixar",
    "froixei": "froixar",
    "froixeis": "froixel",
    "froixeleira": "froixeleiro",
    "froixeleiras": "froixeleiro",
    "froixeleiros": "froixeleiro",
    "froixem": "froixar",
    "froixemo": "froixar",
    "froixemos": "froixar",
    "froixes": "froixar",
    "froixezas": "froixeza",
    "froixidades": "froixidade",
    "froixidões": "froixidão",
    "froixo": "froixar",
    "froixos": "froixo",
    "froixou": "froixar",
    "froixá": "froixar",
    "froixámo": "froixar",
    "froixámos": "froixar",
    "froixáramo": "froixar",
    "froixáramos": "froixar",
    "froixárei": "froixar",
    "froixáreis": "froixar",
    "froixásseis": "froixar",
    "froixássemos": "froixar",
    "froixávamo": "froixar",
    "froixávamos": "froixar",
    "froixávei": "froixar",
    "froixáveis": "froixar",
    "froles": "frol",
    "frolhós": "frolhó",
    "frondas": "fronda",
    "frondeada": "frondear",
    "frondeadas": "frondear",
    "frondeado": "frondear",
    "frondeados": "frondear",
    "frondeai": "frondear",
    "frondeais": "frondear",
    "frondeamo": "frondear",
    "frondeamos": "frondear",
    "frondeando": "frondear",
    "frondeara": "frondear",
    "frondearam": "frondear",
    "frondearas": "frondear",
    "frondearde": "frondear",
    "frondeardes": "frondear",
    "frondeare": "frondear",
    "frondearei": "frondear",
    "frondeareis": "frondear",
    "frondearem": "frondear",
    "frondearemos": "frondear",
    "frondeares": "frondear",
    "frondearia": "frondear",
    "frondeariam": "frondear",
    "frondearias": "frondear",
    "frondearmo": "frondear",
    "frondearmos": "frondear",
    "frondeará": "frondear",
    "frondearás": "frondear",
    "frondearão": "frondear",
    "frondearíamos": "frondear",
    "frondearíeis": "frondear",
    "frondeasse": "frondear",
    "frondeassem": "frondear",
    "frondeasses": "frondear",
    "frondeaste": "frondear",
    "frondeastes": "frondear",
    "frondeava": "frondear",
    "frondeavam": "frondear",
    "frondeavas": "frondear",
    "frondeei": "frondear",
    "frondeeis": "frondear",
    "frondeemo": "frondear",
    "frondeemos": "frondear",
    "frondeia": "frondear",
    "frondeiam": "frondear",
    "frondeias": "frondear",
    "frondeie": "frondear",
    "frondeiem": "frondear",
    "frondeies": "frondear",
    "frondeio": "frondear",
    "frondeja": "frondejar",
    "frondejada": "frondejar",
    "frondejadas": "frondejar",
    "frondejado": "frondejar",
    "frondejados": "frondejar",
    "frondejai": "frondejar",
    "frondejais": "frondejar",
    "frondejam": "frondejar",
    "frondejamo": "frondejar",
    "frondejamos": "frondejar",
    "frondejando": "frondejar",
    "frondejantes": "frondejante",
    "frondejara": "frondejar",
    "frondejaram": "frondejar",
    "frondejaras": "frondejar",
    "frondejarde": "frondejar",
    "frondejardes": "frondejar",
    "frondejare": "frondejar",
    "frondejarei": "frondejar",
    "frondejareis": "frondejar",
    "frondejarem": "frondejar",
    "frondejaremos": "frondejar",
    "frondejares": "frondejar",
    "frondejaria": "frondejar",
    "frondejariam": "frondejar",
    "frondejarias": "frondejar",
    "frondejarmo": "frondejar",
    "frondejarmos": "frondejar",
    "frondejará": "frondejar",
    "frondejarás": "frondejar",
    "frondejarão": "frondejar",
    "frondejaríamos": "frondejar",
    "frondejaríeis": "frondejar",
    "frondejas": "frondejar",
    "frondejasse": "frondejar",
    "frondejassem": "frondejar",
    "frondejasses": "frondejar",
    "frondejaste": "frondejar",
    "frondejastes": "frondejar",
    "frondejava": "frondejar",
    "frondejavam": "frondejar",
    "frondejavas": "frondejar",
    "frondeje": "frondejar",
    "frondejei": "frondejar",
    "frondejeis": "frondejar",
    "frondejem": "frondejar",
    "frondejemo": "frondejar",
    "frondejemos": "frondejar",
    "frondejes": "frondejar",
    "frondejo": "frondejar",
    "frondejou": "frondejar",
    "frondejá": "frondejar",
    "frondejámo": "frondejar",
    "frondejámos": "frondejar",
    "frondejáramo": "frondejar",
    "frondejáramos": "frondejar",
    "frondejárei": "frondejar",
    "frondejáreis": "frondejar",
    "frondejásseis": "frondejar",
    "frondejássemos": "frondejar",
    "frondejávamo": "frondejar",
    "frondejávamos": "frondejar",
    "frondejávei": "frondejar",
    "frondejáveis": "frondejar",
    "frondentes": "frondente",
    "frondeou": "frondear",
    "frondes": "fronde",
    "frondesce": "frondescer",
    "frondescei": "frondescer",
    "frondesceis": "frondescer",
    "frondescem": "frondescer",
    "frondescemo": "frondescer",
    "frondescemos": "frondescer",
    "frondescendo": "frondescer",
    "frondescentes": "frondescente",
    "frondescera": "frondescer",
    "frondesceram": "frondescer",
    "frondesceras": "frondescer",
    "frondescerdes": "frondescer",
    "frondescerei": "frondescer",
    "frondescereis": "frondescer",
    "frondescerem": "frondescer",
    "frondesceremos": "frondescer",
    "frondesceres": "frondescer",
    "frondesceria": "frondescer",
    "frondesceriam": "frondescer",
    "frondescerias": "frondescer",
    "frondescermo": "frondescer",
    "frondescermos": "frondescer",
    "frondescerá": "frondescer",
    "frondescerás": "frondescer",
    "frondescerão": "frondescer",
    "frondesceríamos": "frondescer",
    "frondesceríeis": "frondescer",
    "frondesces": "frondescer",
    "frondescesse": "frondescer",
    "frondescessem": "frondescer",
    "frondescesses": "frondescer",
    "frondesceste": "frondescer",
    "frondescestes": "frondescer",
    "frondesceu": "frondescer",
    "frondesci": "frondescer",
    "frondescia": "frondescer",
    "frondesciam": "frondescer",
    "frondescias": "frondescer",
    "frondescida": "frondescer",
    "frondescidas": "frondescer",
    "frondescido": "frondescer",
    "frondescidos": "frondescer",
    "frondescências": "frondescência",
    "frondescêramo": "frondescer",
    "frondescêramos": "frondescer",
    "frondescêreis": "frondescer",
    "frondescêsseis": "frondescer",
    "frondescêssemos": "frondescer",
    "frondescíamo": "frondescer",
    "frondescíamos": "frondescer",
    "frondescíeis": "frondescer",
    "frondesça": "frondescer",
    "frondesçais": "frondescer",
    "frondesçam": "frondescer",
    "frondesçamo": "frondescer",
    "frondesçamos": "frondescer",
    "frondesças": "frondescer",
    "frondesço": "frondescer",
    "frondeá": "frondear",
    "frondeámo": "frondear",
    "frondeámos": "frondear",
    "frondeáramo": "frondear",
    "frondeáramos": "frondear",
    "frondeárei": "frondear",
    "frondeáreis": "frondear",
    "frondeásseis": "frondear",
    "frondeássemos": "frondear",
    "frondeávamo": "frondear",
    "frondeávamos": "frondear",
    "frondeávei": "frondear",
    "frondeáveis": "frondear",
    "frondosa": "frondoso",
    "frondosas": "frondoso",
    "frondosidades": "frondosidade",
    "frondosos": "frondoso",
    "frondícolas": "frondícola",
    "frondífera": "frondífero",
    "frondíferas": "frondífero",
    "frondíferos": "frondífero",
    "frondípara": "frondíparo",
    "frondíparas": "frondíparo",
    "frondíparos": "frondíparo",
    "fronha": "fronho",
    "fronhas": "fronho",
    "fronhazinha": "fronha",
    "fronhazinhas": "fronha",
    "fronhazita": "fronha",
    "fronhazitas": "fronha",
    "fronhos": "fronho",
    "frontaberta": "frontaberto",
    "frontabertas": "frontaberto",
    "frontabertos": "frontaberto",
    "frontadas": "frontada",
    "frontais": "frontal",
    "frontaleiras": "frontaleira",
    "frontalidades": "frontalidade",
    "frontarias": "frontaria",
    "fronteada": "frontear",
    "fronteadas": "frontear",
    "fronteado": "frontear",
    "fronteados": "frontear",
    "fronteai": "frontear",
    "fronteais": "frontear",
    "fronteamo": "frontear",
    "fronteamos": "frontear",
    "fronteando": "frontear",
    "fronteara": "frontear",
    "frontearam": "frontear",
    "frontearas": "frontear",
    "frontearde": "frontear",
    "fronteardes": "frontear",
    "fronteare": "frontear",
    "frontearei": "frontear",
    "fronteareis": "frontear",
    "frontearem": "frontear",
    "frontearemos": "frontear",
    "fronteares": "frontear",
    "frontearia": "frontear",
    "fronteariam": "frontear",
    "frontearias": "frontear",
    "frontearmo": "frontear",
    "frontearmos": "frontear",
    "fronteará": "frontear",
    "frontearás": "frontear",
    "frontearão": "frontear",
    "frontearíamos": "frontear",
    "frontearíeis": "frontear",
    "fronteasse": "frontear",
    "fronteassem": "frontear",
    "fronteasses": "frontear",
    "fronteaste": "frontear",
    "fronteastes": "frontear",
    "fronteava": "frontear",
    "fronteavam": "frontear",
    "fronteavas": "frontear",
    "fronteei": "frontear",
    "fronteeis": "frontear",
    "fronteemo": "frontear",
    "fronteemos": "frontear",
    "fronteia": "frontear",
    "fronteiam": "frontear",
    "fronteias": "frontear",
    "fronteie": "frontear",
    "fronteiem": "frontear",
    "fronteies": "frontear",
    "fronteio": "frontear",
    "fronteira": "fronteiro",
    "fronteirada": "fronteirar",
    "fronteiradas": "fronteirar",
    "fronteirado": "fronteirar",
    "fronteirados": "fronteirar",
    "fronteirai": "fronteirar",
    "fronteirais": "fronteirar",
    "fronteiram": "fronteirar",
    "fronteiramo": "fronteirar",
    "fronteiramos": "fronteirar",
    "fronteirando": "fronteirar",
    "fronteirara": "fronteirar",
    "fronteiraram": "fronteirar",
    "fronteiraras": "fronteirar",
    "fronteirarde": "fronteirar",
    "fronteirardes": "fronteirar",
    "fronteirare": "fronteirar",
    "fronteirarei": "fronteirar",
    "fronteirareis": "fronteirar",
    "fronteirarem": "fronteirar",
    "fronteiraremos": "fronteirar",
    "fronteirares": "fronteirar",
    "fronteiraria": "fronteirar",
    "fronteirariam": "fronteirar",
    "fronteirarias": "fronteirar",
    "fronteirarmo": "fronteirar",
    "fronteirarmos": "fronteirar",
    "fronteirará": "fronteirar",
    "fronteirarás": "fronteirar",
    "fronteirarão": "fronteirar",
    "fronteiraríamos": "fronteirar",
    "fronteiraríeis": "fronteirar",
    "fronteiras": "fronteiro",
    "fronteirasse": "fronteirar",
    "fronteirassem": "fronteirar",
    "fronteirasses": "fronteirar",
    "fronteiraste": "fronteirar",
    "fronteirastes": "fronteirar",
    "fronteirava": "fronteirar",
    "fronteiravam": "fronteirar",
    "fronteiravas": "fronteirar",
    "fronteire": "fronteirar",
    "fronteirei": "fronteirar",
    "fronteireis": "fronteirar",
    "fronteirem": "fronteirar",
    "fronteiremo": "fronteirar",
    "fronteiremos": "fronteirar",
    "fronteires": "fronteirar",
    "fronteiriça": "fronteiriço",
    "fronteiriças": "fronteiriço",
    "fronteiriços": "fronteiriço",
    "fronteiro": "fronteirar",
    "fronteiros": "fronteiro",
    "fronteirou": "fronteirar",
    "fronteirá": "fronteirar",
    "fronteirámo": "fronteirar",
    "fronteirámos": "fronteirar",
    "fronteiráramo": "fronteirar",
    "fronteiráramos": "fronteirar",
    "fronteirárei": "fronteirar",
    "fronteiráreis": "fronteirar",
    "fronteirásseis": "fronteirar",
    "fronteirássemos": "fronteirar",
    "fronteirávamo": "fronteirar",
    "fronteirávamos": "fronteirar",
    "fronteirávei": "fronteirar",
    "fronteiráveis": "fronteirar",
    "fronteou": "frontear",
    "frontes": "fronte",
    "fronteá": "frontear",
    "fronteámo": "frontear",
    "fronteámos": "frontear",
    "fronteáramo": "frontear",
    "fronteáramos": "frontear",
    "fronteárei": "frontear",
    "fronteáreis": "frontear",
    "fronteásseis": "frontear",
    "fronteássemos": "frontear",
    "fronteávamo": "frontear",
    "fronteávamos": "frontear",
    "fronteávei": "frontear",
    "fronteáveis": "frontear",
    "frontina": "frontino",
    "frontinas": "frontino",
    "frontinos": "frontino",
    "frontispiciais": "frontispicial",
    "frontispícios": "frontispício",
    "frontoparietais": "frontoparietal",
    "frontões": "frontão",
    "froque": "frocar",
    "froquei": "frocar",
    "froqueis": "frocar",
    "froquem": "frocar",
    "froquemo": "frocar",
    "froquemos": "frocar",
    "froques": "froque",
    "froscas": "frosca",
    "frotas": "frota",
    "frouvas": "frouva",
    "frouxa": "frouxo",
    "frouxada": "frouxar",
    "frouxadas": "frouxar",
    "frouxado": "frouxar",
    "frouxados": "frouxar",
    "frouxai": "frouxar",
    "frouxais": "frouxar",
    "frouxam": "frouxar",
    "frouxamo": "frouxar",
    "frouxamos": "frouxar",
    "frouxando": "frouxar",
    "frouxara": "frouxar",
    "frouxaram": "frouxar",
    "frouxaras": "frouxar",
    "frouxardes": "frouxar",
    "frouxarei": "frouxar",
    "frouxareis": "frouxar",
    "frouxarem": "frouxar",
    "frouxaremos": "frouxar",
    "frouxares": "frouxar",
    "frouxaria": "frouxar",
    "frouxariam": "frouxar",
    "frouxarias": "frouxar",
    "frouxarmo": "frouxar",
    "frouxarmos": "frouxar",
    "frouxará": "frouxar",
    "frouxarás": "frouxar",
    "frouxarão": "frouxar",
    "frouxaríamos": "frouxar",
    "frouxaríeis": "frouxar",
    "frouxas": "frouxo",
    "frouxasse": "frouxar",
    "frouxassem": "frouxar",
    "frouxasses": "frouxar",
    "frouxaste": "frouxar",
    "frouxastes": "frouxar",
    "frouxava": "frouxar",
    "frouxavam": "frouxar",
    "frouxavas": "frouxar",
    "frouxe": "frouxar",
    "frouxei": "frouxar",
    "frouxeis": "frouxel",
    "frouxelada": "frouxelado",
    "frouxeladas": "frouxelado",
    "frouxelados": "frouxelado",
    "frouxeleira": "frouxeleiro",
    "frouxeleiras": "frouxeleiro",
    "frouxeleiros": "frouxeleiro",
    "frouxem": "frouxar",
    "frouxemo": "frouxar",
    "frouxemos": "frouxar",
    "frouxes": "frouxar",
    "frouxezas": "frouxeza",
    "frouxidades": "frouxidade",
    "frouxidões": "frouxidão",
    "frouxo": "frouxar",
    "frouxos": "frouxo",
    "frouxou": "frouxar",
    "frouxámo": "frouxar",
    "frouxámos": "frouxar",
    "frouxáramo": "frouxar",
    "frouxáramos": "frouxar",
    "frouxáreis": "frouxar",
    "frouxásseis": "frouxar",
    "frouxássemos": "frouxar",
    "frouxávamo": "frouxar",
    "frouxávamos": "frouxar",
    "frouxáveis": "frouxar",
    "frouças": "frouça",
    "frua": "fruir",
    "fruais": "fruir",
    "fruam": "fruir",
    "fruamo": "fruir",
    "fruamos": "fruir",
    "fruas": "fruir",
    "frudora": "frudor",
    "frudoras": "frudor",
    "frudores": "frudor",
    "fruem": "fruir",
    "frufrus": "frufru",
    "frugais": "frugal",
    "frugalidades": "frugalidade",
    "frugalismos": "frugalismo",
    "frugivoristas": "frugivorista",
    "frugífera": "frugífero",
    "frugíferas": "frugífero",
    "frugíferos": "frugífero",
    "frugívora": "frugívoro",
    "frugívoras": "frugívoro",
    "frugívoros": "frugívoro",
    "frui": "fruir",
    "fruida": "fruido",
    "fruidas": "fruido",
    "fruidos": "fruido",
    "fruindo": "fruir",
    "fruirdes": "fruir",
    "fruirei": "fruir",
    "fruireis": "fruir",
    "fruiremos": "fruir",
    "fruiria": "fruir",
    "fruiriam": "fruir",
    "fruirias": "fruir",
    "fruirmo": "fruir",
    "fruirmos": "fruir",
    "fruirá": "fruir",
    "fruirás": "fruir",
    "fruirão": "fruir",
    "fruiríamos": "fruir",
    "fruiríeis": "fruir",
    "fruis": "fruir",
    "fruitas": "fruita",
    "fruiteiras": "fruiteira",
    "fruitiva": "fruitivo",
    "fruitivas": "fruitivo",
    "fruitivos": "fruitivo",
    "fruitácea": "fruitáceo",
    "fruitáceas": "fruitáceo",
    "fruitáceos": "fruitáceo",
    "fruiu": "fruir",
    "fruições": "fruição",
    "frumentais": "frumental",
    "frumentações": "frumentação",
    "frumentos": "frumento",
    "frumentosa": "frumentoso",
    "frumentosas": "frumentoso",
    "frumentosos": "frumentoso",
    "frumentária": "frumentário",
    "frumentárias": "frumentário",
    "frumentários": "frumentário",
    "frumentícia": "frumentício",
    "frumentícias": "frumentício",
    "frumentícios": "frumentício",
    "frunchos": "fruncho",
    "fruncos": "frunco",
    "fruo": "fruir",
    "frusta": "frusto",
    "frustas": "frusto",
    "frustes": "fruste",
    "frustos": "frusto",
    "frustra": "frustrar",
    "frustrada": "frustrar",
    "frustradas": "frustrar",
    "frustrado": "frustrar",
    "frustradora": "frustrador",
    "frustradoras": "frustrador",
    "frustradores": "frustrador",
    "frustrados": "frustrar",
    "frustrai": "frustrar",
    "frustrais": "frustrar",
    "frustram": "frustrar",
    "frustramo": "frustrar",
    "frustramos": "frustrar",
    "frustrando": "frustrar",
    "frustrantes": "frustrante",
    "frustrara": "frustrar",
    "frustraram": "frustrar",
    "frustraras": "frustrar",
    "frustrarde": "frustrar",
    "frustrardes": "frustrar",
    "frustrare": "frustrar",
    "frustrarei": "frustrar",
    "frustrareis": "frustrar",
    "frustrarem": "frustrar",
    "frustraremos": "frustrar",
    "frustrares": "frustrar",
    "frustraria": "frustrar",
    "frustrariam": "frustrar",
    "frustrarias": "frustrar",
    "frustrarmo": "frustrar",
    "frustrarmos": "frustrar",
    "frustrará": "frustrar",
    "frustrarás": "frustrar",
    "frustrarão": "frustrar",
    "frustraríamos": "frustrar",
    "frustraríeis": "frustrar",
    "frustras": "frustrar",
    "frustrasse": "frustrar",
    "frustrassem": "frustrar",
    "frustrasses": "frustrar",
    "frustraste": "frustrar",
    "frustrastes": "frustrar",
    "frustratória": "frustratório",
    "frustratórias": "frustratório",
    "frustratórios": "frustratório",
    "frustrava": "frustrar",
    "frustravam": "frustrar",
    "frustravas": "frustrar",
    "frustrações": "frustração",
    "frustre": "frustrar",
    "frustrei": "frustrar",
    "frustreis": "frustrar",
    "frustrem": "frustrar",
    "frustremo": "frustrar",
    "frustremos": "frustrar",
    "frustres": "frustre",
    "frustro": "frustrar",
    "frustrou": "frustrar",
    "frustrá": "frustrar",
    "frustrámo": "frustrar",
    "frustrámos": "frustrar",
    "frustráramo": "frustrar",
    "frustráramos": "frustrar",
    "frustrárei": "frustrar",
    "frustráreis": "frustrar",
    "frustrásseis": "frustrar",
    "frustrássemos": "frustrar",
    "frustrávamo": "frustrar",
    "frustrávamos": "frustrar",
    "frustrávei": "frustrar",
    "frustráveis": "frustrar",
    "frustrânea": "frustrâneo",
    "frustrâneas": "frustrâneo",
    "frustrâneos": "frustrâneo",
    "frustulada": "frustulado",
    "frustuladas": "frustulado",
    "frustulados": "frustulado",
    "fruta": "frutar",
    "frutada": "frutar",
    "frutadas": "frutar",
    "frutado": "frutar",
    "frutados": "frutar",
    "frutai": "frutar",
    "frutais": "frutar",
    "frutam": "frutar",
    "frutamo": "frutar",
    "frutamos": "frutar",
    "frutando": "frutar",
    "frutara": "frutar",
    "frutaram": "frutar",
    "frutaras": "frutar",
    "frutarde": "frutar",
    "frutardes": "frutar",
    "frutare": "frutar",
    "frutarei": "frutar",
    "frutareis": "frutar",
    "frutarem": "frutar",
    "frutaremos": "frutar",
    "frutares": "frutar",
    "frutaria": "frutar",
    "frutariam": "frutar",
    "frutarias": "frutar",
    "frutarmo": "frutar",
    "frutarmos": "frutar",
    "frutará": "frutar",
    "frutarás": "frutar",
    "frutarão": "frutar",
    "frutaríamos": "frutar",
    "frutaríeis": "frutar",
    "frutas": "frutar",
    "frutasse": "frutar",
    "frutassem": "frutar",
    "frutasses": "frutar",
    "frutaste": "frutar",
    "frutastes": "frutar",
    "frutava": "frutar",
    "frutavam": "frutar",
    "frutavas": "frutar",
    "frute": "frutar",
    "fruteada": "frutear",
    "fruteadas": "frutear",
    "fruteado": "frutear",
    "fruteados": "frutear",
    "fruteai": "frutear",
    "fruteais": "frutear",
    "fruteamo": "frutear",
    "fruteamos": "frutear",
    "fruteando": "frutear",
    "fruteara": "frutear",
    "frutearam": "frutear",
    "frutearas": "frutear",
    "fruteardes": "frutear",
    "frutearei": "frutear",
    "fruteareis": "frutear",
    "frutearem": "frutear",
    "frutearemos": "frutear",
    "fruteares": "frutear",
    "frutearia": "frutear",
    "fruteariam": "frutear",
    "frutearias": "frutear",
    "frutearmo": "frutear",
    "frutearmos": "frutear",
    "fruteará": "frutear",
    "frutearás": "frutear",
    "frutearão": "frutear",
    "frutearíamos": "frutear",
    "frutearíeis": "frutear",
    "fruteasse": "frutear",
    "fruteassem": "frutear",
    "fruteasses": "frutear",
    "fruteaste": "frutear",
    "fruteastes": "frutear",
    "fruteava": "frutear",
    "fruteavam": "frutear",
    "fruteavas": "frutear",
    "fruteei": "frutear",
    "fruteeis": "frutear",
    "fruteemo": "frutear",
    "fruteemos": "frutear",
    "frutei": "frutar",
    "fruteia": "frutear",
    "fruteiam": "frutear",
    "fruteias": "frutear",
    "fruteie": "frutear",
    "fruteiem": "frutear",
    "fruteies": "frutear",
    "fruteio": "frutear",
    "fruteira": "fruteiro",
    "fruteiras": "fruteiro",
    "fruteiros": "fruteiro",
    "fruteis": "frutar",
    "frutem": "frutar",
    "frutemo": "frutar",
    "frutemos": "frutar",
    "fruteou": "frutear",
    "frutes": "frutar",
    "frutesce": "frutescer",
    "frutescei": "frutescer",
    "frutesceis": "frutescer",
    "frutescem": "frutescer",
    "frutescemo": "frutescer",
    "frutescemos": "frutescer",
    "frutescendo": "frutescer",
    "frutescentes": "frutescente",
    "frutescera": "frutescer",
    "frutesceram": "frutescer",
    "frutesceras": "frutescer",
    "frutescerdes": "frutescer",
    "frutescerei": "frutescer",
    "frutescereis": "frutescer",
    "frutescerem": "frutescer",
    "frutesceremos": "frutescer",
    "frutesceres": "frutescer",
    "frutesceria": "frutescer",
    "frutesceriam": "frutescer",
    "frutescerias": "frutescer",
    "frutescermo": "frutescer",
    "frutescermos": "frutescer",
    "frutescerá": "frutescer",
    "frutescerás": "frutescer",
    "frutescerão": "frutescer",
    "frutesceríamos": "frutescer",
    "frutesceríeis": "frutescer",
    "frutesces": "frutescer",
    "frutescesse": "frutescer",
    "frutescessem": "frutescer",
    "frutescesses": "frutescer",
    "frutesceste": "frutescer",
    "frutescestes": "frutescer",
    "frutesceu": "frutescer",
    "frutesci": "frutescer",
    "frutescia": "frutescer",
    "frutesciam": "frutescer",
    "frutescias": "frutescer",
    "frutescida": "frutescer",
    "frutescidas": "frutescer",
    "frutescido": "frutescer",
    "frutescidos": "frutescer",
    "frutescências": "frutescência",
    "frutescêramo": "frutescer",
    "frutescêramos": "frutescer",
    "frutescêreis": "frutescer",
    "frutescêsseis": "frutescer",
    "frutescêssemos": "frutescer",
    "frutescíamo": "frutescer",
    "frutescíamos": "frutescer",
    "frutescíeis": "frutescer",
    "frutesça": "frutescer",
    "frutesçais": "frutescer",
    "frutesçam": "frutescer",
    "frutesçamo": "frutescer",
    "frutesçamos": "frutescer",
    "frutesças": "frutescer",
    "frutesço": "frutescer",
    "fruteámo": "frutear",
    "fruteámos": "frutear",
    "fruteáramo": "frutear",
    "fruteáramos": "frutear",
    "fruteáreis": "frutear",
    "fruteásseis": "frutear",
    "fruteássemos": "frutear",
    "fruteávamo": "frutear",
    "fruteávamos": "frutear",
    "fruteáveis": "frutear",
    "fruticetos": "fruticeto",
    "fruticulosa": "fruticuloso",
    "fruticulosas": "fruticuloso",
    "fruticulosos": "fruticuloso",
    "fruticultora": "fruticultor",
    "fruticultoras": "fruticultor",
    "fruticultores": "fruticultor",
    "fruticulturas": "fruticultura",
    "fruticética": "fruticético",
    "fruticéticas": "fruticético",
    "fruticéticos": "fruticético",
    "frutidores": "frutidor",
    "frutifica": "frutificar",
    "frutificada": "frutificar",
    "frutificadas": "frutificar",
    "frutificado": "frutificar",
    "frutificados": "frutificar",
    "frutificais": "frutificar",
    "frutificam": "frutificar",
    "frutificamo": "frutificar",
    "frutificamos": "frutificar",
    "frutificando": "frutificar",
    "frutificara": "frutificar",
    "frutificaram": "frutificar",
    "frutificaras": "frutificar",
    "frutificardes": "frutificar",
    "frutificarei": "frutificar",
    "frutificareis": "frutificar",
    "frutificarem": "frutificar",
    "frutificaremos": "frutificar",
    "frutificares": "frutificar",
    "frutificaria": "frutificar",
    "frutificariam": "frutificar",
    "frutificarias": "frutificar",
    "frutificarmo": "frutificar",
    "frutificarmos": "frutificar",
    "frutificará": "frutificar",
    "frutificarás": "frutificar",
    "frutificarão": "frutificar",
    "frutificaríamos": "frutificar",
    "frutificaríeis": "frutificar",
    "frutificas": "frutificar",
    "frutificasse": "frutificar",
    "frutificassem": "frutificar",
    "frutificasses": "frutificar",
    "frutificaste": "frutificar",
    "frutificastes": "frutificar",
    "frutificativa": "frutificativo",
    "frutificativas": "frutificativo",
    "frutificativos": "frutificativo",
    "frutificava": "frutificar",
    "frutificavam": "frutificar",
    "frutificavas": "frutificar",
    "frutificações": "frutificação",
    "frutifico": "frutificar",
    "frutificou": "frutificar",
    "frutificámo": "frutificar",
    "frutificámos": "frutificar",
    "frutificáramo": "frutificar",
    "frutificáramos": "frutificar",
    "frutificáreis": "frutificar",
    "frutificásseis": "frutificar",
    "frutificássemos": "frutificar",
    "frutificávamo": "frutificar",
    "frutificávamos": "frutificar",
    "frutificáveis": "frutificar",
    "frutifique": "frutificar",
    "frutifiquei": "frutificar",
    "frutifiqueis": "frutificar",
    "frutifiquem": "frutificar",
    "frutifiquemos": "frutificar",
    "frutifiques": "frutificar",
    "frutiformes": "frutiforme",
    "frutinha": "fruta",
    "frutinhas": "fruta",
    "frutita": "fruta",
    "frutitas": "fruta",
    "fruto": "frutar",
    "frutos": "fruto",
    "frutoses": "frutose",
    "frutou": "frutar",
    "frutuosa": "frutuoso",
    "frutuosas": "frutuoso",
    "frutuosos": "frutuoso",
    "frutuária": "frutuário",
    "frutuárias": "frutuário",
    "frutuários": "frutuário",
    "frutá": "frutar",
    "frutámo": "frutar",
    "frutámos": "frutar",
    "frutáramo": "frutar",
    "frutáramos": "frutar",
    "frutárei": "frutar",
    "frutáreis": "frutar",
    "frutásseis": "frutar",
    "frutássemos": "frutar",
    "frutávamo": "frutar",
    "frutávamos": "frutar",
    "frutávei": "frutar",
    "frutáveis": "frutar",
    "frutícolas": "frutícola",
    "frutífera": "frutífero",
    "frutíferas": "frutífero",
    "frutíferos": "frutífero",
    "frutígera": "frutígero",
    "frutígeras": "frutígero",
    "frutígeros": "frutígero",
    "frutívoa": "frutívoo",
    "frutívoas": "frutívoo",
    "frutívoos": "frutívoo",
    "fruí": "fruir",
    "fruía": "fruir",
    "fruíam": "fruir",
    "fruíamo": "fruir",
    "fruíamos": "fruir",
    "fruías": "fruir",
    "fruída": "fruir",
    "fruídas": "fruir",
    "fruído": "fruir",
    "fruídos": "fruir",
    "fruíeis": "fruir",
    "fruímo": "fruir",
    "fruímos": "fruir",
    "fruíra": "fruir",
    "fruíram": "fruir",
    "fruíramo": "fruir",
    "fruíramos": "fruir",
    "fruíras": "fruir",
    "fruíreis": "fruir",
    "fruírem": "fruir",
    "fruíres": "fruir",
    "fruís": "fruir",
    "fruísse": "fruir",
    "fruísseis": "fruir",
    "fruíssem": "fruir",
    "fruíssemos": "fruir",
    "fruísses": "fruir",
    "fruíste": "fruir",
    "fruístes": "fruir",
    "frágeis": "frágil",
    "fráguas": "frágua",
    "frásica": "frásico",
    "frásicas": "frásico",
    "frásicos": "frásico",
    "frâmeas": "frâmea",
    "frâncias": "frância",
    "frâncica": "frâncico",
    "frâncicas": "frâncico",
    "frâncicos": "frâncico",
    "frângula": "frângulo",
    "frângulas": "frângulo",
    "frângulos": "frângulo",
    "frémitos": "frémito",
    "frénica": "frénico",
    "frénicas": "frénico",
    "frénicos": "frénico",
    "frígia": "frígio",
    "frígias": "frígio",
    "frígica": "frígico",
    "frígicas": "frígico",
    "frígicos": "frígico",
    "frígida": "frígido",
    "frígidas": "frígido",
    "frígidos": "frígido",
    "frígios": "frígio",
    "frísia": "frísio",
    "frísias": "frísio",
    "frísica": "frísico",
    "frísicas": "frísico",
    "frísicos": "frísico",
    "frísios": "frísio",
    "frívola": "frívolo",
    "frívolas": "frívolo",
    "frívolos": "frívolo",
    "frôndea": "frôndeo",
    "frôndeas": "frôndeo",
    "frôndeos": "frôndeo",
    "frôndulas": "frôndula",
    "frúnculos": "frúnculo",
    "frústulas": "frústula",
    "frútices": "frútice",
    "ftalatos": "ftalato",
    "ftalática": "ftalático",
    "ftaláticas": "ftalático",
    "ftaláticos": "ftalático",
    "ftanites": "ftanite",
    "ftanitos": "ftanito",
    "ftanítica": "ftanítico",
    "ftaníticas": "ftanítico",
    "ftaníticos": "ftanítico",
    "ftiríaca": "ftiríaco",
    "ftiríacas": "ftiríaco",
    "ftiríacos": "ftiríaco",
    "ftiríases": "ftiríase",
    "ftisiúrias": "ftisiúria",
    "ftisiúrica": "ftisiúrico",
    "ftisiúricas": "ftisiúrico",
    "ftisiúricos": "ftisiúrico",
    "ftálica": "ftálico",
    "ftálicas": "ftálico",
    "ftálicos": "ftálico",
    "ftártica": "ftártico",
    "ftárticas": "ftártico",
    "ftárticos": "ftártico",
    "fubas": "fuba",
    "fubecas": "fubeca",
    "fubás": "fubá",
    "fucamenas": "fucamena",
    "fucenses": "fucense",
    "fuchsinas": "fuchsina",
    "fuciformes": "fuciforme",
    "fucos": "fuco",
    "fucácea": "fucáceo",
    "fucáceas": "fucáceo",
    "fucáceos": "fucáceo",
    "fucícolas": "fucícola",
    "fucóides": "fucóide",
    "fueiradas": "fueirada",
    "fueiros": "fueiro",
    "fuetas": "fueta",
    "fufas": "fufa",
    "fufinha": "fufa",
    "fufinhas": "fufa",
    "fufita": "fufa",
    "fufitas": "fufa",
    "fugacidades": "fugacidade",
    "fugada": "fugado",
    "fugadas": "fugado",
    "fugados": "fugado",
    "fugalaças": "fugalaça",
    "fugas": "fuga",
    "fugatos": "fugato",
    "fugazes": "fugaz",
    "fugentes": "fugente",
    "fugi": "fugir",
    "fugia": "fugir",
    "fugiam": "fugir",
    "fugias": "fugir",
    "fugida": "fugir",
    "fugidas": "fugir",
    "fugidelas": "fugidela",
    "fugidia": "fugidio",
    "fugidias": "fugidio",
    "fugidios": "fugidio",
    "fugidiça": "fugidiço",
    "fugidiças": "fugidiço",
    "fugidiços": "fugidiço",
    "fugido": "fugir",
    "fugidos": "fugir",
    "fugientes": "fugiente",
    "fugimo": "fugir",
    "fugimos": "fugir",
    "fugindo": "fugir",
    "fugintes": "fuginte",
    "fugiona": "fugião",
    "fugionas": "fugião",
    "fugira": "fugir",
    "fugiram": "fugir",
    "fugiras": "fugir",
    "fugirdes": "fugir",
    "fugirei": "fugir",
    "fugireis": "fugir",
    "fugirem": "fugir",
    "fugiremos": "fugir",
    "fugires": "fugir",
    "fugiria": "fugir",
    "fugiriam": "fugir",
    "fugirias": "fugir",
    "fugirmo": "fugir",
    "fugirmos": "fugir",
    "fugirá": "fugir",
    "fugirás": "fugir",
    "fugirão": "fugir",
    "fugiríamos": "fugir",
    "fugiríeis": "fugir",
    "fugis": "fugir",
    "fugisse": "fugir",
    "fugissem": "fugir",
    "fugisses": "fugir",
    "fugiste": "fugir",
    "fugistes": "fugir",
    "fugitiva": "fugitivo",
    "fugitivas": "fugitivo",
    "fugitivos": "fugitivo",
    "fugiu": "fugir",
    "fugiões": "fugião",
    "fugona": "fugão",
    "fugonas": "fugão",
    "fugueira": "fugueiro",
    "fugueiras": "fugueiro",
    "fugueiros": "fugueiro",
    "fugíamo": "fugir",
    "fugíamos": "fugir",
    "fugíeis": "fugir",
    "fugíramo": "fugir",
    "fugíramos": "fugir",
    "fugíreis": "fugir",
    "fugísseis": "fugir",
    "fugíssemos": "fugir",
    "fugões": "fugão",
    "fui": "ser",
    "fuinhas": "fuinha",
    "fuinhos": "fuinho",
    "fuja": "fugir",
    "fujais": "fugir",
    "fujam": "fugir",
    "fujamo": "fugir",
    "fujamos": "fugir",
    "fujas": "fugir",
    "fujo": "fugir",
    "fujona": "fujão",
    "fujonas": "fujão",
    "fujões": "fujão",
    "fula": "fulo",
    "fulames": "fulame",
    "fulana": "fulano",
    "fulanas": "fulano",
    "fulanos": "fulano",
    "fulas": "fulo",
    "fulcrada": "fulcrado",
    "fulcradas": "fulcrado",
    "fulcrados": "fulcrado",
    "fulcrais": "fulcral",
    "fulcros": "fulcro",
    "fuldas": "fulda",
    "fulecas": "fuleca",
    "fulecras": "fulecra",
    "fulge": "fulgir",
    "fulgem": "fulgir",
    "fulgenteada": "fulgentear",
    "fulgenteadas": "fulgentear",
    "fulgenteado": "fulgentear",
    "fulgenteados": "fulgentear",
    "fulgenteai": "fulgentear",
    "fulgenteais": "fulgentear",
    "fulgenteamo": "fulgentear",
    "fulgenteamos": "fulgentear",
    "fulgenteando": "fulgentear",
    "fulgenteara": "fulgentear",
    "fulgentearam": "fulgentear",
    "fulgentearas": "fulgentear",
    "fulgentearde": "fulgentear",
    "fulgenteardes": "fulgentear",
    "fulgenteare": "fulgentear",
    "fulgentearei": "fulgentear",
    "fulgenteareis": "fulgentear",
    "fulgentearem": "fulgentear",
    "fulgentearemos": "fulgentear",
    "fulgenteares": "fulgentear",
    "fulgentearia": "fulgentear",
    "fulgenteariam": "fulgentear",
    "fulgentearias": "fulgentear",
    "fulgentearmo": "fulgentear",
    "fulgentearmos": "fulgentear",
    "fulgenteará": "fulgentear",
    "fulgentearás": "fulgentear",
    "fulgentearão": "fulgentear",
    "fulgentearíamos": "fulgentear",
    "fulgentearíeis": "fulgentear",
    "fulgenteasse": "fulgentear",
    "fulgenteassem": "fulgentear",
    "fulgenteasses": "fulgentear",
    "fulgenteaste": "fulgentear",
    "fulgenteastes": "fulgentear",
    "fulgenteava": "fulgentear",
    "fulgenteavam": "fulgentear",
    "fulgenteavas": "fulgentear",
    "fulgenteei": "fulgentear",
    "fulgenteeis": "fulgentear",
    "fulgenteemo": "fulgentear",
    "fulgenteemos": "fulgentear",
    "fulgenteia": "fulgentear",
    "fulgenteiam": "fulgentear",
    "fulgenteias": "fulgentear",
    "fulgenteie": "fulgentear",
    "fulgenteiem": "fulgentear",
    "fulgenteies": "fulgentear",
    "fulgenteio": "fulgentear",
    "fulgenteou": "fulgentear",
    "fulgentes": "fulgente",
    "fulgenteá": "fulgentear",
    "fulgenteámo": "fulgentear",
    "fulgenteámos": "fulgentear",
    "fulgenteáramo": "fulgentear",
    "fulgenteáramos": "fulgentear",
    "fulgenteárei": "fulgentear",
    "fulgenteáreis": "fulgentear",
    "fulgenteásseis": "fulgentear",
    "fulgenteássemos": "fulgentear",
    "fulgenteávamo": "fulgentear",
    "fulgenteávamos": "fulgentear",
    "fulgenteávei": "fulgentear",
    "fulgenteáveis": "fulgentear",
    "fulges": "fulgir",
    "fulgi": "fulgir",
    "fulgia": "fulgir",
    "fulgiam": "fulgir",
    "fulgias": "fulgir",
    "fulgida": "fulgir",
    "fulgidas": "fulgir",
    "fulgido": "fulgir",
    "fulgidos": "fulgir",
    "fulgimo": "fulgir",
    "fulgimos": "fulgir",
    "fulgindo": "fulgir",
    "fulgira": "fulgir",
    "fulgiram": "fulgir",
    "fulgiras": "fulgir",
    "fulgirdes": "fulgir",
    "fulgirei": "fulgir",
    "fulgireis": "fulgir",
    "fulgirem": "fulgir",
    "fulgiremos": "fulgir",
    "fulgires": "fulgir",
    "fulgiria": "fulgir",
    "fulgiriam": "fulgir",
    "fulgirias": "fulgir",
    "fulgirmo": "fulgir",
    "fulgirmos": "fulgir",
    "fulgirá": "fulgir",
    "fulgirás": "fulgir",
    "fulgirão": "fulgir",
    "fulgiríamos": "fulgir",
    "fulgiríeis": "fulgir",
    "fulgis": "fulgir",
    "fulgisse": "fulgir",
    "fulgissem": "fulgir",
    "fulgisses": "fulgir",
    "fulgiste": "fulgir",
    "fulgistes": "fulgir",
    "fulgiu": "fulgir",
    "fulgores": "fulgor",
    "fulgorídea": "fulgorídeo",
    "fulgorídeas": "fulgorídeo",
    "fulgorídeos": "fulgorídeo",
    "fulgura": "fulgurar",
    "fulgurada": "fulgurar",
    "fulguradas": "fulgurar",
    "fulgurado": "fulgurar",
    "fulgurados": "fulgurar",
    "fulgurai": "fulgurar",
    "fulgurais": "fulgurar",
    "fulguram": "fulgurar",
    "fulguramo": "fulgurar",
    "fulguramos": "fulgurar",
    "fulgurando": "fulgurar",
    "fulgurantes": "fulgurante",
    "fulgurara": "fulgurar",
    "fulguraram": "fulgurar",
    "fulguraras": "fulgurar",
    "fulgurardes": "fulgurar",
    "fulgurarei": "fulgurar",
    "fulgurareis": "fulgurar",
    "fulgurarem": "fulgurar",
    "fulguraremos": "fulgurar",
    "fulgurares": "fulgurar",
    "fulguraria": "fulgurar",
    "fulgurariam": "fulgurar",
    "fulgurarias": "fulgurar",
    "fulgurarmo": "fulgurar",
    "fulgurarmos": "fulgurar",
    "fulgurará": "fulgurar",
    "fulgurarás": "fulgurar",
    "fulgurarão": "fulgurar",
    "fulguraríamos": "fulgurar",
    "fulguraríeis": "fulgurar",
    "fulguras": "fulgurar",
    "fulgurasse": "fulgurar",
    "fulgurassem": "fulgurar",
    "fulgurasses": "fulgurar",
    "fulguraste": "fulgurar",
    "fulgurastes": "fulgurar",
    "fulgurava": "fulgurar",
    "fulguravam": "fulgurar",
    "fulguravas": "fulgurar",
    "fulgurações": "fulguração",
    "fulgure": "fulgurar",
    "fulgurei": "fulgurar",
    "fulgureis": "fulgurar",
    "fulgurem": "fulgurar",
    "fulguremo": "fulgurar",
    "fulguremos": "fulgurar",
    "fulgures": "fulgurar",
    "fulguritos": "fulgurito",
    "fulguro": "fulgurar",
    "fulgurosa": "fulguroso",
    "fulgurosas": "fulguroso",
    "fulgurosos": "fulguroso",
    "fulgurou": "fulgurar",
    "fulgurámo": "fulgurar",
    "fulgurámos": "fulgurar",
    "fulguráramo": "fulgurar",
    "fulguráramos": "fulgurar",
    "fulguráreis": "fulgurar",
    "fulgurásseis": "fulgurar",
    "fulgurássemos": "fulgurar",
    "fulgurávamo": "fulgurar",
    "fulgurávamos": "fulgurar",
    "fulguráveis": "fulgurar",
    "fulgurâncias": "fulgurância",
    "fulgências": "fulgência",
    "fulgíamo": "fulgir",
    "fulgíamos": "fulgir",
    "fulgíeis": "fulgir",
    "fulgíramo": "fulgir",
    "fulgíramos": "fulgir",
    "fulgíreis": "fulgir",
    "fulgísseis": "fulgir",
    "fulgíssemos": "fulgir",
    "fulgóridas": "fulgórida",
    "fulharias": "fulharia",
    "fulheira": "fulheiro",
    "fulheiras": "fulheiro",
    "fulheiros": "fulheiro",
    "fulicária": "fulicário",
    "fulicárias": "fulicário",
    "fulicários": "fulicário",
    "fuligens": "fuligem",
    "fuliginosa": "fuliginoso",
    "fuliginosas": "fuliginoso",
    "fuliginosidades": "fuliginosidade",
    "fuliginosos": "fuliginoso",
    "fulistas": "fulista",
    "fulja": "fulgir",
    "fuljais": "fulgir",
    "fuljam": "fulgir",
    "fuljamo": "fulgir",
    "fuljamos": "fulgir",
    "fuljas": "fulgir",
    "fuljo": "fulgir",
    "fulmialgodões": "fulmialgodão",
    "fulmilenhos": "fulmilenho",
    "fulmina": "fulminar",
    "fulminada": "fulminar",
    "fulminadas": "fulminar",
    "fulminado": "fulminar",
    "fulminadora": "fulminador",
    "fulminadoras": "fulminador",
    "fulminadores": "fulminador",
    "fulminados": "fulminar",
    "fulminai": "fulminar",
    "fulminais": "fulminar",
    "fulminam": "fulminar",
    "fulminamo": "fulminar",
    "fulminamos": "fulminar",
    "fulminando": "fulminar",
    "fulminantes": "fulminante",
    "fulminara": "fulminar",
    "fulminaram": "fulminar",
    "fulminaras": "fulminar",
    "fulminarde": "fulminar",
    "fulminardes": "fulminar",
    "fulminare": "fulminar",
    "fulminarei": "fulminar",
    "fulminareis": "fulminar",
    "fulminarem": "fulminar",
    "fulminaremos": "fulminar",
    "fulminares": "fulminar",
    "fulminaria": "fulminar",
    "fulminariam": "fulminar",
    "fulminarias": "fulminar",
    "fulminarmo": "fulminar",
    "fulminarmos": "fulminar",
    "fulminará": "fulminar",
    "fulminarás": "fulminar",
    "fulminarão": "fulminar",
    "fulminaríamos": "fulminar",
    "fulminaríeis": "fulminar",
    "fulminas": "fulminar",
    "fulminasse": "fulminar",
    "fulminassem": "fulminar",
    "fulminasses": "fulminar",
    "fulminaste": "fulminar",
    "fulminastes": "fulminar",
    "fulminatos": "fulminato",
    "fulminatória": "fulminatório",
    "fulminatórias": "fulminatório",
    "fulminatórios": "fulminatório",
    "fulminava": "fulminar",
    "fulminavam": "fulminar",
    "fulminavas": "fulminar",
    "fulminações": "fulminação",
    "fulmine": "fulminar",
    "fulminei": "fulminar",
    "fulmineis": "fulminar",
    "fulminem": "fulminar",
    "fulminemo": "fulminar",
    "fulminemos": "fulminar",
    "fulmines": "fulminar",
    "fulminivoma": "fulminivomo",
    "fulminivomas": "fulminivomo",
    "fulminivomos": "fulminivomo",
    "fulmino": "fulminar",
    "fulminosa": "fulminoso",
    "fulminosas": "fulminoso",
    "fulminosos": "fulminoso",
    "fulminou": "fulminar",
    "fulminá": "fulminar",
    "fulminámo": "fulminar",
    "fulminámos": "fulminar",
    "fulmináramo": "fulminar",
    "fulmináramos": "fulminar",
    "fulminárei": "fulminar",
    "fulmináreis": "fulminar",
    "fulminásseis": "fulminar",
    "fulminássemos": "fulminar",
    "fulminávamo": "fulminar",
    "fulminávamos": "fulminar",
    "fulminávei": "fulminar",
    "fulmináveis": "fulminar",
    "fulminífera": "fulminífero",
    "fulminíferas": "fulminífero",
    "fulminíferos": "fulminífero",
    "fulminígera": "fulminígero",
    "fulminígeras": "fulminígero",
    "fulminígeros": "fulminígero",
    "fulmínea": "fulmíneo",
    "fulmíneas": "fulmíneo",
    "fulmíneos": "fulmíneo",
    "fulos": "fulo",
    "fulosas": "fulosa",
    "fulva": "fulvo",
    "fulvas": "fulvo",
    "fulverina": "fulverino",
    "fulverinas": "fulverino",
    "fulverinos": "fulverino",
    "fulvescentes": "fulvescente",
    "fulvescências": "fulvescência",
    "fulvipenes": "fulvipene",
    "fulvirrostra": "fulvirrostro",
    "fulvirrostras": "fulvirrostro",
    "fulvirrostros": "fulvirrostro",
    "fulvos": "fulvo",
    "fulvípedes": "fulvípede",
    "fulígina": "fulígino",
    "fulíginas": "fulígino",
    "fulíginos": "fulígino",
    "fulões": "fulão",
    "fuma": "fumar",
    "fumaceiras": "fumaceira",
    "fumacinha": "fumaça",
    "fumacinhas": "fumaça",
    "fumacita": "fumaça",
    "fumacitas": "fumaça",
    "fumada": "fumar",
    "fumadas": "fumar",
    "fumadeira": "fumadeiro",
    "fumadeiras": "fumadeiro",
    "fumadeiros": "fumadeiro",
    "fumado": "fumar",
    "fumadora": "fumador",
    "fumadoras": "fumador",
    "fumadores": "fumador",
    "fumados": "fumar",
    "fumagens": "fumagem",
    "fumaginas": "fumagina",
    "fumai": "fumar",
    "fumais": "fumar",
    "fumam": "fumar",
    "fumamo": "fumar",
    "fumamos": "fumar",
    "fumando": "fumar",
    "fumantes": "fumante",
    "fumara": "fumarar",
    "fumarada": "fumarar",
    "fumaradas": "fumarar",
    "fumarado": "fumarar",
    "fumarados": "fumarar",
    "fumarai": "fumarar",
    "fumarais": "fumarar",
    "fumaram": "fumarar",
    "fumaramo": "fumarar",
    "fumaramos": "fumarar",
    "fumarando": "fumarar",
    "fumarara": "fumarar",
    "fumararam": "fumarar",
    "fumararas": "fumarar",
    "fumarardes": "fumarar",
    "fumararei": "fumarar",
    "fumarareis": "fumarar",
    "fumararem": "fumarar",
    "fumararemos": "fumarar",
    "fumarares": "fumarar",
    "fumararia": "fumarar",
    "fumarariam": "fumarar",
    "fumararias": "fumarar",
    "fumararmo": "fumarar",
    "fumararmos": "fumarar",
    "fumarará": "fumarar",
    "fumararás": "fumarar",
    "fumararão": "fumarar",
    "fumararíamos": "fumarar",
    "fumararíeis": "fumarar",
    "fumaras": "fumarar",
    "fumarasse": "fumarar",
    "fumarassem": "fumarar",
    "fumarasses": "fumarar",
    "fumaraste": "fumarar",
    "fumarastes": "fumarar",
    "fumarava": "fumarar",
    "fumaravam": "fumarar",
    "fumaravas": "fumarar",
    "fumaraças": "fumaraça",
    "fumarde": "fumar",
    "fumardes": "fumar",
    "fumare": "fumarar",
    "fumaredas": "fumareda",
    "fumarei": "fumarar",
    "fumareis": "fumarar",
    "fumarem": "fumarar",
    "fumaremo": "fumarar",
    "fumaremos": "fumarar",
    "fumarenta": "fumarento",
    "fumarentas": "fumarento",
    "fumarentos": "fumarento",
    "fumares": "fumarar",
    "fumaria": "fumar",
    "fumariam": "fumar",
    "fumarias": "fumaria",
    "fumaricácea": "fumaricáceo",
    "fumaricáceas": "fumaricáceo",
    "fumaricáceos": "fumaricáceo",
    "fumariáceas": "fumariácea",
    "fumarmo": "fumar",
    "fumarmos": "fumar",
    "fumaro": "fumarar",
    "fumarolas": "fumarola",
    "fumarou": "fumarar",
    "fumará": "fumar",
    "fumarámo": "fumarar",
    "fumarámos": "fumarar",
    "fumaráramo": "fumarar",
    "fumaráramos": "fumarar",
    "fumaráreis": "fumarar",
    "fumarás": "fumar",
    "fumarásseis": "fumarar",
    "fumarássemos": "fumarar",
    "fumarávamo": "fumarar",
    "fumarávamos": "fumarar",
    "fumaráveis": "fumarar",
    "fumarão": "fumar",
    "fumaríamos": "fumar",
    "fumaríeis": "fumar",
    "fumas": "fumar",
    "fumasse": "fumar",
    "fumassem": "fumar",
    "fumasses": "fumar",
    "fumaste": "fumar",
    "fumastes": "fumar",
    "fumatória": "fumatório",
    "fumatórias": "fumatório",
    "fumatórios": "fumatório",
    "fumava": "fumar",
    "fumavam": "fumar",
    "fumavas": "fumar",
    "fumaçadas": "fumaçada",
    "fumaças": "fumaça",
    "fumaçenta": "fumaçento",
    "fumaçentas": "fumaçento",
    "fumaçentos": "fumaçento",
    "fume": "fumar",
    "fumeada": "fumear",
    "fumeadas": "fumear",
    "fumeado": "fumear",
    "fumeados": "fumear",
    "fumeai": "fumear",
    "fumeais": "fumear",
    "fumeamo": "fumear",
    "fumeamos": "fumear",
    "fumeando": "fumear",
    "fumeantes": "fumeante",
    "fumeara": "fumear",
    "fumearam": "fumear",
    "fumearas": "fumear",
    "fumeardes": "fumear",
    "fumearei": "fumear",
    "fumeareis": "fumear",
    "fumearem": "fumear",
    "fumearemos": "fumear",
    "fumeares": "fumear",
    "fumearia": "fumear",
    "fumeariam": "fumear",
    "fumearias": "fumear",
    "fumearmo": "fumear",
    "fumearmos": "fumear",
    "fumeará": "fumear",
    "fumearás": "fumear",
    "fumearão": "fumear",
    "fumearíamos": "fumear",
    "fumearíeis": "fumear",
    "fumeasse": "fumear",
    "fumeassem": "fumear",
    "fumeasses": "fumear",
    "fumeaste": "fumear",
    "fumeastes": "fumear",
    "fumeava": "fumear",
    "fumeavam": "fumear",
    "fumeavas": "fumear",
    "fumeei": "fumear",
    "fumeeis": "fumear",
    "fumeemo": "fumear",
    "fumeemos": "fumear",
    "fumega": "fumegar",
    "fumegada": "fumegar",
    "fumegadas": "fumegar",
    "fumegado": "fumegar",
    "fumegados": "fumegar",
    "fumegai": "fumegar",
    "fumegais": "fumegar",
    "fumegam": "fumegar",
    "fumegamo": "fumegar",
    "fumegamos": "fumegar",
    "fumegando": "fumegar",
    "fumegantes": "fumegante",
    "fumegara": "fumegar",
    "fumegaram": "fumegar",
    "fumegaras": "fumegar",
    "fumegardes": "fumegar",
    "fumegarei": "fumegar",
    "fumegareis": "fumegar",
    "fumegarem": "fumegar",
    "fumegaremos": "fumegar",
    "fumegares": "fumegar",
    "fumegaria": "fumegar",
    "fumegariam": "fumegar",
    "fumegarias": "fumegar",
    "fumegarmo": "fumegar",
    "fumegarmos": "fumegar",
    "fumegará": "fumegar",
    "fumegarás": "fumegar",
    "fumegarão": "fumegar",
    "fumegaríamos": "fumegar",
    "fumegaríeis": "fumegar",
    "fumegas": "fumegar",
    "fumegasse": "fumegar",
    "fumegassem": "fumegar",
    "fumegasses": "fumegar",
    "fumegaste": "fumegar",
    "fumegastes": "fumegar",
    "fumegava": "fumegar",
    "fumegavam": "fumegar",
    "fumegavas": "fumegar",
    "fumego": "fumegar",
    "fumegou": "fumegar",
    "fumegue": "fumegar",
    "fumeguei": "fumegar",
    "fumegueis": "fumegar",
    "fumeguem": "fumegar",
    "fumeguemo": "fumegar",
    "fumeguemos": "fumegar",
    "fumegues": "fumegar",
    "fumegámo": "fumegar",
    "fumegámos": "fumegar",
    "fumegáramo": "fumegar",
    "fumegáramos": "fumegar",
    "fumegáreis": "fumegar",
    "fumegásseis": "fumegar",
    "fumegássemos": "fumegar",
    "fumegávamo": "fumegar",
    "fumegávamos": "fumegar",
    "fumegáveis": "fumegar",
    "fumei": "fumar",
    "fumeia": "fumear",
    "fumeiam": "fumear",
    "fumeias": "fumear",
    "fumeie": "fumear",
    "fumeiem": "fumear",
    "fumeies": "fumear",
    "fumeio": "fumear",
    "fumeiros": "fumeiro",
    "fumeis": "fumar",
    "fumem": "fumar",
    "fumemo": "fumar",
    "fumemos": "fumar",
    "fumeou": "fumear",
    "fumes": "fumar",
    "fumeámo": "fumear",
    "fumeámos": "fumear",
    "fumeáramo": "fumear",
    "fumeáramos": "fumear",
    "fumeáreis": "fumear",
    "fumeásseis": "fumear",
    "fumeássemos": "fumear",
    "fumeávamo": "fumear",
    "fumeávamos": "fumear",
    "fumeáveis": "fumear",
    "fumiflamantes": "fumiflamante",
    "fumifóbica": "fumifóbico",
    "fumifóbicas": "fumifóbico",
    "fumifóbicos": "fumifóbico",
    "fumiga": "fumigar",
    "fumigada": "fumigar",
    "fumigadas": "fumigar",
    "fumigado": "fumigar",
    "fumigadora": "fumigador",
    "fumigadoras": "fumigador",
    "fumigadores": "fumigador",
    "fumigados": "fumigar",
    "fumigai": "fumigar",
    "fumigais": "fumigar",
    "fumigam": "fumigar",
    "fumigamo": "fumigar",
    "fumigamos": "fumigar",
    "fumigando": "fumigar",
    "fumigara": "fumigar",
    "fumigaram": "fumigar",
    "fumigaras": "fumigar",
    "fumigarde": "fumigar",
    "fumigardes": "fumigar",
    "fumigare": "fumigar",
    "fumigarei": "fumigar",
    "fumigareis": "fumigar",
    "fumigarem": "fumigar",
    "fumigaremos": "fumigar",
    "fumigares": "fumigar",
    "fumigaria": "fumigar",
    "fumigariam": "fumigar",
    "fumigarias": "fumigar",
    "fumigarmo": "fumigar",
    "fumigarmos": "fumigar",
    "fumigará": "fumigar",
    "fumigarás": "fumigar",
    "fumigarão": "fumigar",
    "fumigaríamos": "fumigar",
    "fumigaríeis": "fumigar",
    "fumigas": "fumigar",
    "fumigasse": "fumigar",
    "fumigassem": "fumigar",
    "fumigasses": "fumigar",
    "fumigaste": "fumigar",
    "fumigastes": "fumigar",
    "fumigatória": "fumigatório",
    "fumigatórias": "fumigatório",
    "fumigatórios": "fumigatório",
    "fumigava": "fumigar",
    "fumigavam": "fumigar",
    "fumigavas": "fumigar",
    "fumigações": "fumigação",
    "fumigo": "fumigar",
    "fumigou": "fumigar",
    "fumigue": "fumigar",
    "fumiguei": "fumigar",
    "fumigueis": "fumigar",
    "fumiguem": "fumigar",
    "fumiguemo": "fumigar",
    "fumiguemos": "fumigar",
    "fumigues": "fumigar",
    "fumigá": "fumigar",
    "fumigámo": "fumigar",
    "fumigámos": "fumigar",
    "fumigáramo": "fumigar",
    "fumigáramos": "fumigar",
    "fumigárei": "fumigar",
    "fumigáreis": "fumigar",
    "fumigásseis": "fumigar",
    "fumigássemos": "fumigar",
    "fumigávamo": "fumigar",
    "fumigávamos": "fumigar",
    "fumigávei": "fumigar",
    "fumigáveis": "fumigar",
    "fuminés": "fuminé",
    "fumistas": "fumista",
    "fumo": "fumar",
    "fumona": "fumão",
    "fumonas": "fumão",
    "fumos": "fumo",
    "fumosa": "fumoso",
    "fumosas": "fumoso",
    "fumosidades": "fumosidade",
    "fumosos": "fumoso",
    "fumou": "fumar",
    "fumá": "fumar",
    "fumámo": "fumar",
    "fumámos": "fumar",
    "fumáramo": "fumar",
    "fumáramos": "fumar",
    "fumárei": "fumar",
    "fumáreis": "fumar",
    "fumárias": "fumária",
    "fumárica": "fumárico",
    "fumáricas": "fumárico",
    "fumáricos": "fumárico",
    "fumásseis": "fumar",
    "fumássemos": "fumar",
    "fumávamo": "fumar",
    "fumávamos": "fumar",
    "fumávei": "fumar",
    "fumáveis": "fumável",
    "fumífera": "fumífero",
    "fumíferas": "fumífero",
    "fumíferos": "fumífero",
    "fumífica": "fumífico",
    "fumíficas": "fumífico",
    "fumíficos": "fumífico",
    "fumífoba": "fumífobo",
    "fumífobas": "fumífobo",
    "fumífobos": "fumífobo",
    "fumífuga": "fumífugo",
    "fumífugas": "fumífugo",
    "fumífugos": "fumífugo",
    "fumígera": "fumígero",
    "fumígeras": "fumígero",
    "fumígeros": "fumígero",
    "fumívoma": "fumívomo",
    "fumívomas": "fumívomo",
    "fumívomos": "fumívomo",
    "fumívora": "fumívoro",
    "fumívoras": "fumívoro",
    "fumívoros": "fumívoro",
    "fumões": "fumão",
    "funambulesca": "funambulesco",
    "funambulescas": "funambulesco",
    "funambulescos": "funambulesco",
    "funambulismos": "funambulismo",
    "funareácea": "funareáceo",
    "funareáceas": "funareáceo",
    "funareáceos": "funareáceo",
    "funariáceas": "funariácea",
    "funcas": "funca",
    "funchais": "funchal",
    "funchos": "funcho",
    "funciona": "funcionar",
    "funcionada": "funcionar",
    "funcionadas": "funcionar",
    "funcionado": "funcionar",
    "funcionados": "funcionar",
    "funcionai": "funcionar",
    "funcionais": "funcionar",
    "funcionalidades": "funcionalidade",
    "funcionalismos": "funcionalismo",
    "funcionalistas": "funcionalista",
    "funcionam": "funcionar",
    "funcionamentos": "funcionamento",
    "funcionamo": "funcionar",
    "funcionamos": "funcionar",
    "funcionando": "funcionar",
    "funcionara": "funcionar",
    "funcionaram": "funcionar",
    "funcionaras": "funcionar",
    "funcionardes": "funcionar",
    "funcionarei": "funcionar",
    "funcionareis": "funcionar",
    "funcionarem": "funcionar",
    "funcionaremos": "funcionar",
    "funcionares": "funcionar",
    "funcionaria": "funcionar",
    "funcionariam": "funcionar",
    "funcionarias": "funcionar",
    "funcionarmo": "funcionar",
    "funcionarmos": "funcionar",
    "funcionará": "funcionar",
    "funcionarás": "funcionar",
    "funcionarão": "funcionar",
    "funcionaríamos": "funcionar",
    "funcionaríeis": "funcionar",
    "funcionas": "funcionar",
    "funcionasse": "funcionar",
    "funcionassem": "funcionar",
    "funcionasses": "funcionar",
    "funcionaste": "funcionar",
    "funcionastes": "funcionar",
    "funcionava": "funcionar",
    "funcionavam": "funcionar",
    "funcionavas": "funcionar",
    "funcione": "funcionar",
    "funcionei": "funcionar",
    "funcioneis": "funcionar",
    "funcionem": "funcionar",
    "funcionemo": "funcionar",
    "funcionemos": "funcionar",
    "funciones": "funcionar",
    "funcionistas": "funcionista",
    "funciono": "funcionar",
    "funcionou": "funcionar",
    "funcionámo": "funcionar",
    "funcionámos": "funcionar",
    "funcionáramo": "funcionar",
    "funcionáramos": "funcionar",
    "funcionáreis": "funcionar",
    "funcionária": "funcionário",
    "funcionárias": "funcionário",
    "funcionários": "funcionário",
    "funcionásseis": "funcionar",
    "funcionássemos": "funcionar",
    "funcionávamo": "funcionar",
    "funcionávamos": "funcionar",
    "funcionáveis": "funcionar",
    "funda": "fundo",
    "fundada": "fundar",
    "fundadas": "fundar",
    "fundado": "fundar",
    "fundadora": "fundador",
    "fundadoras": "fundador",
    "fundadores": "fundador",
    "fundados": "fundar",
    "fundagens": "fundagem",
    "fundai": "fundar",
    "fundais": "fundir",
    "fundalhas": "fundalha",
    "fundalhos": "fundalho",
    "fundam": "fundir",
    "fundamenta": "fundamentar",
    "fundamentabilidades": "fundamentabilidade",
    "fundamentada": "fundamentar",
    "fundamentadas": "fundamentar",
    "fundamentado": "fundamentar",
    "fundamentados": "fundamentar",
    "fundamentai": "fundamentar",
    "fundamentais": "fundamentar",
    "fundamentalismos": "fundamentalismo",
    "fundamentalistas": "fundamentalista",
    "fundamentam": "fundamentar",
    "fundamentamo": "fundamentar",
    "fundamentamos": "fundamentar",
    "fundamentando": "fundamentar",
    "fundamentara": "fundamentar",
    "fundamentaram": "fundamentar",
    "fundamentaras": "fundamentar",
    "fundamentarde": "fundamentar",
    "fundamentardes": "fundamentar",
    "fundamentare": "fundamentar",
    "fundamentarei": "fundamentar",
    "fundamentareis": "fundamentar",
    "fundamentarem": "fundamentar",
    "fundamentaremos": "fundamentar",
    "fundamentares": "fundamentar",
    "fundamentaria": "fundamentar",
    "fundamentariam": "fundamentar",
    "fundamentarias": "fundamentar",
    "fundamentarmo": "fundamentar",
    "fundamentarmos": "fundamentar",
    "fundamentará": "fundamentar",
    "fundamentarás": "fundamentar",
    "fundamentarão": "fundamentar",
    "fundamentaríamos": "fundamentar",
    "fundamentaríeis": "fundamentar",
    "fundamentas": "fundamentar",
    "fundamentasse": "fundamentar",
    "fundamentassem": "fundamentar",
    "fundamentasses": "fundamentar",
    "fundamentaste": "fundamentar",
    "fundamentastes": "fundamentar",
    "fundamentava": "fundamentar",
    "fundamentavam": "fundamentar",
    "fundamentavas": "fundamentar",
    "fundamentações": "fundamentação",
    "fundamente": "fundamentar",
    "fundamentei": "fundamentar",
    "fundamenteis": "fundamentar",
    "fundamentem": "fundamentar",
    "fundamentemo": "fundamentar",
    "fundamentemos": "fundamentar",
    "fundamentes": "fundamentar",
    "fundamento": "fundamentar",
    "fundamentos": "fundamento",
    "fundamentou": "fundamentar",
    "fundamentá": "fundamentar",
    "fundamentámo": "fundamentar",
    "fundamentámos": "fundamentar",
    "fundamentáramo": "fundamentar",
    "fundamentáramos": "fundamentar",
    "fundamentárei": "fundamentar",
    "fundamentáreis": "fundamentar",
    "fundamentásseis": "fundamentar",
    "fundamentássemos": "fundamentar",
    "fundamentávamo": "fundamentar",
    "fundamentávamos": "fundamentar",
    "fundamentávei": "fundamentar",
    "fundamentáveis": "fundamentar",
    "fundamo": "fundir",
    "fundamos": "fundir",
    "fundando": "fundar",
    "fundara": "fundar",
    "fundaram": "fundar",
    "fundaras": "fundar",
    "fundarde": "fundar",
    "fundardes": "fundar",
    "fundare": "fundar",
    "fundarei": "fundar",
    "fundareis": "fundar",
    "fundarem": "fundar",
    "fundaremos": "fundar",
    "fundares": "fundar",
    "fundaria": "fundar",
    "fundariam": "fundar",
    "fundarias": "fundar",
    "fundarmo": "fundar",
    "fundarmos": "fundar",
    "fundará": "fundar",
    "fundarás": "fundar",
    "fundarão": "fundar",
    "fundaríamos": "fundar",
    "fundaríeis": "fundar",
    "fundas": "fundo",
    "fundasse": "fundar",
    "fundassem": "fundar",
    "fundasses": "fundar",
    "fundaste": "fundar",
    "fundastes": "fundar",
    "fundava": "fundar",
    "fundavam": "fundar",
    "fundavas": "fundar",
    "fundações": "fundação",
    "funde": "fundir",
    "fundeada": "fundear",
    "fundeadas": "fundear",
    "fundeado": "fundear",
    "fundeadoiros": "fundeadoiro",
    "fundeados": "fundear",
    "fundeadouros": "fundeadouro",
    "fundeai": "fundear",
    "fundeais": "fundear",
    "fundeamentos": "fundeamento",
    "fundeamo": "fundear",
    "fundeamos": "fundear",
    "fundeando": "fundear",
    "fundeara": "fundear",
    "fundearam": "fundear",
    "fundearas": "fundear",
    "fundeardes": "fundear",
    "fundearei": "fundear",
    "fundeareis": "fundear",
    "fundearem": "fundear",
    "fundearemos": "fundear",
    "fundeares": "fundear",
    "fundearia": "fundear",
    "fundeariam": "fundear",
    "fundearias": "fundear",
    "fundearmo": "fundear",
    "fundearmos": "fundear",
    "fundeará": "fundear",
    "fundearás": "fundear",
    "fundearão": "fundear",
    "fundearíamos": "fundear",
    "fundearíeis": "fundear",
    "fundeasse": "fundear",
    "fundeassem": "fundear",
    "fundeasses": "fundear",
    "fundeaste": "fundear",
    "fundeastes": "fundear",
    "fundeava": "fundear",
    "fundeavam": "fundear",
    "fundeavas": "fundear",
    "fundeei": "fundear",
    "fundeeis": "fundear",
    "fundeemo": "fundear",
    "fundeemos": "fundear",
    "fundei": "fundar",
    "fundeia": "fundear",
    "fundeiam": "fundear",
    "fundeias": "fundear",
    "fundeie": "fundear",
    "fundeiem": "fundear",
    "fundeies": "fundear",
    "fundeio": "fundear",
    "fundeira": "fundeiro",
    "fundeiras": "fundeiro",
    "fundeiros": "fundeiro",
    "fundeis": "fundar",
    "fundem": "fundir",
    "fundemo": "fundar",
    "fundemos": "fundar",
    "fundentes": "fundente",
    "fundeou": "fundear",
    "fundes": "fundir",
    "fundeámo": "fundear",
    "fundeámos": "fundear",
    "fundeáramo": "fundear",
    "fundeáramos": "fundear",
    "fundeáreis": "fundear",
    "fundeária": "fundeário",
    "fundeárias": "fundeário",
    "fundeários": "fundeário",
    "fundeásseis": "fundear",
    "fundeássemos": "fundear",
    "fundeávamo": "fundear",
    "fundeávamos": "fundear",
    "fundeáveis": "fundear",
    "fundi": "fundir",
    "fundia": "fundir",
    "fundiam": "fundir",
    "fundias": "fundir",
    "fundibulários": "fundibulário",
    "fundida": "fundir",
    "fundidas": "fundir",
    "fundido": "fundir",
    "fundidora": "fundidor",
    "fundidoras": "fundidor",
    "fundidores": "fundidor",
    "fundidos": "fundir",
    "fundilha": "fundilhar",
    "fundilhada": "fundilhar",
    "fundilhadas": "fundilhar",
    "fundilhado": "fundilhar",
    "fundilhados": "fundilhar",
    "fundilhai": "fundilhar",
    "fundilhais": "fundilhar",
    "fundilham": "fundilhar",
    "fundilhamo": "fundilhar",
    "fundilhamos": "fundilhar",
    "fundilhando": "fundilhar",
    "fundilhara": "fundilhar",
    "fundilharam": "fundilhar",
    "fundilharas": "fundilhar",
    "fundilharde": "fundilhar",
    "fundilhardes": "fundilhar",
    "fundilhare": "fundilhar",
    "fundilharei": "fundilhar",
    "fundilhareis": "fundilhar",
    "fundilharem": "fundilhar",
    "fundilharemos": "fundilhar",
    "fundilhares": "fundilhar",
    "fundilharia": "fundilhar",
    "fundilhariam": "fundilhar",
    "fundilharias": "fundilhar",
    "fundilharmo": "fundilhar",
    "fundilharmos": "fundilhar",
    "fundilhará": "fundilhar",
    "fundilharás": "fundilhar",
    "fundilharão": "fundilhar",
    "fundilharíamos": "fundilhar",
    "fundilharíeis": "fundilhar",
    "fundilhas": "fundilhar",
    "fundilhasse": "fundilhar",
    "fundilhassem": "fundilhar",
    "fundilhasses": "fundilhar",
    "fundilhaste": "fundilhar",
    "fundilhastes": "fundilhar",
    "fundilhava": "fundilhar",
    "fundilhavam": "fundilhar",
    "fundilhavas": "fundilhar",
    "fundilhe": "fundilhar",
    "fundilhei": "fundilhar",
    "fundilheis": "fundilhar",
    "fundilhem": "fundilhar",
    "fundilhemo": "fundilhar",
    "fundilhemos": "fundilhar",
    "fundilhes": "fundilhar",
    "fundilho": "fundilhar",
    "fundilhos": "fundilho",
    "fundilhou": "fundilhar",
    "fundilhá": "fundilhar",
    "fundilhámo": "fundilhar",
    "fundilhámos": "fundilhar",
    "fundilháramo": "fundilhar",
    "fundilháramos": "fundilhar",
    "fundilhárei": "fundilhar",
    "fundilháreis": "fundilhar",
    "fundilhásseis": "fundilhar",
    "fundilhássemos": "fundilhar",
    "fundilhávamo": "fundilhar",
    "fundilhávamos": "fundilhar",
    "fundilhávei": "fundilhar",
    "fundilháveis": "fundilhar",
    "fundimo": "fundir",
    "fundimos": "fundir",
    "fundindo": "fundir",
    "fundira": "fundir",
    "fundiram": "fundir",
    "fundiras": "fundir",
    "fundirde": "fundir",
    "fundirdes": "fundir",
    "fundire": "fundir",
    "fundirei": "fundir",
    "fundireis": "fundir",
    "fundirem": "fundir",
    "fundiremos": "fundir",
    "fundires": "fundir",
    "fundiria": "fundir",
    "fundiriam": "fundir",
    "fundirias": "fundir",
    "fundirmo": "fundir",
    "fundirmos": "fundir",
    "fundirá": "fundir",
    "fundirás": "fundir",
    "fundirão": "fundir",
    "fundiríamos": "fundir",
    "fundiríeis": "fundir",
    "fundis": "fundir",
    "fundismos": "fundismo",
    "fundisse": "fundir",
    "fundissem": "fundir",
    "fundisses": "fundir",
    "fundistas": "fundista",
    "fundiste": "fundir",
    "fundistes": "fundir",
    "fundiu": "fundir",
    "fundiária": "fundiário",
    "fundiárias": "fundiário",
    "fundiários": "fundiário",
    "fundições": "fundição",
    "fundo": "fundir",
    "fundos": "fundo",
    "fundou": "fundar",
    "fundujos": "fundujo",
    "funduras": "fundura",
    "fundá": "fundar",
    "fundámo": "fundar",
    "fundámos": "fundar",
    "fundáramo": "fundar",
    "fundáramos": "fundar",
    "fundárei": "fundar",
    "fundáreis": "fundar",
    "fundásseis": "fundar",
    "fundássemos": "fundar",
    "fundávamo": "fundar",
    "fundávamos": "fundar",
    "fundávei": "fundar",
    "fundáveis": "fundável",
    "fundíamo": "fundir",
    "fundíamos": "fundir",
    "fundíbulos": "fundíbulo",
    "fundíei": "fundir",
    "fundíeis": "fundir",
    "fundíramo": "fundir",
    "fundíramos": "fundir",
    "fundírei": "fundir",
    "fundíreis": "fundir",
    "fundísseis": "fundir",
    "fundíssemos": "fundir",
    "fundíveis": "fundível",
    "fundões": "fundão",
    "funeis": "funel",
    "funerais": "funeral",
    "funerária": "funerário",
    "funerárias": "funerário",
    "funerários": "funerário",
    "funesta": "funesto",
    "funestada": "funestar",
    "funestadas": "funestar",
    "funestado": "funestar",
    "funestadora": "funestador",
    "funestadoras": "funestador",
    "funestadores": "funestador",
    "funestados": "funestar",
    "funestai": "funestar",
    "funestais": "funestar",
    "funestam": "funestar",
    "funestamo": "funestar",
    "funestamos": "funestar",
    "funestando": "funestar",
    "funestara": "funestar",
    "funestaram": "funestar",
    "funestaras": "funestar",
    "funestarde": "funestar",
    "funestardes": "funestar",
    "funestare": "funestar",
    "funestarei": "funestar",
    "funestareis": "funestar",
    "funestarem": "funestar",
    "funestaremos": "funestar",
    "funestares": "funestar",
    "funestaria": "funestar",
    "funestariam": "funestar",
    "funestarias": "funestar",
    "funestarmo": "funestar",
    "funestarmos": "funestar",
    "funestará": "funestar",
    "funestarás": "funestar",
    "funestarão": "funestar",
    "funestaríamos": "funestar",
    "funestaríeis": "funestar",
    "funestas": "funesto",
    "funestasse": "funestar",
    "funestassem": "funestar",
    "funestasses": "funestar",
    "funestaste": "funestar",
    "funestastes": "funestar",
    "funestava": "funestar",
    "funestavam": "funestar",
    "funestavas": "funestar",
    "funestações": "funestação",
    "funeste": "funestar",
    "funestei": "funestar",
    "funesteis": "funestar",
    "funestem": "funestar",
    "funestemo": "funestar",
    "funestemos": "funestar",
    "funestes": "funestar",
    "funesto": "funestar",
    "funestos": "funesto",
    "funestou": "funestar",
    "funestá": "funestar",
    "funestámo": "funestar",
    "funestámos": "funestar",
    "funestáramo": "funestar",
    "funestáramos": "funestar",
    "funestárei": "funestar",
    "funestáreis": "funestar",
    "funestásseis": "funestar",
    "funestássemos": "funestar",
    "funestávamo": "funestar",
    "funestávamos": "funestar",
    "funestávei": "funestar",
    "funestáveis": "funestar",
    "funga": "fungar",
    "fungada": "fungar",
    "fungadas": "fungar",
    "fungadeiras": "fungadeira",
    "fungadelas": "fungadela",
    "fungado": "fungar",
    "fungados": "fungar",
    "fungai": "fungar",
    "fungais": "fungar",
    "fungam": "fungar",
    "fungamo": "fungar",
    "fungamos": "fungar",
    "fungando": "fungar",
    "fungara": "fungar",
    "fungaram": "fungar",
    "fungaras": "fungar",
    "fungardes": "fungar",
    "fungarei": "fungar",
    "fungareis": "fungar",
    "fungarem": "fungar",
    "fungaremos": "fungar",
    "fungares": "fungar",
    "fungaria": "fungar",
    "fungariam": "fungar",
    "fungarias": "fungar",
    "fungarmo": "fungar",
    "fungarmos": "fungar",
    "fungará": "fungar",
    "fungarás": "fungar",
    "fungarão": "fungar",
    "fungaríamos": "fungar",
    "fungaríeis": "fungar",
    "fungas": "fungar",
    "fungasse": "fungar",
    "fungassem": "fungar",
    "fungasses": "fungar",
    "fungaste": "fungar",
    "fungastes": "fungar",
    "fungava": "fungar",
    "fungavam": "fungar",
    "fungavas": "fungar",
    "funges": "funge",
    "fungicidas": "fungicida",
    "fungiformes": "fungiforme",
    "funginas": "fungina",
    "fungo": "fungar",
    "fungona": "fungão",
    "fungonas": "fungão",
    "fungos": "fungo",
    "fungosa": "fungoso",
    "fungosas": "fungoso",
    "fungosidades": "fungosidade",
    "fungosos": "fungoso",
    "fungou": "fungar",
    "fungue": "fungar",
    "funguei": "fungar",
    "fungueis": "fungar",
    "funguem": "fungar",
    "funguemo": "fungar",
    "funguemos": "fungar",
    "fungues": "fungar",
    "fungámo": "fungar",
    "fungámos": "fungar",
    "fungáramo": "fungar",
    "fungáramos": "fungar",
    "fungáreis": "fungar",
    "fungásseis": "fungar",
    "fungássemos": "fungar",
    "fungávamo": "fungar",
    "fungávamos": "fungar",
    "fungáveis": "fungar",
    "fungícolas": "fungícola",
    "fungínica": "fungínico",
    "fungínicas": "fungínico",
    "fungínicos": "fungínico",
    "fungíveis": "fungível",
    "fungões": "fungão",
    "funiculares": "funicular",
    "funiformes": "funiforme",
    "funilarias": "funilaria",
    "funileira": "funileiro",
    "funileiras": "funileiro",
    "funileiros": "funileiro",
    "funis": "funil",
    "funárias": "funária",
    "funâmbula": "funâmbulo",
    "funâmbulas": "funâmbulo",
    "funâmbulos": "funâmbulo",
    "funçanadas": "funçanada",
    "funçanatas": "funçanata",
    "funçanistas": "funçanista",
    "funções": "função",
    "funérea": "funéreo",
    "funéreas": "funéreo",
    "funéreos": "funéreo",
    "funéus": "funéu",
    "funículos": "funículo",
    "fura": "furar",
    "furacidades": "furacidade",
    "furacões": "furacão",
    "furada": "furar",
    "furadas": "furar",
    "furado": "furar",
    "furadoiros": "furadoiro",
    "furadora": "furador",
    "furadoras": "furador",
    "furadores": "furador",
    "furados": "furar",
    "furadouros": "furadouro",
    "furagens": "furagem",
    "furai": "furar",
    "furais": "furar",
    "furam": "furar",
    "furamo": "furar",
    "furamos": "furar",
    "furando": "furar",
    "furara": "furar",
    "furaram": "furar",
    "furaras": "furar",
    "furarde": "furar",
    "furardes": "furar",
    "furare": "furar",
    "furarei": "furar",
    "furareis": "furar",
    "furarem": "furar",
    "furaremos": "furar",
    "furares": "furar",
    "furaria": "furar",
    "furariam": "furar",
    "furarias": "furar",
    "furarmo": "furar",
    "furarmos": "furar",
    "furará": "furar",
    "furarás": "furar",
    "furarão": "furar",
    "furaríamos": "furar",
    "furaríeis": "furar",
    "furas": "furar",
    "furasse": "furar",
    "furassem": "furar",
    "furasses": "furar",
    "furaste": "furar",
    "furastes": "furar",
    "furava": "furar",
    "furavam": "furar",
    "furavas": "furar",
    "furbescos": "furbesco",
    "furcates": "furcate",
    "furcos": "furco",
    "furcífera": "furcífero",
    "furcíferas": "furcífero",
    "furcíferos": "furcífero",
    "furdas": "furda",
    "furdões": "furdão",
    "fure": "furar",
    "furei": "furar",
    "fureis": "furar",
    "furem": "furar",
    "furemo": "furar",
    "furemos": "furar",
    "furentes": "furente",
    "fures": "furar",
    "furfurações": "furfuração",
    "furfurácea": "furfuráceo",
    "furfuráceas": "furfuráceo",
    "furfuráceos": "furfuráceo",
    "furfúrea": "furfúreo",
    "furfúreas": "furfúreo",
    "furfúreos": "furfúreo",
    "furgonetas": "furgoneta",
    "furgões": "furgão",
    "furiais": "furial",
    "furibunda": "furibundo",
    "furibundas": "furibundo",
    "furibundos": "furibundo",
    "furifolhas": "furifolha",
    "furifuna": "furifunar",
    "furifunada": "furifunar",
    "furifunadas": "furifunar",
    "furifunado": "furifunar",
    "furifunados": "furifunar",
    "furifunai": "furifunar",
    "furifunais": "furifunar",
    "furifunam": "furifunar",
    "furifunamo": "furifunar",
    "furifunamos": "furifunar",
    "furifunando": "furifunar",
    "furifunara": "furifunar",
    "furifunaram": "furifunar",
    "furifunaras": "furifunar",
    "furifunarde": "furifunar",
    "furifunardes": "furifunar",
    "furifunare": "furifunar",
    "furifunarei": "furifunar",
    "furifunareis": "furifunar",
    "furifunarem": "furifunar",
    "furifunaremos": "furifunar",
    "furifunares": "furifunar",
    "furifunaria": "furifunar",
    "furifunariam": "furifunar",
    "furifunarias": "furifunar",
    "furifunarmo": "furifunar",
    "furifunarmos": "furifunar",
    "furifunará": "furifunar",
    "furifunarás": "furifunar",
    "furifunarão": "furifunar",
    "furifunaríamos": "furifunar",
    "furifunaríeis": "furifunar",
    "furifunas": "furifunar",
    "furifunasse": "furifunar",
    "furifunassem": "furifunar",
    "furifunasses": "furifunar",
    "furifunaste": "furifunar",
    "furifunastes": "furifunar",
    "furifunava": "furifunar",
    "furifunavam": "furifunar",
    "furifunavas": "furifunar",
    "furifune": "furifunar",
    "furifunei": "furifunar",
    "furifuneis": "furifunar",
    "furifunem": "furifunar",
    "furifunemo": "furifunar",
    "furifunemos": "furifunar",
    "furifunes": "furifunar",
    "furifuno": "furifunar",
    "furifunou": "furifunar",
    "furifuná": "furifunar",
    "furifunámo": "furifunar",
    "furifunámos": "furifunar",
    "furifunáramo": "furifunar",
    "furifunáramos": "furifunar",
    "furifunárei": "furifunar",
    "furifunáreis": "furifunar",
    "furifunásseis": "furifunar",
    "furifunássemos": "furifunar",
    "furifunávamo": "furifunar",
    "furifunávamos": "furifunar",
    "furifunávei": "furifunar",
    "furifunáveis": "furifunar",
    "furinho": "furo",
    "furinhos": "furo",
    "furiosa": "furioso",
    "furiosas": "furioso",
    "furiosidades": "furiosidade",
    "furiosos": "furioso",
    "furito": "furo",
    "furitos": "furo",
    "furlanas": "furlana",
    "furnas": "furna",
    "furo": "furar",
    "furoa": "furoar",
    "furoada": "furoar",
    "furoadas": "furoar",
    "furoado": "furoar",
    "furoados": "furoar",
    "furoai": "furoar",
    "furoais": "furoar",
    "furoam": "furoar",
    "furoamo": "furoar",
    "furoamos": "furoar",
    "furoando": "furoar",
    "furoara": "furoar",
    "furoaram": "furoar",
    "furoaras": "furoar",
    "furoarde": "furoar",
    "furoardes": "furoar",
    "furoare": "furoar",
    "furoarei": "furoar",
    "furoareis": "furoar",
    "furoarem": "furoar",
    "furoaremos": "furoar",
    "furoares": "furoar",
    "furoaria": "furoar",
    "furoariam": "furoar",
    "furoarias": "furoar",
    "furoarmo": "furoar",
    "furoarmos": "furoar",
    "furoará": "furoar",
    "furoarás": "furoar",
    "furoarão": "furoar",
    "furoaríamos": "furoar",
    "furoaríeis": "furoar",
    "furoas": "furoar",
    "furoasse": "furoar",
    "furoassem": "furoar",
    "furoasses": "furoar",
    "furoaste": "furoar",
    "furoastes": "furoar",
    "furoava": "furoar",
    "furoavam": "furoar",
    "furoavas": "furoar",
    "furoe": "furoar",
    "furoei": "furoar",
    "furoeis": "furoar",
    "furoem": "furoar",
    "furoemo": "furoar",
    "furoemos": "furoar",
    "furoes": "furoar",
    "furoleira": "furoleiro",
    "furoleiras": "furoleiro",
    "furoleiros": "furoleiro",
    "furona": "furão",
    "furonas": "furão",
    "furoo": "furoar",
    "furoou": "furoar",
    "furores": "furor",
    "furos": "furo",
    "furou": "furar",
    "furoá": "furoar",
    "furoámo": "furoar",
    "furoámos": "furoar",
    "furoáramo": "furoar",
    "furoáramos": "furoar",
    "furoárei": "furoar",
    "furoáreis": "furoar",
    "furoásseis": "furoar",
    "furoássemos": "furoar",
    "furoávamo": "furoar",
    "furoávamos": "furoar",
    "furoávei": "furoar",
    "furoáveis": "furoar",
    "furrieis": "furriel",
    "furta": "furtar",
    "furtada": "furtar",
    "furtadas": "furtar",
    "furtadelas": "furtadela",
    "furtado": "furtar",
    "furtados": "furtar",
    "furtai": "furtar",
    "furtais": "furtar",
    "furtam": "furtar",
    "furtamo": "furtar",
    "furtamos": "furtar",
    "furtando": "furtar",
    "furtara": "furtar",
    "furtaram": "furtar",
    "furtaras": "furtar",
    "furtarde": "furtar",
    "furtardes": "furtar",
    "furtare": "furtar",
    "furtarei": "furtar",
    "furtareis": "furtar",
    "furtarem": "furtar",
    "furtaremos": "furtar",
    "furtares": "furtar",
    "furtaria": "furtar",
    "furtariam": "furtar",
    "furtarias": "furtar",
    "furtarmo": "furtar",
    "furtarmos": "furtar",
    "furtará": "furtar",
    "furtarás": "furtar",
    "furtarão": "furtar",
    "furtaríamos": "furtar",
    "furtaríeis": "furtar",
    "furtas": "furtar",
    "furtasse": "furtar",
    "furtassem": "furtar",
    "furtasses": "furtar",
    "furtaste": "furtar",
    "furtastes": "furtar",
    "furtava": "furtar",
    "furtavam": "furtar",
    "furtavas": "furtar",
    "furte": "furtar",
    "furtei": "furtar",
    "furteis": "furtar",
    "furtem": "furtar",
    "furtemo": "furtar",
    "furtemos": "furtar",
    "furtes": "furtar",
    "furtiva": "furtivo",
    "furtivas": "furtivo",
    "furtivos": "furtivo",
    "furto": "furtar",
    "furtos": "furto",
    "furtou": "furtar",
    "furtá": "furtar",
    "furtámo": "furtar",
    "furtámos": "furtar",
    "furtáramo": "furtar",
    "furtáramos": "furtar",
    "furtárei": "furtar",
    "furtáreis": "furtar",
    "furtásseis": "furtar",
    "furtássemos": "furtar",
    "furtávamo": "furtar",
    "furtávamos": "furtar",
    "furtávei": "furtar",
    "furtáveis": "furtável",
    "furunculares": "furuncular",
    "furunculosa": "furunculoso",
    "furunculosas": "furunculoso",
    "furunculoses": "furunculose",
    "furunculosos": "furunculoso",
    "furá": "furar",
    "furámo": "furar",
    "furámos": "furar",
    "furáramo": "furar",
    "furáramos": "furar",
    "furárei": "furar",
    "furáreis": "furar",
    "furásseis": "furar",
    "furássemos": "furar",
    "furávamo": "furar",
    "furávamos": "furar",
    "furávei": "furar",
    "furáveis": "furável",
    "furões": "furão",
    "furúnculos": "furúnculo",
    "fusadas": "fusada",
    "fusas": "fusa",
    "fusca": "fusco",
    "fuscalva": "fuscalvo",
    "fuscalvas": "fuscalvo",
    "fuscalvos": "fuscalvo",
    "fuscas": "fusco",
    "fuscicórnea": "fuscicórneo",
    "fuscicórneas": "fuscicórneo",
    "fuscicórneos": "fuscicórneo",
    "fuscinas": "fuscina",
    "fuscipenes": "fuscipene",
    "fuscirrostra": "fuscirrostro",
    "fuscirrostras": "fuscirrostro",
    "fuscirrostros": "fuscirrostro",
    "fuscos": "fusco",
    "fuscícula": "fuscículo",
    "fuscículas": "fuscículo",
    "fuscículos": "fuscículo",
    "fuscímana": "fuscímano",
    "fuscímanas": "fuscímano",
    "fuscímanos": "fuscímano",
    "fuseira": "fuseiro",
    "fuseiras": "fuseiro",
    "fuseiros": "fuseiro",
    "fuselada": "fuselado",
    "fuseladas": "fuselado",
    "fuselados": "fuselado",
    "fuselagens": "fuselagem",
    "fuselas": "fusela",
    "fuselos": "fuselo",
    "fusibilidades": "fusibilidade",
    "fusiformes": "fusiforme",
    "fusilada": "fusilado",
    "fusiladas": "fusilado",
    "fusiladora": "fusilador",
    "fusiladoras": "fusilador",
    "fusiladores": "fusilador",
    "fusilados": "fusilado",
    "fusilantes": "fusilante",
    "fusiloas": "fusiloa",
    "fusionada": "fusionado",
    "fusionadas": "fusionado",
    "fusionados": "fusionado",
    "fusionistas": "fusionista",
    "fusos": "fuso",
    "fusquidões": "fusquidão",
    "fustalhas": "fustalha",
    "fustas": "fusta",
    "fustes": "fuste",
    "fustiga": "fustigar",
    "fustigada": "fustigar",
    "fustigadas": "fustigar",
    "fustigadelas": "fustigadela",
    "fustigado": "fustigar",
    "fustigadora": "fustigador",
    "fustigadoras": "fustigador",
    "fustigadores": "fustigador",
    "fustigados": "fustigar",
    "fustigai": "fustigar",
    "fustigais": "fustigar",
    "fustigam": "fustigar",
    "fustigamo": "fustigar",
    "fustigamos": "fustigar",
    "fustigando": "fustigar",
    "fustigantes": "fustigante",
    "fustigara": "fustigar",
    "fustigaram": "fustigar",
    "fustigaras": "fustigar",
    "fustigarde": "fustigar",
    "fustigardes": "fustigar",
    "fustigare": "fustigar",
    "fustigarei": "fustigar",
    "fustigareis": "fustigar",
    "fustigarem": "fustigar",
    "fustigaremos": "fustigar",
    "fustigares": "fustigar",
    "fustigaria": "fustigar",
    "fustigariam": "fustigar",
    "fustigarias": "fustigar",
    "fustigarmo": "fustigar",
    "fustigarmos": "fustigar",
    "fustigará": "fustigar",
    "fustigarás": "fustigar",
    "fustigarão": "fustigar",
    "fustigaríamos": "fustigar",
    "fustigaríeis": "fustigar",
    "fustigas": "fustigar",
    "fustigasse": "fustigar",
    "fustigassem": "fustigar",
    "fustigasses": "fustigar",
    "fustigaste": "fustigar",
    "fustigastes": "fustigar",
    "fustigava": "fustigar",
    "fustigavam": "fustigar",
    "fustigavas": "fustigar",
    "fustigações": "fustigação",
    "fustigo": "fustigar",
    "fustigos": "fustigo",
    "fustigou": "fustigar",
    "fustigue": "fustigar",
    "fustiguei": "fustigar",
    "fustigueis": "fustigar",
    "fustiguem": "fustigar",
    "fustiguemo": "fustigar",
    "fustiguemos": "fustigar",
    "fustigues": "fustigar",
    "fustigá": "fustigar",
    "fustigámo": "fustigar",
    "fustigámos": "fustigar",
    "fustigáramo": "fustigar",
    "fustigáramos": "fustigar",
    "fustigárei": "fustigar",
    "fustigáreis": "fustigar",
    "fustigásseis": "fustigar",
    "fustigássemos": "fustigar",
    "fustigávamo": "fustigar",
    "fustigávamos": "fustigar",
    "fustigávei": "fustigar",
    "fustigáveis": "fustigar",
    "fustões": "fustão",
    "fusulinas": "fusulina",
    "fusulinídeos": "fusulinídeo",
    "fusípedes": "fusípede",
    "fusíveis": "fusível",
    "fusória": "fusório",
    "fusórias": "fusório",
    "fusórios": "fusório",
    "fusões": "fusão",
    "futebolistas": "futebolista",
    "futebolística": "futebolístico",
    "futebolísticas": "futebolístico",
    "futebolísticos": "futebolístico",
    "futebóis": "futebol",
    "futilidades": "futilidade",
    "futiliza": "futilizar",
    "futilizada": "futilizar",
    "futilizadas": "futilizar",
    "futilizado": "futilizar",
    "futilizados": "futilizar",
    "futilizai": "futilizar",
    "futilizais": "futilizar",
    "futilizam": "futilizar",
    "futilizamo": "futilizar",
    "futilizamos": "futilizar",
    "futilizando": "futilizar",
    "futilizara": "futilizar",
    "futilizaram": "futilizar",
    "futilizaras": "futilizar",
    "futilizarde": "futilizar",
    "futilizardes": "futilizar",
    "futilizare": "futilizar",
    "futilizarei": "futilizar",
    "futilizareis": "futilizar",
    "futilizarem": "futilizar",
    "futilizaremos": "futilizar",
    "futilizares": "futilizar",
    "futilizaria": "futilizar",
    "futilizariam": "futilizar",
    "futilizarias": "futilizar",
    "futilizarmo": "futilizar",
    "futilizarmos": "futilizar",
    "futilizará": "futilizar",
    "futilizarás": "futilizar",
    "futilizarão": "futilizar",
    "futilizaríamos": "futilizar",
    "futilizaríeis": "futilizar",
    "futilizas": "futilizar",
    "futilizasse": "futilizar",
    "futilizassem": "futilizar",
    "futilizasses": "futilizar",
    "futilizaste": "futilizar",
    "futilizastes": "futilizar",
    "futilizava": "futilizar",
    "futilizavam": "futilizar",
    "futilizavas": "futilizar",
    "futilize": "futilizar",
    "futilizei": "futilizar",
    "futilizeis": "futilizar",
    "futilizem": "futilizar",
    "futilizemo": "futilizar",
    "futilizemos": "futilizar",
    "futilizes": "futilizar",
    "futilizo": "futilizar",
    "futilizou": "futilizar",
    "futilizá": "futilizar",
    "futilizámo": "futilizar",
    "futilizámos": "futilizar",
    "futilizáramo": "futilizar",
    "futilizáramos": "futilizar",
    "futilizárei": "futilizar",
    "futilizáreis": "futilizar",
    "futilizásseis": "futilizar",
    "futilizássemos": "futilizar",
    "futilizávamo": "futilizar",
    "futilizávamos": "futilizar",
    "futilizávei": "futilizar",
    "futilizáveis": "futilizar",
    "futres": "futre",
    "futricadas": "futricada",
    "futricagens": "futricagem",
    "futricas": "futrica",
    "futriqueira": "futriqueiro",
    "futriqueiras": "futriqueiro",
    "futriqueiros": "futriqueiro",
    "futriquices": "futriquice",
    "futura": "futuro",
    "futurada": "futurar",
    "futuradas": "futurar",
    "futurado": "futurar",
    "futurados": "futurar",
    "futurai": "futurar",
    "futurais": "futurar",
    "futuram": "futurar",
    "futuramo": "futurar",
    "futuramos": "futurar",
    "futurando": "futurar",
    "futurara": "futurar",
    "futuraram": "futurar",
    "futuraras": "futurar",
    "futurarde": "futurar",
    "futurardes": "futurar",
    "futurare": "futurar",
    "futurarei": "futurar",
    "futurareis": "futurar",
    "futurarem": "futurar",
    "futuraremos": "futurar",
    "futurares": "futurar",
    "futuraria": "futurar",
    "futurariam": "futurar",
    "futurarias": "futurar",
    "futurarmo": "futurar",
    "futurarmos": "futurar",
    "futurará": "futurar",
    "futurarás": "futurar",
    "futurarão": "futurar",
    "futuraríamos": "futurar",
    "futuraríeis": "futurar",
    "futuras": "futuro",
    "futurasse": "futurar",
    "futurassem": "futurar",
    "futurasses": "futurar",
    "futuraste": "futurar",
    "futurastes": "futurar",
    "futurava": "futurar",
    "futuravam": "futurar",
    "futuravas": "futurar",
    "futurações": "futuração",
    "future": "futurar",
    "futurei": "futurar",
    "futureis": "futurar",
    "futurem": "futurar",
    "futuremo": "futurar",
    "futuremos": "futurar",
    "futures": "futurar",
    "futuridades": "futuridade",
    "futurismos": "futurismo",
    "futuristas": "futurista",
    "futurizações": "futurização",
    "futurizáveis": "futurizável",
    "futurições": "futurição",
    "futuro": "futurar",
    "futurologias": "futurologia",
    "futuros": "futuro",
    "futurosa": "futuroso",
    "futurosas": "futuroso",
    "futurosos": "futuroso",
    "futurou": "futurar",
    "futurá": "futurar",
    "futurámo": "futurar",
    "futurámos": "futurar",
    "futuráramo": "futurar",
    "futuráramos": "futurar",
    "futurárei": "futurar",
    "futuráreis": "futurar",
    "futurásseis": "futurar",
    "futurássemos": "futurar",
    "futurávamo": "futurar",
    "futurávamos": "futurar",
    "futurávei": "futurar",
    "futuráveis": "futurar",
    "futurística": "futurístico",
    "futurísticas": "futurístico",
    "futurísticos": "futurístico",
    "futuríveis": "futurível",
    "fuxica": "fuxicar",
    "fuxicada": "fuxicar",
    "fuxicadas": "fuxicar",
    "fuxicado": "fuxicar",
    "fuxicados": "fuxicar",
    "fuxicai": "fuxicar",
    "fuxicais": "fuxicar",
    "fuxicam": "fuxicar",
    "fuxicamo": "fuxicar",
    "fuxicamos": "fuxicar",
    "fuxicando": "fuxicar",
    "fuxicara": "fuxicar",
    "fuxicaram": "fuxicar",
    "fuxicaras": "fuxicar",
    "fuxicarde": "fuxicar",
    "fuxicardes": "fuxicar",
    "fuxicare": "fuxicar",
    "fuxicarei": "fuxicar",
    "fuxicareis": "fuxicar",
    "fuxicarem": "fuxicar",
    "fuxicaremos": "fuxicar",
    "fuxicares": "fuxicar",
    "fuxicaria": "fuxicar",
    "fuxicariam": "fuxicar",
    "fuxicarias": "fuxicar",
    "fuxicarmo": "fuxicar",
    "fuxicarmos": "fuxicar",
    "fuxicará": "fuxicar",
    "fuxicarás": "fuxicar",
    "fuxicarão": "fuxicar",
    "fuxicaríamos": "fuxicar",
    "fuxicaríeis": "fuxicar",
    "fuxicas": "fuxicar",
    "fuxicasse": "fuxicar",
    "fuxicassem": "fuxicar",
    "fuxicasses": "fuxicar",
    "fuxicaste": "fuxicar",
    "fuxicastes": "fuxicar",
    "fuxicava": "fuxicar",
    "fuxicavam": "fuxicar",
    "fuxicavas": "fuxicar",
    "fuxico": "fuxicar",
    "fuxicos": "fuxico",
    "fuxicou": "fuxicar",
    "fuxicá": "fuxicar",
    "fuxicámo": "fuxicar",
    "fuxicámos": "fuxicar",
    "fuxicáramo": "fuxicar",
    "fuxicáramos": "fuxicar",
    "fuxicárei": "fuxicar",
    "fuxicáreis": "fuxicar",
    "fuxicásseis": "fuxicar",
    "fuxicássemos": "fuxicar",
    "fuxicávamo": "fuxicar",
    "fuxicávamos": "fuxicar",
    "fuxicávei": "fuxicar",
    "fuxicáveis": "fuxicar",
    "fuxique": "fuxicar",
    "fuxiquei": "fuxicar",
    "fuxiqueis": "fuxicar",
    "fuxiquem": "fuxicar",
    "fuxiquemo": "fuxicar",
    "fuxiquemos": "fuxicar",
    "fuxiques": "fuxicar",
    "fuzila": "fuzilar",
    "fuzilada": "fuzilar",
    "fuziladas": "fuzilar",
    "fuzilado": "fuzilar",
    "fuziladora": "fuzilador",
    "fuziladoras": "fuzilador",
    "fuziladores": "fuzilador",
    "fuzilados": "fuzilar",
    "fuzilai": "fuzilar",
    "fuzilais": "fuzilar",
    "fuzilam": "fuzilar",
    "fuzilamentos": "fuzilamento",
    "fuzilamo": "fuzilar",
    "fuzilamos": "fuzilar",
    "fuzilando": "fuzilar",
    "fuzilara": "fuzilar",
    "fuzilaram": "fuzilar",
    "fuzilaras": "fuzilar",
    "fuzilarde": "fuzilar",
    "fuzilardes": "fuzilar",
    "fuzilare": "fuzilar",
    "fuzilarei": "fuzilar",
    "fuzilareis": "fuzilar",
    "fuzilarem": "fuzilar",
    "fuzilaremos": "fuzilar",
    "fuzilares": "fuzilar",
    "fuzilaria": "fuzilar",
    "fuzilariam": "fuzilar",
    "fuzilarias": "fuzilaria",
    "fuzilarmo": "fuzilar",
    "fuzilarmos": "fuzilar",
    "fuzilará": "fuzilar",
    "fuzilarás": "fuzilar",
    "fuzilarão": "fuzilar",
    "fuzilaríamos": "fuzilar",
    "fuzilaríeis": "fuzilar",
    "fuzilas": "fuzilar",
    "fuzilasse": "fuzilar",
    "fuzilassem": "fuzilar",
    "fuzilasses": "fuzilar",
    "fuzilaste": "fuzilar",
    "fuzilastes": "fuzilar",
    "fuzilava": "fuzilar",
    "fuzilavam": "fuzilar",
    "fuzilavas": "fuzilar",
    "fuzilações": "fuzilação",
    "fuzile": "fuzilar",
    "fuzilei": "fuzilar",
    "fuzileiros": "fuzileiro",
    "fuzileis": "fuzilar",
    "fuzilem": "fuzilar",
    "fuzilemo": "fuzilar",
    "fuzilemos": "fuzilar",
    "fuziles": "fuzilar",
    "fuzilhões": "fuzilhão",
    "fuzilo": "fuzilar",
    "fuzilou": "fuzilar",
    "fuzilá": "fuzilar",
    "fuzilámo": "fuzilar",
    "fuzilámos": "fuzilar",
    "fuziláramo": "fuzilar",
    "fuziláramos": "fuzilar",
    "fuzilárei": "fuzilar",
    "fuziláreis": "fuzilar",
    "fuzilásseis": "fuzilar",
    "fuzilássemos": "fuzilar",
    "fuzilávamo": "fuzilar",
    "fuzilávamos": "fuzilar",
    "fuzilávei": "fuzilar",
    "fuziláveis": "fuzilar",
    "fuzis": "fuzil",
    "fuás": "fuá",
    "fuças": "fuça",
    "fá": "fazer",
    "fábricas": "fábrica",
    "fábulas": "fábula",
    "fáceis": "fácil",
    "fáculas": "fácula",
    "fádica": "fádico",
    "fádicas": "fádico",
    "fádicos": "fádico",
    "fáleras": "fálera",
    "fálica": "fálico",
    "fálicas": "fálico",
    "fálicos": "fálico",
    "fármacos": "fármaco",
    "fárrea": "fárreo",
    "fárreas": "fárreo",
    "fárreos": "fárreo",
    "fás": "fá",
    "fátua": "fátuo",
    "fátuas": "fátuo",
    "fátuos": "fátuo",
    "fáunulas": "fáunula",
    "fâmulos": "fâmulo",
    "fâneros": "fânero",
    "fãs": "fã",
    "féculas": "fécula",
    "féis": "fel",
    "félea": "féleo",
    "féleas": "féleo",
    "féleos": "féleo",
    "félidas": "félida",
    "félsica": "félsico",
    "félsicas": "félsico",
    "félsicos": "félsico",
    "fémica": "fémico",
    "fémicas": "fémico",
    "fémicos": "fémico",
    "fémures": "fémur",
    "fénica": "fénico",
    "fénicas": "fénico",
    "fénicos": "fénico",
    "fénixes": "fénix",
    "féretros": "féretro",
    "férias": "féria",
    "férmios": "férmio",
    "férrea": "férreo",
    "férreas": "férreo",
    "férreos": "férreo",
    "férteis": "fértil",
    "férulas": "férula",
    "férvea": "férveo",
    "férveas": "férveo",
    "férveos": "férveo",
    "férvida": "férvido",
    "férvidas": "férvido",
    "férvidos": "férvido",
    "fés": "fé",
    "fétida": "fétido",
    "fétidas": "fétido",
    "fétidos": "fétido",
    "fê": "fazer",
    "fêmea": "macho",
    "fêmeas": "macho",
    "fêmeos": "fêmeo",
    "fês": "fê",
    "fêtões": "fêtão",
    "fêveras": "fêvera",
    "fíbulas": "fíbula",
    "fífias": "fífia",
    "fígados": "fígado",
    "fígaros": "fígaro",
    "fígulos": "fígulo",
    "fílmica": "fílmico",
    "fílmicas": "fílmico",
    "fílmicos": "fílmico",
    "fílulas": "fílula",
    "fímbrias": "fímbria",
    "física": "físico",
    "físicas": "físico",
    "físicos": "físico",
    "físseis": "físsil",
    "fístulas": "fístula",
    "fócia": "fócio",
    "fócias": "fócio",
    "fócios": "fócio",
    "fóias": "fóia",
    "fóides": "fóide",
    "fólica": "fólico",
    "fólicas": "fólico",
    "fólicos": "fólico",
    "fólios": "fólio",
    "fónica": "fónico",
    "fónicas": "fónico",
    "fónicos": "fónico",
    "fórcipes": "fórcipe",
    "fórfexes": "fórfex",
    "fórfices": "fórfice",
    "fórmica": "fórmico",
    "fórmicas": "fórmico",
    "fórmicos": "fórmico",
    "fórmulas": "fórmula",
    "fórnices": "fórnice",
    "fóruns": "fórum",
    "fósforos": "fósforo",
    "fósseis": "fóssil",
    "fóssulas": "fóssula",
    "fôlegos": "fôlego",
    "fôramo": "ser",
    "fôramos": "ser",
    "fôrei": "ser",
    "fôreis": "ser",
    "fôsseis": "ser",
    "fôssemos": "ser",
    "fúchsias": "fúchsia",
    "fúfia": "fúfio",
    "fúfias": "fúfio",
    "fúfios": "fúfio",
    "fúlgida": "fúlgido",
    "fúlgidas": "fúlgido",
    "fúlgidos": "fúlgido",
    "fúlgura": "fúlguro",
    "fúlguras": "fúlguro",
    "fúlguros": "fúlguro",
    "fúlvida": "fúlvido",
    "fúlvidas": "fúlvido",
    "fúlvidos": "fúlvido",
    "fúmea": "fúmeo",
    "fúmeas": "fúmeo",
    "fúmeos": "fúmeo",
    "fúmida": "fúmido",
    "fúmidas": "fúmido",
    "fúmidos": "fúmido",
    "fúnebres": "fúnebre",
    "fúngica": "fúngico",
    "fúngicas": "fúngico",
    "fúngicos": "fúngico",
    "fúrculas": "fúrcula",
    "fúrias": "fúria",
    "fúsis": "fúsil",
    "fúteis": "fútil",
    "gaba": "gabar",
    "gabada": "gabar",
    "gabadas": "gabar",
    "gabadelas": "gabadela",
    "gabado": "gabar",
    "gabadora": "gabador",
    "gabadoras": "gabador",
    "gabadores": "gabador",
    "gabados": "gabar",
    "gabadíssima": "gabado",
    "gabadíssimas": "gabado",
    "gabadíssimo": "gabado",
    "gabadíssimos": "gabado",
    "gabai": "gabar",
    "gabais": "gabar",
    "gabam": "gabar",
    "gabamentos": "gabamento",
    "gabamo": "gabar",
    "gabamos": "gabar",
    "gabando": "gabar",
    "gabanelas": "gabanela",
    "gabanças": "gabança",
    "gabanços": "gabanço",
    "gabaonitas": "gabaonita",
    "gabara": "gabar",
    "gabaram": "gabar",
    "gabaras": "gabar",
    "gabarde": "gabar",
    "gabardes": "gabar",
    "gabardinas": "gabardina",
    "gabardines": "gabardine",
    "gabardos": "gabardo",
    "gabare": "gabar",
    "gabarei": "gabar",
    "gabareis": "gabar",
    "gabarem": "gabar",
    "gabaremos": "gabar",
    "gabares": "gabar",
    "gabaria": "gabar",
    "gabariam": "gabar",
    "gabarias": "gabar",
    "gabaritagens": "gabaritagem",
    "gabaritos": "gabarito",
    "gabarmo": "gabar",
    "gabarmos": "gabar",
    "gabarolas": "gabarola",
    "gabarolices": "gabarolice",
    "gabarotes": "gabarote",
    "gabarras": "gabarra",
    "gabarreira": "gabarreiro",
    "gabarreiras": "gabarreiro",
    "gabarreiros": "gabarreiro",
    "gabarrices": "gabarrice",
    "gabarros": "gabarro",
    "gabará": "gabar",
    "gabarás": "gabar",
    "gabarão": "gabar",
    "gabaríamos": "gabar",
    "gabaríeis": "gabar",
    "gabas": "gabar",
    "gabasse": "gabar",
    "gabassem": "gabar",
    "gabasses": "gabar",
    "gabaste": "gabar",
    "gabastes": "gabar",
    "gabatórios": "gabatório",
    "gabava": "gabar",
    "gabavam": "gabar",
    "gabavas": "gabar",
    "gabazolas": "gabazola",
    "gabaços": "gabaço",
    "gabações": "gabação",
    "gabe": "gabar",
    "gabei": "gabar",
    "gabeis": "gabar",
    "gabelas": "gabela",
    "gabelos": "gabelo",
    "gabem": "gabar",
    "gabemo": "gabar",
    "gabemos": "gabar",
    "gabes": "gabar",
    "gabia": "gabiar",
    "gabiada": "gabiar",
    "gabiadas": "gabiar",
    "gabiado": "gabiar",
    "gabiados": "gabiar",
    "gabiagens": "gabiagem",
    "gabiai": "gabiar",
    "gabiais": "gabiar",
    "gabiam": "gabiar",
    "gabiamo": "gabiar",
    "gabiamos": "gabiar",
    "gabiando": "gabiar",
    "gabiara": "gabiar",
    "gabiaram": "gabiar",
    "gabiaras": "gabiar",
    "gabiardes": "gabiar",
    "gabiarei": "gabiar",
    "gabiareis": "gabiar",
    "gabiarem": "gabiar",
    "gabiaremos": "gabiar",
    "gabiares": "gabiar",
    "gabiaria": "gabiar",
    "gabiariam": "gabiar",
    "gabiarias": "gabiar",
    "gabiarmo": "gabiar",
    "gabiarmos": "gabiar",
    "gabiarras": "gabiarra",
    "gabiará": "gabiar",
    "gabiarás": "gabiar",
    "gabiarão": "gabiar",
    "gabiaríamos": "gabiar",
    "gabiaríeis": "gabiar",
    "gabias": "gabiar",
    "gabiasse": "gabiar",
    "gabiassem": "gabiar",
    "gabiasses": "gabiar",
    "gabiaste": "gabiar",
    "gabiastes": "gabiar",
    "gabiava": "gabiar",
    "gabiavam": "gabiar",
    "gabiavas": "gabiar",
    "gabie": "gabiar",
    "gabiei": "gabiar",
    "gabieis": "gabiar",
    "gabiem": "gabiar",
    "gabiemo": "gabiar",
    "gabiemos": "gabiar",
    "gabies": "gabiar",
    "gabinarda": "gabinardo",
    "gabinardas": "gabinardo",
    "gabinardos": "gabinardo",
    "gabinetes": "gabinete",
    "gabio": "gabiar",
    "gabiona": "gabionar",
    "gabionada": "gabionar",
    "gabionadas": "gabionar",
    "gabionado": "gabionar",
    "gabionadora": "gabionador",
    "gabionadoras": "gabionador",
    "gabionadores": "gabionador",
    "gabionados": "gabionar",
    "gabionai": "gabionar",
    "gabionais": "gabionar",
    "gabionam": "gabionar",
    "gabionamo": "gabionar",
    "gabionamos": "gabionar",
    "gabionando": "gabionar",
    "gabionara": "gabionar",
    "gabionaram": "gabionar",
    "gabionaras": "gabionar",
    "gabionardes": "gabionar",
    "gabionarei": "gabionar",
    "gabionareis": "gabionar",
    "gabionarem": "gabionar",
    "gabionaremos": "gabionar",
    "gabionares": "gabionar",
    "gabionaria": "gabionar",
    "gabionariam": "gabionar",
    "gabionarias": "gabionar",
    "gabionarmo": "gabionar",
    "gabionarmos": "gabionar",
    "gabionará": "gabionar",
    "gabionarás": "gabionar",
    "gabionarão": "gabionar",
    "gabionaríamos": "gabionar",
    "gabionaríeis": "gabionar",
    "gabionas": "gabionar",
    "gabionasse": "gabionar",
    "gabionassem": "gabionar",
    "gabionasses": "gabionar",
    "gabionaste": "gabionar",
    "gabionastes": "gabionar",
    "gabionava": "gabionar",
    "gabionavam": "gabionar",
    "gabionavas": "gabionar",
    "gabione": "gabionar",
    "gabionei": "gabionar",
    "gabioneis": "gabionar",
    "gabionem": "gabionar",
    "gabionemo": "gabionar",
    "gabionemos": "gabionar",
    "gabiones": "gabionar",
    "gabiono": "gabionar",
    "gabionou": "gabionar",
    "gabionámo": "gabionar",
    "gabionámos": "gabionar",
    "gabionáramo": "gabionar",
    "gabionáramos": "gabionar",
    "gabionáreis": "gabionar",
    "gabionásseis": "gabionar",
    "gabionássemos": "gabionar",
    "gabionávamo": "gabionar",
    "gabionávamos": "gabionar",
    "gabionáveis": "gabionar",
    "gabiou": "gabiar",
    "gabirua": "gabiru",
    "gabiruas": "gabiru",
    "gabirus": "gabiru",
    "gabiámo": "gabiar",
    "gabiámos": "gabiar",
    "gabiáramo": "gabiar",
    "gabiáramos": "gabiar",
    "gabiáreis": "gabiar",
    "gabiásseis": "gabiar",
    "gabiássemos": "gabiar",
    "gabiávamo": "gabiar",
    "gabiávamos": "gabiar",
    "gabiáveis": "gabiar",
    "gabiões": "gabião",
    "gabo": "gabar",
    "gabolas": "gabola",
    "gabolass": "gabolas",
    "gabona": "gabão",
    "gabonas": "gabão",
    "gabonenses": "gabonense",
    "gabonesa": "gabonês",
    "gabonesas": "gabonês",
    "gaboneses": "gabonês",
    "gabordos": "gabordo",
    "gabos": "gabo",
    "gabou": "gabar",
    "gabrielenses": "gabrielense",
    "gabros": "gabro",
    "gabá": "gabar",
    "gabámo": "gabar",
    "gabámos": "gabar",
    "gabáramo": "gabar",
    "gabáramos": "gabar",
    "gabárei": "gabar",
    "gabáreis": "gabar",
    "gabásseis": "gabar",
    "gabássemos": "gabar",
    "gabávamo": "gabar",
    "gabávamos": "gabar",
    "gabávei": "gabar",
    "gabáveis": "gabar",
    "gabões": "gabão",
    "gachas": "gacha",
    "gachetas": "gacheta",
    "gachos": "gacho",
    "gadachins": "gadachim",
    "gadanha": "gadanhar",
    "gadanhada": "gadanhar",
    "gadanhadas": "gadanhar",
    "gadanhado": "gadanhar",
    "gadanhados": "gadanhar",
    "gadanhai": "gadanhar",
    "gadanhais": "gadanhar",
    "gadanham": "gadanhar",
    "gadanhamo": "gadanhar",
    "gadanhamos": "gadanhar",
    "gadanhando": "gadanhar",
    "gadanhara": "gadanhar",
    "gadanharam": "gadanhar",
    "gadanharas": "gadanhar",
    "gadanharde": "gadanhar",
    "gadanhardes": "gadanhar",
    "gadanhare": "gadanhar",
    "gadanharei": "gadanhar",
    "gadanhareis": "gadanhar",
    "gadanharem": "gadanhar",
    "gadanharemos": "gadanhar",
    "gadanhares": "gadanhar",
    "gadanharia": "gadanhar",
    "gadanhariam": "gadanhar",
    "gadanharias": "gadanhar",
    "gadanharmo": "gadanhar",
    "gadanharmos": "gadanhar",
    "gadanhará": "gadanhar",
    "gadanharás": "gadanhar",
    "gadanharão": "gadanhar",
    "gadanharíamos": "gadanhar",
    "gadanharíeis": "gadanhar",
    "gadanhas": "gadanhar",
    "gadanhasse": "gadanhar",
    "gadanhassem": "gadanhar",
    "gadanhasses": "gadanhar",
    "gadanhaste": "gadanhar",
    "gadanhastes": "gadanhar",
    "gadanhava": "gadanhar",
    "gadanhavam": "gadanhar",
    "gadanhavas": "gadanhar",
    "gadanhe": "gadanhar",
    "gadanhei": "gadanhar",
    "gadanheira": "gadanheiro",
    "gadanheiras": "gadanheiro",
    "gadanheiros": "gadanheiro",
    "gadanheis": "gadanhar",
    "gadanhem": "gadanhar",
    "gadanhemo": "gadanhar",
    "gadanhemos": "gadanhar",
    "gadanhes": "gadanhar",
    "gadanho": "gadanhar",
    "gadanhos": "gadanho",
    "gadanhou": "gadanhar",
    "gadanhá": "gadanhar",
    "gadanhámo": "gadanhar",
    "gadanhámos": "gadanhar",
    "gadanháramo": "gadanhar",
    "gadanháramos": "gadanhar",
    "gadanhárei": "gadanhar",
    "gadanháreis": "gadanhar",
    "gadanhásseis": "gadanhar",
    "gadanhássemos": "gadanhar",
    "gadanhávamo": "gadanhar",
    "gadanhávamos": "gadanhar",
    "gadanhávei": "gadanhar",
    "gadanháveis": "gadanhar",
    "gadarias": "gadaria",
    "gadelhas": "gadelha",
    "gadelhos": "gadelho",
    "gadelhuda": "gadelhudo",
    "gadelhudas": "gadelhudo",
    "gadelhudos": "gadelhudo",
    "gademares": "gademar",
    "gaditana": "gaditano",
    "gaditanas": "gaditano",
    "gaditanos": "gaditano",
    "gadolínios": "gadolínio",
    "gados": "gado",
    "gadropes": "gadrope",
    "gadunhas": "gadunha",
    "gadunhos": "gadunho",
    "gaduínas": "gaduína",
    "gadídeos": "gadídeo",
    "gadóides": "gadóide",
    "gaeis": "gael",
    "gafa": "gafar",
    "gafada": "gafar",
    "gafadas": "gafar",
    "gafado": "gafar",
    "gafados": "gafar",
    "gafai": "gafar",
    "gafais": "gafar",
    "gafam": "gafar",
    "gafamo": "gafar",
    "gafamos": "gafar",
    "gafando": "gafar",
    "gafanhona": "gafanhão",
    "gafanhonas": "gafanhão",
    "gafanhotadas": "gafanhotada",
    "gafanhotos": "gafanhoto",
    "gafanhotões": "gafanhotão",
    "gafanhões": "gafanhão",
    "gafara": "gafar",
    "gafaram": "gafar",
    "gafaras": "gafar",
    "gafarde": "gafar",
    "gafardes": "gafar",
    "gafare": "gafar",
    "gafarei": "gafar",
    "gafareis": "gafar",
    "gafarem": "gafar",
    "gafaremos": "gafar",
    "gafares": "gafar",
    "gafaria": "gafar",
    "gafariam": "gafar",
    "gafarias": "gafaria",
    "gafarmo": "gafar",
    "gafarmos": "gafar",
    "gafará": "gafar",
    "gafarás": "gafar",
    "gafarão": "gafar",
    "gafaríamos": "gafar",
    "gafaríeis": "gafar",
    "gafas": "gafar",
    "gafasse": "gafar",
    "gafassem": "gafar",
    "gafasses": "gafar",
    "gafaste": "gafar",
    "gafastes": "gafar",
    "gafava": "gafar",
    "gafavam": "gafar",
    "gafavas": "gafar",
    "gafe": "gafar",
    "gafei": "gafar",
    "gafeira": "gafeirar",
    "gafeirada": "gafeirar",
    "gafeiradas": "gafeirar",
    "gafeirado": "gafeirar",
    "gafeirados": "gafeirar",
    "gafeirai": "gafeirar",
    "gafeirais": "gafeirar",
    "gafeiram": "gafeirar",
    "gafeiramo": "gafeirar",
    "gafeiramos": "gafeirar",
    "gafeirando": "gafeirar",
    "gafeirara": "gafeirar",
    "gafeiraram": "gafeirar",
    "gafeiraras": "gafeirar",
    "gafeirarde": "gafeirar",
    "gafeirardes": "gafeirar",
    "gafeirare": "gafeirar",
    "gafeirarei": "gafeirar",
    "gafeirareis": "gafeirar",
    "gafeirarem": "gafeirar",
    "gafeiraremos": "gafeirar",
    "gafeirares": "gafeirar",
    "gafeiraria": "gafeirar",
    "gafeirariam": "gafeirar",
    "gafeirarias": "gafeirar",
    "gafeirarmo": "gafeirar",
    "gafeirarmos": "gafeirar",
    "gafeirará": "gafeirar",
    "gafeirarás": "gafeirar",
    "gafeirarão": "gafeirar",
    "gafeiraríamos": "gafeirar",
    "gafeiraríeis": "gafeirar",
    "gafeiras": "gafeirar",
    "gafeirasse": "gafeirar",
    "gafeirassem": "gafeirar",
    "gafeirasses": "gafeirar",
    "gafeiraste": "gafeirar",
    "gafeirastes": "gafeirar",
    "gafeirava": "gafeirar",
    "gafeiravam": "gafeirar",
    "gafeiravas": "gafeirar",
    "gafeirações": "gafeiração",
    "gafeire": "gafeirar",
    "gafeirei": "gafeirar",
    "gafeireis": "gafeirar",
    "gafeirem": "gafeirar",
    "gafeiremo": "gafeirar",
    "gafeiremos": "gafeirar",
    "gafeires": "gafeirar",
    "gafeiro": "gafeirar",
    "gafeirosa": "gafeiroso",
    "gafeirosas": "gafeiroso",
    "gafeirosos": "gafeiroso",
    "gafeirou": "gafeirar",
    "gafeirá": "gafeirar",
    "gafeirámo": "gafeirar",
    "gafeirámos": "gafeirar",
    "gafeiráramo": "gafeirar",
    "gafeiráramos": "gafeirar",
    "gafeirárei": "gafeirar",
    "gafeiráreis": "gafeirar",
    "gafeirásseis": "gafeirar",
    "gafeirássemos": "gafeirar",
    "gafeirávamo": "gafeirar",
    "gafeirávamos": "gafeirar",
    "gafeirávei": "gafeirar",
    "gafeiráveis": "gafeirar",
    "gafeis": "gafar",
    "gafem": "gafar",
    "gafemo": "gafar",
    "gafemos": "gafar",
    "gafenta": "gafento",
    "gafentas": "gafento",
    "gafentos": "gafento",
    "gafes": "gafe",
    "gafetopes": "gafetope",
    "gaffes": "gaffe",
    "gafo": "gafar",
    "gaforinas": "gaforina",
    "gaforinhas": "gaforinha",
    "gafou": "gafar",
    "gafá": "gafar",
    "gafámo": "gafar",
    "gafámos": "gafar",
    "gafáramo": "gafar",
    "gafáramos": "gafar",
    "gafárei": "gafar",
    "gafáreis": "gafar",
    "gafás": "gafá",
    "gafásseis": "gafar",
    "gafássemos": "gafar",
    "gafávamo": "gafar",
    "gafávamos": "gafar",
    "gafávei": "gafar",
    "gafáveis": "gafar",
    "gaga": "gago",
    "gagas": "gago",
    "gagatas": "gagata",
    "gagaus": "gagau",
    "gagaístas": "gagaísta",
    "gages": "gage",
    "gaginos": "gagino",
    "gagos": "gago",
    "gagosas": "gagosa",
    "gagueada": "gaguear",
    "gagueadas": "gaguear",
    "gagueado": "gaguear",
    "gagueados": "gaguear",
    "gagueai": "gaguear",
    "gagueais": "gaguear",
    "gagueamo": "gaguear",
    "gagueamos": "gaguear",
    "gagueando": "gaguear",
    "gagueara": "gaguear",
    "gaguearam": "gaguear",
    "gaguearas": "gaguear",
    "gagueardes": "gaguear",
    "gaguearei": "gaguear",
    "gagueareis": "gaguear",
    "gaguearem": "gaguear",
    "gaguearemos": "gaguear",
    "gagueares": "gaguear",
    "gaguearia": "gaguear",
    "gagueariam": "gaguear",
    "gaguearias": "gaguear",
    "gaguearmo": "gaguear",
    "gaguearmos": "gaguear",
    "gagueará": "gaguear",
    "gaguearás": "gaguear",
    "gaguearão": "gaguear",
    "gaguearíamos": "gaguear",
    "gaguearíeis": "gaguear",
    "gagueasse": "gaguear",
    "gagueassem": "gaguear",
    "gagueasses": "gaguear",
    "gagueaste": "gaguear",
    "gagueastes": "gaguear",
    "gagueava": "gaguear",
    "gagueavam": "gaguear",
    "gagueavas": "gaguear",
    "gagueei": "gaguear",
    "gagueeis": "gaguear",
    "gagueemo": "gaguear",
    "gagueemos": "gaguear",
    "gagueia": "gaguear",
    "gagueiam": "gaguear",
    "gagueias": "gaguear",
    "gagueie": "gaguear",
    "gagueiem": "gaguear",
    "gagueies": "gaguear",
    "gagueio": "gaguear",
    "gagueiras": "gagueira",
    "gagueja": "gaguejar",
    "gaguejada": "gaguejar",
    "gaguejadas": "gaguejar",
    "gaguejado": "gaguejar",
    "gaguejados": "gaguejar",
    "gaguejai": "gaguejar",
    "gaguejais": "gaguejar",
    "gaguejam": "gaguejar",
    "gaguejamentos": "gaguejamento",
    "gaguejamo": "gaguejar",
    "gaguejamos": "gaguejar",
    "gaguejando": "gaguejar",
    "gaguejara": "gaguejar",
    "gaguejaram": "gaguejar",
    "gaguejaras": "gaguejar",
    "gaguejardes": "gaguejar",
    "gaguejarei": "gaguejar",
    "gaguejareis": "gaguejar",
    "gaguejarem": "gaguejar",
    "gaguejaremos": "gaguejar",
    "gaguejares": "gaguejar",
    "gaguejaria": "gaguejar",
    "gaguejariam": "gaguejar",
    "gaguejarias": "gaguejar",
    "gaguejarmo": "gaguejar",
    "gaguejarmos": "gaguejar",
    "gaguejará": "gaguejar",
    "gaguejarás": "gaguejar",
    "gaguejarão": "gaguejar",
    "gaguejaríamos": "gaguejar",
    "gaguejaríeis": "gaguejar",
    "gaguejas": "gaguejar",
    "gaguejasse": "gaguejar",
    "gaguejassem": "gaguejar",
    "gaguejasses": "gaguejar",
    "gaguejaste": "gaguejar",
    "gaguejastes": "gaguejar",
    "gaguejava": "gaguejar",
    "gaguejavam": "gaguejar",
    "gaguejavas": "gaguejar",
    "gagueje": "gaguejar",
    "gaguejei": "gaguejar",
    "gaguejeis": "gaguejar",
    "gaguejem": "gaguejar",
    "gaguejemo": "gaguejar",
    "gaguejemos": "gaguejar",
    "gaguejes": "gaguejar",
    "gaguejo": "gaguejar",
    "gaguejos": "gaguejo",
    "gaguejou": "gaguejar",
    "gaguejámo": "gaguejar",
    "gaguejámos": "gaguejar",
    "gaguejáramo": "gaguejar",
    "gaguejáramos": "gaguejar",
    "gaguejáreis": "gaguejar",
    "gaguejásseis": "gaguejar",
    "gaguejássemos": "gaguejar",
    "gaguejávamo": "gaguejar",
    "gaguejávamos": "gaguejar",
    "gaguejáveis": "gaguejar",
    "gagueou": "gaguear",
    "gagueámo": "gaguear",
    "gagueámos": "gaguear",
    "gagueáramo": "gaguear",
    "gagueáramos": "gaguear",
    "gagueáreis": "gaguear",
    "gagueásseis": "gaguear",
    "gagueássemos": "gaguear",
    "gagueávamo": "gaguear",
    "gagueávamos": "gaguear",
    "gagueáveis": "gaguear",
    "gaguices": "gaguice",
    "gagões": "gagão",
    "gaia": "gaiar",
    "gaiacóis": "gaiacol",
    "gaiada": "gaiar",
    "gaiadas": "gaiar",
    "gaiado": "gaiar",
    "gaiados": "gaiar",
    "gaiai": "gaiar",
    "gaiais": "gaiar",
    "gaiam": "gaiar",
    "gaiamo": "gaiar",
    "gaiamos": "gaiar",
    "gaiando": "gaiar",
    "gaiara": "gaiar",
    "gaiaram": "gaiar",
    "gaiaras": "gaiar",
    "gaiardes": "gaiar",
    "gaiarei": "gaiar",
    "gaiareis": "gaiar",
    "gaiarem": "gaiar",
    "gaiaremos": "gaiar",
    "gaiares": "gaiar",
    "gaiaria": "gaiar",
    "gaiariam": "gaiar",
    "gaiarias": "gaiar",
    "gaiarmo": "gaiar",
    "gaiarmos": "gaiar",
    "gaiará": "gaiar",
    "gaiarás": "gaiar",
    "gaiarão": "gaiar",
    "gaiaríamos": "gaiar",
    "gaiaríeis": "gaiar",
    "gaias": "gaiar",
    "gaiasse": "gaiar",
    "gaiassem": "gaiar",
    "gaiasses": "gaiar",
    "gaiaste": "gaiar",
    "gaiastes": "gaiar",
    "gaiata": "gaiato",
    "gaiatada": "gaiatar",
    "gaiatadas": "gaiatar",
    "gaiatado": "gaiatar",
    "gaiatados": "gaiatar",
    "gaiatai": "gaiatar",
    "gaiatais": "gaiatar",
    "gaiatam": "gaiatar",
    "gaiatamo": "gaiatar",
    "gaiatamos": "gaiatar",
    "gaiatando": "gaiatar",
    "gaiatara": "gaiatar",
    "gaiataram": "gaiatar",
    "gaiataras": "gaiatar",
    "gaiatardes": "gaiatar",
    "gaiatarei": "gaiatar",
    "gaiatareis": "gaiatar",
    "gaiatarem": "gaiatar",
    "gaiataremos": "gaiatar",
    "gaiatares": "gaiatar",
    "gaiataria": "gaiatar",
    "gaiatariam": "gaiatar",
    "gaiatarias": "gaiatar",
    "gaiatarmo": "gaiatar",
    "gaiatarmos": "gaiatar",
    "gaiatará": "gaiatar",
    "gaiatarás": "gaiatar",
    "gaiatarão": "gaiatar",
    "gaiataríamos": "gaiatar",
    "gaiataríeis": "gaiatar",
    "gaiatas": "gaiato",
    "gaiatasse": "gaiatar",
    "gaiatassem": "gaiatar",
    "gaiatasses": "gaiatar",
    "gaiataste": "gaiatar",
    "gaiatastes": "gaiatar",
    "gaiatava": "gaiatar",
    "gaiatavam": "gaiatar",
    "gaiatavas": "gaiatar",
    "gaiate": "gaiatar",
    "gaiatei": "gaiatar",
    "gaiateis": "gaiatar",
    "gaiatem": "gaiatar",
    "gaiatemo": "gaiatar",
    "gaiatemos": "gaiatar",
    "gaiates": "gaiatar",
    "gaiatices": "gaiatice",
    "gaiato": "gaiatar",
    "gaiatos": "gaiato",
    "gaiatou": "gaiatar",
    "gaiatámo": "gaiatar",
    "gaiatámos": "gaiatar",
    "gaiatáramo": "gaiatar",
    "gaiatáramos": "gaiatar",
    "gaiatáreis": "gaiatar",
    "gaiatásseis": "gaiatar",
    "gaiatássemos": "gaiatar",
    "gaiatávamo": "gaiatar",
    "gaiatávamos": "gaiatar",
    "gaiatáveis": "gaiatar",
    "gaiava": "gaiar",
    "gaiavam": "gaiar",
    "gaiavas": "gaiar",
    "gaibéia": "gaibéu",
    "gaibéias": "gaibéu",
    "gaibéus": "gaibéu",
    "gaie": "gaiar",
    "gaiei": "gaiar",
    "gaieis": "gaiar",
    "gaiem": "gaiar",
    "gaiemo": "gaiar",
    "gaiemos": "gaiar",
    "gaies": "gaiar",
    "gaifona": "gaifonar",
    "gaifonada": "gaifonar",
    "gaifonadas": "gaifonar",
    "gaifonado": "gaifonar",
    "gaifonados": "gaifonar",
    "gaifonai": "gaifonar",
    "gaifonais": "gaifonar",
    "gaifonam": "gaifonar",
    "gaifonamo": "gaifonar",
    "gaifonamos": "gaifonar",
    "gaifonando": "gaifonar",
    "gaifonara": "gaifonar",
    "gaifonaram": "gaifonar",
    "gaifonaras": "gaifonar",
    "gaifonardes": "gaifonar",
    "gaifonarei": "gaifonar",
    "gaifonareis": "gaifonar",
    "gaifonarem": "gaifonar",
    "gaifonaremos": "gaifonar",
    "gaifonares": "gaifonar",
    "gaifonaria": "gaifonar",
    "gaifonariam": "gaifonar",
    "gaifonarias": "gaifonar",
    "gaifonarmo": "gaifonar",
    "gaifonarmos": "gaifonar",
    "gaifonará": "gaifonar",
    "gaifonarás": "gaifonar",
    "gaifonarão": "gaifonar",
    "gaifonaríamos": "gaifonar",
    "gaifonaríeis": "gaifonar",
    "gaifonas": "gaifonar",
    "gaifonasse": "gaifonar",
    "gaifonassem": "gaifonar",
    "gaifonasses": "gaifonar",
    "gaifonaste": "gaifonar",
    "gaifonastes": "gaifonar",
    "gaifonava": "gaifonar",
    "gaifonavam": "gaifonar",
    "gaifonavas": "gaifonar",
    "gaifone": "gaifonar",
    "gaifonei": "gaifonar",
    "gaifoneis": "gaifonar",
    "gaifonem": "gaifonar",
    "gaifonemo": "gaifonar",
    "gaifonemos": "gaifonar",
    "gaifones": "gaifonar",
    "gaifonices": "gaifonice",
    "gaifono": "gaifonar",
    "gaifonou": "gaifonar",
    "gaifonámo": "gaifonar",
    "gaifonámos": "gaifonar",
    "gaifonáramo": "gaifonar",
    "gaifonáramos": "gaifonar",
    "gaifonáreis": "gaifonar",
    "gaifonásseis": "gaifonar",
    "gaifonássemos": "gaifonar",
    "gaifonávamo": "gaifonar",
    "gaifonávamos": "gaifonar",
    "gaifonáveis": "gaifonar",
    "gaio": "gaiar",
    "gaiolas": "gaiola",
    "gaioleira": "gaioleiro",
    "gaioleiras": "gaioleiro",
    "gaioleiros": "gaioleiro",
    "gaiolins": "gaiolim",
    "gaiolos": "gaiolo",
    "gaiorros": "gaiorro",
    "gaios": "gaio",
    "gaiosas": "gaiosa",
    "gaiou": "gaiar",
    "gaipas": "gaipa",
    "gaipeira": "gaipeiro",
    "gaipeiras": "gaipeiro",
    "gaipeiros": "gaipeiro",
    "gaipelos": "gaipelo",
    "gaiperras": "gaiperra",
    "gaipilhas": "gaipilha",
    "gaipos": "gaipo",
    "gais": "gal",
    "gaita": "gaitar",
    "gaitada": "gaitar",
    "gaitadas": "gaitar",
    "gaitado": "gaitar",
    "gaitados": "gaitar",
    "gaitai": "gaitar",
    "gaitais": "gaitar",
    "gaitam": "gaitar",
    "gaitamo": "gaitar",
    "gaitamos": "gaitar",
    "gaitando": "gaitar",
    "gaitara": "gaitar",
    "gaitaram": "gaitar",
    "gaitaras": "gaitar",
    "gaitarde": "gaitar",
    "gaitardes": "gaitar",
    "gaitare": "gaitar",
    "gaitarei": "gaitar",
    "gaitareis": "gaitar",
    "gaitarem": "gaitar",
    "gaitaremos": "gaitar",
    "gaitares": "gaitar",
    "gaitaria": "gaitar",
    "gaitariam": "gaitar",
    "gaitarias": "gaitar",
    "gaitarmo": "gaitar",
    "gaitarmos": "gaitar",
    "gaitará": "gaitar",
    "gaitarás": "gaitar",
    "gaitarão": "gaitar",
    "gaitaríamos": "gaitar",
    "gaitaríeis": "gaitar",
    "gaitas": "gaitar",
    "gaitasse": "gaitar",
    "gaitassem": "gaitar",
    "gaitasses": "gaitar",
    "gaitaste": "gaitar",
    "gaitastes": "gaitar",
    "gaitava": "gaitar",
    "gaitavam": "gaitar",
    "gaitavas": "gaitar",
    "gaite": "gaitar",
    "gaiteada": "gaitear",
    "gaiteadas": "gaitear",
    "gaiteado": "gaitear",
    "gaiteados": "gaitear",
    "gaiteai": "gaitear",
    "gaiteais": "gaitear",
    "gaiteamo": "gaitear",
    "gaiteamos": "gaitear",
    "gaiteando": "gaitear",
    "gaiteara": "gaitear",
    "gaitearam": "gaitear",
    "gaitearas": "gaitear",
    "gaiteardes": "gaitear",
    "gaitearei": "gaitear",
    "gaiteareis": "gaitear",
    "gaitearem": "gaitear",
    "gaitearemos": "gaitear",
    "gaiteares": "gaitear",
    "gaitearia": "gaitear",
    "gaiteariam": "gaitear",
    "gaitearias": "gaitear",
    "gaitearmo": "gaitear",
    "gaitearmos": "gaitear",
    "gaiteará": "gaitear",
    "gaitearás": "gaitear",
    "gaitearão": "gaitear",
    "gaitearíamos": "gaitear",
    "gaitearíeis": "gaitear",
    "gaiteasse": "gaitear",
    "gaiteassem": "gaitear",
    "gaiteasses": "gaitear",
    "gaiteaste": "gaitear",
    "gaiteastes": "gaitear",
    "gaiteava": "gaitear",
    "gaiteavam": "gaitear",
    "gaiteavas": "gaitear",
    "gaiteei": "gaitear",
    "gaiteeis": "gaitear",
    "gaiteemo": "gaitear",
    "gaiteemos": "gaitear",
    "gaitei": "gaitar",
    "gaiteia": "gaitear",
    "gaiteiam": "gaitear",
    "gaiteias": "gaitear",
    "gaiteie": "gaitear",
    "gaiteiem": "gaitear",
    "gaiteies": "gaitear",
    "gaiteio": "gaitear",
    "gaiteira": "gaiteiro",
    "gaiteiras": "gaiteiro",
    "gaiteirices": "gaiteirice",
    "gaiteiros": "gaiteiro",
    "gaiteis": "gaitar",
    "gaitem": "gaitar",
    "gaitemo": "gaitar",
    "gaitemos": "gaitar",
    "gaiteou": "gaitear",
    "gaites": "gaitar",
    "gaiteámo": "gaitear",
    "gaiteámos": "gaitear",
    "gaiteáramo": "gaitear",
    "gaiteáramos": "gaitear",
    "gaiteáreis": "gaitear",
    "gaiteásseis": "gaitear",
    "gaiteássemos": "gaitear",
    "gaiteávamo": "gaitear",
    "gaiteávamos": "gaitear",
    "gaiteáveis": "gaitear",
    "gaitinha": "gaita",
    "gaitinhas": "gaita",
    "gaitita": "gaita",
    "gaititas": "gaita",
    "gaito": "gaitar",
    "gaitonas": "gaitona",
    "gaitou": "gaitar",
    "gaitá": "gaitar",
    "gaitámo": "gaitar",
    "gaitámos": "gaitar",
    "gaitáramo": "gaitar",
    "gaitáramos": "gaitar",
    "gaitárei": "gaitar",
    "gaitáreis": "gaitar",
    "gaitásseis": "gaitar",
    "gaitássemos": "gaitar",
    "gaitávamo": "gaitar",
    "gaitávamos": "gaitar",
    "gaitávei": "gaitar",
    "gaitáveis": "gaitar",
    "gaiulos": "gaiulo",
    "gaiva": "gaivar",
    "gaivada": "gaivar",
    "gaivadas": "gaivar",
    "gaivado": "gaivar",
    "gaivados": "gaivar",
    "gaivagens": "gaivagem",
    "gaivai": "gaivar",
    "gaivais": "gaivar",
    "gaivam": "gaivar",
    "gaivamo": "gaivar",
    "gaivamos": "gaivar",
    "gaivando": "gaivar",
    "gaivara": "gaivar",
    "gaivaram": "gaivar",
    "gaivaras": "gaivar",
    "gaivarde": "gaivar",
    "gaivardes": "gaivar",
    "gaivare": "gaivar",
    "gaivarei": "gaivar",
    "gaivareis": "gaivar",
    "gaivarem": "gaivar",
    "gaivaremos": "gaivar",
    "gaivares": "gaivar",
    "gaivaria": "gaivar",
    "gaivariam": "gaivar",
    "gaivarias": "gaivar",
    "gaivarmo": "gaivar",
    "gaivarmos": "gaivar",
    "gaivará": "gaivar",
    "gaivarás": "gaivar",
    "gaivarão": "gaivar",
    "gaivaríamos": "gaivar",
    "gaivaríeis": "gaivar",
    "gaivas": "gaivar",
    "gaivasse": "gaivar",
    "gaivassem": "gaivar",
    "gaivasses": "gaivar",
    "gaivaste": "gaivar",
    "gaivastes": "gaivar",
    "gaivava": "gaivar",
    "gaivavam": "gaivar",
    "gaivavas": "gaivar",
    "gaive": "gaivar",
    "gaivei": "gaivar",
    "gaiveis": "gaivel",
    "gaivem": "gaivar",
    "gaivemo": "gaivar",
    "gaivemos": "gaivar",
    "gaives": "gaivar",
    "gaivinas": "gaivina",
    "gaivinhas": "gaivinha",
    "gaivo": "gaivar",
    "gaivotas": "gaivota",
    "gaivoteada": "gaivotear",
    "gaivoteadas": "gaivotear",
    "gaivoteado": "gaivotear",
    "gaivoteados": "gaivotear",
    "gaivoteai": "gaivotear",
    "gaivoteais": "gaivotear",
    "gaivoteamo": "gaivotear",
    "gaivoteamos": "gaivotear",
    "gaivoteando": "gaivotear",
    "gaivoteara": "gaivotear",
    "gaivotearam": "gaivotear",
    "gaivotearas": "gaivotear",
    "gaivoteardes": "gaivotear",
    "gaivotearei": "gaivotear",
    "gaivoteareis": "gaivotear",
    "gaivotearem": "gaivotear",
    "gaivotearemos": "gaivotear",
    "gaivoteares": "gaivotear",
    "gaivotearia": "gaivotear",
    "gaivoteariam": "gaivotear",
    "gaivotearias": "gaivotear",
    "gaivotearmo": "gaivotear",
    "gaivotearmos": "gaivotear",
    "gaivoteará": "gaivotear",
    "gaivotearás": "gaivotear",
    "gaivotearão": "gaivotear",
    "gaivotearíamos": "gaivotear",
    "gaivotearíeis": "gaivotear",
    "gaivoteasse": "gaivotear",
    "gaivoteassem": "gaivotear",
    "gaivoteasses": "gaivotear",
    "gaivoteaste": "gaivotear",
    "gaivoteastes": "gaivotear",
    "gaivoteava": "gaivotear",
    "gaivoteavam": "gaivotear",
    "gaivoteavas": "gaivotear",
    "gaivoteei": "gaivotear",
    "gaivoteeis": "gaivotear",
    "gaivoteemo": "gaivotear",
    "gaivoteemos": "gaivotear",
    "gaivoteia": "gaivotear",
    "gaivoteiam": "gaivotear",
    "gaivoteias": "gaivotear",
    "gaivoteie": "gaivotear",
    "gaivoteiem": "gaivotear",
    "gaivoteies": "gaivotear",
    "gaivoteio": "gaivotear",
    "gaivoteou": "gaivotear",
    "gaivoteámo": "gaivotear",
    "gaivoteámos": "gaivotear",
    "gaivoteáramo": "gaivotear",
    "gaivoteáramos": "gaivotear",
    "gaivoteáreis": "gaivotear",
    "gaivoteásseis": "gaivotear",
    "gaivoteássemos": "gaivotear",
    "gaivoteávamo": "gaivotear",
    "gaivoteávamos": "gaivotear",
    "gaivoteáveis": "gaivotear",
    "gaivotões": "gaivotão",
    "gaivou": "gaivar",
    "gaivá": "gaivar",
    "gaivámo": "gaivar",
    "gaivámos": "gaivar",
    "gaiváramo": "gaivar",
    "gaiváramos": "gaivar",
    "gaivárei": "gaivar",
    "gaiváreis": "gaivar",
    "gaivásseis": "gaivar",
    "gaivássemos": "gaivar",
    "gaivávamo": "gaivar",
    "gaivávamos": "gaivar",
    "gaivávei": "gaivar",
    "gaiváveis": "gaivar",
    "gaivões": "gaivão",
    "gaiámo": "gaiar",
    "gaiámos": "gaiar",
    "gaiáramo": "gaiar",
    "gaiáramos": "gaiar",
    "gaiáreis": "gaiar",
    "gaiásseis": "gaiar",
    "gaiássemos": "gaiar",
    "gaiávamo": "gaiar",
    "gaiávamos": "gaiar",
    "gaiáveis": "gaiar",
    "gaiútas": "gaiúta",
    "gaja": "gajo",
    "gajada": "gajar",
    "gajadas": "gajar",
    "gajado": "gajar",
    "gajados": "gajar",
    "gajai": "gajar",
    "gajais": "gajar",
    "gajam": "gajar",
    "gajamo": "gajar",
    "gajamos": "gajar",
    "gajando": "gajar",
    "gajandumbos": "gajandumbo",
    "gajara": "gajar",
    "gajaram": "gajar",
    "gajaras": "gajar",
    "gajardes": "gajar",
    "gajarei": "gajar",
    "gajareis": "gajar",
    "gajarem": "gajar",
    "gajaremos": "gajar",
    "gajares": "gajar",
    "gajaria": "gajar",
    "gajariam": "gajar",
    "gajarias": "gajar",
    "gajarmo": "gajar",
    "gajarmos": "gajar",
    "gajará": "gajar",
    "gajarás": "gajar",
    "gajarão": "gajar",
    "gajaríamos": "gajar",
    "gajaríeis": "gajar",
    "gajas": "gajo",
    "gajasse": "gajar",
    "gajassem": "gajar",
    "gajasses": "gajar",
    "gajaste": "gajar",
    "gajastes": "gajar",
    "gajatas": "gajata",
    "gajatos": "gajato",
    "gajava": "gajar",
    "gajavam": "gajar",
    "gajavas": "gajar",
    "gajavatos": "gajavato",
    "gaje": "gajar",
    "gajei": "gajar",
    "gajeiros": "gajeiro",
    "gajeis": "gajar",
    "gajem": "gajar",
    "gajemo": "gajar",
    "gajemos": "gajar",
    "gajes": "gajar",
    "gajices": "gajice",
    "gajo": "gajar",
    "gajona": "gajão",
    "gajonas": "gajão",
    "gajos": "gajo",
    "gajou": "gajar",
    "gajámo": "gajar",
    "gajámos": "gajar",
    "gajáramo": "gajar",
    "gajáramos": "gajar",
    "gajáreis": "gajar",
    "gajásseis": "gajar",
    "gajássemos": "gajar",
    "gajávamo": "gajar",
    "gajávamos": "gajar",
    "gajáveis": "gajar",
    "gajés": "gajé",
    "gajões": "gajão",
    "gala": "galar",
    "galacristas": "galacrista",
    "galactagoga": "galactagogo",
    "galactagogas": "galactagogo",
    "galactagogos": "galactagogo",
    "galactites": "galactite",
    "galactoceles": "galactocele",
    "galactologias": "galactologia",
    "galactométrica": "galactométrico",
    "galactométricas": "galactométrico",
    "galactométricos": "galactométrico",
    "galactorreias": "galactorreia",
    "galactorréica": "galactorréico",
    "galactorréicas": "galactorréico",
    "galactorréicos": "galactorréico",
    "galactoses": "galactose",
    "galactífaga": "galactífago",
    "galactífagas": "galactífago",
    "galactífagos": "galactífago",
    "galactífera": "galactífero",
    "galactíferas": "galactífero",
    "galactíferos": "galactífero",
    "galactófaga": "galactófago",
    "galactófagas": "galactófago",
    "galactófagos": "galactófago",
    "galactófora": "galactóforo",
    "galactóforas": "galactóforo",
    "galactóforos": "galactóforo",
    "galactómetros": "galactómetro",
    "galactósica": "galactósico",
    "galactósicas": "galactósico",
    "galactósicos": "galactósico",
    "galada": "galar",
    "galadas": "galar",
    "galado": "galar",
    "galados": "galar",
    "galaduras": "galadura",
    "galafuras": "galafura",
    "galagalas": "galagala",
    "galai": "galar",
    "galaica": "galaico",
    "galaicas": "galaico",
    "galaicos": "galaico",
    "galaios": "galaio",
    "galais": "galar",
    "galalaus": "galalau",
    "galalites": "galalite",
    "galam": "galar",
    "galamo": "galar",
    "galamos": "galar",
    "galando": "galar",
    "galaneada": "galanear",
    "galaneadas": "galanear",
    "galaneado": "galanear",
    "galaneados": "galanear",
    "galaneai": "galanear",
    "galaneais": "galanear",
    "galaneamo": "galanear",
    "galaneamos": "galanear",
    "galaneando": "galanear",
    "galaneara": "galanear",
    "galanearam": "galanear",
    "galanearas": "galanear",
    "galaneardes": "galanear",
    "galanearei": "galanear",
    "galaneareis": "galanear",
    "galanearem": "galanear",
    "galanearemos": "galanear",
    "galaneares": "galanear",
    "galanearia": "galanear",
    "galaneariam": "galanear",
    "galanearias": "galanear",
    "galanearmo": "galanear",
    "galanearmos": "galanear",
    "galaneará": "galanear",
    "galanearás": "galanear",
    "galanearão": "galanear",
    "galanearíamos": "galanear",
    "galanearíeis": "galanear",
    "galaneasse": "galanear",
    "galaneassem": "galanear",
    "galaneasses": "galanear",
    "galaneaste": "galanear",
    "galaneastes": "galanear",
    "galaneava": "galanear",
    "galaneavam": "galanear",
    "galaneavas": "galanear",
    "galaneei": "galanear",
    "galaneeis": "galanear",
    "galaneemo": "galanear",
    "galaneemos": "galanear",
    "galaneia": "galanear",
    "galaneiam": "galanear",
    "galaneias": "galanear",
    "galaneie": "galanear",
    "galaneiem": "galanear",
    "galaneies": "galanear",
    "galaneio": "galanear",
    "galaneou": "galanear",
    "galaneámo": "galanear",
    "galaneámos": "galanear",
    "galaneáramo": "galanear",
    "galaneáramos": "galanear",
    "galaneáreis": "galanear",
    "galaneásseis": "galanear",
    "galaneássemos": "galanear",
    "galaneávamo": "galanear",
    "galaneávamos": "galanear",
    "galaneáveis": "galanear",
    "galangas": "galanga",
    "galangundos": "galangundo",
    "galangômbias": "galangômbia",
    "galanices": "galanice",
    "galantarias": "galantaria",
    "galanteada": "galantear",
    "galanteadas": "galantear",
    "galanteado": "galantear",
    "galanteadora": "galanteador",
    "galanteadoras": "galanteador",
    "galanteadores": "galanteador",
    "galanteados": "galantear",
    "galanteai": "galantear",
    "galanteais": "galantear",
    "galanteamo": "galantear",
    "galanteamos": "galantear",
    "galanteando": "galantear",
    "galanteara": "galantear",
    "galantearam": "galantear",
    "galantearas": "galantear",
    "galanteardes": "galantear",
    "galantearei": "galantear",
    "galanteareis": "galantear",
    "galantearem": "galantear",
    "galantearemos": "galantear",
    "galanteares": "galantear",
    "galantearia": "galantear",
    "galanteariam": "galantear",
    "galantearias": "galantear",
    "galantearmo": "galantear",
    "galantearmos": "galantear",
    "galanteará": "galantear",
    "galantearás": "galantear",
    "galantearão": "galantear",
    "galantearíamos": "galantear",
    "galantearíeis": "galantear",
    "galanteasse": "galantear",
    "galanteassem": "galantear",
    "galanteasses": "galantear",
    "galanteaste": "galantear",
    "galanteastes": "galantear",
    "galanteava": "galantear",
    "galanteavam": "galantear",
    "galanteavas": "galantear",
    "galanteei": "galantear",
    "galanteeis": "galantear",
    "galanteemo": "galantear",
    "galanteemos": "galantear",
    "galanteia": "galantear",
    "galanteiam": "galantear",
    "galanteias": "galantear",
    "galanteie": "galantear",
    "galanteiem": "galantear",
    "galanteies": "galantear",
    "galanteio": "galantear",
    "galanteios": "galanteio",
    "galanteou": "galantear",
    "galanterias": "galanteria",
    "galantes": "galante",
    "galanteámo": "galantear",
    "galanteámos": "galantear",
    "galanteáramo": "galantear",
    "galanteáramos": "galantear",
    "galanteáreis": "galantear",
    "galanteásseis": "galantear",
    "galanteássemos": "galantear",
    "galanteávamo": "galantear",
    "galanteávamos": "galantear",
    "galanteáveis": "galantear",
    "galantinas": "galantina",
    "galantines": "galantine",
    "galantinha": "galante",
    "galantinhas": "galante",
    "galantinho": "galante",
    "galantinhos": "galante",
    "galantita": "galante",
    "galantitas": "galante",
    "galantito": "galante",
    "galantitos": "galante",
    "galapos": "galapo",
    "galapões": "galapão",
    "galara": "galar",
    "galaram": "galar",
    "galaras": "galar",
    "galarde": "galar",
    "galardes": "galar",
    "galardoa": "galardoar",
    "galardoada": "galardoar",
    "galardoadas": "galardoar",
    "galardoado": "galardoar",
    "galardoadora": "galardoador",
    "galardoadoras": "galardoador",
    "galardoadores": "galardoador",
    "galardoados": "galardoar",
    "galardoai": "galardoar",
    "galardoais": "galardoar",
    "galardoam": "galardoar",
    "galardoamo": "galardoar",
    "galardoamos": "galardoar",
    "galardoando": "galardoar",
    "galardoara": "galardoar",
    "galardoaram": "galardoar",
    "galardoaras": "galardoar",
    "galardoarde": "galardoar",
    "galardoardes": "galardoar",
    "galardoare": "galardoar",
    "galardoarei": "galardoar",
    "galardoareis": "galardoar",
    "galardoarem": "galardoar",
    "galardoaremos": "galardoar",
    "galardoares": "galardoar",
    "galardoaria": "galardoar",
    "galardoariam": "galardoar",
    "galardoarias": "galardoar",
    "galardoarmo": "galardoar",
    "galardoarmos": "galardoar",
    "galardoará": "galardoar",
    "galardoarás": "galardoar",
    "galardoarão": "galardoar",
    "galardoaríamos": "galardoar",
    "galardoaríeis": "galardoar",
    "galardoas": "galardoar",
    "galardoasse": "galardoar",
    "galardoassem": "galardoar",
    "galardoasses": "galardoar",
    "galardoaste": "galardoar",
    "galardoastes": "galardoar",
    "galardoava": "galardoar",
    "galardoavam": "galardoar",
    "galardoavas": "galardoar",
    "galardoe": "galardoar",
    "galardoei": "galardoar",
    "galardoeis": "galardoar",
    "galardoem": "galardoar",
    "galardoemo": "galardoar",
    "galardoemos": "galardoar",
    "galardoes": "galardoar",
    "galardoo": "galardoar",
    "galardoou": "galardoar",
    "galardoá": "galardoar",
    "galardoámo": "galardoar",
    "galardoámos": "galardoar",
    "galardoáramo": "galardoar",
    "galardoáramos": "galardoar",
    "galardoárei": "galardoar",
    "galardoáreis": "galardoar",
    "galardoásseis": "galardoar",
    "galardoássemos": "galardoar",
    "galardoávamo": "galardoar",
    "galardoávamos": "galardoar",
    "galardoávei": "galardoar",
    "galardoáveis": "galardoar",
    "galardões": "galardão",
    "galare": "galar",
    "galarei": "galar",
    "galareis": "galar",
    "galarem": "galar",
    "galaremos": "galar",
    "galares": "galar",
    "galaria": "galar",
    "galariam": "galar",
    "galarias": "galar",
    "galarins": "galarim",
    "galarmo": "galar",
    "galarmos": "galar",
    "galará": "galar",
    "galarás": "galar",
    "galarão": "galar",
    "galaríamos": "galar",
    "galaríeis": "galar",
    "galas": "galar",
    "galasse": "galar",
    "galassem": "galar",
    "galasses": "galar",
    "galaste": "galar",
    "galastes": "galar",
    "galava": "galar",
    "galavam": "galar",
    "galavas": "galar",
    "galazias": "galazia",
    "galazimes": "galazime",
    "galações": "galação",
    "galbos": "galbo",
    "galciparlas": "galciparla",
    "galderia": "galderiar",
    "galderiada": "galderiar",
    "galderiadas": "galderiar",
    "galderiado": "galderiar",
    "galderiados": "galderiar",
    "galderiai": "galderiar",
    "galderiais": "galderiar",
    "galderiam": "galderiar",
    "galderiamo": "galderiar",
    "galderiamos": "galderiar",
    "galderiando": "galderiar",
    "galderiara": "galderiar",
    "galderiaram": "galderiar",
    "galderiaras": "galderiar",
    "galderiardes": "galderiar",
    "galderiarei": "galderiar",
    "galderiareis": "galderiar",
    "galderiarem": "galderiar",
    "galderiaremos": "galderiar",
    "galderiares": "galderiar",
    "galderiaria": "galderiar",
    "galderiariam": "galderiar",
    "galderiarias": "galderiar",
    "galderiarmo": "galderiar",
    "galderiarmos": "galderiar",
    "galderiará": "galderiar",
    "galderiarás": "galderiar",
    "galderiarão": "galderiar",
    "galderiaríamos": "galderiar",
    "galderiaríeis": "galderiar",
    "galderias": "galderiar",
    "galderiasse": "galderiar",
    "galderiassem": "galderiar",
    "galderiasses": "galderiar",
    "galderiaste": "galderiar",
    "galderiastes": "galderiar",
    "galderiava": "galderiar",
    "galderiavam": "galderiar",
    "galderiavas": "galderiar",
    "galderie": "galderiar",
    "galderiei": "galderiar",
    "galderieis": "galderiar",
    "galderiem": "galderiar",
    "galderiemo": "galderiar",
    "galderiemos": "galderiar",
    "galderies": "galderiar",
    "galderio": "galderiar",
    "galderiou": "galderiar",
    "galderiámo": "galderiar",
    "galderiámos": "galderiar",
    "galderiáramo": "galderiar",
    "galderiáramos": "galderiar",
    "galderiáreis": "galderiar",
    "galderiásseis": "galderiar",
    "galderiássemos": "galderiar",
    "galderiávamo": "galderiar",
    "galderiávamos": "galderiar",
    "galderiáveis": "galderiar",
    "galdrapas": "galdrapa",
    "galdripeira": "galdripeiro",
    "galdripeiras": "galdripeiro",
    "galdripeiros": "galdripeiro",
    "galdéria": "galdério",
    "galdérias": "galdério",
    "galdérios": "galdério",
    "gale": "galar",
    "galeada": "galear",
    "galeadas": "galear",
    "galeado": "galear",
    "galeados": "galear",
    "galeai": "galear",
    "galeais": "galear",
    "galeamo": "galear",
    "galeamos": "galear",
    "galeando": "galear",
    "galeantropias": "galeantropia",
    "galeantrópica": "galeantrópico",
    "galeantrópicas": "galeantrópico",
    "galeantrópicos": "galeantrópico",
    "galeara": "galear",
    "galearam": "galear",
    "galearas": "galear",
    "galeardes": "galear",
    "galearei": "galear",
    "galeareis": "galear",
    "galearem": "galear",
    "galearemos": "galear",
    "galeares": "galear",
    "galearia": "galear",
    "galeariam": "galear",
    "galearias": "galear",
    "galearmo": "galear",
    "galearmos": "galear",
    "galeará": "galear",
    "galearás": "galear",
    "galearão": "galear",
    "galearíamos": "galear",
    "galearíeis": "galear",
    "galeasse": "galear",
    "galeassem": "galear",
    "galeasses": "galear",
    "galeaste": "galear",
    "galeastes": "galear",
    "galeava": "galear",
    "galeavam": "galear",
    "galeavas": "galear",
    "galeaças": "galeaça",
    "galeei": "galear",
    "galeeis": "galear",
    "galeemo": "galear",
    "galeemos": "galear",
    "galega": "galego",
    "galegadas": "galegada",
    "galegas": "galego",
    "galegos": "galego",
    "galeguices": "galeguice",
    "galei": "galar",
    "galeia": "galear",
    "galeiam": "galear",
    "galeias": "galear",
    "galeie": "galear",
    "galeiem": "galear",
    "galeies": "galear",
    "galeiformes": "galeiforme",
    "galeio": "galear",
    "galeios": "galeio",
    "galeirões": "galeirão",
    "galeis": "galar",
    "galelas": "galela",
    "galelos": "galelo",
    "galem": "galar",
    "galemo": "galar",
    "galemos": "galar",
    "galenas": "galena",
    "galengues": "galengue",
    "galenismos": "galenismo",
    "galenistas": "galenista",
    "galenites": "galenite",
    "galenos": "galeno",
    "galenses": "galense",
    "galenítica": "galenítico",
    "galeníticas": "galenítico",
    "galeníticos": "galenítico",
    "galeofobias": "galeofobia",
    "galeofóbica": "galeofóbico",
    "galeofóbicas": "galeofóbico",
    "galeofóbicos": "galeofóbico",
    "galeonetes": "galeonete",
    "galeopitecos": "galeopiteco",
    "galeotas": "galeota",
    "galeotes": "galeote",
    "galeou": "galear",
    "galeras": "galera",
    "galeriana": "galeriano",
    "galerianas": "galeriano",
    "galerianos": "galeriano",
    "galerias": "galeria",
    "galeristas": "galerista",
    "galerna": "galerno",
    "galernas": "galerno",
    "galernos": "galerno",
    "galeros": "galero",
    "gales": "galar",
    "galesa": "galês",
    "galesas": "galês",
    "galeses": "galês",
    "galezias": "galezia",
    "galeámo": "galear",
    "galeámos": "galear",
    "galeáramo": "galear",
    "galeáramos": "galear",
    "galeáreis": "galear",
    "galeásseis": "galear",
    "galeássemos": "galear",
    "galeávamo": "galear",
    "galeávamos": "galear",
    "galeáveis": "galear",
    "galeófoba": "galeófobo",
    "galeófobas": "galeófobo",
    "galeófobos": "galeófobo",
    "galeões": "galeão",
    "galfarros": "galfarro",
    "galfeiras": "galfeira",
    "galfoeiras": "galfoeira",
    "galga": "galgo",
    "galgada": "galgar",
    "galgadas": "galgar",
    "galgadeiras": "galgadeira",
    "galgado": "galgar",
    "galgados": "galgar",
    "galgai": "galgar",
    "galgais": "galgar",
    "galgam": "galgar",
    "galgamo": "galgar",
    "galgamos": "galgar",
    "galgando": "galgar",
    "galgara": "galgar",
    "galgaram": "galgar",
    "galgaras": "galgar",
    "galgarde": "galgar",
    "galgardes": "galgar",
    "galgare": "galgar",
    "galgarei": "galgar",
    "galgareis": "galgar",
    "galgarem": "galgar",
    "galgaremos": "galgar",
    "galgares": "galgar",
    "galgaria": "galgar",
    "galgariam": "galgar",
    "galgarias": "galgar",
    "galgarmo": "galgar",
    "galgarmos": "galgar",
    "galgará": "galgar",
    "galgarás": "galgar",
    "galgarão": "galgar",
    "galgaríamos": "galgar",
    "galgaríeis": "galgar",
    "galgas": "galgo",
    "galgasse": "galgar",
    "galgassem": "galgar",
    "galgasses": "galgar",
    "galgaste": "galgar",
    "galgastes": "galgar",
    "galgava": "galgar",
    "galgavam": "galgar",
    "galgavas": "galgar",
    "galgazes": "galgaz",
    "galgações": "galgação",
    "galgo": "galgar",
    "galgos": "galgo",
    "galgou": "galgar",
    "galgue": "galgar",
    "galguei": "galgar",
    "galgueira": "galgueiro",
    "galgueiras": "galgueiro",
    "galgueiros": "galgueiro",
    "galgueis": "galgar",
    "galguem": "galgar",
    "galguemo": "galgar",
    "galguemos": "galgar",
    "galgues": "galgar",
    "galguinha": "galgo",
    "galguinhas": "galgo",
    "galguinho": "galgo",
    "galguinhos": "galgo",
    "galguita": "galgo",
    "galguitas": "galgo",
    "galguito": "galgo",
    "galguitos": "galgo",
    "galgá": "galgar",
    "galgámo": "galgar",
    "galgámos": "galgar",
    "galgáramo": "galgar",
    "galgáramos": "galgar",
    "galgárei": "galgar",
    "galgáreis": "galgar",
    "galgásseis": "galgar",
    "galgássemos": "galgar",
    "galgávamo": "galgar",
    "galgávamos": "galgar",
    "galgávei": "galgar",
    "galgáveis": "galgar",
    "galhadas": "galhada",
    "galhaduras": "galhadura",
    "galharda": "galhardo",
    "galhardas": "galhardo",
    "galhardeada": "galhardear",
    "galhardeadas": "galhardear",
    "galhardeado": "galhardear",
    "galhardeados": "galhardear",
    "galhardeai": "galhardear",
    "galhardeais": "galhardear",
    "galhardeamo": "galhardear",
    "galhardeamos": "galhardear",
    "galhardeando": "galhardear",
    "galhardeara": "galhardear",
    "galhardearam": "galhardear",
    "galhardearas": "galhardear",
    "galhardeardes": "galhardear",
    "galhardearei": "galhardear",
    "galhardeareis": "galhardear",
    "galhardearem": "galhardear",
    "galhardearemos": "galhardear",
    "galhardeares": "galhardear",
    "galhardearia": "galhardear",
    "galhardeariam": "galhardear",
    "galhardearias": "galhardear",
    "galhardearmo": "galhardear",
    "galhardearmos": "galhardear",
    "galhardeará": "galhardear",
    "galhardearás": "galhardear",
    "galhardearão": "galhardear",
    "galhardearíamos": "galhardear",
    "galhardearíeis": "galhardear",
    "galhardeasse": "galhardear",
    "galhardeassem": "galhardear",
    "galhardeasses": "galhardear",
    "galhardeaste": "galhardear",
    "galhardeastes": "galhardear",
    "galhardeava": "galhardear",
    "galhardeavam": "galhardear",
    "galhardeavas": "galhardear",
    "galhardeei": "galhardear",
    "galhardeeis": "galhardear",
    "galhardeemo": "galhardear",
    "galhardeemos": "galhardear",
    "galhardeia": "galhardear",
    "galhardeiam": "galhardear",
    "galhardeias": "galhardear",
    "galhardeie": "galhardear",
    "galhardeiem": "galhardear",
    "galhardeies": "galhardear",
    "galhardeio": "galhardear",
    "galhardeou": "galhardear",
    "galhardetes": "galhardete",
    "galhardeámo": "galhardear",
    "galhardeámos": "galhardear",
    "galhardeáramo": "galhardear",
    "galhardeáramos": "galhardear",
    "galhardeáreis": "galhardear",
    "galhardeásseis": "galhardear",
    "galhardeássemos": "galhardear",
    "galhardeávamo": "galhardear",
    "galhardeávamos": "galhardear",
    "galhardeáveis": "galhardear",
    "galhardias": "galhardia",
    "galhardos": "galhardo",
    "galhas": "galha",
    "galheiras": "galheira",
    "galheiros": "galheiro",
    "galhetas": "galheta",
    "galheteiros": "galheteiro",
    "galhipos": "galhipo",
    "galhofa": "galhofar",
    "galhofada": "galhofar",
    "galhofadas": "galhofar",
    "galhofado": "galhofar",
    "galhofados": "galhofar",
    "galhofai": "galhofar",
    "galhofais": "galhofar",
    "galhofam": "galhofar",
    "galhofamo": "galhofar",
    "galhofamos": "galhofar",
    "galhofando": "galhofar",
    "galhofara": "galhofar",
    "galhofaram": "galhofar",
    "galhofaras": "galhofar",
    "galhofardes": "galhofar",
    "galhofarei": "galhofar",
    "galhofareis": "galhofar",
    "galhofarem": "galhofar",
    "galhofaremos": "galhofar",
    "galhofares": "galhofar",
    "galhofaria": "galhofar",
    "galhofariam": "galhofar",
    "galhofarias": "galhofaria",
    "galhofarmo": "galhofar",
    "galhofarmos": "galhofar",
    "galhofará": "galhofar",
    "galhofarás": "galhofar",
    "galhofarão": "galhofar",
    "galhofaríamos": "galhofar",
    "galhofaríeis": "galhofar",
    "galhofas": "galhofar",
    "galhofasse": "galhofar",
    "galhofassem": "galhofar",
    "galhofasses": "galhofar",
    "galhofaste": "galhofar",
    "galhofastes": "galhofar",
    "galhofava": "galhofar",
    "galhofavam": "galhofar",
    "galhofavas": "galhofar",
    "galhofe": "galhofar",
    "galhofeada": "galhofear",
    "galhofeadas": "galhofear",
    "galhofeado": "galhofear",
    "galhofeados": "galhofear",
    "galhofeai": "galhofear",
    "galhofeais": "galhofear",
    "galhofeamo": "galhofear",
    "galhofeamos": "galhofear",
    "galhofeando": "galhofear",
    "galhofeara": "galhofear",
    "galhofearam": "galhofear",
    "galhofearas": "galhofear",
    "galhofeardes": "galhofear",
    "galhofearei": "galhofear",
    "galhofeareis": "galhofear",
    "galhofearem": "galhofear",
    "galhofearemos": "galhofear",
    "galhofeares": "galhofear",
    "galhofearia": "galhofear",
    "galhofeariam": "galhofear",
    "galhofearias": "galhofear",
    "galhofearmo": "galhofear",
    "galhofearmos": "galhofear",
    "galhofeará": "galhofear",
    "galhofearás": "galhofear",
    "galhofearão": "galhofear",
    "galhofearíamos": "galhofear",
    "galhofearíeis": "galhofear",
    "galhofeasse": "galhofear",
    "galhofeassem": "galhofear",
    "galhofeasses": "galhofear",
    "galhofeaste": "galhofear",
    "galhofeastes": "galhofear",
    "galhofeava": "galhofear",
    "galhofeavam": "galhofear",
    "galhofeavas": "galhofear",
    "galhofeei": "galhofear",
    "galhofeeis": "galhofear",
    "galhofeemo": "galhofear",
    "galhofeemos": "galhofear",
    "galhofei": "galhofar",
    "galhofeia": "galhofear",
    "galhofeiam": "galhofear",
    "galhofeias": "galhofear",
    "galhofeie": "galhofear",
    "galhofeiem": "galhofear",
    "galhofeies": "galhofear",
    "galhofeio": "galhofear",
    "galhofeira": "galhofeiro",
    "galhofeiras": "galhofeiro",
    "galhofeiros": "galhofeiro",
    "galhofeis": "galhofar",
    "galhofem": "galhofar",
    "galhofemo": "galhofar",
    "galhofemos": "galhofar",
    "galhofenta": "galhofento",
    "galhofentas": "galhofento",
    "galhofentos": "galhofento",
    "galhofeou": "galhofear",
    "galhofes": "galhofar",
    "galhofeámo": "galhofear",
    "galhofeámos": "galhofear",
    "galhofeáramo": "galhofear",
    "galhofeáramos": "galhofear",
    "galhofeáreis": "galhofear",
    "galhofeásseis": "galhofear",
    "galhofeássemos": "galhofear",
    "galhofeávamo": "galhofear",
    "galhofeávamos": "galhofear",
    "galhofeáveis": "galhofear",
    "galhofo": "galhofar",
    "galhofou": "galhofar",
    "galhofámo": "galhofar",
    "galhofámos": "galhofar",
    "galhofáramo": "galhofar",
    "galhofáramos": "galhofar",
    "galhofáreis": "galhofar",
    "galhofásseis": "galhofar",
    "galhofássemos": "galhofar",
    "galhofávamo": "galhofar",
    "galhofávamos": "galhofar",
    "galhofáveis": "galhofar",
    "galhos": "galho",
    "galhuda": "galhudo",
    "galhudas": "galhudo",
    "galhudos": "galhudo",
    "galicana": "galicano",
    "galicanas": "galicano",
    "galicanismos": "galicanismo",
    "galicanos": "galicano",
    "galicetes": "galicete",
    "galiciana": "galiciano",
    "galicianas": "galiciano",
    "galicianos": "galiciano",
    "galiciparlas": "galiciparla",
    "galicismos": "galicismo",
    "galicistas": "galicista",
    "galiciza": "galicizar",
    "galicizada": "galicizar",
    "galicizadas": "galicizar",
    "galicizado": "galicizar",
    "galicizados": "galicizar",
    "galicizai": "galicizar",
    "galicizais": "galicizar",
    "galicizam": "galicizar",
    "galicizamo": "galicizar",
    "galicizamos": "galicizar",
    "galicizando": "galicizar",
    "galicizara": "galicizar",
    "galicizaram": "galicizar",
    "galicizaras": "galicizar",
    "galicizarde": "galicizar",
    "galicizardes": "galicizar",
    "galicizare": "galicizar",
    "galicizarei": "galicizar",
    "galicizareis": "galicizar",
    "galicizarem": "galicizar",
    "galicizaremos": "galicizar",
    "galicizares": "galicizar",
    "galicizaria": "galicizar",
    "galicizariam": "galicizar",
    "galicizarias": "galicizar",
    "galicizarmo": "galicizar",
    "galicizarmos": "galicizar",
    "galicizará": "galicizar",
    "galicizarás": "galicizar",
    "galicizarão": "galicizar",
    "galicizaríamos": "galicizar",
    "galicizaríeis": "galicizar",
    "galicizas": "galicizar",
    "galicizasse": "galicizar",
    "galicizassem": "galicizar",
    "galicizasses": "galicizar",
    "galicizaste": "galicizar",
    "galicizastes": "galicizar",
    "galicizava": "galicizar",
    "galicizavam": "galicizar",
    "galicizavas": "galicizar",
    "galicize": "galicizar",
    "galicizei": "galicizar",
    "galicizeis": "galicizar",
    "galicizem": "galicizar",
    "galicizemo": "galicizar",
    "galicizemos": "galicizar",
    "galicizes": "galicizar",
    "galicizo": "galicizar",
    "galicizou": "galicizar",
    "galicizá": "galicizar",
    "galicizámo": "galicizar",
    "galicizámos": "galicizar",
    "galicizáramo": "galicizar",
    "galicizáramos": "galicizar",
    "galicizárei": "galicizar",
    "galicizáreis": "galicizar",
    "galicizásseis": "galicizar",
    "galicizássemos": "galicizar",
    "galicizávamo": "galicizar",
    "galicizávamos": "galicizar",
    "galicizávei": "galicizar",
    "galicizáveis": "galicizável",
    "galicínios": "galicínio",
    "galienses": "galiense",
    "galiformes": "galiforme",
    "galileia": "galileu",
    "galileias": "galileu",
    "galileus": "galileu",
    "galilés": "galilé",
    "galimatizações": "galimatização",
    "galimos": "galimo",
    "galinhadas": "galinhada",
    "galinhas": "galinha",
    "galinhaços": "galinhaço",
    "galinheira": "galinheiro",
    "galinheiras": "galinheiro",
    "galinheiros": "galinheiro",
    "galinho": "galo",
    "galinholas": "galinhola",
    "galinhos": "galo",
    "galinhotas": "galinhota",
    "galinhós": "galinhó",
    "galinicultora": "galinicultor",
    "galinicultoras": "galinicultor",
    "galinicultores": "galinicultor",
    "galiniculturas": "galinicultura",
    "galinulídea": "galinulídeo",
    "galinulídeas": "galinulídeo",
    "galinulídeos": "galinulídeo",
    "galinácea": "galináceo",
    "galináceas": "galináceo",
    "galináceos": "galináceo",
    "galinúlidas": "galinúlida",
    "galiparlas": "galiparla",
    "galipotes": "galipote",
    "galipódios": "galipódio",
    "galipós": "galipó",
    "galipões": "galipão",
    "galispos": "galispo",
    "galistas": "galista",
    "galito": "galo",
    "galitos": "galo",
    "galiva": "galivar",
    "galivada": "galivar",
    "galivadas": "galivar",
    "galivado": "galivar",
    "galivados": "galivar",
    "galivai": "galivar",
    "galivais": "galivar",
    "galivam": "galivar",
    "galivamo": "galivar",
    "galivamos": "galivar",
    "galivando": "galivar",
    "galivara": "galivar",
    "galivaram": "galivar",
    "galivaras": "galivar",
    "galivarde": "galivar",
    "galivardes": "galivar",
    "galivare": "galivar",
    "galivarei": "galivar",
    "galivareis": "galivar",
    "galivarem": "galivar",
    "galivaremos": "galivar",
    "galivares": "galivar",
    "galivaria": "galivar",
    "galivariam": "galivar",
    "galivarias": "galivar",
    "galivarmo": "galivar",
    "galivarmos": "galivar",
    "galivará": "galivar",
    "galivarás": "galivar",
    "galivarão": "galivar",
    "galivaríamos": "galivar",
    "galivaríeis": "galivar",
    "galivas": "galivar",
    "galivasse": "galivar",
    "galivassem": "galivar",
    "galivasses": "galivar",
    "galivaste": "galivar",
    "galivastes": "galivar",
    "galivava": "galivar",
    "galivavam": "galivar",
    "galivavas": "galivar",
    "galivações": "galivação",
    "galive": "galivar",
    "galivei": "galivar",
    "galiveis": "galivar",
    "galivem": "galivar",
    "galivemo": "galivar",
    "galivemos": "galivar",
    "galives": "galivar",
    "galivo": "galivar",
    "galivou": "galivar",
    "galivá": "galivar",
    "galivámo": "galivar",
    "galivámos": "galivar",
    "galiváramo": "galivar",
    "galiváramos": "galivar",
    "galivárei": "galivar",
    "galiváreis": "galivar",
    "galivásseis": "galivar",
    "galivássemos": "galivar",
    "galivávamo": "galivar",
    "galivávamos": "galivar",
    "galivávei": "galivar",
    "galiváveis": "galivar",
    "galiziana": "galiziano",
    "galizianas": "galiziano",
    "galizianos": "galiziano",
    "galizias": "galizia",
    "galo": "galar",
    "galochas": "galocha",
    "galocristas": "galocrista",
    "galofilias": "galofilia",
    "galofobias": "galofobia",
    "galomanias": "galomania",
    "galomaníaca": "galomaníaco",
    "galomaníacas": "galomaníaco",
    "galomaníacos": "galomaníaco",
    "galonada": "galonado",
    "galonadas": "galonado",
    "galonados": "galonado",
    "galopa": "galopar",
    "galopada": "galopar",
    "galopadas": "galopar",
    "galopado": "galopar",
    "galopadora": "galopador",
    "galopadoras": "galopador",
    "galopadores": "galopador",
    "galopados": "galopar",
    "galopai": "galopar",
    "galopais": "galopar",
    "galopam": "galopar",
    "galopamo": "galopar",
    "galopamos": "galopar",
    "galopando": "galopar",
    "galopantes": "galopante",
    "galopara": "galopar",
    "galoparam": "galopar",
    "galoparas": "galopar",
    "galopardes": "galopar",
    "galoparei": "galopar",
    "galopareis": "galopar",
    "galoparem": "galopar",
    "galoparemos": "galopar",
    "galopares": "galopar",
    "galoparia": "galopar",
    "galopariam": "galopar",
    "galoparias": "galopar",
    "galoparmo": "galopar",
    "galoparmos": "galopar",
    "galopará": "galopar",
    "galoparás": "galopar",
    "galoparão": "galopar",
    "galoparíamos": "galopar",
    "galoparíeis": "galopar",
    "galopas": "galopar",
    "galopasse": "galopar",
    "galopassem": "galopar",
    "galopasses": "galopar",
    "galopaste": "galopar",
    "galopastes": "galopar",
    "galopava": "galopar",
    "galopavam": "galopar",
    "galopavas": "galopar",
    "galope": "galopar",
    "galopeada": "galopear",
    "galopeadas": "galopear",
    "galopeado": "galopear",
    "galopeados": "galopear",
    "galopeai": "galopear",
    "galopeais": "galopear",
    "galopeamo": "galopear",
    "galopeamos": "galopear",
    "galopeando": "galopear",
    "galopeara": "galopear",
    "galopearam": "galopear",
    "galopearas": "galopear",
    "galopeardes": "galopear",
    "galopearei": "galopear",
    "galopeareis": "galopear",
    "galopearem": "galopear",
    "galopearemos": "galopear",
    "galopeares": "galopear",
    "galopearia": "galopear",
    "galopeariam": "galopear",
    "galopearias": "galopear",
    "galopearmo": "galopear",
    "galopearmos": "galopear",
    "galopeará": "galopear",
    "galopearás": "galopear",
    "galopearão": "galopear",
    "galopearíamos": "galopear",
    "galopearíeis": "galopear",
    "galopeasse": "galopear",
    "galopeassem": "galopear",
    "galopeasses": "galopear",
    "galopeaste": "galopear",
    "galopeastes": "galopear",
    "galopeava": "galopear",
    "galopeavam": "galopear",
    "galopeavas": "galopear",
    "galopeei": "galopear",
    "galopeeis": "galopear",
    "galopeemo": "galopear",
    "galopeemos": "galopear",
    "galopei": "galopar",
    "galopeia": "galopear",
    "galopeiam": "galopear",
    "galopeias": "galopear",
    "galopeie": "galopear",
    "galopeiem": "galopear",
    "galopeies": "galopear",
    "galopeio": "galopear",
    "galopeis": "galopar",
    "galopem": "galopar",
    "galopemo": "galopar",
    "galopemos": "galopar",
    "galopeou": "galopear",
    "galopes": "galope",
    "galopezinho": "galope",
    "galopezinhos": "galope",
    "galopezito": "galope",
    "galopezitos": "galope",
    "galopeámo": "galopear",
    "galopeámos": "galopear",
    "galopeáramo": "galopear",
    "galopeáramos": "galopear",
    "galopeáreis": "galopear",
    "galopeásseis": "galopear",
    "galopeássemos": "galopear",
    "galopeávamo": "galopear",
    "galopeávamos": "galopear",
    "galopeáveis": "galopear",
    "galopina": "galopinar",
    "galopinada": "galopinar",
    "galopinadas": "galopinar",
    "galopinado": "galopinar",
    "galopinados": "galopinar",
    "galopinagens": "galopinagem",
    "galopinai": "galopinar",
    "galopinais": "galopinar",
    "galopinam": "galopinar",
    "galopinamo": "galopinar",
    "galopinamos": "galopinar",
    "galopinando": "galopinar",
    "galopinara": "galopinar",
    "galopinaram": "galopinar",
    "galopinaras": "galopinar",
    "galopinardes": "galopinar",
    "galopinarei": "galopinar",
    "galopinareis": "galopinar",
    "galopinarem": "galopinar",
    "galopinaremos": "galopinar",
    "galopinares": "galopinar",
    "galopinaria": "galopinar",
    "galopinariam": "galopinar",
    "galopinarias": "galopinar",
    "galopinarmo": "galopinar",
    "galopinarmos": "galopinar",
    "galopinará": "galopinar",
    "galopinarás": "galopinar",
    "galopinarão": "galopinar",
    "galopinaríamos": "galopinar",
    "galopinaríeis": "galopinar",
    "galopinas": "galopinar",
    "galopinasse": "galopinar",
    "galopinassem": "galopinar",
    "galopinasses": "galopinar",
    "galopinaste": "galopinar",
    "galopinastes": "galopinar",
    "galopinava": "galopinar",
    "galopinavam": "galopinar",
    "galopinavas": "galopinar",
    "galopine": "galopinar",
    "galopinei": "galopinar",
    "galopineis": "galopinar",
    "galopinem": "galopinar",
    "galopinemo": "galopinar",
    "galopinemos": "galopinar",
    "galopines": "galopinar",
    "galopino": "galopinar",
    "galopinou": "galopinar",
    "galopins": "galopim",
    "galopinámo": "galopinar",
    "galopinámos": "galopinar",
    "galopináramo": "galopinar",
    "galopináramos": "galopinar",
    "galopináreis": "galopinar",
    "galopinásseis": "galopinar",
    "galopinássemos": "galopinar",
    "galopinávamo": "galopinar",
    "galopinávamos": "galopinar",
    "galopináveis": "galopinar",
    "galopo": "galopar",
    "galopou": "galopar",
    "galopámo": "galopar",
    "galopámos": "galopar",
    "galopáramo": "galopar",
    "galopáramos": "galopar",
    "galopáreis": "galopar",
    "galopásseis": "galopar",
    "galopássemos": "galopar",
    "galopávamo": "galopar",
    "galopávamos": "galopar",
    "galopáveis": "galopar",
    "galos": "galo",
    "galou": "galar",
    "galra": "galrar",
    "galrachos": "galracho",
    "galrada": "galrar",
    "galradas": "galrar",
    "galrado": "galrar",
    "galrados": "galrar",
    "galrai": "galrar",
    "galrais": "galrar",
    "galram": "galrar",
    "galramo": "galrar",
    "galramos": "galrar",
    "galrando": "galrar",
    "galrara": "galrar",
    "galraram": "galrar",
    "galraras": "galrar",
    "galrardes": "galrar",
    "galrarei": "galrar",
    "galrareis": "galrar",
    "galrarem": "galrar",
    "galraremos": "galrar",
    "galrares": "galrar",
    "galraria": "galrar",
    "galrariam": "galrar",
    "galrarias": "galrar",
    "galrarmo": "galrar",
    "galrarmos": "galrar",
    "galrará": "galrar",
    "galrarás": "galrar",
    "galrarão": "galrar",
    "galraríamos": "galrar",
    "galraríeis": "galrar",
    "galras": "galrar",
    "galrasse": "galrar",
    "galrassem": "galrar",
    "galrasses": "galrar",
    "galraste": "galrar",
    "galrastes": "galrar",
    "galrava": "galrar",
    "galravam": "galrar",
    "galravas": "galrar",
    "galre": "galrar",
    "galreada": "galrear",
    "galreadas": "galrear",
    "galreado": "galrear",
    "galreadora": "galreador",
    "galreadoras": "galreador",
    "galreadores": "galreador",
    "galreados": "galrear",
    "galreai": "galrear",
    "galreais": "galrear",
    "galreamo": "galrear",
    "galreamos": "galrear",
    "galreando": "galrear",
    "galreara": "galrear",
    "galrearam": "galrear",
    "galrearas": "galrear",
    "galreardes": "galrear",
    "galrearei": "galrear",
    "galreareis": "galrear",
    "galrearem": "galrear",
    "galrearemos": "galrear",
    "galreares": "galrear",
    "galrearia": "galrear",
    "galreariam": "galrear",
    "galrearias": "galrear",
    "galrearmo": "galrear",
    "galrearmos": "galrear",
    "galreará": "galrear",
    "galrearás": "galrear",
    "galrearão": "galrear",
    "galrearíamos": "galrear",
    "galrearíeis": "galrear",
    "galreasse": "galrear",
    "galreassem": "galrear",
    "galreasses": "galrear",
    "galreaste": "galrear",
    "galreastes": "galrear",
    "galreava": "galrear",
    "galreavam": "galrear",
    "galreavas": "galrear",
    "galreei": "galrear",
    "galreeis": "galrear",
    "galreemo": "galrear",
    "galreemos": "galrear",
    "galrei": "galrar",
    "galreia": "galrear",
    "galreiam": "galrear",
    "galreias": "galrear",
    "galreie": "galrear",
    "galreiem": "galrear",
    "galreies": "galrear",
    "galreio": "galrear",
    "galreioa": "galreio",
    "galreioas": "galreio",
    "galreioes": "galreio",
    "galreira": "galreiro",
    "galreiras": "galreiro",
    "galreiros": "galreiro",
    "galreis": "galrar",
    "galreja": "galrejar",
    "galrejada": "galrejar",
    "galrejadas": "galrejar",
    "galrejado": "galrejar",
    "galrejadora": "galrejador",
    "galrejadoras": "galrejador",
    "galrejadores": "galrejador",
    "galrejados": "galrejar",
    "galrejai": "galrejar",
    "galrejais": "galrejar",
    "galrejam": "galrejar",
    "galrejamo": "galrejar",
    "galrejamos": "galrejar",
    "galrejando": "galrejar",
    "galrejara": "galrejar",
    "galrejaram": "galrejar",
    "galrejaras": "galrejar",
    "galrejardes": "galrejar",
    "galrejarei": "galrejar",
    "galrejareis": "galrejar",
    "galrejarem": "galrejar",
    "galrejaremos": "galrejar",
    "galrejares": "galrejar",
    "galrejaria": "galrejar",
    "galrejariam": "galrejar",
    "galrejarias": "galrejar",
    "galrejarmo": "galrejar",
    "galrejarmos": "galrejar",
    "galrejará": "galrejar",
    "galrejarás": "galrejar",
    "galrejarão": "galrejar",
    "galrejaríamos": "galrejar",
    "galrejaríeis": "galrejar",
    "galrejas": "galrejar",
    "galrejasse": "galrejar",
    "galrejassem": "galrejar",
    "galrejasses": "galrejar",
    "galrejaste": "galrejar",
    "galrejastes": "galrejar",
    "galrejava": "galrejar",
    "galrejavam": "galrejar",
    "galrejavas": "galrejar",
    "galreje": "galrejar",
    "galrejei": "galrejar",
    "galrejeis": "galrejar",
    "galrejem": "galrejar",
    "galrejemo": "galrejar",
    "galrejemos": "galrejar",
    "galrejes": "galrejar",
    "galrejo": "galrejar",
    "galrejou": "galrejar",
    "galrejámo": "galrejar",
    "galrejámos": "galrejar",
    "galrejáramo": "galrejar",
    "galrejáramos": "galrejar",
    "galrejáreis": "galrejar",
    "galrejásseis": "galrejar",
    "galrejássemos": "galrejar",
    "galrejávamo": "galrejar",
    "galrejávamos": "galrejar",
    "galrejáveis": "galrejar",
    "galrem": "galrar",
    "galremo": "galrar",
    "galremos": "galrar",
    "galreou": "galrear",
    "galres": "galrar",
    "galreámo": "galrear",
    "galreámos": "galrear",
    "galreáramo": "galrear",
    "galreáramos": "galrear",
    "galreáreis": "galrear",
    "galreásseis": "galrear",
    "galreássemos": "galrear",
    "galreávamo": "galrear",
    "galreávamos": "galrear",
    "galreáveis": "galrear",
    "galrichos": "galricho",
    "galripas": "galripa",
    "galripos": "galripo",
    "galritos": "galrito",
    "galriços": "galriço",
    "galro": "galrar",
    "galrona": "galrão",
    "galronas": "galrão",
    "galrou": "galrar",
    "galrreadora": "galrreador",
    "galrreadoras": "galrreador",
    "galrreadores": "galrreador",
    "galrrona": "galrrão",
    "galrronas": "galrrão",
    "galrrões": "galrrão",
    "galrámo": "galrar",
    "galrámos": "galrar",
    "galráramo": "galrar",
    "galráramos": "galrar",
    "galráreis": "galrar",
    "galrásseis": "galrar",
    "galrássemos": "galrar",
    "galrávamo": "galrar",
    "galrávamos": "galrar",
    "galráveis": "galrar",
    "galrões": "galrão",
    "galubés": "galubé",
    "galucha": "galucho",
    "galuchadas": "galuchada",
    "galuchas": "galucho",
    "galuchos": "galucho",
    "galulas": "galula",
    "galvanismos": "galvanismo",
    "galvaniza": "galvanizar",
    "galvanizada": "galvanizar",
    "galvanizadas": "galvanizar",
    "galvanizado": "galvanizar",
    "galvanizadora": "galvanizador",
    "galvanizadoras": "galvanizador",
    "galvanizadores": "galvanizador",
    "galvanizados": "galvanizar",
    "galvanizai": "galvanizar",
    "galvanizais": "galvanizar",
    "galvanizam": "galvanizar",
    "galvanizamo": "galvanizar",
    "galvanizamos": "galvanizar",
    "galvanizando": "galvanizar",
    "galvanizantes": "galvanizante",
    "galvanizara": "galvanizar",
    "galvanizaram": "galvanizar",
    "galvanizaras": "galvanizar",
    "galvanizarde": "galvanizar",
    "galvanizardes": "galvanizar",
    "galvanizare": "galvanizar",
    "galvanizarei": "galvanizar",
    "galvanizareis": "galvanizar",
    "galvanizarem": "galvanizar",
    "galvanizaremos": "galvanizar",
    "galvanizares": "galvanizar",
    "galvanizaria": "galvanizar",
    "galvanizariam": "galvanizar",
    "galvanizarias": "galvanizar",
    "galvanizarmo": "galvanizar",
    "galvanizarmos": "galvanizar",
    "galvanizará": "galvanizar",
    "galvanizarás": "galvanizar",
    "galvanizarão": "galvanizar",
    "galvanizaríamos": "galvanizar",
    "galvanizaríeis": "galvanizar",
    "galvanizas": "galvanizar",
    "galvanizasse": "galvanizar",
    "galvanizassem": "galvanizar",
    "galvanizasses": "galvanizar",
    "galvanizaste": "galvanizar",
    "galvanizastes": "galvanizar",
    "galvanizava": "galvanizar",
    "galvanizavam": "galvanizar",
    "galvanizavas": "galvanizar",
    "galvanizações": "galvanização",
    "galvanize": "galvanizar",
    "galvanizei": "galvanizar",
    "galvanizeis": "galvanizar",
    "galvanizem": "galvanizar",
    "galvanizemo": "galvanizar",
    "galvanizemos": "galvanizar",
    "galvanizes": "galvanizar",
    "galvanizo": "galvanizar",
    "galvanizou": "galvanizar",
    "galvanizá": "galvanizar",
    "galvanizámo": "galvanizar",
    "galvanizámos": "galvanizar",
    "galvanizáramo": "galvanizar",
    "galvanizáramos": "galvanizar",
    "galvanizárei": "galvanizar",
    "galvanizáreis": "galvanizar",
    "galvanizásseis": "galvanizar",
    "galvanizássemos": "galvanizar",
    "galvanizávamo": "galvanizar",
    "galvanizávamos": "galvanizar",
    "galvanizávei": "galvanizar",
    "galvanizáveis": "galvanizável",
    "galvanocautérica": "galvanocautérico",
    "galvanocautéricas": "galvanocautérico",
    "galvanocautéricos": "galvanocautérico",
    "galvanocautérios": "galvanocautério",
    "galvanocáustica": "galvanocáustico",
    "galvanocáusticas": "galvanocáustico",
    "galvanocáusticos": "galvanocáustico",
    "galvanografias": "galvanografia",
    "galvanogravuras": "galvanogravura",
    "galvanográfica": "galvanográfico",
    "galvanográficas": "galvanográfico",
    "galvanográficos": "galvanográfico",
    "galvanoluminescentes": "galvanoluminescente",
    "galvanoluminescências": "galvanoluminescência",
    "galvanomagnetismos": "galvanomagnetismo",
    "galvanomagnética": "galvanomagnético",
    "galvanomagnéticas": "galvanomagnético",
    "galvanomagnéticos": "galvanomagnético",
    "galvanometrias": "galvanometria",
    "galvanométrica": "galvanométrico",
    "galvanométricas": "galvanométrico",
    "galvanométricos": "galvanométrico",
    "galvanoplastias": "galvanoplastia",
    "galvanoplástica": "galvanoplástico",
    "galvanoplásticas": "galvanoplástico",
    "galvanoplásticos": "galvanoplástico",
    "galvanopuncturas": "galvanopunctura",
    "galvanoscopias": "galvanoscopia",
    "galvanoscópica": "galvanoscópico",
    "galvanoscópicas": "galvanoscópico",
    "galvanoscópicos": "galvanoscópico",
    "galvanoscópios": "galvanoscópio",
    "galvanostegias": "galvanostegia",
    "galvanostésica": "galvanostésico",
    "galvanostésicas": "galvanostésico",
    "galvanostésicos": "galvanostésico",
    "galvanotaxias": "galvanotaxia",
    "galvanoterapeutas": "galvanoterapeuta",
    "galvanoterapias": "galvanoterapia",
    "galvanoterapistas": "galvanoterapista",
    "galvanoterapêutica": "galvanoterapêutico",
    "galvanoterapêuticas": "galvanoterapêutico",
    "galvanoterapêuticos": "galvanoterapêutico",
    "galvanoterápica": "galvanoterápico",
    "galvanoterápicas": "galvanoterápico",
    "galvanoterápicos": "galvanoterápico",
    "galvanotipias": "galvanotipia",
    "galvanotopismos": "galvanotopismo",
    "galvanotrópica": "galvanotrópico",
    "galvanotrópicas": "galvanotrópico",
    "galvanotrópicos": "galvanotrópico",
    "galvanotáxica": "galvanotáxico",
    "galvanotáxicas": "galvanotáxico",
    "galvanotáxicos": "galvanotáxico",
    "galvanotípica": "galvanotípico",
    "galvanotípicas": "galvanotípico",
    "galvanotípicos": "galvanotípico",
    "galvanómetros": "galvanómetro",
    "galvetas": "galveta",
    "galvânica": "galvânico",
    "galvânicas": "galvânico",
    "galvânicos": "galvânico",
    "galvões": "galvão",
    "galá": "galar",
    "galáctica": "galáctico",
    "galácticas": "galáctico",
    "galácticos": "galáctico",
    "galámo": "galar",
    "galámos": "galar",
    "galápagos": "galápago",
    "galáramo": "galar",
    "galáramos": "galar",
    "galárei": "galar",
    "galáreis": "galar",
    "galásseis": "galar",
    "galássemos": "galar",
    "galávamo": "galar",
    "galávamos": "galar",
    "galávei": "galar",
    "galáveis": "galar",
    "galáxias": "galáxia",
    "galãs": "galã",
    "galénica": "galénico",
    "galénicas": "galénico",
    "galénicos": "galénico",
    "galéolas": "galéola",
    "galés": "galé",
    "galícia": "galício",
    "galícias": "galício",
    "galícios": "galício",
    "galícolas": "galícola",
    "galófila": "galófilo",
    "galófilas": "galófilo",
    "galófilos": "galófilo",
    "galófoba": "galófobo",
    "galófobas": "galófobo",
    "galófobos": "galófobo",
    "galómana": "galómano",
    "galómanas": "galómano",
    "galómanos": "galómano",
    "galões": "galão",
    "gama": "gamo",
    "gamabadonas": "gamabadona",
    "gamacismos": "gamacismo",
    "gamacistas": "gamacista",
    "gamada": "gamar",
    "gamadas": "gamar",
    "gamado": "gamar",
    "gamados": "gamar",
    "gamagrafias": "gamagrafia",
    "gamagráfica": "gamagráfico",
    "gamagráficas": "gamagráfico",
    "gamagráficos": "gamagráfico",
    "gamai": "gamar",
    "gamais": "gamar",
    "gamam": "gamar",
    "gamamo": "gamar",
    "gamamos": "gamar",
    "gamando": "gamar",
    "gamanços": "gamanço",
    "gamara": "gamar",
    "gamaram": "gamar",
    "gamaras": "gamar",
    "gamarde": "gamar",
    "gamardes": "gamar",
    "gamare": "gamar",
    "gamarei": "gamar",
    "gamareis": "gamar",
    "gamarem": "gamar",
    "gamaremos": "gamar",
    "gamares": "gamar",
    "gamaria": "gamar",
    "gamariam": "gamar",
    "gamarias": "gamar",
    "gamarmo": "gamar",
    "gamarmos": "gamar",
    "gamarras": "gamarra",
    "gamará": "gamar",
    "gamarás": "gamar",
    "gamarão": "gamar",
    "gamaríamos": "gamar",
    "gamaríeis": "gamar",
    "gamas": "gamo",
    "gamasse": "gamar",
    "gamassem": "gamar",
    "gamasses": "gamar",
    "gamaste": "gamar",
    "gamastes": "gamar",
    "gamava": "gamar",
    "gamavam": "gamar",
    "gamavas": "gamar",
    "gamações": "gamação",
    "gambarras": "gambarra",
    "gambas": "gamba",
    "gambetas": "gambeta",
    "gambeteira": "gambeteiro",
    "gambeteiras": "gambeteiro",
    "gambeteiros": "gambeteiro",
    "gambiana": "gambiano",
    "gambianas": "gambiano",
    "gambianos": "gambiano",
    "gambiarras": "gambiarra",
    "gambitos": "gambito",
    "gamboas": "gamboa",
    "gamboeiros": "gamboeiro",
    "gambotas": "gambota",
    "gambozinos": "gambozino",
    "gamboínas": "gamboína",
    "gambás": "gambá",
    "gambérrias": "gambérria",
    "game": "gamar",
    "gamei": "gamar",
    "gameira": "gameiro",
    "gameiras": "gameiro",
    "gameiros": "gameiro",
    "gameis": "gamar",
    "gameladas": "gamelada",
    "gamelas": "gamela",
    "gameleiras": "gameleira",
    "gameleirenses": "gameleirense",
    "gamelos": "gamelo",
    "gamelotes": "gamelote",
    "gamelórios": "gamelório",
    "gamelões": "gamelão",
    "gamem": "gamar",
    "gamemo": "gamar",
    "gamemos": "gamar",
    "gamenha": "gamenho",
    "gamenhas": "gamenho",
    "gamenhices": "gamenhice",
    "gamenhos": "gamenho",
    "games": "gamar",
    "gametas": "gameta",
    "gametogenésica": "gametogenésico",
    "gametogenésicas": "gametogenésico",
    "gametogenésicos": "gametogenésico",
    "gametogenética": "gametogenético",
    "gametogenéticas": "gametogenético",
    "gametogenéticos": "gametogenético",
    "gametogéneses": "gametogénese",
    "gametogénica": "gametogénico",
    "gametogénicas": "gametogénico",
    "gametogénicos": "gametogénico",
    "gametos": "gameto",
    "gametângica": "gametângico",
    "gametângicas": "gametângico",
    "gametângicos": "gametângico",
    "gametângios": "gametângio",
    "gametófita": "gametófito",
    "gametófitas": "gametófito",
    "gametófitos": "gametófito",
    "gametófora": "gametóforo",
    "gametóforas": "gametóforo",
    "gametóforos": "gametóforo",
    "gamo": "gamar",
    "gamodilias": "gamodilia",
    "gamofila": "gamofilo",
    "gamofilas": "gamofilo",
    "gamofilos": "gamofilo",
    "gamofobias": "gamofobia",
    "gamofóbica": "gamofóbico",
    "gamofóbicas": "gamofóbico",
    "gamofóbicos": "gamofóbico",
    "gamogástrea": "gamogástreo",
    "gamogástreas": "gamogástreo",
    "gamogástreos": "gamogástreo",
    "gamogástrica": "gamogástrico",
    "gamogástricas": "gamogástrico",
    "gamogástricos": "gamogástrico",
    "gamogéneses": "gamogénese",
    "gamomanias": "gamomania",
    "gamomaníaca": "gamomaníaco",
    "gamomaníacas": "gamomaníaco",
    "gamomaníacos": "gamomaníaco",
    "gamopétala": "gamopétalo",
    "gamopétalas": "gamopétalo",
    "gamopétalos": "gamopétalo",
    "gamos": "gamo",
    "gamossépala": "gamossépalo",
    "gamossépalas": "gamossépalo",
    "gamossépalos": "gamossépalo",
    "gamostila": "gamostilo",
    "gamostilas": "gamostilo",
    "gamostilos": "gamostilo",
    "gamotes": "gamote",
    "gamou": "gamar",
    "gamozóides": "gamozóide",
    "gamutas": "gamuta",
    "gamutes": "gamute",
    "gamá": "gamar",
    "gamámo": "gamar",
    "gamámos": "gamar",
    "gamáramo": "gamar",
    "gamáramos": "gamar",
    "gamárei": "gamar",
    "gamáreis": "gamar",
    "gamásseis": "gamar",
    "gamássemos": "gamar",
    "gamávamo": "gamar",
    "gamávamos": "gamar",
    "gamávei": "gamar",
    "gamáveis": "gamável",
    "gamófila": "gamófilo",
    "gamófilas": "gamófilo",
    "gamófilos": "gamófilo",
    "gamófoba": "gamófobo",
    "gamófobas": "gamófobo",
    "gamófobos": "gamófobo",
    "gamómana": "gamómano",
    "gamómanas": "gamómano",
    "gamómanos": "gamómano",
    "gamões": "gamão",
    "gamútis": "gamúti",
    "gana": "ganir",
    "ganachas": "ganacha",
    "ganadarias": "ganadaria",
    "ganadeira": "ganadeiro",
    "ganadeiras": "ganadeiro",
    "ganadeiros": "ganadeiro",
    "ganais": "ganir",
    "ganam": "ganir",
    "ganamo": "ganir",
    "ganamos": "ganir",
    "ganancia": "gananciar",
    "gananciada": "gananciar",
    "gananciadas": "gananciar",
    "gananciado": "gananciar",
    "gananciados": "gananciar",
    "gananciai": "gananciar",
    "gananciais": "gananciar",
    "gananciam": "gananciar",
    "gananciamo": "gananciar",
    "gananciamos": "gananciar",
    "gananciando": "gananciar",
    "gananciara": "gananciar",
    "gananciaram": "gananciar",
    "gananciaras": "gananciar",
    "gananciarde": "gananciar",
    "gananciardes": "gananciar",
    "gananciare": "gananciar",
    "gananciarei": "gananciar",
    "gananciareis": "gananciar",
    "gananciarem": "gananciar",
    "gananciaremos": "gananciar",
    "gananciares": "gananciar",
    "gananciaria": "gananciar",
    "gananciariam": "gananciar",
    "gananciarias": "gananciar",
    "gananciarmo": "gananciar",
    "gananciarmos": "gananciar",
    "gananciará": "gananciar",
    "gananciarás": "gananciar",
    "gananciarão": "gananciar",
    "gananciaríamos": "gananciar",
    "gananciaríeis": "gananciar",
    "ganancias": "gananciar",
    "gananciasse": "gananciar",
    "gananciassem": "gananciar",
    "gananciasses": "gananciar",
    "gananciaste": "gananciar",
    "gananciastes": "gananciar",
    "gananciava": "gananciar",
    "gananciavam": "gananciar",
    "gananciavas": "gananciar",
    "ganancie": "gananciar",
    "gananciei": "gananciar",
    "ganancieis": "gananciar",
    "gananciem": "gananciar",
    "gananciemo": "gananciar",
    "gananciemos": "gananciar",
    "ganancies": "gananciar",
    "ganancio": "gananciar",
    "gananciosa": "ganancioso",
    "gananciosas": "ganancioso",
    "gananciosos": "ganancioso",
    "gananciou": "gananciar",
    "gananciá": "gananciar",
    "gananciámo": "gananciar",
    "gananciámos": "gananciar",
    "gananciáramo": "gananciar",
    "gananciáramos": "gananciar",
    "gananciárei": "gananciar",
    "gananciáreis": "gananciar",
    "gananciásseis": "gananciar",
    "gananciássemos": "gananciar",
    "gananciávamo": "gananciar",
    "gananciávamos": "gananciar",
    "gananciávei": "gananciar",
    "gananciáveis": "gananciar",
    "ganapadas": "ganapada",
    "ganapas": "ganapa",
    "ganapos": "ganapo",
    "ganapões": "ganapão",
    "ganarias": "ganaria",
    "ganas": "ganir",
    "ganaus": "ganau",
    "gancarias": "gancaria",
    "ganchas": "gancha",
    "ganchetas": "gancheta",
    "ganchinho": "gancho",
    "ganchinhos": "gancho",
    "ganchito": "gancho",
    "ganchitos": "gancho",
    "ganchorras": "ganchorra",
    "ganchos": "gancho",
    "ganchosa": "ganchoso",
    "ganchosas": "ganchoso",
    "ganchosos": "ganchoso",
    "gandaeira": "gandaeiro",
    "gandaeiras": "gandaeiro",
    "gandaeiros": "gandaeiro",
    "gandaia": "gandaiar",
    "gandaiada": "gandaiar",
    "gandaiadas": "gandaiar",
    "gandaiado": "gandaiar",
    "gandaiados": "gandaiar",
    "gandaiai": "gandaiar",
    "gandaiais": "gandaiar",
    "gandaiam": "gandaiar",
    "gandaiamo": "gandaiar",
    "gandaiamos": "gandaiar",
    "gandaiando": "gandaiar",
    "gandaiara": "gandaiar",
    "gandaiaram": "gandaiar",
    "gandaiaras": "gandaiar",
    "gandaiardes": "gandaiar",
    "gandaiarei": "gandaiar",
    "gandaiareis": "gandaiar",
    "gandaiarem": "gandaiar",
    "gandaiaremos": "gandaiar",
    "gandaiares": "gandaiar",
    "gandaiaria": "gandaiar",
    "gandaiariam": "gandaiar",
    "gandaiarias": "gandaiar",
    "gandaiarmo": "gandaiar",
    "gandaiarmos": "gandaiar",
    "gandaiará": "gandaiar",
    "gandaiarás": "gandaiar",
    "gandaiarão": "gandaiar",
    "gandaiaríamos": "gandaiar",
    "gandaiaríeis": "gandaiar",
    "gandaias": "gandaiar",
    "gandaiasse": "gandaiar",
    "gandaiassem": "gandaiar",
    "gandaiasses": "gandaiar",
    "gandaiaste": "gandaiar",
    "gandaiastes": "gandaiar",
    "gandaiava": "gandaiar",
    "gandaiavam": "gandaiar",
    "gandaiavas": "gandaiar",
    "gandaie": "gandaiar",
    "gandaiei": "gandaiar",
    "gandaieira": "gandaieiro",
    "gandaieiras": "gandaieiro",
    "gandaieiros": "gandaieiro",
    "gandaieis": "gandaiar",
    "gandaiem": "gandaiar",
    "gandaiemo": "gandaiar",
    "gandaiemos": "gandaiar",
    "gandaies": "gandaiar",
    "gandaiices": "gandaiice",
    "gandaio": "gandaiar",
    "gandaiou": "gandaiar",
    "gandaiámo": "gandaiar",
    "gandaiámos": "gandaiar",
    "gandaiáramo": "gandaiar",
    "gandaiáramos": "gandaiar",
    "gandaiáreis": "gandaiar",
    "gandaiásseis": "gandaiar",
    "gandaiássemos": "gandaiar",
    "gandaiávamo": "gandaiar",
    "gandaiávamos": "gandaiar",
    "gandaiáveis": "gandaiar",
    "gandares": "gandar",
    "gandaresa": "gandarês",
    "gandaresas": "gandarês",
    "gandareses": "gandarês",
    "gandarinhas": "gandarinha",
    "gandas": "ganda",
    "gandaíces": "gandaíce",
    "gandhismos": "gandhismo",
    "gandhistas": "gandhista",
    "gandras": "gandra",
    "gandravos": "gandravo",
    "gandula": "gandulo",
    "gandulas": "gandulo",
    "gandulos": "gandulo",
    "gane": "ganir",
    "ganeiras": "ganeira",
    "ganem": "ganir",
    "ganenses": "ganense",
    "ganes": "ganir",
    "ganesa": "ganês",
    "ganesas": "ganês",
    "ganeses": "ganês",
    "ganganas": "gangana",
    "gangarilhas": "gangarilha",
    "gangarinas": "gangarina",
    "gangas": "ganga",
    "gangionites": "gangionite",
    "gangliformes": "gangliforme",
    "gangliomas": "ganglioma",
    "ganglionares": "ganglionar",
    "ganglionítica": "ganglionítico",
    "ganglioníticas": "ganglionítico",
    "ganglioníticos": "ganglionítico",
    "gangorras": "gangorra",
    "gangosa": "gangoso",
    "gangosas": "gangoso",
    "gangosos": "gangoso",
    "gangrena": "gangrenar",
    "gangrenada": "gangrenar",
    "gangrenadas": "gangrenar",
    "gangrenado": "gangrenar",
    "gangrenados": "gangrenar",
    "gangrenai": "gangrenar",
    "gangrenais": "gangrenar",
    "gangrenam": "gangrenar",
    "gangrenamo": "gangrenar",
    "gangrenamos": "gangrenar",
    "gangrenando": "gangrenar",
    "gangrenara": "gangrenar",
    "gangrenaram": "gangrenar",
    "gangrenaras": "gangrenar",
    "gangrenarde": "gangrenar",
    "gangrenardes": "gangrenar",
    "gangrenare": "gangrenar",
    "gangrenarei": "gangrenar",
    "gangrenareis": "gangrenar",
    "gangrenarem": "gangrenar",
    "gangrenaremos": "gangrenar",
    "gangrenares": "gangrenar",
    "gangrenaria": "gangrenar",
    "gangrenariam": "gangrenar",
    "gangrenarias": "gangrenar",
    "gangrenarmo": "gangrenar",
    "gangrenarmos": "gangrenar",
    "gangrenará": "gangrenar",
    "gangrenarás": "gangrenar",
    "gangrenarão": "gangrenar",
    "gangrenaríamos": "gangrenar",
    "gangrenaríeis": "gangrenar",
    "gangrenas": "gangrenar",
    "gangrenasse": "gangrenar",
    "gangrenassem": "gangrenar",
    "gangrenasses": "gangrenar",
    "gangrenaste": "gangrenar",
    "gangrenastes": "gangrenar",
    "gangrenava": "gangrenar",
    "gangrenavam": "gangrenar",
    "gangrenavas": "gangrenar",
    "gangrene": "gangrenar",
    "gangrenei": "gangrenar",
    "gangreneis": "gangrenar",
    "gangrenem": "gangrenar",
    "gangrenemo": "gangrenar",
    "gangrenemos": "gangrenar",
    "gangrenes": "gangrenar",
    "gangreno": "gangrenar",
    "gangrenosa": "gangrenoso",
    "gangrenosas": "gangrenoso",
    "gangrenosos": "gangrenoso",
    "gangrenou": "gangrenar",
    "gangrená": "gangrenar",
    "gangrenámo": "gangrenar",
    "gangrenámos": "gangrenar",
    "gangrenáramo": "gangrenar",
    "gangrenáramos": "gangrenar",
    "gangrenárei": "gangrenar",
    "gangrenáreis": "gangrenar",
    "gangrenásseis": "gangrenar",
    "gangrenássemos": "gangrenar",
    "gangrenávamo": "gangrenar",
    "gangrenávamos": "gangrenar",
    "gangrenávei": "gangrenar",
    "gangrenáveis": "gangrenar",
    "gangs": "gang",
    "gangsters": "gangster",
    "ganguelas": "ganguela",
    "gangues": "gangue",
    "gangética": "gangético",
    "gangéticas": "gangético",
    "gangéticos": "gangético",
    "gangões": "gangão",
    "ganha": "ganhar",
    "ganhada": "ganhar",
    "ganhadas": "ganhar",
    "ganhadeira": "ganhadeiro",
    "ganhadeiras": "ganhadeiro",
    "ganhadeiros": "ganhadeiro",
    "ganhadiça": "ganhadiço",
    "ganhadiças": "ganhadiço",
    "ganhadiços": "ganhadiço",
    "ganhado": "ganhar",
    "ganhadora": "ganhador",
    "ganhadoras": "ganhador",
    "ganhadores": "ganhador",
    "ganhados": "ganhar",
    "ganhai": "ganhar",
    "ganhais": "ganhar",
    "ganham": "ganhar",
    "ganhamo": "ganhar",
    "ganhamos": "ganhar",
    "ganhando": "ganhar",
    "ganhantes": "ganhante",
    "ganhanças": "ganhança",
    "ganhara": "ganhar",
    "ganharam": "ganhar",
    "ganharas": "ganhar",
    "ganharde": "ganhar",
    "ganhardes": "ganhar",
    "ganhare": "ganhar",
    "ganharei": "ganhar",
    "ganhareis": "ganhar",
    "ganharem": "ganhar",
    "ganharemos": "ganhar",
    "ganhares": "ganhar",
    "ganharia": "ganhar",
    "ganhariam": "ganhar",
    "ganharias": "ganharia",
    "ganharmo": "ganhar",
    "ganharmos": "ganhar",
    "ganhará": "ganhar",
    "ganharás": "ganhar",
    "ganharão": "ganhar",
    "ganharíamos": "ganhar",
    "ganharíeis": "ganhar",
    "ganhas": "ganhar",
    "ganhasse": "ganhar",
    "ganhassem": "ganhar",
    "ganhasses": "ganhar",
    "ganhaste": "ganhar",
    "ganhastes": "ganhar",
    "ganhava": "ganhar",
    "ganhavam": "ganhar",
    "ganhavas": "ganhar",
    "ganhe": "ganhar",
    "ganhei": "ganhar",
    "ganheis": "ganhar",
    "ganhem": "ganhar",
    "ganhemo": "ganhar",
    "ganhemos": "ganhar",
    "ganhes": "ganhar",
    "ganho": "ganhar",
    "ganhos": "ganho",
    "ganhosa": "ganhoso",
    "ganhosas": "ganhoso",
    "ganhosos": "ganhoso",
    "ganhotes": "ganhote",
    "ganhotos": "ganhoto",
    "ganhou": "ganhar",
    "ganhunças": "ganhunça",
    "ganhuças": "ganhuça",
    "ganhuços": "ganhuço",
    "ganhá": "ganhar",
    "ganhámo": "ganhar",
    "ganhámos": "ganhar",
    "ganháramo": "ganhar",
    "ganháramos": "ganhar",
    "ganhárei": "ganhar",
    "ganháreis": "ganhar",
    "ganhásseis": "ganhar",
    "ganhássemos": "ganhar",
    "ganhávamo": "ganhar",
    "ganhávamos": "ganhar",
    "ganhávei": "ganhar",
    "ganháveis": "ganhável",
    "ganhós": "ganhó",
    "ganhões": "ganhão",
    "gani": "ganir",
    "gania": "ganir",
    "ganiam": "ganir",
    "ganias": "ganir",
    "ganida": "ganir",
    "ganidas": "ganir",
    "ganideiras": "ganideira",
    "ganido": "ganir",
    "ganidos": "ganir",
    "ganimo": "ganir",
    "ganimos": "ganir",
    "ganindo": "ganir",
    "ganira": "ganir",
    "ganiram": "ganir",
    "ganiras": "ganir",
    "ganirdes": "ganir",
    "ganirei": "ganir",
    "ganireis": "ganir",
    "ganirem": "ganir",
    "ganiremos": "ganir",
    "ganires": "ganir",
    "ganiria": "ganir",
    "ganiriam": "ganir",
    "ganirias": "ganir",
    "ganirmo": "ganir",
    "ganirmos": "ganir",
    "ganirá": "ganir",
    "ganirás": "ganir",
    "ganirão": "ganir",
    "ganiríamos": "ganir",
    "ganiríeis": "ganir",
    "ganis": "ganir",
    "ganisse": "ganir",
    "ganissem": "ganir",
    "ganisses": "ganir",
    "ganiste": "ganir",
    "ganistes": "ganir",
    "ganiu": "ganir",
    "ganiza": "ganizar",
    "ganizada": "ganizar",
    "ganizadas": "ganizar",
    "ganizado": "ganizar",
    "ganizados": "ganizar",
    "ganizai": "ganizar",
    "ganizais": "ganizar",
    "ganizam": "ganizar",
    "ganizamo": "ganizar",
    "ganizamos": "ganizar",
    "ganizando": "ganizar",
    "ganizara": "ganizar",
    "ganizaram": "ganizar",
    "ganizaras": "ganizar",
    "ganizardes": "ganizar",
    "ganizarei": "ganizar",
    "ganizareis": "ganizar",
    "ganizarem": "ganizar",
    "ganizaremos": "ganizar",
    "ganizares": "ganizar",
    "ganizaria": "ganizar",
    "ganizariam": "ganizar",
    "ganizarias": "ganizar",
    "ganizarmo": "ganizar",
    "ganizarmos": "ganizar",
    "ganizará": "ganizar",
    "ganizarás": "ganizar",
    "ganizarão": "ganizar",
    "ganizaríamos": "ganizar",
    "ganizaríeis": "ganizar",
    "ganizas": "ganizar",
    "ganizasse": "ganizar",
    "ganizassem": "ganizar",
    "ganizasses": "ganizar",
    "ganizaste": "ganizar",
    "ganizastes": "ganizar",
    "ganizava": "ganizar",
    "ganizavam": "ganizar",
    "ganizavas": "ganizar",
    "ganize": "ganizar",
    "ganizei": "ganizar",
    "ganizeis": "ganizar",
    "ganizem": "ganizar",
    "ganizemo": "ganizar",
    "ganizemos": "ganizar",
    "ganizes": "ganizar",
    "ganizo": "ganizar",
    "ganizou": "ganizar",
    "ganizámo": "ganizar",
    "ganizámos": "ganizar",
    "ganizáramo": "ganizar",
    "ganizáramos": "ganizar",
    "ganizáreis": "ganizar",
    "ganizásseis": "ganizar",
    "ganizássemos": "ganizar",
    "ganizávamo": "ganizar",
    "ganizávamos": "ganizar",
    "ganizáveis": "ganizar",
    "ganiços": "ganiço",
    "ganjas": "ganja",
    "gano": "ganir",
    "gansa": "ganso",
    "gansadas": "gansada",
    "gansas": "ganso",
    "gansos": "ganso",
    "ganzepes": "ganzepe",
    "ganzás": "ganzá",
    "ganâncias": "ganância",
    "gança": "ganço",
    "ganças": "ganço",
    "ganços": "ganço",
    "ganíamo": "ganir",
    "ganíamos": "ganir",
    "ganíeis": "ganir",
    "ganíramo": "ganir",
    "ganíramos": "ganir",
    "ganíreis": "ganir",
    "ganísseis": "ganir",
    "ganíssemos": "ganir",
    "ganóides": "ganóide",
    "gapeadeiras": "gapeadeira",
    "gapeiras": "gapeira",
    "garabanhos": "garabanho",
    "garabanos": "garabano",
    "garabulhas": "garabulha",
    "garabulhenta": "garabulhento",
    "garabulhentas": "garabulhento",
    "garabulhentos": "garabulhento",
    "garabulhos": "garabulho",
    "garagens": "garagem",
    "garages": "garage",
    "garagistas": "garagista",
    "garajaus": "garajau",
    "garajões": "garajão",
    "garaldinos": "garaldino",
    "garance": "garançar",
    "garancei": "garançar",
    "garanceiras": "garanceira",
    "garanceis": "garançar",
    "garancem": "garançar",
    "garancemo": "garançar",
    "garancemos": "garançar",
    "garances": "garançar",
    "garancinas": "garancina",
    "garanhões": "garanhão",
    "garanjões": "garanjão",
    "garanta": "garantir",
    "garantais": "garantir",
    "garantam": "garantir",
    "garantamo": "garantir",
    "garantamos": "garantir",
    "garantas": "garantir",
    "garante": "garantir",
    "garantem": "garantir",
    "garantes": "garantir",
    "garanti": "garantir",
    "garantia": "garantir",
    "garantiam": "garantir",
    "garantias": "garantir",
    "garantida": "garantir",
    "garantidas": "garantir",
    "garantido": "garantir",
    "garantidora": "garantidor",
    "garantidoras": "garantidor",
    "garantidores": "garantidor",
    "garantidos": "garantir",
    "garantimo": "garantir",
    "garantimos": "garantir",
    "garantindo": "garantir",
    "garantira": "garantir",
    "garantiram": "garantir",
    "garantiras": "garantir",
    "garantirde": "garantir",
    "garantirdes": "garantir",
    "garantire": "garantir",
    "garantirei": "garantir",
    "garantireis": "garantir",
    "garantirem": "garantir",
    "garantiremos": "garantir",
    "garantires": "garantir",
    "garantiria": "garantir",
    "garantiriam": "garantir",
    "garantirias": "garantir",
    "garantirmo": "garantir",
    "garantirmos": "garantir",
    "garantirá": "garantir",
    "garantirás": "garantir",
    "garantirão": "garantir",
    "garantiríamos": "garantir",
    "garantiríeis": "garantir",
    "garantis": "garantir",
    "garantisse": "garantir",
    "garantissem": "garantir",
    "garantisses": "garantir",
    "garantiste": "garantir",
    "garantistes": "garantir",
    "garantiu": "garantir",
    "garanto": "garantir",
    "garantíamo": "garantir",
    "garantíamos": "garantir",
    "garantíei": "garantir",
    "garantíeis": "garantir",
    "garantíramo": "garantir",
    "garantíramos": "garantir",
    "garantírei": "garantir",
    "garantíreis": "garantir",
    "garantísseis": "garantir",
    "garantíssemos": "garantir",
    "garantíveis": "garantível",
    "garança": "garançar",
    "garançada": "garançar",
    "garançadas": "garançar",
    "garançado": "garançar",
    "garançados": "garançar",
    "garançai": "garançar",
    "garançais": "garançar",
    "garançam": "garançar",
    "garançamo": "garançar",
    "garançamos": "garançar",
    "garançando": "garançar",
    "garançara": "garançar",
    "garançaram": "garançar",
    "garançaras": "garançar",
    "garançarde": "garançar",
    "garançardes": "garançar",
    "garançare": "garançar",
    "garançarei": "garançar",
    "garançareis": "garançar",
    "garançarem": "garançar",
    "garançaremos": "garançar",
    "garançares": "garançar",
    "garançaria": "garançar",
    "garançariam": "garançar",
    "garançarias": "garançar",
    "garançarmo": "garançar",
    "garançarmos": "garançar",
    "garançará": "garançar",
    "garançarás": "garançar",
    "garançarão": "garançar",
    "garançaríamos": "garançar",
    "garançaríeis": "garançar",
    "garanças": "garançar",
    "garançasse": "garançar",
    "garançassem": "garançar",
    "garançasses": "garançar",
    "garançaste": "garançar",
    "garançastes": "garançar",
    "garançava": "garançar",
    "garançavam": "garançar",
    "garançavas": "garançar",
    "garanço": "garançar",
    "garançou": "garançar",
    "garançá": "garançar",
    "garançámo": "garançar",
    "garançámos": "garançar",
    "garançáramo": "garançar",
    "garançáramos": "garançar",
    "garançárei": "garançar",
    "garançáreis": "garançar",
    "garançásseis": "garançar",
    "garançássemos": "garançar",
    "garançávamo": "garançar",
    "garançávamos": "garançar",
    "garançávei": "garançar",
    "garançáveis": "garançar",
    "garapas": "garapa",
    "garatujada": "garatujado",
    "garatujadas": "garatujado",
    "garatujados": "garatujado",
    "garatujas": "garatuja",
    "garatujos": "garatujo",
    "garatusas": "garatusa",
    "garavalhas": "garavalha",
    "garavanços": "garavanço",
    "garavatos": "garavato",
    "garavetos": "garaveto",
    "garavins": "garavim",
    "garavunhas": "garavunha",
    "garbos": "garbo",
    "garbosa": "garboso",
    "garbosas": "garboso",
    "garbosidades": "garbosidade",
    "garbosos": "garboso",
    "garceira": "garceiro",
    "garceiras": "garceiro",
    "garceiros": "garceiro",
    "garcejas": "garceja",
    "garcenhos": "garcenho",
    "garcetas": "garceta",
    "garciotes": "garciote",
    "garcêses": "garcês",
    "gardingatos": "gardingato",
    "gardingos": "gardingo",
    "gardinholas": "gardinhola",
    "gardunhas": "gardunha",
    "gardunhos": "gardunho",
    "gardénias": "gardénia",
    "garelas": "garela",
    "garepes": "garepe",
    "gares": "gare",
    "garetes": "garete",
    "garfa": "garfar",
    "garfada": "garfar",
    "garfadas": "garfar",
    "garfado": "garfar",
    "garfados": "garfar",
    "garfai": "garfar",
    "garfais": "garfar",
    "garfam": "garfar",
    "garfamo": "garfar",
    "garfamos": "garfar",
    "garfando": "garfar",
    "garfara": "garfar",
    "garfaram": "garfar",
    "garfaras": "garfar",
    "garfarde": "garfar",
    "garfardes": "garfar",
    "garfare": "garfar",
    "garfarei": "garfar",
    "garfareis": "garfar",
    "garfarem": "garfar",
    "garfaremos": "garfar",
    "garfares": "garfar",
    "garfaria": "garfar",
    "garfariam": "garfar",
    "garfarias": "garfar",
    "garfarmo": "garfar",
    "garfarmos": "garfar",
    "garfará": "garfar",
    "garfarás": "garfar",
    "garfarão": "garfar",
    "garfaríamos": "garfar",
    "garfaríeis": "garfar",
    "garfas": "garfar",
    "garfasse": "garfar",
    "garfassem": "garfar",
    "garfasses": "garfar",
    "garfaste": "garfar",
    "garfastes": "garfar",
    "garfava": "garfar",
    "garfavam": "garfar",
    "garfavas": "garfar",
    "garfe": "garfar",
    "garfei": "garfar",
    "garfeiras": "garfeira",
    "garfeis": "garfar",
    "garfeja": "garfejar",
    "garfejada": "garfejar",
    "garfejadas": "garfejar",
    "garfejado": "garfejar",
    "garfejados": "garfejar",
    "garfejai": "garfejar",
    "garfejais": "garfejar",
    "garfejam": "garfejar",
    "garfejamo": "garfejar",
    "garfejamos": "garfejar",
    "garfejando": "garfejar",
    "garfejara": "garfejar",
    "garfejaram": "garfejar",
    "garfejaras": "garfejar",
    "garfejardes": "garfejar",
    "garfejarei": "garfejar",
    "garfejareis": "garfejar",
    "garfejarem": "garfejar",
    "garfejaremos": "garfejar",
    "garfejares": "garfejar",
    "garfejaria": "garfejar",
    "garfejariam": "garfejar",
    "garfejarias": "garfejar",
    "garfejarmo": "garfejar",
    "garfejarmos": "garfejar",
    "garfejará": "garfejar",
    "garfejarás": "garfejar",
    "garfejarão": "garfejar",
    "garfejaríamos": "garfejar",
    "garfejaríeis": "garfejar",
    "garfejas": "garfejar",
    "garfejasse": "garfejar",
    "garfejassem": "garfejar",
    "garfejasses": "garfejar",
    "garfejaste": "garfejar",
    "garfejastes": "garfejar",
    "garfejava": "garfejar",
    "garfejavam": "garfejar",
    "garfejavas": "garfejar",
    "garfeje": "garfejar",
    "garfejei": "garfejar",
    "garfejeis": "garfejar",
    "garfejem": "garfejar",
    "garfejemo": "garfejar",
    "garfejemos": "garfejar",
    "garfejes": "garfejar",
    "garfejo": "garfejar",
    "garfejou": "garfejar",
    "garfejámo": "garfejar",
    "garfejámos": "garfejar",
    "garfejáramo": "garfejar",
    "garfejáramos": "garfejar",
    "garfejáreis": "garfejar",
    "garfejásseis": "garfejar",
    "garfejássemos": "garfejar",
    "garfejávamo": "garfejar",
    "garfejávamos": "garfejar",
    "garfejáveis": "garfejar",
    "garfem": "garfar",
    "garfemo": "garfar",
    "garfemos": "garfar",
    "garfes": "garfar",
    "garfetes": "garfete",
    "garfilhas": "garfilha",
    "garfinho": "garfo",
    "garfinhos": "garfo",
    "garfito": "garfo",
    "garfitos": "garfo",
    "garfo": "garfar",
    "garfos": "garfo",
    "garfou": "garfar",
    "garfá": "garfar",
    "garfámo": "garfar",
    "garfámos": "garfar",
    "garfáramo": "garfar",
    "garfáramos": "garfar",
    "garfárei": "garfar",
    "garfáreis": "garfar",
    "garfásseis": "garfar",
    "garfássemos": "garfar",
    "garfávamo": "garfar",
    "garfávamos": "garfar",
    "garfávei": "garfar",
    "garfáveis": "garfar",
    "gargajolas": "gargajola",
    "gargalace": "gargalaçar",
    "gargalacei": "gargalaçar",
    "gargalaceis": "gargalaçar",
    "gargalacem": "gargalaçar",
    "gargalacemo": "gargalaçar",
    "gargalacemos": "gargalaçar",
    "gargalaces": "gargalaçar",
    "gargalaça": "gargalaçar",
    "gargalaçada": "gargalaçar",
    "gargalaçadas": "gargalaçar",
    "gargalaçado": "gargalaçar",
    "gargalaçados": "gargalaçar",
    "gargalaçai": "gargalaçar",
    "gargalaçais": "gargalaçar",
    "gargalaçam": "gargalaçar",
    "gargalaçamo": "gargalaçar",
    "gargalaçamos": "gargalaçar",
    "gargalaçando": "gargalaçar",
    "gargalaçara": "gargalaçar",
    "gargalaçaram": "gargalaçar",
    "gargalaçaras": "gargalaçar",
    "gargalaçarde": "gargalaçar",
    "gargalaçardes": "gargalaçar",
    "gargalaçare": "gargalaçar",
    "gargalaçarei": "gargalaçar",
    "gargalaçareis": "gargalaçar",
    "gargalaçarem": "gargalaçar",
    "gargalaçaremos": "gargalaçar",
    "gargalaçares": "gargalaçar",
    "gargalaçaria": "gargalaçar",
    "gargalaçariam": "gargalaçar",
    "gargalaçarias": "gargalaçar",
    "gargalaçarmo": "gargalaçar",
    "gargalaçarmos": "gargalaçar",
    "gargalaçará": "gargalaçar",
    "gargalaçarás": "gargalaçar",
    "gargalaçarão": "gargalaçar",
    "gargalaçaríamos": "gargalaçar",
    "gargalaçaríeis": "gargalaçar",
    "gargalaças": "gargalaçar",
    "gargalaçasse": "gargalaçar",
    "gargalaçassem": "gargalaçar",
    "gargalaçasses": "gargalaçar",
    "gargalaçaste": "gargalaçar",
    "gargalaçastes": "gargalaçar",
    "gargalaçava": "gargalaçar",
    "gargalaçavam": "gargalaçar",
    "gargalaçavas": "gargalaçar",
    "gargalaço": "gargalaçar",
    "gargalaços": "gargalaço",
    "gargalaçou": "gargalaçar",
    "gargalaçá": "gargalaçar",
    "gargalaçámo": "gargalaçar",
    "gargalaçámos": "gargalaçar",
    "gargalaçáramo": "gargalaçar",
    "gargalaçáramos": "gargalaçar",
    "gargalaçárei": "gargalaçar",
    "gargalaçáreis": "gargalaçar",
    "gargalaçásseis": "gargalaçar",
    "gargalaçássemos": "gargalaçar",
    "gargalaçávamo": "gargalaçar",
    "gargalaçávamos": "gargalaçar",
    "gargalaçávei": "gargalaçar",
    "gargalaçáveis": "gargalaçar",
    "gargaleira": "gargaleiro",
    "gargaleiras": "gargaleiro",
    "gargaleiros": "gargaleiro",
    "gargaleja": "gargalejar",
    "gargalejada": "gargalejar",
    "gargalejadas": "gargalejar",
    "gargalejado": "gargalejar",
    "gargalejados": "gargalejar",
    "gargalejai": "gargalejar",
    "gargalejais": "gargalejar",
    "gargalejam": "gargalejar",
    "gargalejamo": "gargalejar",
    "gargalejamos": "gargalejar",
    "gargalejando": "gargalejar",
    "gargalejara": "gargalejar",
    "gargalejaram": "gargalejar",
    "gargalejaras": "gargalejar",
    "gargalejarde": "gargalejar",
    "gargalejardes": "gargalejar",
    "gargalejare": "gargalejar",
    "gargalejarei": "gargalejar",
    "gargalejareis": "gargalejar",
    "gargalejarem": "gargalejar",
    "gargalejaremos": "gargalejar",
    "gargalejares": "gargalejar",
    "gargalejaria": "gargalejar",
    "gargalejariam": "gargalejar",
    "gargalejarias": "gargalejar",
    "gargalejarmo": "gargalejar",
    "gargalejarmos": "gargalejar",
    "gargalejará": "gargalejar",
    "gargalejarás": "gargalejar",
    "gargalejarão": "gargalejar",
    "gargalejaríamos": "gargalejar",
    "gargalejaríeis": "gargalejar",
    "gargalejas": "gargalejar",
    "gargalejasse": "gargalejar",
    "gargalejassem": "gargalejar",
    "gargalejasses": "gargalejar",
    "gargalejaste": "gargalejar",
    "gargalejastes": "gargalejar",
    "gargalejava": "gargalejar",
    "gargalejavam": "gargalejar",
    "gargalejavas": "gargalejar",
    "gargaleje": "gargalejar",
    "gargalejei": "gargalejar",
    "gargalejeis": "gargalejar",
    "gargalejem": "gargalejar",
    "gargalejemo": "gargalejar",
    "gargalejemos": "gargalejar",
    "gargalejes": "gargalejar",
    "gargalejo": "gargalejar",
    "gargalejos": "gargalejo",
    "gargalejou": "gargalejar",
    "gargalejá": "gargalejar",
    "gargalejámo": "gargalejar",
    "gargalejámos": "gargalejar",
    "gargalejáramo": "gargalejar",
    "gargalejáramos": "gargalejar",
    "gargalejárei": "gargalejar",
    "gargalejáreis": "gargalejar",
    "gargalejásseis": "gargalejar",
    "gargalejássemos": "gargalejar",
    "gargalejávamo": "gargalejar",
    "gargalejávamos": "gargalejar",
    "gargalejávei": "gargalejar",
    "gargalejáveis": "gargalejar",
    "gargalha": "gargalhar",
    "gargalhada": "gargalhar",
    "gargalhadas": "gargalhar",
    "gargalhado": "gargalhar",
    "gargalhados": "gargalhar",
    "gargalhai": "gargalhar",
    "gargalhais": "gargalhar",
    "gargalham": "gargalhar",
    "gargalhamo": "gargalhar",
    "gargalhamos": "gargalhar",
    "gargalhando": "gargalhar",
    "gargalhara": "gargalhar",
    "gargalharam": "gargalhar",
    "gargalharas": "gargalhar",
    "gargalhardes": "gargalhar",
    "gargalharei": "gargalhar",
    "gargalhareis": "gargalhar",
    "gargalharem": "gargalhar",
    "gargalharemos": "gargalhar",
    "gargalhares": "gargalhar",
    "gargalharia": "gargalhar",
    "gargalhariam": "gargalhar",
    "gargalharias": "gargalhar",
    "gargalharmo": "gargalhar",
    "gargalharmos": "gargalhar",
    "gargalhará": "gargalhar",
    "gargalharás": "gargalhar",
    "gargalharão": "gargalhar",
    "gargalharíamos": "gargalhar",
    "gargalharíeis": "gargalhar",
    "gargalhas": "gargalhar",
    "gargalhasse": "gargalhar",
    "gargalhassem": "gargalhar",
    "gargalhasses": "gargalhar",
    "gargalhaste": "gargalhar",
    "gargalhastes": "gargalhar",
    "gargalhava": "gargalhar",
    "gargalhavam": "gargalhar",
    "gargalhavas": "gargalhar",
    "gargalhe": "gargalhar",
    "gargalhei": "gargalhar",
    "gargalheiras": "gargalheira",
    "gargalheis": "gargalhar",
    "gargalhem": "gargalhar",
    "gargalhemo": "gargalhar",
    "gargalhemos": "gargalhar",
    "gargalhes": "gargalhar",
    "gargalho": "gargalhar",
    "gargalhos": "gargalho",
    "gargalhou": "gargalhar",
    "gargalhámo": "gargalhar",
    "gargalhámos": "gargalhar",
    "gargalháramo": "gargalhar",
    "gargalháramos": "gargalhar",
    "gargalháreis": "gargalhar",
    "gargalhásseis": "gargalhar",
    "gargalhássemos": "gargalhar",
    "gargalhávamo": "gargalhar",
    "gargalhávamos": "gargalhar",
    "gargalháveis": "gargalhar",
    "gargalichos": "gargalicho",
    "gargalos": "gargalo",
    "gargaluda": "gargaludo",
    "gargaludas": "gargaludo",
    "gargaludos": "gargaludo",
    "garganeira": "garganeiro",
    "garganeiras": "garganeiro",
    "garganeiros": "garganeiro",
    "garganhóis": "garganhol",
    "garganices": "garganice",
    "gargantas": "garganta",
    "gargantazinha": "garganta",
    "gargantazinhas": "garganta",
    "gargantazita": "garganta",
    "gargantazitas": "garganta",
    "garganteada": "gargantear",
    "garganteadas": "gargantear",
    "garganteado": "gargantear",
    "garganteadora": "garganteador",
    "garganteadoras": "garganteador",
    "garganteadores": "garganteador",
    "garganteados": "gargantear",
    "garganteai": "gargantear",
    "garganteais": "gargantear",
    "garganteamo": "gargantear",
    "garganteamos": "gargantear",
    "garganteando": "gargantear",
    "garganteara": "gargantear",
    "gargantearam": "gargantear",
    "gargantearas": "gargantear",
    "gargantearde": "gargantear",
    "garganteardes": "gargantear",
    "garganteare": "gargantear",
    "gargantearei": "gargantear",
    "garganteareis": "gargantear",
    "gargantearem": "gargantear",
    "gargantearemos": "gargantear",
    "garganteares": "gargantear",
    "gargantearia": "gargantear",
    "garganteariam": "gargantear",
    "gargantearias": "gargantear",
    "gargantearmo": "gargantear",
    "gargantearmos": "gargantear",
    "garganteará": "gargantear",
    "gargantearás": "gargantear",
    "gargantearão": "gargantear",
    "gargantearíamos": "gargantear",
    "gargantearíeis": "gargantear",
    "garganteasse": "gargantear",
    "garganteassem": "gargantear",
    "garganteasses": "gargantear",
    "garganteaste": "gargantear",
    "garganteastes": "gargantear",
    "garganteava": "gargantear",
    "garganteavam": "gargantear",
    "garganteavas": "gargantear",
    "garganteações": "garganteação",
    "garganteei": "gargantear",
    "garganteeis": "gargantear",
    "garganteemo": "gargantear",
    "garganteemos": "gargantear",
    "garganteia": "gargantear",
    "garganteiam": "gargantear",
    "garganteias": "gargantear",
    "garganteie": "gargantear",
    "garganteiem": "gargantear",
    "garganteies": "gargantear",
    "garganteio": "gargantear",
    "garganteios": "garganteio",
    "garganteou": "gargantear",
    "garganteá": "gargantear",
    "garganteámo": "gargantear",
    "garganteámos": "gargantear",
    "garganteáramo": "gargantear",
    "garganteáramos": "gargantear",
    "garganteárei": "gargantear",
    "garganteáreis": "gargantear",
    "garganteásseis": "gargantear",
    "garganteássemos": "gargantear",
    "garganteávamo": "gargantear",
    "garganteávamos": "gargantear",
    "garganteávei": "gargantear",
    "garganteáveis": "gargantear",
    "gargantilhas": "gargantilha",
    "gargantinha": "garganta",
    "gargantinhas": "garganta",
    "gargantita": "garganta",
    "gargantitas": "garganta",
    "gargantona": "gargantão",
    "gargantonas": "gargantão",
    "gargantos": "garganto",
    "gargantoíces": "gargantoíce",
    "gargantuesca": "gargantuesco",
    "gargantuescas": "gargantuesco",
    "gargantuescos": "gargantuesco",
    "gargantões": "gargantão",
    "gargareja": "gargarejar",
    "gargarejada": "gargarejar",
    "gargarejadas": "gargarejar",
    "gargarejado": "gargarejar",
    "gargarejados": "gargarejar",
    "gargarejai": "gargarejar",
    "gargarejais": "gargarejar",
    "gargarejam": "gargarejar",
    "gargarejamentos": "gargarejamento",
    "gargarejamo": "gargarejar",
    "gargarejamos": "gargarejar",
    "gargarejando": "gargarejar",
    "gargarejara": "gargarejar",
    "gargarejaram": "gargarejar",
    "gargarejaras": "gargarejar",
    "gargarejardes": "gargarejar",
    "gargarejarei": "gargarejar",
    "gargarejareis": "gargarejar",
    "gargarejarem": "gargarejar",
    "gargarejaremos": "gargarejar",
    "gargarejares": "gargarejar",
    "gargarejaria": "gargarejar",
    "gargarejariam": "gargarejar",
    "gargarejarias": "gargarejar",
    "gargarejarmo": "gargarejar",
    "gargarejarmos": "gargarejar",
    "gargarejará": "gargarejar",
    "gargarejarás": "gargarejar",
    "gargarejarão": "gargarejar",
    "gargarejaríamos": "gargarejar",
    "gargarejaríeis": "gargarejar",
    "gargarejas": "gargarejar",
    "gargarejasse": "gargarejar",
    "gargarejassem": "gargarejar",
    "gargarejasses": "gargarejar",
    "gargarejaste": "gargarejar",
    "gargarejastes": "gargarejar",
    "gargarejava": "gargarejar",
    "gargarejavam": "gargarejar",
    "gargarejavas": "gargarejar",
    "gargareje": "gargarejar",
    "gargarejei": "gargarejar",
    "gargarejeis": "gargarejar",
    "gargarejem": "gargarejar",
    "gargarejemo": "gargarejar",
    "gargarejemos": "gargarejar",
    "gargarejes": "gargarejar",
    "gargarejo": "gargarejar",
    "gargarejos": "gargarejo",
    "gargarejou": "gargarejar",
    "gargarejámo": "gargarejar",
    "gargarejámos": "gargarejar",
    "gargarejáramo": "gargarejar",
    "gargarejáramos": "gargarejar",
    "gargarejáreis": "gargarejar",
    "gargarejásseis": "gargarejar",
    "gargarejássemos": "gargarejar",
    "gargarejávamo": "gargarejar",
    "gargarejávamos": "gargarejar",
    "gargarejáveis": "gargarejar",
    "gargaçaladas": "gargaçalada",
    "gargueiros": "gargueiro",
    "garguleiras": "garguleira",
    "gargântuas": "gargântua",
    "garibaldas": "garibalda",
    "garibaldes": "garibalde",
    "garibaldina": "garibaldino",
    "garibaldinas": "garibaldino",
    "garibaldinos": "garibaldino",
    "garibáldis": "garibáldi",
    "garimpa": "garimpar",
    "garimpada": "garimpar",
    "garimpadas": "garimpar",
    "garimpado": "garimpar",
    "garimpados": "garimpar",
    "garimpai": "garimpar",
    "garimpais": "garimpar",
    "garimpam": "garimpar",
    "garimpamo": "garimpar",
    "garimpamos": "garimpar",
    "garimpando": "garimpar",
    "garimpara": "garimpar",
    "garimparam": "garimpar",
    "garimparas": "garimpar",
    "garimpardes": "garimpar",
    "garimparei": "garimpar",
    "garimpareis": "garimpar",
    "garimparem": "garimpar",
    "garimparemos": "garimpar",
    "garimpares": "garimpar",
    "garimparia": "garimpar",
    "garimpariam": "garimpar",
    "garimparias": "garimpar",
    "garimparmo": "garimpar",
    "garimparmos": "garimpar",
    "garimpará": "garimpar",
    "garimparás": "garimpar",
    "garimparão": "garimpar",
    "garimparíamos": "garimpar",
    "garimparíeis": "garimpar",
    "garimpas": "garimpar",
    "garimpasse": "garimpar",
    "garimpassem": "garimpar",
    "garimpasses": "garimpar",
    "garimpaste": "garimpar",
    "garimpastes": "garimpar",
    "garimpava": "garimpar",
    "garimpavam": "garimpar",
    "garimpavas": "garimpar",
    "garimpe": "garimpar",
    "garimpei": "garimpar",
    "garimpeira": "garimpeiro",
    "garimpeiras": "garimpeiro",
    "garimpeiros": "garimpeiro",
    "garimpeis": "garimpar",
    "garimpem": "garimpar",
    "garimpemo": "garimpar",
    "garimpemos": "garimpar",
    "garimpes": "garimpar",
    "garimpo": "garimpar",
    "garimpos": "garimpo",
    "garimpou": "garimpar",
    "garimpámo": "garimpar",
    "garimpámos": "garimpar",
    "garimpáramo": "garimpar",
    "garimpáramos": "garimpar",
    "garimpáreis": "garimpar",
    "garimpásseis": "garimpar",
    "garimpássemos": "garimpar",
    "garimpávamo": "garimpar",
    "garimpávamos": "garimpar",
    "garimpáveis": "garimpar",
    "garis": "gari",
    "gariteira": "gariteiro",
    "gariteiras": "gariteiro",
    "gariteiros": "gariteiro",
    "garitos": "garito",
    "garlindréus": "garlindréu",
    "garlindéus": "garlindéu",
    "garlopas": "garlopa",
    "garnachas": "garnacha",
    "garnachices": "garnachice",
    "garnachona": "garnachão",
    "garnachonas": "garnachão",
    "garnachos": "garnacho",
    "garnachões": "garnachão",
    "garneada": "garnear",
    "garneadas": "garnear",
    "garneado": "garnear",
    "garneados": "garnear",
    "garneai": "garnear",
    "garneais": "garnear",
    "garneamo": "garnear",
    "garneamos": "garnear",
    "garneando": "garnear",
    "garneara": "garnear",
    "garnearam": "garnear",
    "garnearas": "garnear",
    "garnearde": "garnear",
    "garneardes": "garnear",
    "garneare": "garnear",
    "garnearei": "garnear",
    "garneareis": "garnear",
    "garnearem": "garnear",
    "garnearemos": "garnear",
    "garneares": "garnear",
    "garnearia": "garnear",
    "garneariam": "garnear",
    "garnearias": "garnear",
    "garnearmo": "garnear",
    "garnearmos": "garnear",
    "garneará": "garnear",
    "garnearás": "garnear",
    "garnearão": "garnear",
    "garnearíamos": "garnear",
    "garnearíeis": "garnear",
    "garneasse": "garnear",
    "garneassem": "garnear",
    "garneasses": "garnear",
    "garneaste": "garnear",
    "garneastes": "garnear",
    "garneava": "garnear",
    "garneavam": "garnear",
    "garneavas": "garnear",
    "garneei": "garnear",
    "garneeis": "garnear",
    "garneemo": "garnear",
    "garneemos": "garnear",
    "garneia": "garnear",
    "garneiam": "garnear",
    "garneias": "garnear",
    "garneie": "garnear",
    "garneiem": "garnear",
    "garneies": "garnear",
    "garneio": "garnear",
    "garnelas": "garnela",
    "garneou": "garnear",
    "garneá": "garnear",
    "garneámo": "garnear",
    "garneámos": "garnear",
    "garneáramo": "garnear",
    "garneáramos": "garnear",
    "garneárei": "garnear",
    "garneáreis": "garnear",
    "garneásseis": "garnear",
    "garneássemos": "garnear",
    "garneávamo": "garnear",
    "garneávamos": "garnear",
    "garneávei": "garnear",
    "garneáveis": "garnear",
    "garnierites": "garnierite",
    "garnisés": "garnisé",
    "garnizés": "garnizé",
    "garos": "garo",
    "garota": "garoto",
    "garotada": "garotar",
    "garotadas": "garotar",
    "garotado": "garotar",
    "garotados": "garotar",
    "garotagens": "garotagem",
    "garotai": "garotar",
    "garotais": "garotar",
    "garotam": "garotar",
    "garotamo": "garotar",
    "garotamos": "garotar",
    "garotando": "garotar",
    "garotara": "garotar",
    "garotaram": "garotar",
    "garotaras": "garotar",
    "garotardes": "garotar",
    "garotarei": "garotar",
    "garotareis": "garotar",
    "garotarem": "garotar",
    "garotaremos": "garotar",
    "garotares": "garotar",
    "garotaria": "garotar",
    "garotariam": "garotar",
    "garotarias": "garotar",
    "garotarmo": "garotar",
    "garotarmos": "garotar",
    "garotará": "garotar",
    "garotarás": "garotar",
    "garotarão": "garotar",
    "garotaríamos": "garotar",
    "garotaríeis": "garotar",
    "garotas": "garoto",
    "garotasse": "garotar",
    "garotassem": "garotar",
    "garotasses": "garotar",
    "garotaste": "garotar",
    "garotastes": "garotar",
    "garotava": "garotar",
    "garotavam": "garotar",
    "garotavas": "garotar",
    "garote": "garotar",
    "garotei": "garotar",
    "garoteis": "garotar",
    "garotelha": "garotelho",
    "garotelhas": "garotelho",
    "garotelhos": "garotelho",
    "garotem": "garotar",
    "garotemo": "garotar",
    "garotemos": "garotar",
    "garotes": "garotar",
    "garotetes": "garotete",
    "garotices": "garotice",
    "garotinha": "garoto",
    "garotinhas": "garoto",
    "garotinho": "garoto",
    "garotinhos": "garoto",
    "garotis": "garotil",
    "garotita": "garoto",
    "garotitas": "garoto",
    "garotito": "garoto",
    "garotitos": "garoto",
    "garoto": "garotar",
    "garotona": "garoto",
    "garotonas": "garoto",
    "garotos": "garoto",
    "garototes": "garotote",
    "garotou": "garotar",
    "garotámo": "garotar",
    "garotámos": "garotar",
    "garotáramo": "garotar",
    "garotáramos": "garotar",
    "garotáreis": "garotar",
    "garotásseis": "garotar",
    "garotássemos": "garotar",
    "garotávamo": "garotar",
    "garotávamos": "garotar",
    "garotáveis": "garotar",
    "garotão": "garoto",
    "garotões": "garoto",
    "garoupas": "garoupa",
    "garra": "garro",
    "garrada": "garrar",
    "garradas": "garrar",
    "garrado": "garrar",
    "garrados": "garrar",
    "garrafadas": "garrafada",
    "garrafais": "garrafal",
    "garrafarias": "garrafaria",
    "garrafas": "garrafa",
    "garrafeiras": "garrafeira",
    "garrafeiros": "garrafeiro",
    "garrafinha": "garrafa",
    "garrafinhas": "garrafa",
    "garrafita": "garrafa",
    "garrafitas": "garrafa",
    "garrafosa": "garrafoso",
    "garrafosas": "garrafoso",
    "garrafosos": "garrafoso",
    "garrafãozinho": "garrafão",
    "garrafãozito": "garrafão",
    "garrafões": "garrafão",
    "garrafõezinhos": "garrafão",
    "garrafõezitos": "garrafão",
    "garraginas": "garragina",
    "garrai": "garrar",
    "garraiadas": "garraiada",
    "garraios": "garraio",
    "garrais": "garrir",
    "garram": "garrir",
    "garramo": "garrir",
    "garramos": "garrir",
    "garranas": "garrana",
    "garrancha": "garranchar",
    "garranchada": "garranchar",
    "garranchadas": "garranchar",
    "garranchado": "garranchar",
    "garranchados": "garranchar",
    "garranchai": "garranchar",
    "garranchais": "garranchar",
    "garrancham": "garranchar",
    "garranchamo": "garranchar",
    "garranchamos": "garranchar",
    "garranchando": "garranchar",
    "garranchara": "garranchar",
    "garrancharam": "garranchar",
    "garrancharas": "garranchar",
    "garrancharde": "garranchar",
    "garranchardes": "garranchar",
    "garranchare": "garranchar",
    "garrancharei": "garranchar",
    "garranchareis": "garranchar",
    "garrancharem": "garranchar",
    "garrancharemos": "garranchar",
    "garranchares": "garranchar",
    "garrancharia": "garranchar",
    "garranchariam": "garranchar",
    "garrancharias": "garranchar",
    "garrancharmo": "garranchar",
    "garrancharmos": "garranchar",
    "garranchará": "garranchar",
    "garrancharás": "garranchar",
    "garrancharão": "garranchar",
    "garrancharíamos": "garranchar",
    "garrancharíeis": "garranchar",
    "garranchas": "garranchar",
    "garranchasse": "garranchar",
    "garranchassem": "garranchar",
    "garranchasses": "garranchar",
    "garranchaste": "garranchar",
    "garranchastes": "garranchar",
    "garranchava": "garranchar",
    "garranchavam": "garranchar",
    "garranchavas": "garranchar",
    "garranche": "garranchar",
    "garranchei": "garranchar",
    "garrancheis": "garranchar",
    "garranchem": "garranchar",
    "garranchemo": "garranchar",
    "garranchemos": "garranchar",
    "garranches": "garranchar",
    "garrancho": "garranchar",
    "garranchos": "garrancho",
    "garranchou": "garranchar",
    "garranchá": "garranchar",
    "garranchámo": "garranchar",
    "garranchámos": "garranchar",
    "garrancháramo": "garranchar",
    "garrancháramos": "garranchar",
    "garranchárei": "garranchar",
    "garrancháreis": "garranchar",
    "garranchásseis": "garranchar",
    "garranchássemos": "garranchar",
    "garranchávamo": "garranchar",
    "garranchávamos": "garranchar",
    "garranchávei": "garranchar",
    "garrancháveis": "garranchar",
    "garrando": "garrar",
    "garranos": "garrano",
    "garrantos": "garranto",
    "garrara": "garrar",
    "garraram": "garrar",
    "garraras": "garrar",
    "garrardes": "garrar",
    "garrarei": "garrar",
    "garrareis": "garrar",
    "garrarem": "garrar",
    "garraremos": "garrar",
    "garrares": "garrar",
    "garraria": "garrar",
    "garrariam": "garrar",
    "garrarias": "garrar",
    "garrarmo": "garrar",
    "garrarmos": "garrar",
    "garrará": "garrar",
    "garrarás": "garrar",
    "garrarão": "garrar",
    "garraríamos": "garrar",
    "garraríeis": "garrar",
    "garras": "garro",
    "garrasse": "garrar",
    "garrassem": "garrar",
    "garrasses": "garrar",
    "garraste": "garrar",
    "garrastes": "garrar",
    "garraus": "garrau",
    "garrava": "garrar",
    "garravam": "garrar",
    "garravas": "garrar",
    "garrazes": "garraz",
    "garre": "garrir",
    "garreada": "garrear",
    "garreadas": "garrear",
    "garreado": "garrear",
    "garreados": "garrear",
    "garreai": "garrear",
    "garreais": "garrear",
    "garreamo": "garrear",
    "garreamos": "garrear",
    "garreando": "garrear",
    "garreara": "garrear",
    "garrearam": "garrear",
    "garrearas": "garrear",
    "garrearde": "garrear",
    "garreardes": "garrear",
    "garreare": "garrear",
    "garrearei": "garrear",
    "garreareis": "garrear",
    "garrearem": "garrear",
    "garrearemos": "garrear",
    "garreares": "garrear",
    "garrearia": "garrear",
    "garreariam": "garrear",
    "garrearias": "garrear",
    "garrearmo": "garrear",
    "garrearmos": "garrear",
    "garreará": "garrear",
    "garrearás": "garrear",
    "garrearão": "garrear",
    "garrearíamos": "garrear",
    "garrearíeis": "garrear",
    "garreasse": "garrear",
    "garreassem": "garrear",
    "garreasses": "garrear",
    "garreaste": "garrear",
    "garreastes": "garrear",
    "garreava": "garrear",
    "garreavam": "garrear",
    "garreavas": "garrear",
    "garreei": "garrear",
    "garreeis": "garrear",
    "garreemo": "garrear",
    "garreemos": "garrear",
    "garrei": "garrar",
    "garreia": "garrear",
    "garreiam": "garrear",
    "garreias": "garrear",
    "garreie": "garrear",
    "garreiem": "garrear",
    "garreies": "garrear",
    "garreio": "garrear",
    "garreis": "garrar",
    "garrem": "garrir",
    "garremo": "garrar",
    "garremos": "garrar",
    "garrenta": "garrento",
    "garrentas": "garrento",
    "garrentos": "garrento",
    "garreou": "garrear",
    "garres": "garrir",
    "garrettiana": "garrettiano",
    "garrettianas": "garrettiano",
    "garrettianismos": "garrettianismo",
    "garrettianistas": "garrettianista",
    "garrettianos": "garrettiano",
    "garreá": "garrear",
    "garreámo": "garrear",
    "garreámos": "garrear",
    "garreáramo": "garrear",
    "garreáramos": "garrear",
    "garreárei": "garrear",
    "garreáreis": "garrear",
    "garreásseis": "garrear",
    "garreássemos": "garrear",
    "garreávamo": "garrear",
    "garreávamos": "garrear",
    "garreávei": "garrear",
    "garreáveis": "garrear",
    "garri": "garrir",
    "garria": "garrir",
    "garriam": "garrir",
    "garrias": "garrir",
    "garrida": "garrir",
    "garridas": "garrir",
    "garridices": "garridice",
    "garridismos": "garridismo",
    "garrido": "garrir",
    "garridos": "garrir",
    "garrimo": "garrir",
    "garrimos": "garrir",
    "garrinchos": "garrincho",
    "garrindo": "garrir",
    "garrira": "garrir",
    "garriram": "garrir",
    "garriras": "garrir",
    "garrirdes": "garrir",
    "garrirei": "garrir",
    "garrireis": "garrir",
    "garrirem": "garrir",
    "garriremos": "garrir",
    "garrires": "garrir",
    "garriria": "garrir",
    "garririam": "garrir",
    "garririas": "garrir",
    "garrirmo": "garrir",
    "garrirmos": "garrir",
    "garrirá": "garrir",
    "garrirás": "garrir",
    "garrirão": "garrir",
    "garriríamos": "garrir",
    "garriríeis": "garrir",
    "garris": "garrir",
    "garrisse": "garrir",
    "garrissem": "garrir",
    "garrisses": "garrir",
    "garriste": "garrir",
    "garristes": "garrir",
    "garriu": "garrir",
    "garriços": "garriço",
    "garro": "garrir",
    "garrocha": "garrochar",
    "garrochada": "garrochar",
    "garrochadas": "garrochar",
    "garrochado": "garrochar",
    "garrochadora": "garrochador",
    "garrochadoras": "garrochador",
    "garrochadores": "garrochador",
    "garrochados": "garrochar",
    "garrochai": "garrochar",
    "garrochais": "garrochar",
    "garrocham": "garrochar",
    "garrochamo": "garrochar",
    "garrochamos": "garrochar",
    "garrochando": "garrochar",
    "garrochara": "garrochar",
    "garrocharam": "garrochar",
    "garrocharas": "garrochar",
    "garrocharde": "garrochar",
    "garrochardes": "garrochar",
    "garrochare": "garrochar",
    "garrocharei": "garrochar",
    "garrochareis": "garrochar",
    "garrocharem": "garrochar",
    "garrocharemos": "garrochar",
    "garrochares": "garrochar",
    "garrocharia": "garrochar",
    "garrochariam": "garrochar",
    "garrocharias": "garrochar",
    "garrocharmo": "garrochar",
    "garrocharmos": "garrochar",
    "garrochará": "garrochar",
    "garrocharás": "garrochar",
    "garrocharão": "garrochar",
    "garrocharíamos": "garrochar",
    "garrocharíeis": "garrochar",
    "garrochas": "garrochar",
    "garrochasse": "garrochar",
    "garrochassem": "garrochar",
    "garrochasses": "garrochar",
    "garrochaste": "garrochar",
    "garrochastes": "garrochar",
    "garrochava": "garrochar",
    "garrochavam": "garrochar",
    "garrochavas": "garrochar",
    "garroche": "garrochar",
    "garrochei": "garrochar",
    "garrocheis": "garrochar",
    "garrochem": "garrochar",
    "garrochemo": "garrochar",
    "garrochemos": "garrochar",
    "garroches": "garrochar",
    "garrocho": "garrochar",
    "garrochou": "garrochar",
    "garrochá": "garrochar",
    "garrochámo": "garrochar",
    "garrochámos": "garrochar",
    "garrocháramo": "garrochar",
    "garrocháramos": "garrochar",
    "garrochárei": "garrochar",
    "garrocháreis": "garrochar",
    "garrochásseis": "garrochar",
    "garrochássemos": "garrochar",
    "garrochávamo": "garrochar",
    "garrochávamos": "garrochar",
    "garrochávei": "garrochar",
    "garrocháveis": "garrochar",
    "garrochões": "garrochão",
    "garros": "garro",
    "garrota": "garrotar",
    "garrotada": "garrotar",
    "garrotadas": "garrotar",
    "garrotado": "garrotar",
    "garrotados": "garrotar",
    "garrotai": "garrotar",
    "garrotais": "garrotar",
    "garrotam": "garrotar",
    "garrotamo": "garrotar",
    "garrotamos": "garrotar",
    "garrotando": "garrotar",
    "garrotara": "garrotar",
    "garrotaram": "garrotar",
    "garrotaras": "garrotar",
    "garrotarde": "garrotar",
    "garrotardes": "garrotar",
    "garrotare": "garrotar",
    "garrotarei": "garrotar",
    "garrotareis": "garrotar",
    "garrotarem": "garrotar",
    "garrotaremos": "garrotar",
    "garrotares": "garrotar",
    "garrotaria": "garrotar",
    "garrotariam": "garrotar",
    "garrotarias": "garrotar",
    "garrotarmo": "garrotar",
    "garrotarmos": "garrotar",
    "garrotará": "garrotar",
    "garrotarás": "garrotar",
    "garrotarão": "garrotar",
    "garrotaríamos": "garrotar",
    "garrotaríeis": "garrotar",
    "garrotas": "garrotar",
    "garrotasse": "garrotar",
    "garrotassem": "garrotar",
    "garrotasses": "garrotar",
    "garrotaste": "garrotar",
    "garrotastes": "garrotar",
    "garrotava": "garrotar",
    "garrotavam": "garrotar",
    "garrotavas": "garrotar",
    "garrote": "garrotar",
    "garroteada": "garrotear",
    "garroteadas": "garrotear",
    "garroteado": "garrotear",
    "garroteados": "garrotear",
    "garroteai": "garrotear",
    "garroteais": "garrotear",
    "garroteamo": "garrotear",
    "garroteamos": "garrotear",
    "garroteando": "garrotear",
    "garroteara": "garrotear",
    "garrotearam": "garrotear",
    "garrotearas": "garrotear",
    "garrotearde": "garrotear",
    "garroteardes": "garrotear",
    "garroteare": "garrotear",
    "garrotearei": "garrotear",
    "garroteareis": "garrotear",
    "garrotearem": "garrotear",
    "garrotearemos": "garrotear",
    "garroteares": "garrotear",
    "garrotearia": "garrotear",
    "garroteariam": "garrotear",
    "garrotearias": "garrotear",
    "garrotearmo": "garrotear",
    "garrotearmos": "garrotear",
    "garroteará": "garrotear",
    "garrotearás": "garrotear",
    "garrotearão": "garrotear",
    "garrotearíamos": "garrotear",
    "garrotearíeis": "garrotear",
    "garroteasse": "garrotear",
    "garroteassem": "garrotear",
    "garroteasses": "garrotear",
    "garroteaste": "garrotear",
    "garroteastes": "garrotear",
    "garroteava": "garrotear",
    "garroteavam": "garrotear",
    "garroteavas": "garrotear",
    "garroteei": "garrotear",
    "garroteeis": "garrotear",
    "garroteemo": "garrotear",
    "garroteemos": "garrotear",
    "garrotei": "garrotar",
    "garroteia": "garrotear",
    "garroteiam": "garrotear",
    "garroteias": "garrotear",
    "garroteie": "garrotear",
    "garroteiem": "garrotear",
    "garroteies": "garrotear",
    "garroteio": "garrotear",
    "garroteis": "garrotar",
    "garrotem": "garrotar",
    "garrotemo": "garrotar",
    "garrotemos": "garrotar",
    "garroteou": "garrotear",
    "garrotes": "garrote",
    "garroteá": "garrotear",
    "garroteámo": "garrotear",
    "garroteámos": "garrotear",
    "garroteáramo": "garrotear",
    "garroteáramos": "garrotear",
    "garroteárei": "garrotear",
    "garroteáreis": "garrotear",
    "garroteásseis": "garrotear",
    "garroteássemos": "garrotear",
    "garroteávamo": "garrotear",
    "garroteávamos": "garrotear",
    "garroteávei": "garrotear",
    "garroteáveis": "garrotear",
    "garrotilhos": "garrotilho",
    "garroto": "garrotar",
    "garrotou": "garrotar",
    "garrotá": "garrotar",
    "garrotámo": "garrotar",
    "garrotámos": "garrotar",
    "garrotáramo": "garrotar",
    "garrotáramos": "garrotar",
    "garrotárei": "garrotar",
    "garrotáreis": "garrotar",
    "garrotásseis": "garrotar",
    "garrotássemos": "garrotar",
    "garrotávamo": "garrotar",
    "garrotávamos": "garrotar",
    "garrotávei": "garrotar",
    "garrotáveis": "garrotar",
    "garrou": "garrar",
    "garruchas": "garrucha",
    "garruchos": "garrucho",
    "garrula": "garrular",
    "garrulada": "garrular",
    "garruladas": "garrular",
    "garrulado": "garrular",
    "garrulados": "garrular",
    "garrulai": "garrular",
    "garrulais": "garrular",
    "garrulam": "garrular",
    "garrulamo": "garrular",
    "garrulamos": "garrular",
    "garrulando": "garrular",
    "garrulara": "garrular",
    "garrularam": "garrular",
    "garrularas": "garrular",
    "garrulardes": "garrular",
    "garrularei": "garrular",
    "garrulareis": "garrular",
    "garrularem": "garrular",
    "garrularemos": "garrular",
    "garrulares": "garrular",
    "garrularia": "garrular",
    "garrulariam": "garrular",
    "garrularias": "garrular",
    "garrularmo": "garrular",
    "garrularmos": "garrular",
    "garrulará": "garrular",
    "garrularás": "garrular",
    "garrularão": "garrular",
    "garrularíamos": "garrular",
    "garrularíeis": "garrular",
    "garrulas": "garrular",
    "garrulasse": "garrular",
    "garrulassem": "garrular",
    "garrulasses": "garrular",
    "garrulaste": "garrular",
    "garrulastes": "garrular",
    "garrulava": "garrular",
    "garrulavam": "garrular",
    "garrulavas": "garrular",
    "garrule": "garrular",
    "garrulei": "garrular",
    "garruleis": "garrular",
    "garrulem": "garrular",
    "garrulemo": "garrular",
    "garrulemos": "garrular",
    "garrules": "garrular",
    "garrulices": "garrulice",
    "garrulidades": "garrulidade",
    "garrulo": "garrular",
    "garrulou": "garrular",
    "garrulámo": "garrular",
    "garrulámos": "garrular",
    "garruláramo": "garrular",
    "garruláramos": "garrular",
    "garruláreis": "garrular",
    "garrulásseis": "garrular",
    "garrulássemos": "garrular",
    "garrulávamo": "garrular",
    "garrulávamos": "garrular",
    "garruláveis": "garrular",
    "garrunchos": "garruncho",
    "garruços": "garruço",
    "garrámo": "garrar",
    "garrámos": "garrar",
    "garráramo": "garrar",
    "garráramos": "garrar",
    "garráreis": "garrar",
    "garrásseis": "garrar",
    "garrássemos": "garrar",
    "garrávamo": "garrar",
    "garrávamos": "garrar",
    "garráveis": "garrar",
    "garríamo": "garrir",
    "garríamos": "garrir",
    "garríeis": "garrir",
    "garríramo": "garrir",
    "garríramos": "garrir",
    "garríreis": "garrir",
    "garrísseis": "garrir",
    "garríssemos": "garrir",
    "garrões": "garrão",
    "garupadas": "garupada",
    "garupas": "garupa",
    "garupeiros": "garupeiro",
    "garzinas": "garzina",
    "garça": "garço",
    "garças": "garço",
    "garços": "garço",
    "garçotas": "garçota",
    "garçotes": "garçote",
    "garçotos": "garçoto",
    "garções": "garção",
    "garões": "garão",
    "gasalha": "gasalhar",
    "gasalhada": "gasalhar",
    "gasalhadas": "gasalhar",
    "gasalhado": "gasalhar",
    "gasalhados": "gasalhar",
    "gasalhai": "gasalhar",
    "gasalhais": "gasalhar",
    "gasalham": "gasalhar",
    "gasalhamentos": "gasalhamento",
    "gasalhamo": "gasalhar",
    "gasalhamos": "gasalhar",
    "gasalhando": "gasalhar",
    "gasalhara": "gasalhar",
    "gasalharam": "gasalhar",
    "gasalharas": "gasalhar",
    "gasalharde": "gasalhar",
    "gasalhardes": "gasalhar",
    "gasalhare": "gasalhar",
    "gasalharei": "gasalhar",
    "gasalhareis": "gasalhar",
    "gasalharem": "gasalhar",
    "gasalharemos": "gasalhar",
    "gasalhares": "gasalhar",
    "gasalharia": "gasalhar",
    "gasalhariam": "gasalhar",
    "gasalharias": "gasalhar",
    "gasalharmo": "gasalhar",
    "gasalharmos": "gasalhar",
    "gasalhará": "gasalhar",
    "gasalharás": "gasalhar",
    "gasalharão": "gasalhar",
    "gasalharíamos": "gasalhar",
    "gasalharíeis": "gasalhar",
    "gasalhas": "gasalhar",
    "gasalhasse": "gasalhar",
    "gasalhassem": "gasalhar",
    "gasalhasses": "gasalhar",
    "gasalhaste": "gasalhar",
    "gasalhastes": "gasalhar",
    "gasalhava": "gasalhar",
    "gasalhavam": "gasalhar",
    "gasalhavas": "gasalhar",
    "gasalhe": "gasalhar",
    "gasalhei": "gasalhar",
    "gasalheis": "gasalhar",
    "gasalhem": "gasalhar",
    "gasalhemo": "gasalhar",
    "gasalhemos": "gasalhar",
    "gasalhes": "gasalhar",
    "gasalho": "gasalhar",
    "gasalhos": "gasalho",
    "gasalhosa": "gasalhoso",
    "gasalhosas": "gasalhoso",
    "gasalhosos": "gasalhoso",
    "gasalhou": "gasalhar",
    "gasalhá": "gasalhar",
    "gasalhámo": "gasalhar",
    "gasalhámos": "gasalhar",
    "gasalháramo": "gasalhar",
    "gasalháramos": "gasalhar",
    "gasalhárei": "gasalhar",
    "gasalháreis": "gasalhar",
    "gasalhásseis": "gasalhar",
    "gasalhássemos": "gasalhar",
    "gasalhávamo": "gasalhar",
    "gasalhávamos": "gasalhar",
    "gasalhávei": "gasalhar",
    "gasalháveis": "gasalhar",
    "gascona": "gascão",
    "gasconadas": "gasconada",
    "gasconas": "gascão",
    "gascões": "gascão",
    "gaseada": "gasear",
    "gaseadas": "gasear",
    "gaseado": "gasear",
    "gaseados": "gasear",
    "gaseai": "gasear",
    "gaseais": "gasear",
    "gaseamo": "gasear",
    "gaseamos": "gasear",
    "gaseando": "gasear",
    "gaseara": "gasear",
    "gasearam": "gasear",
    "gasearas": "gasear",
    "gasearde": "gasear",
    "gaseardes": "gasear",
    "gaseare": "gasear",
    "gasearei": "gasear",
    "gaseareis": "gasear",
    "gasearem": "gasear",
    "gasearemos": "gasear",
    "gaseares": "gasear",
    "gasearia": "gasear",
    "gaseariam": "gasear",
    "gasearias": "gasear",
    "gasearmo": "gasear",
    "gasearmos": "gasear",
    "gaseará": "gasear",
    "gasearás": "gasear",
    "gasearão": "gasear",
    "gasearíamos": "gasear",
    "gasearíeis": "gasear",
    "gaseasse": "gasear",
    "gaseassem": "gasear",
    "gaseasses": "gasear",
    "gaseaste": "gasear",
    "gaseastes": "gasear",
    "gaseava": "gasear",
    "gaseavam": "gasear",
    "gaseavas": "gasear",
    "gaseei": "gasear",
    "gaseeis": "gasear",
    "gaseemo": "gasear",
    "gaseemos": "gasear",
    "gaseia": "gasear",
    "gaseiam": "gasear",
    "gaseias": "gasear",
    "gaseie": "gasear",
    "gaseiem": "gasear",
    "gaseies": "gasear",
    "gaseifica": "gaseificar",
    "gaseificada": "gaseificar",
    "gaseificadas": "gaseificar",
    "gaseificado": "gaseificar",
    "gaseificadora": "gaseificador",
    "gaseificadoras": "gaseificador",
    "gaseificadores": "gaseificador",
    "gaseificados": "gaseificar",
    "gaseificai": "gaseificar",
    "gaseificais": "gaseificar",
    "gaseificam": "gaseificar",
    "gaseificamo": "gaseificar",
    "gaseificamos": "gaseificar",
    "gaseificando": "gaseificar",
    "gaseificara": "gaseificar",
    "gaseificaram": "gaseificar",
    "gaseificaras": "gaseificar",
    "gaseificarde": "gaseificar",
    "gaseificardes": "gaseificar",
    "gaseificare": "gaseificar",
    "gaseificarei": "gaseificar",
    "gaseificareis": "gaseificar",
    "gaseificarem": "gaseificar",
    "gaseificaremos": "gaseificar",
    "gaseificares": "gaseificar",
    "gaseificaria": "gaseificar",
    "gaseificariam": "gaseificar",
    "gaseificarias": "gaseificar",
    "gaseificarmo": "gaseificar",
    "gaseificarmos": "gaseificar",
    "gaseificará": "gaseificar",
    "gaseificarás": "gaseificar",
    "gaseificarão": "gaseificar",
    "gaseificaríamos": "gaseificar",
    "gaseificaríeis": "gaseificar",
    "gaseificas": "gaseificar",
    "gaseificasse": "gaseificar",
    "gaseificassem": "gaseificar",
    "gaseificasses": "gaseificar",
    "gaseificaste": "gaseificar",
    "gaseificastes": "gaseificar",
    "gaseificava": "gaseificar",
    "gaseificavam": "gaseificar",
    "gaseificavas": "gaseificar",
    "gaseificações": "gaseificação",
    "gaseifico": "gaseificar",
    "gaseificou": "gaseificar",
    "gaseificá": "gaseificar",
    "gaseificámo": "gaseificar",
    "gaseificámos": "gaseificar",
    "gaseificáramo": "gaseificar",
    "gaseificáramos": "gaseificar",
    "gaseificárei": "gaseificar",
    "gaseificáreis": "gaseificar",
    "gaseificásseis": "gaseificar",
    "gaseificássemos": "gaseificar",
    "gaseificávamo": "gaseificar",
    "gaseificávamos": "gaseificar",
    "gaseificávei": "gaseificar",
    "gaseificáveis": "gaseificar",
    "gaseifique": "gaseificar",
    "gaseifiquei": "gaseificar",
    "gaseifiqueis": "gaseificar",
    "gaseifiquem": "gaseificar",
    "gaseifiquemo": "gaseificar",
    "gaseifiquemos": "gaseificar",
    "gaseifiques": "gaseificar",
    "gaseiformes": "gaseiforme",
    "gaseio": "gasear",
    "gaseira": "gaseiro",
    "gaseiras": "gaseiro",
    "gaseiros": "gaseiro",
    "gaseou": "gasear",
    "gases": "gás",
    "gaseá": "gasear",
    "gaseámo": "gasear",
    "gaseámos": "gasear",
    "gaseáramo": "gasear",
    "gaseáramos": "gasear",
    "gaseárei": "gasear",
    "gaseáreis": "gasear",
    "gaseásseis": "gasear",
    "gaseássemos": "gasear",
    "gaseávamo": "gasear",
    "gaseávamos": "gasear",
    "gaseávei": "gasear",
    "gaseáveis": "gasear",
    "gasganetes": "gasganete",
    "gasguetes": "gasguete",
    "gasguita": "gasguito",
    "gasguitas": "gasguito",
    "gasguitos": "gasguito",
    "gasifica": "gasificar",
    "gasificada": "gasificar",
    "gasificadas": "gasificar",
    "gasificado": "gasificar",
    "gasificados": "gasificar",
    "gasificai": "gasificar",
    "gasificais": "gasificar",
    "gasificam": "gasificar",
    "gasificamo": "gasificar",
    "gasificamos": "gasificar",
    "gasificando": "gasificar",
    "gasificara": "gasificar",
    "gasificaram": "gasificar",
    "gasificaras": "gasificar",
    "gasificarde": "gasificar",
    "gasificardes": "gasificar",
    "gasificare": "gasificar",
    "gasificarei": "gasificar",
    "gasificareis": "gasificar",
    "gasificarem": "gasificar",
    "gasificaremos": "gasificar",
    "gasificares": "gasificar",
    "gasificaria": "gasificar",
    "gasificariam": "gasificar",
    "gasificarias": "gasificar",
    "gasificarmo": "gasificar",
    "gasificarmos": "gasificar",
    "gasificará": "gasificar",
    "gasificarás": "gasificar",
    "gasificarão": "gasificar",
    "gasificaríamos": "gasificar",
    "gasificaríeis": "gasificar",
    "gasificas": "gasificar",
    "gasificasse": "gasificar",
    "gasificassem": "gasificar",
    "gasificasses": "gasificar",
    "gasificaste": "gasificar",
    "gasificastes": "gasificar",
    "gasificava": "gasificar",
    "gasificavam": "gasificar",
    "gasificavas": "gasificar",
    "gasificações": "gasificação",
    "gasifico": "gasificar",
    "gasificou": "gasificar",
    "gasificá": "gasificar",
    "gasificámo": "gasificar",
    "gasificámos": "gasificar",
    "gasificáramo": "gasificar",
    "gasificáramos": "gasificar",
    "gasificárei": "gasificar",
    "gasificáreis": "gasificar",
    "gasificásseis": "gasificar",
    "gasificássemos": "gasificar",
    "gasificávamo": "gasificar",
    "gasificávamos": "gasificar",
    "gasificávei": "gasificar",
    "gasificáveis": "gasificar",
    "gasifique": "gasificar",
    "gasifiquei": "gasificar",
    "gasifiqueis": "gasificar",
    "gasifiquem": "gasificar",
    "gasifiquemo": "gasificar",
    "gasifiquemos": "gasificar",
    "gasifiques": "gasificar",
    "gasnates": "gasnate",
    "gasnetes": "gasnete",
    "gasodutos": "gasoduto",
    "gasogéneos": "gasogéneo",
    "gasolinas": "gasolina",
    "gasolineiras": "gasolineira",
    "gasometrias": "gasometria",
    "gasométrica": "gasométrico",
    "gasométricas": "gasométrico",
    "gasométricos": "gasométrico",
    "gasosa": "gasoso",
    "gasosas": "gasoso",
    "gasosos": "gasoso",
    "gaspachos": "gaspacho",
    "gaspeada": "gaspear",
    "gaspeadas": "gaspear",
    "gaspeadeiras": "gaspeadeira",
    "gaspeado": "gaspear",
    "gaspeados": "gaspear",
    "gaspeai": "gaspear",
    "gaspeais": "gaspear",
    "gaspeamo": "gaspear",
    "gaspeamos": "gaspear",
    "gaspeando": "gaspear",
    "gaspeara": "gaspear",
    "gaspearam": "gaspear",
    "gaspearas": "gaspear",
    "gaspearde": "gaspear",
    "gaspeardes": "gaspear",
    "gaspeare": "gaspear",
    "gaspearei": "gaspear",
    "gaspeareis": "gaspear",
    "gaspearem": "gaspear",
    "gaspearemos": "gaspear",
    "gaspeares": "gaspear",
    "gaspearia": "gaspear",
    "gaspeariam": "gaspear",
    "gaspearias": "gaspear",
    "gaspearmo": "gaspear",
    "gaspearmos": "gaspear",
    "gaspeará": "gaspear",
    "gaspearás": "gaspear",
    "gaspearão": "gaspear",
    "gaspearíamos": "gaspear",
    "gaspearíeis": "gaspear",
    "gaspeasse": "gaspear",
    "gaspeassem": "gaspear",
    "gaspeasses": "gaspear",
    "gaspeaste": "gaspear",
    "gaspeastes": "gaspear",
    "gaspeava": "gaspear",
    "gaspeavam": "gaspear",
    "gaspeavas": "gaspear",
    "gaspeei": "gaspear",
    "gaspeeis": "gaspear",
    "gaspeemo": "gaspear",
    "gaspeemos": "gaspear",
    "gaspeia": "gaspear",
    "gaspeiam": "gaspear",
    "gaspeias": "gaspear",
    "gaspeie": "gaspear",
    "gaspeiem": "gaspear",
    "gaspeies": "gaspear",
    "gaspeio": "gaspear",
    "gaspeou": "gaspear",
    "gaspeá": "gaspear",
    "gaspeámo": "gaspear",
    "gaspeámos": "gaspear",
    "gaspeáramo": "gaspear",
    "gaspeáramos": "gaspear",
    "gaspeárei": "gaspear",
    "gaspeáreis": "gaspear",
    "gaspeásseis": "gaspear",
    "gaspeássemos": "gaspear",
    "gaspeávamo": "gaspear",
    "gaspeávamos": "gaspear",
    "gaspeávei": "gaspear",
    "gaspeáveis": "gaspear",
    "gaspópias": "gaspópia",
    "gasta": "gasto",
    "gastada": "gastar",
    "gastadas": "gastar",
    "gastadeira": "gastador",
    "gastadeiras": "gastador",
    "gastado": "gastar",
    "gastadora": "gastador",
    "gastadoras": "gastador",
    "gastadores": "gastador",
    "gastados": "gastar",
    "gastai": "gastar",
    "gastais": "gastar",
    "gastalhos": "gastalho",
    "gastam": "gastar",
    "gastamentos": "gastamento",
    "gastamo": "gastar",
    "gastamos": "gastar",
    "gastando": "gastar",
    "gastara": "gastar",
    "gastaram": "gastar",
    "gastaras": "gastar",
    "gastarde": "gastar",
    "gastardes": "gastar",
    "gastare": "gastar",
    "gastarei": "gastar",
    "gastareis": "gastar",
    "gastarem": "gastar",
    "gastaremos": "gastar",
    "gastares": "gastar",
    "gastaria": "gastar",
    "gastariam": "gastar",
    "gastarias": "gastar",
    "gastarmo": "gastar",
    "gastarmos": "gastar",
    "gastará": "gastar",
    "gastarás": "gastar",
    "gastarão": "gastar",
    "gastaríamos": "gastar",
    "gastaríeis": "gastar",
    "gastas": "gasto",
    "gastasse": "gastar",
    "gastassem": "gastar",
    "gastasses": "gastar",
    "gastaste": "gastar",
    "gastastes": "gastar",
    "gastava": "gastar",
    "gastavam": "gastar",
    "gastavas": "gastar",
    "gaste": "gastar",
    "gastei": "gastar",
    "gasteis": "gastar",
    "gastem": "gastar",
    "gastemo": "gastar",
    "gastemos": "gastar",
    "gasteralgias": "gasteralgia",
    "gastes": "gastar",
    "gasto": "gastar",
    "gastona": "gastão",
    "gastonas": "gastão",
    "gastos": "gasto",
    "gastou": "gastar",
    "gastralgias": "gastralgia",
    "gastrectasias": "gastrectasia",
    "gastrectómica": "gastrectómico",
    "gastrectómicas": "gastrectómico",
    "gastrectómicos": "gastrectómico",
    "gastrenterites": "gastrenterite",
    "gastrenterocolites": "gastrenterocolite",
    "gastrenterocolítica": "gastrenterocolítico",
    "gastrenterocolíticas": "gastrenterocolítico",
    "gastrenterocolíticos": "gastrenterocolítico",
    "gastrenterologias": "gastrenterologia",
    "gastrenterologistas": "gastrenterologista",
    "gastrenterítica": "gastrenterítico",
    "gastrenteríticas": "gastrenterítico",
    "gastrenteríticos": "gastrenterítico",
    "gastrintestinais": "gastrintestinal",
    "gastrites": "gastrite",
    "gastroceles": "gastrocele",
    "gastrocnémica": "gastrocnémico",
    "gastrocnémicas": "gastrocnémico",
    "gastrocnémicos": "gastrocnémico",
    "gastrocnémios": "gastrocnémio",
    "gastrocolites": "gastrocolite",
    "gastrocolítica": "gastrocolítico",
    "gastrocolíticas": "gastrocolítico",
    "gastrocolíticos": "gastrocolítico",
    "gastrodiafanites": "gastrodiafanite",
    "gastrodiafanoscópica": "gastrodiafanoscópico",
    "gastrodiafanoscópicas": "gastrodiafanoscópico",
    "gastrodiafanoscópicos": "gastrodiafanoscópico",
    "gastrodiafanoscópios": "gastrodiafanoscópio",
    "gastrodiafanítica": "gastrodiafanítico",
    "gastrodiafaníticas": "gastrodiafanítico",
    "gastrodiafaníticos": "gastrodiafanítico",
    "gastroduodenais": "gastroduodenal",
    "gastroduodenites": "gastroduodenite",
    "gastroduodenítica": "gastroduodenítico",
    "gastroduodeníticas": "gastroduodenítico",
    "gastroduodeníticos": "gastroduodenítico",
    "gastrolatrias": "gastrolatria",
    "gastrologias": "gastrologia",
    "gastrológica": "gastrológico",
    "gastrológicas": "gastrológico",
    "gastrológicos": "gastrológico",
    "gastromanias": "gastromania",
    "gastromaníaca": "gastromaníaco",
    "gastromaníacas": "gastromaníaco",
    "gastromaníacos": "gastromaníaco",
    "gastronefrites": "gastronefrite",
    "gastronefrítica": "gastronefrítico",
    "gastronefríticas": "gastronefrítico",
    "gastronefríticos": "gastronefrítico",
    "gastronomias": "gastronomia",
    "gastronómica": "gastronómico",
    "gastronómicas": "gastronómico",
    "gastronómicos": "gastronómico",
    "gastropatas": "gastropata",
    "gastropatias": "gastropatia",
    "gastroplastias": "gastroplastia",
    "gastroplástica": "gastroplástico",
    "gastroplásticas": "gastroplástico",
    "gastroplásticos": "gastroplástico",
    "gastropática": "gastropático",
    "gastropáticas": "gastropático",
    "gastropáticos": "gastropático",
    "gastrorragias": "gastrorragia",
    "gastrorreias": "gastrorreia",
    "gastrorrágica": "gastrorrágico",
    "gastrorrágicas": "gastrorrágico",
    "gastrorrágicos": "gastrorrágico",
    "gastros": "gastro",
    "gastroscopias": "gastroscopia",
    "gastroscópica": "gastroscópico",
    "gastroscópicas": "gastroscópico",
    "gastroscópicos": "gastroscópico",
    "gastroscópios": "gastroscópio",
    "gastrostomias": "gastrostomia",
    "gastrostómica": "gastrostómico",
    "gastrostómicas": "gastrostómico",
    "gastrostómicos": "gastrostómico",
    "gastrovasculares": "gastrovascular",
    "gastrozoária": "gastrozoário",
    "gastrozoárias": "gastrozoário",
    "gastrozoários": "gastrozoário",
    "gastrulações": "gastrulação",
    "gastrálgica": "gastrálgico",
    "gastrálgicas": "gastrálgico",
    "gastrálgicos": "gastrálgico",
    "gastrícolas": "gastrícola",
    "gastríloqua": "gastríloquo",
    "gastríloquas": "gastríloquo",
    "gastríloquos": "gastríloquo",
    "gastrítica": "gastrítico",
    "gastríticas": "gastrítico",
    "gastríticos": "gastrítico",
    "gastrófila": "gastrófilo",
    "gastrófilas": "gastrófilo",
    "gastrófilos": "gastrófilo",
    "gastrófora": "gastróforo",
    "gastróforas": "gastróforo",
    "gastróforos": "gastróforo",
    "gastrólatras": "gastrólatra",
    "gastróloga": "gastrólogo",
    "gastrólogas": "gastrólogo",
    "gastrólogos": "gastrólogo",
    "gastrómana": "gastrómano",
    "gastrómanas": "gastrómano",
    "gastrómanos": "gastrómano",
    "gastrónoma": "gastrónomo",
    "gastrónomas": "gastrónomo",
    "gastrónomos": "gastrónomo",
    "gastrópodes": "gastrópode",
    "gastrósticos": "gastróstico",
    "gastrótica": "gastrótico",
    "gastróticas": "gastrótico",
    "gastróticos": "gastrótico",
    "gastá": "gastar",
    "gastámo": "gastar",
    "gastámos": "gastar",
    "gastáramo": "gastar",
    "gastáramos": "gastar",
    "gastárei": "gastar",
    "gastáreis": "gastar",
    "gastásseis": "gastar",
    "gastássemos": "gastar",
    "gastávamo": "gastar",
    "gastávamos": "gastar",
    "gastávei": "gastar",
    "gastáveis": "gastável",
    "gastões": "gastão",
    "gasógena": "gasógeno",
    "gasógenas": "gasógeno",
    "gasógenos": "gasógeno",
    "gasóleos": "gasóleo",
    "gasómetros": "gasómetro",
    "gata": "gato",
    "gatada": "gatar",
    "gatadas": "gatar",
    "gatado": "gatar",
    "gatados": "gatar",
    "gatafunhos": "gatafunho",
    "gatai": "gatar",
    "gatais": "gatar",
    "gatam": "gatar",
    "gatamo": "gatar",
    "gatamos": "gatar",
    "gatando": "gatar",
    "gatanha": "gatanhar",
    "gatanhada": "gatanhar",
    "gatanhadas": "gatanhar",
    "gatanhado": "gatanhar",
    "gatanhados": "gatanhar",
    "gatanhai": "gatanhar",
    "gatanhais": "gatanhar",
    "gatanham": "gatanhar",
    "gatanhamo": "gatanhar",
    "gatanhamos": "gatanhar",
    "gatanhando": "gatanhar",
    "gatanhara": "gatanhar",
    "gatanharam": "gatanhar",
    "gatanharas": "gatanhar",
    "gatanharde": "gatanhar",
    "gatanhardes": "gatanhar",
    "gatanhare": "gatanhar",
    "gatanharei": "gatanhar",
    "gatanhareis": "gatanhar",
    "gatanharem": "gatanhar",
    "gatanharemos": "gatanhar",
    "gatanhares": "gatanhar",
    "gatanharia": "gatanhar",
    "gatanhariam": "gatanhar",
    "gatanharias": "gatanhar",
    "gatanharmo": "gatanhar",
    "gatanharmos": "gatanhar",
    "gatanhará": "gatanhar",
    "gatanharás": "gatanhar",
    "gatanharão": "gatanhar",
    "gatanharíamos": "gatanhar",
    "gatanharíeis": "gatanhar",
    "gatanhas": "gatanhar",
    "gatanhasse": "gatanhar",
    "gatanhassem": "gatanhar",
    "gatanhasses": "gatanhar",
    "gatanhaste": "gatanhar",
    "gatanhastes": "gatanhar",
    "gatanhava": "gatanhar",
    "gatanhavam": "gatanhar",
    "gatanhavas": "gatanhar",
    "gatanhe": "gatanhar",
    "gatanhei": "gatanhar",
    "gatanheis": "gatanhar",
    "gatanhem": "gatanhar",
    "gatanhemo": "gatanhar",
    "gatanhemos": "gatanhar",
    "gatanhes": "gatanhar",
    "gatanho": "gatanhar",
    "gatanhos": "gatanho",
    "gatanhou": "gatanhar",
    "gatanhá": "gatanhar",
    "gatanhámo": "gatanhar",
    "gatanhámos": "gatanhar",
    "gatanháramo": "gatanhar",
    "gatanháramos": "gatanhar",
    "gatanhárei": "gatanhar",
    "gatanháreis": "gatanhar",
    "gatanhásseis": "gatanhar",
    "gatanhássemos": "gatanhar",
    "gatanhávamo": "gatanhar",
    "gatanhávamos": "gatanhar",
    "gatanhávei": "gatanhar",
    "gatanháveis": "gatanhar",
    "gatara": "gatar",
    "gataram": "gatar",
    "gataras": "gatar",
    "gatarde": "gatar",
    "gatardes": "gatar",
    "gatare": "gatar",
    "gatarei": "gatar",
    "gatareis": "gatar",
    "gatarem": "gatar",
    "gataremos": "gatar",
    "gatares": "gatar",
    "gataria": "gatar",
    "gatariam": "gatar",
    "gatarias": "gataria",
    "gatarmo": "gatar",
    "gatarmos": "gatar",
    "gatarradas": "gatarrada",
    "gatarrona": "gatarrão",
    "gatarronas": "gatarrão",
    "gatarrões": "gatarrão",
    "gatará": "gatar",
    "gatarás": "gatar",
    "gatarão": "gatar",
    "gataríamos": "gatar",
    "gataríeis": "gatar",
    "gatas": "gato",
    "gatasse": "gatar",
    "gatassem": "gatar",
    "gatasses": "gatar",
    "gataste": "gatar",
    "gatastes": "gatar",
    "gatava": "gatar",
    "gatavam": "gatar",
    "gatavas": "gatar",
    "gate": "gatar",
    "gateada": "gatear",
    "gateadas": "gatear",
    "gateado": "gatear",
    "gateados": "gatear",
    "gateai": "gatear",
    "gateais": "gatear",
    "gateamo": "gatear",
    "gateamos": "gatear",
    "gateando": "gatear",
    "gateara": "gatear",
    "gatearam": "gatear",
    "gatearas": "gatear",
    "gatearde": "gatear",
    "gateardes": "gatear",
    "gateare": "gatear",
    "gatearei": "gatear",
    "gateareis": "gatear",
    "gatearem": "gatear",
    "gatearemos": "gatear",
    "gateares": "gatear",
    "gatearia": "gatear",
    "gateariam": "gatear",
    "gatearias": "gatear",
    "gatearmo": "gatear",
    "gatearmos": "gatear",
    "gateará": "gatear",
    "gatearás": "gatear",
    "gatearão": "gatear",
    "gatearíamos": "gatear",
    "gatearíeis": "gatear",
    "gateasse": "gatear",
    "gateassem": "gatear",
    "gateasses": "gatear",
    "gateaste": "gatear",
    "gateastes": "gatear",
    "gateava": "gatear",
    "gateavam": "gatear",
    "gateavas": "gatear",
    "gateca": "gateco",
    "gatecas": "gateco",
    "gatecos": "gateco",
    "gateei": "gatear",
    "gateeis": "gatear",
    "gateemo": "gatear",
    "gateemos": "gatear",
    "gatei": "gatar",
    "gateia": "gatear",
    "gateiam": "gatear",
    "gateias": "gatear",
    "gateie": "gatear",
    "gateiem": "gatear",
    "gateies": "gatear",
    "gateio": "gatear",
    "gateira": "gateiro",
    "gateiras": "gateiro",
    "gateiros": "gateiro",
    "gateis": "gatar",
    "gatem": "gatar",
    "gatemo": "gatar",
    "gatemos": "gatar",
    "gateou": "gatear",
    "gates": "gatar",
    "gatesca": "gatesco",
    "gatescas": "gatesco",
    "gatescos": "gatesco",
    "gatesgas": "gatesga",
    "gateá": "gatear",
    "gateámo": "gatear",
    "gateámos": "gatear",
    "gateáramo": "gatear",
    "gateáramos": "gatear",
    "gateárei": "gatear",
    "gateáreis": "gatear",
    "gateásseis": "gatear",
    "gateássemos": "gatear",
    "gateávamo": "gatear",
    "gateávamos": "gatear",
    "gateávei": "gatear",
    "gateáveis": "gatear",
    "gatices": "gatice",
    "gaticidas": "gaticida",
    "gaticídios": "gaticídio",
    "gatilhos": "gatilho",
    "gatimonhas": "gatimonha",
    "gatinas": "gatina",
    "gatinha": "gato",
    "gatinhada": "gatinhar",
    "gatinhadas": "gatinhar",
    "gatinhado": "gatinhar",
    "gatinhados": "gatinhar",
    "gatinhai": "gatinhar",
    "gatinhais": "gatinhar",
    "gatinham": "gatinhar",
    "gatinhamo": "gatinhar",
    "gatinhamos": "gatinhar",
    "gatinhando": "gatinhar",
    "gatinhara": "gatinhar",
    "gatinharam": "gatinhar",
    "gatinharas": "gatinhar",
    "gatinhardes": "gatinhar",
    "gatinharei": "gatinhar",
    "gatinhareis": "gatinhar",
    "gatinharem": "gatinhar",
    "gatinharemos": "gatinhar",
    "gatinhares": "gatinhar",
    "gatinharia": "gatinhar",
    "gatinhariam": "gatinhar",
    "gatinharias": "gatinhar",
    "gatinharmo": "gatinhar",
    "gatinharmos": "gatinhar",
    "gatinhará": "gatinhar",
    "gatinharás": "gatinhar",
    "gatinharão": "gatinhar",
    "gatinharíamos": "gatinhar",
    "gatinharíeis": "gatinhar",
    "gatinhas": "gato",
    "gatinhasse": "gatinhar",
    "gatinhassem": "gatinhar",
    "gatinhasses": "gatinhar",
    "gatinhaste": "gatinhar",
    "gatinhastes": "gatinhar",
    "gatinhava": "gatinhar",
    "gatinhavam": "gatinhar",
    "gatinhavas": "gatinhar",
    "gatinhe": "gatinhar",
    "gatinhei": "gatinhar",
    "gatinheis": "gatinhar",
    "gatinhem": "gatinhar",
    "gatinhemo": "gatinhar",
    "gatinhemos": "gatinhar",
    "gatinhes": "gatinhar",
    "gatinho": "gato",
    "gatinhos": "gato",
    "gatinhou": "gatinhar",
    "gatinhámo": "gatinhar",
    "gatinhámos": "gatinhar",
    "gatinháramo": "gatinhar",
    "gatinháramos": "gatinhar",
    "gatinháreis": "gatinhar",
    "gatinhásseis": "gatinhar",
    "gatinhássemos": "gatinhar",
    "gatinhávamo": "gatinhar",
    "gatinhávamos": "gatinhar",
    "gatinháveis": "gatinhar",
    "gatis": "gatil",
    "gatismos": "gatismo",
    "gatita": "gato",
    "gatitas": "gato",
    "gatito": "gato",
    "gatitos": "gato",
    "gato": "gatar",
    "gatona": "gatão",
    "gatonas": "gatona",
    "gatorra": "gatorro",
    "gatorras": "gatorro",
    "gatorros": "gatorro",
    "gatos": "gato",
    "gatosa": "gatoso",
    "gatosas": "gatoso",
    "gatosos": "gatoso",
    "gatou": "gatar",
    "gatuna": "gatuno",
    "gatunada": "gatunar",
    "gatunadas": "gatunar",
    "gatunado": "gatunar",
    "gatunados": "gatunar",
    "gatunagens": "gatunagem",
    "gatunai": "gatunar",
    "gatunais": "gatunar",
    "gatunam": "gatunar",
    "gatunamo": "gatunar",
    "gatunamos": "gatunar",
    "gatunando": "gatunar",
    "gatunara": "gatunar",
    "gatunaram": "gatunar",
    "gatunaras": "gatunar",
    "gatunardes": "gatunar",
    "gatunarei": "gatunar",
    "gatunareis": "gatunar",
    "gatunarem": "gatunar",
    "gatunaremos": "gatunar",
    "gatunares": "gatunar",
    "gatunaria": "gatunar",
    "gatunariam": "gatunar",
    "gatunarias": "gatunar",
    "gatunarmo": "gatunar",
    "gatunarmos": "gatunar",
    "gatunará": "gatunar",
    "gatunarás": "gatunar",
    "gatunarão": "gatunar",
    "gatunaríamos": "gatunar",
    "gatunaríeis": "gatunar",
    "gatunas": "gatuno",
    "gatunasse": "gatunar",
    "gatunassem": "gatunar",
    "gatunasses": "gatunar",
    "gatunaste": "gatunar",
    "gatunastes": "gatunar",
    "gatunava": "gatunar",
    "gatunavam": "gatunar",
    "gatunavas": "gatunar",
    "gatune": "gatunar",
    "gatunei": "gatunar",
    "gatuneis": "gatunar",
    "gatunem": "gatunar",
    "gatunemo": "gatunar",
    "gatunemos": "gatunar",
    "gatunes": "gatunar",
    "gatunhas": "gatunha",
    "gatunices": "gatunice",
    "gatunismos": "gatunismo",
    "gatuno": "gatunar",
    "gatunos": "gatuno",
    "gatunou": "gatunar",
    "gatunámo": "gatunar",
    "gatunámos": "gatunar",
    "gatunáramo": "gatunar",
    "gatunáramos": "gatunar",
    "gatunáreis": "gatunar",
    "gatunásseis": "gatunar",
    "gatunássemos": "gatunar",
    "gatunávamo": "gatunar",
    "gatunávamos": "gatunar",
    "gatunáveis": "gatunar",
    "gaturamos": "gaturamo",
    "gatá": "gatar",
    "gatámo": "gatar",
    "gatámos": "gatar",
    "gatáramo": "gatar",
    "gatáramos": "gatar",
    "gatárei": "gatar",
    "gatáreis": "gatar",
    "gatárias": "gatária",
    "gatásseis": "gatar",
    "gatássemos": "gatar",
    "gatávamo": "gatar",
    "gatávamos": "gatar",
    "gatávei": "gatar",
    "gatáveis": "gatar",
    "gatázios": "gatázio",
    "gatões": "gatão",
    "gauchadas": "gauchada",
    "gauchismos": "gauchismo",
    "gaudas": "gauda",
    "gauderia": "gauderiar",
    "gauderiada": "gauderiar",
    "gauderiadas": "gauderiar",
    "gauderiado": "gauderiar",
    "gauderiados": "gauderiar",
    "gauderiai": "gauderiar",
    "gauderiais": "gauderiar",
    "gauderiam": "gauderiar",
    "gauderiamo": "gauderiar",
    "gauderiamos": "gauderiar",
    "gauderiando": "gauderiar",
    "gauderiara": "gauderiar",
    "gauderiaram": "gauderiar",
    "gauderiaras": "gauderiar",
    "gauderiardes": "gauderiar",
    "gauderiarei": "gauderiar",
    "gauderiareis": "gauderiar",
    "gauderiarem": "gauderiar",
    "gauderiaremos": "gauderiar",
    "gauderiares": "gauderiar",
    "gauderiaria": "gauderiar",
    "gauderiariam": "gauderiar",
    "gauderiarias": "gauderiar",
    "gauderiarmo": "gauderiar",
    "gauderiarmos": "gauderiar",
    "gauderiará": "gauderiar",
    "gauderiarás": "gauderiar",
    "gauderiarão": "gauderiar",
    "gauderiaríamos": "gauderiar",
    "gauderiaríeis": "gauderiar",
    "gauderias": "gauderiar",
    "gauderiasse": "gauderiar",
    "gauderiassem": "gauderiar",
    "gauderiasses": "gauderiar",
    "gauderiaste": "gauderiar",
    "gauderiastes": "gauderiar",
    "gauderiava": "gauderiar",
    "gauderiavam": "gauderiar",
    "gauderiavas": "gauderiar",
    "gauderie": "gauderiar",
    "gauderiei": "gauderiar",
    "gauderieis": "gauderiar",
    "gauderiem": "gauderiar",
    "gauderiemo": "gauderiar",
    "gauderiemos": "gauderiar",
    "gauderies": "gauderiar",
    "gauderio": "gauderiar",
    "gauderiou": "gauderiar",
    "gauderiámo": "gauderiar",
    "gauderiámos": "gauderiar",
    "gauderiáramo": "gauderiar",
    "gauderiáramos": "gauderiar",
    "gauderiáreis": "gauderiar",
    "gauderiásseis": "gauderiar",
    "gauderiássemos": "gauderiar",
    "gauderiávamo": "gauderiar",
    "gauderiávamos": "gauderiar",
    "gauderiáveis": "gauderiar",
    "gaudia": "gaudiar",
    "gaudiada": "gaudiar",
    "gaudiadas": "gaudiar",
    "gaudiado": "gaudiar",
    "gaudiados": "gaudiar",
    "gaudiai": "gaudiar",
    "gaudiais": "gaudiar",
    "gaudiam": "gaudiar",
    "gaudiamo": "gaudiar",
    "gaudiamos": "gaudiar",
    "gaudiando": "gaudiar",
    "gaudiara": "gaudiar",
    "gaudiaram": "gaudiar",
    "gaudiaras": "gaudiar",
    "gaudiardes": "gaudiar",
    "gaudiarei": "gaudiar",
    "gaudiareis": "gaudiar",
    "gaudiarem": "gaudiar",
    "gaudiaremos": "gaudiar",
    "gaudiares": "gaudiar",
    "gaudiaria": "gaudiar",
    "gaudiariam": "gaudiar",
    "gaudiarias": "gaudiar",
    "gaudiarmo": "gaudiar",
    "gaudiarmos": "gaudiar",
    "gaudiará": "gaudiar",
    "gaudiarás": "gaudiar",
    "gaudiarão": "gaudiar",
    "gaudiaríamos": "gaudiar",
    "gaudiaríeis": "gaudiar",
    "gaudias": "gaudiar",
    "gaudiasse": "gaudiar",
    "gaudiassem": "gaudiar",
    "gaudiasses": "gaudiar",
    "gaudiaste": "gaudiar",
    "gaudiastes": "gaudiar",
    "gaudiava": "gaudiar",
    "gaudiavam": "gaudiar",
    "gaudiavas": "gaudiar",
    "gaudie": "gaudiar",
    "gaudiei": "gaudiar",
    "gaudieis": "gaudiar",
    "gaudiem": "gaudiar",
    "gaudiemo": "gaudiar",
    "gaudiemos": "gaudiar",
    "gaudies": "gaudiar",
    "gaudina": "gaudinar",
    "gaudinada": "gaudinar",
    "gaudinadas": "gaudinar",
    "gaudinado": "gaudinar",
    "gaudinados": "gaudinar",
    "gaudinai": "gaudinar",
    "gaudinais": "gaudinar",
    "gaudinam": "gaudinar",
    "gaudinamo": "gaudinar",
    "gaudinamos": "gaudinar",
    "gaudinando": "gaudinar",
    "gaudinara": "gaudinar",
    "gaudinaram": "gaudinar",
    "gaudinaras": "gaudinar",
    "gaudinardes": "gaudinar",
    "gaudinarei": "gaudinar",
    "gaudinareis": "gaudinar",
    "gaudinarem": "gaudinar",
    "gaudinaremos": "gaudinar",
    "gaudinares": "gaudinar",
    "gaudinaria": "gaudinar",
    "gaudinariam": "gaudinar",
    "gaudinarias": "gaudinar",
    "gaudinarmo": "gaudinar",
    "gaudinarmos": "gaudinar",
    "gaudinará": "gaudinar",
    "gaudinarás": "gaudinar",
    "gaudinarão": "gaudinar",
    "gaudinaríamos": "gaudinar",
    "gaudinaríeis": "gaudinar",
    "gaudinas": "gaudinar",
    "gaudinasse": "gaudinar",
    "gaudinassem": "gaudinar",
    "gaudinasses": "gaudinar",
    "gaudinaste": "gaudinar",
    "gaudinastes": "gaudinar",
    "gaudinava": "gaudinar",
    "gaudinavam": "gaudinar",
    "gaudinavas": "gaudinar",
    "gaudine": "gaudinar",
    "gaudinei": "gaudinar",
    "gaudineis": "gaudinar",
    "gaudinem": "gaudinar",
    "gaudinemo": "gaudinar",
    "gaudinemos": "gaudinar",
    "gaudines": "gaudinar",
    "gaudino": "gaudinar",
    "gaudinou": "gaudinar",
    "gaudinámo": "gaudinar",
    "gaudinámos": "gaudinar",
    "gaudináramo": "gaudinar",
    "gaudináramos": "gaudinar",
    "gaudináreis": "gaudinar",
    "gaudinásseis": "gaudinar",
    "gaudinássemos": "gaudinar",
    "gaudinávamo": "gaudinar",
    "gaudinávamos": "gaudinar",
    "gaudináveis": "gaudinar",
    "gaudio": "gaudiar",
    "gaudiosa": "gaudioso",
    "gaudiosas": "gaudioso",
    "gaudiosos": "gaudioso",
    "gaudiou": "gaudiar",
    "gaudiámo": "gaudiar",
    "gaudiámos": "gaudiar",
    "gaudiáramo": "gaudiar",
    "gaudiáramos": "gaudiar",
    "gaudiáreis": "gaudiar",
    "gaudiásseis": "gaudiar",
    "gaudiássemos": "gaudiar",
    "gaudiávamo": "gaudiar",
    "gaudiávamos": "gaudiar",
    "gaudiáveis": "gaudiar",
    "gaudéria": "gaudério",
    "gaudérias": "gaudério",
    "gaudérios": "gaudério",
    "gaulesa": "gaulês",
    "gaulesas": "gaulês",
    "gauleses": "gaulês",
    "gaullistas": "gaullista",
    "gauros": "gauro",
    "gaus": "gau",
    "gausses": "gauss",
    "gaussianas": "gaussiana",
    "gaussianos": "gaussiano",
    "gaussímetros": "gaussímetro",
    "gavarros": "gavarro",
    "gaveada": "gavear",
    "gaveadas": "gavear",
    "gaveado": "gavear",
    "gaveadora": "gaveador",
    "gaveadoras": "gaveador",
    "gaveadores": "gaveador",
    "gaveados": "gavear",
    "gaveai": "gavear",
    "gaveais": "gavear",
    "gaveamo": "gavear",
    "gaveamos": "gavear",
    "gaveando": "gavear",
    "gaveara": "gavear",
    "gavearam": "gavear",
    "gavearas": "gavear",
    "gaveardes": "gavear",
    "gavearei": "gavear",
    "gaveareis": "gavear",
    "gavearem": "gavear",
    "gavearemos": "gavear",
    "gaveares": "gavear",
    "gavearia": "gavear",
    "gaveariam": "gavear",
    "gavearias": "gavear",
    "gavearmo": "gavear",
    "gavearmos": "gavear",
    "gaveará": "gavear",
    "gavearás": "gavear",
    "gavearão": "gavear",
    "gavearíamos": "gavear",
    "gavearíeis": "gavear",
    "gaveasse": "gavear",
    "gaveassem": "gavear",
    "gaveasses": "gavear",
    "gaveaste": "gavear",
    "gaveastes": "gavear",
    "gaveava": "gavear",
    "gaveavam": "gavear",
    "gaveavas": "gavear",
    "gaveei": "gavear",
    "gaveeis": "gavear",
    "gaveemo": "gavear",
    "gaveemos": "gavear",
    "gaveia": "gavear",
    "gaveiam": "gavear",
    "gaveias": "gavear",
    "gaveie": "gavear",
    "gaveiem": "gavear",
    "gaveies": "gavear",
    "gaveio": "gavear",
    "gavelas": "gavela",
    "gaveou": "gavear",
    "gavetas": "gaveta",
    "gaveteiros": "gaveteiro",
    "gavetopes": "gavetope",
    "gavetos": "gaveto",
    "gavetões": "gavetão",
    "gaveámo": "gavear",
    "gaveámos": "gavear",
    "gaveáramo": "gavear",
    "gaveáramos": "gavear",
    "gaveáreis": "gavear",
    "gaveásseis": "gavear",
    "gaveássemos": "gavear",
    "gaveávamo": "gavear",
    "gaveávamos": "gavear",
    "gaveáveis": "gavear",
    "gaviais": "gavial",
    "gavietes": "gaviete",
    "gaviformes": "gaviforme",
    "gavinas": "gavina",
    "gavinhas": "gavinha",
    "gavinhosa": "gavinhoso",
    "gavinhosas": "gavinhoso",
    "gavinhosos": "gavinhoso",
    "gavitas": "gavita",
    "gavitos": "gavito",
    "gaviões": "gavião",
    "gavotas": "gavota",
    "gavões": "gavão",
    "gaxetas": "gaxeta",
    "gays": "gay",
    "gazais": "gazal",
    "gazas": "gaza",
    "gazeada": "gazear",
    "gazeadas": "gazear",
    "gazeado": "gazear",
    "gazeadora": "gazeador",
    "gazeadoras": "gazeador",
    "gazeadores": "gazeador",
    "gazeados": "gazear",
    "gazeai": "gazear",
    "gazeais": "gazear",
    "gazeamo": "gazear",
    "gazeamos": "gazear",
    "gazeando": "gazear",
    "gazeantes": "gazeante",
    "gazeara": "gazear",
    "gazearam": "gazear",
    "gazearas": "gazear",
    "gazeardes": "gazear",
    "gazearei": "gazear",
    "gazeareis": "gazear",
    "gazearem": "gazear",
    "gazearemos": "gazear",
    "gazeares": "gazear",
    "gazearia": "gazear",
    "gazeariam": "gazear",
    "gazearias": "gazear",
    "gazearmo": "gazear",
    "gazearmos": "gazear",
    "gazeará": "gazear",
    "gazearás": "gazear",
    "gazearão": "gazear",
    "gazearíamos": "gazear",
    "gazearíeis": "gazear",
    "gazeasora": "gazeasor",
    "gazeasoras": "gazeasor",
    "gazeasores": "gazeasor",
    "gazeasse": "gazear",
    "gazeassem": "gazear",
    "gazeasses": "gazear",
    "gazeaste": "gazear",
    "gazeastes": "gazear",
    "gazeava": "gazear",
    "gazeavam": "gazear",
    "gazeavas": "gazear",
    "gazeei": "gazear",
    "gazeeis": "gazear",
    "gazeemo": "gazear",
    "gazeemos": "gazear",
    "gazeia": "gazear",
    "gazeiam": "gazear",
    "gazeias": "gazear",
    "gazeie": "gazear",
    "gazeiem": "gazear",
    "gazeies": "gazear",
    "gazeio": "gazear",
    "gazeios": "gazeio",
    "gazelas": "gazela",
    "gazeou": "gazear",
    "gazes": "gaze",
    "gazetais": "gazetal",
    "gazetas": "gazeta",
    "gazeteira": "gazeteiro",
    "gazeteiras": "gazeteiro",
    "gazeteiros": "gazeteiro",
    "gazetilhas": "gazetilha",
    "gazetilheira": "gazetilheiro",
    "gazetilheiras": "gazetilheiro",
    "gazetilheiros": "gazetilheiro",
    "gazetilhistas": "gazetilhista",
    "gazetismos": "gazetismo",
    "gazetistas": "gazetista",
    "gazetária": "gazetário",
    "gazetárias": "gazetário",
    "gazetários": "gazetário",
    "gazeámo": "gazear",
    "gazeámos": "gazear",
    "gazeáramo": "gazear",
    "gazeáramos": "gazear",
    "gazeáreis": "gazear",
    "gazeásseis": "gazear",
    "gazeássemos": "gazear",
    "gazeávamo": "gazear",
    "gazeávamos": "gazear",
    "gazeáveis": "gazear",
    "gazias": "gazia",
    "gazis": "gazil",
    "gazivas": "gaziva",
    "gazofiláceos": "gazofiláceo",
    "gazolas": "gazola",
    "gazuas": "gazua",
    "gazulares": "gazular",
    "gazéis": "gazel",
    "gazões": "gazão",
    "gaélica": "gaélico",
    "gaélicas": "gaélico",
    "gaélicos": "gaélico",
    "gaúcha": "gaúcho",
    "gaúchas": "gaúcho",
    "gaúchos": "gaúcho",
    "geada": "gear",
    "geadas": "gear",
    "geado": "gear",
    "geados": "gear",
    "geai": "gear",
    "geais": "gear",
    "geamo": "gear",
    "geamos": "gear",
    "geando": "gear",
    "geanticlinais": "geanticlinal",
    "geara": "gear",
    "gearam": "gear",
    "gearas": "gear",
    "geardes": "gear",
    "gearei": "gear",
    "geareis": "gear",
    "gearem": "gear",
    "gearemos": "gear",
    "geares": "gear",
    "gearia": "gear",
    "geariam": "gear",
    "gearias": "gear",
    "gearmo": "gear",
    "gearmos": "gear",
    "geará": "gear",
    "gearás": "gear",
    "gearão": "gear",
    "gearíamos": "gear",
    "gearíeis": "gear",
    "geasse": "gear",
    "geassem": "gear",
    "geasses": "gear",
    "geaste": "gear",
    "geastes": "gear",
    "geava": "gear",
    "geavam": "gear",
    "geavas": "gear",
    "geba": "gebo",
    "gebada": "gebar",
    "gebadas": "gebar",
    "gebado": "gebar",
    "gebados": "gebar",
    "gebai": "gebar",
    "gebais": "gebar",
    "gebam": "gebar",
    "gebamo": "gebar",
    "gebamos": "gebar",
    "gebando": "gebar",
    "gebara": "gebar",
    "gebaram": "gebar",
    "gebaras": "gebar",
    "gebarde": "gebar",
    "gebardes": "gebar",
    "gebare": "gebar",
    "gebarei": "gebar",
    "gebareis": "gebar",
    "gebarem": "gebar",
    "gebaremos": "gebar",
    "gebares": "gebar",
    "gebaria": "gebar",
    "gebariam": "gebar",
    "gebarias": "gebar",
    "gebarmo": "gebar",
    "gebarmos": "gebar",
    "gebará": "gebar",
    "gebarás": "gebar",
    "gebarão": "gebar",
    "gebaríamos": "gebar",
    "gebaríeis": "gebar",
    "gebas": "gebo",
    "gebasse": "gebar",
    "gebassem": "gebar",
    "gebasses": "gebar",
    "gebaste": "gebar",
    "gebastes": "gebar",
    "gebava": "gebar",
    "gebavam": "gebar",
    "gebavas": "gebar",
    "gebe": "gebar",
    "gebei": "gebar",
    "gebeis": "gebar",
    "gebem": "gebar",
    "gebemo": "gebar",
    "gebemos": "gebar",
    "gebes": "gebar",
    "gebices": "gebice",
    "gebo": "gebar",
    "gebos": "gebo",
    "gebosa": "geboso",
    "gebosas": "geboso",
    "gebosos": "geboso",
    "gebou": "gebar",
    "gebra": "gebrar",
    "gebrada": "gebrar",
    "gebradas": "gebrar",
    "gebrado": "gebrar",
    "gebrados": "gebrar",
    "gebrai": "gebrar",
    "gebrais": "gebrar",
    "gebram": "gebrar",
    "gebramo": "gebrar",
    "gebramos": "gebrar",
    "gebrando": "gebrar",
    "gebrara": "gebrar",
    "gebraram": "gebrar",
    "gebraras": "gebrar",
    "gebrardes": "gebrar",
    "gebrarei": "gebrar",
    "gebrareis": "gebrar",
    "gebrarem": "gebrar",
    "gebraremos": "gebrar",
    "gebrares": "gebrar",
    "gebraria": "gebrar",
    "gebrariam": "gebrar",
    "gebrarias": "gebrar",
    "gebrarmo": "gebrar",
    "gebrarmos": "gebrar",
    "gebrará": "gebrar",
    "gebrarás": "gebrar",
    "gebrarão": "gebrar",
    "gebraríamos": "gebrar",
    "gebraríeis": "gebrar",
    "gebras": "gebrar",
    "gebrasse": "gebrar",
    "gebrassem": "gebrar",
    "gebrasses": "gebrar",
    "gebraste": "gebrar",
    "gebrastes": "gebrar",
    "gebrava": "gebrar",
    "gebravam": "gebrar",
    "gebravas": "gebrar",
    "gebre": "gebrar",
    "gebrei": "gebrar",
    "gebreiras": "gebreira",
    "gebreis": "gebrar",
    "gebrem": "gebrar",
    "gebremo": "gebrar",
    "gebremos": "gebrar",
    "gebres": "gebre",
    "gebro": "gebrar",
    "gebrou": "gebrar",
    "gebrámo": "gebrar",
    "gebrámos": "gebrar",
    "gebráramo": "gebrar",
    "gebráramos": "gebrar",
    "gebráreis": "gebrar",
    "gebrásseis": "gebrar",
    "gebrássemos": "gebrar",
    "gebrávamo": "gebrar",
    "gebrávamos": "gebrar",
    "gebráveis": "gebrar",
    "gebá": "gebar",
    "gebámo": "gebar",
    "gebámos": "gebar",
    "gebáramo": "gebar",
    "gebáramos": "gebar",
    "gebárei": "gebar",
    "gebáreis": "gebar",
    "gebásseis": "gebar",
    "gebássemos": "gebar",
    "gebávamo": "gebar",
    "gebávamos": "gebar",
    "gebávei": "gebar",
    "gebáveis": "gebar",
    "gecos": "geco",
    "gediniana": "gediniano",
    "gedinianas": "gediniano",
    "gedinianos": "gediniano",
    "geei": "gear",
    "geeira": "geeiro",
    "geeiras": "geeiro",
    "geeiros": "geeiro",
    "geeis": "gear",
    "geemo": "gear",
    "geemos": "gear",
    "geenas": "geena",
    "geenta": "geento",
    "geentas": "geento",
    "geentos": "geento",
    "gefinianos": "gefiniano",
    "gefirina": "gefirino",
    "gefirinas": "gefirino",
    "gefirinos": "gefirino",
    "gefírea": "gefíreo",
    "gefíreas": "gefíreo",
    "gefíreos": "gefíreo",
    "geia": "gear",
    "geiam": "gear",
    "geias": "gear",
    "geidrografias": "geidrografia",
    "geie": "gear",
    "geiem": "gear",
    "geies": "gear",
    "geio": "gear",
    "geios": "geio",
    "geiseritos": "geiserito",
    "geistórias": "geistória",
    "geistórica": "geistórico",
    "geistóricas": "geistórico",
    "geistóricos": "geistórico",
    "geitosa": "geitoso",
    "geitosas": "geitoso",
    "geitosazinha": "geitoso",
    "geitosazinhas": "geitoso",
    "geitosazita": "geitoso",
    "geitosazitas": "geitoso",
    "geitosaça": "geitosaço",
    "geitosaças": "geitosaço",
    "geitosaços": "geitosaço",
    "geitoseca": "geitoseco",
    "geitosecas": "geitoseco",
    "geitosecos": "geitoseco",
    "geitosica": "geitosico",
    "geitosicas": "geitosico",
    "geitosicos": "geitosico",
    "geitosinha": "geitoso",
    "geitosinhas": "geitoso",
    "geitosinho": "geitoso",
    "geitosinhos": "geitoso",
    "geitosita": "geitoso",
    "geitositas": "geitoso",
    "geitosito": "geitoso",
    "geitositos": "geitoso",
    "geitosona": "geitosão",
    "geitosonas": "geitosão",
    "geitosos": "geitoso",
    "geitosota": "geitosote",
    "geitosotas": "geitosote",
    "geitosotes": "geitosote",
    "geitosozinho": "geitoso",
    "geitosozinhos": "geitoso",
    "geitosozito": "geitoso",
    "geitosozitos": "geitoso",
    "geitosíssima": "geitoso",
    "geitosíssimas": "geitoso",
    "geitosíssimo": "geitoso",
    "geitosíssimos": "geitoso",
    "geitosões": "geitosão",
    "geitrográfica": "geitrográfico",
    "geitrográficas": "geitrográfico",
    "geitrográficos": "geitrográfico",
    "gela": "gelar",
    "gelada": "gelar",
    "geladarias": "geladaria",
    "geladas": "gelar",
    "geladeiras": "geladeira",
    "geladinho": "gelado",
    "geladinhos": "gelado",
    "geladito": "gelado",
    "geladitos": "gelado",
    "geladiça": "geladiço",
    "geladiças": "geladiço",
    "geladiços": "geladiço",
    "gelado": "gelar",
    "geladora": "gelador",
    "geladoras": "gelador",
    "geladores": "gelador",
    "gelados": "gelar",
    "geladuras": "geladura",
    "gelai": "gelar",
    "gelais": "gelar",
    "gelam": "gelar",
    "gelamo": "gelar",
    "gelamos": "gelar",
    "gelando": "gelar",
    "gelantos": "gelanto",
    "gelara": "gelar",
    "gelaram": "gelar",
    "gelaras": "gelar",
    "gelarde": "gelar",
    "gelardes": "gelar",
    "gelare": "gelar",
    "gelarei": "gelar",
    "gelareis": "gelar",
    "gelarem": "gelar",
    "gelaremos": "gelar",
    "gelares": "gelar",
    "gelaria": "gelar",
    "gelariam": "gelar",
    "gelarias": "gelar",
    "gelarmo": "gelar",
    "gelarmos": "gelar",
    "gelará": "gelar",
    "gelarás": "gelar",
    "gelarão": "gelar",
    "gelaríamos": "gelar",
    "gelaríeis": "gelar",
    "gelas": "gelar",
    "gelasinas": "gelasina",
    "gelasse": "gelar",
    "gelassem": "gelar",
    "gelasses": "gelar",
    "gelaste": "gelar",
    "gelastes": "gelar",
    "gelatarias": "gelataria",
    "gelatinas": "gelatina",
    "gelatiniformes": "gelatiniforme",
    "gelatiniza": "gelatinizar",
    "gelatinizada": "gelatinizar",
    "gelatinizadas": "gelatinizar",
    "gelatinizado": "gelatinizar",
    "gelatinizados": "gelatinizar",
    "gelatinizai": "gelatinizar",
    "gelatinizais": "gelatinizar",
    "gelatinizam": "gelatinizar",
    "gelatinizamo": "gelatinizar",
    "gelatinizamos": "gelatinizar",
    "gelatinizando": "gelatinizar",
    "gelatinizara": "gelatinizar",
    "gelatinizaram": "gelatinizar",
    "gelatinizaras": "gelatinizar",
    "gelatinizarde": "gelatinizar",
    "gelatinizardes": "gelatinizar",
    "gelatinizare": "gelatinizar",
    "gelatinizarei": "gelatinizar",
    "gelatinizareis": "gelatinizar",
    "gelatinizarem": "gelatinizar",
    "gelatinizaremos": "gelatinizar",
    "gelatinizares": "gelatinizar",
    "gelatinizaria": "gelatinizar",
    "gelatinizariam": "gelatinizar",
    "gelatinizarias": "gelatinizar",
    "gelatinizarmo": "gelatinizar",
    "gelatinizarmos": "gelatinizar",
    "gelatinizará": "gelatinizar",
    "gelatinizarás": "gelatinizar",
    "gelatinizarão": "gelatinizar",
    "gelatinizaríamos": "gelatinizar",
    "gelatinizaríeis": "gelatinizar",
    "gelatinizas": "gelatinizar",
    "gelatinizasse": "gelatinizar",
    "gelatinizassem": "gelatinizar",
    "gelatinizasses": "gelatinizar",
    "gelatinizaste": "gelatinizar",
    "gelatinizastes": "gelatinizar",
    "gelatinizava": "gelatinizar",
    "gelatinizavam": "gelatinizar",
    "gelatinizavas": "gelatinizar",
    "gelatinizações": "gelatinização",
    "gelatinize": "gelatinizar",
    "gelatinizei": "gelatinizar",
    "gelatinizeis": "gelatinizar",
    "gelatinizem": "gelatinizar",
    "gelatinizemo": "gelatinizar",
    "gelatinizemos": "gelatinizar",
    "gelatinizes": "gelatinizar",
    "gelatinizo": "gelatinizar",
    "gelatinizou": "gelatinizar",
    "gelatinizá": "gelatinizar",
    "gelatinizámo": "gelatinizar",
    "gelatinizámos": "gelatinizar",
    "gelatinizáramo": "gelatinizar",
    "gelatinizáramos": "gelatinizar",
    "gelatinizárei": "gelatinizar",
    "gelatinizáreis": "gelatinizar",
    "gelatinizásseis": "gelatinizar",
    "gelatinizássemos": "gelatinizar",
    "gelatinizávamo": "gelatinizar",
    "gelatinizávamos": "gelatinizar",
    "gelatinizávei": "gelatinizar",
    "gelatinizáveis": "gelatinizar",
    "gelatinografias": "gelatinografia",
    "gelatinosa": "gelatinoso",
    "gelatinosas": "gelatinoso",
    "gelatinosos": "gelatinoso",
    "gelava": "gelar",
    "gelavam": "gelar",
    "gelavas": "gelar",
    "gele": "gelar",
    "gelei": "gelar",
    "geleias": "geleia",
    "geleificações": "geleificação",
    "geleiras": "geleira",
    "geleis": "gelar",
    "gelem": "gelar",
    "gelemo": "gelar",
    "gelemos": "gelar",
    "geles": "gelar",
    "gelhas": "gelha",
    "gelifarei": "gelifazer",
    "gelifareis": "gelifazer",
    "gelifaremos": "gelifazer",
    "gelifaria": "gelifazer",
    "gelifariam": "gelifazer",
    "gelifarias": "gelifazer",
    "gelifará": "gelifazer",
    "gelifarás": "gelifazer",
    "gelifarão": "gelifazer",
    "gelifaríamos": "gelifazer",
    "gelifaríeis": "gelifazer",
    "gelifaz": "gelifazer",
    "gelifaze": "gelifazer",
    "gelifazei": "gelifazer",
    "gelifazeis": "gelifazer",
    "gelifazem": "gelifazer",
    "gelifazemo": "gelifazer",
    "gelifazemos": "gelifazer",
    "gelifazendo": "gelifazer",
    "gelifazerde": "gelifazer",
    "gelifazerdes": "gelifazer",
    "gelifazere": "gelifazer",
    "gelifazerem": "gelifazer",
    "gelifazeres": "gelifazer",
    "gelifazermo": "gelifazer",
    "gelifazermos": "gelifazer",
    "gelifazes": "gelifazer",
    "gelifazia": "gelifazer",
    "gelifaziam": "gelifazer",
    "gelifazias": "gelifazer",
    "gelifazê": "gelifazer",
    "gelifazíamo": "gelifazer",
    "gelifazíamos": "gelifazer",
    "gelifazíei": "gelifazer",
    "gelifazíeis": "gelifazer",
    "gelifaça": "gelifazer",
    "gelifaçais": "gelifazer",
    "gelifaçam": "gelifazer",
    "gelifaçamo": "gelifazer",
    "gelifaçamos": "gelifazer",
    "gelifaças": "gelifazer",
    "gelifaço": "gelifazer",
    "gelifeita": "gelifazer",
    "gelifeitas": "gelifazer",
    "gelifeito": "gelifazer",
    "gelifeitos": "gelifazer",
    "gelifez": "gelifazer",
    "gelifi": "gelifazer",
    "gelifica": "gelificar",
    "gelificada": "gelificar",
    "gelificadas": "gelificar",
    "gelificado": "gelificar",
    "gelificados": "gelificar",
    "gelificai": "gelificar",
    "gelificais": "gelificar",
    "gelificam": "gelificar",
    "gelificamo": "gelificar",
    "gelificamos": "gelificar",
    "gelificando": "gelificar",
    "gelificara": "gelificar",
    "gelificaram": "gelificar",
    "gelificaras": "gelificar",
    "gelificarde": "gelificar",
    "gelificardes": "gelificar",
    "gelificare": "gelificar",
    "gelificarei": "gelificar",
    "gelificareis": "gelificar",
    "gelificarem": "gelificar",
    "gelificaremos": "gelificar",
    "gelificares": "gelificar",
    "gelificaria": "gelificar",
    "gelificariam": "gelificar",
    "gelificarias": "gelificar",
    "gelificarmo": "gelificar",
    "gelificarmos": "gelificar",
    "gelificará": "gelificar",
    "gelificarás": "gelificar",
    "gelificarão": "gelificar",
    "gelificaríamos": "gelificar",
    "gelificaríeis": "gelificar",
    "gelificas": "gelificar",
    "gelificasse": "gelificar",
    "gelificassem": "gelificar",
    "gelificasses": "gelificar",
    "gelificaste": "gelificar",
    "gelificastes": "gelificar",
    "gelificava": "gelificar",
    "gelificavam": "gelificar",
    "gelificavas": "gelificar",
    "gelifico": "gelificar",
    "gelificou": "gelificar",
    "gelificá": "gelificar",
    "gelificámo": "gelificar",
    "gelificámos": "gelificar",
    "gelificáramo": "gelificar",
    "gelificáramos": "gelificar",
    "gelificárei": "gelificar",
    "gelificáreis": "gelificar",
    "gelificásseis": "gelificar",
    "gelificássemos": "gelificar",
    "gelificávamo": "gelificar",
    "gelificávamos": "gelificar",
    "gelificávei": "gelificar",
    "gelificáveis": "gelificável",
    "gelifique": "gelificar",
    "gelifiquei": "gelificar",
    "gelifiqueis": "gelificar",
    "gelifiquem": "gelificar",
    "gelifiquemo": "gelificar",
    "gelifiquemos": "gelificar",
    "gelifiques": "gelificar",
    "gelifiz": "gelifazer",
    "gelifizemo": "gelifazer",
    "gelifizemos": "gelifazer",
    "gelifizer": "gelifazer",
    "gelifizera": "gelifazer",
    "gelifizeram": "gelifazer",
    "gelifizeras": "gelifazer",
    "gelifizerdes": "gelifazer",
    "gelifizerem": "gelifazer",
    "gelifizeres": "gelifazer",
    "gelifizermos": "gelifazer",
    "gelifizesse": "gelifazer",
    "gelifizessem": "gelifazer",
    "gelifizesses": "gelifazer",
    "gelifizeste": "gelifazer",
    "gelifizestes": "gelifazer",
    "gelifizéramo": "gelifazer",
    "gelifizéramos": "gelifazer",
    "gelifizérei": "gelifazer",
    "gelifizéreis": "gelifazer",
    "gelifizésseis": "gelifazer",
    "gelifizéssemos": "gelifazer",
    "gelifá": "gelifazer",
    "gelifê": "gelifazer",
    "gelinho": "gelo",
    "gelinhos": "gelo",
    "gelito": "gelo",
    "gelitos": "gelo",
    "gelividades": "gelividade",
    "gelo": "gelar",
    "gelos": "gelo",
    "geloses": "gelose",
    "gelosias": "gelosia",
    "gelou": "gelar",
    "gelá": "gelar",
    "gelámo": "gelar",
    "gelámos": "gelar",
    "geláramo": "gelar",
    "geláramos": "gelar",
    "gelárei": "gelar",
    "geláreis": "gelar",
    "gelásseis": "gelar",
    "gelássemos": "gelar",
    "gelávamo": "gelar",
    "gelávamos": "gelar",
    "gelávei": "gelar",
    "geláveis": "gelar",
    "gelícolas": "gelícola",
    "gelósica": "gelósico",
    "gelósicas": "gelósico",
    "gelósicos": "gelósico",
    "gema": "gemer",
    "gemada": "gemar",
    "gemadas": "gemar",
    "gemado": "gemar",
    "gemados": "gemar",
    "gemagens": "gemagem",
    "gemai": "gemar",
    "gemais": "gemer",
    "gemam": "gemer",
    "gemamo": "gemer",
    "gemamos": "gemer",
    "gemando": "gemar",
    "gemantes": "gemante",
    "gemara": "gemar",
    "gemaram": "gemar",
    "gemaras": "gemar",
    "gemarde": "gemar",
    "gemardes": "gemar",
    "gemare": "gemar",
    "gemarei": "gemar",
    "gemareis": "gemar",
    "gemarem": "gemar",
    "gemaremos": "gemar",
    "gemares": "gemar",
    "gemaria": "gemar",
    "gemariam": "gemar",
    "gemarias": "gemar",
    "gemarmo": "gemar",
    "gemarmos": "gemar",
    "gemará": "gemar",
    "gemarás": "gemar",
    "gemarão": "gemar",
    "gemaríamos": "gemar",
    "gemaríeis": "gemar",
    "gemas": "gemer",
    "gemasse": "gemar",
    "gemassem": "gemar",
    "gemasses": "gemar",
    "gemaste": "gemar",
    "gemastes": "gemar",
    "gematrias": "gematria",
    "gemava": "gemar",
    "gemavam": "gemar",
    "gemavas": "gemar",
    "gemações": "gemação",
    "geme": "gemer",
    "gemebunda": "gemebundo",
    "gemebundas": "gemebundo",
    "gemebundos": "gemebundo",
    "gemedeiras": "gemedeira",
    "gemedoiros": "gemedoiro",
    "gemedora": "gemedor",
    "gemedoras": "gemedor",
    "gemedores": "gemedor",
    "gemedouros": "gemedouro",
    "gemei": "gemer",
    "gemeidades": "gemeidade",
    "gemeis": "gemer",
    "gemelares": "gemelar",
    "gemelga": "gemelgo",
    "gemelgas": "gemelgo",
    "gemelgos": "gemelgo",
    "gemelos": "gemelo",
    "gemelíparas": "gemelípara",
    "gemem": "gemer",
    "gememo": "gemer",
    "gememos": "gemer",
    "gemendo": "gemer",
    "gementes": "gemente",
    "gemeologias": "gemeologia",
    "gemeológica": "gemeológico",
    "gemeológicas": "gemeológico",
    "gemeológicos": "gemeológico",
    "gemera": "gemer",
    "gemeram": "gemer",
    "gemeras": "gemer",
    "gemerdes": "gemer",
    "gemerei": "gemer",
    "gemereis": "gemer",
    "gemerem": "gemer",
    "gemeremos": "gemer",
    "gemeres": "gemer",
    "gemeria": "gemer",
    "gemeriam": "gemer",
    "gemerias": "gemer",
    "gemermo": "gemer",
    "gemermos": "gemer",
    "gemerá": "gemer",
    "gemerás": "gemer",
    "gemerão": "gemer",
    "gemeríamos": "gemer",
    "gemeríeis": "gemer",
    "gemes": "gemer",
    "gemesse": "gemer",
    "gemessem": "gemer",
    "gemesses": "gemer",
    "gemeste": "gemer",
    "gemestes": "gemer",
    "gemeu": "gemer",
    "gemi": "gemer",
    "gemia": "gemer",
    "gemiam": "gemer",
    "gemias": "gemer",
    "gemica": "gemicar",
    "gemicada": "gemicar",
    "gemicadas": "gemicar",
    "gemicado": "gemicar",
    "gemicados": "gemicar",
    "gemicais": "gemicar",
    "gemicam": "gemicar",
    "gemicamo": "gemicar",
    "gemicamos": "gemicar",
    "gemicando": "gemicar",
    "gemicara": "gemicar",
    "gemicaram": "gemicar",
    "gemicaras": "gemicar",
    "gemicardes": "gemicar",
    "gemicarei": "gemicar",
    "gemicareis": "gemicar",
    "gemicarem": "gemicar",
    "gemicaremos": "gemicar",
    "gemicares": "gemicar",
    "gemicaria": "gemicar",
    "gemicariam": "gemicar",
    "gemicarias": "gemicar",
    "gemicarmo": "gemicar",
    "gemicarmos": "gemicar",
    "gemicará": "gemicar",
    "gemicarás": "gemicar",
    "gemicarão": "gemicar",
    "gemicaríamos": "gemicar",
    "gemicaríeis": "gemicar",
    "gemicas": "gemicar",
    "gemicasse": "gemicar",
    "gemicassem": "gemicar",
    "gemicasses": "gemicar",
    "gemicaste": "gemicar",
    "gemicastes": "gemicar",
    "gemicava": "gemicar",
    "gemicavam": "gemicar",
    "gemicavas": "gemicar",
    "gemico": "gemicar",
    "gemicou": "gemicar",
    "gemicámo": "gemicar",
    "gemicámos": "gemicar",
    "gemicáramo": "gemicar",
    "gemicáramos": "gemicar",
    "gemicáreis": "gemicar",
    "gemicásseis": "gemicar",
    "gemicássemos": "gemicar",
    "gemicávamo": "gemicar",
    "gemicávamos": "gemicar",
    "gemicáveis": "gemicar",
    "gemida": "gemido",
    "gemidas": "gemido",
    "gemideiras": "gemideira",
    "gemido": "gemer",
    "gemidos": "gemido",
    "gemina": "geminar",
    "geminada": "geminar",
    "geminadas": "geminar",
    "geminado": "geminar",
    "geminados": "geminar",
    "geminai": "geminar",
    "geminais": "geminar",
    "geminam": "geminar",
    "geminamo": "geminar",
    "geminamos": "geminar",
    "geminando": "geminar",
    "geminara": "geminar",
    "geminaram": "geminar",
    "geminaras": "geminar",
    "geminarde": "geminar",
    "geminardes": "geminar",
    "geminare": "geminar",
    "geminarei": "geminar",
    "geminareis": "geminar",
    "geminarem": "geminar",
    "geminaremos": "geminar",
    "geminares": "geminar",
    "geminaria": "geminar",
    "geminariam": "geminar",
    "geminarias": "geminar",
    "geminarmo": "geminar",
    "geminarmos": "geminar",
    "geminará": "geminar",
    "geminarás": "geminar",
    "geminarão": "geminar",
    "geminaríamos": "geminar",
    "geminaríeis": "geminar",
    "geminas": "geminar",
    "geminasse": "geminar",
    "geminassem": "geminar",
    "geminasses": "geminar",
    "geminaste": "geminar",
    "geminastes": "geminar",
    "geminava": "geminar",
    "geminavam": "geminar",
    "geminavas": "geminar",
    "geminações": "geminação",
    "gemine": "geminar",
    "geminei": "geminar",
    "gemineis": "geminar",
    "geminem": "geminar",
    "geminemo": "geminar",
    "geminemos": "geminar",
    "gemines": "geminar",
    "geminiana": "geminiano",
    "geminianas": "geminiano",
    "geminianos": "geminiano",
    "geminiflora": "geminifloro",
    "geminifloras": "geminifloro",
    "geminifloros": "geminifloro",
    "gemino": "geminar",
    "geminou": "geminar",
    "geminá": "geminar",
    "geminámo": "geminar",
    "geminámos": "geminar",
    "gemináramo": "geminar",
    "gemináramos": "geminar",
    "geminárei": "geminar",
    "gemináreis": "geminar",
    "geminásseis": "geminar",
    "geminássemos": "geminar",
    "geminávamo": "geminar",
    "geminávamos": "geminar",
    "geminávei": "geminar",
    "gemináveis": "geminável",
    "gemiparidades": "gemiparidade",
    "gemique": "gemicar",
    "gemiquei": "gemicar",
    "gemiqueis": "gemicar",
    "gemiquem": "gemicar",
    "gemiquemos": "gemicar",
    "gemiques": "gemicar",
    "gemo": "gemer",
    "gemologias": "gemologia",
    "gemologistas": "gemologista",
    "gemou": "gemar",
    "gempilídeos": "gempilídeo",
    "gempílidas": "gempílida",
    "gemulações": "gemulação",
    "gemá": "gemar",
    "gemámo": "gemar",
    "gemámos": "gemar",
    "gemáramo": "gemar",
    "gemáramos": "gemar",
    "gemárei": "gemar",
    "gemáreis": "gemar",
    "gemásseis": "gemar",
    "gemássemos": "gemar",
    "gemávamo": "gemar",
    "gemávamos": "gemar",
    "gemávei": "gemar",
    "gemáveis": "gemar",
    "gemêramo": "gemer",
    "gemêramos": "gemer",
    "gemêreis": "gemer",
    "gemêsseis": "gemer",
    "gemêssemos": "gemer",
    "gemíamo": "gemer",
    "gemíamos": "gemer",
    "gemíeis": "gemer",
    "gemífera": "gemífero",
    "gemíferas": "gemífero",
    "gemíferos": "gemífero",
    "gemípara": "gemíparo",
    "gemíparas": "gemíparo",
    "gemíparos": "gemíparo",
    "gemóloga": "gemólogo",
    "gemólogas": "gemólogo",
    "gemólogos": "gemólogo",
    "genais": "genal",
    "gencianas": "genciana",
    "gencianácea": "gencianáceo",
    "gencianáceas": "gencianáceo",
    "gencianáceos": "gencianáceo",
    "gendarmarias": "gendarmaria",
    "gendarmes": "gendarme",
    "genealogias": "genealogia",
    "genealogistas": "genealogista",
    "genealógica": "genealógico",
    "genealógicas": "genealógico",
    "genealógicos": "genealógico",
    "genealóloga": "genealólogo",
    "genealólogas": "genealólogo",
    "genealólogos": "genealólogo",
    "genearcas": "genearca",
    "genebradas": "genebrada",
    "genebras": "genebra",
    "genebreiros": "genebreiro",
    "genebrenses": "genebrense",
    "genebresa": "genebrês",
    "genebresas": "genebrês",
    "genebreses": "genebrês",
    "genebrina": "genebrino",
    "genebrinas": "genebrino",
    "genebrinos": "genebrino",
    "generacionismos": "generacionismo",
    "generais": "general",
    "generalados": "generalado",
    "generalas": "generala",
    "generalatos": "generalato",
    "generalidades": "generalidade",
    "generalistas": "generalista",
    "generaliza": "generalizar",
    "generalizada": "generalizar",
    "generalizadas": "generalizar",
    "generalizado": "generalizar",
    "generalizadora": "generalizador",
    "generalizadoras": "generalizador",
    "generalizadores": "generalizador",
    "generalizados": "generalizar",
    "generalizai": "generalizar",
    "generalizais": "generalizar",
    "generalizam": "generalizar",
    "generalizamo": "generalizar",
    "generalizamos": "generalizar",
    "generalizando": "generalizar",
    "generalizantes": "generalizante",
    "generalizara": "generalizar",
    "generalizaram": "generalizar",
    "generalizaras": "generalizar",
    "generalizarde": "generalizar",
    "generalizardes": "generalizar",
    "generalizare": "generalizar",
    "generalizarei": "generalizar",
    "generalizareis": "generalizar",
    "generalizarem": "generalizar",
    "generalizaremos": "generalizar",
    "generalizares": "generalizar",
    "generalizaria": "generalizar",
    "generalizariam": "generalizar",
    "generalizarias": "generalizar",
    "generalizarmo": "generalizar",
    "generalizarmos": "generalizar",
    "generalizará": "generalizar",
    "generalizarás": "generalizar",
    "generalizarão": "generalizar",
    "generalizaríamos": "generalizar",
    "generalizaríeis": "generalizar",
    "generalizas": "generalizar",
    "generalizasse": "generalizar",
    "generalizassem": "generalizar",
    "generalizasses": "generalizar",
    "generalizaste": "generalizar",
    "generalizastes": "generalizar",
    "generalizava": "generalizar",
    "generalizavam": "generalizar",
    "generalizavas": "generalizar",
    "generalizações": "generalização",
    "generalize": "generalizar",
    "generalizei": "generalizar",
    "generalizeis": "generalizar",
    "generalizem": "generalizar",
    "generalizemo": "generalizar",
    "generalizemos": "generalizar",
    "generalizes": "generalizar",
    "generalizo": "generalizar",
    "generalizou": "generalizar",
    "generalizá": "generalizar",
    "generalizámo": "generalizar",
    "generalizámos": "generalizar",
    "generalizáramo": "generalizar",
    "generalizáramos": "generalizar",
    "generalizárei": "generalizar",
    "generalizáreis": "generalizar",
    "generalizásseis": "generalizar",
    "generalizássemos": "generalizar",
    "generalizávamo": "generalizar",
    "generalizávamos": "generalizar",
    "generalizávei": "generalizar",
    "generalizáveis": "generalizável",
    "generalíssimos": "generalíssimo",
    "generativa": "generativo",
    "generativas": "generativo",
    "generativos": "generativo",
    "generatrizes": "generatriz",
    "generosa": "generoso",
    "generosas": "generoso",
    "generosidades": "generosidade",
    "generosos": "generoso",
    "genes": "gene",
    "genesíaca": "genesíaco",
    "genesíacas": "genesíaco",
    "genesíacos": "genesíaco",
    "genetias": "genetia",
    "geneticistas": "geneticista",
    "genetliologias": "genetliologia",
    "genetliologistas": "genetliologista",
    "genetliológica": "genetliológico",
    "genetliológicas": "genetliológico",
    "genetliológicos": "genetliológico",
    "genetlióloga": "genetliólogo",
    "genetliólogas": "genetliólogo",
    "genetliólogos": "genetliólogo",
    "genetlíaca": "genetlíaco",
    "genetlíacas": "genetlíaco",
    "genetlíacos": "genetlíaco",
    "genetrizes": "genetriz",
    "gengibirras": "gengibirra",
    "gengibres": "gengibre",
    "gengivais": "gengival",
    "gengivas": "gengiva",
    "gengivites": "gengivite",
    "gengivítica": "gengivítico",
    "gengivíticas": "gengivítico",
    "gengivíticos": "gengivítico",
    "gengíbrica": "gengíbrico",
    "gengíbricas": "gengíbrico",
    "gengíbricos": "gengíbrico",
    "geniais": "genial",
    "genialidades": "genialidade",
    "genicas": "genica",
    "geniculada": "geniculado",
    "geniculadas": "geniculado",
    "geniculados": "geniculado",
    "geniculares": "genicular",
    "geniculações": "geniculação",
    "genioplastias": "genioplastia",
    "genioplástica": "genioplástico",
    "genioplásticas": "genioplástico",
    "genioplásticos": "genioplástico",
    "geniosa": "genioso",
    "geniosas": "genioso",
    "geniosos": "genioso",
    "genitais": "genital",
    "genitiva": "genitivo",
    "genitivas": "genitivo",
    "genitivos": "genitivo",
    "genitora": "genitor",
    "genitoras": "genitor",
    "genitores": "genitor",
    "genitriz": "genitor",
    "genitrizes": "genitor",
    "genituras": "genitura",
    "geniturinária": "geniturinário",
    "geniturinárias": "geniturinário",
    "geniturinários": "geniturinário",
    "genitálias": "genitália",
    "genoblastos": "genoblasto",
    "genocidas": "genocida",
    "genocídios": "genocídio",
    "genológica": "genológico",
    "genológicas": "genológico",
    "genológicos": "genológico",
    "genomas": "genoma",
    "genonomias": "genonomia",
    "genopatias": "genopatia",
    "genoplastias": "genoplastia",
    "genoplástica": "genoplástico",
    "genoplásticas": "genoplástico",
    "genoplásticos": "genoplástico",
    "genopática": "genopático",
    "genopáticas": "genopático",
    "genopáticos": "genopático",
    "genotípica": "genotípico",
    "genotípicas": "genotípico",
    "genotípicos": "genotípico",
    "genovenses": "genovense",
    "genovesa": "genovês",
    "genovesas": "genovês",
    "genoveses": "genovês",
    "genreada": "genrear",
    "genreadas": "genrear",
    "genreado": "genrear",
    "genreados": "genrear",
    "genreai": "genrear",
    "genreais": "genrear",
    "genreamo": "genrear",
    "genreamos": "genrear",
    "genreando": "genrear",
    "genreara": "genrear",
    "genrearam": "genrear",
    "genrearas": "genrear",
    "genreardes": "genrear",
    "genrearei": "genrear",
    "genreareis": "genrear",
    "genrearem": "genrear",
    "genrearemos": "genrear",
    "genreares": "genrear",
    "genrearia": "genrear",
    "genreariam": "genrear",
    "genrearias": "genrear",
    "genrearmo": "genrear",
    "genrearmos": "genrear",
    "genreará": "genrear",
    "genrearás": "genrear",
    "genrearão": "genrear",
    "genrearíamos": "genrear",
    "genrearíeis": "genrear",
    "genreasse": "genrear",
    "genreassem": "genrear",
    "genreasses": "genrear",
    "genreaste": "genrear",
    "genreastes": "genrear",
    "genreava": "genrear",
    "genreavam": "genrear",
    "genreavas": "genrear",
    "genreei": "genrear",
    "genreeis": "genrear",
    "genreemo": "genrear",
    "genreemos": "genrear",
    "genreia": "genrear",
    "genreiam": "genrear",
    "genreias": "genrear",
    "genreie": "genrear",
    "genreiem": "genrear",
    "genreies": "genrear",
    "genreio": "genrear",
    "genreou": "genrear",
    "genreámo": "genrear",
    "genreámos": "genrear",
    "genreáramo": "genrear",
    "genreáramos": "genrear",
    "genreáreis": "genrear",
    "genreásseis": "genrear",
    "genreássemos": "genrear",
    "genreávamo": "genrear",
    "genreávamos": "genrear",
    "genreáveis": "genrear",
    "genros": "genro",
    "gentalhas": "gentalha",
    "gentaças": "gentaça",
    "gentecas": "genteca",
    "gentes": "gente",
    "gentia": "gentio",
    "gentiagas": "gentiaga",
    "gentias": "gentio",
    "gentilezas": "gentileza",
    "gentilidades": "gentilidade",
    "gentilismos": "gentilismo",
    "gentiliza": "gentilizar",
    "gentilizada": "gentilizar",
    "gentilizadas": "gentilizar",
    "gentilizado": "gentilizar",
    "gentilizados": "gentilizar",
    "gentilizai": "gentilizar",
    "gentilizais": "gentilizar",
    "gentilizam": "gentilizar",
    "gentilizamo": "gentilizar",
    "gentilizamos": "gentilizar",
    "gentilizando": "gentilizar",
    "gentilizara": "gentilizar",
    "gentilizaram": "gentilizar",
    "gentilizaras": "gentilizar",
    "gentilizarde": "gentilizar",
    "gentilizardes": "gentilizar",
    "gentilizare": "gentilizar",
    "gentilizarei": "gentilizar",
    "gentilizareis": "gentilizar",
    "gentilizarem": "gentilizar",
    "gentilizaremos": "gentilizar",
    "gentilizares": "gentilizar",
    "gentilizaria": "gentilizar",
    "gentilizariam": "gentilizar",
    "gentilizarias": "gentilizar",
    "gentilizarmo": "gentilizar",
    "gentilizarmos": "gentilizar",
    "gentilizará": "gentilizar",
    "gentilizarás": "gentilizar",
    "gentilizarão": "gentilizar",
    "gentilizaríamos": "gentilizar",
    "gentilizaríeis": "gentilizar",
    "gentilizas": "gentilizar",
    "gentilizasse": "gentilizar",
    "gentilizassem": "gentilizar",
    "gentilizasses": "gentilizar",
    "gentilizaste": "gentilizar",
    "gentilizastes": "gentilizar",
    "gentilizava": "gentilizar",
    "gentilizavam": "gentilizar",
    "gentilizavas": "gentilizar",
    "gentilize": "gentilizar",
    "gentilizei": "gentilizar",
    "gentilizeis": "gentilizar",
    "gentilizem": "gentilizar",
    "gentilizemo": "gentilizar",
    "gentilizemos": "gentilizar",
    "gentilizes": "gentilizar",
    "gentilizo": "gentilizar",
    "gentilizou": "gentilizar",
    "gentilizá": "gentilizar",
    "gentilizámo": "gentilizar",
    "gentilizámos": "gentilizar",
    "gentilizáramo": "gentilizar",
    "gentilizáramos": "gentilizar",
    "gentilizárei": "gentilizar",
    "gentilizáreis": "gentilizar",
    "gentilizásseis": "gentilizar",
    "gentilizássemos": "gentilizar",
    "gentilizávamo": "gentilizar",
    "gentilizávamos": "gentilizar",
    "gentilizávei": "gentilizar",
    "gentilizáveis": "gentilizar",
    "gentilícia": "gentilício",
    "gentilícias": "gentilício",
    "gentilícios": "gentilício",
    "gentilídea": "gentilídeo",
    "gentilídeas": "gentilídeo",
    "gentilídeos": "gentilídeo",
    "gentios": "gentio",
    "gentis": "gentil",
    "gentlemen": "gentleman",
    "gentuças": "gentuça",
    "gentílica": "gentílico",
    "gentílicas": "gentílico",
    "gentílicos": "gentílico",
    "gentílidas": "gentílida",
    "genuenses": "genuense",
    "genuflecte": "genuflectir",
    "genuflectem": "genuflectir",
    "genuflectes": "genuflectir",
    "genuflecti": "genuflectir",
    "genuflectia": "genuflectir",
    "genuflectiam": "genuflectir",
    "genuflectias": "genuflectir",
    "genuflectida": "genuflectir",
    "genuflectidas": "genuflectir",
    "genuflectido": "genuflectir",
    "genuflectidos": "genuflectir",
    "genuflectimo": "genuflectir",
    "genuflectimos": "genuflectir",
    "genuflectindo": "genuflectir",
    "genuflectira": "genuflectir",
    "genuflectiram": "genuflectir",
    "genuflectiras": "genuflectir",
    "genuflectirde": "genuflectir",
    "genuflectirdes": "genuflectir",
    "genuflectire": "genuflectir",
    "genuflectirei": "genuflectir",
    "genuflectireis": "genuflectir",
    "genuflectirem": "genuflectir",
    "genuflectiremos": "genuflectir",
    "genuflectires": "genuflectir",
    "genuflectiria": "genuflectir",
    "genuflectiriam": "genuflectir",
    "genuflectirias": "genuflectir",
    "genuflectirmo": "genuflectir",
    "genuflectirmos": "genuflectir",
    "genuflectirá": "genuflectir",
    "genuflectirás": "genuflectir",
    "genuflectirão": "genuflectir",
    "genuflectiríamos": "genuflectir",
    "genuflectiríeis": "genuflectir",
    "genuflectis": "genuflectir",
    "genuflectisse": "genuflectir",
    "genuflectissem": "genuflectir",
    "genuflectisses": "genuflectir",
    "genuflectiste": "genuflectir",
    "genuflectistes": "genuflectir",
    "genuflectiu": "genuflectir",
    "genuflectora": "genuflector",
    "genuflectoras": "genuflector",
    "genuflectores": "genuflector",
    "genuflectíamo": "genuflectir",
    "genuflectíamos": "genuflectir",
    "genuflectíei": "genuflectir",
    "genuflectíeis": "genuflectir",
    "genuflectíramo": "genuflectir",
    "genuflectíramos": "genuflectir",
    "genuflectírei": "genuflectir",
    "genuflectíreis": "genuflectir",
    "genuflectísseis": "genuflectir",
    "genuflectíssemos": "genuflectir",
    "genuflexa": "genuflexo",
    "genuflexas": "genuflexo",
    "genuflexos": "genuflexo",
    "genuflexórios": "genuflexório",
    "genuflexões": "genuflexão",
    "genuflicta": "genuflectir",
    "genuflictais": "genuflectir",
    "genuflictam": "genuflectir",
    "genuflictamo": "genuflectir",
    "genuflictamos": "genuflectir",
    "genuflictas": "genuflectir",
    "genuflicto": "genuflectir",
    "genuinidades": "genuinidade",
    "genuína": "genuíno",
    "genuínas": "genuíno",
    "genuínos": "genuíno",
    "genérica": "genérico",
    "genéricas": "genérico",
    "genéricos": "genérico",
    "genésica": "genésico",
    "genésicas": "genésico",
    "genésicos": "genésico",
    "genética": "genético",
    "genéticas": "genético",
    "genéticos": "genético",
    "genótipos": "genótipo",
    "geoadministrativa": "geoadministrativo",
    "geoadministrativas": "geoadministrativo",
    "geoadministrativos": "geoadministrativo",
    "geoanticlinais": "geoanticlinal",
    "geobiologias": "geobiologia",
    "geobotânica": "geobotânico",
    "geobotânicas": "geobotânico",
    "geobotânicos": "geobotânico",
    "geocarpias": "geocarpia",
    "geocentrismos": "geocentrismo",
    "geocentristas": "geocentrista",
    "geocinética": "geocinético",
    "geocinéticas": "geocinético",
    "geocinéticos": "geocinético",
    "geociências": "geociência",
    "geoclimatologias": "geoclimatologia",
    "geoclimatologistas": "geoclimatologista",
    "geoclimatológica": "geoclimatológico",
    "geoclimatológicas": "geoclimatológico",
    "geoclimatológicos": "geoclimatológico",
    "geoclimatóloga": "geoclimatólogo",
    "geoclimatólogas": "geoclimatólogo",
    "geoclimatólogos": "geoclimatólogo",
    "geocronologias": "geocronologia",
    "geocronologistas": "geocronologista",
    "geocronológica": "geocronológico",
    "geocronológicas": "geocronológico",
    "geocronológicos": "geocronológico",
    "geoculturais": "geocultural",
    "geocêntrica": "geocêntrico",
    "geocêntricas": "geocêntrico",
    "geocêntricos": "geocêntrico",
    "geocíclica": "geocíclico",
    "geocíclicas": "geocíclico",
    "geocíclicos": "geocíclico",
    "geodes": "geode",
    "geodesias": "geodesia",
    "geodesigráfica": "geodesigráfico",
    "geodesigráficas": "geodesigráfico",
    "geodesigráficos": "geodesigráfico",
    "geodesimetrias": "geodesimetria",
    "geodesimétrica": "geodesimétrico",
    "geodesimétricas": "geodesimétrico",
    "geodesimétricos": "geodesimétrico",
    "geodesistas": "geodesista",
    "geodesígrafos": "geodesígrafo",
    "geodesímetros": "geodesímetro",
    "geodimetrias": "geodimetria",
    "geodimétrica": "geodimétrico",
    "geodimétricas": "geodimétrico",
    "geodimétricos": "geodimétrico",
    "geodinâmca": "geodinâmco",
    "geodinâmcas": "geodinâmco",
    "geodinâmcos": "geodinâmco",
    "geodinâmicas": "geodinâmica",
    "geodésias": "geodésia",
    "geodésica": "geodésico",
    "geodésicas": "geodésico",
    "geodésicos": "geodésico",
    "geodímetros": "geodímetro",
    "geoeconomias": "geoeconomia",
    "geoeconomistas": "geoeconomista",
    "geoeconómica": "geoeconómico",
    "geoeconómicas": "geoeconómico",
    "geoeconómicos": "geoeconómico",
    "geoestacionária": "geoestacionário",
    "geoestacionárias": "geoestacionário",
    "geoestacionários": "geoestacionário",
    "geoestratégica": "geoestratégico",
    "geoestratégicas": "geoestratégico",
    "geoestratégicos": "geoestratégico",
    "geofagias": "geofagia",
    "geofones": "geofone",
    "geofágica": "geofágico",
    "geofágicas": "geofágico",
    "geofágicos": "geofágico",
    "geofísica": "geofísico",
    "geofísicas": "geofísico",
    "geofísicos": "geofísico",
    "geofónica": "geofónico",
    "geofónicas": "geofónico",
    "geofónicos": "geofónico",
    "geogenias": "geogenia",
    "geogenésica": "geogenésico",
    "geogenésicas": "geogenésico",
    "geogenésicos": "geogenésico",
    "geogenética": "geogenético",
    "geogenéticas": "geogenético",
    "geogenéticos": "geogenético",
    "geognoseológica": "geognoseológico",
    "geognoseológicas": "geognoseológico",
    "geognoseológicos": "geognoseológico",
    "geognosias": "geognosia",
    "geognosiologistas": "geognosiologista",
    "geognosióloga": "geognosiólogo",
    "geognosiólogas": "geognosiólogo",
    "geognosiólogos": "geognosiólogo",
    "geognósica": "geognósico",
    "geognósicas": "geognósico",
    "geognósicos": "geognósico",
    "geografias": "geografia",
    "geográfica": "geográfico",
    "geográficas": "geográfico",
    "geográficos": "geográfico",
    "geogénica": "geogénico",
    "geogénicas": "geogénico",
    "geogénicos": "geogénico",
    "geolitologias": "geolitologia",
    "geolitologistas": "geolitologista",
    "geolitológica": "geolitológico",
    "geolitológicas": "geolitológico",
    "geolitológicos": "geolitológico",
    "geolitóloga": "geolitólogo",
    "geolitólogas": "geolitólogo",
    "geolitólogos": "geolitólogo",
    "geologias": "geologia",
    "geologistas": "geologista",
    "geolítica": "geolítico",
    "geolíticas": "geolítico",
    "geolíticos": "geolítico",
    "geológica": "geológico",
    "geológicas": "geológico",
    "geológicos": "geológico",
    "geomagnetismos": "geomagnetismo",
    "geomagnética": "geomagnético",
    "geomagnéticas": "geomagnético",
    "geomagnéticos": "geomagnético",
    "geomancias": "geomancia",
    "geomantes": "geomante",
    "geometrias": "geometria",
    "geometristas": "geometrista",
    "geometrizações": "geometrização",
    "geometrografias": "geometrografia",
    "geometrográfica": "geometrográfico",
    "geometrográficas": "geometrográfico",
    "geometrográficos": "geometrográfico",
    "geometrídea": "geometrídeo",
    "geometrídeas": "geometrídeo",
    "geometrídeos": "geometrídeo",
    "geometrógrafa": "geometrógrafo",
    "geometrógrafas": "geometrógrafo",
    "geometrógrafos": "geometrógrafo",
    "geomorfogenias": "geomorfogenia",
    "geomorfogénica": "geomorfogénico",
    "geomorfogénicas": "geomorfogénico",
    "geomorfogénicos": "geomorfogénico",
    "geomorfologias": "geomorfologia",
    "geomorfológica": "geomorfológico",
    "geomorfológicas": "geomorfológico",
    "geomorfológicos": "geomorfológico",
    "geomântica": "geomântico",
    "geomânticas": "geomântico",
    "geomânticos": "geomântico",
    "geométrais": "geométral",
    "geométrica": "geométrico",
    "geométricas": "geométrico",
    "geométricos": "geométrico",
    "geométridas": "geométrida",
    "geonemias": "geonemia",
    "geonomias": "geonomia",
    "geonomástica": "geonomástico",
    "geonomásticas": "geonomástico",
    "geonomásticos": "geonomástico",
    "geonémica": "geonémico",
    "geonémicas": "geonémico",
    "geonémicos": "geonémico",
    "geonímica": "geonímico",
    "geonímicas": "geonímico",
    "geonímicos": "geonímico",
    "geopitecos": "geopiteco",
    "geopolítica": "geopolítico",
    "geopolíticas": "geopolítico",
    "geopolíticos": "geopolítico",
    "geopsicologias": "geopsicologia",
    "geopsicológica": "geopsicológico",
    "geopsicológicas": "geopsicológico",
    "geopsicológicos": "geopsicológico",
    "geopsicóloga": "geopsicólogo",
    "geopsicólogas": "geopsicólogo",
    "geopsicólogos": "geopsicólogo",
    "geoquímica": "geoquímico",
    "geoquímicas": "geoquímico",
    "geoquímicos": "geoquímico",
    "georamas": "georama",
    "georgiana": "georgiano",
    "georgianas": "georgiano",
    "georgianos": "georgiano",
    "georginas": "georgina",
    "georgismos": "georgismo",
    "geosa": "geoso",
    "geosas": "geoso",
    "geoscopa": "geoscopo",
    "geoscopas": "geoscopo",
    "geoscopias": "geoscopia",
    "geoscopos": "geoscopo",
    "geoscópica": "geoscópico",
    "geoscópicas": "geoscópico",
    "geoscópicos": "geoscópico",
    "geosferas": "geosfera",
    "geosférica": "geosférico",
    "geosféricas": "geosférico",
    "geosféricos": "geosférico",
    "geosos": "geoso",
    "geossauros": "geossauro",
    "geossinclinais": "geossinclinal",
    "geostática": "geostático",
    "geostáticas": "geostático",
    "geostáticos": "geostático",
    "geotactismos": "geotactismo",
    "geotectónica": "geotectónico",
    "geotectónicas": "geotectónico",
    "geotectónicos": "geotectónico",
    "geotermias": "geotermia",
    "geotermismos": "geotermismo",
    "geotropismos": "geotropismo",
    "geotrópica": "geotrópico",
    "geotrópicas": "geotrópico",
    "geotrópicos": "geotrópico",
    "geotérmica": "geotérmico",
    "geotérmicas": "geotérmico",
    "geotérmicos": "geotérmico",
    "geou": "gear",
    "gera": "gerar",
    "geracionais": "geracional",
    "gerada": "gerar",
    "geradas": "gerar",
    "gerado": "gerar",
    "geradoiros": "geradoiro",
    "geradora": "gerador",
    "geradoras": "geradora",
    "geradores": "gerador",
    "gerados": "gerar",
    "geradouros": "geradouro",
    "gerai": "gerar",
    "gerais": "gerar",
    "geraldina": "geraldino",
    "geraldinas": "geraldino",
    "geraldinos": "geraldino",
    "geralistas": "geralista",
    "geram": "gerar",
    "geramo": "gerar",
    "geramos": "gerar",
    "gerando": "gerar",
    "geraniácea": "geraniáceo",
    "geraniáceas": "geraniáceo",
    "geraniáceos": "geraniáceo",
    "gerara": "gerar",
    "geraram": "gerar",
    "geraras": "gerar",
    "gerarde": "gerar",
    "gerardes": "gerar",
    "gerare": "gerar",
    "gerarei": "gerar",
    "gerareis": "gerar",
    "gerarem": "gerar",
    "geraremos": "gerar",
    "gerares": "gerar",
    "geraria": "gerar",
    "gerariam": "gerar",
    "gerarias": "gerar",
    "gerarmo": "gerar",
    "gerarmos": "gerar",
    "gerará": "gerar",
    "gerarás": "gerar",
    "gerarão": "gerar",
    "geraríamos": "gerar",
    "geraríeis": "gerar",
    "geras": "gerar",
    "gerasse": "gerar",
    "gerassem": "gerar",
    "gerasses": "gerar",
    "geraste": "gerar",
    "gerastes": "gerar",
    "gerativa": "gerativo",
    "gerativas": "gerativo",
    "gerativos": "gerativo",
    "geratriz": "gerador",
    "geratrizes": "geratriz",
    "gerava": "gerar",
    "geravam": "gerar",
    "geravas": "gerar",
    "gerações": "geração",
    "gerbos": "gerbo",
    "gerbões": "gerbão",
    "gerdermias": "gerdermia",
    "gere": "gerir",
    "gerece": "gerecer",
    "gerecei": "gerecer",
    "gereceis": "gerecer",
    "gerecem": "gerecer",
    "gerecemo": "gerecer",
    "gerecemos": "gerecer",
    "gerecendo": "gerecer",
    "gerecera": "gerecer",
    "gereceram": "gerecer",
    "gereceras": "gerecer",
    "gerecerdes": "gerecer",
    "gerecerei": "gerecer",
    "gerecereis": "gerecer",
    "gerecerem": "gerecer",
    "gereceremos": "gerecer",
    "gereceres": "gerecer",
    "gereceria": "gerecer",
    "gereceriam": "gerecer",
    "gerecerias": "gerecer",
    "gerecermo": "gerecer",
    "gerecermos": "gerecer",
    "gerecerá": "gerecer",
    "gerecerás": "gerecer",
    "gerecerão": "gerecer",
    "gereceríamos": "gerecer",
    "gereceríeis": "gerecer",
    "gereces": "gerecer",
    "gerecesse": "gerecer",
    "gerecessem": "gerecer",
    "gerecesses": "gerecer",
    "gereceste": "gerecer",
    "gerecestes": "gerecer",
    "gereceu": "gerecer",
    "gereci": "gerecer",
    "gerecia": "gerecer",
    "gereciam": "gerecer",
    "gerecias": "gerecer",
    "gerecida": "gerecer",
    "gerecidas": "gerecer",
    "gerecido": "gerecer",
    "gerecidos": "gerecer",
    "gerecêramo": "gerecer",
    "gerecêramos": "gerecer",
    "gerecêreis": "gerecer",
    "gerecêsseis": "gerecer",
    "gerecêssemos": "gerecer",
    "gerecíamo": "gerecer",
    "gerecíamos": "gerecer",
    "gerecíeis": "gerecer",
    "gerei": "gerar",
    "gereis": "gerar",
    "gerem": "gerir",
    "geremo": "gerar",
    "geremos": "gerar",
    "gerenciamentos": "gerenciamento",
    "gerentes": "gerente",
    "geres": "gerir",
    "geresana": "geresano",
    "geresanas": "geresano",
    "geresanos": "geresano",
    "geresiana": "geresiano",
    "geresianas": "geresiano",
    "geresianos": "geresiano",
    "geresina": "geresino",
    "geresinas": "geresino",
    "geresinos": "geresino",
    "geresã": "geresão",
    "geresãos": "geresão",
    "geresãs": "geresão",
    "gereça": "gerecer",
    "gereçais": "gerecer",
    "gereçam": "gerecer",
    "gereçamo": "gerecer",
    "gereçamos": "gerecer",
    "gereças": "gerecer",
    "gereço": "gerecer",
    "gergelins": "gergelim",
    "gergiladas": "gergilada",
    "geri": "gerir",
    "geria": "gerir",
    "geriam": "gerir",
    "gerias": "gerir",
    "geriatras": "geriatra",
    "geriatrias": "geriatria",
    "geribandas": "geribanda",
    "geribés": "geribé",
    "gerida": "gerir",
    "geridas": "gerir",
    "gerido": "gerir",
    "geridos": "gerir",
    "gerifaltes": "gerifalte",
    "gerifaltos": "gerifalto",
    "gerigonças": "gerigonça",
    "gerimo": "gerir",
    "gerimos": "gerir",
    "gerindo": "gerir",
    "geringonças": "geringonça",
    "gerira": "gerir",
    "geriram": "gerir",
    "geriras": "gerir",
    "gerirde": "gerir",
    "gerirdes": "gerir",
    "gerire": "gerir",
    "gerirei": "gerir",
    "gerireis": "gerir",
    "gerirem": "gerir",
    "geriremos": "gerir",
    "gerires": "gerir",
    "geriria": "gerir",
    "geririam": "gerir",
    "geririas": "gerir",
    "gerirmo": "gerir",
    "gerirmos": "gerir",
    "gerirá": "gerir",
    "gerirás": "gerir",
    "gerirão": "gerir",
    "geriríamos": "gerir",
    "geriríeis": "gerir",
    "geris": "gerir",
    "gerisse": "gerir",
    "gerissem": "gerir",
    "gerisses": "gerir",
    "geriste": "gerir",
    "geristes": "gerir",
    "geriu": "gerir",
    "geriátrica": "geriátrico",
    "geriátricas": "geriátrico",
    "geriátricos": "geriátrico",
    "germana": "germano",
    "germanadas": "germanada",
    "germanais": "germanal",
    "germanas": "germano",
    "germanices": "germanice",
    "germanidades": "germanidade",
    "germanismos": "germanismo",
    "germanistas": "germanista",
    "germaniza": "germanizar",
    "germanizada": "germanizar",
    "germanizadas": "germanizar",
    "germanizado": "germanizar",
    "germanizados": "germanizar",
    "germanizai": "germanizar",
    "germanizais": "germanizar",
    "germanizam": "germanizar",
    "germanizamo": "germanizar",
    "germanizamos": "germanizar",
    "germanizando": "germanizar",
    "germanizara": "germanizar",
    "germanizaram": "germanizar",
    "germanizaras": "germanizar",
    "germanizarde": "germanizar",
    "germanizardes": "germanizar",
    "germanizare": "germanizar",
    "germanizarei": "germanizar",
    "germanizareis": "germanizar",
    "germanizarem": "germanizar",
    "germanizaremos": "germanizar",
    "germanizares": "germanizar",
    "germanizaria": "germanizar",
    "germanizariam": "germanizar",
    "germanizarias": "germanizar",
    "germanizarmo": "germanizar",
    "germanizarmos": "germanizar",
    "germanizará": "germanizar",
    "germanizarás": "germanizar",
    "germanizarão": "germanizar",
    "germanizaríamos": "germanizar",
    "germanizaríeis": "germanizar",
    "germanizas": "germanizar",
    "germanizasse": "germanizar",
    "germanizassem": "germanizar",
    "germanizasses": "germanizar",
    "germanizaste": "germanizar",
    "germanizastes": "germanizar",
    "germanizava": "germanizar",
    "germanizavam": "germanizar",
    "germanizavas": "germanizar",
    "germanizações": "germanização",
    "germanize": "germanizar",
    "germanizei": "germanizar",
    "germanizeis": "germanizar",
    "germanizem": "germanizar",
    "germanizemo": "germanizar",
    "germanizemos": "germanizar",
    "germanizes": "germanizar",
    "germanizo": "germanizar",
    "germanizou": "germanizar",
    "germanizá": "germanizar",
    "germanizámo": "germanizar",
    "germanizámos": "germanizar",
    "germanizáramo": "germanizar",
    "germanizáramos": "germanizar",
    "germanizárei": "germanizar",
    "germanizáreis": "germanizar",
    "germanizásseis": "germanizar",
    "germanizássemos": "germanizar",
    "germanizávamo": "germanizar",
    "germanizávamos": "germanizar",
    "germanizávei": "germanizar",
    "germanizáveis": "germanizável",
    "germanofilias": "germanofilia",
    "germanofobias": "germanofobia",
    "germanos": "germano",
    "germanófila": "germanófilo",
    "germanófilas": "germanófilo",
    "germanófilos": "germanófilo",
    "germanófoba": "germanófobo",
    "germanófobas": "germanófobo",
    "germanófobos": "germanófobo",
    "germes": "germe",
    "germicidas": "germicida",
    "germina": "germinar",
    "germinabilidades": "germinabilidade",
    "germinada": "germinar",
    "germinadas": "germinar",
    "germinado": "germinar",
    "germinadoiros": "germinadoiro",
    "germinadora": "germinador",
    "germinadoras": "germinador",
    "germinadores": "germinador",
    "germinados": "germinar",
    "germinadouros": "germinadouro",
    "germinai": "germinar",
    "germinais": "germinar",
    "germinam": "germinar",
    "germinamo": "germinar",
    "germinamos": "germinar",
    "germinando": "germinar",
    "germinantes": "germinante",
    "germinara": "germinar",
    "germinaram": "germinar",
    "germinaras": "germinar",
    "germinardes": "germinar",
    "germinarei": "germinar",
    "germinareis": "germinar",
    "germinarem": "germinar",
    "germinaremos": "germinar",
    "germinares": "germinar",
    "germinaria": "germinar",
    "germinariam": "germinar",
    "germinarias": "germinar",
    "germinarmo": "germinar",
    "germinarmos": "germinar",
    "germinará": "germinar",
    "germinarás": "germinar",
    "germinarão": "germinar",
    "germinaríamos": "germinar",
    "germinaríeis": "germinar",
    "germinas": "germinar",
    "germinasse": "germinar",
    "germinassem": "germinar",
    "germinasses": "germinar",
    "germinaste": "germinar",
    "germinastes": "germinar",
    "germinativa": "germinativo",
    "germinativas": "germinativo",
    "germinativos": "germinativo",
    "germinava": "germinar",
    "germinavam": "germinar",
    "germinavas": "germinar",
    "germinações": "germinação",
    "germine": "germinar",
    "germinei": "germinar",
    "germineis": "germinar",
    "germinem": "germinar",
    "germinemo": "germinar",
    "germinemos": "germinar",
    "germines": "germinar",
    "gerministas": "germinista",
    "germino": "germinar",
    "germinou": "germinar",
    "germinámo": "germinar",
    "germinámos": "germinar",
    "germináramo": "germinar",
    "germináramos": "germinar",
    "germináreis": "germinar",
    "germinásseis": "germinar",
    "germinássemos": "germinar",
    "germinávamo": "germinar",
    "germinávamos": "germinar",
    "germináveis": "germinar",
    "germinípara": "germiníparo",
    "germiníparas": "germiníparo",
    "germiníparos": "germiníparo",
    "germânica": "germânico",
    "germânicas": "germânico",
    "germânicos": "germânico",
    "germânios": "germânio",
    "germões": "germão",
    "gero": "gerar",
    "gerocomias": "gerocomia",
    "gerocómica": "gerocómico",
    "gerocómicas": "gerocómico",
    "gerocómicos": "gerocómico",
    "gerocómios": "gerocómio",
    "gerodérmica": "gerodérmico",
    "gerodérmicas": "gerodérmico",
    "gerodérmicos": "gerodérmico",
    "geromorfismos": "geromorfismo",
    "geromórfica": "geromórfico",
    "geromórficas": "geromórfico",
    "geromórficos": "geromórfico",
    "gerontes": "geronte",
    "gerontocracias": "gerontocracia",
    "gerontocratas": "gerontocrata",
    "gerontocrática": "gerontocrático",
    "gerontocráticas": "gerontocrático",
    "gerontocráticos": "gerontocrático",
    "gerontocómica": "gerontocómico",
    "gerontocómicas": "gerontocómico",
    "gerontocómicos": "gerontocómico",
    "gerontocómios": "gerontocómio",
    "gerontofilias": "gerontofilia",
    "gerontologias": "gerontologia",
    "gerontologistas": "gerontologista",
    "gerontológica": "gerontológico",
    "gerontológicas": "gerontológico",
    "gerontológicos": "gerontológico",
    "gerontófila": "gerontófilo",
    "gerontófilas": "gerontófilo",
    "gerontófilos": "gerontófilo",
    "gerontóloga": "gerontólogo",
    "gerontólogas": "gerontólogo",
    "gerontólogos": "gerontólogo",
    "geros": "gero",
    "geroterapeutas": "geroterapeuta",
    "geroterapias": "geroterapia",
    "geroterapistas": "geroterapista",
    "geroterapêutica": "geroterapêutico",
    "geroterapêuticas": "geroterapêutico",
    "geroterapêuticos": "geroterapêutico",
    "geroterápica": "geroterápico",
    "geroterápicas": "geroterápico",
    "geroterápicos": "geroterápico",
    "gerou": "gerar",
    "gerundiais": "gerundial",
    "gerundiva": "gerundivo",
    "gerundivas": "gerundivo",
    "gerundivos": "gerundivo",
    "gerundífica": "gerundífico",
    "gerundíficas": "gerundífico",
    "gerundíficos": "gerundífico",
    "gervões": "gervão",
    "gerzelins": "gerzelim",
    "gerá": "gerar",
    "gerámo": "gerar",
    "gerámos": "gerar",
    "geráramo": "gerar",
    "geráramos": "gerar",
    "gerárei": "gerar",
    "geráreis": "gerar",
    "gerásseis": "gerar",
    "gerássemos": "gerar",
    "gerávamo": "gerar",
    "gerávamos": "gerar",
    "gerávei": "gerar",
    "geráveis": "gerável",
    "gerânios": "gerânio",
    "gerências": "gerência",
    "geríamo": "gerir",
    "geríamos": "gerir",
    "geríei": "gerir",
    "geríeis": "gerir",
    "geríramo": "gerir",
    "geríramos": "gerir",
    "gerírei": "gerir",
    "geríreis": "gerir",
    "gerísseis": "gerir",
    "geríssemos": "gerir",
    "geríveis": "gerível",
    "gerúndios": "gerúndio",
    "gerúsias": "gerúsia",
    "gesneriáceas": "gesneriácea",
    "gesnérias": "gesnéria",
    "gessa": "gessar",
    "gessada": "gessar",
    "gessadas": "gessar",
    "gessado": "gessar",
    "gessados": "gessar",
    "gessagens": "gessagem",
    "gessai": "gessar",
    "gessais": "gessar",
    "gessam": "gessar",
    "gessamo": "gessar",
    "gessamos": "gessar",
    "gessando": "gessar",
    "gessara": "gessar",
    "gessaram": "gessar",
    "gessaras": "gessar",
    "gessarde": "gessar",
    "gessardes": "gessar",
    "gessare": "gessar",
    "gessarei": "gessar",
    "gessareis": "gessar",
    "gessarem": "gessar",
    "gessaremos": "gessar",
    "gessares": "gessar",
    "gessaria": "gessar",
    "gessariam": "gessar",
    "gessarias": "gessar",
    "gessarmo": "gessar",
    "gessarmos": "gessar",
    "gessará": "gessar",
    "gessarás": "gessar",
    "gessarão": "gessar",
    "gessaríamos": "gessar",
    "gessaríeis": "gessar",
    "gessas": "gessar",
    "gessasse": "gessar",
    "gessassem": "gessar",
    "gessasses": "gessar",
    "gessaste": "gessar",
    "gessastes": "gessar",
    "gessava": "gessar",
    "gessavam": "gessar",
    "gessavas": "gessar",
    "gesse": "gessar",
    "gessei": "gessar",
    "gesseira": "gesseiro",
    "gesseiras": "gesseiro",
    "gesseiros": "gesseiro",
    "gesseis": "gessar",
    "gessem": "gessar",
    "gessemo": "gessar",
    "gessemos": "gessar",
    "gesses": "gessar",
    "gessetes": "gessete",
    "gesso": "gessar",
    "gessos": "gesso",
    "gessosa": "gessoso",
    "gessosas": "gessoso",
    "gessosos": "gessoso",
    "gessou": "gessar",
    "gessá": "gessar",
    "gessámo": "gessar",
    "gessámos": "gessar",
    "gessáramo": "gessar",
    "gessáramos": "gessar",
    "gessárei": "gessar",
    "gessáreis": "gessar",
    "gessásseis": "gessar",
    "gessássemos": "gessar",
    "gessávamo": "gessar",
    "gessávamos": "gessar",
    "gessávei": "gessar",
    "gessáveis": "gessar",
    "gestalismos": "gestalismo",
    "gestantes": "gestante",
    "gestapos": "gestapo",
    "gestas": "gesta",
    "gestatória": "gestatório",
    "gestatórias": "gestatório",
    "gestatórios": "gestatório",
    "gestações": "gestação",
    "gesticula": "gesticular",
    "gesticulada": "gesticular",
    "gesticuladas": "gesticular",
    "gesticulado": "gesticular",
    "gesticuladora": "gesticulador",
    "gesticuladoras": "gesticulador",
    "gesticuladores": "gesticulador",
    "gesticulados": "gesticular",
    "gesticulai": "gesticular",
    "gesticulais": "gesticular",
    "gesticulam": "gesticular",
    "gesticulamo": "gesticular",
    "gesticulamos": "gesticular",
    "gesticulando": "gesticular",
    "gesticulara": "gesticular",
    "gesticularam": "gesticular",
    "gesticularas": "gesticular",
    "gesticulardes": "gesticular",
    "gesticularei": "gesticular",
    "gesticulareis": "gesticular",
    "gesticularem": "gesticular",
    "gesticularemos": "gesticular",
    "gesticulares": "gesticular",
    "gesticularia": "gesticular",
    "gesticulariam": "gesticular",
    "gesticularias": "gesticular",
    "gesticularmo": "gesticular",
    "gesticularmos": "gesticular",
    "gesticulará": "gesticular",
    "gesticularás": "gesticular",
    "gesticularão": "gesticular",
    "gesticularíamos": "gesticular",
    "gesticularíeis": "gesticular",
    "gesticulas": "gesticular",
    "gesticulasse": "gesticular",
    "gesticulassem": "gesticular",
    "gesticulasses": "gesticular",
    "gesticulaste": "gesticular",
    "gesticulastes": "gesticular",
    "gesticulava": "gesticular",
    "gesticulavam": "gesticular",
    "gesticulavas": "gesticular",
    "gesticulações": "gesticulação",
    "gesticule": "gesticular",
    "gesticulei": "gesticular",
    "gesticuleis": "gesticular",
    "gesticulem": "gesticular",
    "gesticulemo": "gesticular",
    "gesticulemos": "gesticular",
    "gesticules": "gesticular",
    "gesticulo": "gesticular",
    "gesticulou": "gesticular",
    "gesticulámo": "gesticular",
    "gesticulámos": "gesticular",
    "gesticuláramo": "gesticular",
    "gesticuláramos": "gesticular",
    "gesticuláreis": "gesticular",
    "gesticulásseis": "gesticular",
    "gesticulássemos": "gesticular",
    "gesticulávamo": "gesticular",
    "gesticulávamos": "gesticular",
    "gesticuláveis": "gesticular",
    "gestora": "gestor",
    "gestoras": "gestor",
    "gestores": "gestor",
    "gestos": "gesto",
    "gestoses": "gestose",
    "gestozinho": "gesto",
    "gestozinhos": "gesto",
    "gestozito": "gesto",
    "gestozitos": "gesto",
    "gestrelas": "gestrela",
    "gestuais": "gestual",
    "gestualidades": "gestualidade",
    "gestuculadora": "gestuculador",
    "gestuculadoras": "gestuculador",
    "gestuculadores": "gestuculador",
    "gestões": "gestão",
    "getas": "geta",
    "geámo": "gear",
    "geámos": "gear",
    "geáramo": "gear",
    "geáramos": "gear",
    "geáreis": "gear",
    "geásseis": "gear",
    "geássemos": "gear",
    "geávamo": "gear",
    "geávamos": "gear",
    "geáveis": "gear",
    "geófaga": "geófago",
    "geófagas": "geófago",
    "geófagos": "geófago",
    "geógena": "geógeno",
    "geógenas": "geógeno",
    "geógenos": "geógeno",
    "geógrafa": "geógrafo",
    "geógrafas": "geógrafo",
    "geógrafos": "geógrafo",
    "geóides": "geóide",
    "geóloga": "geólogo",
    "geólogas": "geólogo",
    "geólogos": "geólogo",
    "geómetras": "geómetra",
    "geórgica": "geórgico",
    "geórgicas": "geórgico",
    "geórgicos": "geórgico",
    "gg": "g",
    "ghettos": "ghetto",
    "gibanetes": "gibanete",
    "gibas": "giba",
    "gibatões": "gibatão",
    "gibelina": "gibelino",
    "gibelinas": "gibelino",
    "gibelinos": "gibelino",
    "gibosa": "giboso",
    "gibosas": "giboso",
    "gibosidades": "gibosidade",
    "gibosos": "giboso",
    "gibraltarina": "gibraltarino",
    "gibraltarinas": "gibraltarino",
    "gibraltarinos": "gibraltarino",
    "gibsites": "gibsite",
    "gibsítica": "gibsítico",
    "gibsíticas": "gibsítico",
    "gibsíticos": "gibsítico",
    "gibões": "gibão",
    "gicleres": "gicler",
    "gidouros": "gidouro",
    "giestais": "giestal",
    "giestas": "giesta",
    "giesteiras": "giesteira",
    "giesteiros": "giesteiro",
    "giestosa": "giestoso",
    "giestosas": "giestoso",
    "giestosos": "giestoso",
    "giestós": "giestó",
    "giganta": "gigante",
    "gigantas": "gigante",
    "giganteada": "gigantear",
    "giganteadas": "gigantear",
    "giganteado": "gigantear",
    "giganteados": "gigantear",
    "giganteai": "gigantear",
    "giganteais": "gigantear",
    "giganteamo": "gigantear",
    "giganteamos": "gigantear",
    "giganteando": "gigantear",
    "giganteara": "gigantear",
    "gigantearam": "gigantear",
    "gigantearas": "gigantear",
    "giganteardes": "gigantear",
    "gigantearei": "gigantear",
    "giganteareis": "gigantear",
    "gigantearem": "gigantear",
    "gigantearemos": "gigantear",
    "giganteares": "gigantear",
    "gigantearia": "gigantear",
    "giganteariam": "gigantear",
    "gigantearias": "gigantear",
    "gigantearmo": "gigantear",
    "gigantearmos": "gigantear",
    "giganteará": "gigantear",
    "gigantearás": "gigantear",
    "gigantearão": "gigantear",
    "gigantearíamos": "gigantear",
    "gigantearíeis": "gigantear",
    "giganteasse": "gigantear",
    "giganteassem": "gigantear",
    "giganteasses": "gigantear",
    "giganteaste": "gigantear",
    "giganteastes": "gigantear",
    "giganteava": "gigantear",
    "giganteavam": "gigantear",
    "giganteavas": "gigantear",
    "giganteei": "gigantear",
    "giganteeis": "gigantear",
    "giganteemo": "gigantear",
    "giganteemos": "gigantear",
    "giganteia": "giganteu",
    "giganteiam": "gigantear",
    "giganteias": "giganteu",
    "giganteie": "gigantear",
    "giganteiem": "gigantear",
    "giganteies": "gigantear",
    "giganteio": "gigantear",
    "giganteou": "gigantear",
    "gigantes": "gigante",
    "gigantesca": "gigantesco",
    "gigantescas": "gigantesco",
    "gigantescos": "gigantesco",
    "giganteus": "giganteu",
    "giganteámo": "gigantear",
    "giganteámos": "gigantear",
    "giganteáramo": "gigantear",
    "giganteáramos": "gigantear",
    "giganteáreis": "gigantear",
    "giganteásseis": "gigantear",
    "giganteássemos": "gigantear",
    "giganteávamo": "gigantear",
    "giganteávamos": "gigantear",
    "giganteáveis": "gigantear",
    "gigantis": "gigantil",
    "gigantismos": "gigantismo",
    "gigantiza": "gigantizar",
    "gigantizada": "gigantizar",
    "gigantizadas": "gigantizar",
    "gigantizado": "gigantizar",
    "gigantizados": "gigantizar",
    "gigantizai": "gigantizar",
    "gigantizais": "gigantizar",
    "gigantizam": "gigantizar",
    "gigantizamo": "gigantizar",
    "gigantizamos": "gigantizar",
    "gigantizando": "gigantizar",
    "gigantizara": "gigantizar",
    "gigantizaram": "gigantizar",
    "gigantizaras": "gigantizar",
    "gigantizarde": "gigantizar",
    "gigantizardes": "gigantizar",
    "gigantizare": "gigantizar",
    "gigantizarei": "gigantizar",
    "gigantizareis": "gigantizar",
    "gigantizarem": "gigantizar",
    "gigantizaremos": "gigantizar",
    "gigantizares": "gigantizar",
    "gigantizaria": "gigantizar",
    "gigantizariam": "gigantizar",
    "gigantizarias": "gigantizar",
    "gigantizarmo": "gigantizar",
    "gigantizarmos": "gigantizar",
    "gigantizará": "gigantizar",
    "gigantizarás": "gigantizar",
    "gigantizarão": "gigantizar",
    "gigantizaríamos": "gigantizar",
    "gigantizaríeis": "gigantizar",
    "gigantizas": "gigantizar",
    "gigantizasse": "gigantizar",
    "gigantizassem": "gigantizar",
    "gigantizasses": "gigantizar",
    "gigantizaste": "gigantizar",
    "gigantizastes": "gigantizar",
    "gigantizava": "gigantizar",
    "gigantizavam": "gigantizar",
    "gigantizavas": "gigantizar",
    "gigantize": "gigantizar",
    "gigantizei": "gigantizar",
    "gigantizeis": "gigantizar",
    "gigantizem": "gigantizar",
    "gigantizemo": "gigantizar",
    "gigantizemos": "gigantizar",
    "gigantizes": "gigantizar",
    "gigantizo": "gigantizar",
    "gigantizou": "gigantizar",
    "gigantizá": "gigantizar",
    "gigantizámo": "gigantizar",
    "gigantizámos": "gigantizar",
    "gigantizáramo": "gigantizar",
    "gigantizáramos": "gigantizar",
    "gigantizárei": "gigantizar",
    "gigantizáreis": "gigantizar",
    "gigantizásseis": "gigantizar",
    "gigantizássemos": "gigantizar",
    "gigantizávamo": "gigantizar",
    "gigantizávamos": "gigantizar",
    "gigantizávei": "gigantizar",
    "gigantizáveis": "gigantizar",
    "gigantomaquias": "gigantomaquia",
    "gigantomáquica": "gigantomáquico",
    "gigantomáquicas": "gigantomáquico",
    "gigantomáquicos": "gigantomáquico",
    "gigantorrincos": "gigantorrinco",
    "gigantostrácea": "gigantostráceo",
    "gigantostráceas": "gigantostráceo",
    "gigantostráceos": "gigantostráceo",
    "gigantífera": "gigantífero",
    "gigantíferas": "gigantífero",
    "gigantíferos": "gigantífero",
    "gigantófona": "gigantófono",
    "gigantófonas": "gigantófono",
    "gigantófonos": "gigantófono",
    "gigantões": "gigantão",
    "gigas": "giga",
    "gigolôs": "gigolô",
    "gigos": "gigo",
    "gigotes": "gigote",
    "gigâmetros": "gigâmetro",
    "gigântica": "gigântico",
    "gigânticas": "gigântico",
    "gigânticos": "gigântico",
    "gigôs": "gigô",
    "gilas": "gila",
    "gilbarbeiras": "gilbarbeira",
    "gilbardeiras": "gilbardeira",
    "gilberts": "gilbert",
    "giletes": "gilete",
    "gilettes": "gilette",
    "gilvazes": "gilvaz",
    "gilvicentesca": "gilvicentesco",
    "gilvicentescas": "gilvicentesco",
    "gilvicentescos": "gilvicentesco",
    "gimbolinhas": "gimbolinha",
    "gimbos": "gimbo",
    "gimnandra": "gimnandro",
    "gimnandras": "gimnandro",
    "gimnandrias": "gimnandria",
    "gimnandros": "gimnandro",
    "gimnanta": "gimnanto",
    "gimnantas": "gimnanto",
    "gimnantos": "gimnanto",
    "gimnasiarcas": "gimnasiarca",
    "gimnasiarcos": "gimnasiarco",
    "gimnasiárquica": "gimnasiárquico",
    "gimnasiárquicas": "gimnasiárquico",
    "gimnasiárquicos": "gimnasiárquico",
    "gimnfóbica": "gimnfóbico",
    "gimnfóbicas": "gimnfóbico",
    "gimnfóbicos": "gimnfóbico",
    "gimnocarpa": "gimnocarpo",
    "gimnocarpas": "gimnocarpo",
    "gimnocarpos": "gimnocarpo",
    "gimnocaules": "gimnocaule",
    "gimnocefálica": "gimnocefálico",
    "gimnocefálicas": "gimnocefálico",
    "gimnocefálicos": "gimnocefálico",
    "gimnocerados": "gimnocerado",
    "gimnocárpica": "gimnocárpico",
    "gimnocárpicas": "gimnocárpico",
    "gimnocárpicos": "gimnocárpico",
    "gimnocéfala": "gimnocéfalo",
    "gimnocéfalas": "gimnocéfalo",
    "gimnocéfalos": "gimnocéfalo",
    "gimnodermos": "gimnodermo",
    "gimnodesportiva": "gimnodesportivo",
    "gimnodesportivas": "gimnodesportivo",
    "gimnodesportivos": "gimnodesportivo",
    "gimnofionos": "gimnofiono",
    "gimnofiónia": "gimnofiónio",
    "gimnofiónias": "gimnofiónio",
    "gimnofiónios": "gimnofiónio",
    "gimnofobias": "gimnofobia",
    "gimnospermas": "gimnosperma",
    "gimnospermias": "gimnospermia",
    "gimnospérmica": "gimnospérmico",
    "gimnospérmicas": "gimnospérmico",
    "gimnospérmicos": "gimnospérmico",
    "gimnotos": "gimnoto",
    "gimnotídea": "gimnotídeo",
    "gimnotídeas": "gimnotídeo",
    "gimnotídeos": "gimnotídeo",
    "gimnura": "gimnuro",
    "gimnuras": "gimnuro",
    "gimnuros": "gimnuro",
    "gimnófoba": "gimnófobo",
    "gimnófobas": "gimnófobo",
    "gimnófobos": "gimnófobo",
    "gimnótidas": "gimnótida",
    "ginandra": "ginandro",
    "ginandras": "ginandro",
    "ginandromorfa": "ginandromorfo",
    "ginandromorfas": "ginandromorfo",
    "ginandromorfismos": "ginandromorfismo",
    "ginandromorfos": "ginandromorfo",
    "ginandromórfica": "ginandromórfico",
    "ginandromórficas": "ginandromórfico",
    "ginandromórficos": "ginandromórfico",
    "ginandros": "ginandro",
    "ginantropa": "ginantropo",
    "ginantropas": "ginantropo",
    "ginantropias": "ginantropia",
    "ginantropos": "ginantropo",
    "ginantrópica": "ginantrópico",
    "ginantrópicas": "ginantrópico",
    "ginantrópicos": "ginantrópico",
    "ginasiais": "ginasial",
    "ginasiana": "ginasiano",
    "ginasianas": "ginasiano",
    "ginasianos": "ginasiano",
    "ginastas": "ginasta",
    "ginasticada": "ginasticado",
    "ginasticadas": "ginasticado",
    "ginasticados": "ginasticado",
    "gincanas": "gincana",
    "gineceus": "gineceu",
    "ginecocracias": "ginecocracia",
    "ginecocratas": "ginecocrata",
    "ginecocrática": "ginecocrático",
    "ginecocráticas": "ginecocrático",
    "ginecocráticos": "ginecocrático",
    "ginecofobias": "ginecofobia",
    "ginecofóbica": "ginecofóbico",
    "ginecofóbicas": "ginecofóbico",
    "ginecofóbicos": "ginecofóbico",
    "ginecografias": "ginecografia",
    "ginecologias": "ginecologia",
    "ginecologistas": "ginecologista",
    "ginecológica": "ginecológico",
    "ginecológicas": "ginecológico",
    "ginecológicos": "ginecológico",
    "ginecomanias": "ginecomania",
    "ginecomaníaca": "ginecomaníaco",
    "ginecomaníacas": "ginecomaníaco",
    "ginecomaníacos": "ginecomaníaco",
    "ginecomastias": "ginecomastia",
    "ginecomastos": "ginecomasto",
    "ginecrocracias": "ginecrocracia",
    "ginecrocratas": "ginecrocrata",
    "ginecófoba": "ginecófobo",
    "ginecófobas": "ginecófobo",
    "ginecófobos": "ginecófobo",
    "ginecómana": "ginecómano",
    "ginecómanas": "ginecómano",
    "ginecómanos": "ginecómano",
    "gineiras": "gineira",
    "ginerlinas": "ginerlina",
    "ginetada": "ginetado",
    "ginetadas": "ginetado",
    "ginetados": "ginetado",
    "ginetas": "gineta",
    "ginetaços": "ginetaço",
    "ginetes": "ginete",
    "ginetos": "gineto",
    "ginetários": "ginetário",
    "ginga": "gingar",
    "gingada": "gingar",
    "gingadas": "gingar",
    "gingado": "gingar",
    "gingadora": "gingador",
    "gingadoras": "gingador",
    "gingadores": "gingador",
    "gingados": "gingar",
    "gingai": "gingar",
    "gingais": "gingar",
    "gingam": "gingar",
    "gingamo": "gingar",
    "gingamos": "gingar",
    "gingando": "gingar",
    "gingantes": "gingante",
    "gingara": "gingar",
    "gingaram": "gingar",
    "gingaras": "gingar",
    "gingarde": "gingar",
    "gingardes": "gingar",
    "gingare": "gingar",
    "gingarei": "gingar",
    "gingareis": "gingar",
    "gingarem": "gingar",
    "gingaremos": "gingar",
    "gingares": "gingar",
    "gingaria": "gingar",
    "gingariam": "gingar",
    "gingarias": "gingar",
    "gingarmo": "gingar",
    "gingarmos": "gingar",
    "gingará": "gingar",
    "gingarás": "gingar",
    "gingarão": "gingar",
    "gingaríamos": "gingar",
    "gingaríeis": "gingar",
    "gingas": "gingar",
    "gingasse": "gingar",
    "gingassem": "gingar",
    "gingasses": "gingar",
    "gingaste": "gingar",
    "gingastes": "gingar",
    "gingava": "gingar",
    "gingavam": "gingar",
    "gingavas": "gingar",
    "gingações": "gingação",
    "gingerlinas": "gingerlina",
    "gingerlins": "gingerlim",
    "ginges": "ginge",
    "gingo": "gingar",
    "gingona": "gingão",
    "gingonas": "gingão",
    "gingos": "gingo",
    "gingou": "gingar",
    "gingue": "gingar",
    "ginguei": "gingar",
    "gingueis": "gingar",
    "ginguem": "gingar",
    "ginguemo": "gingar",
    "ginguemos": "gingar",
    "gingues": "gingar",
    "gingá": "gingar",
    "gingámo": "gingar",
    "gingámos": "gingar",
    "gingáramo": "gingar",
    "gingáramos": "gingar",
    "gingárei": "gingar",
    "gingáreis": "gingar",
    "gingásseis": "gingar",
    "gingássemos": "gingar",
    "gingávamo": "gingar",
    "gingávamos": "gingar",
    "gingávei": "gingar",
    "gingáveis": "gingar",
    "gingões": "gingão",
    "ginjais": "ginjal",
    "ginjas": "ginja",
    "ginjeiras": "ginjeira",
    "ginjinhas": "ginjinha",
    "ginofobias": "ginofobia",
    "ginofóbica": "ginofóbico",
    "ginofóbicas": "ginofóbico",
    "ginofóbicos": "ginofóbico",
    "ginostemas": "ginostema",
    "ginostégios": "ginostégio",
    "ginostémica": "ginostémico",
    "ginostémicas": "ginostémico",
    "ginostémicos": "ginostémico",
    "ginostémios": "ginostémio",
    "gins": "gin",
    "ginásios": "ginásio",
    "ginástica": "ginástico",
    "ginásticas": "ginástico",
    "ginásticos": "ginástico",
    "ginândrica": "ginândrico",
    "ginândricas": "ginândrico",
    "ginândricos": "ginândrico",
    "ginófoba": "ginófobo",
    "ginófobas": "ginófobo",
    "ginófobos": "ginófobo",
    "ginófora": "ginóforo",
    "ginóforas": "ginóforo",
    "ginóforos": "ginóforo",
    "ginóstemos": "ginóstemo",
    "giobertites": "giobertite",
    "gios": "gio",
    "gipaetos": "gipaeto",
    "gipsografias": "gipsografia",
    "gipsos": "gipso",
    "gipsosa": "gipsoso",
    "gipsosas": "gipsoso",
    "gipsosos": "gipsoso",
    "gipsífera": "gipsífero",
    "gipsíferas": "gipsífero",
    "gipsíferos": "gipsífero",
    "gipsófila": "gipsófilo",
    "gipsófilas": "gipsófilo",
    "gipsófilos": "gipsófilo",
    "gira": "giro",
    "girada": "girar",
    "giradas": "girar",
    "girado": "girar",
    "giradores": "girador",
    "girados": "girar",
    "girafas": "girafa",
    "girafídea": "girafídeo",
    "girafídeas": "girafídeo",
    "girafídeos": "girafídeo",
    "girai": "girar",
    "girais": "girar",
    "giraldinhas": "giraldinha",
    "giram": "girar",
    "giramo": "girar",
    "giramos": "girar",
    "girando": "girar",
    "girandola": "girandolar",
    "girandolada": "girandolar",
    "girandoladas": "girandolar",
    "girandolado": "girandolar",
    "girandolados": "girandolar",
    "girandolai": "girandolar",
    "girandolais": "girandolar",
    "girandolam": "girandolar",
    "girandolamo": "girandolar",
    "girandolamos": "girandolar",
    "girandolando": "girandolar",
    "girandolara": "girandolar",
    "girandolaram": "girandolar",
    "girandolaras": "girandolar",
    "girandolarde": "girandolar",
    "girandolardes": "girandolar",
    "girandolare": "girandolar",
    "girandolarei": "girandolar",
    "girandolareis": "girandolar",
    "girandolarem": "girandolar",
    "girandolaremos": "girandolar",
    "girandolares": "girandolar",
    "girandolaria": "girandolar",
    "girandolariam": "girandolar",
    "girandolarias": "girandolar",
    "girandolarmo": "girandolar",
    "girandolarmos": "girandolar",
    "girandolará": "girandolar",
    "girandolarás": "girandolar",
    "girandolarão": "girandolar",
    "girandolaríamos": "girandolar",
    "girandolaríeis": "girandolar",
    "girandolas": "girandolar",
    "girandolasse": "girandolar",
    "girandolassem": "girandolar",
    "girandolasses": "girandolar",
    "girandolaste": "girandolar",
    "girandolastes": "girandolar",
    "girandolava": "girandolar",
    "girandolavam": "girandolar",
    "girandolavas": "girandolar",
    "girandole": "girandolar",
    "girandolei": "girandolar",
    "girandoleis": "girandolar",
    "girandolem": "girandolar",
    "girandolemo": "girandolar",
    "girandolemos": "girandolar",
    "girandoles": "girandolar",
    "girandolo": "girandolar",
    "girandolou": "girandolar",
    "girandolá": "girandolar",
    "girandolámo": "girandolar",
    "girandolámos": "girandolar",
    "girandoláramo": "girandolar",
    "girandoláramos": "girandolar",
    "girandolárei": "girandolar",
    "girandoláreis": "girandolar",
    "girandolásseis": "girandolar",
    "girandolássemos": "girandolar",
    "girandolávamo": "girandolar",
    "girandolávamos": "girandolar",
    "girandolávei": "girandolar",
    "girandoláveis": "girandolar",
    "girantes": "girante",
    "girara": "girar",
    "giraram": "girar",
    "giraras": "girar",
    "girardes": "girar",
    "girarei": "girar",
    "girareis": "girar",
    "girarem": "girar",
    "giraremos": "girar",
    "girares": "girar",
    "giraria": "girar",
    "girariam": "girar",
    "girarias": "girar",
    "girarmo": "girar",
    "girarmos": "girar",
    "girará": "girar",
    "girarás": "girar",
    "girarão": "girar",
    "giraríamos": "girar",
    "giraríeis": "girar",
    "giras": "giro",
    "girasse": "girar",
    "girassem": "girar",
    "girasses": "girar",
    "girassóis": "girassol",
    "giraste": "girar",
    "girastes": "girar",
    "giratas": "girata",
    "giratória": "giratório",
    "giratórias": "giratório",
    "giratórios": "giratório",
    "girava": "girar",
    "giravam": "girar",
    "giravas": "girar",
    "giravoltas": "giravolta",
    "girações": "giração",
    "gire": "girar",
    "girei": "girar",
    "gireis": "girar",
    "girem": "girar",
    "giremo": "girar",
    "giremos": "girar",
    "gires": "girar",
    "girgolinas": "girgolina",
    "girigotes": "girigote",
    "girinos": "girino",
    "girls": "girl",
    "giro": "girar",
    "girofles": "girofle",
    "giromagnetismos": "giromagnetismo",
    "giromagnética": "giromagnético",
    "giromagnéticas": "giromagnético",
    "giromagnéticos": "giromagnético",
    "giromancias": "giromancia",
    "giromantes": "giromante",
    "girometrias": "girometria",
    "giromântica": "giromântico",
    "giromânticas": "giromântico",
    "giromânticos": "giromântico",
    "girométrica": "girométrico",
    "girométricas": "girométrico",
    "girométricos": "girométrico",
    "girondas": "gironda",
    "girondina": "girondino",
    "girondinas": "girondino",
    "girondinos": "girondino",
    "giropilotos": "giropiloto",
    "giroplanos": "giroplano",
    "giros": "giro",
    "giroscopias": "giroscopia",
    "giroscopismos": "giroscopismo",
    "giroscópica": "giroscópico",
    "giroscópicas": "giroscópico",
    "giroscópicos": "giroscópico",
    "giroscópios": "giroscópio",
    "giroselas": "girosela",
    "girostática": "girostático",
    "girostáticas": "girostático",
    "girostáticos": "girostático",
    "girota": "girote",
    "girotas": "girote",
    "girotes": "girote",
    "girou": "girar",
    "giráfidas": "giráfida",
    "girámo": "girar",
    "girámos": "girar",
    "giráramo": "girar",
    "giráramos": "girar",
    "giráreis": "girar",
    "girásseis": "girar",
    "girássemos": "girar",
    "girávamo": "girar",
    "girávamos": "girar",
    "giráveis": "girar",
    "girândolas": "girândola",
    "girómetros": "girómetro",
    "giróstatos": "giróstato",
    "girões": "girão",
    "gisnada": "gisnado",
    "gisnadas": "gisnado",
    "gisnados": "gisnado",
    "gitana": "gitano",
    "gitanas": "gitano",
    "gitanos": "gitano",
    "givetiana": "givetiano",
    "givetianas": "givetiano",
    "givetianos": "givetiano",
    "giza": "gizar",
    "gizada": "gizar",
    "gizadas": "gizar",
    "gizado": "gizar",
    "gizados": "gizar",
    "gizai": "gizar",
    "gizais": "gizar",
    "gizam": "gizar",
    "gizamentos": "gizamento",
    "gizamo": "gizar",
    "gizamos": "gizar",
    "gizando": "gizar",
    "gizara": "gizar",
    "gizaram": "gizar",
    "gizaras": "gizar",
    "gizarde": "gizar",
    "gizardes": "gizar",
    "gizare": "gizar",
    "gizarei": "gizar",
    "gizareis": "gizar",
    "gizarem": "gizar",
    "gizaremos": "gizar",
    "gizares": "gizar",
    "gizaria": "gizar",
    "gizariam": "gizar",
    "gizarias": "gizar",
    "gizarmo": "gizar",
    "gizarmos": "gizar",
    "gizará": "gizar",
    "gizarás": "gizar",
    "gizarão": "gizar",
    "gizaríamos": "gizar",
    "gizaríeis": "gizar",
    "gizas": "gizar",
    "gizasse": "gizar",
    "gizassem": "gizar",
    "gizasses": "gizar",
    "gizaste": "gizar",
    "gizastes": "gizar",
    "gizava": "gizar",
    "gizavam": "gizar",
    "gizavas": "gizar",
    "gize": "gizar",
    "gizei": "gizar",
    "gizeis": "gizar",
    "gizem": "gizar",
    "gizemo": "gizar",
    "gizemos": "gizar",
    "gizes": "gizar",
    "gizo": "gizar",
    "gizou": "gizar",
    "gizá": "gizar",
    "gizámo": "gizar",
    "gizámos": "gizar",
    "gizáramo": "gizar",
    "gizáramos": "gizar",
    "gizárei": "gizar",
    "gizáreis": "gizar",
    "gizásseis": "gizar",
    "gizássemos": "gizar",
    "gizávamo": "gizar",
    "gizávamos": "gizar",
    "gizávei": "gizar",
    "gizáveis": "gizável",
    "giárdias": "giárdia",
    "glabelares": "glabelar",
    "glabelas": "glabela",
    "glabra": "glabro",
    "glabras": "glabro",
    "glabrescentes": "glabrescente",
    "glabrismos": "glabrismo",
    "glabriúscula": "glabriúsculo",
    "glabriúsculas": "glabriúsculo",
    "glabriúsculos": "glabriúsculo",
    "glabros": "glabro",
    "glabrítica": "glabrítico",
    "glabríticas": "glabrítico",
    "glabríticos": "glabrítico",
    "glaciais": "glacial",
    "glaciares": "glaciar",
    "glaciaristas": "glaciarista",
    "glaciações": "glaciação",
    "glaciologias": "glaciologia",
    "glaciologistas": "glaciologista",
    "glaciológica": "glaciológico",
    "glaciológicas": "glaciológico",
    "glaciológicos": "glaciológico",
    "glaciária": "glaciário",
    "glaciárias": "glaciário",
    "glaciários": "glaciário",
    "glacióloga": "glaciólogo",
    "glaciólogas": "glaciólogo",
    "glaciólogos": "glaciólogo",
    "glacês": "glacê",
    "gladia": "gladiar",
    "gladiada": "gladiar",
    "gladiadas": "gladiar",
    "gladiado": "gladiar",
    "gladiadora": "gladiador",
    "gladiadoras": "gladiador",
    "gladiadores": "gladiador",
    "gladiados": "gladiar",
    "gladiai": "gladiar",
    "gladiais": "gladiar",
    "gladiam": "gladiar",
    "gladiamo": "gladiar",
    "gladiamos": "gladiar",
    "gladiando": "gladiar",
    "gladiara": "gladiar",
    "gladiaram": "gladiar",
    "gladiaras": "gladiar",
    "gladiarde": "gladiar",
    "gladiardes": "gladiar",
    "gladiare": "gladiar",
    "gladiarei": "gladiar",
    "gladiareis": "gladiar",
    "gladiarem": "gladiar",
    "gladiaremos": "gladiar",
    "gladiares": "gladiar",
    "gladiaria": "gladiar",
    "gladiariam": "gladiar",
    "gladiarias": "gladiar",
    "gladiarmo": "gladiar",
    "gladiarmos": "gladiar",
    "gladiará": "gladiar",
    "gladiarás": "gladiar",
    "gladiarão": "gladiar",
    "gladiaríamos": "gladiar",
    "gladiaríeis": "gladiar",
    "gladias": "gladiar",
    "gladiasse": "gladiar",
    "gladiassem": "gladiar",
    "gladiasses": "gladiar",
    "gladiaste": "gladiar",
    "gladiastes": "gladiar",
    "gladiaturas": "gladiatura",
    "gladiatória": "gladiatório",
    "gladiatórias": "gladiatório",
    "gladiatórios": "gladiatório",
    "gladiava": "gladiar",
    "gladiavam": "gladiar",
    "gladiavas": "gladiar",
    "gladie": "gladiar",
    "gladiei": "gladiar",
    "gladieis": "gladiar",
    "gladiem": "gladiar",
    "gladiemo": "gladiar",
    "gladiemos": "gladiar",
    "gladies": "gladiar",
    "gladiformes": "gladiforme",
    "gladio": "gladiar",
    "gladiou": "gladiar",
    "gladiá": "gladiar",
    "gladiámo": "gladiar",
    "gladiámos": "gladiar",
    "gladiáramo": "gladiar",
    "gladiáramos": "gladiar",
    "gladiárei": "gladiar",
    "gladiáreis": "gladiar",
    "gladiásseis": "gladiar",
    "gladiássemos": "gladiar",
    "gladiávamo": "gladiar",
    "gladiávamos": "gladiar",
    "gladiávei": "gladiar",
    "gladiáveis": "gladiar",
    "gladífera": "gladífero",
    "gladíferas": "gladífero",
    "gladíferos": "gladífero",
    "gladíolos": "gladíolo",
    "glagolítica": "glagolítico",
    "glagolíticas": "glagolítico",
    "glagolíticos": "glagolítico",
    "glaiadinas": "glaiadina",
    "glamorosa": "glamoroso",
    "glamorosas": "glamoroso",
    "glamorosos": "glamoroso",
    "glamours": "glamour",
    "glandes": "glande",
    "glandiformes": "glandiforme",
    "glandulares": "glandular",
    "glandulações": "glandulação",
    "glandulosa": "glanduloso",
    "glandulosas": "glanduloso",
    "glandulosos": "glanduloso",
    "glandulífera": "glandulífero",
    "glandulíferas": "glandulífero",
    "glandulíferos": "glandulífero",
    "glandífera": "glandífero",
    "glandíferas": "glandífero",
    "glandíferos": "glandífero",
    "glandívora": "glandívoro",
    "glandívoras": "glandívoro",
    "glandívoros": "glandívoro",
    "glauca": "glauco",
    "glaucas": "glauco",
    "glaucofila": "glaucofilo",
    "glaucofilas": "glaucofilo",
    "glaucofilos": "glaucofilo",
    "glaucomadosa": "glaucomadoso",
    "glaucomadosas": "glaucomadoso",
    "glaucomadosos": "glaucomadoso",
    "glaucomas": "glaucoma",
    "glauconites": "glauconite",
    "glauconítica": "glauconítico",
    "glauconíticas": "glauconítico",
    "glauconíticos": "glauconítico",
    "glaucos": "glauco",
    "glaucófanos": "glaucófano",
    "glaucófila": "glaucófilo",
    "glaucófilas": "glaucófilo",
    "glaucófilos": "glaucófilo",
    "glebas": "gleba",
    "glenodinas": "glenodina",
    "glenoidais": "glenoidal",
    "glenoideia": "glenoideu",
    "glenoideias": "glenoideu",
    "glenoideus": "glenoideu",
    "glenóidea": "glenóideo",
    "glenóideas": "glenóideo",
    "glenóideos": "glenóideo",
    "glenóides": "glenóide",
    "gleucométrica": "gleucométrico",
    "gleucométricas": "gleucométrico",
    "gleucométricos": "gleucométrico",
    "gleucómetros": "gleucómetro",
    "gliadinas": "gliadina",
    "gliadínica": "gliadínico",
    "gliadínicas": "gliadínico",
    "gliadínicos": "gliadínico",
    "glicecogénica": "glicecogénico",
    "glicecogénicas": "glicecogénico",
    "glicecogénicos": "glicecogénico",
    "glicemias": "glicemia",
    "glicerana": "glicerano",
    "gliceranas": "glicerano",
    "gliceranos": "glicerano",
    "gliceratos": "glicerato",
    "glicerenses": "glicerense",
    "glicerilos": "glicerilo",
    "glicerinas": "glicerina",
    "glicerosfofatos": "glicerosfofato",
    "glicerosfosfática": "glicerosfosfático",
    "glicerosfosfáticas": "glicerosfosfático",
    "glicerosfosfáticos": "glicerosfosfático",
    "glicerosfosfórica": "glicerosfosfórico",
    "glicerosfosfóricas": "glicerosfosfórico",
    "glicerosfosfóricos": "glicerosfosfórico",
    "glicerínica": "glicerínico",
    "glicerínicas": "glicerínico",
    "glicerínicos": "glicerínico",
    "gliceróis": "glicerol",
    "gliceróleos": "gliceróleo",
    "glicinas": "glicina",
    "glicocolas": "glicocola",
    "glicogenias": "glicogenia",
    "glicogéneses": "glicogénese",
    "glicogénios": "glicogénio",
    "glicométrica": "glicométrico",
    "glicométricas": "glicométrico",
    "glicométricos": "glicométrico",
    "glicoses": "glicose",
    "glicosurias": "glicosuria",
    "glicosúrias": "glicosúria",
    "glicosúrica": "glicosúrico",
    "glicosúricas": "glicosúrico",
    "glicosúricos": "glicosúrico",
    "glicémica": "glicémico",
    "glicémicas": "glicémico",
    "glicémicos": "glicémico",
    "glicérea": "glicéreo",
    "glicéreas": "glicéreo",
    "glicéreos": "glicéreo",
    "glicérias": "glicéria",
    "glicérica": "glicérico",
    "glicéricas": "glicérico",
    "glicéricos": "glicérico",
    "glicérida": "glicérido",
    "glicéridas": "glicérido",
    "glicéridos": "glicérido",
    "glicídios": "glicídio",
    "glicínias": "glicínia",
    "glicínios": "glicínio",
    "glicóis": "glicol",
    "glicólises": "glicólise",
    "glicómetros": "glicómetro",
    "glicónica": "glicónico",
    "glicónicas": "glicónico",
    "glicónicos": "glicónico",
    "glicósica": "glicósico",
    "glicósicas": "glicósico",
    "glicósicos": "glicósico",
    "glicósidos": "glicósido",
    "glicótica": "glicótico",
    "glicóticas": "glicótico",
    "glicóticos": "glicótico",
    "glifos": "glifo",
    "gliomas": "glioma",
    "glioxais": "glioxal",
    "gliptodontes": "gliptodonte",
    "gliptogenésica": "gliptogenésico",
    "gliptogenésicas": "gliptogenésico",
    "gliptogenésicos": "gliptogenésico",
    "gliptogenética": "gliptogenético",
    "gliptogenéticas": "gliptogenético",
    "gliptogenéticos": "gliptogenético",
    "gliptognosias": "gliptognosia",
    "gliptognosistas": "gliptognosista",
    "gliptognósica": "gliptognósico",
    "gliptognósicas": "gliptognósico",
    "gliptognósicos": "gliptognósico",
    "gliptognóstica": "gliptognóstico",
    "gliptognósticas": "gliptognóstico",
    "gliptognósticos": "gliptognóstico",
    "gliptografias": "gliptografia",
    "gliptográfica": "gliptográfico",
    "gliptográficas": "gliptográfico",
    "gliptográficos": "gliptográfico",
    "gliptogéneses": "gliptogénese",
    "gliptogénica": "gliptogénico",
    "gliptogénicas": "gliptogénico",
    "gliptogénicos": "gliptogénico",
    "gliptologias": "gliptologia",
    "gliptologistas": "gliptologista",
    "gliptológica": "gliptológico",
    "gliptológicas": "gliptológico",
    "gliptológicos": "gliptológico",
    "gliptíca": "gliptíco",
    "gliptícas": "gliptíco",
    "gliptícos": "gliptíco",
    "gliptóloga": "gliptólogo",
    "gliptólogas": "gliptólogo",
    "gliptólogos": "gliptólogo",
    "glissandos": "glissando",
    "globais": "global",
    "globalidades": "globalidade",
    "globalismos": "globalismo",
    "globaliza": "globalizar",
    "globalizada": "globalizar",
    "globalizadas": "globalizar",
    "globalizado": "globalizar",
    "globalizados": "globalizar",
    "globalizai": "globalizar",
    "globalizais": "globalizar",
    "globalizam": "globalizar",
    "globalizamo": "globalizar",
    "globalizamos": "globalizar",
    "globalizando": "globalizar",
    "globalizantes": "globalizante",
    "globalizara": "globalizar",
    "globalizaram": "globalizar",
    "globalizaras": "globalizar",
    "globalizarde": "globalizar",
    "globalizardes": "globalizar",
    "globalizare": "globalizar",
    "globalizarei": "globalizar",
    "globalizareis": "globalizar",
    "globalizarem": "globalizar",
    "globalizaremos": "globalizar",
    "globalizares": "globalizar",
    "globalizaria": "globalizar",
    "globalizariam": "globalizar",
    "globalizarias": "globalizar",
    "globalizarmo": "globalizar",
    "globalizarmos": "globalizar",
    "globalizará": "globalizar",
    "globalizarás": "globalizar",
    "globalizarão": "globalizar",
    "globalizaríamos": "globalizar",
    "globalizaríeis": "globalizar",
    "globalizas": "globalizar",
    "globalizasse": "globalizar",
    "globalizassem": "globalizar",
    "globalizasses": "globalizar",
    "globalizaste": "globalizar",
    "globalizastes": "globalizar",
    "globalizava": "globalizar",
    "globalizavam": "globalizar",
    "globalizavas": "globalizar",
    "globalizações": "globalização",
    "globalize": "globalizar",
    "globalizei": "globalizar",
    "globalizeis": "globalizar",
    "globalizem": "globalizar",
    "globalizemo": "globalizar",
    "globalizemos": "globalizar",
    "globalizes": "globalizar",
    "globalizo": "globalizar",
    "globalizou": "globalizar",
    "globalizá": "globalizar",
    "globalizámo": "globalizar",
    "globalizámos": "globalizar",
    "globalizáramo": "globalizar",
    "globalizáramos": "globalizar",
    "globalizárei": "globalizar",
    "globalizáreis": "globalizar",
    "globalizásseis": "globalizar",
    "globalizássemos": "globalizar",
    "globalizávamo": "globalizar",
    "globalizávamos": "globalizar",
    "globalizávei": "globalizar",
    "globalizáveis": "globalizar",
    "globalística": "globalístico",
    "globalísticas": "globalístico",
    "globalísticos": "globalístico",
    "globiflora": "globifloro",
    "globifloras": "globifloro",
    "globifloros": "globifloro",
    "globiformes": "globiforme",
    "globigerinas": "globigerina",
    "globinas": "globina",
    "globos": "globo",
    "globosa": "globoso",
    "globosas": "globoso",
    "globosidades": "globosidade",
    "globosos": "globoso",
    "globulares": "globular",
    "globulareácea": "globulareáceo",
    "globulareáceas": "globulareáceo",
    "globulareáceos": "globulareáceo",
    "globulariáceas": "globulariácea",
    "globulinas": "globulina",
    "globulitos": "globulito",
    "globulosa": "globuloso",
    "globulosas": "globuloso",
    "globulosos": "globuloso",
    "globífera": "globífero",
    "globíferas": "globífero",
    "globíferos": "globífero",
    "glomera": "glomerar",
    "glomerada": "glomerar",
    "glomeradas": "glomerar",
    "glomerado": "glomerar",
    "glomerados": "glomerar",
    "glomerai": "glomerar",
    "glomerais": "glomerar",
    "glomeram": "glomerar",
    "glomeramo": "glomerar",
    "glomeramos": "glomerar",
    "glomerando": "glomerar",
    "glomerara": "glomerar",
    "glomeraram": "glomerar",
    "glomeraras": "glomerar",
    "glomerarde": "glomerar",
    "glomerardes": "glomerar",
    "glomerare": "glomerar",
    "glomerarei": "glomerar",
    "glomerareis": "glomerar",
    "glomerarem": "glomerar",
    "glomeraremos": "glomerar",
    "glomerares": "glomerar",
    "glomeraria": "glomerar",
    "glomerariam": "glomerar",
    "glomerarias": "glomerar",
    "glomerarmo": "glomerar",
    "glomerarmos": "glomerar",
    "glomerará": "glomerar",
    "glomerarás": "glomerar",
    "glomerarão": "glomerar",
    "glomeraríamos": "glomerar",
    "glomeraríeis": "glomerar",
    "glomeras": "glomerar",
    "glomerasse": "glomerar",
    "glomerassem": "glomerar",
    "glomerasses": "glomerar",
    "glomeraste": "glomerar",
    "glomerastes": "glomerar",
    "glomerava": "glomerar",
    "glomeravam": "glomerar",
    "glomeravas": "glomerar",
    "glomere": "glomerar",
    "glomerei": "glomerar",
    "glomereis": "glomerar",
    "glomerem": "glomerar",
    "glomeremo": "glomerar",
    "glomeremos": "glomerar",
    "glomeres": "glomerar",
    "glomero": "glomerar",
    "glomerou": "glomerar",
    "glomerulares": "glomerular",
    "glomerulites": "glomerulite",
    "glomerá": "glomerar",
    "glomerámo": "glomerar",
    "glomerámos": "glomerar",
    "glomeráramo": "glomerar",
    "glomeráramos": "glomerar",
    "glomerárei": "glomerar",
    "glomeráreis": "glomerar",
    "glomerásseis": "glomerar",
    "glomerássemos": "glomerar",
    "glomerávamo": "glomerar",
    "glomerávamos": "glomerar",
    "glomerávei": "glomerar",
    "glomeráveis": "glomerar",
    "glomos": "glomo",
    "glomérulos": "glomérulo",
    "gloria": "gloriar",
    "gloriada": "gloriar",
    "gloriadas": "gloriar",
    "gloriado": "gloriar",
    "gloriados": "gloriar",
    "gloriai": "gloriar",
    "gloriais": "gloriar",
    "gloriam": "gloriar",
    "gloriamo": "gloriar",
    "gloriamos": "gloriar",
    "gloriando": "gloriar",
    "gloriara": "gloriar",
    "gloriaram": "gloriar",
    "gloriaras": "gloriar",
    "gloriarde": "gloriar",
    "gloriardes": "gloriar",
    "gloriare": "gloriar",
    "gloriarei": "gloriar",
    "gloriareis": "gloriar",
    "gloriarem": "gloriar",
    "gloriaremos": "gloriar",
    "gloriares": "gloriar",
    "gloriaria": "gloriar",
    "gloriariam": "gloriar",
    "gloriarias": "gloriar",
    "gloriarmo": "gloriar",
    "gloriarmos": "gloriar",
    "gloriará": "gloriar",
    "gloriarás": "gloriar",
    "gloriarão": "gloriar",
    "gloriaríamos": "gloriar",
    "gloriaríeis": "gloriar",
    "glorias": "gloriar",
    "gloriasse": "gloriar",
    "gloriassem": "gloriar",
    "gloriasses": "gloriar",
    "gloriaste": "gloriar",
    "gloriastes": "gloriar",
    "gloriava": "gloriar",
    "gloriavam": "gloriar",
    "gloriavas": "gloriar",
    "glorie": "gloriar",
    "gloriei": "gloriar",
    "glorieis": "gloriar",
    "gloriem": "gloriar",
    "gloriemo": "gloriar",
    "gloriemos": "gloriar",
    "glorienses": "gloriense",
    "glories": "gloriar",
    "glorifica": "glorificar",
    "glorificada": "glorificar",
    "glorificadas": "glorificar",
    "glorificado": "glorificar",
    "glorificadora": "glorificador",
    "glorificadoras": "glorificador",
    "glorificadores": "glorificador",
    "glorificados": "glorificar",
    "glorificai": "glorificar",
    "glorificais": "glorificar",
    "glorificam": "glorificar",
    "glorificamo": "glorificar",
    "glorificamos": "glorificar",
    "glorificando": "glorificar",
    "glorificantes": "glorificante",
    "glorificara": "glorificar",
    "glorificaram": "glorificar",
    "glorificaras": "glorificar",
    "glorificarde": "glorificar",
    "glorificardes": "glorificar",
    "glorificare": "glorificar",
    "glorificarei": "glorificar",
    "glorificareis": "glorificar",
    "glorificarem": "glorificar",
    "glorificaremos": "glorificar",
    "glorificares": "glorificar",
    "glorificaria": "glorificar",
    "glorificariam": "glorificar",
    "glorificarias": "glorificar",
    "glorificarmo": "glorificar",
    "glorificarmos": "glorificar",
    "glorificará": "glorificar",
    "glorificarás": "glorificar",
    "glorificarão": "glorificar",
    "glorificaríamos": "glorificar",
    "glorificaríeis": "glorificar",
    "glorificas": "glorificar",
    "glorificasse": "glorificar",
    "glorificassem": "glorificar",
    "glorificasses": "glorificar",
    "glorificaste": "glorificar",
    "glorificastes": "glorificar",
    "glorificava": "glorificar",
    "glorificavam": "glorificar",
    "glorificavas": "glorificar",
    "glorificações": "glorificação",
    "glorifico": "glorificar",
    "glorificou": "glorificar",
    "glorificá": "glorificar",
    "glorificámo": "glorificar",
    "glorificámos": "glorificar",
    "glorificáramo": "glorificar",
    "glorificáramos": "glorificar",
    "glorificárei": "glorificar",
    "glorificáreis": "glorificar",
    "glorificásseis": "glorificar",
    "glorificássemos": "glorificar",
    "glorificávamo": "glorificar",
    "glorificávamos": "glorificar",
    "glorificávei": "glorificar",
    "glorificáveis": "glorificável",
    "glorifique": "glorificar",
    "glorifiquei": "glorificar",
    "glorifiqueis": "glorificar",
    "glorifiquem": "glorificar",
    "glorifiquemo": "glorificar",
    "glorifiquemos": "glorificar",
    "glorifiques": "glorificar",
    "glorio": "gloriar",
    "gloriosa": "glorioso",
    "gloriosas": "glorioso",
    "gloriosos": "glorioso",
    "gloriou": "gloriar",
    "gloriá": "gloriar",
    "gloriámo": "gloriar",
    "gloriámos": "gloriar",
    "gloriáramo": "gloriar",
    "gloriáramos": "gloriar",
    "gloriárei": "gloriar",
    "gloriáreis": "gloriar",
    "gloriásseis": "gloriar",
    "gloriássemos": "gloriar",
    "gloriávamo": "gloriar",
    "gloriávamos": "gloriar",
    "gloriávei": "gloriar",
    "gloriáveis": "gloriar",
    "gloríolas": "gloríola",
    "glosa": "glosar",
    "glosada": "glosar",
    "glosadas": "glosar",
    "glosado": "glosar",
    "glosadora": "glosador",
    "glosadoras": "glosador",
    "glosadores": "glosador",
    "glosados": "glosar",
    "glosai": "glosar",
    "glosais": "glosar",
    "glosam": "glosar",
    "glosamo": "glosar",
    "glosamos": "glosar",
    "glosando": "glosar",
    "glosara": "glosar",
    "glosaram": "glosar",
    "glosaras": "glosar",
    "glosarde": "glosar",
    "glosardes": "glosar",
    "glosare": "glosar",
    "glosarei": "glosar",
    "glosareis": "glosar",
    "glosarem": "glosar",
    "glosaremos": "glosar",
    "glosares": "glosar",
    "glosaria": "glosar",
    "glosariam": "glosar",
    "glosarias": "glosar",
    "glosarmo": "glosar",
    "glosarmos": "glosar",
    "glosará": "glosar",
    "glosarás": "glosar",
    "glosarão": "glosar",
    "glosaríamos": "glosar",
    "glosaríeis": "glosar",
    "glosas": "glosar",
    "glosasse": "glosar",
    "glosassem": "glosar",
    "glosasses": "glosar",
    "glosaste": "glosar",
    "glosastes": "glosar",
    "glosava": "glosar",
    "glosavam": "glosar",
    "glosavas": "glosar",
    "glose": "glosar",
    "glosei": "glosar",
    "gloseis": "glosar",
    "glosem": "glosar",
    "glosemo": "glosar",
    "glosemos": "glosar",
    "gloses": "glosar",
    "gloso": "glosar",
    "glosou": "glosar",
    "glossados": "glossado",
    "glossalgias": "glossalgia",
    "glossantrazes": "glossantraz",
    "glossaristas": "glossarista",
    "glossas": "glossa",
    "glossemas": "glossema",
    "glossemáticas": "glossemática",
    "glossiana": "glossiano",
    "glossianas": "glossiano",
    "glossianos": "glossiano",
    "glossinas": "glossina",
    "glossites": "glossite",
    "glossodontes": "glossodonte",
    "glossodínias": "glossodínia",
    "glossodínica": "glossodínico",
    "glossodínicas": "glossodínico",
    "glossodínicos": "glossodínico",
    "glossofaríngea": "glossofaríngeo",
    "glossofaríngeas": "glossofaríngeo",
    "glossofaríngeos": "glossofaríngeo",
    "glossofaríngica": "glossofaríngico",
    "glossofaríngicas": "glossofaríngico",
    "glossofaríngicos": "glossofaríngico",
    "glossografias": "glossografia",
    "glossográfica": "glossográfico",
    "glossográficas": "glossográfico",
    "glossográficos": "glossográfico",
    "glossolalias": "glossolalia",
    "glossologias": "glossologia",
    "glossologistas": "glossologista",
    "glossolálica": "glossolálico",
    "glossolálicas": "glossolálico",
    "glossolálicos": "glossolálico",
    "glossológica": "glossológico",
    "glossológicas": "glossológico",
    "glossológicos": "glossológico",
    "glossomanias": "glossomania",
    "glossomantes": "glossomante",
    "glossomaníaca": "glossomaníaco",
    "glossomaníacas": "glossomaníaco",
    "glossomaníacos": "glossomaníaco",
    "glossoplegias": "glossoplegia",
    "glossoplégica": "glossoplégico",
    "glossoplégicas": "glossoplégico",
    "glossoplégicos": "glossoplégico",
    "glossotomias": "glossotomia",
    "glossotómica": "glossotómico",
    "glossotómicas": "glossotómico",
    "glossotómicos": "glossotómico",
    "glossálgica": "glossálgico",
    "glossálgicas": "glossálgico",
    "glossálgicos": "glossálgico",
    "glossários": "glossário",
    "glossógrafa": "glossógrafo",
    "glossógrafas": "glossógrafo",
    "glossógrafos": "glossógrafo",
    "glossóides": "glossóide",
    "glossóloga": "glossólogo",
    "glossólogas": "glossólogo",
    "glossólogos": "glossólogo",
    "glossómana": "glossómano",
    "glossómanas": "glossómano",
    "glossómanos": "glossómano",
    "glossótomos": "glossótomo",
    "glosá": "glosar",
    "glosámo": "glosar",
    "glosámos": "glosar",
    "glosáramo": "glosar",
    "glosáramos": "glosar",
    "glosárei": "glosar",
    "glosáreis": "glosar",
    "glosásseis": "glosar",
    "glosássemos": "glosar",
    "glosávamo": "glosar",
    "glosávamos": "glosar",
    "glosávei": "glosar",
    "glosáveis": "glosável",
    "glotes": "glote",
    "gloticologias": "gloticologia",
    "gloticologistas": "gloticologista",
    "gloticóloga": "gloticólogo",
    "gloticólogas": "gloticólogo",
    "gloticólogos": "gloticólogo",
    "glotiologias": "glotiologia",
    "glotiologistas": "glotiologista",
    "glotites": "glotite",
    "glotologias": "glotologia",
    "glotologistas": "glotologista",
    "glotológica": "glotológico",
    "glotológicas": "glotológico",
    "glotológicos": "glotológico",
    "glotora": "glotorar",
    "glotorada": "glotorar",
    "glotoradas": "glotorar",
    "glotorado": "glotorar",
    "glotorados": "glotorar",
    "glotorai": "glotorar",
    "glotorais": "glotorar",
    "glotoram": "glotorar",
    "glotoramo": "glotorar",
    "glotoramos": "glotorar",
    "glotorando": "glotorar",
    "glotorara": "glotorar",
    "glotoraram": "glotorar",
    "glotoraras": "glotorar",
    "glotorardes": "glotorar",
    "glotorarei": "glotorar",
    "glotorareis": "glotorar",
    "glotorarem": "glotorar",
    "glotoraremos": "glotorar",
    "glotorares": "glotorar",
    "glotoraria": "glotorar",
    "glotorariam": "glotorar",
    "glotorarias": "glotorar",
    "glotorarmo": "glotorar",
    "glotorarmos": "glotorar",
    "glotorará": "glotorar",
    "glotorarás": "glotorar",
    "glotorarão": "glotorar",
    "glotoraríamos": "glotorar",
    "glotoraríeis": "glotorar",
    "glotoras": "glotorar",
    "glotorasse": "glotorar",
    "glotorassem": "glotorar",
    "glotorasses": "glotorar",
    "glotoraste": "glotorar",
    "glotorastes": "glotorar",
    "glotorava": "glotorar",
    "glotoravam": "glotorar",
    "glotoravas": "glotorar",
    "glotore": "glotorar",
    "glotorei": "glotorar",
    "glotoreis": "glotorar",
    "glotorem": "glotorar",
    "glotoremo": "glotorar",
    "glotoremos": "glotorar",
    "glotores": "glotorar",
    "glotoro": "glotorar",
    "glotorou": "glotorar",
    "glotorámo": "glotorar",
    "glotorámos": "glotorar",
    "glotoráramo": "glotorar",
    "glotoráramos": "glotorar",
    "glotoráreis": "glotorar",
    "glotorásseis": "glotorar",
    "glotorássemos": "glotorar",
    "glotorávamo": "glotorar",
    "glotorávamos": "glotorar",
    "glotoráveis": "glotorar",
    "glotítica": "glotítico",
    "glotíticas": "glotítico",
    "glotíticos": "glotítico",
    "glotóloga": "glotólogo",
    "glotólogas": "glotólogo",
    "glotólogos": "glotólogo",
    "gloxímias": "gloxímia",
    "glucanases": "glucanase",
    "glucosídios": "glucosídio",
    "glucídios": "glucídio",
    "gluglus": "gluglu",
    "glumas": "gluma",
    "glumelas": "glumela",
    "glumácea": "glumáceo",
    "glumáceas": "glumáceo",
    "glumáceos": "glumáceo",
    "glutamatos": "glutamato",
    "glutens": "glúten",
    "gluteínas": "gluteína",
    "gluteínica": "gluteínico",
    "gluteínicas": "gluteínico",
    "gluteínicos": "gluteínico",
    "glutina": "glutinar",
    "glutinada": "glutinar",
    "glutinadas": "glutinar",
    "glutinado": "glutinar",
    "glutinados": "glutinar",
    "glutinai": "glutinar",
    "glutinais": "glutinar",
    "glutinam": "glutinar",
    "glutinamo": "glutinar",
    "glutinamos": "glutinar",
    "glutinando": "glutinar",
    "glutinara": "glutinar",
    "glutinaram": "glutinar",
    "glutinaras": "glutinar",
    "glutinarde": "glutinar",
    "glutinardes": "glutinar",
    "glutinare": "glutinar",
    "glutinarei": "glutinar",
    "glutinareis": "glutinar",
    "glutinarem": "glutinar",
    "glutinaremos": "glutinar",
    "glutinares": "glutinar",
    "glutinaria": "glutinar",
    "glutinariam": "glutinar",
    "glutinarias": "glutinar",
    "glutinarmo": "glutinar",
    "glutinarmos": "glutinar",
    "glutinará": "glutinar",
    "glutinarás": "glutinar",
    "glutinarão": "glutinar",
    "glutinaríamos": "glutinar",
    "glutinaríeis": "glutinar",
    "glutinas": "glutinar",
    "glutinasse": "glutinar",
    "glutinassem": "glutinar",
    "glutinasses": "glutinar",
    "glutinaste": "glutinar",
    "glutinastes": "glutinar",
    "glutinativa": "glutinativo",
    "glutinativas": "glutinativo",
    "glutinativos": "glutinativo",
    "glutinava": "glutinar",
    "glutinavam": "glutinar",
    "glutinavas": "glutinar",
    "glutine": "glutinar",
    "glutinei": "glutinar",
    "glutineis": "glutinar",
    "glutinem": "glutinar",
    "glutinemo": "glutinar",
    "glutinemos": "glutinar",
    "glutines": "glutinar",
    "glutino": "glutinar",
    "glutinosa": "glutinoso",
    "glutinosas": "glutinoso",
    "glutinosidades": "glutinosidade",
    "glutinosos": "glutinoso",
    "glutinou": "glutinar",
    "glutiná": "glutinar",
    "glutinámo": "glutinar",
    "glutinámos": "glutinar",
    "glutináramo": "glutinar",
    "glutináramos": "glutinar",
    "glutinárei": "glutinar",
    "glutináreis": "glutinar",
    "glutinásseis": "glutinar",
    "glutinássemos": "glutinar",
    "glutinávamo": "glutinar",
    "glutinávamos": "glutinar",
    "glutinávei": "glutinar",
    "glutináveis": "glutinar",
    "glutona": "glutão",
    "glutonarias": "glutonaria",
    "glutonas": "glutão",
    "glutâmica": "glutâmico",
    "glutâmicas": "glutâmico",
    "glutâmicos": "glutâmico",
    "glutónica": "glutónico",
    "glutónicas": "glutónico",
    "glutónicos": "glutónico",
    "glutões": "glutão",
    "gládios": "gládio",
    "gláucias": "gláucia",
    "gláucica": "gláucico",
    "gláucicas": "gláucico",
    "gláucicos": "gláucico",
    "glândulas": "glândula",
    "glícidos": "glícido",
    "glípticas": "glíptica",
    "glóbulos": "glóbulo",
    "glórias": "glória",
    "glóssica": "glóssico",
    "glóssicas": "glóssico",
    "glóssicos": "glóssico",
    "glótica": "glótico",
    "glóticas": "glótico",
    "glóticos": "glótico",
    "glúcidos": "glúcido",
    "glútea": "glúteo",
    "glúteas": "glúteo",
    "glútenes": "glúten",
    "glúteos": "glúteo",
    "gnaisses": "gnaisse",
    "gnastomados": "gnastomado",
    "gnatalgias": "gnatalgia",
    "gnaticídios": "gnaticídio",
    "gnatodontes": "gnatodonte",
    "gnatácea": "gnatáceo",
    "gnatáceas": "gnatáceo",
    "gnatáceos": "gnatáceo",
    "gnatícia": "gnatício",
    "gnatícias": "gnatício",
    "gnatícios": "gnatício",
    "gneisses": "gneisse",
    "gnetáceas": "gnetácea",
    "gnomas": "gnoma",
    "gnomologias": "gnomologia",
    "gnomologistas": "gnomologista",
    "gnomológica": "gnomológico",
    "gnomológicas": "gnomológico",
    "gnomológicos": "gnomológico",
    "gnomonistas": "gnomonista",
    "gnomos": "gnomo",
    "gnomóloga": "gnomólogo",
    "gnomólogas": "gnomólogo",
    "gnomólogos": "gnomólogo",
    "gnomónica": "gnomónico",
    "gnomónicas": "gnomónico",
    "gnomónicos": "gnomónico",
    "gnoses": "gnose",
    "gnosiologias": "gnosiologia",
    "gnosiologistas": "gnosiologista",
    "gnosiológica": "gnosiológico",
    "gnosiológicas": "gnosiológico",
    "gnosiológicos": "gnosiológico",
    "gnosióloga": "gnosiólogo",
    "gnosiólogas": "gnosiólogo",
    "gnosiólogos": "gnosiólogo",
    "gnosticismos": "gnosticismo",
    "gnus": "gnu",
    "gnómica": "gnómico",
    "gnómicas": "gnómico",
    "gnómicos": "gnómico",
    "gnómones": "gnómon",
    "gnómons": "gnómon",
    "gnósica": "gnósico",
    "gnósicas": "gnósico",
    "gnósicos": "gnósico",
    "gnóstica": "gnóstico",
    "gnósticas": "gnóstico",
    "gnósticos": "gnóstico",
    "goana": "goano",
    "goanas": "goano",
    "goanesa": "goanês",
    "goanesas": "goanês",
    "goaneses": "goanês",
    "goanos": "goano",
    "gobelinos": "gobelino",
    "gobelins": "gobelim",
    "gobiões": "gobião",
    "gobos": "gobo",
    "goches": "goche",
    "goda": "godo",
    "godas": "godo",
    "goderins": "goderim",
    "godilhões": "godilhão",
    "godiões": "godião",
    "godorins": "godorim",
    "godos": "godo",
    "godrins": "godrim",
    "godés": "godé",
    "godês": "godê",
    "godões": "godão",
    "goela": "goelar",
    "goelada": "goelar",
    "goeladas": "goelar",
    "goelado": "goelar",
    "goelados": "goelar",
    "goelai": "goelar",
    "goelais": "goelar",
    "goelam": "goelar",
    "goelamo": "goelar",
    "goelamos": "goelar",
    "goelando": "goelar",
    "goelara": "goelar",
    "goelaram": "goelar",
    "goelaras": "goelar",
    "goelardes": "goelar",
    "goelarei": "goelar",
    "goelareis": "goelar",
    "goelarem": "goelar",
    "goelaremos": "goelar",
    "goelares": "goelar",
    "goelaria": "goelar",
    "goelariam": "goelar",
    "goelarias": "goelar",
    "goelarmo": "goelar",
    "goelarmos": "goelar",
    "goelará": "goelar",
    "goelarás": "goelar",
    "goelarão": "goelar",
    "goelaríamos": "goelar",
    "goelaríeis": "goelar",
    "goelas": "goelar",
    "goelasse": "goelar",
    "goelassem": "goelar",
    "goelasses": "goelar",
    "goelaste": "goelar",
    "goelastes": "goelar",
    "goelava": "goelar",
    "goelavam": "goelar",
    "goelavas": "goelar",
    "goele": "goelar",
    "goelei": "goelar",
    "goeleiras": "goeleira",
    "goeleis": "goelar",
    "goelem": "goelar",
    "goelemo": "goelar",
    "goelemos": "goelar",
    "goeles": "goelar",
    "goelo": "goelar",
    "goelou": "goelar",
    "goelámo": "goelar",
    "goelámos": "goelar",
    "goeláramo": "goelar",
    "goeláramos": "goelar",
    "goeláreis": "goelar",
    "goelásseis": "goelar",
    "goelássemos": "goelar",
    "goelávamo": "goelar",
    "goelávamos": "goelar",
    "goeláveis": "goelar",
    "goenses": "goense",
    "goesa": "goês",
    "goesas": "goês",
    "goeses": "goês",
    "goethiana": "goethiano",
    "goethianas": "goethiano",
    "goethianos": "goethiano",
    "goetites": "goetite",
    "gofos": "gofo",
    "gofra": "gofrar",
    "gofrada": "gofrar",
    "gofradas": "gofrar",
    "gofrado": "gofrar",
    "gofradora": "gofrador",
    "gofradoras": "gofrador",
    "gofradores": "gofrador",
    "gofrados": "gofrar",
    "gofraduras": "gofradura",
    "gofrai": "gofrar",
    "gofrais": "gofrar",
    "gofram": "gofrar",
    "goframo": "gofrar",
    "goframos": "gofrar",
    "gofrando": "gofrar",
    "gofrantes": "gofrante",
    "gofrara": "gofrar",
    "gofraram": "gofrar",
    "gofraras": "gofrar",
    "gofrarde": "gofrar",
    "gofrardes": "gofrar",
    "gofrare": "gofrar",
    "gofrarei": "gofrar",
    "gofrareis": "gofrar",
    "gofrarem": "gofrar",
    "gofraremos": "gofrar",
    "gofrares": "gofrar",
    "gofraria": "gofrar",
    "gofrariam": "gofrar",
    "gofrarias": "gofrar",
    "gofrarmo": "gofrar",
    "gofrarmos": "gofrar",
    "gofrará": "gofrar",
    "gofrarás": "gofrar",
    "gofrarão": "gofrar",
    "gofraríamos": "gofrar",
    "gofraríeis": "gofrar",
    "gofras": "gofrar",
    "gofrasse": "gofrar",
    "gofrassem": "gofrar",
    "gofrasses": "gofrar",
    "gofraste": "gofrar",
    "gofrastes": "gofrar",
    "gofrava": "gofrar",
    "gofravam": "gofrar",
    "gofravas": "gofrar",
    "gofre": "gofrar",
    "gofrei": "gofrar",
    "gofreis": "gofrar",
    "gofrem": "gofrar",
    "gofremo": "gofrar",
    "gofremos": "gofrar",
    "gofres": "gofrar",
    "gofro": "gofrar",
    "gofrou": "gofrar",
    "gofrá": "gofrar",
    "gofrámo": "gofrar",
    "gofrámos": "gofrar",
    "gofráramo": "gofrar",
    "gofráramos": "gofrar",
    "gofrárei": "gofrar",
    "gofráreis": "gofrar",
    "gofrásseis": "gofrar",
    "gofrássemos": "gofrar",
    "gofrávamo": "gofrar",
    "gofrávamos": "gofrar",
    "gofrávei": "gofrar",
    "gofráveis": "gofrar",
    "gogas": "goga",
    "gogos": "gogo",
    "gogosa": "gogoso",
    "gogosas": "gogoso",
    "gogosos": "gogoso",
    "goguenta": "goguento",
    "goguentas": "goguento",
    "goguentos": "goguento",
    "goiabais": "goiabal",
    "goiabeiras": "goiabeira",
    "goiana": "goiano",
    "goianas": "goiano",
    "goianos": "goiano",
    "goisiana": "goisiano",
    "goisianas": "goisiano",
    "goisianos": "goisiano",
    "goiva": "goivar",
    "goivada": "goivar",
    "goivadas": "goivar",
    "goivado": "goivar",
    "goivados": "goivar",
    "goivaduras": "goivadura",
    "goivai": "goivar",
    "goivais": "goivar",
    "goivam": "goivar",
    "goivamo": "goivar",
    "goivamos": "goivar",
    "goivando": "goivar",
    "goivara": "goivar",
    "goivaram": "goivar",
    "goivaras": "goivar",
    "goivarde": "goivar",
    "goivardes": "goivar",
    "goivare": "goivar",
    "goivarei": "goivar",
    "goivareis": "goivar",
    "goivarem": "goivar",
    "goivaremos": "goivar",
    "goivares": "goivar",
    "goivaria": "goivar",
    "goivariam": "goivar",
    "goivarias": "goivaria",
    "goivarmo": "goivar",
    "goivarmos": "goivar",
    "goivará": "goivar",
    "goivarás": "goivar",
    "goivarão": "goivar",
    "goivaríamos": "goivar",
    "goivaríeis": "goivar",
    "goivas": "goivar",
    "goivasse": "goivar",
    "goivassem": "goivar",
    "goivasses": "goivar",
    "goivaste": "goivar",
    "goivastes": "goivar",
    "goivava": "goivar",
    "goivavam": "goivar",
    "goivavas": "goivar",
    "goive": "goivar",
    "goivei": "goivar",
    "goiveiros": "goiveiro",
    "goiveis": "goivar",
    "goivem": "goivar",
    "goivemo": "goivar",
    "goivemos": "goivar",
    "goives": "goivar",
    "goivetes": "goivete",
    "goivo": "goivar",
    "goivos": "goivo",
    "goivou": "goivar",
    "goivá": "goivar",
    "goivámo": "goivar",
    "goivámos": "goivar",
    "goiváramo": "goivar",
    "goiváramos": "goivar",
    "goivárei": "goivar",
    "goiváreis": "goivar",
    "goivásseis": "goivar",
    "goivássemos": "goivar",
    "goivávamo": "goivar",
    "goivávamos": "goivar",
    "goivávei": "goivar",
    "goiváveis": "goivar",
    "goiás": "goiá",
    "goladas": "golada",
    "golas": "gola",
    "golaços": "golaço",
    "golcondas": "golconda",
    "goleada": "golear",
    "goleadas": "golear",
    "goleado": "golear",
    "goleadora": "goleador",
    "goleadoras": "goleador",
    "goleadores": "goleador",
    "goleados": "golear",
    "goleai": "golear",
    "goleais": "golear",
    "goleamo": "golear",
    "goleamos": "golear",
    "goleando": "golear",
    "goleara": "golear",
    "golearam": "golear",
    "golearas": "golear",
    "golearde": "golear",
    "goleardes": "golear",
    "goleare": "golear",
    "golearei": "golear",
    "goleareis": "golear",
    "golearem": "golear",
    "golearemos": "golear",
    "goleares": "golear",
    "golearia": "golear",
    "goleariam": "golear",
    "golearias": "golear",
    "golearmo": "golear",
    "golearmos": "golear",
    "goleará": "golear",
    "golearás": "golear",
    "golearão": "golear",
    "golearíamos": "golear",
    "golearíeis": "golear",
    "goleasse": "golear",
    "goleassem": "golear",
    "goleasses": "golear",
    "goleaste": "golear",
    "goleastes": "golear",
    "goleava": "golear",
    "goleavam": "golear",
    "goleavas": "golear",
    "goleei": "golear",
    "goleeis": "golear",
    "goleemo": "golear",
    "goleemos": "golear",
    "goleia": "golear",
    "goleiam": "golear",
    "goleias": "golear",
    "goleie": "golear",
    "goleiem": "golear",
    "goleies": "golear",
    "goleio": "golear",
    "goleira": "goleiro",
    "goleiras": "goleiro",
    "goleiros": "goleiro",
    "goleja": "golejar",
    "golejada": "golejar",
    "golejadas": "golejar",
    "golejado": "golejar",
    "golejados": "golejar",
    "golejai": "golejar",
    "golejais": "golejar",
    "golejam": "golejar",
    "golejamo": "golejar",
    "golejamos": "golejar",
    "golejando": "golejar",
    "golejara": "golejar",
    "golejaram": "golejar",
    "golejaras": "golejar",
    "golejardes": "golejar",
    "golejarei": "golejar",
    "golejareis": "golejar",
    "golejarem": "golejar",
    "golejaremos": "golejar",
    "golejares": "golejar",
    "golejaria": "golejar",
    "golejariam": "golejar",
    "golejarias": "golejar",
    "golejarmo": "golejar",
    "golejarmos": "golejar",
    "golejará": "golejar",
    "golejarás": "golejar",
    "golejarão": "golejar",
    "golejaríamos": "golejar",
    "golejaríeis": "golejar",
    "golejas": "golejar",
    "golejasse": "golejar",
    "golejassem": "golejar",
    "golejasses": "golejar",
    "golejaste": "golejar",
    "golejastes": "golejar",
    "golejava": "golejar",
    "golejavam": "golejar",
    "golejavas": "golejar",
    "goleje": "golejar",
    "golejei": "golejar",
    "golejeis": "golejar",
    "golejem": "golejar",
    "golejemo": "golejar",
    "golejemos": "golejar",
    "golejes": "golejar",
    "golejo": "golejar",
    "golejou": "golejar",
    "golejámo": "golejar",
    "golejámos": "golejar",
    "golejáramo": "golejar",
    "golejáramos": "golejar",
    "golejáreis": "golejar",
    "golejásseis": "golejar",
    "golejássemos": "golejar",
    "golejávamo": "golejar",
    "golejávamos": "golejar",
    "golejáveis": "golejar",
    "golelha": "golelhar",
    "golelhada": "golelhar",
    "golelhadas": "golelhar",
    "golelhado": "golelhar",
    "golelhados": "golelhar",
    "golelhai": "golelhar",
    "golelhais": "golelhar",
    "golelham": "golelhar",
    "golelhamo": "golelhar",
    "golelhamos": "golelhar",
    "golelhando": "golelhar",
    "golelhara": "golelhar",
    "golelharam": "golelhar",
    "golelharas": "golelhar",
    "golelhardes": "golelhar",
    "golelharei": "golelhar",
    "golelhareis": "golelhar",
    "golelharem": "golelhar",
    "golelharemos": "golelhar",
    "golelhares": "golelhar",
    "golelharia": "golelhar",
    "golelhariam": "golelhar",
    "golelharias": "golelhar",
    "golelharmo": "golelhar",
    "golelharmos": "golelhar",
    "golelhará": "golelhar",
    "golelharás": "golelhar",
    "golelharão": "golelhar",
    "golelharíamos": "golelhar",
    "golelharíeis": "golelhar",
    "golelhas": "golelhar",
    "golelhasse": "golelhar",
    "golelhassem": "golelhar",
    "golelhasses": "golelhar",
    "golelhaste": "golelhar",
    "golelhastes": "golelhar",
    "golelhava": "golelhar",
    "golelhavam": "golelhar",
    "golelhavas": "golelhar",
    "golelhe": "golelhar",
    "golelhei": "golelhar",
    "golelheira": "golelheiro",
    "golelheiras": "golelheiro",
    "golelheiros": "golelheiro",
    "golelheis": "golelhar",
    "golelhem": "golelhar",
    "golelhemo": "golelhar",
    "golelhemos": "golelhar",
    "golelhes": "golelhar",
    "golelho": "golelhar",
    "golelhou": "golelhar",
    "golelhámo": "golelhar",
    "golelhámos": "golelhar",
    "golelháramo": "golelhar",
    "golelháramos": "golelhar",
    "golelháreis": "golelhar",
    "golelhásseis": "golelhar",
    "golelhássemos": "golelhar",
    "golelhávamo": "golelhar",
    "golelhávamos": "golelhar",
    "golelháveis": "golelhar",
    "goleou": "golear",
    "goles": "gole",
    "goletas": "goleta",
    "goleá": "golear",
    "goleámo": "golear",
    "goleámos": "golear",
    "goleáramo": "golear",
    "goleáramos": "golear",
    "goleárei": "golear",
    "goleáreis": "golear",
    "goleásseis": "golear",
    "goleássemos": "golear",
    "goleávamo": "golear",
    "goleávamos": "golear",
    "goleávei": "golear",
    "goleáveis": "golear",
    "golfa": "golfar",
    "golfada": "golfar",
    "golfadas": "golfar",
    "golfado": "golfar",
    "golfados": "golfar",
    "golfai": "golfar",
    "golfais": "golfar",
    "golfam": "golfar",
    "golfamo": "golfar",
    "golfamos": "golfar",
    "golfando": "golfar",
    "golfara": "golfar",
    "golfaram": "golfar",
    "golfaras": "golfar",
    "golfarde": "golfar",
    "golfardes": "golfar",
    "golfare": "golfar",
    "golfarei": "golfar",
    "golfareis": "golfar",
    "golfarem": "golfar",
    "golfaremos": "golfar",
    "golfares": "golfar",
    "golfaria": "golfar",
    "golfariam": "golfar",
    "golfarias": "golfar",
    "golfarmo": "golfar",
    "golfarmos": "golfar",
    "golfará": "golfar",
    "golfarás": "golfar",
    "golfarão": "golfar",
    "golfaríamos": "golfar",
    "golfaríeis": "golfar",
    "golfas": "golfar",
    "golfasse": "golfar",
    "golfassem": "golfar",
    "golfasses": "golfar",
    "golfaste": "golfar",
    "golfastes": "golfar",
    "golfava": "golfar",
    "golfavam": "golfar",
    "golfavas": "golfar",
    "golfe": "golfar",
    "golfei": "golfar",
    "golfeis": "golfar",
    "golfeja": "golfejar",
    "golfejada": "golfejar",
    "golfejadas": "golfejar",
    "golfejado": "golfejar",
    "golfejados": "golfejar",
    "golfejai": "golfejar",
    "golfejais": "golfejar",
    "golfejam": "golfejar",
    "golfejamo": "golfejar",
    "golfejamos": "golfejar",
    "golfejando": "golfejar",
    "golfejara": "golfejar",
    "golfejaram": "golfejar",
    "golfejaras": "golfejar",
    "golfejarde": "golfejar",
    "golfejardes": "golfejar",
    "golfejare": "golfejar",
    "golfejarei": "golfejar",
    "golfejareis": "golfejar",
    "golfejarem": "golfejar",
    "golfejaremos": "golfejar",
    "golfejares": "golfejar",
    "golfejaria": "golfejar",
    "golfejariam": "golfejar",
    "golfejarias": "golfejar",
    "golfejarmo": "golfejar",
    "golfejarmos": "golfejar",
    "golfejará": "golfejar",
    "golfejarás": "golfejar",
    "golfejarão": "golfejar",
    "golfejaríamos": "golfejar",
    "golfejaríeis": "golfejar",
    "golfejas": "golfejar",
    "golfejasse": "golfejar",
    "golfejassem": "golfejar",
    "golfejasses": "golfejar",
    "golfejaste": "golfejar",
    "golfejastes": "golfejar",
    "golfejava": "golfejar",
    "golfejavam": "golfejar",
    "golfejavas": "golfejar",
    "golfeje": "golfejar",
    "golfejei": "golfejar",
    "golfejeis": "golfejar",
    "golfejem": "golfejar",
    "golfejemo": "golfejar",
    "golfejemos": "golfejar",
    "golfejes": "golfejar",
    "golfejo": "golfejar",
    "golfejou": "golfejar",
    "golfejá": "golfejar",
    "golfejámo": "golfejar",
    "golfejámos": "golfejar",
    "golfejáramo": "golfejar",
    "golfejáramos": "golfejar",
    "golfejárei": "golfejar",
    "golfejáreis": "golfejar",
    "golfejásseis": "golfejar",
    "golfejássemos": "golfejar",
    "golfejávamo": "golfejar",
    "golfejávamos": "golfejar",
    "golfejávei": "golfejar",
    "golfejáveis": "golfejar",
    "golfem": "golfar",
    "golfemo": "golfar",
    "golfemos": "golfar",
    "golfes": "golfe",
    "golfinhos": "golfinho",
    "golfistas": "golfista",
    "golfo": "golfar",
    "golfos": "golfo",
    "golfou": "golfar",
    "golfá": "golfar",
    "golfámo": "golfar",
    "golfámos": "golfar",
    "golfáramo": "golfar",
    "golfáramos": "golfar",
    "golfárei": "golfar",
    "golfáreis": "golfar",
    "golfásseis": "golfar",
    "golfássemos": "golfar",
    "golfávamo": "golfar",
    "golfávamos": "golfar",
    "golfávei": "golfar",
    "golfáveis": "golfar",
    "golfões": "golfão",
    "goliarda": "goliardo",
    "goliardas": "goliardo",
    "goliardos": "goliardo",
    "golilhas": "golilha",
    "golinho": "golo",
    "golinhos": "golo",
    "golito": "golo",
    "golitos": "golo",
    "golos": "golo",
    "golpadas": "golpada",
    "golpaças": "golpaça",
    "golpeada": "golpear",
    "golpeadas": "golpear",
    "golpeado": "golpear",
    "golpeados": "golpear",
    "golpeaduras": "golpeadura",
    "golpeai": "golpear",
    "golpeais": "golpear",
    "golpeamo": "golpear",
    "golpeamos": "golpear",
    "golpeando": "golpear",
    "golpeantes": "golpeante",
    "golpeara": "golpear",
    "golpearam": "golpear",
    "golpearas": "golpear",
    "golpearde": "golpear",
    "golpeardes": "golpear",
    "golpeare": "golpear",
    "golpearei": "golpear",
    "golpeareis": "golpear",
    "golpearem": "golpear",
    "golpearemos": "golpear",
    "golpeares": "golpear",
    "golpearia": "golpear",
    "golpeariam": "golpear",
    "golpearias": "golpear",
    "golpearmo": "golpear",
    "golpearmos": "golpear",
    "golpeará": "golpear",
    "golpearás": "golpear",
    "golpearão": "golpear",
    "golpearíamos": "golpear",
    "golpearíeis": "golpear",
    "golpeasse": "golpear",
    "golpeassem": "golpear",
    "golpeasses": "golpear",
    "golpeaste": "golpear",
    "golpeastes": "golpear",
    "golpeava": "golpear",
    "golpeavam": "golpear",
    "golpeavas": "golpear",
    "golpeei": "golpear",
    "golpeeis": "golpear",
    "golpeemo": "golpear",
    "golpeemos": "golpear",
    "golpeia": "golpear",
    "golpeiam": "golpear",
    "golpeias": "golpear",
    "golpeie": "golpear",
    "golpeiem": "golpear",
    "golpeies": "golpear",
    "golpeio": "golpear",
    "golpelhas": "golpelha",
    "golpelheiras": "golpelheira",
    "golpeou": "golpear",
    "golpes": "golpe",
    "golpeá": "golpear",
    "golpeámo": "golpear",
    "golpeámos": "golpear",
    "golpeáramo": "golpear",
    "golpeáramos": "golpear",
    "golpeárei": "golpear",
    "golpeáreis": "golpear",
    "golpeásseis": "golpear",
    "golpeássemos": "golpear",
    "golpeávamo": "golpear",
    "golpeávamos": "golpear",
    "golpeávei": "golpear",
    "golpeáveis": "golpeável",
    "golpismos": "golpismo",
    "golpistas": "golpista",
    "golpoeamentos": "golpoeamento",
    "golpázios": "golpázio",
    "golquíperes": "golquíper",
    "goma": "gomar",
    "gomada": "gomar",
    "gomadas": "gomar",
    "gomadeiras": "gomadeira",
    "gomado": "gomar",
    "gomados": "gomar",
    "gomai": "gomar",
    "gomais": "gomar",
    "gomam": "gomar",
    "gomamo": "gomar",
    "gomamos": "gomar",
    "gomando": "gomar",
    "gomara": "gomar",
    "gomaram": "gomar",
    "gomaras": "gomar",
    "gomardes": "gomar",
    "gomarei": "gomar",
    "gomareis": "gomar",
    "gomarem": "gomar",
    "gomaremos": "gomar",
    "gomares": "gomar",
    "gomaria": "gomar",
    "gomariam": "gomar",
    "gomarias": "gomar",
    "gomarmo": "gomar",
    "gomarmos": "gomar",
    "gomarras": "gomarra",
    "gomará": "gomar",
    "gomarás": "gomar",
    "gomarão": "gomar",
    "gomaríamos": "gomar",
    "gomaríeis": "gomar",
    "gomas": "gomar",
    "gomasse": "gomar",
    "gomassem": "gomar",
    "gomasses": "gomar",
    "gomaste": "gomar",
    "gomastes": "gomar",
    "gomava": "gomar",
    "gomavam": "gomar",
    "gomavas": "gomar",
    "gomações": "gomação",
    "gombas": "gomba",
    "gombos": "gombo",
    "gome": "gomar",
    "gomedares": "gomedar",
    "gomei": "gomar",
    "gomeira": "gomeiro",
    "gomeiras": "gomeiro",
    "gomeiros": "gomeiro",
    "gomeis": "gomar",
    "gomeleiras": "gomeleira",
    "gomem": "gomar",
    "gomemo": "gomar",
    "gomemos": "gomar",
    "gomenolada": "gomenolado",
    "gomenoladas": "gomenolado",
    "gomenolados": "gomenolado",
    "gomenóis": "gomenol",
    "gomes": "gomar",
    "gomiadas": "gomiada",
    "gomias": "gomia",
    "gomilosa": "gomiloso",
    "gomilosas": "gomiloso",
    "gomilosos": "gomiloso",
    "gominho": "gomo",
    "gominhos": "gomo",
    "gomis": "gomil",
    "gomito": "gomo",
    "gomitos": "gomo",
    "gomo": "gomar",
    "gomos": "gomo",
    "gomosa": "gomoso",
    "gomosas": "gomoso",
    "gomosidades": "gomosidade",
    "gomosos": "gomoso",
    "gomou": "gomar",
    "gomámo": "gomar",
    "gomámos": "gomar",
    "gomáramo": "gomar",
    "gomáramos": "gomar",
    "gomáreis": "gomar",
    "gomásseis": "gomar",
    "gomássemos": "gomar",
    "gomávamo": "gomar",
    "gomávamos": "gomar",
    "gomáveis": "gomável",
    "gomífera": "gomífero",
    "gomíferas": "gomífero",
    "gomíferos": "gomífero",
    "gonadias": "gonadia",
    "gonalgias": "gonalgia",
    "gondola": "gondolar",
    "gondolada": "gondolar",
    "gondoladas": "gondolar",
    "gondolado": "gondolar",
    "gondolados": "gondolar",
    "gondolai": "gondolar",
    "gondolais": "gondolar",
    "gondolam": "gondolar",
    "gondolamo": "gondolar",
    "gondolamos": "gondolar",
    "gondolando": "gondolar",
    "gondolara": "gondolar",
    "gondolaram": "gondolar",
    "gondolaras": "gondolar",
    "gondolardes": "gondolar",
    "gondolarei": "gondolar",
    "gondolareis": "gondolar",
    "gondolarem": "gondolar",
    "gondolaremos": "gondolar",
    "gondolares": "gondolar",
    "gondolaria": "gondolar",
    "gondolariam": "gondolar",
    "gondolarias": "gondolar",
    "gondolarmo": "gondolar",
    "gondolarmos": "gondolar",
    "gondolará": "gondolar",
    "gondolarás": "gondolar",
    "gondolarão": "gondolar",
    "gondolaríamos": "gondolar",
    "gondolaríeis": "gondolar",
    "gondolas": "gondolar",
    "gondolasse": "gondolar",
    "gondolassem": "gondolar",
    "gondolasses": "gondolar",
    "gondolaste": "gondolar",
    "gondolastes": "gondolar",
    "gondolava": "gondolar",
    "gondolavam": "gondolar",
    "gondolavas": "gondolar",
    "gondole": "gondolar",
    "gondolei": "gondolar",
    "gondoleira": "gondoleiro",
    "gondoleiras": "gondoleiro",
    "gondoleiros": "gondoleiro",
    "gondoleis": "gondolar",
    "gondolem": "gondolar",
    "gondolemo": "gondolar",
    "gondolemos": "gondolar",
    "gondoles": "gondolar",
    "gondolo": "gondolar",
    "gondolou": "gondolar",
    "gondolámo": "gondolar",
    "gondolámos": "gondolar",
    "gondoláramo": "gondolar",
    "gondoláramos": "gondolar",
    "gondoláreis": "gondolar",
    "gondolásseis": "gondolar",
    "gondolássemos": "gondolar",
    "gondolávamo": "gondolar",
    "gondolávamos": "gondolar",
    "gondoláveis": "gondolar",
    "gondos": "gondo",
    "gonelinas": "gonelina",
    "gonetes": "gonete",
    "gonfocarpos": "gonfocarpo",
    "gonfoses": "gonfose",
    "gongons": "gongom",
    "gongorismos": "gongorismo",
    "gongoristas": "gongorista",
    "gongoriza": "gongorizar",
    "gongorizada": "gongorizar",
    "gongorizadas": "gongorizar",
    "gongorizado": "gongorizar",
    "gongorizados": "gongorizar",
    "gongorizai": "gongorizar",
    "gongorizais": "gongorizar",
    "gongorizam": "gongorizar",
    "gongorizamo": "gongorizar",
    "gongorizamos": "gongorizar",
    "gongorizando": "gongorizar",
    "gongorizara": "gongorizar",
    "gongorizaram": "gongorizar",
    "gongorizaras": "gongorizar",
    "gongorizarde": "gongorizar",
    "gongorizardes": "gongorizar",
    "gongorizare": "gongorizar",
    "gongorizarei": "gongorizar",
    "gongorizareis": "gongorizar",
    "gongorizarem": "gongorizar",
    "gongorizaremos": "gongorizar",
    "gongorizares": "gongorizar",
    "gongorizaria": "gongorizar",
    "gongorizariam": "gongorizar",
    "gongorizarias": "gongorizar",
    "gongorizarmo": "gongorizar",
    "gongorizarmos": "gongorizar",
    "gongorizará": "gongorizar",
    "gongorizarás": "gongorizar",
    "gongorizarão": "gongorizar",
    "gongorizaríamos": "gongorizar",
    "gongorizaríeis": "gongorizar",
    "gongorizas": "gongorizar",
    "gongorizasse": "gongorizar",
    "gongorizassem": "gongorizar",
    "gongorizasses": "gongorizar",
    "gongorizaste": "gongorizar",
    "gongorizastes": "gongorizar",
    "gongorizava": "gongorizar",
    "gongorizavam": "gongorizar",
    "gongorizavas": "gongorizar",
    "gongorize": "gongorizar",
    "gongorizei": "gongorizar",
    "gongorizeis": "gongorizar",
    "gongorizem": "gongorizar",
    "gongorizemo": "gongorizar",
    "gongorizemos": "gongorizar",
    "gongorizes": "gongorizar",
    "gongorizo": "gongorizar",
    "gongorizou": "gongorizar",
    "gongorizá": "gongorizar",
    "gongorizámo": "gongorizar",
    "gongorizámos": "gongorizar",
    "gongorizáramo": "gongorizar",
    "gongorizáramos": "gongorizar",
    "gongorizárei": "gongorizar",
    "gongorizáreis": "gongorizar",
    "gongorizásseis": "gongorizar",
    "gongorizássemos": "gongorizar",
    "gongorizávamo": "gongorizar",
    "gongorizávamos": "gongorizar",
    "gongorizávei": "gongorizar",
    "gongorizáveis": "gongorizar",
    "gongorística": "gongorístico",
    "gongorísticas": "gongorístico",
    "gongorísticos": "gongorístico",
    "gongos": "gongo",
    "gongronas": "gongrona",
    "gongs": "gong",
    "gonguices": "gonguice",
    "gongórica": "gongórico",
    "gongóricas": "gongórico",
    "gongóricos": "gongórico",
    "gongós": "gongó",
    "gonialgias": "gonialgia",
    "goniatites": "goniatite",
    "goniatítica": "goniatítico",
    "goniatíticas": "goniatítico",
    "goniatíticos": "goniatítico",
    "goniocócica": "goniocócico",
    "goniocócicas": "goniocócico",
    "goniocócicos": "goniocócico",
    "goniográfica": "goniográfico",
    "goniográficas": "goniográfico",
    "goniográficos": "goniográfico",
    "goniometrias": "goniometria",
    "goniométrica": "goniométrico",
    "goniométricas": "goniométrico",
    "goniométricos": "goniométrico",
    "goniógrafos": "goniógrafo",
    "goniómetros": "goniómetro",
    "gonoceles": "gonocele",
    "gonococias": "gonococia",
    "gonococos": "gonococo",
    "gonocorismos": "gonocorismo",
    "gonocórica": "gonocórico",
    "gonocóricas": "gonocórico",
    "gonocóricos": "gonocórico",
    "gonorreias": "gonorreia",
    "gonorreica": "gonorreico",
    "gonorreicas": "gonorreico",
    "gonorreicos": "gonorreico",
    "gonotecas": "gonoteca",
    "gonozóides": "gonozóide",
    "gonus": "gonu",
    "gonzos": "gonzo",
    "gonçalinhos": "gonçalinho",
    "gonçalvismos": "gonçalvismo",
    "gonídias": "gonídia",
    "gonídios": "gonídio",
    "gonócitos": "gonócito",
    "gonóforos": "gonóforo",
    "gora": "gorar",
    "gorada": "gorar",
    "goradas": "gorar",
    "gorado": "gorar",
    "gorados": "gorar",
    "gorai": "gorar",
    "gorais": "gorar",
    "goram": "gorar",
    "goramo": "gorar",
    "goramos": "gorar",
    "goranatimbóes": "goranatimbó",
    "gorando": "gorar",
    "gorara": "gorar",
    "goraram": "gorar",
    "goraras": "gorar",
    "gorarde": "gorar",
    "gorardes": "gorar",
    "gorare": "gorar",
    "gorarei": "gorar",
    "gorareis": "gorar",
    "gorarem": "gorar",
    "goraremos": "gorar",
    "gorares": "gorar",
    "goraria": "gorar",
    "gorariam": "gorar",
    "gorarias": "gorar",
    "gorarmo": "gorar",
    "gorarmos": "gorar",
    "gorará": "gorar",
    "gorarás": "gorar",
    "gorarão": "gorar",
    "goraríamos": "gorar",
    "goraríeis": "gorar",
    "goras": "gorar",
    "gorasse": "gorar",
    "gorassem": "gorar",
    "gorasses": "gorar",
    "goraste": "gorar",
    "gorastes": "gorar",
    "gorava": "gorar",
    "goravam": "gorar",
    "goravas": "gorar",
    "gorazeira": "gorazeiro",
    "gorazeiras": "gorazeiro",
    "gorazeiros": "gorazeiro",
    "gorazes": "goraz",
    "gorda": "gordo",
    "gordalhaça": "gordalhaço",
    "gordalhaças": "gordalhaço",
    "gordalhaços": "gordalhaço",
    "gordalhona": "gordalhão",
    "gordalhonas": "gordalhão",
    "gordalhuda": "gordalhudo",
    "gordalhudas": "gordalhudo",
    "gordalhudos": "gordalhudo",
    "gordalhufa": "gordalhufo",
    "gordalhufas": "gordalhufo",
    "gordalhufos": "gordalhufo",
    "gordalhões": "gordalhão",
    "gordanchuda": "gordanchudo",
    "gordanchudas": "gordanchudo",
    "gordanchudos": "gordanchudo",
    "gordas": "gordo",
    "gordazinha": "gordo",
    "gordazinhas": "gordo",
    "gordazita": "gordo",
    "gordazitas": "gordo",
    "gordeca": "gordeco",
    "gordecas": "gordeco",
    "gordecos": "gordeco",
    "gordiana": "gordiano",
    "gordianas": "gordiano",
    "gordianos": "gordiano",
    "gordinha": "gordo",
    "gordinhas": "gordo",
    "gordinho": "gordo",
    "gordinhos": "gordo",
    "gordita": "gordo",
    "gorditas": "gordo",
    "gordito": "gordo",
    "gorditos": "gordo",
    "gordos": "gordo",
    "gordota": "gordote",
    "gordotas": "gordote",
    "gordotes": "gordote",
    "gordozinho": "gordo",
    "gordozinhos": "gordo",
    "gordozito": "gordo",
    "gordozitos": "gordo",
    "gorducha": "gorducho",
    "gorduchas": "gorducho",
    "gorduchos": "gorducho",
    "gordunha": "gordunho",
    "gordunhas": "gordunho",
    "gordunhos": "gordunho",
    "gorduras": "gordura",
    "gordurenta": "gordurento",
    "gordurentas": "gordurento",
    "gordurentos": "gordurento",
    "gordurinha": "gordura",
    "gordurinhas": "gordura",
    "gordurita": "gordura",
    "gorduritas": "gordura",
    "gordurosa": "gorduroso",
    "gordurosas": "gorduroso",
    "gordurosos": "gorduroso",
    "gordíssima": "gordo",
    "gordíssimas": "gordo",
    "gordíssimo": "gordo",
    "gordíssimos": "gordo",
    "gore": "gorar",
    "gorei": "gorar",
    "goreira": "goreiro",
    "goreiras": "goreiro",
    "goreiros": "goreiro",
    "goreis": "gorar",
    "gorem": "gorar",
    "goremo": "gorar",
    "goremos": "gorar",
    "gores": "gorar",
    "gorgas": "gorga",
    "gorgazes": "gorgaz",
    "gorgola": "gorgolar",
    "gorgolada": "gorgolar",
    "gorgoladas": "gorgolar",
    "gorgolado": "gorgolar",
    "gorgolados": "gorgolar",
    "gorgolai": "gorgolar",
    "gorgolais": "gorgolar",
    "gorgolam": "gorgolar",
    "gorgolamo": "gorgolar",
    "gorgolamos": "gorgolar",
    "gorgolando": "gorgolar",
    "gorgolara": "gorgolar",
    "gorgolaram": "gorgolar",
    "gorgolaras": "gorgolar",
    "gorgolardes": "gorgolar",
    "gorgolarei": "gorgolar",
    "gorgolareis": "gorgolar",
    "gorgolarem": "gorgolar",
    "gorgolaremos": "gorgolar",
    "gorgolares": "gorgolar",
    "gorgolaria": "gorgolar",
    "gorgolariam": "gorgolar",
    "gorgolarias": "gorgolar",
    "gorgolarmo": "gorgolar",
    "gorgolarmos": "gorgolar",
    "gorgolará": "gorgolar",
    "gorgolarás": "gorgolar",
    "gorgolarão": "gorgolar",
    "gorgolaríamos": "gorgolar",
    "gorgolaríeis": "gorgolar",
    "gorgolas": "gorgolar",
    "gorgolasse": "gorgolar",
    "gorgolassem": "gorgolar",
    "gorgolasses": "gorgolar",
    "gorgolaste": "gorgolar",
    "gorgolastes": "gorgolar",
    "gorgolava": "gorgolar",
    "gorgolavam": "gorgolar",
    "gorgolavas": "gorgolar",
    "gorgole": "gorgolar",
    "gorgolei": "gorgolar",
    "gorgoleis": "gorgolar",
    "gorgoleja": "gorgolejar",
    "gorgolejada": "gorgolejar",
    "gorgolejadas": "gorgolejar",
    "gorgolejado": "gorgolejar",
    "gorgolejados": "gorgolejar",
    "gorgolejai": "gorgolejar",
    "gorgolejais": "gorgolejar",
    "gorgolejam": "gorgolejar",
    "gorgolejamo": "gorgolejar",
    "gorgolejamos": "gorgolejar",
    "gorgolejando": "gorgolejar",
    "gorgolejantes": "gorgolejante",
    "gorgolejara": "gorgolejar",
    "gorgolejaram": "gorgolejar",
    "gorgolejaras": "gorgolejar",
    "gorgolejardes": "gorgolejar",
    "gorgolejarei": "gorgolejar",
    "gorgolejareis": "gorgolejar",
    "gorgolejarem": "gorgolejar",
    "gorgolejaremos": "gorgolejar",
    "gorgolejares": "gorgolejar",
    "gorgolejaria": "gorgolejar",
    "gorgolejariam": "gorgolejar",
    "gorgolejarias": "gorgolejar",
    "gorgolejarmo": "gorgolejar",
    "gorgolejarmos": "gorgolejar",
    "gorgolejará": "gorgolejar",
    "gorgolejarás": "gorgolejar",
    "gorgolejarão": "gorgolejar",
    "gorgolejaríamos": "gorgolejar",
    "gorgolejaríeis": "gorgolejar",
    "gorgolejas": "gorgolejar",
    "gorgolejasse": "gorgolejar",
    "gorgolejassem": "gorgolejar",
    "gorgolejasses": "gorgolejar",
    "gorgolejaste": "gorgolejar",
    "gorgolejastes": "gorgolejar",
    "gorgolejava": "gorgolejar",
    "gorgolejavam": "gorgolejar",
    "gorgolejavas": "gorgolejar",
    "gorgoleje": "gorgolejar",
    "gorgolejei": "gorgolejar",
    "gorgolejeis": "gorgolejar",
    "gorgolejem": "gorgolejar",
    "gorgolejemo": "gorgolejar",
    "gorgolejemos": "gorgolejar",
    "gorgolejes": "gorgolejar",
    "gorgolejo": "gorgolejar",
    "gorgolejos": "gorgolejo",
    "gorgolejou": "gorgolejar",
    "gorgolejámo": "gorgolejar",
    "gorgolejámos": "gorgolejar",
    "gorgolejáramo": "gorgolejar",
    "gorgolejáramos": "gorgolejar",
    "gorgolejáreis": "gorgolejar",
    "gorgolejásseis": "gorgolejar",
    "gorgolejássemos": "gorgolejar",
    "gorgolejávamo": "gorgolejar",
    "gorgolejávamos": "gorgolejar",
    "gorgolejáveis": "gorgolejar",
    "gorgolem": "gorgolar",
    "gorgolemo": "gorgolar",
    "gorgolemos": "gorgolar",
    "gorgoles": "gorgolar",
    "gorgoletas": "gorgoleta",
    "gorgolha": "gorgolhar",
    "gorgolhada": "gorgolhar",
    "gorgolhadas": "gorgolhar",
    "gorgolhado": "gorgolhar",
    "gorgolhados": "gorgolhar",
    "gorgolhai": "gorgolhar",
    "gorgolhais": "gorgolhar",
    "gorgolham": "gorgolhar",
    "gorgolhamo": "gorgolhar",
    "gorgolhamos": "gorgolhar",
    "gorgolhando": "gorgolhar",
    "gorgolhara": "gorgolhar",
    "gorgolharam": "gorgolhar",
    "gorgolharas": "gorgolhar",
    "gorgolharde": "gorgolhar",
    "gorgolhardes": "gorgolhar",
    "gorgolhare": "gorgolhar",
    "gorgolharei": "gorgolhar",
    "gorgolhareis": "gorgolhar",
    "gorgolharem": "gorgolhar",
    "gorgolharemos": "gorgolhar",
    "gorgolhares": "gorgolhar",
    "gorgolharia": "gorgolhar",
    "gorgolhariam": "gorgolhar",
    "gorgolharias": "gorgolhar",
    "gorgolharmo": "gorgolhar",
    "gorgolharmos": "gorgolhar",
    "gorgolhará": "gorgolhar",
    "gorgolharás": "gorgolhar",
    "gorgolharão": "gorgolhar",
    "gorgolharíamos": "gorgolhar",
    "gorgolharíeis": "gorgolhar",
    "gorgolhas": "gorgolhar",
    "gorgolhasse": "gorgolhar",
    "gorgolhassem": "gorgolhar",
    "gorgolhasses": "gorgolhar",
    "gorgolhaste": "gorgolhar",
    "gorgolhastes": "gorgolhar",
    "gorgolhava": "gorgolhar",
    "gorgolhavam": "gorgolhar",
    "gorgolhavas": "gorgolhar",
    "gorgolhe": "gorgolhar",
    "gorgolhei": "gorgolhar",
    "gorgolheis": "gorgolhar",
    "gorgolhem": "gorgolhar",
    "gorgolhemo": "gorgolhar",
    "gorgolhemos": "gorgolhar",
    "gorgolhes": "gorgolhar",
    "gorgolho": "gorgolhar",
    "gorgolhou": "gorgolhar",
    "gorgolhá": "gorgolhar",
    "gorgolhámo": "gorgolhar",
    "gorgolhámos": "gorgolhar",
    "gorgolháramo": "gorgolhar",
    "gorgolháramos": "gorgolhar",
    "gorgolhárei": "gorgolhar",
    "gorgolháreis": "gorgolhar",
    "gorgolhásseis": "gorgolhar",
    "gorgolhássemos": "gorgolhar",
    "gorgolhávamo": "gorgolhar",
    "gorgolhávamos": "gorgolhar",
    "gorgolhávei": "gorgolhar",
    "gorgolháveis": "gorgolhar",
    "gorgolhões": "gorgolhão",
    "gorgolo": "gorgolar",
    "gorgolou": "gorgolar",
    "gorgolámo": "gorgolar",
    "gorgolámos": "gorgolar",
    "gorgoláramo": "gorgolar",
    "gorgoláramos": "gorgolar",
    "gorgoláreis": "gorgolar",
    "gorgolásseis": "gorgolar",
    "gorgolássemos": "gorgolar",
    "gorgolávamo": "gorgolar",
    "gorgolávamos": "gorgolar",
    "gorgoláveis": "gorgolar",
    "gorgolões": "gorgolão",
    "gorgomilas": "gorgomila",
    "gorgomilos": "gorgomilo",
    "gorgomis": "gorgomil",
    "gorgonzolas": "gorgonzola",
    "gorgorejos": "gorgorejo",
    "gorgorinas": "gorgorina",
    "gorgorões": "gorgorão",
    "gorgotos": "gorgoto",
    "gorgulhenta": "gorgulhento",
    "gorgulhentas": "gorgulhento",
    "gorgulhentos": "gorgulhento",
    "gorgulhos": "gorgulho",
    "gorguzes": "gorguz",
    "gorilas": "gorila",
    "gorilona": "gorilão",
    "gorilonas": "gorilão",
    "gorilões": "gorilão",
    "gorjais": "gorjal",
    "gorjas": "gorja",
    "gorjeada": "gorjear",
    "gorjeadas": "gorjear",
    "gorjeado": "gorjear",
    "gorjeadora": "gorjeador",
    "gorjeadoras": "gorjeador",
    "gorjeadores": "gorjeador",
    "gorjeados": "gorjear",
    "gorjeai": "gorjear",
    "gorjeais": "gorjear",
    "gorjeamo": "gorjear",
    "gorjeamos": "gorjear",
    "gorjeando": "gorjear",
    "gorjeara": "gorjear",
    "gorjearam": "gorjear",
    "gorjearas": "gorjear",
    "gorjeardes": "gorjear",
    "gorjearei": "gorjear",
    "gorjeareis": "gorjear",
    "gorjearem": "gorjear",
    "gorjearemos": "gorjear",
    "gorjeares": "gorjear",
    "gorjearia": "gorjear",
    "gorjeariam": "gorjear",
    "gorjearias": "gorjear",
    "gorjearmo": "gorjear",
    "gorjearmos": "gorjear",
    "gorjeará": "gorjear",
    "gorjearás": "gorjear",
    "gorjearão": "gorjear",
    "gorjearíamos": "gorjear",
    "gorjearíeis": "gorjear",
    "gorjeasse": "gorjear",
    "gorjeassem": "gorjear",
    "gorjeasses": "gorjear",
    "gorjeaste": "gorjear",
    "gorjeastes": "gorjear",
    "gorjeava": "gorjear",
    "gorjeavam": "gorjear",
    "gorjeavas": "gorjear",
    "gorjeei": "gorjear",
    "gorjeeis": "gorjear",
    "gorjeemo": "gorjear",
    "gorjeemos": "gorjear",
    "gorjeia": "gorjear",
    "gorjeiam": "gorjear",
    "gorjeias": "gorjear",
    "gorjeie": "gorjear",
    "gorjeiem": "gorjear",
    "gorjeies": "gorjear",
    "gorjeio": "gorjear",
    "gorjeios": "gorjeio",
    "gorjeiras": "gorjeira",
    "gorjeou": "gorjear",
    "gorjetas": "gorjeta",
    "gorjetes": "gorjete",
    "gorjeámo": "gorjear",
    "gorjeámos": "gorjear",
    "gorjeáramo": "gorjear",
    "gorjeáramos": "gorjear",
    "gorjeáreis": "gorjear",
    "gorjeásseis": "gorjear",
    "gorjeássemos": "gorjear",
    "gorjeávamo": "gorjear",
    "gorjeávamos": "gorjear",
    "gorjeáveis": "gorjear",
    "gorna": "gornir",
    "gornais": "gornir",
    "gornam": "gornir",
    "gornamo": "gornir",
    "gornamos": "gornir",
    "gornas": "gornir",
    "gorne": "gornir",
    "gornem": "gornir",
    "gornes": "gornir",
    "gorni": "gornir",
    "gornia": "gornir",
    "gorniam": "gornir",
    "gornias": "gornir",
    "gornida": "gornir",
    "gornidas": "gornir",
    "gornido": "gornir",
    "gornidos": "gornir",
    "gornimo": "gornir",
    "gornimos": "gornir",
    "gornindo": "gornir",
    "gornira": "gornir",
    "gorniram": "gornir",
    "gorniras": "gornir",
    "gornirde": "gornir",
    "gornirdes": "gornir",
    "gornire": "gornir",
    "gornirei": "gornir",
    "gornireis": "gornir",
    "gornirem": "gornir",
    "gorniremos": "gornir",
    "gornires": "gornir",
    "gorniria": "gornir",
    "gorniriam": "gornir",
    "gornirias": "gornir",
    "gornirmo": "gornir",
    "gornirmos": "gornir",
    "gornirá": "gornir",
    "gornirás": "gornir",
    "gornirão": "gornir",
    "gorniríamos": "gornir",
    "gorniríeis": "gornir",
    "gornis": "gornir",
    "gornisse": "gornir",
    "gornissem": "gornir",
    "gornisses": "gornir",
    "gorniste": "gornir",
    "gornistes": "gornir",
    "gorniu": "gornir",
    "gorno": "gornir",
    "gorníamo": "gornir",
    "gorníamos": "gornir",
    "gorníei": "gornir",
    "gorníeis": "gornir",
    "gorníramo": "gornir",
    "gorníramos": "gornir",
    "gornírei": "gornir",
    "gorníreis": "gornir",
    "gornísseis": "gornir",
    "gorníssemos": "gornir",
    "goro": "gorar",
    "gorou": "gorar",
    "gorras": "gorra",
    "gorreiros": "gorreiro",
    "gorros": "gorro",
    "gorruchos": "gorrucho",
    "gorvinhas": "gorvinha",
    "gorá": "gorar",
    "gorámo": "gorar",
    "gorámos": "gorar",
    "goráramo": "gorar",
    "goráramos": "gorar",
    "gorárei": "gorar",
    "goráreis": "gorar",
    "gorás": "gorá",
    "gorásseis": "gorar",
    "gorássemos": "gorar",
    "gorávamo": "gorar",
    "gorávamos": "gorar",
    "gorávei": "gorar",
    "goráveis": "gorar",
    "gosma": "gosmar",
    "gosmada": "gosmar",
    "gosmadas": "gosmar",
    "gosmado": "gosmar",
    "gosmados": "gosmar",
    "gosmai": "gosmar",
    "gosmais": "gosmar",
    "gosmam": "gosmar",
    "gosmamo": "gosmar",
    "gosmamos": "gosmar",
    "gosmando": "gosmar",
    "gosmara": "gosmar",
    "gosmaram": "gosmar",
    "gosmaras": "gosmar",
    "gosmardes": "gosmar",
    "gosmarei": "gosmar",
    "gosmareis": "gosmar",
    "gosmarem": "gosmar",
    "gosmaremos": "gosmar",
    "gosmares": "gosmar",
    "gosmaria": "gosmar",
    "gosmariam": "gosmar",
    "gosmarias": "gosmar",
    "gosmarmo": "gosmar",
    "gosmarmos": "gosmar",
    "gosmará": "gosmar",
    "gosmarás": "gosmar",
    "gosmarão": "gosmar",
    "gosmaríamos": "gosmar",
    "gosmaríeis": "gosmar",
    "gosmas": "gosmar",
    "gosmasse": "gosmar",
    "gosmassem": "gosmar",
    "gosmasses": "gosmar",
    "gosmaste": "gosmar",
    "gosmastes": "gosmar",
    "gosmava": "gosmar",
    "gosmavam": "gosmar",
    "gosmavas": "gosmar",
    "gosme": "gosmar",
    "gosmei": "gosmar",
    "gosmeis": "gosmar",
    "gosmem": "gosmar",
    "gosmemo": "gosmar",
    "gosmemos": "gosmar",
    "gosmenta": "gosmento",
    "gosmentas": "gosmento",
    "gosmentos": "gosmento",
    "gosmes": "gosmar",
    "gosmo": "gosmar",
    "gosmosa": "gosmoso",
    "gosmosas": "gosmoso",
    "gosmosos": "gosmoso",
    "gosmou": "gosmar",
    "gosmámo": "gosmar",
    "gosmámos": "gosmar",
    "gosmáramo": "gosmar",
    "gosmáramos": "gosmar",
    "gosmáreis": "gosmar",
    "gosmásseis": "gosmar",
    "gosmássemos": "gosmar",
    "gosmávamo": "gosmar",
    "gosmávamos": "gosmar",
    "gosmáveis": "gosmar",
    "gosta": "gostar",
    "gostada": "gostar",
    "gostadas": "gostar",
    "gostado": "gostar",
    "gostados": "gostar",
    "gostai": "gostar",
    "gostais": "gostar",
    "gostam": "gostar",
    "gostamo": "gostar",
    "gostamos": "gostar",
    "gostando": "gostar",
    "gostara": "gostar",
    "gostaram": "gostar",
    "gostaras": "gostar",
    "gostardes": "gostar",
    "gostarei": "gostar",
    "gostareis": "gostar",
    "gostarem": "gostar",
    "gostaremos": "gostar",
    "gostares": "gostar",
    "gostaria": "gostar",
    "gostariam": "gostar",
    "gostarias": "gostar",
    "gostarmo": "gostar",
    "gostarmos": "gostar",
    "gostará": "gostar",
    "gostarás": "gostar",
    "gostarão": "gostar",
    "gostaríamos": "gostar",
    "gostaríeis": "gostar",
    "gostas": "gostar",
    "gostasse": "gostar",
    "gostassem": "gostar",
    "gostasses": "gostar",
    "gostaste": "gostar",
    "gostastes": "gostar",
    "gostava": "gostar",
    "gostavam": "gostar",
    "gostavas": "gostar",
    "goste": "gostar",
    "gostei": "gostar",
    "gosteis": "gostar",
    "gostem": "gostar",
    "gostemo": "gostar",
    "gostemos": "gostar",
    "gostes": "gostar",
    "gostilhos": "gostilho",
    "gostinho": "gosto",
    "gostinhos": "gosto",
    "gostito": "gosto",
    "gostitos": "gosto",
    "gosto": "gostar",
    "gostos": "gosto",
    "gostosa": "gostoso",
    "gostosas": "gostoso",
    "gostosos": "gostoso",
    "gostou": "gostar",
    "gostámo": "gostar",
    "gostámos": "gostar",
    "gostáramo": "gostar",
    "gostáramos": "gostar",
    "gostáreis": "gostar",
    "gostásseis": "gostar",
    "gostássemos": "gostar",
    "gostávamo": "gostar",
    "gostávamos": "gostar",
    "gostáveis": "gostável",
    "gotas": "gota",
    "goteada": "gotear",
    "goteadas": "gotear",
    "goteado": "gotear",
    "goteados": "gotear",
    "goteai": "gotear",
    "goteais": "gotear",
    "goteamo": "gotear",
    "goteamos": "gotear",
    "goteando": "gotear",
    "goteara": "gotear",
    "gotearam": "gotear",
    "gotearas": "gotear",
    "goteardes": "gotear",
    "gotearei": "gotear",
    "goteareis": "gotear",
    "gotearem": "gotear",
    "gotearemos": "gotear",
    "goteares": "gotear",
    "gotearia": "gotear",
    "goteariam": "gotear",
    "gotearias": "gotear",
    "gotearmo": "gotear",
    "gotearmos": "gotear",
    "goteará": "gotear",
    "gotearás": "gotear",
    "gotearão": "gotear",
    "gotearíamos": "gotear",
    "gotearíeis": "gotear",
    "goteasse": "gotear",
    "goteassem": "gotear",
    "goteasses": "gotear",
    "goteaste": "gotear",
    "goteastes": "gotear",
    "goteava": "gotear",
    "goteavam": "gotear",
    "goteavas": "gotear",
    "goteei": "gotear",
    "goteeis": "gotear",
    "goteemo": "gotear",
    "goteemos": "gotear",
    "goteia": "gotear",
    "goteiam": "gotear",
    "goteias": "gotear",
    "goteie": "gotear",
    "goteiem": "gotear",
    "goteies": "gotear",
    "goteio": "gotear",
    "goteiras": "goteira",
    "goteja": "gotejar",
    "gotejada": "gotejar",
    "gotejadas": "gotejar",
    "gotejado": "gotejar",
    "gotejados": "gotejar",
    "gotejai": "gotejar",
    "gotejais": "gotejar",
    "gotejam": "gotejar",
    "gotejamentos": "gotejamento",
    "gotejamo": "gotejar",
    "gotejamos": "gotejar",
    "gotejando": "gotejar",
    "gotejantes": "gotejante",
    "gotejara": "gotejar",
    "gotejaram": "gotejar",
    "gotejaras": "gotejar",
    "gotejardes": "gotejar",
    "gotejarei": "gotejar",
    "gotejareis": "gotejar",
    "gotejarem": "gotejar",
    "gotejaremos": "gotejar",
    "gotejares": "gotejar",
    "gotejaria": "gotejar",
    "gotejariam": "gotejar",
    "gotejarias": "gotejar",
    "gotejarmo": "gotejar",
    "gotejarmos": "gotejar",
    "gotejará": "gotejar",
    "gotejarás": "gotejar",
    "gotejarão": "gotejar",
    "gotejaríamos": "gotejar",
    "gotejaríeis": "gotejar",
    "gotejas": "gotejar",
    "gotejasse": "gotejar",
    "gotejassem": "gotejar",
    "gotejasses": "gotejar",
    "gotejaste": "gotejar",
    "gotejastes": "gotejar",
    "gotejava": "gotejar",
    "gotejavam": "gotejar",
    "gotejavas": "gotejar",
    "goteje": "gotejar",
    "gotejei": "gotejar",
    "gotejeis": "gotejar",
    "gotejem": "gotejar",
    "gotejemo": "gotejar",
    "gotejemos": "gotejar",
    "gotejes": "gotejar",
    "gotejo": "gotejar",
    "gotejou": "gotejar",
    "gotejámo": "gotejar",
    "gotejámos": "gotejar",
    "gotejáramo": "gotejar",
    "gotejáramos": "gotejar",
    "gotejáreis": "gotejar",
    "gotejásseis": "gotejar",
    "gotejássemos": "gotejar",
    "gotejávamo": "gotejar",
    "gotejávamos": "gotejar",
    "gotejáveis": "gotejar",
    "goteou": "gotear",
    "gotes": "gote",
    "goteámo": "gotear",
    "goteámos": "gotear",
    "goteáramo": "gotear",
    "goteáramos": "gotear",
    "goteáreis": "gotear",
    "goteásseis": "gotear",
    "goteássemos": "gotear",
    "goteávamo": "gotear",
    "goteávamos": "gotear",
    "goteáveis": "gotear",
    "gotimétrica": "gotimétrico",
    "gotimétricas": "gotimétrico",
    "gotimétricos": "gotimétrico",
    "gotingos": "gotingo",
    "gotinha": "gota",
    "gotinhas": "gota",
    "gotita": "gota",
    "gotitas": "gota",
    "gotlandiana": "gotlandiano",
    "gotlandianas": "gotlandiano",
    "gotlandianos": "gotlandiano",
    "gotos": "goto",
    "gotosa": "gotoso",
    "gotosas": "gotoso",
    "gotosos": "gotoso",
    "gotículas": "gotícula",
    "gotímetros": "gotímetro",
    "goulina": "gouli",
    "goulinas": "gouli",
    "goulis": "gouli",
    "gourmets": "gourmet",
    "gouvarinha": "gouvarinhar",
    "gouvarinhada": "gouvarinhar",
    "gouvarinhadas": "gouvarinhar",
    "gouvarinhado": "gouvarinhar",
    "gouvarinhados": "gouvarinhar",
    "gouvarinhai": "gouvarinhar",
    "gouvarinhais": "gouvarinhar",
    "gouvarinham": "gouvarinhar",
    "gouvarinhamo": "gouvarinhar",
    "gouvarinhamos": "gouvarinhar",
    "gouvarinhando": "gouvarinhar",
    "gouvarinhara": "gouvarinhar",
    "gouvarinharam": "gouvarinhar",
    "gouvarinharas": "gouvarinhar",
    "gouvarinhardes": "gouvarinhar",
    "gouvarinharei": "gouvarinhar",
    "gouvarinhareis": "gouvarinhar",
    "gouvarinharem": "gouvarinhar",
    "gouvarinharemos": "gouvarinhar",
    "gouvarinhares": "gouvarinhar",
    "gouvarinharia": "gouvarinhar",
    "gouvarinhariam": "gouvarinhar",
    "gouvarinharias": "gouvarinhar",
    "gouvarinharmo": "gouvarinhar",
    "gouvarinharmos": "gouvarinhar",
    "gouvarinhará": "gouvarinhar",
    "gouvarinharás": "gouvarinhar",
    "gouvarinharão": "gouvarinhar",
    "gouvarinharíamos": "gouvarinhar",
    "gouvarinharíeis": "gouvarinhar",
    "gouvarinhas": "gouvarinhar",
    "gouvarinhasse": "gouvarinhar",
    "gouvarinhassem": "gouvarinhar",
    "gouvarinhasses": "gouvarinhar",
    "gouvarinhaste": "gouvarinhar",
    "gouvarinhastes": "gouvarinhar",
    "gouvarinhava": "gouvarinhar",
    "gouvarinhavam": "gouvarinhar",
    "gouvarinhavas": "gouvarinhar",
    "gouvarinhe": "gouvarinhar",
    "gouvarinhei": "gouvarinhar",
    "gouvarinheis": "gouvarinhar",
    "gouvarinhem": "gouvarinhar",
    "gouvarinhemo": "gouvarinhar",
    "gouvarinhemos": "gouvarinhar",
    "gouvarinhes": "gouvarinhar",
    "gouvarinho": "gouvarinhar",
    "gouvarinhou": "gouvarinhar",
    "gouvarinhámo": "gouvarinhar",
    "gouvarinhámos": "gouvarinhar",
    "gouvarinháramo": "gouvarinhar",
    "gouvarinháramos": "gouvarinhar",
    "gouvarinháreis": "gouvarinhar",
    "gouvarinhásseis": "gouvarinhar",
    "gouvarinhássemos": "gouvarinhar",
    "gouvarinhávamo": "gouvarinhar",
    "gouvarinhávamos": "gouvarinhar",
    "gouvarinháveis": "gouvarinhar",
    "gouveana": "gouveano",
    "gouveanas": "gouveano",
    "gouveanos": "gouveano",
    "gouveia": "gouveio",
    "gouveias": "gouveio",
    "gouveios": "gouveio",
    "gouves": "gouve",
    "governa": "governar",
    "governabilidades": "governabilidade",
    "governada": "governar",
    "governadas": "governar",
    "governadeira": "governadeiro",
    "governadeiras": "governadeiro",
    "governadeiros": "governadeiro",
    "governado": "governar",
    "governadora": "governador",
    "governadoras": "governador",
    "governadores": "governador",
    "governadorias": "governadoria",
    "governados": "governar",
    "governai": "governar",
    "governais": "governar",
    "governalhos": "governalho",
    "governam": "governar",
    "governamentais": "governamental",
    "governamentalistas": "governamentalista",
    "governamentos": "governamento",
    "governamo": "governar",
    "governamos": "governar",
    "governando": "governar",
    "governantas": "governanta",
    "governantes": "governante",
    "governantrizes": "governantriz",
    "governanças": "governança",
    "governara": "governar",
    "governaram": "governar",
    "governaras": "governar",
    "governarde": "governar",
    "governardes": "governar",
    "governare": "governar",
    "governarei": "governar",
    "governareis": "governar",
    "governarem": "governar",
    "governaremos": "governar",
    "governares": "governar",
    "governaria": "governar",
    "governariam": "governar",
    "governarias": "governar",
    "governarmo": "governar",
    "governarmos": "governar",
    "governará": "governar",
    "governarás": "governar",
    "governarão": "governar",
    "governaríamos": "governar",
    "governaríeis": "governar",
    "governas": "governar",
    "governasse": "governar",
    "governassem": "governar",
    "governasses": "governar",
    "governaste": "governar",
    "governastes": "governar",
    "governativa": "governativo",
    "governativas": "governativo",
    "governativos": "governativo",
    "governatriz": "governador",
    "governatrizes": "governador",
    "governava": "governar",
    "governavam": "governar",
    "governavas": "governar",
    "governações": "governação",
    "governe": "governar",
    "governei": "governar",
    "governeis": "governar",
    "governem": "governar",
    "governemo": "governar",
    "governemos": "governar",
    "governes": "governar",
    "governicha": "governichar",
    "governichada": "governichar",
    "governichadas": "governichar",
    "governichado": "governichar",
    "governichados": "governichar",
    "governichai": "governichar",
    "governichais": "governichar",
    "governicham": "governichar",
    "governichamo": "governichar",
    "governichamos": "governichar",
    "governichando": "governichar",
    "governichara": "governichar",
    "governicharam": "governichar",
    "governicharas": "governichar",
    "governichardes": "governichar",
    "governicharei": "governichar",
    "governichareis": "governichar",
    "governicharem": "governichar",
    "governicharemos": "governichar",
    "governichares": "governichar",
    "governicharia": "governichar",
    "governichariam": "governichar",
    "governicharias": "governichar",
    "governicharmo": "governichar",
    "governicharmos": "governichar",
    "governichará": "governichar",
    "governicharás": "governichar",
    "governicharão": "governichar",
    "governicharíamos": "governichar",
    "governicharíeis": "governichar",
    "governichas": "governichar",
    "governichasse": "governichar",
    "governichassem": "governichar",
    "governichasses": "governichar",
    "governichaste": "governichar",
    "governichastes": "governichar",
    "governichava": "governichar",
    "governichavam": "governichar",
    "governichavas": "governichar",
    "governiche": "governichar",
    "governichei": "governichar",
    "governicheis": "governichar",
    "governichem": "governichar",
    "governichemo": "governichar",
    "governichemos": "governichar",
    "governiches": "governichar",
    "governicho": "governichar",
    "governichou": "governichar",
    "governichámo": "governichar",
    "governichámos": "governichar",
    "governicháramo": "governichar",
    "governicháramos": "governichar",
    "governicháreis": "governichar",
    "governichásseis": "governichar",
    "governichássemos": "governichar",
    "governichávamo": "governichar",
    "governichávamos": "governichar",
    "governicháveis": "governichar",
    "governismos": "governismo",
    "governistas": "governista",
    "governo": "governar",
    "governos": "governo",
    "governou": "governar",
    "governá": "governar",
    "governámo": "governar",
    "governámos": "governar",
    "governáramo": "governar",
    "governáramos": "governar",
    "governárei": "governar",
    "governáreis": "governar",
    "governásseis": "governar",
    "governássemos": "governar",
    "governávamo": "governar",
    "governávamos": "governar",
    "governávei": "governar",
    "governáveis": "governável",
    "govetes": "govete",
    "goza": "gozar",
    "gozada": "gozar",
    "gozadas": "gozar",
    "gozado": "gozar",
    "gozadora": "gozador",
    "gozadoras": "gozador",
    "gozadores": "gozador",
    "gozados": "gozar",
    "gozadíssima": "gozado",
    "gozadíssimas": "gozado",
    "gozadíssimo": "gozado",
    "gozadíssimos": "gozado",
    "gozai": "gozar",
    "gozais": "gozar",
    "gozam": "gozar",
    "gozamo": "gozar",
    "gozamos": "gozar",
    "gozando": "gozar",
    "gozara": "gozar",
    "gozaram": "gozar",
    "gozaras": "gozar",
    "gozarde": "gozar",
    "gozardes": "gozar",
    "gozare": "gozar",
    "gozarei": "gozar",
    "gozareis": "gozar",
    "gozarem": "gozar",
    "gozaremos": "gozar",
    "gozares": "gozar",
    "gozaria": "gozar",
    "gozariam": "gozar",
    "gozarias": "gozar",
    "gozarmo": "gozar",
    "gozarmos": "gozar",
    "gozará": "gozar",
    "gozarás": "gozar",
    "gozarão": "gozar",
    "gozaríamos": "gozar",
    "gozaríeis": "gozar",
    "gozas": "gozar",
    "gozasse": "gozar",
    "gozassem": "gozar",
    "gozasses": "gozar",
    "gozaste": "gozar",
    "gozastes": "gozar",
    "gozava": "gozar",
    "gozavam": "gozar",
    "gozavas": "gozar",
    "goze": "gozar",
    "gozei": "gozar",
    "gozeis": "gozar",
    "gozem": "gozar",
    "gozemo": "gozar",
    "gozemos": "gozar",
    "gozes": "gozar",
    "gozo": "gozar",
    "gozona": "gozão",
    "gozonas": "gozão",
    "gozos": "gozo",
    "gozosa": "gozoso",
    "gozosas": "gozoso",
    "gozosos": "gozoso",
    "gozou": "gozar",
    "gozá": "gozar",
    "gozámo": "gozar",
    "gozámos": "gozar",
    "gozáramo": "gozar",
    "gozáramos": "gozar",
    "gozárei": "gozar",
    "gozáreis": "gozar",
    "gozásseis": "gozar",
    "gozássemos": "gozar",
    "gozávamo": "gozar",
    "gozávamos": "gozar",
    "gozávei": "gozar",
    "gozáveis": "gozar",
    "gozões": "gozão",
    "graais": "graal",
    "grabatos": "grabato",
    "graceja": "gracejar",
    "gracejada": "gracejar",
    "gracejadas": "gracejar",
    "gracejado": "gracejar",
    "gracejadora": "gracejador",
    "gracejadoras": "gracejador",
    "gracejadores": "gracejador",
    "gracejados": "gracejar",
    "gracejai": "gracejar",
    "gracejais": "gracejar",
    "gracejam": "gracejar",
    "gracejamo": "gracejar",
    "gracejamos": "gracejar",
    "gracejando": "gracejar",
    "gracejara": "gracejar",
    "gracejaram": "gracejar",
    "gracejaras": "gracejar",
    "gracejardes": "gracejar",
    "gracejarei": "gracejar",
    "gracejareis": "gracejar",
    "gracejarem": "gracejar",
    "gracejaremos": "gracejar",
    "gracejares": "gracejar",
    "gracejaria": "gracejar",
    "gracejariam": "gracejar",
    "gracejarias": "gracejar",
    "gracejarmo": "gracejar",
    "gracejarmos": "gracejar",
    "gracejará": "gracejar",
    "gracejarás": "gracejar",
    "gracejarão": "gracejar",
    "gracejaríamos": "gracejar",
    "gracejaríeis": "gracejar",
    "gracejas": "gracejar",
    "gracejasse": "gracejar",
    "gracejassem": "gracejar",
    "gracejasses": "gracejar",
    "gracejaste": "gracejar",
    "gracejastes": "gracejar",
    "gracejava": "gracejar",
    "gracejavam": "gracejar",
    "gracejavas": "gracejar",
    "graceje": "gracejar",
    "gracejei": "gracejar",
    "gracejeis": "gracejar",
    "gracejem": "gracejar",
    "gracejemo": "gracejar",
    "gracejemos": "gracejar",
    "gracejes": "gracejar",
    "gracejo": "gracejar",
    "gracejos": "gracejo",
    "gracejou": "gracejar",
    "gracejámo": "gracejar",
    "gracejámos": "gracejar",
    "gracejáramo": "gracejar",
    "gracejáramos": "gracejar",
    "gracejáreis": "gracejar",
    "gracejásseis": "gracejar",
    "gracejássemos": "gracejar",
    "gracejávamo": "gracejar",
    "gracejávamos": "gracejar",
    "gracejáveis": "gracejar",
    "gracenta": "gracento",
    "gracentas": "gracento",
    "gracentos": "gracento",
    "gracetas": "graceta",
    "gracifoliada": "gracifoliado",
    "gracifoliadas": "gracifoliado",
    "gracifoliados": "gracifoliado",
    "gracilidades": "gracilidade",
    "gracilirrostra": "gracilirrostro",
    "gracilirrostras": "gracilirrostro",
    "gracilirrostros": "gracilirrostro",
    "gracilípedes": "gracilípede",
    "gracinha": "graça",
    "gracinhas": "graça",
    "graciolada": "graciolado",
    "gracioladas": "graciolado",
    "graciolados": "graciolado",
    "graciolinas": "graciolina",
    "graciosa": "gracioso",
    "graciosas": "gracioso",
    "graciosidades": "graciosidade",
    "graciosos": "gracioso",
    "gracita": "gracitar",
    "gracitada": "gracitar",
    "gracitadas": "gracitar",
    "gracitado": "gracitar",
    "gracitados": "gracitar",
    "gracitai": "gracitar",
    "gracitais": "gracitar",
    "gracitam": "gracitar",
    "gracitamo": "gracitar",
    "gracitamos": "gracitar",
    "gracitando": "gracitar",
    "gracitara": "gracitar",
    "gracitaram": "gracitar",
    "gracitaras": "gracitar",
    "gracitardes": "gracitar",
    "gracitarei": "gracitar",
    "gracitareis": "gracitar",
    "gracitarem": "gracitar",
    "gracitaremos": "gracitar",
    "gracitares": "gracitar",
    "gracitaria": "gracitar",
    "gracitariam": "gracitar",
    "gracitarias": "gracitar",
    "gracitarmo": "gracitar",
    "gracitarmos": "gracitar",
    "gracitará": "gracitar",
    "gracitarás": "gracitar",
    "gracitarão": "gracitar",
    "gracitaríamos": "gracitar",
    "gracitaríeis": "gracitar",
    "gracitas": "gracitar",
    "gracitasse": "gracitar",
    "gracitassem": "gracitar",
    "gracitasses": "gracitar",
    "gracitaste": "gracitar",
    "gracitastes": "gracitar",
    "gracitava": "gracitar",
    "gracitavam": "gracitar",
    "gracitavas": "gracitar",
    "gracite": "gracitar",
    "gracitei": "gracitar",
    "graciteis": "gracitar",
    "gracitem": "gracitar",
    "gracitemo": "gracitar",
    "gracitemos": "gracitar",
    "gracites": "gracitar",
    "gracito": "gracitar",
    "gracitou": "gracitar",
    "gracitámo": "gracitar",
    "gracitámos": "gracitar",
    "gracitáramo": "gracitar",
    "gracitáramos": "gracitar",
    "gracitáreis": "gracitar",
    "gracitásseis": "gracitar",
    "gracitássemos": "gracitar",
    "gracitávamo": "gracitar",
    "gracitávamos": "gracitar",
    "gracitáveis": "gracitar",
    "gracílima": "grácil",
    "gracílimas": "grácil",
    "gracílimo": "grácil",
    "gracílimos": "grácil",
    "gracíolas": "gracíola",
    "grada": "grado",
    "gradada": "gradar",
    "gradadas": "gradar",
    "gradado": "gradar",
    "gradadora": "gradador",
    "gradadoras": "gradador",
    "gradadores": "gradador",
    "gradados": "gradar",
    "gradaduras": "gradadura",
    "gradagens": "gradagem",
    "gradai": "gradar",
    "gradais": "gradar",
    "gradam": "gradar",
    "gradamo": "gradar",
    "gradamos": "gradar",
    "gradando": "gradar",
    "gradara": "gradar",
    "gradaram": "gradar",
    "gradaras": "gradar",
    "gradarde": "gradar",
    "gradardes": "gradar",
    "gradare": "gradar",
    "gradarei": "gradar",
    "gradareis": "gradar",
    "gradarem": "gradar",
    "gradaremos": "gradar",
    "gradares": "gradar",
    "gradaria": "gradar",
    "gradariam": "gradar",
    "gradarias": "gradaria",
    "gradarmo": "gradar",
    "gradarmos": "gradar",
    "gradará": "gradar",
    "gradarás": "gradar",
    "gradarão": "gradar",
    "gradaríamos": "gradar",
    "gradaríeis": "gradar",
    "gradas": "grado",
    "gradasse": "gradar",
    "gradassem": "gradar",
    "gradasses": "gradar",
    "gradaste": "gradar",
    "gradastes": "gradar",
    "gradativa": "gradativo",
    "gradativas": "gradativo",
    "gradativos": "gradativo",
    "gradava": "gradar",
    "gradavam": "gradar",
    "gradavas": "gradar",
    "gradações": "gradação",
    "grade": "gradar",
    "gradeada": "gradear",
    "gradeadas": "gradear",
    "gradeado": "gradear",
    "gradeados": "gradear",
    "gradeai": "gradear",
    "gradeais": "gradear",
    "gradeamentos": "gradeamento",
    "gradeamo": "gradear",
    "gradeamos": "gradear",
    "gradeando": "gradear",
    "gradeara": "gradear",
    "gradearam": "gradear",
    "gradearas": "gradear",
    "gradearde": "gradear",
    "gradeardes": "gradear",
    "gradeare": "gradear",
    "gradearei": "gradear",
    "gradeareis": "gradear",
    "gradearem": "gradear",
    "gradearemos": "gradear",
    "gradeares": "gradear",
    "gradearia": "gradear",
    "gradeariam": "gradear",
    "gradearias": "gradear",
    "gradearmo": "gradear",
    "gradearmos": "gradear",
    "gradeará": "gradear",
    "gradearás": "gradear",
    "gradearão": "gradear",
    "gradearíamos": "gradear",
    "gradearíeis": "gradear",
    "gradeasse": "gradear",
    "gradeassem": "gradear",
    "gradeasses": "gradear",
    "gradeaste": "gradear",
    "gradeastes": "gradear",
    "gradeava": "gradear",
    "gradeavam": "gradear",
    "gradeavas": "gradear",
    "gradecas": "gradeca",
    "gradece": "gradecer",
    "gradecei": "gradecer",
    "gradeceis": "gradecer",
    "gradecem": "gradecer",
    "gradecemo": "gradecer",
    "gradecemos": "gradecer",
    "gradecendo": "gradecer",
    "gradecera": "gradecer",
    "gradeceram": "gradecer",
    "gradeceras": "gradecer",
    "gradecerdes": "gradecer",
    "gradecerei": "gradecer",
    "gradecereis": "gradecer",
    "gradecerem": "gradecer",
    "gradeceremos": "gradecer",
    "gradeceres": "gradecer",
    "gradeceria": "gradecer",
    "gradeceriam": "gradecer",
    "gradecerias": "gradecer",
    "gradecermo": "gradecer",
    "gradecermos": "gradecer",
    "gradecerá": "gradecer",
    "gradecerás": "gradecer",
    "gradecerão": "gradecer",
    "gradeceríamos": "gradecer",
    "gradeceríeis": "gradecer",
    "gradeces": "gradecer",
    "gradecesse": "gradecer",
    "gradecessem": "gradecer",
    "gradecesses": "gradecer",
    "gradeceste": "gradecer",
    "gradecestes": "gradecer",
    "gradeceu": "gradecer",
    "gradeci": "gradecer",
    "gradecia": "gradecer",
    "gradeciam": "gradecer",
    "gradecias": "gradecer",
    "gradecida": "gradecer",
    "gradecidas": "gradecer",
    "gradecido": "gradecer",
    "gradecidos": "gradecer",
    "gradecêramo": "gradecer",
    "gradecêramos": "gradecer",
    "gradecêreis": "gradecer",
    "gradecêsseis": "gradecer",
    "gradecêssemos": "gradecer",
    "gradecíamo": "gradecer",
    "gradecíamos": "gradecer",
    "gradecíeis": "gradecer",
    "gradeei": "gradear",
    "gradeeis": "gradear",
    "gradeemo": "gradear",
    "gradeemos": "gradear",
    "gradei": "gradar",
    "gradeia": "gradear",
    "gradeiam": "gradear",
    "gradeias": "gradear",
    "gradeie": "gradear",
    "gradeiem": "gradear",
    "gradeies": "gradear",
    "gradeio": "gradear",
    "gradeira": "gradeiro",
    "gradeiras": "gradeiro",
    "gradeiros": "gradeiro",
    "gradeis": "gradar",
    "gradeja": "gradejar",
    "gradejada": "gradejar",
    "gradejadas": "gradejar",
    "gradejado": "gradejar",
    "gradejados": "gradejar",
    "gradejai": "gradejar",
    "gradejais": "gradejar",
    "gradejam": "gradejar",
    "gradejamo": "gradejar",
    "gradejamos": "gradejar",
    "gradejando": "gradejar",
    "gradejara": "gradejar",
    "gradejaram": "gradejar",
    "gradejaras": "gradejar",
    "gradejarde": "gradejar",
    "gradejardes": "gradejar",
    "gradejare": "gradejar",
    "gradejarei": "gradejar",
    "gradejareis": "gradejar",
    "gradejarem": "gradejar",
    "gradejaremos": "gradejar",
    "gradejares": "gradejar",
    "gradejaria": "gradejar",
    "gradejariam": "gradejar",
    "gradejarias": "gradejar",
    "gradejarmo": "gradejar",
    "gradejarmos": "gradejar",
    "gradejará": "gradejar",
    "gradejarás": "gradejar",
    "gradejarão": "gradejar",
    "gradejaríamos": "gradejar",
    "gradejaríeis": "gradejar",
    "gradejas": "gradejar",
    "gradejasse": "gradejar",
    "gradejassem": "gradejar",
    "gradejasses": "gradejar",
    "gradejaste": "gradejar",
    "gradejastes": "gradejar",
    "gradejava": "gradejar",
    "gradejavam": "gradejar",
    "gradejavas": "gradejar",
    "gradeje": "gradejar",
    "gradejei": "gradejar",
    "gradejeis": "gradejar",
    "gradejem": "gradejar",
    "gradejemo": "gradejar",
    "gradejemos": "gradejar",
    "gradejes": "gradejar",
    "gradejo": "gradejar",
    "gradejou": "gradejar",
    "gradejá": "gradejar",
    "gradejámo": "gradejar",
    "gradejámos": "gradejar",
    "gradejáramo": "gradejar",
    "gradejáramos": "gradejar",
    "gradejárei": "gradejar",
    "gradejáreis": "gradejar",
    "gradejásseis": "gradejar",
    "gradejássemos": "gradejar",
    "gradejávamo": "gradejar",
    "gradejávamos": "gradejar",
    "gradejávei": "gradejar",
    "gradejáveis": "gradejar",
    "gradelhas": "gradelha",
    "gradem": "gradar",
    "grademo": "gradar",
    "grademos": "gradar",
    "gradeou": "gradear",
    "grades": "grade",
    "gradezas": "gradeza",
    "gradezecas": "gradezeca",
    "gradeá": "gradear",
    "gradeámo": "gradear",
    "gradeámos": "gradear",
    "gradeáramo": "gradear",
    "gradeáramos": "gradear",
    "gradeárei": "gradear",
    "gradeáreis": "gradear",
    "gradeásseis": "gradear",
    "gradeássemos": "gradear",
    "gradeávamo": "gradear",
    "gradeávamos": "gradear",
    "gradeávei": "gradear",
    "gradeáveis": "gradear",
    "gradeça": "gradecer",
    "gradeçais": "gradecer",
    "gradeçam": "gradecer",
    "gradeçamo": "gradecer",
    "gradeçamos": "gradecer",
    "gradeças": "gradecer",
    "gradeço": "gradecer",
    "gradientes": "gradiente",
    "gradina": "gradinar",
    "gradinada": "gradinar",
    "gradinadas": "gradinar",
    "gradinado": "gradinar",
    "gradinados": "gradinar",
    "gradinai": "gradinar",
    "gradinais": "gradinar",
    "gradinam": "gradinar",
    "gradinamo": "gradinar",
    "gradinamos": "gradinar",
    "gradinando": "gradinar",
    "gradinara": "gradinar",
    "gradinaram": "gradinar",
    "gradinaras": "gradinar",
    "gradinarde": "gradinar",
    "gradinardes": "gradinar",
    "gradinare": "gradinar",
    "gradinarei": "gradinar",
    "gradinareis": "gradinar",
    "gradinarem": "gradinar",
    "gradinaremos": "gradinar",
    "gradinares": "gradinar",
    "gradinaria": "gradinar",
    "gradinariam": "gradinar",
    "gradinarias": "gradinar",
    "gradinarmo": "gradinar",
    "gradinarmos": "gradinar",
    "gradinará": "gradinar",
    "gradinarás": "gradinar",
    "gradinarão": "gradinar",
    "gradinaríamos": "gradinar",
    "gradinaríeis": "gradinar",
    "gradinas": "gradinar",
    "gradinasse": "gradinar",
    "gradinassem": "gradinar",
    "gradinasses": "gradinar",
    "gradinaste": "gradinar",
    "gradinastes": "gradinar",
    "gradinava": "gradinar",
    "gradinavam": "gradinar",
    "gradinavas": "gradinar",
    "gradine": "gradinar",
    "gradinei": "gradinar",
    "gradineis": "gradinar",
    "gradinem": "gradinar",
    "gradinemo": "gradinar",
    "gradinemos": "gradinar",
    "gradines": "gradinar",
    "gradinha": "grade",
    "gradinhas": "grade",
    "gradino": "gradinar",
    "gradinou": "gradinar",
    "gradins": "gradim",
    "gradiná": "gradinar",
    "gradinámo": "gradinar",
    "gradinámos": "gradinar",
    "gradináramo": "gradinar",
    "gradináramos": "gradinar",
    "gradinárei": "gradinar",
    "gradináreis": "gradinar",
    "gradinásseis": "gradinar",
    "gradinássemos": "gradinar",
    "gradinávamo": "gradinar",
    "gradinávamos": "gradinar",
    "gradinávei": "gradinar",
    "gradináveis": "gradinar",
    "gradis": "gradil",
    "gradita": "grade",
    "graditas": "grade",
    "grado": "gradar",
    "grados": "grado",
    "gradotes": "gradote",
    "gradou": "gradar",
    "gradua": "graduar",
    "graduada": "graduar",
    "graduadas": "graduar",
    "graduado": "graduar",
    "graduadora": "graduador",
    "graduadoras": "graduador",
    "graduadores": "graduador",
    "graduados": "graduar",
    "graduai": "graduar",
    "graduais": "graduar",
    "gradualismos": "gradualismo",
    "gradualistas": "gradualista",
    "graduam": "graduar",
    "graduamentos": "graduamento",
    "graduamo": "graduar",
    "graduamos": "graduar",
    "graduando": "graduar",
    "graduara": "graduar",
    "graduaram": "graduar",
    "graduaras": "graduar",
    "graduarde": "graduar",
    "graduardes": "graduar",
    "graduare": "graduar",
    "graduarei": "graduar",
    "graduareis": "graduar",
    "graduarem": "graduar",
    "graduaremos": "graduar",
    "graduares": "graduar",
    "graduaria": "graduar",
    "graduariam": "graduar",
    "graduarias": "graduar",
    "graduarmo": "graduar",
    "graduarmos": "graduar",
    "graduará": "graduar",
    "graduarás": "graduar",
    "graduarão": "graduar",
    "graduaríamos": "graduar",
    "graduaríeis": "graduar",
    "graduas": "graduar",
    "graduasse": "graduar",
    "graduassem": "graduar",
    "graduasses": "graduar",
    "graduaste": "graduar",
    "graduastes": "graduar",
    "graduava": "graduar",
    "graduavam": "graduar",
    "graduavas": "graduar",
    "graduações": "graduação",
    "gradue": "graduar",
    "graduei": "graduar",
    "gradueis": "graduar",
    "graduem": "graduar",
    "graduemo": "graduar",
    "graduemos": "graduar",
    "gradues": "graduar",
    "graduo": "graduar",
    "graduou": "graduar",
    "graduras": "gradura",
    "graduá": "graduar",
    "graduámo": "graduar",
    "graduámos": "graduar",
    "graduáramo": "graduar",
    "graduáramos": "graduar",
    "graduárei": "graduar",
    "graduáreis": "graduar",
    "graduásseis": "graduar",
    "graduássemos": "graduar",
    "graduávamo": "graduar",
    "graduávamos": "graduar",
    "graduávei": "graduar",
    "graduáveis": "graduável",
    "gradá": "gradar",
    "gradámo": "gradar",
    "gradámos": "gradar",
    "gradáramo": "gradar",
    "gradáramos": "gradar",
    "gradárei": "gradar",
    "gradáreis": "gradar",
    "gradásseis": "gradar",
    "gradássemos": "gradar",
    "gradávamo": "gradar",
    "gradávamos": "gradar",
    "gradávei": "gradar",
    "gradáveis": "gradar",
    "gradões": "gradão",
    "graeiros": "graeiro",
    "graeladas": "graelada",
    "graelos": "graelo",
    "grafa": "grafar",
    "grafada": "grafar",
    "grafadas": "grafar",
    "grafado": "grafar",
    "grafados": "grafar",
    "grafai": "grafar",
    "grafais": "grafar",
    "grafam": "grafar",
    "grafamo": "grafar",
    "grafamos": "grafar",
    "grafando": "grafar",
    "grafanhotos": "grafanhoto",
    "grafara": "grafar",
    "grafaram": "grafar",
    "grafaras": "grafar",
    "grafarde": "grafar",
    "grafardes": "grafar",
    "grafare": "grafar",
    "grafarei": "grafar",
    "grafareis": "grafar",
    "grafarem": "grafar",
    "grafaremos": "grafar",
    "grafares": "grafar",
    "grafaria": "grafar",
    "grafariam": "grafar",
    "grafarias": "grafar",
    "grafarmo": "grafar",
    "grafarmos": "grafar",
    "grafará": "grafar",
    "grafarás": "grafar",
    "grafarão": "grafar",
    "grafaríamos": "grafar",
    "grafaríeis": "grafar",
    "grafas": "grafar",
    "grafasse": "grafar",
    "grafassem": "grafar",
    "grafasses": "grafar",
    "grafaste": "grafar",
    "grafastes": "grafar",
    "grafava": "grafar",
    "grafavam": "grafar",
    "grafavas": "grafar",
    "grafe": "grafar",
    "grafei": "grafar",
    "grafeis": "grafar",
    "grafem": "grafar",
    "grafemas": "grafema",
    "grafemo": "grafar",
    "grafemos": "grafar",
    "grafemáticas": "grafemática",
    "grafes": "grafar",
    "grafias": "grafia",
    "grafilas": "grafila",
    "grafismos": "grafismo",
    "grafistas": "grafista",
    "grafita": "grafitar",
    "grafitada": "grafitar",
    "grafitadas": "grafitar",
    "grafitado": "grafitar",
    "grafitados": "grafitar",
    "grafitai": "grafitar",
    "grafitais": "grafitar",
    "grafitam": "grafitar",
    "grafitamo": "grafitar",
    "grafitamos": "grafitar",
    "grafitando": "grafitar",
    "grafitara": "grafitar",
    "grafitaram": "grafitar",
    "grafitaras": "grafitar",
    "grafitarde": "grafitar",
    "grafitardes": "grafitar",
    "grafitare": "grafitar",
    "grafitarei": "grafitar",
    "grafitareis": "grafitar",
    "grafitarem": "grafitar",
    "grafitaremos": "grafitar",
    "grafitares": "grafitar",
    "grafitaria": "grafitar",
    "grafitariam": "grafitar",
    "grafitarias": "grafitar",
    "grafitarmo": "grafitar",
    "grafitarmos": "grafitar",
    "grafitará": "grafitar",
    "grafitarás": "grafitar",
    "grafitarão": "grafitar",
    "grafitaríamos": "grafitar",
    "grafitaríeis": "grafitar",
    "grafitas": "grafitar",
    "grafitasse": "grafitar",
    "grafitassem": "grafitar",
    "grafitasses": "grafitar",
    "grafitaste": "grafitar",
    "grafitastes": "grafitar",
    "grafitava": "grafitar",
    "grafitavam": "grafitar",
    "grafitavas": "grafitar",
    "grafite": "grafitar",
    "grafitei": "grafitar",
    "grafiteis": "grafitar",
    "grafitem": "grafitar",
    "grafitemo": "grafitar",
    "grafitemos": "grafitar",
    "grafites": "grafite",
    "grafitizações": "grafitização",
    "grafito": "grafitar",
    "grafitos": "grafito",
    "grafitou": "grafitar",
    "grafitá": "grafitar",
    "grafitámo": "grafitar",
    "grafitámos": "grafitar",
    "grafitáramo": "grafitar",
    "grafitáramos": "grafitar",
    "grafitárei": "grafitar",
    "grafitáreis": "grafitar",
    "grafitásseis": "grafitar",
    "grafitássemos": "grafitar",
    "grafitávamo": "grafitar",
    "grafitávamos": "grafitar",
    "grafitávei": "grafitar",
    "grafitáveis": "grafitar",
    "grafo": "grafar",
    "grafofobias": "grafofobia",
    "grafofones": "grafofone",
    "grafofóbica": "grafofóbico",
    "grafofóbicas": "grafofóbico",
    "grafofóbicos": "grafofóbico",
    "grafofónica": "grafofónico",
    "grafofónicas": "grafofónico",
    "grafofónicos": "grafofónico",
    "grafognosias": "grafognosia",
    "grafognosistas": "grafognosista",
    "grafognósica": "grafognósico",
    "grafognósicas": "grafognósico",
    "grafognósicos": "grafognósico",
    "grafologias": "grafologia",
    "grafologistas": "grafologista",
    "grafológica": "grafológico",
    "grafológicas": "grafológico",
    "grafológicos": "grafológico",
    "grafomanias": "grafomania",
    "grafomaníaca": "grafomaníaco",
    "grafomaníacas": "grafomaníaco",
    "grafomaníacos": "grafomaníaco",
    "grafométrica": "grafométrico",
    "grafométricas": "grafométrico",
    "grafométricos": "grafométrico",
    "grafonolas": "grafonola",
    "grafonomias": "grafonomia",
    "grafonomistas": "grafonomista",
    "grafonómica": "grafonómico",
    "grafonómicas": "grafonómico",
    "grafonómicos": "grafonómico",
    "grafopsicologistas": "grafopsicologista",
    "grafopsicológica": "grafopsicológico",
    "grafopsicológicas": "grafopsicológico",
    "grafopsicológicos": "grafopsicológico",
    "grafopsicóloga": "grafopsicólogo",
    "grafopsicólogas": "grafopsicólogo",
    "grafopsicólogos": "grafopsicólogo",
    "graforreias": "graforreia",
    "graforreica": "graforreico",
    "graforreicas": "graforreico",
    "graforreicos": "graforreico",
    "grafostática": "grafostático",
    "grafostáticas": "grafostático",
    "grafostáticos": "grafostático",
    "grafotipologias": "grafotipologia",
    "grafotipológica": "grafotipológico",
    "grafotipológicas": "grafotipológico",
    "grafotipológicos": "grafotipológico",
    "grafou": "grafar",
    "grafá": "grafar",
    "grafámo": "grafar",
    "grafámos": "grafar",
    "grafáramo": "grafar",
    "grafáramos": "grafar",
    "grafárei": "grafar",
    "grafáreis": "grafar",
    "grafásseis": "grafar",
    "grafássemos": "grafar",
    "grafávamo": "grafar",
    "grafávamos": "grafar",
    "grafávei": "grafar",
    "grafáveis": "grafar",
    "grafítica": "grafítico",
    "grafíticas": "grafítico",
    "grafíticos": "grafítico",
    "grafófoba": "grafófobo",
    "grafófobas": "grafófobo",
    "grafófobos": "grafófobo",
    "grafóloga": "grafólogo",
    "grafólogas": "grafólogo",
    "grafólogos": "grafólogo",
    "grafómana": "grafómano",
    "grafómanas": "grafómano",
    "grafómanos": "grafómano",
    "grafómetros": "grafómetro",
    "grageias": "grageia",
    "grageus": "grageu",
    "graia": "graiar",
    "graiada": "graiar",
    "graiadas": "graiar",
    "graiado": "graiar",
    "graiados": "graiar",
    "graiai": "graiar",
    "graiais": "graiar",
    "graiam": "graiar",
    "graiamo": "graiar",
    "graiamos": "graiar",
    "graiando": "graiar",
    "graiara": "graiar",
    "graiaram": "graiar",
    "graiaras": "graiar",
    "graiardes": "graiar",
    "graiarei": "graiar",
    "graiareis": "graiar",
    "graiarem": "graiar",
    "graiaremos": "graiar",
    "graiares": "graiar",
    "graiaria": "graiar",
    "graiariam": "graiar",
    "graiarias": "graiar",
    "graiarmo": "graiar",
    "graiarmos": "graiar",
    "graiará": "graiar",
    "graiarás": "graiar",
    "graiarão": "graiar",
    "graiaríamos": "graiar",
    "graiaríeis": "graiar",
    "graias": "graiar",
    "graiasse": "graiar",
    "graiassem": "graiar",
    "graiasses": "graiar",
    "graiaste": "graiar",
    "graiastes": "graiar",
    "graiava": "graiar",
    "graiavam": "graiar",
    "graiavas": "graiar",
    "graie": "graiar",
    "graiei": "graiar",
    "graieis": "graiar",
    "graiem": "graiar",
    "graiemo": "graiar",
    "graiemos": "graiar",
    "graies": "graiar",
    "grainhas": "grainha",
    "graio": "graiar",
    "graiou": "graiar",
    "grais": "gral",
    "graisenes": "graisen",
    "graiámo": "graiar",
    "graiámos": "graiar",
    "graiáramo": "graiar",
    "graiáramos": "graiar",
    "graiáreis": "graiar",
    "graiásseis": "graiar",
    "graiássemos": "graiar",
    "graiávamo": "graiar",
    "graiávamos": "graiar",
    "graiáveis": "graiar",
    "grajeadora": "grajeador",
    "grajeadoras": "grajeador",
    "grajeadores": "grajeador",
    "grajeias": "grajeia",
    "gralha": "gralhar",
    "gralhada": "gralhar",
    "gralhadas": "gralhar",
    "gralhado": "gralhar",
    "gralhadora": "gralhador",
    "gralhadoras": "gralhador",
    "gralhadores": "gralhador",
    "gralhados": "gralhar",
    "gralhai": "gralhar",
    "gralhais": "gralhar",
    "gralham": "gralhar",
    "gralhamo": "gralhar",
    "gralhamos": "gralhar",
    "gralhando": "gralhar",
    "gralhara": "gralhar",
    "gralharam": "gralhar",
    "gralharas": "gralhar",
    "gralhardes": "gralhar",
    "gralharei": "gralhar",
    "gralhareis": "gralhar",
    "gralharem": "gralhar",
    "gralharemos": "gralhar",
    "gralhares": "gralhar",
    "gralharia": "gralhar",
    "gralhariam": "gralhar",
    "gralharias": "gralhar",
    "gralharmo": "gralhar",
    "gralharmos": "gralhar",
    "gralhará": "gralhar",
    "gralharás": "gralhar",
    "gralharão": "gralhar",
    "gralharíamos": "gralhar",
    "gralharíeis": "gralhar",
    "gralhas": "gralhar",
    "gralhasse": "gralhar",
    "gralhassem": "gralhar",
    "gralhasses": "gralhar",
    "gralhaste": "gralhar",
    "gralhastes": "gralhar",
    "gralhava": "gralhar",
    "gralhavam": "gralhar",
    "gralhavas": "gralhar",
    "gralhe": "gralhar",
    "gralhei": "gralhar",
    "gralheiras": "gralheira",
    "gralheis": "gralhar",
    "gralhem": "gralhar",
    "gralhemo": "gralhar",
    "gralhemos": "gralhar",
    "gralhes": "gralhar",
    "gralho": "gralhar",
    "gralhos": "gralho",
    "gralhou": "gralhar",
    "gralhámo": "gralhar",
    "gralhámos": "gralhar",
    "gralháramo": "gralhar",
    "gralháramos": "gralhar",
    "gralháreis": "gralhar",
    "gralhásseis": "gralhar",
    "gralhássemos": "gralhar",
    "gralhávamo": "gralhar",
    "gralhávamos": "gralhar",
    "gralháveis": "gralhar",
    "grama": "gramar",
    "gramada": "gramar",
    "gramadas": "gramar",
    "gramadeiras": "gramadeira",
    "gramado": "gramar",
    "gramados": "gramar",
    "gramagens": "gramagem",
    "gramai": "gramar",
    "gramais": "gramar",
    "gramalheiras": "gramalheira",
    "gramam": "gramar",
    "gramamo": "gramar",
    "gramamos": "gramar",
    "gramando": "gramar",
    "gramara": "gramar",
    "gramaram": "gramar",
    "gramaras": "gramar",
    "gramarde": "gramar",
    "gramardes": "gramar",
    "gramare": "gramar",
    "gramarei": "gramar",
    "gramareis": "gramar",
    "gramarem": "gramar",
    "gramaremos": "gramar",
    "gramares": "gramar",
    "gramaria": "gramar",
    "gramariam": "gramar",
    "gramarias": "gramar",
    "gramarmo": "gramar",
    "gramarmos": "gramar",
    "gramará": "gramar",
    "gramarás": "gramar",
    "gramarão": "gramar",
    "gramaríamos": "gramar",
    "gramaríeis": "gramar",
    "gramas": "gramar",
    "gramasse": "gramar",
    "gramassem": "gramar",
    "gramasses": "gramar",
    "gramaste": "gramar",
    "gramastes": "gramar",
    "gramatas": "gramata",
    "gramatica": "gramaticar",
    "gramaticada": "gramaticar",
    "gramaticadas": "gramaticar",
    "gramaticado": "gramaticar",
    "gramaticados": "gramaticar",
    "gramaticais": "gramaticar",
    "gramaticalidades": "gramaticalidade",
    "gramaticalismos": "gramaticalismo",
    "gramaticaliza": "gramaticalizar",
    "gramaticalizada": "gramaticalizar",
    "gramaticalizadas": "gramaticalizar",
    "gramaticalizado": "gramaticalizar",
    "gramaticalizados": "gramaticalizar",
    "gramaticalizai": "gramaticalizar",
    "gramaticalizais": "gramaticalizar",
    "gramaticalizam": "gramaticalizar",
    "gramaticalizamo": "gramaticalizar",
    "gramaticalizamos": "gramaticalizar",
    "gramaticalizando": "gramaticalizar",
    "gramaticalizara": "gramaticalizar",
    "gramaticalizaram": "gramaticalizar",
    "gramaticalizaras": "gramaticalizar",
    "gramaticalizarde": "gramaticalizar",
    "gramaticalizardes": "gramaticalizar",
    "gramaticalizare": "gramaticalizar",
    "gramaticalizarei": "gramaticalizar",
    "gramaticalizareis": "gramaticalizar",
    "gramaticalizarem": "gramaticalizar",
    "gramaticalizaremos": "gramaticalizar",
    "gramaticalizares": "gramaticalizar",
    "gramaticalizaria": "gramaticalizar",
    "gramaticalizariam": "gramaticalizar",
    "gramaticalizarias": "gramaticalizar",
    "gramaticalizarmo": "gramaticalizar",
    "gramaticalizarmos": "gramaticalizar",
    "gramaticalizará": "gramaticalizar",
    "gramaticalizarás": "gramaticalizar",
    "gramaticalizarão": "gramaticalizar",
    "gramaticalizaríamos": "gramaticalizar",
    "gramaticalizaríeis": "gramaticalizar",
    "gramaticalizas": "gramaticalizar",
    "gramaticalizasse": "gramaticalizar",
    "gramaticalizassem": "gramaticalizar",
    "gramaticalizasses": "gramaticalizar",
    "gramaticalizaste": "gramaticalizar",
    "gramaticalizastes": "gramaticalizar",
    "gramaticalizava": "gramaticalizar",
    "gramaticalizavam": "gramaticalizar",
    "gramaticalizavas": "gramaticalizar",
    "gramaticalize": "gramaticalizar",
    "gramaticalizei": "gramaticalizar",
    "gramaticalizeis": "gramaticalizar",
    "gramaticalizem": "gramaticalizar",
    "gramaticalizemo": "gramaticalizar",
    "gramaticalizemos": "gramaticalizar",
    "gramaticalizes": "gramaticalizar",
    "gramaticalizo": "gramaticalizar",
    "gramaticalizou": "gramaticalizar",
    "gramaticalizá": "gramaticalizar",
    "gramaticalizámo": "gramaticalizar",
    "gramaticalizámos": "gramaticalizar",
    "gramaticalizáramo": "gramaticalizar",
    "gramaticalizáramos": "gramaticalizar",
    "gramaticalizárei": "gramaticalizar",
    "gramaticalizáreis": "gramaticalizar",
    "gramaticalizásseis": "gramaticalizar",
    "gramaticalizássemos": "gramaticalizar",
    "gramaticalizávamo": "gramaticalizar",
    "gramaticalizávamos": "gramaticalizar",
    "gramaticalizávei": "gramaticalizar",
    "gramaticalizáveis": "gramaticalizável",
    "gramaticam": "gramaticar",
    "gramaticamo": "gramaticar",
    "gramaticamos": "gramaticar",
    "gramaticando": "gramaticar",
    "gramaticara": "gramaticar",
    "gramaticaram": "gramaticar",
    "gramaticaras": "gramaticar",
    "gramaticardes": "gramaticar",
    "gramaticarei": "gramaticar",
    "gramaticareis": "gramaticar",
    "gramaticarem": "gramaticar",
    "gramaticaremos": "gramaticar",
    "gramaticares": "gramaticar",
    "gramaticaria": "gramaticar",
    "gramaticariam": "gramaticar",
    "gramaticarias": "gramaticar",
    "gramaticarmo": "gramaticar",
    "gramaticarmos": "gramaticar",
    "gramaticará": "gramaticar",
    "gramaticarás": "gramaticar",
    "gramaticarão": "gramaticar",
    "gramaticaríamos": "gramaticar",
    "gramaticaríeis": "gramaticar",
    "gramaticas": "gramaticar",
    "gramaticasse": "gramaticar",
    "gramaticassem": "gramaticar",
    "gramaticasses": "gramaticar",
    "gramaticaste": "gramaticar",
    "gramaticastes": "gramaticar",
    "gramaticava": "gramaticar",
    "gramaticavam": "gramaticar",
    "gramaticavas": "gramaticar",
    "gramaticistas": "gramaticista",
    "gramatico": "gramaticar",
    "gramaticografias": "gramaticografia",
    "gramaticográfica": "gramaticográfico",
    "gramaticográficas": "gramaticográfico",
    "gramaticográficos": "gramaticográfico",
    "gramaticologias": "gramaticologia",
    "gramaticologistas": "gramaticologista",
    "gramaticológica": "gramaticológico",
    "gramaticológicas": "gramaticológico",
    "gramaticológicos": "gramaticológico",
    "gramaticona": "gramaticão",
    "gramaticonas": "gramaticão",
    "gramaticou": "gramaticar",
    "gramaticámo": "gramaticar",
    "gramaticámos": "gramaticar",
    "gramaticáramo": "gramaticar",
    "gramaticáramos": "gramaticar",
    "gramaticáreis": "gramaticar",
    "gramaticásseis": "gramaticar",
    "gramaticássemos": "gramaticar",
    "gramaticávamo": "gramaticar",
    "gramaticávamos": "gramaticar",
    "gramaticáveis": "gramaticável",
    "gramaticógrafa": "gramaticógrafo",
    "gramaticógrafas": "gramaticógrafo",
    "gramaticógrafos": "gramaticógrafo",
    "gramaticóloga": "gramaticólogo",
    "gramaticólogas": "gramaticólogo",
    "gramaticólogos": "gramaticólogo",
    "gramaticões": "gramaticão",
    "gramatique": "gramaticar",
    "gramatiquei": "gramaticar",
    "gramatiqueis": "gramaticar",
    "gramatiquem": "gramaticar",
    "gramatiquemos": "gramaticar",
    "gramatiques": "gramaticar",
    "gramatiquices": "gramatiquice",
    "gramatistas": "gramatista",
    "gramatologias": "gramatologia",
    "gramatologistas": "gramatologista",
    "gramatológica": "gramatológico",
    "gramatológicas": "gramatológico",
    "gramatológicos": "gramatológico",
    "gramatóloga": "gramatólogo",
    "gramatólogas": "gramatólogo",
    "gramatólogos": "gramatólogo",
    "gramava": "gramar",
    "gramavam": "gramar",
    "gramavas": "gramar",
    "gramaços": "gramaço",
    "grame": "gramar",
    "gramei": "gramar",
    "grameis": "gramar",
    "gramem": "gramar",
    "gramemo": "gramar",
    "gramemos": "gramar",
    "grames": "gramar",
    "graminha": "graminhar",
    "graminhada": "graminhar",
    "graminhadas": "graminhar",
    "graminhado": "graminhar",
    "graminhados": "graminhar",
    "graminhai": "graminhar",
    "graminhais": "graminhar",
    "graminham": "graminhar",
    "graminhamo": "graminhar",
    "graminhamos": "graminhar",
    "graminhando": "graminhar",
    "graminhara": "graminhar",
    "graminharam": "graminhar",
    "graminharas": "graminhar",
    "graminharde": "graminhar",
    "graminhardes": "graminhar",
    "graminhare": "graminhar",
    "graminharei": "graminhar",
    "graminhareis": "graminhar",
    "graminharem": "graminhar",
    "graminharemos": "graminhar",
    "graminhares": "graminhar",
    "graminharia": "graminhar",
    "graminhariam": "graminhar",
    "graminharias": "graminhar",
    "graminharmo": "graminhar",
    "graminharmos": "graminhar",
    "graminhará": "graminhar",
    "graminharás": "graminhar",
    "graminharão": "graminhar",
    "graminharíamos": "graminhar",
    "graminharíeis": "graminhar",
    "graminhas": "graminhar",
    "graminhasse": "graminhar",
    "graminhassem": "graminhar",
    "graminhasses": "graminhar",
    "graminhaste": "graminhar",
    "graminhastes": "graminhar",
    "graminhava": "graminhar",
    "graminhavam": "graminhar",
    "graminhavas": "graminhar",
    "graminhe": "graminhar",
    "graminhei": "graminhar",
    "graminheira": "graminheiro",
    "graminheiras": "graminheiro",
    "graminheiros": "graminheiro",
    "graminheis": "graminhar",
    "graminhem": "graminhar",
    "graminhemo": "graminhar",
    "graminhemos": "graminhar",
    "graminhes": "graminhar",
    "graminho": "graminhar",
    "graminhos": "graminho",
    "graminhou": "graminhar",
    "graminhá": "graminhar",
    "graminhámo": "graminhar",
    "graminhámos": "graminhar",
    "graminháramo": "graminhar",
    "graminháramos": "graminhar",
    "graminhárei": "graminhar",
    "graminháreis": "graminhar",
    "graminhásseis": "graminhar",
    "graminhássemos": "graminhar",
    "graminhávamo": "graminhar",
    "graminhávamos": "graminhar",
    "graminhávei": "graminhar",
    "graminháveis": "graminhar",
    "graminiformes": "graminiforme",
    "graminosa": "graminoso",
    "graminosas": "graminoso",
    "graminosos": "graminoso",
    "graminícolas": "graminícola",
    "graminívora": "graminívoro",
    "graminívoras": "graminívoro",
    "graminívoros": "graminívoro",
    "gramo": "gramar",
    "gramofones": "gramofone",
    "gramofónica": "gramofónico",
    "gramofónicas": "gramofónico",
    "gramofónicos": "gramofónico",
    "gramométrica": "gramométrico",
    "gramométricas": "gramométrico",
    "gramométricos": "gramométrico",
    "gramonilhos": "gramonilho",
    "gramou": "gramar",
    "gramozilhos": "gramozilho",
    "grampa": "grampar",
    "grampada": "grampar",
    "grampadas": "grampar",
    "grampado": "grampar",
    "grampados": "grampar",
    "grampai": "grampar",
    "grampais": "grampar",
    "grampam": "grampar",
    "grampamo": "grampar",
    "grampamos": "grampar",
    "grampando": "grampar",
    "grampara": "grampar",
    "gramparam": "grampar",
    "gramparas": "grampar",
    "gramparde": "grampar",
    "grampardes": "grampar",
    "grampare": "grampar",
    "gramparei": "grampar",
    "grampareis": "grampar",
    "gramparem": "grampar",
    "gramparemos": "grampar",
    "grampares": "grampar",
    "gramparia": "grampar",
    "grampariam": "grampar",
    "gramparias": "grampar",
    "gramparmo": "grampar",
    "gramparmos": "grampar",
    "grampará": "grampar",
    "gramparás": "grampar",
    "gramparão": "grampar",
    "gramparíamos": "grampar",
    "gramparíeis": "grampar",
    "grampas": "grampar",
    "grampasse": "grampar",
    "grampassem": "grampar",
    "grampasses": "grampar",
    "grampaste": "grampar",
    "grampastes": "grampar",
    "grampava": "grampar",
    "grampavam": "grampar",
    "grampavas": "grampar",
    "grampe": "grampar",
    "grampeada": "grampear",
    "grampeadas": "grampear",
    "grampeado": "grampear",
    "grampeados": "grampear",
    "grampeai": "grampear",
    "grampeais": "grampear",
    "grampeamo": "grampear",
    "grampeamos": "grampear",
    "grampeando": "grampear",
    "grampeara": "grampear",
    "grampearam": "grampear",
    "grampearas": "grampear",
    "grampearde": "grampear",
    "grampeardes": "grampear",
    "grampeare": "grampear",
    "grampearei": "grampear",
    "grampeareis": "grampear",
    "grampearem": "grampear",
    "grampearemos": "grampear",
    "grampeares": "grampear",
    "grampearia": "grampear",
    "grampeariam": "grampear",
    "grampearias": "grampear",
    "grampearmo": "grampear",
    "grampearmos": "grampear",
    "grampeará": "grampear",
    "grampearás": "grampear",
    "grampearão": "grampear",
    "grampearíamos": "grampear",
    "grampearíeis": "grampear",
    "grampeasse": "grampear",
    "grampeassem": "grampear",
    "grampeasses": "grampear",
    "grampeaste": "grampear",
    "grampeastes": "grampear",
    "grampeava": "grampear",
    "grampeavam": "grampear",
    "grampeavas": "grampear",
    "grampeei": "grampear",
    "grampeeis": "grampear",
    "grampeemo": "grampear",
    "grampeemos": "grampear",
    "grampei": "grampar",
    "grampeia": "grampear",
    "grampeiam": "grampear",
    "grampeias": "grampear",
    "grampeie": "grampear",
    "grampeiem": "grampear",
    "grampeies": "grampear",
    "grampeio": "grampear",
    "grampeis": "grampar",
    "grampem": "grampar",
    "grampemo": "grampar",
    "grampemos": "grampar",
    "grampeou": "grampear",
    "grampes": "grampar",
    "grampeá": "grampear",
    "grampeámo": "grampear",
    "grampeámos": "grampear",
    "grampeáramo": "grampear",
    "grampeáramos": "grampear",
    "grampeárei": "grampear",
    "grampeáreis": "grampear",
    "grampeásseis": "grampear",
    "grampeássemos": "grampear",
    "grampeávamo": "grampear",
    "grampeávamos": "grampear",
    "grampeávei": "grampear",
    "grampeáveis": "grampear",
    "grampo": "grampar",
    "grampos": "grampo",
    "grampou": "grampar",
    "grampá": "grampar",
    "grampámo": "grampar",
    "grampámos": "grampar",
    "grampáramo": "grampar",
    "grampáramos": "grampar",
    "grampárei": "grampar",
    "grampáreis": "grampar",
    "grampásseis": "grampar",
    "grampássemos": "grampar",
    "grampávamo": "grampar",
    "grampávamos": "grampar",
    "grampávei": "grampar",
    "grampáveis": "grampar",
    "gramá": "gramar",
    "gramámo": "gramar",
    "gramámos": "gramar",
    "gramáramo": "gramar",
    "gramáramos": "gramar",
    "gramárei": "gramar",
    "gramáreis": "gramar",
    "gramásseis": "gramar",
    "gramássemos": "gramar",
    "gramática": "gramático",
    "gramáticas": "gramático",
    "gramáticos": "gramático",
    "gramávamo": "gramar",
    "gramávamos": "gramar",
    "gramávei": "gramar",
    "gramáveis": "gramável",
    "gramínea": "gramíneo",
    "gramíneas": "gramíneo",
    "gramíneos": "gramíneo",
    "gramómetros": "gramómetro",
    "gramões": "gramão",
    "grana": "granir",
    "granada": "granar",
    "granadas": "granar",
    "granadeiros": "granadeiro",
    "granadilhos": "granadilho",
    "granadina": "granadino",
    "granadinas": "granadino",
    "granadinos": "granadino",
    "granadis": "granadil",
    "granado": "granar",
    "granadora": "granador",
    "granadoras": "granador",
    "granadores": "granador",
    "granados": "granar",
    "granai": "granar",
    "granais": "granir",
    "granalhas": "granalha",
    "granam": "granir",
    "granamo": "granir",
    "granamos": "granir",
    "granando": "granar",
    "granara": "granar",
    "granaram": "granar",
    "granaras": "granar",
    "granarde": "granar",
    "granardes": "granar",
    "granare": "granar",
    "granarei": "granar",
    "granareis": "granar",
    "granarem": "granar",
    "granaremos": "granar",
    "granares": "granar",
    "granaria": "granar",
    "granariam": "granar",
    "granarias": "granar",
    "granarmo": "granar",
    "granarmos": "granar",
    "granará": "granar",
    "granarás": "granar",
    "granarão": "granar",
    "granaríamos": "granar",
    "granaríeis": "granar",
    "granas": "granir",
    "granasse": "granar",
    "granassem": "granar",
    "granasses": "granar",
    "granaste": "granar",
    "granastes": "granar",
    "granates": "granate",
    "granava": "granar",
    "granavam": "granar",
    "granavas": "granar",
    "grandalhaça": "grandalhaço",
    "grandalhaças": "grandalhaço",
    "grandalhaços": "grandalhaço",
    "grandalhona": "grandalhão",
    "grandalhonas": "grandalhão",
    "grandalhões": "grandalhão",
    "grandeca": "grandeco",
    "grandecas": "grandeco",
    "grandecos": "grandeco",
    "grandeiras": "grandeira",
    "grandes": "grande",
    "grandeva": "grandevo",
    "grandevas": "grandevo",
    "grandevos": "grandevo",
    "grandezas": "grandeza",
    "grandiloquentes": "grandiloquente",
    "grandiloquências": "grandiloquência",
    "grandinha": "grande",
    "grandinhas": "grande",
    "grandinho": "grande",
    "grandinhos": "grande",
    "grandiosa": "grandioso",
    "grandiosas": "grandioso",
    "grandiosidades": "grandiosidade",
    "grandiosos": "grandioso",
    "grandita": "grande",
    "granditas": "grande",
    "grandito": "grande",
    "granditos": "grande",
    "grandona": "grandão",
    "grandonas": "grandão",
    "grandota": "grandote",
    "grandotas": "grandote",
    "grandotes": "grandote",
    "granduras": "grandura",
    "grandíloqua": "grandíloquo",
    "grandíloquas": "grandíloquo",
    "grandíloquos": "grandíloquo",
    "grandíssima": "grande",
    "grandíssimas": "grande",
    "grandíssimo": "grande",
    "grandíssimos": "grande",
    "grandões": "grandão",
    "grane": "granir",
    "graneada": "granear",
    "graneadas": "granear",
    "graneado": "granear",
    "graneados": "granear",
    "graneai": "granear",
    "graneais": "granear",
    "graneamo": "granear",
    "graneamos": "granear",
    "graneando": "granear",
    "graneara": "granear",
    "granearam": "granear",
    "granearas": "granear",
    "graneardes": "granear",
    "granearei": "granear",
    "graneareis": "granear",
    "granearem": "granear",
    "granearemos": "granear",
    "graneares": "granear",
    "granearia": "granear",
    "graneariam": "granear",
    "granearias": "granear",
    "granearmo": "granear",
    "granearmos": "granear",
    "graneará": "granear",
    "granearás": "granear",
    "granearão": "granear",
    "granearíamos": "granear",
    "granearíeis": "granear",
    "graneasse": "granear",
    "graneassem": "granear",
    "graneasses": "granear",
    "graneaste": "granear",
    "graneastes": "granear",
    "graneava": "granear",
    "graneavam": "granear",
    "graneavas": "granear",
    "graneei": "granear",
    "graneeis": "granear",
    "graneemo": "granear",
    "graneemos": "granear",
    "granei": "granar",
    "graneia": "granear",
    "graneiam": "granear",
    "graneias": "granear",
    "graneie": "granear",
    "graneiem": "granear",
    "graneies": "granear",
    "graneio": "granear",
    "graneis": "granar",
    "graneleira": "graneleiro",
    "graneleiras": "graneleiro",
    "graneleiros": "graneleiro",
    "granem": "granir",
    "granemo": "granar",
    "granemos": "granar",
    "graneou": "granear",
    "granes": "granir",
    "graneámo": "granear",
    "graneámos": "granear",
    "graneáramo": "granear",
    "graneáramos": "granear",
    "graneáreis": "granear",
    "graneásseis": "granear",
    "graneássemos": "granear",
    "graneávamo": "granear",
    "graneávamos": "granear",
    "graneáveis": "granear",
    "grani": "granir",
    "grania": "granir",
    "graniam": "granir",
    "granias": "granir",
    "granida": "granir",
    "granidas": "granir",
    "granido": "granir",
    "granidores": "granidor",
    "granidos": "granir",
    "graniformes": "graniforme",
    "granilitos": "granilito",
    "granimo": "granir",
    "granimos": "granir",
    "granindo": "granir",
    "granira": "granir",
    "graniram": "granir",
    "graniras": "granir",
    "granirde": "granir",
    "granirdes": "granir",
    "granire": "granir",
    "granirei": "granir",
    "granireis": "granir",
    "granirem": "granir",
    "graniremos": "granir",
    "granires": "granir",
    "graniria": "granir",
    "graniriam": "granir",
    "granirias": "granir",
    "granirmo": "granir",
    "granirmos": "granir",
    "granirá": "granir",
    "granirás": "granir",
    "granirão": "granir",
    "graniríamos": "granir",
    "graniríeis": "granir",
    "granis": "granir",
    "granisse": "granir",
    "granissem": "granir",
    "granisses": "granir",
    "graniste": "granir",
    "granistes": "granir",
    "granisés": "granisé",
    "granita": "granitar",
    "granitada": "granitar",
    "granitadas": "granitar",
    "granitado": "granitar",
    "granitados": "granitar",
    "granitai": "granitar",
    "granitais": "granitar",
    "granitam": "granitar",
    "granitamo": "granitar",
    "granitamos": "granitar",
    "granitando": "granitar",
    "granitara": "granitar",
    "granitaram": "granitar",
    "granitaras": "granitar",
    "granitarde": "granitar",
    "granitardes": "granitar",
    "granitare": "granitar",
    "granitarei": "granitar",
    "granitareis": "granitar",
    "granitarem": "granitar",
    "granitaremos": "granitar",
    "granitares": "granitar",
    "granitaria": "granitar",
    "granitariam": "granitar",
    "granitarias": "granitar",
    "granitarmo": "granitar",
    "granitarmos": "granitar",
    "granitará": "granitar",
    "granitarás": "granitar",
    "granitarão": "granitar",
    "granitaríamos": "granitar",
    "granitaríeis": "granitar",
    "granitas": "granitar",
    "granitasse": "granitar",
    "granitassem": "granitar",
    "granitasses": "granitar",
    "granitaste": "granitar",
    "granitastes": "granitar",
    "granitava": "granitar",
    "granitavam": "granitar",
    "granitavas": "granitar",
    "granite": "granitar",
    "granitei": "granitar",
    "graniteis": "granitar",
    "granitem": "granitar",
    "granitemo": "granitar",
    "granitemos": "granitar",
    "granites": "granitar",
    "granitizações": "granitização",
    "granito": "granitar",
    "granitos": "granito",
    "granitosa": "granitoso",
    "granitosas": "granitoso",
    "granitosos": "granitoso",
    "granitou": "granitar",
    "granitá": "granitar",
    "granitámo": "granitar",
    "granitámos": "granitar",
    "granitáramo": "granitar",
    "granitáramos": "granitar",
    "granitárei": "granitar",
    "granitáreis": "granitar",
    "granitásseis": "granitar",
    "granitássemos": "granitar",
    "granitávamo": "granitar",
    "granitávamos": "granitar",
    "granitávei": "granitar",
    "granitáveis": "granitar",
    "granitóides": "granitóide",
    "granitões": "granitão",
    "graniu": "granir",
    "graniza": "granizar",
    "granizada": "granizar",
    "granizadas": "granizar",
    "granizado": "granizar",
    "granizadora": "granizador",
    "granizadoras": "granizador",
    "granizadores": "granizador",
    "granizados": "granizar",
    "granizai": "granizar",
    "granizais": "granizar",
    "granizam": "granizar",
    "granizamo": "granizar",
    "granizamos": "granizar",
    "granizando": "granizar",
    "granizara": "granizar",
    "granizaram": "granizar",
    "granizaras": "granizar",
    "granizardes": "granizar",
    "granizarei": "granizar",
    "granizareis": "granizar",
    "granizarem": "granizar",
    "granizaremos": "granizar",
    "granizares": "granizar",
    "granizaria": "granizar",
    "granizariam": "granizar",
    "granizarias": "granizar",
    "granizarmo": "granizar",
    "granizarmos": "granizar",
    "granizará": "granizar",
    "granizarás": "granizar",
    "granizarão": "granizar",
    "granizaríamos": "granizar",
    "granizaríeis": "granizar",
    "granizas": "granizar",
    "granizasse": "granizar",
    "granizassem": "granizar",
    "granizasses": "granizar",
    "granizaste": "granizar",
    "granizastes": "granizar",
    "granizava": "granizar",
    "granizavam": "granizar",
    "granizavas": "granizar",
    "granize": "granizar",
    "granizei": "granizar",
    "granizeis": "granizar",
    "granizem": "granizar",
    "granizemo": "granizar",
    "granizemos": "granizar",
    "granizes": "granizar",
    "granizo": "granizar",
    "granizos": "granizo",
    "granizou": "granizar",
    "granizámo": "granizar",
    "granizámos": "granizar",
    "granizáramo": "granizar",
    "granizáramos": "granizar",
    "granizáreis": "granizar",
    "granizásseis": "granizar",
    "granizássemos": "granizar",
    "granizávamo": "granizar",
    "granizávamos": "granizar",
    "granizáveis": "granizar",
    "granjarias": "granjaria",
    "granjas": "granja",
    "granjeada": "granjear",
    "granjeadas": "granjear",
    "granjeado": "granjear",
    "granjeadora": "granjeador",
    "granjeadoras": "granjeador",
    "granjeadores": "granjeador",
    "granjeados": "granjear",
    "granjeai": "granjear",
    "granjeais": "granjear",
    "granjeamo": "granjear",
    "granjeamos": "granjear",
    "granjeando": "granjear",
    "granjeara": "granjear",
    "granjearam": "granjear",
    "granjearas": "granjear",
    "granjearde": "granjear",
    "granjeardes": "granjear",
    "granjeare": "granjear",
    "granjearei": "granjear",
    "granjeareis": "granjear",
    "granjearem": "granjear",
    "granjearemos": "granjear",
    "granjeares": "granjear",
    "granjearia": "granjear",
    "granjeariam": "granjear",
    "granjearias": "granjearia",
    "granjearmo": "granjear",
    "granjearmos": "granjear",
    "granjeará": "granjear",
    "granjearás": "granjear",
    "granjearão": "granjear",
    "granjearíamos": "granjear",
    "granjearíeis": "granjear",
    "granjeasse": "granjear",
    "granjeassem": "granjear",
    "granjeasses": "granjear",
    "granjeaste": "granjear",
    "granjeastes": "granjear",
    "granjeava": "granjear",
    "granjeavam": "granjear",
    "granjeavas": "granjear",
    "granjeei": "granjear",
    "granjeeis": "granjear",
    "granjeemo": "granjear",
    "granjeemos": "granjear",
    "granjeia": "granjear",
    "granjeiam": "granjear",
    "granjeias": "granjear",
    "granjeie": "granjear",
    "granjeiem": "granjear",
    "granjeies": "granjear",
    "granjeio": "granjear",
    "granjeios": "granjeio",
    "granjeira": "granjeiro",
    "granjeiras": "granjeiro",
    "granjeiros": "granjeiro",
    "granjeou": "granjear",
    "granjeá": "granjear",
    "granjeámo": "granjear",
    "granjeámos": "granjear",
    "granjeáramo": "granjear",
    "granjeáramos": "granjear",
    "granjeárei": "granjear",
    "granjeáreis": "granjear",
    "granjeásseis": "granjear",
    "granjeássemos": "granjear",
    "granjeávamo": "granjear",
    "granjeávamos": "granjear",
    "granjeávei": "granjear",
    "granjeáveis": "granjear",
    "granjoladas": "granjolada",
    "granjolas": "granjola",
    "granjolices": "granjolice",
    "granjos": "granjo",
    "grano": "granir",
    "granoblástica": "granoblástico",
    "granoblásticas": "granoblástico",
    "granoblásticos": "granoblástico",
    "granodioritos": "granodiorito",
    "granodiorítica": "granodiorítico",
    "granodioríticas": "granodiorítico",
    "granodioríticos": "granodiorítico",
    "granosa": "granoso",
    "granosas": "granoso",
    "granosos": "granoso",
    "granou": "granar",
    "granula": "granular",
    "granulada": "granular",
    "granuladas": "granular",
    "granulado": "granular",
    "granuladoras": "granuladora",
    "granulados": "granular",
    "granulagens": "granulagem",
    "granulai": "granular",
    "granulais": "granular",
    "granulam": "granular",
    "granulamo": "granular",
    "granulamos": "granular",
    "granulando": "granular",
    "granulara": "granular",
    "granularam": "granular",
    "granularas": "granular",
    "granularde": "granular",
    "granulardes": "granular",
    "granulare": "granular",
    "granularei": "granular",
    "granulareis": "granular",
    "granularem": "granular",
    "granularemos": "granular",
    "granulares": "granular",
    "granularia": "granular",
    "granulariam": "granular",
    "granularias": "granular",
    "granularmo": "granular",
    "granularmos": "granular",
    "granulará": "granular",
    "granularás": "granular",
    "granularão": "granular",
    "granularíamos": "granular",
    "granularíeis": "granular",
    "granulas": "granular",
    "granulasse": "granular",
    "granulassem": "granular",
    "granulasses": "granular",
    "granulaste": "granular",
    "granulastes": "granular",
    "granulava": "granular",
    "granulavam": "granular",
    "granulavas": "granular",
    "granulações": "granulação",
    "granule": "granular",
    "granulei": "granular",
    "granuleis": "granular",
    "granulem": "granular",
    "granulemo": "granular",
    "granulemos": "granular",
    "granules": "granular",
    "granulias": "granulia",
    "granuliformes": "granuliforme",
    "granulites": "granulite",
    "granulo": "granular",
    "granulocítica": "granulocítico",
    "granulocíticas": "granulocítico",
    "granulocíticos": "granulocítico",
    "granulomas": "granuloma",
    "granulometrias": "granulometria",
    "granulométrica": "granulométrico",
    "granulométricas": "granulométrico",
    "granulométricos": "granulométrico",
    "granulosa": "granuloso",
    "granulosas": "granuloso",
    "granulosidades": "granulosidade",
    "granulosos": "granuloso",
    "granulou": "granular",
    "granulá": "granular",
    "granulámo": "granular",
    "granulámos": "granular",
    "granuláramo": "granular",
    "granuláramos": "granular",
    "granulárei": "granular",
    "granuláreis": "granular",
    "granulásseis": "granular",
    "granulássemos": "granular",
    "granulávamo": "granular",
    "granulávamos": "granular",
    "granulávei": "granular",
    "granuláveis": "granular",
    "granulítica": "granulítico",
    "granulíticas": "granulítico",
    "granulíticos": "granulítico",
    "granulócitos": "granulócito",
    "granzais": "granzal",
    "granzas": "granza",
    "graná": "granar",
    "granámo": "granar",
    "granámos": "granar",
    "granáramo": "granar",
    "granáramos": "granar",
    "granárei": "granar",
    "granáreis": "granar",
    "granásseis": "granar",
    "granássemos": "granar",
    "granávamo": "granar",
    "granávamos": "granar",
    "granávei": "granar",
    "granáveis": "granar",
    "granéis": "granel",
    "graníamo": "granir",
    "graníamos": "granir",
    "graníei": "granir",
    "graníeis": "granir",
    "granífera": "granífero",
    "graníferas": "granífero",
    "graníferos": "granífero",
    "graníramo": "granir",
    "graníramos": "granir",
    "granírei": "granir",
    "graníreis": "granir",
    "granísseis": "granir",
    "graníssemos": "granir",
    "granítica": "granítico",
    "graníticas": "granítico",
    "graníticos": "granítico",
    "granívora": "granívoro",
    "granívoras": "granívoro",
    "granívoros": "granívoro",
    "granófiros": "granófiro",
    "grapas": "grapa",
    "grapsicologias": "grapsicologia",
    "graptólitos": "graptólito",
    "grasna": "grasnar",
    "grasnada": "grasnar",
    "grasnadas": "grasnar",
    "grasnadelas": "grasnadela",
    "grasnado": "grasnar",
    "grasnadora": "grasnador",
    "grasnadoras": "grasnador",
    "grasnadores": "grasnador",
    "grasnados": "grasnar",
    "grasnai": "grasnar",
    "grasnais": "grasnar",
    "grasnam": "grasnar",
    "grasnamo": "grasnar",
    "grasnamos": "grasnar",
    "grasnando": "grasnar",
    "grasnantes": "grasnante",
    "grasnara": "grasnar",
    "grasnaram": "grasnar",
    "grasnaras": "grasnar",
    "grasnardes": "grasnar",
    "grasnarei": "grasnar",
    "grasnareis": "grasnar",
    "grasnarem": "grasnar",
    "grasnaremos": "grasnar",
    "grasnares": "grasnar",
    "grasnaria": "grasnar",
    "grasnariam": "grasnar",
    "grasnarias": "grasnar",
    "grasnarmo": "grasnar",
    "grasnarmos": "grasnar",
    "grasnará": "grasnar",
    "grasnarás": "grasnar",
    "grasnarão": "grasnar",
    "grasnaríamos": "grasnar",
    "grasnaríeis": "grasnar",
    "grasnas": "grasnar",
    "grasnasse": "grasnar",
    "grasnassem": "grasnar",
    "grasnasses": "grasnar",
    "grasnaste": "grasnar",
    "grasnastes": "grasnar",
    "grasnava": "grasnar",
    "grasnavam": "grasnar",
    "grasnavas": "grasnar",
    "grasne": "grasnar",
    "grasnei": "grasnar",
    "grasneis": "grasnar",
    "grasnem": "grasnar",
    "grasnemo": "grasnar",
    "grasnemos": "grasnar",
    "grasnes": "grasnar",
    "grasnidos": "grasnido",
    "grasno": "grasnar",
    "grasnos": "grasno",
    "grasnou": "grasnar",
    "grasnámo": "grasnar",
    "grasnámos": "grasnar",
    "grasnáramo": "grasnar",
    "grasnáramos": "grasnar",
    "grasnáreis": "grasnar",
    "grasnásseis": "grasnar",
    "grasnássemos": "grasnar",
    "grasnávamo": "grasnar",
    "grasnávamos": "grasnar",
    "grasnáveis": "grasnar",
    "graspas": "graspa",
    "grassa": "grassar",
    "grassada": "grassar",
    "grassadas": "grassar",
    "grassado": "grassar",
    "grassados": "grassar",
    "grassai": "grassar",
    "grassais": "grassar",
    "grassam": "grassar",
    "grassamo": "grassar",
    "grassamos": "grassar",
    "grassando": "grassar",
    "grassara": "grassar",
    "grassaram": "grassar",
    "grassaras": "grassar",
    "grassardes": "grassar",
    "grassarei": "grassar",
    "grassareis": "grassar",
    "grassarem": "grassar",
    "grassaremos": "grassar",
    "grassares": "grassar",
    "grassaria": "grassar",
    "grassariam": "grassar",
    "grassarias": "grassar",
    "grassarmo": "grassar",
    "grassarmos": "grassar",
    "grassará": "grassar",
    "grassarás": "grassar",
    "grassarão": "grassar",
    "grassaríamos": "grassar",
    "grassaríeis": "grassar",
    "grassas": "grassar",
    "grassasse": "grassar",
    "grassassem": "grassar",
    "grassasses": "grassar",
    "grassaste": "grassar",
    "grassastes": "grassar",
    "grassava": "grassar",
    "grassavam": "grassar",
    "grassavas": "grassar",
    "grasse": "grassar",
    "grassei": "grassar",
    "grasseis": "grassar",
    "grassem": "grassar",
    "grassemo": "grassar",
    "grassemos": "grassar",
    "grasses": "grassar",
    "grasso": "grassar",
    "grassou": "grassar",
    "grassámo": "grassar",
    "grassámos": "grassar",
    "grassáramo": "grassar",
    "grassáramos": "grassar",
    "grassáreis": "grassar",
    "grassásseis": "grassar",
    "grassássemos": "grassar",
    "grassávamo": "grassar",
    "grassávamos": "grassar",
    "grassáveis": "grassar",
    "grata": "grato",
    "gratas": "grato",
    "grateias": "grateia",
    "gratidões": "gratidão",
    "gratifica": "gratificar",
    "gratificada": "gratificar",
    "gratificadas": "gratificar",
    "gratificado": "gratificar",
    "gratificadora": "gratificador",
    "gratificadoras": "gratificador",
    "gratificadores": "gratificador",
    "gratificados": "gratificar",
    "gratificai": "gratificar",
    "gratificais": "gratificar",
    "gratificam": "gratificar",
    "gratificamo": "gratificar",
    "gratificamos": "gratificar",
    "gratificando": "gratificar",
    "gratificantes": "gratificante",
    "gratificara": "gratificar",
    "gratificaram": "gratificar",
    "gratificaras": "gratificar",
    "gratificarde": "gratificar",
    "gratificardes": "gratificar",
    "gratificare": "gratificar",
    "gratificarei": "gratificar",
    "gratificareis": "gratificar",
    "gratificarem": "gratificar",
    "gratificaremos": "gratificar",
    "gratificares": "gratificar",
    "gratificaria": "gratificar",
    "gratificariam": "gratificar",
    "gratificarias": "gratificar",
    "gratificarmo": "gratificar",
    "gratificarmos": "gratificar",
    "gratificará": "gratificar",
    "gratificarás": "gratificar",
    "gratificarão": "gratificar",
    "gratificaríamos": "gratificar",
    "gratificaríeis": "gratificar",
    "gratificas": "gratificar",
    "gratificasse": "gratificar",
    "gratificassem": "gratificar",
    "gratificasses": "gratificar",
    "gratificaste": "gratificar",
    "gratificastes": "gratificar",
    "gratificava": "gratificar",
    "gratificavam": "gratificar",
    "gratificavas": "gratificar",
    "gratificações": "gratificação",
    "gratifico": "gratificar",
    "gratificou": "gratificar",
    "gratificá": "gratificar",
    "gratificámo": "gratificar",
    "gratificámos": "gratificar",
    "gratificáramo": "gratificar",
    "gratificáramos": "gratificar",
    "gratificárei": "gratificar",
    "gratificáreis": "gratificar",
    "gratificásseis": "gratificar",
    "gratificássemos": "gratificar",
    "gratificávamo": "gratificar",
    "gratificávamos": "gratificar",
    "gratificávei": "gratificar",
    "gratificáveis": "gratificar",
    "gratifique": "gratificar",
    "gratifiquei": "gratificar",
    "gratifiqueis": "gratificar",
    "gratifiquem": "gratificar",
    "gratifiquemo": "gratificar",
    "gratifiquemos": "gratificar",
    "gratifiques": "gratificar",
    "gratina": "gratinar",
    "gratinada": "gratinar",
    "gratinadas": "gratinar",
    "gratinado": "gratinar",
    "gratinados": "gratinar",
    "gratinai": "gratinar",
    "gratinais": "gratinar",
    "gratinam": "gratinar",
    "gratinamo": "gratinar",
    "gratinamos": "gratinar",
    "gratinando": "gratinar",
    "gratinara": "gratinar",
    "gratinaram": "gratinar",
    "gratinaras": "gratinar",
    "gratinarde": "gratinar",
    "gratinardes": "gratinar",
    "gratinare": "gratinar",
    "gratinarei": "gratinar",
    "gratinareis": "gratinar",
    "gratinarem": "gratinar",
    "gratinaremos": "gratinar",
    "gratinares": "gratinar",
    "gratinaria": "gratinar",
    "gratinariam": "gratinar",
    "gratinarias": "gratinar",
    "gratinarmo": "gratinar",
    "gratinarmos": "gratinar",
    "gratinará": "gratinar",
    "gratinarás": "gratinar",
    "gratinarão": "gratinar",
    "gratinaríamos": "gratinar",
    "gratinaríeis": "gratinar",
    "gratinas": "gratinar",
    "gratinasse": "gratinar",
    "gratinassem": "gratinar",
    "gratinasses": "gratinar",
    "gratinaste": "gratinar",
    "gratinastes": "gratinar",
    "gratinava": "gratinar",
    "gratinavam": "gratinar",
    "gratinavas": "gratinar",
    "gratine": "gratinar",
    "gratinei": "gratinar",
    "gratineis": "gratinar",
    "gratinem": "gratinar",
    "gratinemo": "gratinar",
    "gratinemos": "gratinar",
    "gratines": "gratinar",
    "gratino": "gratinar",
    "gratinou": "gratinar",
    "gratiná": "gratinar",
    "gratinámo": "gratinar",
    "gratinámos": "gratinar",
    "gratináramo": "gratinar",
    "gratináramos": "gratinar",
    "gratinárei": "gratinar",
    "gratináreis": "gratinar",
    "gratinásseis": "gratinar",
    "gratinássemos": "gratinar",
    "gratinávamo": "gratinar",
    "gratinávamos": "gratinar",
    "gratinávei": "gratinar",
    "gratináveis": "gratinar",
    "gratos": "grato",
    "gratuidades": "gratuidade",
    "gratuita": "gratuito",
    "gratuitas": "gratuito",
    "gratuitidades": "gratuitidade",
    "gratuitos": "gratuito",
    "gratula": "gratular",
    "gratulada": "gratular",
    "gratuladas": "gratular",
    "gratulado": "gratular",
    "gratulados": "gratular",
    "gratulai": "gratular",
    "gratulais": "gratular",
    "gratulam": "gratular",
    "gratulamo": "gratular",
    "gratulamos": "gratular",
    "gratulando": "gratular",
    "gratulara": "gratular",
    "gratularam": "gratular",
    "gratularas": "gratular",
    "gratularde": "gratular",
    "gratulardes": "gratular",
    "gratulare": "gratular",
    "gratularei": "gratular",
    "gratulareis": "gratular",
    "gratularem": "gratular",
    "gratularemos": "gratular",
    "gratulares": "gratular",
    "gratularia": "gratular",
    "gratulariam": "gratular",
    "gratularias": "gratular",
    "gratularmo": "gratular",
    "gratularmos": "gratular",
    "gratulará": "gratular",
    "gratularás": "gratular",
    "gratularão": "gratular",
    "gratularíamos": "gratular",
    "gratularíeis": "gratular",
    "gratulas": "gratular",
    "gratulasse": "gratular",
    "gratulassem": "gratular",
    "gratulasses": "gratular",
    "gratulaste": "gratular",
    "gratulastes": "gratular",
    "gratulatória": "gratulatório",
    "gratulatórias": "gratulatório",
    "gratulatórios": "gratulatório",
    "gratulava": "gratular",
    "gratulavam": "gratular",
    "gratulavas": "gratular",
    "gratulações": "gratulação",
    "gratule": "gratular",
    "gratulei": "gratular",
    "gratuleis": "gratular",
    "gratulem": "gratular",
    "gratulemo": "gratular",
    "gratulemos": "gratular",
    "gratules": "gratular",
    "gratulo": "gratular",
    "gratulou": "gratular",
    "gratulá": "gratular",
    "gratulámo": "gratular",
    "gratulámos": "gratular",
    "gratuláramo": "gratular",
    "gratuláramos": "gratular",
    "gratulárei": "gratular",
    "gratuláreis": "gratular",
    "gratulásseis": "gratular",
    "gratulássemos": "gratular",
    "gratulávamo": "gratular",
    "gratulávamos": "gratular",
    "gratulávei": "gratular",
    "gratuláveis": "gratular",
    "gratículas": "gratícula",
    "gratífica": "gratífico",
    "gratíficas": "gratífico",
    "gratíficos": "gratífico",
    "graus": "grau",
    "grauvaques": "grauvaque",
    "grava": "gravar",
    "gravada": "gravar",
    "gravadas": "gravar",
    "gravado": "gravar",
    "gravadora": "gravador",
    "gravadoras": "gravador",
    "gravadores": "gravador",
    "gravados": "gravar",
    "gravaduras": "gravadura",
    "gravai": "gravar",
    "gravais": "gravar",
    "gravalhas": "gravalha",
    "gravam": "gravar",
    "gravames": "gravame",
    "gravamo": "gravar",
    "gravamos": "gravar",
    "gravando": "gravar",
    "gravanhas": "gravanha",
    "gravanços": "gravanço",
    "gravara": "gravar",
    "gravaram": "gravar",
    "gravaras": "gravar",
    "gravarde": "gravar",
    "gravardes": "gravar",
    "gravare": "gravar",
    "gravarei": "gravar",
    "gravareis": "gravar",
    "gravarem": "gravar",
    "gravaremos": "gravar",
    "gravares": "gravar",
    "gravaria": "gravar",
    "gravariam": "gravar",
    "gravarias": "gravar",
    "gravarmo": "gravar",
    "gravarmos": "gravar",
    "gravará": "gravar",
    "gravarás": "gravar",
    "gravarão": "gravar",
    "gravaríamos": "gravar",
    "gravaríeis": "gravar",
    "gravas": "gravar",
    "gravasse": "gravar",
    "gravassem": "gravar",
    "gravasses": "gravar",
    "gravaste": "gravar",
    "gravastes": "gravar",
    "gravatarias": "gravataria",
    "gravatas": "gravata",
    "gravateira": "gravateiro",
    "gravateiras": "gravateiro",
    "gravateiros": "gravateiro",
    "gravatilhos": "gravatilho",
    "gravatinhas": "gravatinha",
    "gravatis": "gravatil",
    "gravativa": "gravativo",
    "gravativas": "gravativo",
    "gravativos": "gravativo",
    "gravatos": "gravato",
    "gravatões": "gravatão",
    "gravava": "gravar",
    "gravavam": "gravar",
    "gravavas": "gravar",
    "gravações": "gravação",
    "grave": "gravar",
    "gravei": "gravar",
    "graveis": "gravar",
    "gravelada": "gravelado",
    "graveladas": "gravelado",
    "gravelados": "gravelado",
    "gravelas": "gravela",
    "gravelosa": "graveloso",
    "gravelosas": "graveloso",
    "gravelosos": "graveloso",
    "gravem": "gravar",
    "gravemo": "gravar",
    "gravemos": "gravar",
    "graveolentes": "graveolente",
    "graveolências": "graveolência",
    "graves": "grave",
    "gravetas": "graveta",
    "gravetos": "graveto",
    "gravezas": "graveza",
    "gravezinha": "grave",
    "gravezinhas": "grave",
    "gravezinho": "grave",
    "gravezinhos": "grave",
    "gravezita": "grave",
    "gravezitas": "grave",
    "gravezito": "grave",
    "gravezitos": "grave",
    "gravida": "gravidar",
    "gravidada": "gravidar",
    "gravidadas": "gravidar",
    "gravidades": "gravidade",
    "gravidado": "gravidar",
    "gravidados": "gravidar",
    "gravidai": "gravidar",
    "gravidais": "gravidar",
    "gravidam": "gravidar",
    "gravidamo": "gravidar",
    "gravidamos": "gravidar",
    "gravidando": "gravidar",
    "gravidara": "gravidar",
    "gravidaram": "gravidar",
    "gravidaras": "gravidar",
    "gravidardes": "gravidar",
    "gravidarei": "gravidar",
    "gravidareis": "gravidar",
    "gravidarem": "gravidar",
    "gravidaremos": "gravidar",
    "gravidares": "gravidar",
    "gravidaria": "gravidar",
    "gravidariam": "gravidar",
    "gravidarias": "gravidar",
    "gravidarmo": "gravidar",
    "gravidarmos": "gravidar",
    "gravidará": "gravidar",
    "gravidarás": "gravidar",
    "gravidarão": "gravidar",
    "gravidaríamos": "gravidar",
    "gravidaríeis": "gravidar",
    "gravidas": "gravidar",
    "gravidasse": "gravidar",
    "gravidassem": "gravidar",
    "gravidasses": "gravidar",
    "gravidaste": "gravidar",
    "gravidastes": "gravidar",
    "gravidava": "gravidar",
    "gravidavam": "gravidar",
    "gravidavas": "gravidar",
    "gravide": "gravidar",
    "gravidei": "gravidar",
    "gravideis": "gravidar",
    "gravidem": "gravidar",
    "gravidemo": "gravidar",
    "gravidemos": "gravidar",
    "gravides": "gravidar",
    "gravidezes": "gravidez",
    "gravido": "gravidar",
    "gravidou": "gravidar",
    "gravidámo": "gravidar",
    "gravidámos": "gravidar",
    "gravidáramo": "gravidar",
    "gravidáramos": "gravidar",
    "gravidáreis": "gravidar",
    "gravidásseis": "gravidar",
    "gravidássemos": "gravidar",
    "gravidávamo": "gravidar",
    "gravidávamos": "gravidar",
    "gravidáveis": "gravidar",
    "gravidões": "gravidão",
    "gravigrados": "gravigrado",
    "gravilhas": "gravilha",
    "gravimetrias": "gravimetria",
    "gravimetristas": "gravimetrista",
    "gravimétrica": "gravimétrico",
    "gravimétricas": "gravimétrico",
    "gravimétricos": "gravimétrico",
    "graviscas": "gravisca",
    "gravita": "gravito",
    "gravitacionais": "gravitacional",
    "gravitada": "gravitar",
    "gravitadas": "gravitar",
    "gravitado": "gravitar",
    "gravitados": "gravitar",
    "gravitai": "gravitar",
    "gravitais": "gravitar",
    "gravitam": "gravitar",
    "gravitamo": "gravitar",
    "gravitamos": "gravitar",
    "gravitando": "gravitar",
    "gravitantes": "gravitante",
    "gravitara": "gravitar",
    "gravitaram": "gravitar",
    "gravitaras": "gravitar",
    "gravitardes": "gravitar",
    "gravitarei": "gravitar",
    "gravitareis": "gravitar",
    "gravitarem": "gravitar",
    "gravitaremos": "gravitar",
    "gravitares": "gravitar",
    "gravitaria": "gravitar",
    "gravitariam": "gravitar",
    "gravitarias": "gravitar",
    "gravitarmo": "gravitar",
    "gravitarmos": "gravitar",
    "gravitará": "gravitar",
    "gravitarás": "gravitar",
    "gravitarão": "gravitar",
    "gravitaríamos": "gravitar",
    "gravitaríeis": "gravitar",
    "gravitas": "gravito",
    "gravitasse": "gravitar",
    "gravitassem": "gravitar",
    "gravitasses": "gravitar",
    "gravitaste": "gravitar",
    "gravitastes": "gravitar",
    "gravitava": "gravitar",
    "gravitavam": "gravitar",
    "gravitavas": "gravitar",
    "gravitações": "gravitação",
    "gravite": "gravitar",
    "gravitei": "gravitar",
    "graviteis": "gravitar",
    "gravitem": "gravitar",
    "gravitemo": "gravitar",
    "gravitemos": "gravitar",
    "gravites": "gravitar",
    "gravitinos": "gravitino",
    "gravito": "gravitar",
    "gravitos": "gravito",
    "gravitou": "gravitar",
    "gravitámo": "gravitar",
    "gravitámos": "gravitar",
    "gravitáramo": "gravitar",
    "gravitáramos": "gravitar",
    "gravitáreis": "gravitar",
    "gravitásseis": "gravitar",
    "gravitássemos": "gravitar",
    "gravitávamo": "gravitar",
    "gravitávamos": "gravitar",
    "gravitáveis": "gravitar",
    "gravitões": "gravitão",
    "gravo": "gravar",
    "gravosa": "gravoso",
    "gravosas": "gravoso",
    "gravosos": "gravoso",
    "gravota": "gravote",
    "gravotas": "gravote",
    "gravotes": "gravote",
    "gravou": "gravar",
    "gravuras": "gravura",
    "gravá": "gravar",
    "gravámo": "gravar",
    "gravámos": "gravar",
    "graváramo": "gravar",
    "graváramos": "gravar",
    "gravárei": "gravar",
    "graváreis": "gravar",
    "gravásseis": "gravar",
    "gravássemos": "gravar",
    "gravávamo": "gravar",
    "gravávamos": "gravar",
    "gravávei": "gravar",
    "graváveis": "gravável",
    "gravídica": "gravídico",
    "gravídicas": "gravídico",
    "gravídicos": "gravídico",
    "gravígrada": "gravígrado",
    "gravígradas": "gravígrado",
    "gravígrados": "gravígrado",
    "gravímetros": "gravímetro",
    "gravíssima": "grave",
    "gravíssimas": "grave",
    "gravíssimo": "grave",
    "gravíssimos": "grave",
    "gravítica": "gravítico",
    "gravíticas": "gravítico",
    "gravíticos": "gravítico",
    "graxa": "graxo",
    "graxas": "graxo",
    "graxeada": "graxear",
    "graxeadas": "graxear",
    "graxeado": "graxear",
    "graxeados": "graxear",
    "graxeai": "graxear",
    "graxeais": "graxear",
    "graxeamo": "graxear",
    "graxeamos": "graxear",
    "graxeando": "graxear",
    "graxeara": "graxear",
    "graxearam": "graxear",
    "graxearas": "graxear",
    "graxeardes": "graxear",
    "graxearei": "graxear",
    "graxeareis": "graxear",
    "graxearem": "graxear",
    "graxearemos": "graxear",
    "graxeares": "graxear",
    "graxearia": "graxear",
    "graxeariam": "graxear",
    "graxearias": "graxear",
    "graxearmo": "graxear",
    "graxearmos": "graxear",
    "graxeará": "graxear",
    "graxearás": "graxear",
    "graxearão": "graxear",
    "graxearíamos": "graxear",
    "graxearíeis": "graxear",
    "graxeasse": "graxear",
    "graxeassem": "graxear",
    "graxeasses": "graxear",
    "graxeaste": "graxear",
    "graxeastes": "graxear",
    "graxeava": "graxear",
    "graxeavam": "graxear",
    "graxeavas": "graxear",
    "graxeei": "graxear",
    "graxeeis": "graxear",
    "graxeemo": "graxear",
    "graxeemos": "graxear",
    "graxeia": "graxear",
    "graxeiam": "graxear",
    "graxeias": "graxear",
    "graxeie": "graxear",
    "graxeiem": "graxear",
    "graxeies": "graxear",
    "graxeio": "graxear",
    "graxeira": "graxeiro",
    "graxeiras": "graxeiro",
    "graxeiros": "graxeiro",
    "graxeou": "graxear",
    "graxeámo": "graxear",
    "graxeámos": "graxear",
    "graxeáramo": "graxear",
    "graxeáramos": "graxear",
    "graxeáreis": "graxear",
    "graxeásseis": "graxear",
    "graxeássemos": "graxear",
    "graxeávamo": "graxear",
    "graxeávamos": "graxear",
    "graxeáveis": "graxear",
    "graxistas": "graxista",
    "graxos": "graxo",
    "grazina": "grazinar",
    "grazinada": "grazinar",
    "grazinadas": "grazinar",
    "grazinado": "grazinar",
    "grazinadora": "grazinador",
    "grazinadoras": "grazinador",
    "grazinadores": "grazinador",
    "grazinados": "grazinar",
    "grazinai": "grazinar",
    "grazinais": "grazinar",
    "grazinam": "grazinar",
    "grazinamo": "grazinar",
    "grazinamos": "grazinar",
    "grazinando": "grazinar",
    "grazinara": "grazinar",
    "grazinaram": "grazinar",
    "grazinaras": "grazinar",
    "grazinardes": "grazinar",
    "grazinarei": "grazinar",
    "grazinareis": "grazinar",
    "grazinarem": "grazinar",
    "grazinaremos": "grazinar",
    "grazinares": "grazinar",
    "grazinaria": "grazinar",
    "grazinariam": "grazinar",
    "grazinarias": "grazinar",
    "grazinarmo": "grazinar",
    "grazinarmos": "grazinar",
    "grazinará": "grazinar",
    "grazinarás": "grazinar",
    "grazinarão": "grazinar",
    "grazinaríamos": "grazinar",
    "grazinaríeis": "grazinar",
    "grazinas": "grazinar",
    "grazinasse": "grazinar",
    "grazinassem": "grazinar",
    "grazinasses": "grazinar",
    "grazinaste": "grazinar",
    "grazinastes": "grazinar",
    "grazinava": "grazinar",
    "grazinavam": "grazinar",
    "grazinavas": "grazinar",
    "grazine": "grazinar",
    "grazinei": "grazinar",
    "grazineiras": "grazineira",
    "grazineis": "grazinar",
    "grazinem": "grazinar",
    "grazinemo": "grazinar",
    "grazinemos": "grazinar",
    "grazines": "grazinar",
    "grazino": "grazinar",
    "grazinou": "grazinar",
    "grazinámo": "grazinar",
    "grazinámos": "grazinar",
    "grazináramo": "grazinar",
    "grazináramos": "grazinar",
    "grazináreis": "grazinar",
    "grazinásseis": "grazinar",
    "grazinássemos": "grazinar",
    "grazinávamo": "grazinar",
    "grazinávamos": "grazinar",
    "grazináveis": "grazinar",
    "graças": "graça",
    "graçolas": "graçola",
    "graçotas": "graçota",
    "graúda": "graúdo",
    "graúdas": "graúdo",
    "graúdos": "graúdo",
    "graúlhos": "graúlho",
    "grecianos": "greciano",
    "grecismos": "grecismo",
    "grecistas": "grecista",
    "greciza": "grecizar",
    "grecizada": "grecizar",
    "grecizadas": "grecizar",
    "grecizado": "grecizar",
    "grecizados": "grecizar",
    "grecizai": "grecizar",
    "grecizais": "grecizar",
    "grecizam": "grecizar",
    "grecizamo": "grecizar",
    "grecizamos": "grecizar",
    "grecizando": "grecizar",
    "grecizara": "grecizar",
    "grecizaram": "grecizar",
    "grecizaras": "grecizar",
    "grecizarde": "grecizar",
    "grecizardes": "grecizar",
    "grecizare": "grecizar",
    "grecizarei": "grecizar",
    "grecizareis": "grecizar",
    "grecizarem": "grecizar",
    "grecizaremos": "grecizar",
    "grecizares": "grecizar",
    "grecizaria": "grecizar",
    "grecizariam": "grecizar",
    "grecizarias": "grecizar",
    "grecizarmo": "grecizar",
    "grecizarmos": "grecizar",
    "grecizará": "grecizar",
    "grecizarás": "grecizar",
    "grecizarão": "grecizar",
    "grecizaríamos": "grecizar",
    "grecizaríeis": "grecizar",
    "grecizas": "grecizar",
    "grecizasse": "grecizar",
    "grecizassem": "grecizar",
    "grecizasses": "grecizar",
    "grecizaste": "grecizar",
    "grecizastes": "grecizar",
    "grecizava": "grecizar",
    "grecizavam": "grecizar",
    "grecizavas": "grecizar",
    "grecizações": "grecização",
    "grecize": "grecizar",
    "grecizei": "grecizar",
    "grecizeis": "grecizar",
    "grecizem": "grecizar",
    "grecizemo": "grecizar",
    "grecizemos": "grecizar",
    "grecizes": "grecizar",
    "grecizo": "grecizar",
    "grecizou": "grecizar",
    "grecizá": "grecizar",
    "grecizámo": "grecizar",
    "grecizámos": "grecizar",
    "grecizáramo": "grecizar",
    "grecizáramos": "grecizar",
    "grecizárei": "grecizar",
    "grecizáreis": "grecizar",
    "grecizásseis": "grecizar",
    "grecizássemos": "grecizar",
    "grecizávamo": "grecizar",
    "grecizávamos": "grecizar",
    "grecizávei": "grecizar",
    "grecizáveis": "grecizar",
    "grecomanias": "grecomania",
    "grecomaníaca": "grecomaníaco",
    "grecomaníacas": "grecomaníaco",
    "grecomaníacos": "grecomaníaco",
    "grecómana": "grecómano",
    "grecómanas": "grecómano",
    "grecómanos": "grecómano",
    "gredas": "greda",
    "gredeléns": "gredelém",
    "gredosa": "gredoso",
    "gredosas": "gredoso",
    "gredosos": "gredoso",
    "grega": "grego",
    "gregais": "gregal",
    "gregaladas": "gregalada",
    "gregarina": "gregarino",
    "gregarinas": "gregarino",
    "gregarinos": "gregarino",
    "gregarinídea": "gregarinídeo",
    "gregarinídeas": "gregarinídeo",
    "gregarinídeos": "gregarinídeo",
    "gregarismos": "gregarismo",
    "gregarínea": "gregaríneo",
    "gregaríneas": "gregaríneo",
    "gregaríneos": "gregaríneo",
    "gregarística": "gregarístico",
    "gregarísticas": "gregarístico",
    "gregarísticos": "gregarístico",
    "gregas": "grego",
    "greges": "grege",
    "gregoriana": "gregoriano",
    "gregorianas": "gregoriano",
    "gregorianos": "gregoriano",
    "gregos": "grego",
    "gregotins": "gregotim",
    "gregueja": "greguejar",
    "greguejada": "greguejar",
    "greguejadas": "greguejar",
    "greguejado": "greguejar",
    "greguejados": "greguejar",
    "greguejai": "greguejar",
    "greguejais": "greguejar",
    "greguejam": "greguejar",
    "greguejamo": "greguejar",
    "greguejamos": "greguejar",
    "greguejando": "greguejar",
    "greguejara": "greguejar",
    "greguejaram": "greguejar",
    "greguejaras": "greguejar",
    "greguejarde": "greguejar",
    "greguejardes": "greguejar",
    "greguejare": "greguejar",
    "greguejarei": "greguejar",
    "greguejareis": "greguejar",
    "greguejarem": "greguejar",
    "greguejaremos": "greguejar",
    "greguejares": "greguejar",
    "greguejaria": "greguejar",
    "greguejariam": "greguejar",
    "greguejarias": "greguejar",
    "greguejarmo": "greguejar",
    "greguejarmos": "greguejar",
    "greguejará": "greguejar",
    "greguejarás": "greguejar",
    "greguejarão": "greguejar",
    "greguejaríamos": "greguejar",
    "greguejaríeis": "greguejar",
    "greguejas": "greguejar",
    "greguejasse": "greguejar",
    "greguejassem": "greguejar",
    "greguejasses": "greguejar",
    "greguejaste": "greguejar",
    "greguejastes": "greguejar",
    "greguejava": "greguejar",
    "greguejavam": "greguejar",
    "greguejavas": "greguejar",
    "gregueje": "greguejar",
    "greguejei": "greguejar",
    "greguejeis": "greguejar",
    "greguejem": "greguejar",
    "greguejemo": "greguejar",
    "greguejemos": "greguejar",
    "greguejes": "greguejar",
    "greguejo": "greguejar",
    "greguejou": "greguejar",
    "greguejá": "greguejar",
    "greguejámo": "greguejar",
    "greguejámos": "greguejar",
    "greguejáramo": "greguejar",
    "greguejáramos": "greguejar",
    "greguejárei": "greguejar",
    "greguejáreis": "greguejar",
    "greguejásseis": "greguejar",
    "greguejássemos": "greguejar",
    "greguejávamo": "greguejar",
    "greguejávamos": "greguejar",
    "greguejávei": "greguejar",
    "greguejáveis": "greguejar",
    "gregária": "gregário",
    "gregárias": "gregário",
    "gregários": "gregário",
    "greiros": "greiro",
    "greis": "grei",
    "grejós": "grejó",
    "grela": "grelar",
    "grelada": "grelar",
    "greladas": "grelar",
    "grelado": "grelar",
    "grelados": "grelar",
    "grelai": "grelar",
    "grelais": "grelar",
    "grelam": "grelar",
    "grelamo": "grelar",
    "grelamos": "grelar",
    "grelando": "grelar",
    "grelara": "grelar",
    "grelaram": "grelar",
    "grelaras": "grelar",
    "grelardes": "grelar",
    "grelarei": "grelar",
    "grelareis": "grelar",
    "grelarem": "grelar",
    "grelaremos": "grelar",
    "grelares": "grelar",
    "grelaria": "grelar",
    "grelariam": "grelar",
    "grelarias": "grelar",
    "grelarmo": "grelar",
    "grelarmos": "grelar",
    "grelará": "grelar",
    "grelarás": "grelar",
    "grelarão": "grelar",
    "grelaríamos": "grelar",
    "grelaríeis": "grelar",
    "grelas": "grelar",
    "grelasse": "grelar",
    "grelassem": "grelar",
    "grelasses": "grelar",
    "grelaste": "grelar",
    "grelastes": "grelar",
    "grelava": "grelar",
    "grelavam": "grelar",
    "grelavas": "grelar",
    "grele": "grelar",
    "grelei": "grelar",
    "greleis": "grelar",
    "grelem": "grelar",
    "grelemo": "grelar",
    "grelemos": "grelar",
    "greles": "grelar",
    "grelha": "grelhar",
    "grelhada": "grelhar",
    "grelhadas": "grelhar",
    "grelhadinho": "grelhado",
    "grelhadinhos": "grelhado",
    "grelhadito": "grelhado",
    "grelhaditos": "grelhado",
    "grelhado": "grelhar",
    "grelhadores": "grelhador",
    "grelhados": "grelhar",
    "grelhai": "grelhar",
    "grelhais": "grelhar",
    "grelham": "grelhar",
    "grelhamo": "grelhar",
    "grelhamos": "grelhar",
    "grelhando": "grelhar",
    "grelhara": "grelhar",
    "grelharam": "grelhar",
    "grelharas": "grelhar",
    "grelharde": "grelhar",
    "grelhardes": "grelhar",
    "grelhare": "grelhar",
    "grelharei": "grelhar",
    "grelhareis": "grelhar",
    "grelharem": "grelhar",
    "grelharemos": "grelhar",
    "grelhares": "grelhar",
    "grelharia": "grelhar",
    "grelhariam": "grelhar",
    "grelharias": "grelhar",
    "grelharmo": "grelhar",
    "grelharmos": "grelhar",
    "grelhará": "grelhar",
    "grelharás": "grelhar",
    "grelharão": "grelhar",
    "grelharíamos": "grelhar",
    "grelharíeis": "grelhar",
    "grelhas": "grelhar",
    "grelhasse": "grelhar",
    "grelhassem": "grelhar",
    "grelhasses": "grelhar",
    "grelhaste": "grelhar",
    "grelhastes": "grelhar",
    "grelhava": "grelhar",
    "grelhavam": "grelhar",
    "grelhavas": "grelhar",
    "grelhe": "grelhar",
    "grelhei": "grelhar",
    "grelheiros": "grelheiro",
    "grelheis": "grelhar",
    "grelhem": "grelhar",
    "grelhemo": "grelhar",
    "grelhemos": "grelhar",
    "grelhes": "grelhar",
    "grelho": "grelhar",
    "grelhou": "grelhar",
    "grelhá": "grelhar",
    "grelhámo": "grelhar",
    "grelhámos": "grelhar",
    "grelháramo": "grelhar",
    "grelháramos": "grelhar",
    "grelhárei": "grelhar",
    "grelháreis": "grelhar",
    "grelhásseis": "grelhar",
    "grelhássemos": "grelhar",
    "grelhávamo": "grelhar",
    "grelhávamos": "grelhar",
    "grelhávei": "grelhar",
    "grelháveis": "grelhar",
    "grelinho": "grelo",
    "grelinhos": "grelo",
    "grelito": "grelo",
    "grelitos": "grelo",
    "grelo": "grelar",
    "grelos": "grelo",
    "grelou": "grelar",
    "grelámo": "grelar",
    "grelámos": "grelar",
    "greláramo": "grelar",
    "greláramos": "grelar",
    "greláreis": "grelar",
    "grelásseis": "grelar",
    "grelássemos": "grelar",
    "grelávamo": "grelar",
    "grelávamos": "grelar",
    "greláveis": "grelar",
    "gremiais": "gremial",
    "gremilhas": "gremilha",
    "grenetinas": "grenetina",
    "grenhas": "grenha",
    "grenás": "grená",
    "gresiformes": "gresiforme",
    "gresífera": "gresífero",
    "gresíferas": "gresífero",
    "gresíferos": "gresífero",
    "greta": "gretar",
    "gretada": "gretar",
    "gretadas": "gretar",
    "gretado": "gretar",
    "gretados": "gretar",
    "gretaduras": "gretadura",
    "gretai": "gretar",
    "gretais": "gretar",
    "gretam": "gretar",
    "gretamentos": "gretamento",
    "gretamo": "gretar",
    "gretamos": "gretar",
    "gretando": "gretar",
    "gretara": "gretar",
    "gretaram": "gretar",
    "gretaras": "gretar",
    "gretardes": "gretar",
    "gretarei": "gretar",
    "gretareis": "gretar",
    "gretarem": "gretar",
    "gretaremos": "gretar",
    "gretares": "gretar",
    "gretaria": "gretar",
    "gretariam": "gretar",
    "gretarias": "gretar",
    "gretarmo": "gretar",
    "gretarmos": "gretar",
    "gretará": "gretar",
    "gretarás": "gretar",
    "gretarão": "gretar",
    "gretaríamos": "gretar",
    "gretaríeis": "gretar",
    "gretas": "gretar",
    "gretasse": "gretar",
    "gretassem": "gretar",
    "gretasses": "gretar",
    "gretaste": "gretar",
    "gretastes": "gretar",
    "gretava": "gretar",
    "gretavam": "gretar",
    "gretavas": "gretar",
    "grete": "gretar",
    "gretei": "gretar",
    "greteis": "gretar",
    "gretem": "gretar",
    "gretemo": "gretar",
    "gretemos": "gretar",
    "gretes": "gretar",
    "gretinha": "greta",
    "gretinhas": "greta",
    "gretita": "greta",
    "gretitas": "greta",
    "greto": "gretar",
    "gretou": "gretar",
    "gretámo": "gretar",
    "gretámos": "gretar",
    "gretáramo": "gretar",
    "gretáramos": "gretar",
    "gretáreis": "gretar",
    "gretásseis": "gretar",
    "gretássemos": "gretar",
    "gretávamo": "gretar",
    "gretávamos": "gretar",
    "gretáveis": "gretar",
    "grevada": "grevado",
    "grevadas": "grevado",
    "grevados": "grevado",
    "greves": "greve",
    "grevistas": "grevista",
    "grifa": "grifo",
    "grifada": "grifar",
    "grifadas": "grifar",
    "grifado": "grifar",
    "grifados": "grifar",
    "grifai": "grifar",
    "grifais": "grifar",
    "grifam": "grifar",
    "grifamo": "grifar",
    "grifamos": "grifar",
    "grifando": "grifar",
    "grifara": "grifar",
    "grifaram": "grifar",
    "grifaras": "grifar",
    "grifarde": "grifar",
    "grifardes": "grifar",
    "grifare": "grifar",
    "grifarei": "grifar",
    "grifareis": "grifar",
    "grifarem": "grifar",
    "grifaremos": "grifar",
    "grifares": "grifar",
    "grifaria": "grifar",
    "grifariam": "grifar",
    "grifarias": "grifar",
    "grifarmo": "grifar",
    "grifarmos": "grifar",
    "grifará": "grifar",
    "grifarás": "grifar",
    "grifarão": "grifar",
    "grifaríamos": "grifar",
    "grifaríeis": "grifar",
    "grifas": "grifo",
    "grifasse": "grifar",
    "grifassem": "grifar",
    "grifasses": "grifar",
    "grifaste": "grifar",
    "grifastes": "grifar",
    "grifava": "grifar",
    "grifavam": "grifar",
    "grifavas": "grifar",
    "grife": "grifar",
    "grifei": "grifar",
    "grifeis": "grifar",
    "grifem": "grifar",
    "grifemo": "grifar",
    "grifemos": "grifar",
    "grifenha": "grifenho",
    "grifenhas": "grifenho",
    "grifenhos": "grifenho",
    "grifes": "grifar",
    "grifo": "grifar",
    "grifos": "grifo",
    "grifou": "grifar",
    "grifá": "grifar",
    "grifámo": "grifar",
    "grifámos": "grifar",
    "grifáramo": "grifar",
    "grifáramos": "grifar",
    "grifárei": "grifar",
    "grifáreis": "grifar",
    "grifásseis": "grifar",
    "grifássemos": "grifar",
    "grifávamo": "grifar",
    "grifávamos": "grifar",
    "grifávei": "grifar",
    "grifáveis": "grifar",
    "grifínias": "grifínia",
    "grila": "grilo",
    "grilas": "grilo",
    "grilhadas": "grilhada",
    "grilhagens": "grilhagem",
    "grilharias": "grilharia",
    "grilhetas": "grilheta",
    "grilhos": "grilho",
    "grilhões": "grilhão",
    "grills": "grill",
    "grilos": "grilo",
    "grimas": "grima",
    "grimpa": "grimpo",
    "grimpada": "grimpar",
    "grimpadas": "grimpar",
    "grimpado": "grimpar",
    "grimpados": "grimpar",
    "grimpai": "grimpar",
    "grimpais": "grimpar",
    "grimpam": "grimpar",
    "grimpamo": "grimpar",
    "grimpamos": "grimpar",
    "grimpando": "grimpar",
    "grimpara": "grimpar",
    "grimparam": "grimpar",
    "grimparas": "grimpar",
    "grimpardes": "grimpar",
    "grimparei": "grimpar",
    "grimpareis": "grimpar",
    "grimparem": "grimpar",
    "grimparemos": "grimpar",
    "grimpares": "grimpar",
    "grimparia": "grimpar",
    "grimpariam": "grimpar",
    "grimparias": "grimpar",
    "grimparmo": "grimpar",
    "grimparmos": "grimpar",
    "grimpará": "grimpar",
    "grimparás": "grimpar",
    "grimparão": "grimpar",
    "grimparíamos": "grimpar",
    "grimparíeis": "grimpar",
    "grimpas": "grimpo",
    "grimpasse": "grimpar",
    "grimpassem": "grimpar",
    "grimpasses": "grimpar",
    "grimpaste": "grimpar",
    "grimpastes": "grimpar",
    "grimpava": "grimpar",
    "grimpavam": "grimpar",
    "grimpavas": "grimpar",
    "grimpe": "grimpar",
    "grimpei": "grimpar",
    "grimpeis": "grimpar",
    "grimpem": "grimpar",
    "grimpemo": "grimpar",
    "grimpemos": "grimpar",
    "grimpes": "grimpar",
    "grimpo": "grimpar",
    "grimpos": "grimpo",
    "grimpou": "grimpar",
    "grimpámo": "grimpar",
    "grimpámos": "grimpar",
    "grimpáramo": "grimpar",
    "grimpáramos": "grimpar",
    "grimpáreis": "grimpar",
    "grimpásseis": "grimpar",
    "grimpássemos": "grimpar",
    "grimpávamo": "grimpar",
    "grimpávamos": "grimpar",
    "grimpáveis": "grimpar",
    "grinaldas": "grinalda",
    "grinda": "grindo",
    "grindais": "grindal",
    "grindas": "grindo",
    "grindos": "grindo",
    "grindélias": "grindélia",
    "grinfa": "grinfar",
    "grinfada": "grinfar",
    "grinfadas": "grinfar",
    "grinfado": "grinfar",
    "grinfados": "grinfar",
    "grinfai": "grinfar",
    "grinfais": "grinfar",
    "grinfam": "grinfar",
    "grinfamo": "grinfar",
    "grinfamos": "grinfar",
    "grinfando": "grinfar",
    "grinfara": "grinfar",
    "grinfaram": "grinfar",
    "grinfaras": "grinfar",
    "grinfardes": "grinfar",
    "grinfarei": "grinfar",
    "grinfareis": "grinfar",
    "grinfarem": "grinfar",
    "grinfaremos": "grinfar",
    "grinfares": "grinfar",
    "grinfaria": "grinfar",
    "grinfariam": "grinfar",
    "grinfarias": "grinfar",
    "grinfarmo": "grinfar",
    "grinfarmos": "grinfar",
    "grinfará": "grinfar",
    "grinfarás": "grinfar",
    "grinfarão": "grinfar",
    "grinfaríamos": "grinfar",
    "grinfaríeis": "grinfar",
    "grinfas": "grinfar",
    "grinfasse": "grinfar",
    "grinfassem": "grinfar",
    "grinfasses": "grinfar",
    "grinfaste": "grinfar",
    "grinfastes": "grinfar",
    "grinfava": "grinfar",
    "grinfavam": "grinfar",
    "grinfavas": "grinfar",
    "grinfe": "grinfar",
    "grinfei": "grinfar",
    "grinfeis": "grinfar",
    "grinfem": "grinfar",
    "grinfemo": "grinfar",
    "grinfemos": "grinfar",
    "grinfes": "grinfar",
    "grinfo": "grinfar",
    "grinfou": "grinfar",
    "grinfámo": "grinfar",
    "grinfámos": "grinfar",
    "grinfáramo": "grinfar",
    "grinfáramos": "grinfar",
    "grinfáreis": "grinfar",
    "grinfásseis": "grinfar",
    "grinfássemos": "grinfar",
    "grinfávamo": "grinfar",
    "grinfávamos": "grinfar",
    "grinfáveis": "grinfar",
    "gringa": "gringo",
    "gringas": "gringo",
    "gringolins": "gringolim",
    "gringos": "gringo",
    "griolandesa": "griolandês",
    "griolandesas": "griolandês",
    "griolandeses": "griolandês",
    "griollândias": "griollândia",
    "gripa": "gripar",
    "gripada": "gripar",
    "gripadas": "gripar",
    "gripado": "gripar",
    "gripados": "gripar",
    "gripai": "gripar",
    "gripais": "gripar",
    "gripam": "gripar",
    "gripamo": "gripar",
    "gripamos": "gripar",
    "gripando": "gripar",
    "gripara": "gripar",
    "griparam": "gripar",
    "griparas": "gripar",
    "gripardes": "gripar",
    "griparei": "gripar",
    "gripareis": "gripar",
    "griparem": "gripar",
    "griparemos": "gripar",
    "gripares": "gripar",
    "griparia": "gripar",
    "gripariam": "gripar",
    "griparias": "gripar",
    "griparmo": "gripar",
    "griparmos": "gripar",
    "gripará": "gripar",
    "griparás": "gripar",
    "griparão": "gripar",
    "griparíamos": "gripar",
    "griparíeis": "gripar",
    "gripas": "gripar",
    "gripasse": "gripar",
    "gripassem": "gripar",
    "gripasses": "gripar",
    "gripaste": "gripar",
    "gripastes": "gripar",
    "gripava": "gripar",
    "gripavam": "gripar",
    "gripavas": "gripar",
    "gripe": "gripar",
    "gripei": "gripar",
    "gripeis": "gripar",
    "gripem": "gripar",
    "gripemo": "gripar",
    "gripemos": "gripar",
    "gripes": "gripe",
    "gripo": "gripar",
    "gripou": "gripar",
    "gripámo": "gripar",
    "gripámos": "gripar",
    "gripáramo": "gripar",
    "gripáramos": "gripar",
    "gripáreis": "gripar",
    "gripásseis": "gripar",
    "gripássemos": "gripar",
    "gripávamo": "gripar",
    "gripávamos": "gripar",
    "gripáveis": "gripar",
    "grisa": "grisar",
    "grisada": "grisar",
    "grisadas": "grisar",
    "grisado": "grisar",
    "grisados": "grisar",
    "grisai": "grisar",
    "grisais": "grisar",
    "grisalha": "grisalho",
    "grisalhada": "grisalhar",
    "grisalhadas": "grisalhar",
    "grisalhado": "grisalhar",
    "grisalhados": "grisalhar",
    "grisalhai": "grisalhar",
    "grisalhais": "grisalhar",
    "grisalham": "grisalhar",
    "grisalhamo": "grisalhar",
    "grisalhamos": "grisalhar",
    "grisalhando": "grisalhar",
    "grisalhara": "grisalhar",
    "grisalharam": "grisalhar",
    "grisalharas": "grisalhar",
    "grisalharde": "grisalhar",
    "grisalhardes": "grisalhar",
    "grisalhare": "grisalhar",
    "grisalharei": "grisalhar",
    "grisalhareis": "grisalhar",
    "grisalharem": "grisalhar",
    "grisalharemos": "grisalhar",
    "grisalhares": "grisalhar",
    "grisalharia": "grisalhar",
    "grisalhariam": "grisalhar",
    "grisalharias": "grisalhar",
    "grisalharmo": "grisalhar",
    "grisalharmos": "grisalhar",
    "grisalhará": "grisalhar",
    "grisalharás": "grisalhar",
    "grisalharão": "grisalhar",
    "grisalharíamos": "grisalhar",
    "grisalharíeis": "grisalhar",
    "grisalhas": "grisalho",
    "grisalhasse": "grisalhar",
    "grisalhassem": "grisalhar",
    "grisalhasses": "grisalhar",
    "grisalhaste": "grisalhar",
    "grisalhastes": "grisalhar",
    "grisalhava": "grisalhar",
    "grisalhavam": "grisalhar",
    "grisalhavas": "grisalhar",
    "grisalhe": "grisalhar",
    "grisalhei": "grisalhar",
    "grisalheis": "grisalhar",
    "grisalhem": "grisalhar",
    "grisalhemo": "grisalhar",
    "grisalhemos": "grisalhar",
    "grisalhes": "grisalhar",
    "grisalho": "grisalhar",
    "grisalhos": "grisalho",
    "grisalhou": "grisalhar",
    "grisalhá": "grisalhar",
    "grisalhámo": "grisalhar",
    "grisalhámos": "grisalhar",
    "grisalháramo": "grisalhar",
    "grisalháramos": "grisalhar",
    "grisalhárei": "grisalhar",
    "grisalháreis": "grisalhar",
    "grisalhásseis": "grisalhar",
    "grisalhássemos": "grisalhar",
    "grisalhávamo": "grisalhar",
    "grisalhávamos": "grisalhar",
    "grisalhávei": "grisalhar",
    "grisalháveis": "grisalhar",
    "grisam": "grisar",
    "grisamo": "grisar",
    "grisamos": "grisar",
    "grisando": "grisar",
    "grisandras": "grisandra",
    "grisara": "grisar",
    "grisaram": "grisar",
    "grisaras": "grisar",
    "grisarde": "grisar",
    "grisardes": "grisar",
    "grisare": "grisar",
    "grisarei": "grisar",
    "grisareis": "grisar",
    "grisarem": "grisar",
    "grisaremos": "grisar",
    "grisares": "grisar",
    "grisaria": "grisar",
    "grisariam": "grisar",
    "grisarias": "grisar",
    "grisarmo": "grisar",
    "grisarmos": "grisar",
    "grisará": "grisar",
    "grisarás": "grisar",
    "grisarão": "grisar",
    "grisaríamos": "grisar",
    "grisaríeis": "grisar",
    "grisas": "grisar",
    "grisasse": "grisar",
    "grisassem": "grisar",
    "grisasses": "grisar",
    "grisaste": "grisar",
    "grisastes": "grisar",
    "grisava": "grisar",
    "grisavam": "grisar",
    "grisavas": "grisar",
    "grise": "grisar",
    "grisei": "grisar",
    "griseis": "grisar",
    "grisem": "grisar",
    "grisemo": "grisar",
    "grisemos": "grisar",
    "grises": "grise",
    "grisetas": "griseta",
    "griso": "grisar",
    "grisona": "grisão",
    "grisonas": "grisão",
    "grisou": "grisar",
    "grisumétrica": "grisumétrico",
    "grisumétricas": "grisumétrico",
    "grisumétricos": "grisumétrico",
    "grisus": "grisu",
    "grisá": "grisar",
    "grisámo": "grisar",
    "grisámos": "grisar",
    "grisáramo": "grisar",
    "grisáramos": "grisar",
    "grisárei": "grisar",
    "grisáreis": "grisar",
    "grisásseis": "grisar",
    "grisássemos": "grisar",
    "grisávamo": "grisar",
    "grisávamos": "grisar",
    "grisávei": "grisar",
    "grisáveis": "grisar",
    "griséia": "griséu",
    "griséias": "griséu",
    "griséus": "griséu",
    "grisões": "grisão",
    "grisúmetros": "grisúmetro",
    "grita": "gritar",
    "gritada": "gritar",
    "gritadas": "gritar",
    "gritadeira": "gritadeiro",
    "gritadeiras": "gritadeiro",
    "gritadeiros": "gritadeiro",
    "gritado": "gritar",
    "gritadora": "gritador",
    "gritadoras": "gritador",
    "gritadores": "gritador",
    "gritados": "gritar",
    "gritai": "gritar",
    "gritais": "gritar",
    "gritam": "gritar",
    "gritamo": "gritar",
    "gritamos": "gritar",
    "gritando": "gritar",
    "gritantes": "gritante",
    "gritara": "gritar",
    "gritaram": "gritar",
    "gritaras": "gritar",
    "gritarde": "gritar",
    "gritardes": "gritar",
    "gritare": "gritar",
    "gritarei": "gritar",
    "gritareis": "gritar",
    "gritarem": "gritar",
    "gritaremos": "gritar",
    "gritares": "gritar",
    "gritaria": "gritar",
    "gritariam": "gritar",
    "gritarias": "gritaria",
    "gritarmo": "gritar",
    "gritarmos": "gritar",
    "gritará": "gritar",
    "gritarás": "gritar",
    "gritarão": "gritar",
    "gritaríamos": "gritar",
    "gritaríeis": "gritar",
    "gritas": "gritar",
    "gritasse": "gritar",
    "gritassem": "gritar",
    "gritasses": "gritar",
    "gritaste": "gritar",
    "gritastes": "gritar",
    "gritava": "gritar",
    "gritavam": "gritar",
    "gritavas": "gritar",
    "grite": "gritar",
    "gritei": "gritar",
    "griteira": "griteiro",
    "griteiras": "griteiro",
    "griteiros": "griteiro",
    "griteis": "gritar",
    "gritem": "gritar",
    "gritemo": "gritar",
    "gritemos": "gritar",
    "griterias": "griteria",
    "grites": "gritar",
    "gritinho": "grito",
    "gritinhos": "grito",
    "gritito": "grito",
    "grititos": "grito",
    "grito": "gritar",
    "gritos": "grito",
    "gritou": "gritar",
    "gritá": "gritar",
    "gritámo": "gritar",
    "gritámos": "gritar",
    "gritáramo": "gritar",
    "gritáramos": "gritar",
    "gritárei": "gritar",
    "gritáreis": "gritar",
    "gritásseis": "gritar",
    "gritássemos": "gritar",
    "gritávamo": "gritar",
    "gritávamos": "gritar",
    "gritávei": "gritar",
    "gritáveis": "gritar",
    "griva": "grivar",
    "grivada": "grivar",
    "grivadas": "grivar",
    "grivado": "grivar",
    "grivados": "grivar",
    "grivai": "grivar",
    "grivais": "grivar",
    "grivam": "grivar",
    "grivamo": "grivar",
    "grivamos": "grivar",
    "grivando": "grivar",
    "grivara": "grivar",
    "grivaram": "grivar",
    "grivaras": "grivar",
    "grivardes": "grivar",
    "grivarei": "grivar",
    "grivareis": "grivar",
    "grivarem": "grivar",
    "grivaremos": "grivar",
    "grivares": "grivar",
    "grivaria": "grivar",
    "grivariam": "grivar",
    "grivarias": "grivar",
    "grivarmo": "grivar",
    "grivarmos": "grivar",
    "grivará": "grivar",
    "grivarás": "grivar",
    "grivarão": "grivar",
    "grivaríamos": "grivar",
    "grivaríeis": "grivar",
    "grivas": "grivar",
    "grivasse": "grivar",
    "grivassem": "grivar",
    "grivasses": "grivar",
    "grivaste": "grivar",
    "grivastes": "grivar",
    "grivava": "grivar",
    "grivavam": "grivar",
    "grivavas": "grivar",
    "grive": "grivar",
    "grivei": "grivar",
    "griveis": "grivar",
    "grivem": "grivar",
    "grivemo": "grivar",
    "grivemos": "grivar",
    "grives": "grivar",
    "grivo": "grivar",
    "grivou": "grivar",
    "grivámo": "grivar",
    "grivámos": "grivar",
    "griváramo": "grivar",
    "griváramos": "grivar",
    "griváreis": "grivar",
    "grivásseis": "grivar",
    "grivássemos": "grivar",
    "grivávamo": "grivar",
    "grivávamos": "grivar",
    "griváveis": "grivar",
    "grochos": "grocho",
    "grogues": "grogue",
    "grola": "grolo",
    "grolada": "grolar",
    "groladas": "grolar",
    "grolado": "grolar",
    "grolados": "grolar",
    "grolai": "grolar",
    "grolais": "grolar",
    "grolam": "grolar",
    "grolamo": "grolar",
    "grolamos": "grolar",
    "grolando": "grolar",
    "grolara": "grolar",
    "grolaram": "grolar",
    "grolaras": "grolar",
    "grolardes": "grolar",
    "grolarei": "grolar",
    "grolareis": "grolar",
    "grolarem": "grolar",
    "grolaremos": "grolar",
    "grolares": "grolar",
    "grolaria": "grolar",
    "grolariam": "grolar",
    "grolarias": "grolar",
    "grolarmo": "grolar",
    "grolarmos": "grolar",
    "grolará": "grolar",
    "grolarás": "grolar",
    "grolarão": "grolar",
    "grolaríamos": "grolar",
    "grolaríeis": "grolar",
    "grolas": "grolo",
    "grolasse": "grolar",
    "grolassem": "grolar",
    "grolasses": "grolar",
    "grolaste": "grolar",
    "grolastes": "grolar",
    "grolava": "grolar",
    "grolavam": "grolar",
    "grolavas": "grolar",
    "grole": "grolar",
    "grolei": "grolar",
    "groleis": "grolar",
    "grolem": "grolar",
    "grolemo": "grolar",
    "grolemos": "grolar",
    "groles": "grolar",
    "grolo": "grolar",
    "grolos": "grolo",
    "grolou": "grolar",
    "grolámo": "grolar",
    "grolámos": "grolar",
    "groláramo": "grolar",
    "groláramos": "grolar",
    "groláreis": "grolar",
    "grolásseis": "grolar",
    "grolássemos": "grolar",
    "grolávamo": "grolar",
    "grolávamos": "grolar",
    "groláveis": "grolar",
    "gromas": "groma",
    "gromática": "gromático",
    "gromáticas": "gromático",
    "gromáticos": "gromático",
    "gronelandesa": "gronelandês",
    "gronelandesas": "gronelandês",
    "gronelandeses": "gronelandês",
    "gronelândias": "gronelândia",
    "gronhos": "gronho",
    "grosa": "grosar",
    "grosada": "grosar",
    "grosadas": "grosar",
    "grosado": "grosar",
    "grosadora": "grosador",
    "grosadoras": "grosador",
    "grosadores": "grosador",
    "grosados": "grosar",
    "grosai": "grosar",
    "grosais": "grosar",
    "grosam": "grosar",
    "grosamo": "grosar",
    "grosamos": "grosar",
    "grosando": "grosar",
    "grosara": "grosar",
    "grosaram": "grosar",
    "grosaras": "grosar",
    "grosarde": "grosar",
    "grosardes": "grosar",
    "grosare": "grosar",
    "grosarei": "grosar",
    "grosareis": "grosar",
    "grosarem": "grosar",
    "grosaremos": "grosar",
    "grosares": "grosar",
    "grosaria": "grosar",
    "grosariam": "grosar",
    "grosarias": "grosar",
    "grosarmo": "grosar",
    "grosarmos": "grosar",
    "grosará": "grosar",
    "grosarás": "grosar",
    "grosarão": "grosar",
    "grosaríamos": "grosar",
    "grosaríeis": "grosar",
    "grosas": "grosar",
    "grosasse": "grosar",
    "grosassem": "grosar",
    "grosasses": "grosar",
    "grosaste": "grosar",
    "grosastes": "grosar",
    "grosava": "grosar",
    "grosavam": "grosar",
    "grosavas": "grosar",
    "grose": "grosar",
    "grosei": "grosar",
    "groseis": "grosar",
    "groselhas": "groselha",
    "groselheiras": "groselheira",
    "groselheiros": "groselheiro",
    "grosem": "grosar",
    "grosemo": "grosar",
    "grosemos": "grosar",
    "groses": "grosar",
    "groso": "grosar",
    "grosou": "grosar",
    "grossa": "grosso",
    "grossagranas": "grossagrana",
    "grossarias": "grossaria",
    "grossas": "grosso",
    "grosseca": "grosseco",
    "grossecas": "grosseco",
    "grossecos": "grosseco",
    "grosseira": "grosseiro",
    "grosseiras": "grosseiro",
    "grosseiraça": "grosseiraço",
    "grosseiraças": "grosseiraço",
    "grosseiraços": "grosseiraço",
    "grosseireca": "grosseireco",
    "grosseirecas": "grosseireco",
    "grosseirecos": "grosseireco",
    "grosseirismos": "grosseirismo",
    "grosseirona": "grosseirão",
    "grosseironas": "grosseirão",
    "grosseiros": "grosseiro",
    "grosseirosa": "grosseiroso",
    "grosseirosas": "grosseiroso",
    "grosseirosos": "grosseiroso",
    "grosseirota": "grosseirote",
    "grosseirotas": "grosseirote",
    "grosseirotes": "grosseirote",
    "grosseiríssima": "grosseiro",
    "grosseiríssimas": "grosseiro",
    "grosseiríssimo": "grosseiro",
    "grosseiríssimos": "grosseiro",
    "grosseirões": "grosseirão",
    "grosserias": "grosseria",
    "grossistas": "grossista",
    "grossona": "grossão",
    "grossonas": "grossão",
    "grossos": "grosso",
    "grossota": "grossote",
    "grossotas": "grossote",
    "grossotes": "grossote",
    "grossularinas": "grossularina",
    "grossularites": "grossularite",
    "grossulariácea": "grossulariáceo",
    "grossulariáceas": "grossulariáceo",
    "grossulariáceos": "grossulariáceo",
    "grossularínica": "grossularínico",
    "grossularínicas": "grossularínico",
    "grossularínicos": "grossularínico",
    "grossularítica": "grossularítico",
    "grossularíticas": "grossularítico",
    "grossularíticos": "grossularítico",
    "grossulinas": "grossulina",
    "grossulárias": "grossulária",
    "grossulínica": "grossulínico",
    "grossulínicas": "grossulínico",
    "grossulínicos": "grossulínico",
    "grossuras": "grossura",
    "grossíssima": "grosso",
    "grossíssimas": "grosso",
    "grossíssimo": "grosso",
    "grossíssimos": "grosso",
    "grossões": "grossão",
    "grosá": "grosar",
    "grosámo": "grosar",
    "grosámos": "grosar",
    "grosáramo": "grosar",
    "grosáramos": "grosar",
    "grosárei": "grosar",
    "grosáreis": "grosar",
    "grosásseis": "grosar",
    "grosássemos": "grosar",
    "grosávamo": "grosar",
    "grosávamos": "grosar",
    "grosávei": "grosar",
    "grosáveis": "grosar",
    "grotas": "grota",
    "grotesca": "grotesco",
    "grotescas": "grotesco",
    "grotescos": "grotesco",
    "grous": "grou",
    "grozinhos": "grozinho",
    "grua": "gruir",
    "gruais": "gruir",
    "grualetas": "grualeta",
    "gruam": "gruir",
    "gruamo": "gruir",
    "gruamos": "gruir",
    "gruas": "gruir",
    "gruaus": "gruau",
    "gruda": "grudar",
    "grudada": "grudar",
    "grudadas": "grudar",
    "grudado": "grudar",
    "grudadoiros": "grudadoiro",
    "grudadora": "grudador",
    "grudadoras": "grudador",
    "grudadores": "grudador",
    "grudados": "grudar",
    "grudadouros": "grudadouro",
    "grudaduras": "grudadura",
    "grudai": "grudar",
    "grudais": "grudar",
    "grudam": "grudar",
    "grudamo": "grudar",
    "grudamos": "grudar",
    "grudando": "grudar",
    "grudara": "grudar",
    "grudaram": "grudar",
    "grudaras": "grudar",
    "grudarde": "grudar",
    "grudardes": "grudar",
    "grudare": "grudar",
    "grudarei": "grudar",
    "grudareis": "grudar",
    "grudarem": "grudar",
    "grudaremos": "grudar",
    "grudares": "grudar",
    "grudaria": "grudar",
    "grudariam": "grudar",
    "grudarias": "grudar",
    "grudarmo": "grudar",
    "grudarmos": "grudar",
    "grudará": "grudar",
    "grudarás": "grudar",
    "grudarão": "grudar",
    "grudaríamos": "grudar",
    "grudaríeis": "grudar",
    "grudas": "grudar",
    "grudasse": "grudar",
    "grudassem": "grudar",
    "grudasses": "grudar",
    "grudaste": "grudar",
    "grudastes": "grudar",
    "grudava": "grudar",
    "grudavam": "grudar",
    "grudavas": "grudar",
    "grude": "grudar",
    "grudei": "grudar",
    "grudeis": "grudar",
    "grudem": "grudar",
    "grudemo": "grudar",
    "grudemos": "grudar",
    "grudes": "grude",
    "grudo": "grudar",
    "grudou": "grudar",
    "grudá": "grudar",
    "grudámo": "grudar",
    "grudámos": "grudar",
    "grudáramo": "grudar",
    "grudáramos": "grudar",
    "grudárei": "grudar",
    "grudáreis": "grudar",
    "grudásseis": "grudar",
    "grudássemos": "grudar",
    "grudávamo": "grudar",
    "grudávamos": "grudar",
    "grudávei": "grudar",
    "grudáveis": "grudar",
    "grueira": "grueiro",
    "grueiras": "grueiro",
    "grueiros": "grueiro",
    "gruem": "gruir",
    "grugruleja": "grugrulejar",
    "grugrulejada": "grugrulejar",
    "grugrulejadas": "grugrulejar",
    "grugrulejado": "grugrulejar",
    "grugrulejados": "grugrulejar",
    "grugrulejai": "grugrulejar",
    "grugrulejais": "grugrulejar",
    "grugrulejam": "grugrulejar",
    "grugrulejamo": "grugrulejar",
    "grugrulejamos": "grugrulejar",
    "grugrulejando": "grugrulejar",
    "grugrulejara": "grugrulejar",
    "grugrulejaram": "grugrulejar",
    "grugrulejaras": "grugrulejar",
    "grugrulejardes": "grugrulejar",
    "grugrulejarei": "grugrulejar",
    "grugrulejareis": "grugrulejar",
    "grugrulejarem": "grugrulejar",
    "grugrulejaremos": "grugrulejar",
    "grugrulejares": "grugrulejar",
    "grugrulejaria": "grugrulejar",
    "grugrulejariam": "grugrulejar",
    "grugrulejarias": "grugrulejar",
    "grugrulejarmo": "grugrulejar",
    "grugrulejarmos": "grugrulejar",
    "grugrulejará": "grugrulejar",
    "grugrulejarás": "grugrulejar",
    "grugrulejarão": "grugrulejar",
    "grugrulejaríamos": "grugrulejar",
    "grugrulejaríeis": "grugrulejar",
    "grugrulejas": "grugrulejar",
    "grugrulejasse": "grugrulejar",
    "grugrulejassem": "grugrulejar",
    "grugrulejasses": "grugrulejar",
    "grugrulejaste": "grugrulejar",
    "grugrulejastes": "grugrulejar",
    "grugrulejava": "grugrulejar",
    "grugrulejavam": "grugrulejar",
    "grugrulejavas": "grugrulejar",
    "grugruleje": "grugrulejar",
    "grugrulejei": "grugrulejar",
    "grugrulejeis": "grugrulejar",
    "grugrulejem": "grugrulejar",
    "grugrulejemo": "grugrulejar",
    "grugrulejemos": "grugrulejar",
    "grugrulejes": "grugrulejar",
    "grugrulejo": "grugrulejar",
    "grugrulejos": "grugrulejo",
    "grugrulejou": "grugrulejar",
    "grugrulejámo": "grugrulejar",
    "grugrulejámos": "grugrulejar",
    "grugrulejáramo": "grugrulejar",
    "grugrulejáramos": "grugrulejar",
    "grugrulejáreis": "grugrulejar",
    "grugrulejásseis": "grugrulejar",
    "grugrulejássemos": "grugrulejar",
    "grugrulejávamo": "grugrulejar",
    "grugrulejávamos": "grugrulejar",
    "grugrulejáveis": "grugrulejar",
    "grugrus": "grugru",
    "gruguleja": "grugulejar",
    "grugulejada": "grugulejar",
    "grugulejadas": "grugulejar",
    "grugulejado": "grugulejar",
    "grugulejados": "grugulejar",
    "grugulejai": "grugulejar",
    "grugulejais": "grugulejar",
    "grugulejam": "grugulejar",
    "grugulejamo": "grugulejar",
    "grugulejamos": "grugulejar",
    "grugulejando": "grugulejar",
    "grugulejara": "grugulejar",
    "grugulejaram": "grugulejar",
    "grugulejaras": "grugulejar",
    "grugulejardes": "grugulejar",
    "grugulejarei": "grugulejar",
    "grugulejareis": "grugulejar",
    "grugulejarem": "grugulejar",
    "grugulejaremos": "grugulejar",
    "grugulejares": "grugulejar",
    "grugulejaria": "grugulejar",
    "grugulejariam": "grugulejar",
    "grugulejarias": "grugulejar",
    "grugulejarmo": "grugulejar",
    "grugulejarmos": "grugulejar",
    "grugulejará": "grugulejar",
    "grugulejarás": "grugulejar",
    "grugulejarão": "grugulejar",
    "grugulejaríamos": "grugulejar",
    "grugulejaríeis": "grugulejar",
    "grugulejas": "grugulejar",
    "grugulejasse": "grugulejar",
    "grugulejassem": "grugulejar",
    "grugulejasses": "grugulejar",
    "grugulejaste": "grugulejar",
    "grugulejastes": "grugulejar",
    "grugulejava": "grugulejar",
    "grugulejavam": "grugulejar",
    "grugulejavas": "grugulejar",
    "gruguleje": "grugulejar",
    "grugulejei": "grugulejar",
    "grugulejeis": "grugulejar",
    "grugulejem": "grugulejar",
    "grugulejemo": "grugulejar",
    "grugulejemos": "grugulejar",
    "grugulejes": "grugulejar",
    "grugulejo": "grugulejar",
    "grugulejou": "grugulejar",
    "grugulejámo": "grugulejar",
    "grugulejámos": "grugulejar",
    "grugulejáramo": "grugulejar",
    "grugulejáramos": "grugulejar",
    "grugulejáreis": "grugulejar",
    "grugulejásseis": "grugulejar",
    "grugulejássemos": "grugulejar",
    "grugulejávamo": "grugulejar",
    "grugulejávamos": "grugulejar",
    "grugulejáveis": "grugulejar",
    "grugutubas": "grugutuba",
    "grui": "gruir",
    "gruiformes": "gruiforme",
    "gruindo": "gruir",
    "gruins": "gruim",
    "gruirdes": "gruir",
    "gruirei": "gruir",
    "gruireis": "gruir",
    "gruiremos": "gruir",
    "gruiria": "gruir",
    "gruiriam": "gruir",
    "gruirias": "gruir",
    "gruirmo": "gruir",
    "gruirmos": "gruir",
    "gruirá": "gruir",
    "gruirás": "gruir",
    "gruirão": "gruir",
    "gruiríamos": "gruir",
    "gruiríeis": "gruir",
    "gruis": "gruir",
    "gruiu": "gruir",
    "grulha": "grulhar",
    "grulhada": "grulhar",
    "grulhadas": "grulhar",
    "grulhado": "grulhar",
    "grulhados": "grulhar",
    "grulhai": "grulhar",
    "grulhais": "grulhar",
    "grulham": "grulhar",
    "grulhamo": "grulhar",
    "grulhamos": "grulhar",
    "grulhando": "grulhar",
    "grulhara": "grulhar",
    "grulharam": "grulhar",
    "grulharas": "grulhar",
    "grulhardes": "grulhar",
    "grulharei": "grulhar",
    "grulhareis": "grulhar",
    "grulharem": "grulhar",
    "grulharemos": "grulhar",
    "grulhares": "grulhar",
    "grulharia": "grulhar",
    "grulhariam": "grulhar",
    "grulharias": "grulhar",
    "grulharmo": "grulhar",
    "grulharmos": "grulhar",
    "grulhará": "grulhar",
    "grulharás": "grulhar",
    "grulharão": "grulhar",
    "grulharíamos": "grulhar",
    "grulharíeis": "grulhar",
    "grulhas": "grulhar",
    "grulhasse": "grulhar",
    "grulhassem": "grulhar",
    "grulhasses": "grulhar",
    "grulhaste": "grulhar",
    "grulhastes": "grulhar",
    "grulhava": "grulhar",
    "grulhavam": "grulhar",
    "grulhavas": "grulhar",
    "grulhe": "grulhar",
    "grulhei": "grulhar",
    "grulheis": "grulhar",
    "grulhem": "grulhar",
    "grulhemo": "grulhar",
    "grulhemos": "grulhar",
    "grulhenta": "grulhento",
    "grulhentas": "grulhento",
    "grulhentos": "grulhento",
    "grulhes": "grulhar",
    "grulho": "grulhar",
    "grulhou": "grulhar",
    "grulhámo": "grulhar",
    "grulhámos": "grulhar",
    "grulháramo": "grulhar",
    "grulháramos": "grulhar",
    "grulháreis": "grulhar",
    "grulhásseis": "grulhar",
    "grulhássemos": "grulhar",
    "grulhávamo": "grulhar",
    "grulhávamos": "grulhar",
    "grulháveis": "grulhar",
    "gruma": "grumar",
    "grumada": "grumar",
    "grumadas": "grumar",
    "grumado": "grumar",
    "grumados": "grumar",
    "grumai": "grumar",
    "grumais": "grumar",
    "grumam": "grumar",
    "grumamo": "grumar",
    "grumamos": "grumar",
    "grumando": "grumar",
    "grumara": "grumar",
    "grumaram": "grumar",
    "grumaras": "grumar",
    "grumarde": "grumar",
    "grumardes": "grumar",
    "grumare": "grumar",
    "grumarei": "grumar",
    "grumareis": "grumar",
    "grumarem": "grumar",
    "grumaremos": "grumar",
    "grumares": "grumar",
    "grumaria": "grumar",
    "grumariam": "grumar",
    "grumarias": "grumar",
    "grumarmo": "grumar",
    "grumarmos": "grumar",
    "grumará": "grumar",
    "grumarás": "grumar",
    "grumarão": "grumar",
    "grumaríamos": "grumar",
    "grumaríeis": "grumar",
    "grumas": "grumar",
    "grumasse": "grumar",
    "grumassem": "grumar",
    "grumasses": "grumar",
    "grumaste": "grumar",
    "grumastes": "grumar",
    "grumatis": "grumati",
    "grumava": "grumar",
    "grumavam": "grumar",
    "grumavas": "grumar",
    "grume": "grumar",
    "grumece": "grumecer",
    "grumecei": "grumecer",
    "grumeceis": "grumecer",
    "grumecem": "grumecer",
    "grumecemo": "grumecer",
    "grumecemos": "grumecer",
    "grumecendo": "grumecer",
    "grumecera": "grumecer",
    "grumeceram": "grumecer",
    "grumeceras": "grumecer",
    "grumecerdes": "grumecer",
    "grumecerei": "grumecer",
    "grumecereis": "grumecer",
    "grumecerem": "grumecer",
    "grumeceremos": "grumecer",
    "grumeceres": "grumecer",
    "grumeceria": "grumecer",
    "grumeceriam": "grumecer",
    "grumecerias": "grumecer",
    "grumecermo": "grumecer",
    "grumecermos": "grumecer",
    "grumecerá": "grumecer",
    "grumecerás": "grumecer",
    "grumecerão": "grumecer",
    "grumeceríamos": "grumecer",
    "grumeceríeis": "grumecer",
    "grumeces": "grumecer",
    "grumecesse": "grumecer",
    "grumecessem": "grumecer",
    "grumecesses": "grumecer",
    "grumeceste": "grumecer",
    "grumecestes": "grumecer",
    "grumeceu": "grumecer",
    "grumeci": "grumecer",
    "grumecia": "grumecer",
    "grumeciam": "grumecer",
    "grumecias": "grumecer",
    "grumecida": "grumecer",
    "grumecidas": "grumecer",
    "grumecido": "grumecer",
    "grumecidos": "grumecer",
    "grumecências": "grumecência",
    "grumecêramo": "grumecer",
    "grumecêramos": "grumecer",
    "grumecêreis": "grumecer",
    "grumecêsseis": "grumecer",
    "grumecêssemos": "grumecer",
    "grumecíamo": "grumecer",
    "grumecíamos": "grumecer",
    "grumecíeis": "grumecer",
    "grumei": "grumar",
    "grumeis": "grumar",
    "grumelos": "grumelo",
    "grumem": "grumar",
    "grumemo": "grumar",
    "grumemos": "grumar",
    "grumes": "grumar",
    "grumetagens": "grumetagem",
    "grumetes": "grumete",
    "grumeça": "grumecer",
    "grumeçais": "grumecer",
    "grumeçam": "grumecer",
    "grumeçamo": "grumecer",
    "grumeçamos": "grumecer",
    "grumeças": "grumecer",
    "grumeço": "grumecer",
    "grumo": "grumar",
    "grumos": "grumo",
    "grumosa": "grumoso",
    "grumosas": "grumoso",
    "grumosos": "grumoso",
    "grumou": "grumar",
    "grumá": "grumar",
    "grumámo": "grumar",
    "grumámos": "grumar",
    "grumáramo": "grumar",
    "grumáramos": "grumar",
    "grumárei": "grumar",
    "grumáreis": "grumar",
    "grumásseis": "grumar",
    "grumássemos": "grumar",
    "grumávamo": "grumar",
    "grumávamos": "grumar",
    "grumávei": "grumar",
    "grumáveis": "grumar",
    "grunha": "grunhir",
    "grunhais": "grunhir",
    "grunham": "grunhir",
    "grunhamo": "grunhir",
    "grunhamos": "grunhir",
    "grunhas": "grunhir",
    "grunhe": "grunhir",
    "grunhem": "grunhir",
    "grunhes": "grunhir",
    "grunhi": "grunhir",
    "grunhia": "grunhir",
    "grunhiam": "grunhir",
    "grunhias": "grunhir",
    "grunhida": "grunhir",
    "grunhidas": "grunhir",
    "grunhideiras": "grunhideira",
    "grunhidelas": "grunhidela",
    "grunhido": "grunhir",
    "grunhidora": "grunhidor",
    "grunhidoras": "grunhidor",
    "grunhidores": "grunhidor",
    "grunhidos": "grunhir",
    "grunhimo": "grunhir",
    "grunhimos": "grunhir",
    "grunhindo": "grunhir",
    "grunhira": "grunhir",
    "grunhiram": "grunhir",
    "grunhiras": "grunhir",
    "grunhirdes": "grunhir",
    "grunhirei": "grunhir",
    "grunhireis": "grunhir",
    "grunhirem": "grunhir",
    "grunhiremos": "grunhir",
    "grunhires": "grunhir",
    "grunhiria": "grunhir",
    "grunhiriam": "grunhir",
    "grunhirias": "grunhir",
    "grunhirmo": "grunhir",
    "grunhirmos": "grunhir",
    "grunhirá": "grunhir",
    "grunhirás": "grunhir",
    "grunhirão": "grunhir",
    "grunhiríamos": "grunhir",
    "grunhiríeis": "grunhir",
    "grunhis": "grunhir",
    "grunhisse": "grunhir",
    "grunhissem": "grunhir",
    "grunhisses": "grunhir",
    "grunhiste": "grunhir",
    "grunhistes": "grunhir",
    "grunhiu": "grunhir",
    "grunho": "grunhir",
    "grunhíamo": "grunhir",
    "grunhíamos": "grunhir",
    "grunhíeis": "grunhir",
    "grunhíramo": "grunhir",
    "grunhíramos": "grunhir",
    "grunhíreis": "grunhir",
    "grunhísseis": "grunhir",
    "grunhíssemos": "grunhir",
    "gruo": "gruir",
    "grupa": "grupar",
    "grupada": "grupar",
    "grupadas": "grupar",
    "grupado": "grupar",
    "grupados": "grupar",
    "grupai": "grupar",
    "grupais": "grupar",
    "grupam": "grupar",
    "grupamentos": "grupamento",
    "grupamo": "grupar",
    "grupamos": "grupar",
    "grupando": "grupar",
    "grupara": "grupar",
    "gruparam": "grupar",
    "gruparas": "grupar",
    "gruparde": "grupar",
    "grupardes": "grupar",
    "grupare": "grupar",
    "gruparei": "grupar",
    "grupareis": "grupar",
    "gruparem": "grupar",
    "gruparemos": "grupar",
    "grupares": "grupar",
    "gruparia": "grupar",
    "grupariam": "grupar",
    "gruparias": "grupar",
    "gruparmo": "grupar",
    "gruparmos": "grupar",
    "grupará": "grupar",
    "gruparás": "grupar",
    "gruparão": "grupar",
    "gruparíamos": "grupar",
    "gruparíeis": "grupar",
    "grupas": "grupar",
    "grupasse": "grupar",
    "grupassem": "grupar",
    "grupasses": "grupar",
    "grupaste": "grupar",
    "grupastes": "grupar",
    "grupava": "grupar",
    "grupavam": "grupar",
    "grupavas": "grupar",
    "grupe": "grupar",
    "grupei": "grupar",
    "grupeis": "grupar",
    "grupelhos": "grupelho",
    "grupem": "grupar",
    "grupemo": "grupar",
    "grupemos": "grupar",
    "grupes": "grupar",
    "grupetos": "grupeto",
    "grupinho": "grupo",
    "grupinhos": "grupo",
    "grupito": "grupo",
    "grupitos": "grupo",
    "grupo": "grupar",
    "grupos": "grupo",
    "grupou": "grupar",
    "grupá": "grupar",
    "grupámo": "grupar",
    "grupámos": "grupar",
    "grupáramo": "grupar",
    "grupáramos": "grupar",
    "grupárei": "grupar",
    "grupáreis": "grupar",
    "grupásseis": "grupar",
    "grupássemos": "grupar",
    "grupávamo": "grupar",
    "grupávamos": "grupar",
    "grupávei": "grupar",
    "grupáveis": "grupável",
    "grupúsculos": "grupúsculo",
    "grutas": "gruta",
    "grutesca": "grutesco",
    "grutescas": "grutesco",
    "grutescos": "grutesco",
    "gruyères": "gruyère",
    "gruzínia": "gruzínio",
    "gruzínias": "gruzínio",
    "gruzínios": "gruzínio",
    "gruí": "gruir",
    "gruía": "gruir",
    "gruíam": "gruir",
    "gruíamo": "gruir",
    "gruíamos": "gruir",
    "gruías": "gruir",
    "gruída": "gruir",
    "gruídas": "gruir",
    "gruído": "gruir",
    "gruídos": "gruir",
    "gruíeis": "gruir",
    "gruímo": "gruir",
    "gruímos": "gruir",
    "gruíra": "gruir",
    "gruíram": "gruir",
    "gruíramo": "gruir",
    "gruíramos": "gruir",
    "gruíras": "gruir",
    "gruíreis": "gruir",
    "gruírem": "gruir",
    "gruíres": "gruir",
    "gruís": "gruir",
    "gruísse": "gruir",
    "gruísseis": "gruir",
    "gruíssem": "gruir",
    "gruíssemos": "gruir",
    "gruísses": "gruir",
    "gruíste": "gruir",
    "gruístes": "gruir",
    "gráceis": "grácil",
    "gráfica": "gráfico",
    "gráficas": "gráfico",
    "gráficos": "gráfico",
    "grávida": "grávido",
    "grávidas": "grávido",
    "grávidos": "grávido",
    "grânulos": "grânulo",
    "grãos": "grão",
    "grãozeira": "grãozeiro",
    "grãozeiras": "grãozeiro",
    "grãozeiros": "grãozeiro",
    "grãozinho": "grão",
    "grãozinhos": "grão",
    "grãozito": "grão",
    "grãozitos": "grão",
    "grãs": "grã",
    "grémios": "grémio",
    "grés": "gré",
    "grífica": "grífico",
    "gríficas": "grífico",
    "gríficos": "grífico",
    "gróias": "gróia",
    "grúmulos": "grúmulo",
    "guabirabas": "guabiraba",
    "guabirabeiras": "guabirabeira",
    "guabirobas": "guabiroba",
    "guabirobeiras": "guabirobeira",
    "guabirus": "guabiru",
    "guaches": "guache",
    "guachos": "guacho",
    "guacinas": "guacina",
    "guacos": "guaco",
    "guadamecileira": "guadamecileiro",
    "guadamecileiras": "guadamecileiro",
    "guadamecileiros": "guadamecileiro",
    "guadamecins": "guadamecim",
    "guadamecis": "guadamecil",
    "guadramilesa": "guadramilês",
    "guadramilesas": "guadramilês",
    "guadramileses": "guadramilês",
    "guaia": "guaiar",
    "guaiabas": "guaiaba",
    "guaiacas": "guaiaca",
    "guaiacinas": "guaiacina",
    "guaiacóis": "guaiacol",
    "guaiada": "guaiar",
    "guaiadas": "guaiar",
    "guaiado": "guaiar",
    "guaiados": "guaiar",
    "guaiai": "guaiar",
    "guaiais": "guaiar",
    "guaiam": "guaiar",
    "guaiamo": "guaiar",
    "guaiamos": "guaiar",
    "guaiando": "guaiar",
    "guaiara": "guaiar",
    "guaiaram": "guaiar",
    "guaiaras": "guaiara",
    "guaiardes": "guaiar",
    "guaiarei": "guaiar",
    "guaiareis": "guaiar",
    "guaiarem": "guaiar",
    "guaiaremos": "guaiar",
    "guaiares": "guaiar",
    "guaiaria": "guaiar",
    "guaiariam": "guaiar",
    "guaiarias": "guaiar",
    "guaiarmo": "guaiar",
    "guaiarmos": "guaiar",
    "guaiará": "guaiar",
    "guaiarás": "guaiar",
    "guaiarão": "guaiar",
    "guaiaríamos": "guaiar",
    "guaiaríeis": "guaiar",
    "guaias": "guaiar",
    "guaiasse": "guaiar",
    "guaiassem": "guaiar",
    "guaiasses": "guaiar",
    "guaiaste": "guaiar",
    "guaiastes": "guaiar",
    "guaiava": "guaiar",
    "guaiavam": "guaiar",
    "guaiavas": "guaiar",
    "guaie": "guaiar",
    "guaiei": "guaiar",
    "guaieis": "guaiar",
    "guaiem": "guaiar",
    "guaiemo": "guaiar",
    "guaiemos": "guaiar",
    "guaies": "guaiar",
    "guainambés": "guainambé",
    "guaio": "guaiar",
    "guaiou": "guaiar",
    "guaiámo": "guaiar",
    "guaiámos": "guaiar",
    "guaiáramo": "guaiar",
    "guaiáramos": "guaiar",
    "guaiáreis": "guaiar",
    "guaiásseis": "guaiar",
    "guaiássemos": "guaiar",
    "guaiávamo": "guaiar",
    "guaiávamos": "guaiar",
    "guaiáveis": "guaiar",
    "gualda": "gualdo",
    "gualdais": "gualdir",
    "gualdam": "gualdir",
    "gualdamo": "gualdir",
    "gualdamos": "gualdir",
    "gualdas": "gualdo",
    "gualde": "gualdir",
    "gualdem": "gualdir",
    "gualdes": "gualdir",
    "gualdi": "gualdir",
    "gualdia": "gualdir",
    "gualdiam": "gualdir",
    "gualdias": "gualdir",
    "gualdida": "gualdir",
    "gualdidas": "gualdir",
    "gualdido": "gualdir",
    "gualdidos": "gualdir",
    "gualdimo": "gualdir",
    "gualdimos": "gualdir",
    "gualdindo": "gualdir",
    "gualdipérios": "gualdipério",
    "gualdira": "gualdir",
    "gualdiram": "gualdir",
    "gualdiras": "gualdir",
    "gualdirde": "gualdir",
    "gualdirdes": "gualdir",
    "gualdire": "gualdir",
    "gualdirei": "gualdir",
    "gualdireis": "gualdir",
    "gualdirem": "gualdir",
    "gualdiremos": "gualdir",
    "gualdires": "gualdir",
    "gualdiria": "gualdir",
    "gualdiriam": "gualdir",
    "gualdirias": "gualdir",
    "gualdirmo": "gualdir",
    "gualdirmos": "gualdir",
    "gualdirá": "gualdir",
    "gualdirás": "gualdir",
    "gualdirão": "gualdir",
    "gualdiríamos": "gualdir",
    "gualdiríeis": "gualdir",
    "gualdis": "gualdir",
    "gualdisse": "gualdir",
    "gualdissem": "gualdir",
    "gualdisses": "gualdir",
    "gualdiste": "gualdir",
    "gualdistes": "gualdir",
    "gualdiu": "gualdir",
    "gualdo": "gualdir",
    "gualdos": "gualdo",
    "gualdrapas": "gualdrapa",
    "gualdras": "gualdra",
    "gualdripa": "gualdripar",
    "gualdripada": "gualdripar",
    "gualdripadas": "gualdripar",
    "gualdripado": "gualdripar",
    "gualdripados": "gualdripar",
    "gualdripai": "gualdripar",
    "gualdripais": "gualdripar",
    "gualdripam": "gualdripar",
    "gualdripamo": "gualdripar",
    "gualdripamos": "gualdripar",
    "gualdripando": "gualdripar",
    "gualdripara": "gualdripar",
    "gualdriparam": "gualdripar",
    "gualdriparas": "gualdripar",
    "gualdriparde": "gualdripar",
    "gualdripardes": "gualdripar",
    "gualdripare": "gualdripar",
    "gualdriparei": "gualdripar",
    "gualdripareis": "gualdripar",
    "gualdriparem": "gualdripar",
    "gualdriparemos": "gualdripar",
    "gualdripares": "gualdripar",
    "gualdriparia": "gualdripar",
    "gualdripariam": "gualdripar",
    "gualdriparias": "gualdripar",
    "gualdriparmo": "gualdripar",
    "gualdriparmos": "gualdripar",
    "gualdripará": "gualdripar",
    "gualdriparás": "gualdripar",
    "gualdriparão": "gualdripar",
    "gualdriparíamos": "gualdripar",
    "gualdriparíeis": "gualdripar",
    "gualdripas": "gualdripar",
    "gualdripasse": "gualdripar",
    "gualdripassem": "gualdripar",
    "gualdripasses": "gualdripar",
    "gualdripaste": "gualdripar",
    "gualdripastes": "gualdripar",
    "gualdripava": "gualdripar",
    "gualdripavam": "gualdripar",
    "gualdripavas": "gualdripar",
    "gualdripe": "gualdripar",
    "gualdripei": "gualdripar",
    "gualdripeis": "gualdripar",
    "gualdripem": "gualdripar",
    "gualdripemo": "gualdripar",
    "gualdripemos": "gualdripar",
    "gualdripes": "gualdripar",
    "gualdripo": "gualdripar",
    "gualdripou": "gualdripar",
    "gualdripá": "gualdripar",
    "gualdripámo": "gualdripar",
    "gualdripámos": "gualdripar",
    "gualdripáramo": "gualdripar",
    "gualdripáramos": "gualdripar",
    "gualdripárei": "gualdripar",
    "gualdripáreis": "gualdripar",
    "gualdripásseis": "gualdripar",
    "gualdripássemos": "gualdripar",
    "gualdripávamo": "gualdripar",
    "gualdripávamos": "gualdripar",
    "gualdripávei": "gualdripar",
    "gualdripáveis": "gualdripar",
    "gualdropes": "gualdrope",
    "gualdíamo": "gualdir",
    "gualdíamos": "gualdir",
    "gualdíei": "gualdir",
    "gualdíeis": "gualdir",
    "gualdíramo": "gualdir",
    "gualdíramos": "gualdir",
    "gualdírei": "gualdir",
    "gualdíreis": "gualdir",
    "gualdísseis": "gualdir",
    "gualdíssemos": "gualdir",
    "gualteiras": "gualteira",
    "gualteriana": "gualteriano",
    "gualterianas": "gualteriano",
    "gualterianos": "gualteriano",
    "gualtérias": "gualtéria",
    "guambucos": "guambuco",
    "guampadas": "guampada",
    "guampas": "guampa",
    "guampaços": "guampaço",
    "guanacos": "guanaco",
    "guancha": "guancho",
    "guanchas": "guancho",
    "guanches": "guanche",
    "guanchos": "guancho",
    "guandeiros": "guandeiro",
    "guaneiras": "guaneira",
    "guanidinas": "guanidina",
    "guanidínica": "guanidínico",
    "guanidínicas": "guanidínico",
    "guanidínicos": "guanidínico",
    "guaninas": "guanina",
    "guanos": "guano",
    "guantes": "guante",
    "guapa": "guapo",
    "guapas": "guapo",
    "guapebas": "guapeba",
    "guapebeiras": "guapebeira",
    "guapervas": "guaperva",
    "guapices": "guapice",
    "guapos": "guapo",
    "guapíssima": "guapo",
    "guapíssimas": "guapo",
    "guapíssimo": "guapo",
    "guapíssimos": "guapo",
    "guara": "guarir",
    "guaracões": "guaracão",
    "guarais": "guarir",
    "guaram": "guarir",
    "guaramo": "guarir",
    "guaramos": "guarir",
    "guaranis": "guarani",
    "guaranás": "guaraná",
    "guarapas": "guarapa",
    "guarapiapunhas": "guarapiapunha",
    "guarapus": "guarapu",
    "guaras": "guarir",
    "guarda": "guardar",
    "guardada": "guardar",
    "guardadas": "guardar",
    "guardadeira": "guardador",
    "guardadeiras": "guardador",
    "guardadeiros": "guardadeiro",
    "guardado": "guardar",
    "guardadora": "guardador",
    "guardadoras": "guardador",
    "guardadores": "guardador",
    "guardados": "guardar",
    "guardai": "guardar",
    "guardais": "guardar",
    "guardam": "guardar",
    "guardamo": "guardar",
    "guardamos": "guardar",
    "guardanapos": "guardanapo",
    "guardando": "guardar",
    "guardara": "guardar",
    "guardaram": "guardar",
    "guardaras": "guardar",
    "guardarde": "guardar",
    "guardardes": "guardar",
    "guardare": "guardar",
    "guardarei": "guardar",
    "guardareis": "guardar",
    "guardarem": "guardar",
    "guardaremos": "guardar",
    "guardares": "guardar",
    "guardaria": "guardar",
    "guardariam": "guardar",
    "guardarias": "guardar",
    "guardarmo": "guardar",
    "guardarmos": "guardar",
    "guardará": "guardar",
    "guardarás": "guardar",
    "guardarão": "guardar",
    "guardaríamos": "guardar",
    "guardaríeis": "guardar",
    "guardas": "guardar",
    "guardasse": "guardar",
    "guardassem": "guardar",
    "guardasses": "guardar",
    "guardaste": "guardar",
    "guardastes": "guardar",
    "guardava": "guardar",
    "guardavam": "guardar",
    "guardavas": "guardar",
    "guarde": "guardar",
    "guardeada": "guardear",
    "guardeadas": "guardear",
    "guardeado": "guardear",
    "guardeados": "guardear",
    "guardeai": "guardear",
    "guardeais": "guardear",
    "guardeamo": "guardear",
    "guardeamos": "guardear",
    "guardeando": "guardear",
    "guardeara": "guardear",
    "guardearam": "guardear",
    "guardearas": "guardear",
    "guardearde": "guardear",
    "guardeardes": "guardear",
    "guardeare": "guardear",
    "guardearei": "guardear",
    "guardeareis": "guardear",
    "guardearem": "guardear",
    "guardearemos": "guardear",
    "guardeares": "guardear",
    "guardearia": "guardear",
    "guardeariam": "guardear",
    "guardearias": "guardear",
    "guardearmo": "guardear",
    "guardearmos": "guardear",
    "guardeará": "guardear",
    "guardearás": "guardear",
    "guardearão": "guardear",
    "guardearíamos": "guardear",
    "guardearíeis": "guardear",
    "guardeasse": "guardear",
    "guardeassem": "guardear",
    "guardeasses": "guardear",
    "guardeaste": "guardear",
    "guardeastes": "guardear",
    "guardeava": "guardear",
    "guardeavam": "guardear",
    "guardeavas": "guardear",
    "guardeei": "guardear",
    "guardeeis": "guardear",
    "guardeemo": "guardear",
    "guardeemos": "guardear",
    "guardei": "guardar",
    "guardeia": "guardear",
    "guardeiam": "guardear",
    "guardeias": "guardear",
    "guardeie": "guardear",
    "guardeiem": "guardear",
    "guardeies": "guardear",
    "guardeio": "guardear",
    "guardeis": "guardar",
    "guardem": "guardar",
    "guardemo": "guardar",
    "guardemos": "guardar",
    "guardenses": "guardense",
    "guardeou": "guardear",
    "guardes": "guardar",
    "guardeá": "guardear",
    "guardeámo": "guardear",
    "guardeámos": "guardear",
    "guardeáramo": "guardear",
    "guardeáramos": "guardear",
    "guardeárei": "guardear",
    "guardeáreis": "guardear",
    "guardeásseis": "guardear",
    "guardeássemos": "guardear",
    "guardeávamo": "guardear",
    "guardeávamos": "guardear",
    "guardeávei": "guardear",
    "guardeáveis": "guardear",
    "guardianias": "guardiania",
    "guardins": "guardim",
    "guardinvões": "guardinvão",
    "guardiã": "guardião",
    "guardiães": "guardião",
    "guardiãs": "guardião",
    "guardiões": "guardião",
    "guardo": "guardar",
    "guardou": "guardar",
    "guardá": "guardar",
    "guardámo": "guardar",
    "guardámos": "guardar",
    "guardáramo": "guardar",
    "guardáramos": "guardar",
    "guardárei": "guardar",
    "guardáreis": "guardar",
    "guardásseis": "guardar",
    "guardássemos": "guardar",
    "guardávamo": "guardar",
    "guardávamos": "guardar",
    "guardávei": "guardar",
    "guardáveis": "guardável",
    "guare": "guarir",
    "guarece": "guarecer",
    "guarecei": "guarecer",
    "guareceis": "guarecer",
    "guarecem": "guarecer",
    "guarecemo": "guarecer",
    "guarecemos": "guarecer",
    "guarecendo": "guarecer",
    "guarecera": "guarecer",
    "guareceram": "guarecer",
    "guareceras": "guarecer",
    "guarecerde": "guarecer",
    "guarecerdes": "guarecer",
    "guarecere": "guarecer",
    "guarecerei": "guarecer",
    "guarecereis": "guarecer",
    "guarecerem": "guarecer",
    "guareceremos": "guarecer",
    "guareceres": "guarecer",
    "guareceria": "guarecer",
    "guareceriam": "guarecer",
    "guarecerias": "guarecer",
    "guarecermo": "guarecer",
    "guarecermos": "guarecer",
    "guarecerá": "guarecer",
    "guarecerás": "guarecer",
    "guarecerão": "guarecer",
    "guareceríamos": "guarecer",
    "guareceríeis": "guarecer",
    "guareces": "guarecer",
    "guarecesse": "guarecer",
    "guarecessem": "guarecer",
    "guarecesses": "guarecer",
    "guareceste": "guarecer",
    "guarecestes": "guarecer",
    "guareceu": "guarecer",
    "guareci": "guarecer",
    "guarecia": "guarecer",
    "guareciam": "guarecer",
    "guarecias": "guarecer",
    "guarecida": "guarecer",
    "guarecidas": "guarecer",
    "guarecido": "guarecer",
    "guarecidos": "guarecer",
    "guarecê": "guarecer",
    "guarecêramo": "guarecer",
    "guarecêramos": "guarecer",
    "guarecêrei": "guarecer",
    "guarecêreis": "guarecer",
    "guarecêsseis": "guarecer",
    "guarecêssemos": "guarecer",
    "guarecíamo": "guarecer",
    "guarecíamos": "guarecer",
    "guarecíei": "guarecer",
    "guarecíeis": "guarecer",
    "guarem": "guarir",
    "guarentes": "guarente",
    "guares": "guarir",
    "guareça": "guarecer",
    "guareçais": "guarecer",
    "guareçam": "guarecer",
    "guareçamo": "guarecer",
    "guareçamos": "guarecer",
    "guareças": "guarecer",
    "guareço": "guarecer",
    "guari": "guarir",
    "guaria": "guarir",
    "guariam": "guarir",
    "guarias": "guarir",
    "guaribas": "guariba",
    "guarida": "guarir",
    "guaridas": "guarir",
    "guarido": "guarir",
    "guaridos": "guarir",
    "guarimo": "guarir",
    "guarimos": "guarir",
    "guarindo": "guarir",
    "guarira": "guarir",
    "guariram": "guarir",
    "guariras": "guarir",
    "guarirde": "guarir",
    "guarirdes": "guarir",
    "guarire": "guarir",
    "guarirei": "guarir",
    "guarireis": "guarir",
    "guarirem": "guarir",
    "guariremos": "guarir",
    "guarires": "guarir",
    "guariria": "guarir",
    "guaririam": "guarir",
    "guaririas": "guarir",
    "guarirmo": "guarir",
    "guarirmos": "guarir",
    "guarirá": "guarir",
    "guarirás": "guarir",
    "guarirão": "guarir",
    "guariríamos": "guarir",
    "guariríeis": "guarir",
    "guaris": "guarir",
    "guarisse": "guarir",
    "guarissem": "guarir",
    "guarisses": "guarir",
    "guariste": "guarir",
    "guaristes": "guarir",
    "guaritas": "guarita",
    "guariu": "guarir",
    "guarna": "guarnir",
    "guarnais": "guarnir",
    "guarnam": "guarnir",
    "guarnamo": "guarnir",
    "guarnamos": "guarnir",
    "guarnas": "guarnir",
    "guarne": "guarnir",
    "guarnece": "guarnecer",
    "guarnecedora": "guarnecedor",
    "guarnecedoras": "guarnecedor",
    "guarnecedores": "guarnecedor",
    "guarnecei": "guarnecer",
    "guarneceis": "guarnecer",
    "guarnecem": "guarnecer",
    "guarnecemo": "guarnecer",
    "guarnecemos": "guarnecer",
    "guarnecendo": "guarnecer",
    "guarnecera": "guarnecer",
    "guarneceram": "guarnecer",
    "guarneceras": "guarnecer",
    "guarnecerde": "guarnecer",
    "guarnecerdes": "guarnecer",
    "guarnecere": "guarnecer",
    "guarnecerei": "guarnecer",
    "guarnecereis": "guarnecer",
    "guarnecerem": "guarnecer",
    "guarneceremos": "guarnecer",
    "guarneceres": "guarnecer",
    "guarneceria": "guarnecer",
    "guarneceriam": "guarnecer",
    "guarnecerias": "guarnecer",
    "guarnecermo": "guarnecer",
    "guarnecermos": "guarnecer",
    "guarnecerá": "guarnecer",
    "guarnecerás": "guarnecer",
    "guarnecerão": "guarnecer",
    "guarneceríamos": "guarnecer",
    "guarneceríeis": "guarnecer",
    "guarneces": "guarnecer",
    "guarnecesse": "guarnecer",
    "guarnecessem": "guarnecer",
    "guarnecesses": "guarnecer",
    "guarneceste": "guarnecer",
    "guarnecestes": "guarnecer",
    "guarneceu": "guarnecer",
    "guarneci": "guarnecer",
    "guarnecia": "guarnecer",
    "guarneciam": "guarnecer",
    "guarnecias": "guarnecer",
    "guarnecida": "guarnecido",
    "guarnecidas": "guarnecido",
    "guarnecido": "guarnecer",
    "guarnecidos": "guarnecido",
    "guarnecimentos": "guarnecimento",
    "guarnecê": "guarnecer",
    "guarnecêramo": "guarnecer",
    "guarnecêramos": "guarnecer",
    "guarnecêrei": "guarnecer",
    "guarnecêreis": "guarnecer",
    "guarnecêsseis": "guarnecer",
    "guarnecêssemos": "guarnecer",
    "guarnecíamo": "guarnecer",
    "guarnecíamos": "guarnecer",
    "guarnecíei": "guarnecer",
    "guarnecíeis": "guarnecer",
    "guarnem": "guarnir",
    "guarnes": "guarnir",
    "guarneça": "guarnecer",
    "guarneçais": "guarnecer",
    "guarneçam": "guarnecer",
    "guarneçamo": "guarnecer",
    "guarneçamos": "guarnecer",
    "guarneças": "guarnecer",
    "guarneço": "guarnecer",
    "guarni": "guarnir",
    "guarnia": "guarnir",
    "guarniam": "guarnir",
    "guarnias": "guarnir",
    "guarnida": "guarnir",
    "guarnidas": "guarnir",
    "guarnido": "guarnir",
    "guarnidos": "guarnir",
    "guarnimo": "guarnir",
    "guarnimos": "guarnir",
    "guarnindo": "guarnir",
    "guarnira": "guarnir",
    "guarniram": "guarnir",
    "guarniras": "guarnir",
    "guarnirde": "guarnir",
    "guarnirdes": "guarnir",
    "guarnire": "guarnir",
    "guarnirei": "guarnir",
    "guarnireis": "guarnir",
    "guarnirem": "guarnir",
    "guarniremos": "guarnir",
    "guarnires": "guarnir",
    "guarniria": "guarnir",
    "guarniriam": "guarnir",
    "guarnirias": "guarnir",
    "guarnirmo": "guarnir",
    "guarnirmos": "guarnir",
    "guarnirá": "guarnir",
    "guarnirás": "guarnir",
    "guarnirão": "guarnir",
    "guarniríamos": "guarnir",
    "guarniríeis": "guarnir",
    "guarnis": "guarnir",
    "guarnisse": "guarnir",
    "guarnissem": "guarnir",
    "guarnisses": "guarnir",
    "guarniste": "guarnir",
    "guarnistes": "guarnir",
    "guarniu": "guarnir",
    "guarnições": "guarnição",
    "guarno": "guarnir",
    "guarníamo": "guarnir",
    "guarníamos": "guarnir",
    "guarníei": "guarnir",
    "guarníeis": "guarnir",
    "guarníramo": "guarnir",
    "guarníramos": "guarnir",
    "guarnírei": "guarnir",
    "guarníreis": "guarnir",
    "guarnísseis": "guarnir",
    "guarníssemos": "guarnir",
    "guaro": "guarir",
    "guarulas": "guarula",
    "guarás": "guará",
    "guarázes": "guaráz",
    "guarânias": "guarânia",
    "guaríamo": "guarir",
    "guaríamos": "guarir",
    "guaríei": "guarir",
    "guaríeis": "guarir",
    "guaríramo": "guarir",
    "guaríramos": "guarir",
    "guarírei": "guarir",
    "guaríreis": "guarir",
    "guarísseis": "guarir",
    "guaríssemos": "guarir",
    "guatemalenses": "guatemalense",
    "guatemalteca": "guatemalteco",
    "guatemaltecas": "guatemalteco",
    "guatemaltecos": "guatemalteco",
    "guaxes": "guaxe",
    "guazilados": "guazilado",
    "guazis": "guazil",
    "gucoxos": "gucoxo",
    "gudermannianas": "gudermanniana",
    "guebros": "guebro",
    "guechos": "guecho",
    "guedelhas": "guedelha",
    "guedelhos": "guedelho",
    "gueeiras": "gueeira",
    "gueeiros": "gueeiro",
    "guegues": "guegue",
    "gueijos": "gueijo",
    "gueis": "guei",
    "gueixas": "gueixa",
    "gueixos": "gueixo",
    "guejas": "gueja",
    "guelengues": "guelengue",
    "guelfa": "guelfo",
    "guelfas": "guelfo",
    "guelfos": "guelfo",
    "guelmos": "guelmo",
    "guelras": "guelra",
    "guelrichos": "guelricho",
    "guelritas": "guelrita",
    "guensos": "guenso",
    "guenza": "guenzo",
    "guenzas": "guenzo",
    "guenzos": "guenzo",
    "gueres": "guere",
    "guerras": "guerra",
    "guerrazinha": "guerra",
    "guerrazinhas": "guerra",
    "guerrazita": "guerra",
    "guerrazitas": "guerra",
    "guerreada": "guerrear",
    "guerreadas": "guerrear",
    "guerreado": "guerrear",
    "guerreadora": "guerreador",
    "guerreadoras": "guerreador",
    "guerreadores": "guerreador",
    "guerreados": "guerrear",
    "guerreai": "guerrear",
    "guerreais": "guerrear",
    "guerreamo": "guerrear",
    "guerreamos": "guerrear",
    "guerreando": "guerrear",
    "guerreara": "guerrear",
    "guerrearam": "guerrear",
    "guerrearas": "guerrear",
    "guerrearde": "guerrear",
    "guerreardes": "guerrear",
    "guerreare": "guerrear",
    "guerrearei": "guerrear",
    "guerreareis": "guerrear",
    "guerrearem": "guerrear",
    "guerrearemos": "guerrear",
    "guerreares": "guerrear",
    "guerrearia": "guerrear",
    "guerreariam": "guerrear",
    "guerrearias": "guerrear",
    "guerrearmo": "guerrear",
    "guerrearmos": "guerrear",
    "guerreará": "guerrear",
    "guerrearás": "guerrear",
    "guerrearão": "guerrear",
    "guerrearíamos": "guerrear",
    "guerrearíeis": "guerrear",
    "guerreasse": "guerrear",
    "guerreassem": "guerrear",
    "guerreasses": "guerrear",
    "guerreaste": "guerrear",
    "guerreastes": "guerrear",
    "guerreava": "guerrear",
    "guerreavam": "guerrear",
    "guerreavas": "guerrear",
    "guerreei": "guerrear",
    "guerreeis": "guerrear",
    "guerreemo": "guerrear",
    "guerreemos": "guerrear",
    "guerreia": "guerrear",
    "guerreiam": "guerrear",
    "guerreias": "guerrear",
    "guerreie": "guerrear",
    "guerreiem": "guerrear",
    "guerreies": "guerrear",
    "guerreio": "guerrear",
    "guerreira": "guerreiro",
    "guerreiras": "guerreiro",
    "guerreiros": "guerreiro",
    "guerrenta": "guerrento",
    "guerrentas": "guerrento",
    "guerrentos": "guerrento",
    "guerreona": "guerreão",
    "guerreonas": "guerreão",
    "guerreou": "guerrear",
    "guerreá": "guerrear",
    "guerreámo": "guerrear",
    "guerreámos": "guerrear",
    "guerreáramo": "guerrear",
    "guerreáramos": "guerrear",
    "guerreárei": "guerrear",
    "guerreáreis": "guerrear",
    "guerreásseis": "guerrear",
    "guerreássemos": "guerrear",
    "guerreávamo": "guerrear",
    "guerreávamos": "guerrear",
    "guerreávei": "guerrear",
    "guerreáveis": "guerrear",
    "guerreões": "guerreão",
    "guerrilha": "guerrilhar",
    "guerrilhada": "guerrilhar",
    "guerrilhadas": "guerrilhar",
    "guerrilhado": "guerrilhar",
    "guerrilhados": "guerrilhar",
    "guerrilhagens": "guerrilhagem",
    "guerrilhai": "guerrilhar",
    "guerrilhais": "guerrilhar",
    "guerrilham": "guerrilhar",
    "guerrilhamo": "guerrilhar",
    "guerrilhamos": "guerrilhar",
    "guerrilhando": "guerrilhar",
    "guerrilhara": "guerrilhar",
    "guerrilharam": "guerrilhar",
    "guerrilharas": "guerrilhar",
    "guerrilharde": "guerrilhar",
    "guerrilhardes": "guerrilhar",
    "guerrilhare": "guerrilhar",
    "guerrilharei": "guerrilhar",
    "guerrilhareis": "guerrilhar",
    "guerrilharem": "guerrilhar",
    "guerrilharemos": "guerrilhar",
    "guerrilhares": "guerrilhar",
    "guerrilharia": "guerrilhar",
    "guerrilhariam": "guerrilhar",
    "guerrilharias": "guerrilhar",
    "guerrilharmo": "guerrilhar",
    "guerrilharmos": "guerrilhar",
    "guerrilhará": "guerrilhar",
    "guerrilharás": "guerrilhar",
    "guerrilharão": "guerrilhar",
    "guerrilharíamos": "guerrilhar",
    "guerrilharíeis": "guerrilhar",
    "guerrilhas": "guerrilhar",
    "guerrilhasse": "guerrilhar",
    "guerrilhassem": "guerrilhar",
    "guerrilhasses": "guerrilhar",
    "guerrilhaste": "guerrilhar",
    "guerrilhastes": "guerrilhar",
    "guerrilhava": "guerrilhar",
    "guerrilhavam": "guerrilhar",
    "guerrilhavas": "guerrilhar",
    "guerrilhe": "guerrilhar",
    "guerrilhei": "guerrilhar",
    "guerrilheira": "guerrilheiro",
    "guerrilheiras": "guerrilheiro",
    "guerrilheiros": "guerrilheiro",
    "guerrilheis": "guerrilhar",
    "guerrilhem": "guerrilhar",
    "guerrilhemo": "guerrilhar",
    "guerrilhemos": "guerrilhar",
    "guerrilhes": "guerrilhar",
    "guerrilho": "guerrilhar",
    "guerrilhou": "guerrilhar",
    "guerrilhá": "guerrilhar",
    "guerrilhámo": "guerrilhar",
    "guerrilhámos": "guerrilhar",
    "guerrilháramo": "guerrilhar",
    "guerrilháramos": "guerrilhar",
    "guerrilhárei": "guerrilhar",
    "guerrilháreis": "guerrilhar",
    "guerrilhásseis": "guerrilhar",
    "guerrilhássemos": "guerrilhar",
    "guerrilhávamo": "guerrilhar",
    "guerrilhávamos": "guerrilhar",
    "guerrilhávei": "guerrilhar",
    "guerrilháveis": "guerrilhar",
    "guerrilistas": "guerrilista",
    "guerrinha": "guerra",
    "guerrinhas": "guerra",
    "guerrita": "guerra",
    "guerritas": "guerra",
    "guessa": "guesso",
    "guessas": "guesso",
    "guessos": "guesso",
    "guetos": "gueto",
    "guetozinho": "gueto",
    "guetozinhos": "gueto",
    "guetozito": "gueto",
    "guetozitos": "gueto",
    "guia": "guiar",
    "guiacanas": "guiacana",
    "guiacas": "guiaca",
    "guiada": "guiar",
    "guiadas": "guiar",
    "guiado": "guiar",
    "guiadora": "guiador",
    "guiadoras": "guiador",
    "guiadores": "guiador",
    "guiados": "guiar",
    "guiagens": "guiagem",
    "guiai": "guiar",
    "guiais": "guiar",
    "guiam": "guiar",
    "guiamentos": "guiamento",
    "guiamo": "guiar",
    "guiamos": "guiar",
    "guiamus": "guiamu",
    "guiando": "guiar",
    "guianenses": "guianense",
    "guianesa": "guianês",
    "guianesas": "guianês",
    "guianeses": "guianês",
    "guiantes": "guiante",
    "guiara": "guiar",
    "guiaram": "guiar",
    "guiaras": "guiar",
    "guiarde": "guiar",
    "guiardes": "guiar",
    "guiare": "guiar",
    "guiarei": "guiar",
    "guiareis": "guiar",
    "guiarem": "guiar",
    "guiaremos": "guiar",
    "guiares": "guiar",
    "guiaria": "guiar",
    "guiariam": "guiar",
    "guiarias": "guiar",
    "guiarmo": "guiar",
    "guiarmos": "guiar",
    "guiará": "guiar",
    "guiarás": "guiar",
    "guiarão": "guiar",
    "guiaríamos": "guiar",
    "guiaríeis": "guiar",
    "guias": "guiar",
    "guiasse": "guiar",
    "guiassem": "guiar",
    "guiasses": "guiar",
    "guiaste": "guiar",
    "guiastes": "guiar",
    "guiautos": "guiauto",
    "guiava": "guiar",
    "guiavam": "guiar",
    "guiavas": "guiar",
    "guicha": "guicho",
    "guichas": "guicho",
    "guichos": "guicho",
    "guichés": "guiché",
    "guichês": "guichê",
    "guideres": "guider",
    "guidões": "guidão",
    "guie": "guiar",
    "guiei": "guiar",
    "guieira": "guieiro",
    "guieiras": "guieiro",
    "guieiros": "guieiro",
    "guieis": "guiar",
    "guiem": "guiar",
    "guiemo": "guiar",
    "guiemos": "guiar",
    "guies": "guiar",
    "guigas": "guiga",
    "guigós": "guigó",
    "guildas": "guilda",
    "guilhermes": "guilherme",
    "guilhochadora": "guilhochador",
    "guilhochadoras": "guilhochador",
    "guilhochadores": "guilhochador",
    "guilhos": "guilho",
    "guilhotina": "guilhotinar",
    "guilhotinada": "guilhotinar",
    "guilhotinadas": "guilhotinar",
    "guilhotinado": "guilhotinar",
    "guilhotinados": "guilhotinar",
    "guilhotinai": "guilhotinar",
    "guilhotinais": "guilhotinar",
    "guilhotinam": "guilhotinar",
    "guilhotinamentos": "guilhotinamento",
    "guilhotinamo": "guilhotinar",
    "guilhotinamos": "guilhotinar",
    "guilhotinando": "guilhotinar",
    "guilhotinara": "guilhotinar",
    "guilhotinaram": "guilhotinar",
    "guilhotinaras": "guilhotinar",
    "guilhotinarde": "guilhotinar",
    "guilhotinardes": "guilhotinar",
    "guilhotinare": "guilhotinar",
    "guilhotinarei": "guilhotinar",
    "guilhotinareis": "guilhotinar",
    "guilhotinarem": "guilhotinar",
    "guilhotinaremos": "guilhotinar",
    "guilhotinares": "guilhotinar",
    "guilhotinaria": "guilhotinar",
    "guilhotinariam": "guilhotinar",
    "guilhotinarias": "guilhotinar",
    "guilhotinarmo": "guilhotinar",
    "guilhotinarmos": "guilhotinar",
    "guilhotinará": "guilhotinar",
    "guilhotinarás": "guilhotinar",
    "guilhotinarão": "guilhotinar",
    "guilhotinaríamos": "guilhotinar",
    "guilhotinaríeis": "guilhotinar",
    "guilhotinas": "guilhotinar",
    "guilhotinasse": "guilhotinar",
    "guilhotinassem": "guilhotinar",
    "guilhotinasses": "guilhotinar",
    "guilhotinaste": "guilhotinar",
    "guilhotinastes": "guilhotinar",
    "guilhotinava": "guilhotinar",
    "guilhotinavam": "guilhotinar",
    "guilhotinavas": "guilhotinar",
    "guilhotine": "guilhotinar",
    "guilhotinei": "guilhotinar",
    "guilhotineis": "guilhotinar",
    "guilhotinem": "guilhotinar",
    "guilhotinemo": "guilhotinar",
    "guilhotinemos": "guilhotinar",
    "guilhotines": "guilhotinar",
    "guilhotino": "guilhotinar",
    "guilhotinou": "guilhotinar",
    "guilhotiná": "guilhotinar",
    "guilhotinámo": "guilhotinar",
    "guilhotinámos": "guilhotinar",
    "guilhotináramo": "guilhotinar",
    "guilhotináramos": "guilhotinar",
    "guilhotinárei": "guilhotinar",
    "guilhotináreis": "guilhotinar",
    "guilhotinásseis": "guilhotinar",
    "guilhotinássemos": "guilhotinar",
    "guilhotinávamo": "guilhotinar",
    "guilhotinávamos": "guilhotinar",
    "guilhotinávei": "guilhotinar",
    "guilhotináveis": "guilhotinar",
    "guimbardas": "guimbarda",
    "guina": "guinar",
    "guinada": "guinar",
    "guinadas": "guinar",
    "guinado": "guinar",
    "guinados": "guinar",
    "guinai": "guinar",
    "guinais": "guinar",
    "guinaldas": "guinalda",
    "guinaldeira": "guinaldeiro",
    "guinaldeiras": "guinaldeiro",
    "guinaldeiros": "guinaldeiro",
    "guinaldices": "guinaldice",
    "guinam": "guinar",
    "guinamo": "guinar",
    "guinamos": "guinar",
    "guinando": "guinar",
    "guinara": "guinar",
    "guinaram": "guinar",
    "guinaras": "guinar",
    "guinarde": "guinar",
    "guinardes": "guinar",
    "guinare": "guinar",
    "guinarei": "guinar",
    "guinareis": "guinar",
    "guinarem": "guinar",
    "guinaremos": "guinar",
    "guinares": "guinar",
    "guinaria": "guinar",
    "guinariam": "guinar",
    "guinarias": "guinar",
    "guinarmo": "guinar",
    "guinarmos": "guinar",
    "guinará": "guinar",
    "guinarás": "guinar",
    "guinarão": "guinar",
    "guinaríamos": "guinar",
    "guinaríeis": "guinar",
    "guinas": "guinar",
    "guinasse": "guinar",
    "guinassem": "guinar",
    "guinasses": "guinar",
    "guinaste": "guinar",
    "guinastes": "guinar",
    "guinava": "guinar",
    "guinavam": "guinar",
    "guinavas": "guinar",
    "guincha": "guinchar",
    "guinchada": "guinchar",
    "guinchadas": "guinchar",
    "guinchadeira": "guinchadeiro",
    "guinchadeiras": "guinchadeiro",
    "guinchadeiros": "guinchadeiro",
    "guinchado": "guinchar",
    "guinchadora": "guinchador",
    "guinchadoras": "guinchador",
    "guinchadores": "guinchador",
    "guinchados": "guinchar",
    "guinchai": "guinchar",
    "guinchais": "guinchar",
    "guincham": "guinchar",
    "guinchamo": "guinchar",
    "guinchamos": "guinchar",
    "guinchando": "guinchar",
    "guinchantea": "guinchante",
    "guinchanteas": "guinchante",
    "guinchantees": "guinchante",
    "guinchara": "guinchar",
    "guincharam": "guinchar",
    "guincharas": "guinchar",
    "guinchardes": "guinchar",
    "guincharei": "guinchar",
    "guinchareis": "guinchar",
    "guincharem": "guinchar",
    "guincharemos": "guinchar",
    "guinchares": "guinchar",
    "guincharia": "guinchar",
    "guinchariam": "guinchar",
    "guincharias": "guinchar",
    "guincharmo": "guinchar",
    "guincharmos": "guinchar",
    "guinchará": "guinchar",
    "guincharás": "guinchar",
    "guincharão": "guinchar",
    "guincharíamos": "guinchar",
    "guincharíeis": "guinchar",
    "guinchas": "guinchar",
    "guinchasse": "guinchar",
    "guinchassem": "guinchar",
    "guinchasses": "guinchar",
    "guinchaste": "guinchar",
    "guinchastes": "guinchar",
    "guinchava": "guinchar",
    "guinchavam": "guinchar",
    "guinchavas": "guinchar",
    "guinche": "guinchar",
    "guinchei": "guinchar",
    "guincheis": "guinchar",
    "guinchem": "guinchar",
    "guinchemo": "guinchar",
    "guinchemos": "guinchar",
    "guinches": "guinchar",
    "guincho": "guinchar",
    "guinchos": "guincho",
    "guinchou": "guinchar",
    "guinchámo": "guinchar",
    "guinchámos": "guinchar",
    "guincháramo": "guinchar",
    "guincháramos": "guinchar",
    "guincháreis": "guinchar",
    "guinchásseis": "guinchar",
    "guinchássemos": "guinchar",
    "guinchávamo": "guinchar",
    "guinchávamos": "guinchar",
    "guincháveis": "guinchar",
    "guinda": "guindar",
    "guindada": "guindar",
    "guindadas": "guindar",
    "guindado": "guindar",
    "guindados": "guindar",
    "guindagens": "guindagem",
    "guindai": "guindar",
    "guindais": "guindar",
    "guindaletas": "guindaleta",
    "guindaletes": "guindalete",
    "guindam": "guindar",
    "guindamainas": "guindamaina",
    "guindamentos": "guindamento",
    "guindamo": "guindar",
    "guindamos": "guindar",
    "guindando": "guindar",
    "guindara": "guindar",
    "guindaram": "guindar",
    "guindaras": "guindar",
    "guindarde": "guindar",
    "guindardes": "guindar",
    "guindare": "guindar",
    "guindarei": "guindar",
    "guindareis": "guindar",
    "guindarem": "guindar",
    "guindaremos": "guindar",
    "guindares": "guindar",
    "guindarezas": "guindareza",
    "guindaria": "guindar",
    "guindariam": "guindar",
    "guindarias": "guindar",
    "guindarmo": "guindar",
    "guindarmos": "guindar",
    "guindará": "guindar",
    "guindarás": "guindar",
    "guindarão": "guindar",
    "guindaríamos": "guindar",
    "guindaríeis": "guindar",
    "guindas": "guindar",
    "guindasse": "guindar",
    "guindassem": "guindar",
    "guindasses": "guindar",
    "guindaste": "guindar",
    "guindastes": "guindaste",
    "guindava": "guindar",
    "guindavam": "guindar",
    "guindavas": "guindar",
    "guinde": "guindar",
    "guindei": "guindar",
    "guindeis": "guindar",
    "guindem": "guindar",
    "guindemo": "guindar",
    "guindemos": "guindar",
    "guindes": "guinde",
    "guindo": "guindar",
    "guindolas": "guindola",
    "guindou": "guindar",
    "guindá": "guindar",
    "guindámo": "guindar",
    "guindámos": "guindar",
    "guindáramo": "guindar",
    "guindáramos": "guindar",
    "guindárei": "guindar",
    "guindáreis": "guindar",
    "guindásseis": "guindar",
    "guindássemos": "guindar",
    "guindávamo": "guindar",
    "guindávamos": "guindar",
    "guindávei": "guindar",
    "guindáveis": "guindar",
    "guine": "guinar",
    "guineenses": "guineense",
    "guinei": "guinar",
    "guineis": "guinar",
    "guinem": "guinar",
    "guinemo": "guinar",
    "guinemos": "guinar",
    "guines": "guinar",
    "guingões": "guingão",
    "guinhóis": "guinhol",
    "guino": "guinar",
    "guinolas": "guinola",
    "guinou": "guinar",
    "guiná": "guinar",
    "guinámo": "guinar",
    "guinámos": "guinar",
    "guináramo": "guinar",
    "guináramos": "guinar",
    "guinárei": "guinar",
    "guináreis": "guinar",
    "guinásseis": "guinar",
    "guinássemos": "guinar",
    "guinávamo": "guinar",
    "guinávamos": "guinar",
    "guinávei": "guinar",
    "guináveis": "guinar",
    "guinéia": "guinéu",
    "guinéias": "guinéu",
    "guinés": "guiné",
    "guinéus": "guinéu",
    "guio": "guiar",
    "guionistas": "guionista",
    "guiou": "guiar",
    "guipuras": "guipura",
    "guipuscoana": "guipuscoano",
    "guipuscoanas": "guipuscoano",
    "guipuscoanos": "guipuscoano",
    "guiqantes": "guiqante",
    "guirapongas": "guiraponga",
    "guirlandas": "guirlanda",
    "guirnaldas": "guirnalda",
    "guisa": "guisar",
    "guisada": "guisar",
    "guisadas": "guisar",
    "guisadeiras": "guisadeira",
    "guisado": "guisar",
    "guisados": "guisar",
    "guisai": "guisar",
    "guisais": "guisar",
    "guisam": "guisar",
    "guisamentos": "guisamento",
    "guisamo": "guisar",
    "guisamos": "guisar",
    "guisando": "guisar",
    "guisantes": "guisante",
    "guisara": "guisar",
    "guisaram": "guisar",
    "guisaras": "guisar",
    "guisarde": "guisar",
    "guisardes": "guisar",
    "guisare": "guisar",
    "guisarei": "guisar",
    "guisareis": "guisar",
    "guisarem": "guisar",
    "guisaremos": "guisar",
    "guisares": "guisar",
    "guisaria": "guisar",
    "guisariam": "guisar",
    "guisarias": "guisar",
    "guisarmo": "guisar",
    "guisarmos": "guisar",
    "guisará": "guisar",
    "guisarás": "guisar",
    "guisarão": "guisar",
    "guisaríamos": "guisar",
    "guisaríeis": "guisar",
    "guisas": "guisar",
    "guisasse": "guisar",
    "guisassem": "guisar",
    "guisasses": "guisar",
    "guisaste": "guisar",
    "guisastes": "guisar",
    "guisava": "guisar",
    "guisavam": "guisar",
    "guisavas": "guisar",
    "guise": "guisar",
    "guisei": "guisar",
    "guiseis": "guisar",
    "guisem": "guisar",
    "guisemo": "guisar",
    "guisemos": "guisar",
    "guises": "guisar",
    "guiso": "guisar",
    "guisou": "guisar",
    "guisá": "guisar",
    "guisámo": "guisar",
    "guisámos": "guisar",
    "guisáramo": "guisar",
    "guisáramos": "guisar",
    "guisárei": "guisar",
    "guisáreis": "guisar",
    "guisásseis": "guisar",
    "guisássemos": "guisar",
    "guisávamo": "guisar",
    "guisávamos": "guisar",
    "guisávei": "guisar",
    "guisáveis": "guisar",
    "guitarradas": "guitarrada",
    "guitarras": "guitarra",
    "guitarreada": "guitarrear",
    "guitarreadas": "guitarrear",
    "guitarreado": "guitarrear",
    "guitarreados": "guitarrear",
    "guitarreai": "guitarrear",
    "guitarreais": "guitarrear",
    "guitarreamo": "guitarrear",
    "guitarreamos": "guitarrear",
    "guitarreando": "guitarrear",
    "guitarreara": "guitarrear",
    "guitarrearam": "guitarrear",
    "guitarrearas": "guitarrear",
    "guitarrearde": "guitarrear",
    "guitarreardes": "guitarrear",
    "guitarreare": "guitarrear",
    "guitarrearei": "guitarrear",
    "guitarreareis": "guitarrear",
    "guitarrearem": "guitarrear",
    "guitarrearemos": "guitarrear",
    "guitarreares": "guitarrear",
    "guitarrearia": "guitarrear",
    "guitarreariam": "guitarrear",
    "guitarrearias": "guitarrear",
    "guitarrearmo": "guitarrear",
    "guitarrearmos": "guitarrear",
    "guitarreará": "guitarrear",
    "guitarrearás": "guitarrear",
    "guitarrearão": "guitarrear",
    "guitarrearíamos": "guitarrear",
    "guitarrearíeis": "guitarrear",
    "guitarreasse": "guitarrear",
    "guitarreassem": "guitarrear",
    "guitarreasses": "guitarrear",
    "guitarreaste": "guitarrear",
    "guitarreastes": "guitarrear",
    "guitarreava": "guitarrear",
    "guitarreavam": "guitarrear",
    "guitarreavas": "guitarrear",
    "guitarreei": "guitarrear",
    "guitarreeis": "guitarrear",
    "guitarreemo": "guitarrear",
    "guitarreemos": "guitarrear",
    "guitarreia": "guitarrear",
    "guitarreiam": "guitarrear",
    "guitarreias": "guitarrear",
    "guitarreie": "guitarrear",
    "guitarreiem": "guitarrear",
    "guitarreies": "guitarrear",
    "guitarreio": "guitarrear",
    "guitarreira": "guitarreiro",
    "guitarreiras": "guitarreiro",
    "guitarreiros": "guitarreiro",
    "guitarreou": "guitarrear",
    "guitarreá": "guitarrear",
    "guitarreámo": "guitarrear",
    "guitarreámos": "guitarrear",
    "guitarreáramo": "guitarrear",
    "guitarreáramos": "guitarrear",
    "guitarreárei": "guitarrear",
    "guitarreáreis": "guitarrear",
    "guitarreásseis": "guitarrear",
    "guitarreássemos": "guitarrear",
    "guitarreávamo": "guitarrear",
    "guitarreávamos": "guitarrear",
    "guitarreávei": "guitarrear",
    "guitarreáveis": "guitarrear",
    "guitarrilhas": "guitarrilha",
    "guitarristas": "guitarrista",
    "guitarréus": "guitarréu",
    "guitas": "guita",
    "guitinha": "guita",
    "guitinhas": "guita",
    "guitita": "guita",
    "guititas": "guita",
    "guizalha": "guizalhar",
    "guizalhada": "guizalhar",
    "guizalhadas": "guizalhar",
    "guizalhado": "guizalhar",
    "guizalhados": "guizalhar",
    "guizalhai": "guizalhar",
    "guizalhais": "guizalhar",
    "guizalham": "guizalhar",
    "guizalhamo": "guizalhar",
    "guizalhamos": "guizalhar",
    "guizalhando": "guizalhar",
    "guizalhantes": "guizalhante",
    "guizalhara": "guizalhar",
    "guizalharam": "guizalhar",
    "guizalharas": "guizalhar",
    "guizalhardes": "guizalhar",
    "guizalharei": "guizalhar",
    "guizalhareis": "guizalhar",
    "guizalharem": "guizalhar",
    "guizalharemos": "guizalhar",
    "guizalhares": "guizalhar",
    "guizalharia": "guizalhar",
    "guizalhariam": "guizalhar",
    "guizalharias": "guizalhar",
    "guizalharmo": "guizalhar",
    "guizalharmos": "guizalhar",
    "guizalhará": "guizalhar",
    "guizalharás": "guizalhar",
    "guizalharão": "guizalhar",
    "guizalharíamos": "guizalhar",
    "guizalharíeis": "guizalhar",
    "guizalhas": "guizalhar",
    "guizalhasse": "guizalhar",
    "guizalhassem": "guizalhar",
    "guizalhasses": "guizalhar",
    "guizalhaste": "guizalhar",
    "guizalhastes": "guizalhar",
    "guizalhava": "guizalhar",
    "guizalhavam": "guizalhar",
    "guizalhavas": "guizalhar",
    "guizalhe": "guizalhar",
    "guizalhei": "guizalhar",
    "guizalheis": "guizalhar",
    "guizalhem": "guizalhar",
    "guizalhemo": "guizalhar",
    "guizalhemos": "guizalhar",
    "guizalhes": "guizalhar",
    "guizalho": "guizalhar",
    "guizalhou": "guizalhar",
    "guizalhámo": "guizalhar",
    "guizalhámos": "guizalhar",
    "guizalháramo": "guizalhar",
    "guizalháramos": "guizalhar",
    "guizalháreis": "guizalhar",
    "guizalhásseis": "guizalhar",
    "guizalhássemos": "guizalhar",
    "guizalhávamo": "guizalhar",
    "guizalhávamos": "guizalhar",
    "guizalháveis": "guizalhar",
    "guizeiras": "guizeira",
    "guizos": "guizo",
    "guiá": "guiar",
    "guiámo": "guiar",
    "guiámos": "guiar",
    "guiáramo": "guiar",
    "guiáramos": "guiar",
    "guiárei": "guiar",
    "guiáreis": "guiar",
    "guiásseis": "guiar",
    "guiássemos": "guiar",
    "guiávamo": "guiar",
    "guiávamos": "guiar",
    "guiávei": "guiar",
    "guiáveis": "guiável",
    "guiões": "guião",
    "gulaima": "gulaimar",
    "gulaimada": "gulaimar",
    "gulaimadas": "gulaimar",
    "gulaimado": "gulaimar",
    "gulaimados": "gulaimar",
    "gulaimai": "gulaimar",
    "gulaimais": "gulaimar",
    "gulaimam": "gulaimar",
    "gulaimamo": "gulaimar",
    "gulaimamos": "gulaimar",
    "gulaimando": "gulaimar",
    "gulaimara": "gulaimar",
    "gulaimaram": "gulaimar",
    "gulaimaras": "gulaimar",
    "gulaimardes": "gulaimar",
    "gulaimarei": "gulaimar",
    "gulaimareis": "gulaimar",
    "gulaimarem": "gulaimar",
    "gulaimaremos": "gulaimar",
    "gulaimares": "gulaimar",
    "gulaimaria": "gulaimar",
    "gulaimariam": "gulaimar",
    "gulaimarias": "gulaimar",
    "gulaimarmo": "gulaimar",
    "gulaimarmos": "gulaimar",
    "gulaimará": "gulaimar",
    "gulaimarás": "gulaimar",
    "gulaimarão": "gulaimar",
    "gulaimaríamos": "gulaimar",
    "gulaimaríeis": "gulaimar",
    "gulaimas": "gulaimar",
    "gulaimasse": "gulaimar",
    "gulaimassem": "gulaimar",
    "gulaimasses": "gulaimar",
    "gulaimaste": "gulaimar",
    "gulaimastes": "gulaimar",
    "gulaimava": "gulaimar",
    "gulaimavam": "gulaimar",
    "gulaimavas": "gulaimar",
    "gulaime": "gulaimar",
    "gulaimei": "gulaimar",
    "gulaimeis": "gulaimar",
    "gulaimem": "gulaimar",
    "gulaimemo": "gulaimar",
    "gulaimemos": "gulaimar",
    "gulaimes": "gulaimar",
    "gulaimo": "gulaimar",
    "gulaimou": "gulaimar",
    "gulaimámo": "gulaimar",
    "gulaimámos": "gulaimar",
    "gulaimáramo": "gulaimar",
    "gulaimáramos": "gulaimar",
    "gulaimáreis": "gulaimar",
    "gulaimásseis": "gulaimar",
    "gulaimássemos": "gulaimar",
    "gulaimávamo": "gulaimar",
    "gulaimávamos": "gulaimar",
    "gulaimáveis": "gulaimar",
    "gulapa": "gulapar",
    "gulapada": "gulapar",
    "gulapadas": "gulapar",
    "gulapado": "gulapar",
    "gulapados": "gulapar",
    "gulapai": "gulapar",
    "gulapais": "gulapar",
    "gulapam": "gulapar",
    "gulapamo": "gulapar",
    "gulapamos": "gulapar",
    "gulapando": "gulapar",
    "gulapara": "gulapar",
    "gulaparam": "gulapar",
    "gulaparas": "gulapar",
    "gulapardes": "gulapar",
    "gulaparei": "gulapar",
    "gulapareis": "gulapar",
    "gulaparem": "gulapar",
    "gulaparemos": "gulapar",
    "gulapares": "gulapar",
    "gulaparia": "gulapar",
    "gulapariam": "gulapar",
    "gulaparias": "gulapar",
    "gulaparmo": "gulapar",
    "gulaparmos": "gulapar",
    "gulapará": "gulapar",
    "gulaparás": "gulapar",
    "gulaparão": "gulapar",
    "gulaparíamos": "gulapar",
    "gulaparíeis": "gulapar",
    "gulapas": "gulapar",
    "gulapasse": "gulapar",
    "gulapassem": "gulapar",
    "gulapasses": "gulapar",
    "gulapaste": "gulapar",
    "gulapastes": "gulapar",
    "gulapava": "gulapar",
    "gulapavam": "gulapar",
    "gulapavas": "gulapar",
    "gulape": "gulapar",
    "gulapei": "gulapar",
    "gulapeis": "gulapar",
    "gulapem": "gulapar",
    "gulapemo": "gulapar",
    "gulapemos": "gulapar",
    "gulapes": "gulapar",
    "gulapo": "gulapar",
    "gulapona": "gulapão",
    "gulaponas": "gulapão",
    "gulapou": "gulapar",
    "gulapámo": "gulapar",
    "gulapámos": "gulapar",
    "gulapáramo": "gulapar",
    "gulapáramos": "gulapar",
    "gulapáreis": "gulapar",
    "gulapásseis": "gulapar",
    "gulapássemos": "gulapar",
    "gulapávamo": "gulapar",
    "gulapávamos": "gulapar",
    "gulapáveis": "gulapar",
    "gulapões": "gulapão",
    "gulas": "gula",
    "gulaza": "gulazar",
    "gulazada": "gulazar",
    "gulazadas": "gulazar",
    "gulazado": "gulazar",
    "gulazados": "gulazar",
    "gulazai": "gulazar",
    "gulazais": "gulazar",
    "gulazam": "gulazar",
    "gulazamo": "gulazar",
    "gulazamos": "gulazar",
    "gulazando": "gulazar",
    "gulazara": "gulazar",
    "gulazaram": "gulazar",
    "gulazaras": "gulazar",
    "gulazardes": "gulazar",
    "gulazarei": "gulazar",
    "gulazareis": "gulazar",
    "gulazarem": "gulazar",
    "gulazaremos": "gulazar",
    "gulazares": "gulazar",
    "gulazaria": "gulazar",
    "gulazariam": "gulazar",
    "gulazarias": "gulazar",
    "gulazarmo": "gulazar",
    "gulazarmos": "gulazar",
    "gulazará": "gulazar",
    "gulazarás": "gulazar",
    "gulazarão": "gulazar",
    "gulazaríamos": "gulazar",
    "gulazaríeis": "gulazar",
    "gulazas": "gulazar",
    "gulazasse": "gulazar",
    "gulazassem": "gulazar",
    "gulazasses": "gulazar",
    "gulazaste": "gulazar",
    "gulazastes": "gulazar",
    "gulazava": "gulazar",
    "gulazavam": "gulazar",
    "gulazavas": "gulazar",
    "gulaze": "gulazar",
    "gulazei": "gulazar",
    "gulazeis": "gulazar",
    "gulazem": "gulazar",
    "gulazemo": "gulazar",
    "gulazemos": "gulazar",
    "gulazes": "gulazar",
    "gulazo": "gulazar",
    "gulazou": "gulazar",
    "gulazámo": "gulazar",
    "gulazámos": "gulazar",
    "gulazáramo": "gulazar",
    "gulazáramos": "gulazar",
    "gulazáreis": "gulazar",
    "gulazásseis": "gulazar",
    "gulazássemos": "gulazar",
    "gulazávamo": "gulazar",
    "gulazávamos": "gulazar",
    "gulazáveis": "gulazar",
    "guleima": "guleimar",
    "guleimada": "guleimar",
    "guleimadas": "guleimar",
    "guleimado": "guleimar",
    "guleimados": "guleimar",
    "guleimai": "guleimar",
    "guleimais": "guleimar",
    "guleimam": "guleimar",
    "guleimamo": "guleimar",
    "guleimamos": "guleimar",
    "guleimando": "guleimar",
    "guleimara": "guleimar",
    "guleimaram": "guleimar",
    "guleimaras": "guleimar",
    "guleimardes": "guleimar",
    "guleimarei": "guleimar",
    "guleimareis": "guleimar",
    "guleimarem": "guleimar",
    "guleimaremos": "guleimar",
    "guleimares": "guleimar",
    "guleimaria": "guleimar",
    "guleimariam": "guleimar",
    "guleimarias": "guleimar",
    "guleimarmo": "guleimar",
    "guleimarmos": "guleimar",
    "guleimará": "guleimar",
    "guleimarás": "guleimar",
    "guleimarão": "guleimar",
    "guleimaríamos": "guleimar",
    "guleimaríeis": "guleimar",
    "guleimas": "guleimar",
    "guleimasse": "guleimar",
    "guleimassem": "guleimar",
    "guleimasses": "guleimar",
    "guleimaste": "guleimar",
    "guleimastes": "guleimar",
    "guleimava": "guleimar",
    "guleimavam": "guleimar",
    "guleimavas": "guleimar",
    "guleime": "guleimar",
    "guleimei": "guleimar",
    "guleimeis": "guleimar",
    "guleimem": "guleimar",
    "guleimemo": "guleimar",
    "guleimemos": "guleimar",
    "guleimes": "guleimar",
    "guleimo": "guleimar",
    "guleimou": "guleimar",
    "guleimámo": "guleimar",
    "guleimámos": "guleimar",
    "guleimáramo": "guleimar",
    "guleimáramos": "guleimar",
    "guleimáreis": "guleimar",
    "guleimásseis": "guleimar",
    "guleimássemos": "guleimar",
    "guleimávamo": "guleimar",
    "guleimávamos": "guleimar",
    "guleimáveis": "guleimar",
    "guleiras": "guleira",
    "gulheriteira": "gulheriteiro",
    "gulheriteiras": "gulheriteiro",
    "gulheriteiros": "gulheriteiro",
    "gulherites": "gulherite",
    "gulheritices": "gulheritice",
    "gulodices": "gulodice",
    "gulosa": "guloso",
    "gulosada": "gulosar",
    "gulosadas": "gulosar",
    "gulosado": "gulosar",
    "gulosados": "gulosar",
    "gulosai": "gulosar",
    "gulosais": "gulosar",
    "gulosam": "gulosar",
    "gulosamo": "gulosar",
    "gulosamos": "gulosar",
    "gulosando": "gulosar",
    "gulosara": "gulosar",
    "gulosaram": "gulosar",
    "gulosaras": "gulosar",
    "gulosardes": "gulosar",
    "gulosarei": "gulosar",
    "gulosareis": "gulosar",
    "gulosarem": "gulosar",
    "gulosaremos": "gulosar",
    "gulosares": "gulosar",
    "gulosaria": "gulosar",
    "gulosariam": "gulosar",
    "gulosarias": "gulosar",
    "gulosarmo": "gulosar",
    "gulosarmos": "gulosar",
    "gulosará": "gulosar",
    "gulosarás": "gulosar",
    "gulosarão": "gulosar",
    "gulosaríamos": "gulosar",
    "gulosaríeis": "gulosar",
    "gulosas": "guloso",
    "gulosasse": "gulosar",
    "gulosassem": "gulosar",
    "gulosasses": "gulosar",
    "gulosaste": "gulosar",
    "gulosastes": "gulosar",
    "gulosava": "gulosar",
    "gulosavam": "gulosar",
    "gulosavas": "gulosar",
    "gulose": "gulosar",
    "guloseca": "guloseco",
    "gulosecas": "guloseco",
    "gulosecos": "guloseco",
    "gulosei": "gulosar",
    "guloseimas": "guloseima",
    "guloseis": "gulosar",
    "gulosem": "gulosar",
    "gulosemo": "gulosar",
    "gulosemos": "gulosar",
    "guloses": "gulosar",
    "gulosices": "gulosice",
    "gulosina": "gulosinar",
    "gulosinada": "gulosinar",
    "gulosinadas": "gulosinar",
    "gulosinado": "gulosinar",
    "gulosinados": "gulosinar",
    "gulosinai": "gulosinar",
    "gulosinais": "gulosinar",
    "gulosinam": "gulosinar",
    "gulosinamo": "gulosinar",
    "gulosinamos": "gulosinar",
    "gulosinando": "gulosinar",
    "gulosinara": "gulosinar",
    "gulosinaram": "gulosinar",
    "gulosinaras": "gulosinar",
    "gulosinardes": "gulosinar",
    "gulosinarei": "gulosinar",
    "gulosinareis": "gulosinar",
    "gulosinarem": "gulosinar",
    "gulosinaremos": "gulosinar",
    "gulosinares": "gulosinar",
    "gulosinaria": "gulosinar",
    "gulosinariam": "gulosinar",
    "gulosinarias": "gulosinar",
    "gulosinarmo": "gulosinar",
    "gulosinarmos": "gulosinar",
    "gulosinará": "gulosinar",
    "gulosinarás": "gulosinar",
    "gulosinarão": "gulosinar",
    "gulosinaríamos": "gulosinar",
    "gulosinaríeis": "gulosinar",
    "gulosinas": "gulosinar",
    "gulosinasse": "gulosinar",
    "gulosinassem": "gulosinar",
    "gulosinasses": "gulosinar",
    "gulosinaste": "gulosinar",
    "gulosinastes": "gulosinar",
    "gulosinava": "gulosinar",
    "gulosinavam": "gulosinar",
    "gulosinavas": "gulosinar",
    "gulosine": "gulosinar",
    "gulosinei": "gulosinar",
    "gulosineis": "gulosinar",
    "gulosinem": "gulosinar",
    "gulosinemo": "gulosinar",
    "gulosinemos": "gulosinar",
    "gulosines": "gulosinar",
    "gulosinha": "guloso",
    "gulosinhas": "guloso",
    "gulosinho": "guloso",
    "gulosinhos": "guloso",
    "gulosino": "gulosinar",
    "gulosinou": "gulosinar",
    "gulosinámo": "gulosinar",
    "gulosinámos": "gulosinar",
    "gulosináramo": "gulosinar",
    "gulosináramos": "gulosinar",
    "gulosináreis": "gulosinar",
    "gulosinásseis": "gulosinar",
    "gulosinássemos": "gulosinar",
    "gulosinávamo": "gulosinar",
    "gulosinávamos": "gulosinar",
    "gulosináveis": "gulosinar",
    "gulosita": "guloso",
    "gulositas": "guloso",
    "gulosito": "guloso",
    "gulositos": "guloso",
    "guloso": "gulosar",
    "gulosona": "gulosão",
    "gulosonas": "gulosão",
    "gulosos": "guloso",
    "gulosota": "gulosote",
    "gulosotas": "gulosote",
    "gulosotes": "gulosote",
    "gulosou": "gulosar",
    "gulosámo": "gulosar",
    "gulosámos": "gulosar",
    "gulosáramo": "gulosar",
    "gulosáramos": "gulosar",
    "gulosáreis": "gulosar",
    "gulosásseis": "gulosar",
    "gulosássemos": "gulosar",
    "gulosávamo": "gulosar",
    "gulosávamos": "gulosar",
    "gulosáveis": "gulosar",
    "gulosíssima": "guloso",
    "gulosíssimas": "guloso",
    "gulosíssimo": "guloso",
    "gulosíssimos": "guloso",
    "gulosões": "gulosão",
    "gumes": "gume",
    "gumites": "gumite",
    "gumosa": "gumoso",
    "gumosas": "gumoso",
    "gumosos": "gumoso",
    "gumífera": "gumífero",
    "gumíferas": "gumífero",
    "gumíferos": "gumífero",
    "gunas": "guna",
    "gunchos": "guncho",
    "gundas": "gunda",
    "gundeiras": "gundeira",
    "gundeiros": "gundeiro",
    "gundras": "gundra",
    "gundus": "gundu",
    "gunes": "gune",
    "gungas": "gunga",
    "gupiaras": "gupiara",
    "guras": "gura",
    "gurdes": "gurde",
    "gurejubas": "gurejuba",
    "gurgaus": "gurgau",
    "gurguris": "gurguri",
    "guria": "guri",
    "gurias": "guri",
    "guribas": "guriba",
    "gurijubas": "gurijuba",
    "guris": "guri",
    "guritas": "gurita",
    "guriteira": "guriteiro",
    "guriteiras": "guriteiro",
    "guriteiros": "guriteiro",
    "gurizadas": "gurizada",
    "gurmas": "gurma",
    "gurrinos": "gurrino",
    "gurupiás": "gurupiá",
    "gurus": "guru",
    "gusanos": "gusano",
    "gusas": "gusa",
    "guslas": "gusla",
    "gustativa": "gustativo",
    "gustativas": "gustativo",
    "gustativos": "gustativo",
    "gustatória": "gustatório",
    "gustatórias": "gustatório",
    "gustatórios": "gustatório",
    "gustações": "gustação",
    "gutas": "guta",
    "gutações": "gutação",
    "guteiras": "guteira",
    "guterristas": "guterrista",
    "gutinas": "gutina",
    "gutos": "guto",
    "guturais": "gutural",
    "guturaliza": "guturalizar",
    "guturalizada": "guturalizar",
    "guturalizadas": "guturalizar",
    "guturalizado": "guturalizar",
    "guturalizados": "guturalizar",
    "guturalizai": "guturalizar",
    "guturalizais": "guturalizar",
    "guturalizam": "guturalizar",
    "guturalizamo": "guturalizar",
    "guturalizamos": "guturalizar",
    "guturalizando": "guturalizar",
    "guturalizara": "guturalizar",
    "guturalizaram": "guturalizar",
    "guturalizaras": "guturalizar",
    "guturalizarde": "guturalizar",
    "guturalizardes": "guturalizar",
    "guturalizare": "guturalizar",
    "guturalizarei": "guturalizar",
    "guturalizareis": "guturalizar",
    "guturalizarem": "guturalizar",
    "guturalizaremos": "guturalizar",
    "guturalizares": "guturalizar",
    "guturalizaria": "guturalizar",
    "guturalizariam": "guturalizar",
    "guturalizarias": "guturalizar",
    "guturalizarmo": "guturalizar",
    "guturalizarmos": "guturalizar",
    "guturalizará": "guturalizar",
    "guturalizarás": "guturalizar",
    "guturalizarão": "guturalizar",
    "guturalizaríamos": "guturalizar",
    "guturalizaríeis": "guturalizar",
    "guturalizas": "guturalizar",
    "guturalizasse": "guturalizar",
    "guturalizassem": "guturalizar",
    "guturalizasses": "guturalizar",
    "guturalizaste": "guturalizar",
    "guturalizastes": "guturalizar",
    "guturalizava": "guturalizar",
    "guturalizavam": "guturalizar",
    "guturalizavas": "guturalizar",
    "guturalizações": "guturalização",
    "guturalize": "guturalizar",
    "guturalizei": "guturalizar",
    "guturalizeis": "guturalizar",
    "guturalizem": "guturalizar",
    "guturalizemo": "guturalizar",
    "guturalizemos": "guturalizar",
    "guturalizes": "guturalizar",
    "guturalizo": "guturalizar",
    "guturalizou": "guturalizar",
    "guturalizá": "guturalizar",
    "guturalizámo": "guturalizar",
    "guturalizámos": "guturalizar",
    "guturalizáramo": "guturalizar",
    "guturalizáramos": "guturalizar",
    "guturalizárei": "guturalizar",
    "guturalizáreis": "guturalizar",
    "guturalizásseis": "guturalizar",
    "guturalizássemos": "guturalizar",
    "guturalizávamo": "guturalizar",
    "guturalizávamos": "guturalizar",
    "guturalizávei": "guturalizar",
    "guturalizáveis": "guturalizável",
    "guturosa": "guturoso",
    "guturosas": "guturoso",
    "guturosos": "guturoso",
    "guturotetanias": "guturotetania",
    "guturotetânica": "guturotetânico",
    "guturotetânicas": "guturotetânico",
    "guturotetânicos": "guturotetânico",
    "gutés": "guté",
    "gutífera": "gutífero",
    "gutíferas": "gutífero",
    "gutíferos": "gutífero",
    "guzarates": "guzarate",
    "guzerates": "guzerate",
    "guzos": "guzo",
    "guês": "guê",
    "guímeis": "guímel",
    "gábias": "gábia",
    "gádidas": "gádida",
    "gáiacos": "gáiaco",
    "gálatas": "gálata",
    "gálbanos": "gálbano",
    "gálbulas": "gálbula",
    "gálbulos": "gálbulo",
    "gáleas": "gálea",
    "gálica": "gálico",
    "gálicas": "gálico",
    "gálicos": "gálico",
    "gálios": "gálio",
    "gárgulas": "gárgula",
    "gárrula": "gárrulo",
    "gárrulas": "gárrulo",
    "gárrulos": "gárrulo",
    "gáspeas": "gáspea",
    "gásteres": "gáster",
    "gástrica": "gástrico",
    "gástricas": "gástrico",
    "gástricos": "gástrico",
    "gástrulas": "gástrula",
    "gáudios": "gáudio",
    "gáveas": "gávea",
    "gázea": "gázeo",
    "gázeas": "gázeo",
    "gázeos": "gázeo",
    "gázios": "gázio",
    "gázuas": "gázua",
    "gâmbias": "gâmbia",
    "gâmetas": "gâmeta",
    "gândaras": "gândara",
    "gânglios": "gânglio",
    "gângsters": "gângster",
    "gânguesteres": "gânguester",
    "géiseres": "géiser",
    "gélida": "gélido",
    "gélidas": "gélido",
    "gélidos": "gélido",
    "gémea": "gémeo",
    "gémeas": "gémeo",
    "gémeos": "gémeo",
    "gémina": "gémino",
    "géminas": "gémino",
    "géminos": "gémino",
    "gémulas": "gémula",
    "géneros": "género",
    "géneses": "génese",
    "génios": "génio",
    "génita": "génito",
    "génitas": "génito",
    "génitos": "génito",
    "gérmenes": "gérmen",
    "gética": "gético",
    "géticas": "gético",
    "géticos": "gético",
    "gês": "gê",
    "gílias": "gília",
    "gímnica": "gímnico",
    "gímnicas": "gímnico",
    "gímnicos": "gímnico",
    "gínglimos": "gínglimo",
    "gípsia": "gípsio",
    "gípsias": "gípsio",
    "gípsios": "gípsio",
    "gíria": "gírio",
    "gírias": "gírio",
    "gírios": "gírio",
    "góis": "gói",
    "gólfões": "gólfão",
    "gólgotas": "gólgota",
    "gómitos": "gómito",
    "gónadas": "gónada",
    "gónios": "gónio",
    "górdia": "górdio",
    "górdias": "górdio",
    "górdios": "górdio",
    "górgonas": "górgona",
    "górgones": "górgone",
    "gótica": "gótico",
    "góticas": "gótico",
    "góticos": "gótico",
    "gôndolas": "gôndola",
    "gôngilos": "gôngilo",
    "gúmenas": "gúmena",
    "gútulos": "gútulo",
    "habaneras": "habanera",
    "habenas": "habena",
    "habilidades": "habilidade",
    "habilidosa": "habilidoso",
    "habilidosas": "habilidoso",
    "habilidosos": "habilidoso",
    "habilita": "habilitar",
    "habilitada": "habilitar",
    "habilitadas": "habilitar",
    "habilitado": "habilitar",
    "habilitadora": "habilitador",
    "habilitadoras": "habilitador",
    "habilitadores": "habilitador",
    "habilitados": "habilitar",
    "habilitai": "habilitar",
    "habilitais": "habilitar",
    "habilitam": "habilitar",
    "habilitamo": "habilitar",
    "habilitamos": "habilitar",
    "habilitanda": "habilitando",
    "habilitandas": "habilitando",
    "habilitando": "habilitar",
    "habilitandos": "habilitando",
    "habilitantes": "habilitante",
    "habilitanços": "habilitanço",
    "habilitara": "habilitar",
    "habilitaram": "habilitar",
    "habilitaras": "habilitar",
    "habilitarde": "habilitar",
    "habilitardes": "habilitar",
    "habilitare": "habilitar",
    "habilitarei": "habilitar",
    "habilitareis": "habilitar",
    "habilitarem": "habilitar",
    "habilitaremos": "habilitar",
    "habilitares": "habilitar",
    "habilitaria": "habilitar",
    "habilitariam": "habilitar",
    "habilitarias": "habilitar",
    "habilitarmo": "habilitar",
    "habilitarmos": "habilitar",
    "habilitará": "habilitar",
    "habilitarás": "habilitar",
    "habilitarão": "habilitar",
    "habilitaríamos": "habilitar",
    "habilitaríeis": "habilitar",
    "habilitas": "habilitar",
    "habilitasse": "habilitar",
    "habilitassem": "habilitar",
    "habilitasses": "habilitar",
    "habilitaste": "habilitar",
    "habilitastes": "habilitar",
    "habilitava": "habilitar",
    "habilitavam": "habilitar",
    "habilitavas": "habilitar",
    "habilitações": "habilitação",
    "habilite": "habilitar",
    "habilitei": "habilitar",
    "habiliteis": "habilitar",
    "habilitem": "habilitar",
    "habilitemo": "habilitar",
    "habilitemos": "habilitar",
    "habilites": "habilitar",
    "habilito": "habilitar",
    "habilitou": "habilitar",
    "habilitá": "habilitar",
    "habilitámo": "habilitar",
    "habilitámos": "habilitar",
    "habilitáramo": "habilitar",
    "habilitáramos": "habilitar",
    "habilitárei": "habilitar",
    "habilitáreis": "habilitar",
    "habilitásseis": "habilitar",
    "habilitássemos": "habilitar",
    "habilitávamo": "habilitar",
    "habilitávamos": "habilitar",
    "habilitávei": "habilitar",
    "habilitáveis": "habilitável",
    "habita": "habitar",
    "habitabilidades": "habitabilidade",
    "habitacionais": "habitacional",
    "habitada": "habitar",
    "habitadas": "habitar",
    "habitado": "habitar",
    "habitadora": "habitador",
    "habitadoras": "habitador",
    "habitadores": "habitador",
    "habitados": "habitar",
    "habitai": "habitar",
    "habitais": "habitar",
    "habitam": "habitar",
    "habitamo": "habitar",
    "habitamos": "habitar",
    "habitando": "habitar",
    "habitantes": "habitante",
    "habitara": "habitar",
    "habitaram": "habitar",
    "habitaras": "habitar",
    "habitarde": "habitar",
    "habitardes": "habitar",
    "habitare": "habitar",
    "habitarei": "habitar",
    "habitareis": "habitar",
    "habitarem": "habitar",
    "habitaremos": "habitar",
    "habitares": "habitar",
    "habitaria": "habitar",
    "habitariam": "habitar",
    "habitarias": "habitar",
    "habitarmo": "habitar",
    "habitarmos": "habitar",
    "habitará": "habitar",
    "habitarás": "habitar",
    "habitarão": "habitar",
    "habitaríamos": "habitar",
    "habitaríeis": "habitar",
    "habitas": "habitar",
    "habitasse": "habitar",
    "habitassem": "habitar",
    "habitasses": "habitar",
    "habitaste": "habitar",
    "habitastes": "habitar",
    "habitats": "habitat",
    "habitava": "habitar",
    "habitavam": "habitar",
    "habitavas": "habitar",
    "habitações": "habitação",
    "habite": "habitar",
    "habitei": "habitar",
    "habiteis": "habitar",
    "habitem": "habitar",
    "habitemo": "habitar",
    "habitemos": "habitar",
    "habites": "habitar",
    "habito": "habitar",
    "habitou": "habitar",
    "habitua": "habituar",
    "habituada": "habituar",
    "habituadas": "habituar",
    "habituado": "habituar",
    "habituados": "habituar",
    "habituai": "habituar",
    "habituais": "habituar",
    "habitualidades": "habitualidade",
    "habitualismos": "habitualismo",
    "habituam": "habituar",
    "habituamo": "habituar",
    "habituamos": "habituar",
    "habituando": "habituar",
    "habituara": "habituar",
    "habituaram": "habituar",
    "habituaras": "habituar",
    "habituarde": "habituar",
    "habituardes": "habituar",
    "habituare": "habituar",
    "habituarei": "habituar",
    "habituareis": "habituar",
    "habituarem": "habituar",
    "habituaremos": "habituar",
    "habituares": "habituar",
    "habituaria": "habituar",
    "habituariam": "habituar",
    "habituarias": "habituar",
    "habituarmo": "habituar",
    "habituarmos": "habituar",
    "habituará": "habituar",
    "habituarás": "habituar",
    "habituarão": "habituar",
    "habituaríamos": "habituar",
    "habituaríeis": "habituar",
    "habituas": "habituar",
    "habituasse": "habituar",
    "habituassem": "habituar",
    "habituasses": "habituar",
    "habituaste": "habituar",
    "habituastes": "habituar",
    "habituava": "habituar",
    "habituavam": "habituar",
    "habituavas": "habituar",
    "habituações": "habituação",
    "habitudes": "habitude",
    "habitudinária": "habitudinário",
    "habitudinárias": "habitudinário",
    "habitudinários": "habitudinário",
    "habitue": "habituar",
    "habituei": "habituar",
    "habitueis": "habituar",
    "habituem": "habituar",
    "habituemo": "habituar",
    "habituemos": "habituar",
    "habitues": "habituar",
    "habituo": "habituar",
    "habituou": "habituar",
    "habituá": "habituar",
    "habituámo": "habituar",
    "habituámos": "habituar",
    "habituáramo": "habituar",
    "habituáramos": "habituar",
    "habituárei": "habituar",
    "habituáreis": "habituar",
    "habituásseis": "habituar",
    "habituássemos": "habituar",
    "habituávamo": "habituar",
    "habituávamos": "habituar",
    "habituávei": "habituar",
    "habituáveis": "habituável",
    "habituês": "habituê",
    "habitá": "habitar",
    "habitáculos": "habitáculo",
    "habitámo": "habitar",
    "habitámos": "habitar",
    "habitáramo": "habitar",
    "habitáramos": "habitar",
    "habitárei": "habitar",
    "habitáreis": "habitar",
    "habitásseis": "habitar",
    "habitássemos": "habitar",
    "habitávamo": "habitar",
    "habitávamos": "habitar",
    "habitávei": "habitar",
    "habitáveis": "habitável",
    "haca": "haco",
    "hacaneias": "hacaneia",
    "hacas": "haco",
    "haceres": "hacer",
    "hachuras": "hachura",
    "hackeres": "hacker",
    "hacos": "haco",
    "hacpóliques": "hacpólique",
    "hadjis": "hadji",
    "hadoques": "hadoque",
    "hadrões": "hadrão",
    "haeckeliana": "haeckeliano",
    "haeckelianas": "haeckeliano",
    "haeckelianos": "haeckeliano",
    "hafiestesímetros": "hafiestesímetro",
    "hagiografias": "hagiografia",
    "hagiográfica": "hagiográfico",
    "hagiográficas": "hagiográfico",
    "hagiográficos": "hagiográfico",
    "hagiologias": "hagiologia",
    "hagiológios": "hagiológio",
    "hagiossemantros": "hagiossemantro",
    "hagiógrafa": "hagiógrafo",
    "hagiógrafas": "hagiógrafo",
    "hagiógrafos": "hagiógrafo",
    "hagióloga": "hagiólogo",
    "hagiólogas": "hagiólogo",
    "hagiólogos": "hagiólogo",
    "haicais": "haicai",
    "haissúaques": "haissúaque",
    "haitiana": "haitiano",
    "haitianas": "haitiano",
    "haitianos": "haitiano",
    "haja": "haver",
    "hajais": "haver",
    "hajam": "haver",
    "hajamo": "haver",
    "hajamos": "haver",
    "hajas": "haver",
    "halalis": "halali",
    "halações": "halação",
    "halimedas": "halimeda",
    "halites": "halite",
    "haliêutica": "haliêutico",
    "haliêuticas": "haliêutico",
    "haliêuticos": "haliêutico",
    "halls": "hall",
    "halmirólises": "halmirólise",
    "halocromias": "halocromia",
    "halogena": "halogenar",
    "halogenada": "halogenar",
    "halogenadas": "halogenar",
    "halogenado": "halogenar",
    "halogenados": "halogenar",
    "halogenai": "halogenar",
    "halogenais": "halogenar",
    "halogenam": "halogenar",
    "halogenamo": "halogenar",
    "halogenamos": "halogenar",
    "halogenando": "halogenar",
    "halogenara": "halogenar",
    "halogenaram": "halogenar",
    "halogenaras": "halogenar",
    "halogenarde": "halogenar",
    "halogenardes": "halogenar",
    "halogenare": "halogenar",
    "halogenarei": "halogenar",
    "halogenareis": "halogenar",
    "halogenarem": "halogenar",
    "halogenaremos": "halogenar",
    "halogenares": "halogenar",
    "halogenaria": "halogenar",
    "halogenariam": "halogenar",
    "halogenarias": "halogenar",
    "halogenarmo": "halogenar",
    "halogenarmos": "halogenar",
    "halogenará": "halogenar",
    "halogenarás": "halogenar",
    "halogenarão": "halogenar",
    "halogenaríamos": "halogenar",
    "halogenaríeis": "halogenar",
    "halogenas": "halogenar",
    "halogenasse": "halogenar",
    "halogenassem": "halogenar",
    "halogenasses": "halogenar",
    "halogenaste": "halogenar",
    "halogenastes": "halogenar",
    "halogenava": "halogenar",
    "halogenavam": "halogenar",
    "halogenavas": "halogenar",
    "halogenações": "halogenação",
    "halogene": "halogenar",
    "halogenei": "halogenar",
    "halogeneis": "halogenar",
    "halogenem": "halogenar",
    "halogenemo": "halogenar",
    "halogenemos": "halogenar",
    "halogenes": "halogenar",
    "halogenetos": "halogeneto",
    "halogeno": "halogenar",
    "halogenou": "halogenar",
    "halogená": "halogenar",
    "halogenámo": "halogenar",
    "halogenámos": "halogenar",
    "halogenáramo": "halogenar",
    "halogenáramos": "halogenar",
    "halogenárei": "halogenar",
    "halogenáreis": "halogenar",
    "halogenásseis": "halogenar",
    "halogenássemos": "halogenar",
    "halogenávamo": "halogenar",
    "halogenávamos": "halogenar",
    "halogenávei": "halogenar",
    "halogenáveis": "halogenar",
    "halografias": "halografia",
    "halogénea": "halogéneo",
    "halogéneas": "halogéneo",
    "halogéneos": "halogéneo",
    "haloisites": "haloisite",
    "halologias": "halologia",
    "halomancias": "halomancia",
    "halomantes": "halomante",
    "halometrias": "halometria",
    "halomântica": "halomântico",
    "halomânticas": "halomântico",
    "halomânticos": "halomântico",
    "haloplânctons": "haloplâncton",
    "halorragidáceas": "halorragidácea",
    "halos": "halo",
    "halterees": "haltere",
    "halteres": "halter",
    "halterofilias": "halterofilia",
    "halterofilismos": "halterofilismo",
    "halterofilistas": "halterofilista",
    "halófila": "halófilo",
    "halófilas": "halófilo",
    "halófilos": "halófilo",
    "halóides": "halóide",
    "halómetros": "halómetro",
    "hamadas": "hamada",
    "hamadrias": "hamadria",
    "hamadríadas": "hamadríada",
    "hamadríades": "hamadríade",
    "hamamelidáceas": "hamamelidácea",
    "hamamélides": "hamamélide",
    "hamburgarias": "hamburgaria",
    "hamburgers": "hamburger",
    "hamburguesa": "hamburguês",
    "hamburguesas": "hamburguês",
    "hamburgueses": "hamburguês",
    "hambúrguers": "hambúrguer",
    "hamiltonianas": "hamiltoniana",
    "hamiltonianos": "hamiltoniano",
    "hamitas": "hamita",
    "hamlética": "hamlético",
    "hamléticas": "hamlético",
    "hamléticos": "hamlético",
    "hamulares": "hamular",
    "hamígera": "hamígero",
    "hamígeras": "hamígero",
    "hamígeros": "hamígero",
    "hamítica": "hamítico",
    "hamíticas": "hamítico",
    "hamíticos": "hamítico",
    "handebolistas": "handebolista",
    "handebóis": "handebol",
    "hangares": "hangar",
    "hangos": "hango",
    "hanoveriana": "hanoveriano",
    "hanoverianas": "hanoveriano",
    "hanoverianos": "hanoveriano",
    "hansas": "hansa",
    "hanseática": "hanseático",
    "hanseáticas": "hanseático",
    "hanseáticos": "hanseático",
    "haplitos": "haplito",
    "haplobiontes": "haplobionte",
    "haplodiplobiontes": "haplodiplobionte",
    "haplodiplontes": "haplodiplonte",
    "haplodontes": "haplodonte",
    "haplografias": "haplografia",
    "haploidias": "haploidia",
    "haplologias": "haplologia",
    "haplológica": "haplológico",
    "haplológicas": "haplológico",
    "haplológicos": "haplológico",
    "haplontes": "haplonte",
    "haplopétala": "haplopétalo",
    "haplopétalas": "haplopétalo",
    "haplopétalos": "haplopétalo",
    "haplotomias": "haplotomia",
    "haplítica": "haplítico",
    "haplíticas": "haplítico",
    "haplíticos": "haplítico",
    "haplófases": "haplófase",
    "haplóides": "haplóide",
    "haplóstoma": "haplóstomo",
    "haplóstomas": "haplóstomo",
    "haplóstomos": "haplóstomo",
    "haplótipos": "haplótipo",
    "happenings": "happening",
    "haptotactismos": "haptotactismo",
    "haptotropismos": "haptotropismo",
    "haptotrópica": "haptotrópico",
    "haptotrópicas": "haptotrópico",
    "haptotrópicos": "haptotrópico",
    "haptotáctica": "haptotáctico",
    "haptotácticas": "haptotáctico",
    "haptotácticos": "haptotáctico",
    "haraquiris": "haraquiri",
    "harass": "haras",
    "hardcores": "hardcore",
    "hardwares": "hardware",
    "harenques": "harenque",
    "harlos": "harlo",
    "harmalas": "harmala",
    "harmalinas": "harmalina",
    "harmatões": "harmatão",
    "harminas": "harmina",
    "harmonias": "harmonia",
    "harmonicordes": "harmonicorde",
    "harmoniflutes": "harmoniflute",
    "harmoniosa": "harmonioso",
    "harmoniosas": "harmonioso",
    "harmoniosos": "harmonioso",
    "harmonistas": "harmonista",
    "harmoniza": "harmonizar",
    "harmonizada": "harmonizar",
    "harmonizadas": "harmonizar",
    "harmonizado": "harmonizar",
    "harmonizadora": "harmonizador",
    "harmonizadoras": "harmonizador",
    "harmonizadores": "harmonizador",
    "harmonizados": "harmonizar",
    "harmonizai": "harmonizar",
    "harmonizais": "harmonizar",
    "harmonizam": "harmonizar",
    "harmonizamo": "harmonizar",
    "harmonizamos": "harmonizar",
    "harmonizando": "harmonizar",
    "harmonizara": "harmonizar",
    "harmonizaram": "harmonizar",
    "harmonizaras": "harmonizar",
    "harmonizarde": "harmonizar",
    "harmonizardes": "harmonizar",
    "harmonizare": "harmonizar",
    "harmonizarei": "harmonizar",
    "harmonizareis": "harmonizar",
    "harmonizarem": "harmonizar",
    "harmonizaremos": "harmonizar",
    "harmonizares": "harmonizar",
    "harmonizaria": "harmonizar",
    "harmonizariam": "harmonizar",
    "harmonizarias": "harmonizar",
    "harmonizarmo": "harmonizar",
    "harmonizarmos": "harmonizar",
    "harmonizará": "harmonizar",
    "harmonizarás": "harmonizar",
    "harmonizarão": "harmonizar",
    "harmonizaríamos": "harmonizar",
    "harmonizaríeis": "harmonizar",
    "harmonizas": "harmonizar",
    "harmonizasse": "harmonizar",
    "harmonizassem": "harmonizar",
    "harmonizasses": "harmonizar",
    "harmonizaste": "harmonizar",
    "harmonizastes": "harmonizar",
    "harmonizava": "harmonizar",
    "harmonizavam": "harmonizar",
    "harmonizavas": "harmonizar",
    "harmonizações": "harmonização",
    "harmonize": "harmonizar",
    "harmonizei": "harmonizar",
    "harmonizeis": "harmonizar",
    "harmonizem": "harmonizar",
    "harmonizemo": "harmonizar",
    "harmonizemos": "harmonizar",
    "harmonizes": "harmonizar",
    "harmonizo": "harmonizar",
    "harmonizou": "harmonizar",
    "harmonizá": "harmonizar",
    "harmonizámo": "harmonizar",
    "harmonizámos": "harmonizar",
    "harmonizáramo": "harmonizar",
    "harmonizáramos": "harmonizar",
    "harmonizárei": "harmonizar",
    "harmonizáreis": "harmonizar",
    "harmonizásseis": "harmonizar",
    "harmonizássemos": "harmonizar",
    "harmonizávamo": "harmonizar",
    "harmonizávamos": "harmonizar",
    "harmonizávei": "harmonizar",
    "harmonizáveis": "harmonizável",
    "harmonísticas": "harmonística",
    "harmonómetros": "harmonómetro",
    "harmotómios": "harmotómio",
    "harmónica": "harmónico",
    "harmónicas": "harmónico",
    "harmónicos": "harmónico",
    "harmónios": "harmónio",
    "harmótomos": "harmótomo",
    "harpa": "harpar",
    "harpada": "harpar",
    "harpadas": "harpar",
    "harpado": "harpar",
    "harpados": "harpar",
    "harpagões": "harpagão",
    "harpai": "harpar",
    "harpais": "harpar",
    "harpalos": "harpalo",
    "harpalídeos": "harpalídeo",
    "harpam": "harpar",
    "harpamo": "harpar",
    "harpamos": "harpar",
    "harpando": "harpar",
    "harpara": "harpar",
    "harparam": "harpar",
    "harparas": "harpar",
    "harpardes": "harpar",
    "harparei": "harpar",
    "harpareis": "harpar",
    "harparem": "harpar",
    "harparemos": "harpar",
    "harpares": "harpar",
    "harparia": "harpar",
    "harpariam": "harpar",
    "harparias": "harpar",
    "harparmo": "harpar",
    "harparmos": "harpar",
    "harpará": "harpar",
    "harparás": "harpar",
    "harparão": "harpar",
    "harparíamos": "harpar",
    "harparíeis": "harpar",
    "harpas": "harpar",
    "harpasse": "harpar",
    "harpassem": "harpar",
    "harpasses": "harpar",
    "harpaste": "harpar",
    "harpastes": "harpar",
    "harpava": "harpar",
    "harpavam": "harpar",
    "harpavas": "harpar",
    "harpe": "harpar",
    "harpeada": "harpear",
    "harpeadas": "harpear",
    "harpeado": "harpear",
    "harpeados": "harpear",
    "harpeai": "harpear",
    "harpeais": "harpear",
    "harpeamo": "harpear",
    "harpeamos": "harpear",
    "harpeando": "harpear",
    "harpeara": "harpear",
    "harpearam": "harpear",
    "harpearas": "harpear",
    "harpeardes": "harpear",
    "harpearei": "harpear",
    "harpeareis": "harpear",
    "harpearem": "harpear",
    "harpearemos": "harpear",
    "harpeares": "harpear",
    "harpearia": "harpear",
    "harpeariam": "harpear",
    "harpearias": "harpear",
    "harpearmo": "harpear",
    "harpearmos": "harpear",
    "harpeará": "harpear",
    "harpearás": "harpear",
    "harpearão": "harpear",
    "harpearíamos": "harpear",
    "harpearíeis": "harpear",
    "harpeasse": "harpear",
    "harpeassem": "harpear",
    "harpeasses": "harpear",
    "harpeaste": "harpear",
    "harpeastes": "harpear",
    "harpeava": "harpear",
    "harpeavam": "harpear",
    "harpeavas": "harpear",
    "harpeei": "harpear",
    "harpeeis": "harpear",
    "harpeemo": "harpear",
    "harpeemos": "harpear",
    "harpei": "harpar",
    "harpeia": "harpear",
    "harpeiam": "harpear",
    "harpeias": "harpear",
    "harpeie": "harpear",
    "harpeiem": "harpear",
    "harpeies": "harpear",
    "harpeio": "harpear",
    "harpeis": "harpar",
    "harpeja": "harpejar",
    "harpejada": "harpejar",
    "harpejadas": "harpejar",
    "harpejado": "harpejar",
    "harpejados": "harpejar",
    "harpejai": "harpejar",
    "harpejais": "harpejar",
    "harpejam": "harpejar",
    "harpejamo": "harpejar",
    "harpejamos": "harpejar",
    "harpejando": "harpejar",
    "harpejara": "harpejar",
    "harpejaram": "harpejar",
    "harpejaras": "harpejar",
    "harpejardes": "harpejar",
    "harpejarei": "harpejar",
    "harpejareis": "harpejar",
    "harpejarem": "harpejar",
    "harpejaremos": "harpejar",
    "harpejares": "harpejar",
    "harpejaria": "harpejar",
    "harpejariam": "harpejar",
    "harpejarias": "harpejar",
    "harpejarmo": "harpejar",
    "harpejarmos": "harpejar",
    "harpejará": "harpejar",
    "harpejarás": "harpejar",
    "harpejarão": "harpejar",
    "harpejaríamos": "harpejar",
    "harpejaríeis": "harpejar",
    "harpejas": "harpejar",
    "harpejasse": "harpejar",
    "harpejassem": "harpejar",
    "harpejasses": "harpejar",
    "harpejaste": "harpejar",
    "harpejastes": "harpejar",
    "harpejava": "harpejar",
    "harpejavam": "harpejar",
    "harpejavas": "harpejar",
    "harpeje": "harpejar",
    "harpejei": "harpejar",
    "harpejeis": "harpejar",
    "harpejem": "harpejar",
    "harpejemo": "harpejar",
    "harpejemos": "harpejar",
    "harpejes": "harpejar",
    "harpejo": "harpejar",
    "harpejos": "harpejo",
    "harpejou": "harpejar",
    "harpejámo": "harpejar",
    "harpejámos": "harpejar",
    "harpejáramo": "harpejar",
    "harpejáramos": "harpejar",
    "harpejáreis": "harpejar",
    "harpejásseis": "harpejar",
    "harpejássemos": "harpejar",
    "harpejávamo": "harpejar",
    "harpejávamos": "harpejar",
    "harpejáveis": "harpejar",
    "harpem": "harpar",
    "harpemo": "harpar",
    "harpemos": "harpar",
    "harpeou": "harpear",
    "harpes": "harpar",
    "harpeámo": "harpear",
    "harpeámos": "harpear",
    "harpeáramo": "harpear",
    "harpeáramos": "harpear",
    "harpeáreis": "harpear",
    "harpeásseis": "harpear",
    "harpeássemos": "harpear",
    "harpeávamo": "harpear",
    "harpeávamos": "harpear",
    "harpeáveis": "harpear",
    "harpias": "harpia",
    "harpistas": "harpista",
    "harpo": "harpar",
    "harpou": "harpar",
    "harpálidas": "harpálida",
    "harpámo": "harpar",
    "harpámos": "harpar",
    "harpáramo": "harpar",
    "harpáramos": "harpar",
    "harpáreis": "harpar",
    "harpásseis": "harpar",
    "harpássemos": "harpar",
    "harpávamo": "harpar",
    "harpávamos": "harpar",
    "harpáveis": "harpar",
    "harta": "harto",
    "hartas": "harto",
    "hartos": "harto",
    "harzburgitos": "harzburgito",
    "haréns": "harém",
    "haríolos": "haríolo",
    "hastada": "hastado",
    "hastadas": "hastado",
    "hastados": "hastado",
    "hastapuras": "hastapura",
    "hastarias": "hastaria",
    "hastas": "hasta",
    "hasteada": "hastear",
    "hasteadas": "hastear",
    "hasteado": "hastear",
    "hasteados": "hastear",
    "hasteai": "hastear",
    "hasteais": "hastear",
    "hasteamentos": "hasteamento",
    "hasteamo": "hastear",
    "hasteamos": "hastear",
    "hasteando": "hastear",
    "hasteara": "hastear",
    "hastearam": "hastear",
    "hastearas": "hastear",
    "hastearde": "hastear",
    "hasteardes": "hastear",
    "hasteare": "hastear",
    "hastearei": "hastear",
    "hasteareis": "hastear",
    "hastearem": "hastear",
    "hastearemos": "hastear",
    "hasteares": "hastear",
    "hastearia": "hastear",
    "hasteariam": "hastear",
    "hastearias": "hastear",
    "hastearmo": "hastear",
    "hastearmos": "hastear",
    "hasteará": "hastear",
    "hastearás": "hastear",
    "hastearão": "hastear",
    "hastearíamos": "hastear",
    "hastearíeis": "hastear",
    "hasteasse": "hastear",
    "hasteassem": "hastear",
    "hasteasses": "hastear",
    "hasteaste": "hastear",
    "hasteastes": "hastear",
    "hasteava": "hastear",
    "hasteavam": "hastear",
    "hasteavas": "hastear",
    "hasteei": "hastear",
    "hasteeis": "hastear",
    "hasteemo": "hastear",
    "hasteemos": "hastear",
    "hasteia": "hastear",
    "hasteiam": "hastear",
    "hasteias": "hastear",
    "hasteie": "hastear",
    "hasteiem": "hastear",
    "hasteies": "hastear",
    "hasteio": "hastear",
    "hasteou": "hastear",
    "hastes": "haste",
    "hasteá": "hastear",
    "hasteámo": "hastear",
    "hasteámos": "hastear",
    "hasteáramo": "hastear",
    "hasteáramos": "hastear",
    "hasteárei": "hastear",
    "hasteáreis": "hastear",
    "hasteásseis": "hastear",
    "hasteássemos": "hastear",
    "hasteávamo": "hastear",
    "hasteávamos": "hastear",
    "hasteávei": "hastear",
    "hasteáveis": "hasteável",
    "hastibranca": "hastibranco",
    "hastibrancas": "hastibranco",
    "hastibrancos": "hastibranco",
    "hastifina": "hastifino",
    "hastifinas": "hastifino",
    "hastifinos": "hastifino",
    "hastifoliada": "hastifoliado",
    "hastifoliadas": "hastifoliado",
    "hastifoliados": "hastifoliado",
    "hastiformes": "hastiforme",
    "hastifólia": "hastifólio",
    "hastifólias": "hastifólio",
    "hastifólios": "hastifólio",
    "hastilhas": "hastilha",
    "hastilheiras": "hastilheira",
    "hastins": "hastim",
    "hastis": "hastil",
    "hastária": "hastário",
    "hastárias": "hastário",
    "hastários": "hastário",
    "haura": "haurir",
    "haurais": "haurir",
    "hauram": "haurir",
    "hauramo": "haurir",
    "hauramos": "haurir",
    "hauras": "haurir",
    "haure": "haurir",
    "haurem": "haurir",
    "haures": "haurir",
    "hauri": "haurir",
    "hauria": "haurir",
    "hauriam": "haurir",
    "haurias": "haurir",
    "haurida": "haurir",
    "hauridas": "haurir",
    "haurido": "haurir",
    "hauridos": "haurir",
    "haurimo": "haurir",
    "haurimos": "haurir",
    "haurindo": "haurir",
    "haurira": "haurir",
    "hauriram": "haurir",
    "hauriras": "haurir",
    "haurirde": "haurir",
    "haurirdes": "haurir",
    "haurire": "haurir",
    "haurirei": "haurir",
    "haurireis": "haurir",
    "haurirem": "haurir",
    "hauriremos": "haurir",
    "haurires": "haurir",
    "hauriria": "haurir",
    "hauririam": "haurir",
    "hauririas": "haurir",
    "haurirmo": "haurir",
    "haurirmos": "haurir",
    "haurirá": "haurir",
    "haurirás": "haurir",
    "haurirão": "haurir",
    "hauriríamos": "haurir",
    "hauriríeis": "haurir",
    "hauris": "haurir",
    "haurisse": "haurir",
    "haurissem": "haurir",
    "haurisses": "haurir",
    "hauriste": "haurir",
    "hauristes": "haurir",
    "hauriu": "haurir",
    "hauro": "haurir",
    "hauríamo": "haurir",
    "hauríamos": "haurir",
    "hauríei": "haurir",
    "hauríeis": "haurir",
    "hauríramo": "haurir",
    "hauríramos": "haurir",
    "haurírei": "haurir",
    "hauríreis": "haurir",
    "haurísseis": "haurir",
    "hauríssemos": "haurir",
    "hauríveis": "haurível",
    "haussmannites": "haussmannite",
    "haustelados": "haustelado",
    "haustelos": "haustelo",
    "haustos": "hausto",
    "haustórios": "haustório",
    "hauterivianos": "hauteriviano",
    "hauínas": "hauína",
    "havaiana": "havaiano",
    "havaianas": "havaiano",
    "havaianos": "havaiano",
    "havana": "havano",
    "havanas": "havano",
    "havanesa": "havanês",
    "havanesas": "havanês",
    "havaneses": "havanês",
    "havanos": "havano",
    "havei": "haver",
    "haveis": "haver",
    "havemo": "haver",
    "havemos": "haver",
    "havendo": "haver",
    "haverde": "haver",
    "haverdes": "haver",
    "havere": "haver",
    "haverei": "haver",
    "havereis": "haver",
    "haverem": "haver",
    "haveremos": "haver",
    "haveres": "haver",
    "haveria": "haver",
    "haveriam": "haver",
    "haverias": "haver",
    "havermo": "haver",
    "havermos": "haver",
    "haverá": "haver",
    "haverás": "haver",
    "haverão": "haver",
    "haveríamos": "haver",
    "haveríeis": "haver",
    "havia": "haver",
    "haviam": "haver",
    "havias": "haver",
    "havida": "havido",
    "havidas": "havido",
    "havido": "haver",
    "havidos": "havido",
    "havê": "haver",
    "havíamo": "haver",
    "havíamos": "haver",
    "havíei": "haver",
    "havíeis": "haver",
    "haxixes": "haxixe",
    "haxixismos": "haxixismo",
    "heautognoses": "heautognose",
    "hebdomadária": "hebdomadário",
    "hebdomadárias": "hebdomadário",
    "hebdomadários": "hebdomadário",
    "hebdomática": "hebdomático",
    "hebdomáticas": "hebdomático",
    "hebdomáticos": "hebdomático",
    "hebdómadas": "hebdómada",
    "hebefrenias": "hebefrenia",
    "hebelogias": "hebelogia",
    "hebertismos": "hebertismo",
    "hebertistas": "hebertista",
    "hebeta": "hebetar",
    "hebetada": "hebetar",
    "hebetadas": "hebetar",
    "hebetado": "hebetar",
    "hebetados": "hebetar",
    "hebetai": "hebetar",
    "hebetais": "hebetar",
    "hebetam": "hebetar",
    "hebetamo": "hebetar",
    "hebetamos": "hebetar",
    "hebetando": "hebetar",
    "hebetantes": "hebetante",
    "hebetara": "hebetar",
    "hebetaram": "hebetar",
    "hebetaras": "hebetar",
    "hebetarde": "hebetar",
    "hebetardes": "hebetar",
    "hebetare": "hebetar",
    "hebetarei": "hebetar",
    "hebetareis": "hebetar",
    "hebetarem": "hebetar",
    "hebetaremos": "hebetar",
    "hebetares": "hebetar",
    "hebetaria": "hebetar",
    "hebetariam": "hebetar",
    "hebetarias": "hebetar",
    "hebetarmo": "hebetar",
    "hebetarmos": "hebetar",
    "hebetará": "hebetar",
    "hebetarás": "hebetar",
    "hebetarão": "hebetar",
    "hebetaríamos": "hebetar",
    "hebetaríeis": "hebetar",
    "hebetas": "hebetar",
    "hebetasse": "hebetar",
    "hebetassem": "hebetar",
    "hebetasses": "hebetar",
    "hebetaste": "hebetar",
    "hebetastes": "hebetar",
    "hebetava": "hebetar",
    "hebetavam": "hebetar",
    "hebetavas": "hebetar",
    "hebetações": "hebetação",
    "hebete": "hebetar",
    "hebetei": "hebetar",
    "hebeteis": "hebetar",
    "hebetem": "hebetar",
    "hebetemo": "hebetar",
    "hebetemos": "hebetar",
    "hebetes": "hebetar",
    "hebetismos": "hebetismo",
    "hebeto": "hebetar",
    "hebetou": "hebetar",
    "hebetudes": "hebetude",
    "hebetá": "hebetar",
    "hebetámo": "hebetar",
    "hebetámos": "hebetar",
    "hebetáramo": "hebetar",
    "hebetáramos": "hebetar",
    "hebetárei": "hebetar",
    "hebetáreis": "hebetar",
    "hebetásseis": "hebetar",
    "hebetássemos": "hebetar",
    "hebetávamo": "hebetar",
    "hebetávamos": "hebetar",
    "hebetávei": "hebetar",
    "hebetáveis": "hebetar",
    "hebraica": "hebraico",
    "hebraicas": "hebraico",
    "hebraicos": "hebraico",
    "hebraizantes": "hebraizante",
    "hebraísmos": "hebraísmo",
    "hebraístas": "hebraísta",
    "hebreia": "hebreu",
    "hebreias": "hebreu",
    "hebreus": "hebreu",
    "hecatombas": "hecatomba",
    "hecatombes": "hecatombe",
    "hecatostilos": "hecatostilo",
    "hecceidades": "hecceidade",
    "hectaedros": "hectaedro",
    "hectares": "hectare",
    "hecticidades": "hecticidade",
    "hectoedrias": "hectoedria",
    "hectogramas": "hectograma",
    "hectográfica": "hectográfico",
    "hectográficas": "hectográfico",
    "hectográficos": "hectográfico",
    "hectolitros": "hectolitro",
    "hectosteres": "hectostere",
    "hectostéreos": "hectostéreo",
    "hectoédrica": "hectoédrico",
    "hectoédricas": "hectoédrico",
    "hectoédricos": "hectoédrico",
    "hectágonos": "hectágono",
    "hectógrafos": "hectógrafo",
    "hectómetros": "hectómetro",
    "hedenbergites": "hedenbergite",
    "hederiformes": "hederiforme",
    "hederinas": "hederina",
    "hederosa": "hederoso",
    "hederosas": "hederoso",
    "hederosos": "hederoso",
    "hederácea": "hederáceo",
    "hederáceas": "hederáceo",
    "hederáceos": "hederáceo",
    "hederígera": "hederígero",
    "hederígeras": "hederígero",
    "hederígeros": "hederígero",
    "hedionda": "hediondo",
    "hediondas": "hediondo",
    "hediondezaes": "hediondeza",
    "hediondezes": "hediondez",
    "hediondos": "hediondo",
    "hedonismos": "hedonismo",
    "hedonistas": "hedonista",
    "hedroceles": "hedrocele",
    "hedónica": "hedónico",
    "hedónicas": "hedónico",
    "hedónicos": "hedónico",
    "hegeliana": "hegeliano",
    "hegelianas": "hegeliano",
    "hegelianismos": "hegelianismo",
    "hegelianos": "hegeliano",
    "hegelismos": "hegelismo",
    "hegemonias": "hegemonia",
    "hegemoniza": "hegemonizar",
    "hegemonizada": "hegemonizar",
    "hegemonizadas": "hegemonizar",
    "hegemonizado": "hegemonizar",
    "hegemonizados": "hegemonizar",
    "hegemonizai": "hegemonizar",
    "hegemonizais": "hegemonizar",
    "hegemonizam": "hegemonizar",
    "hegemonizamo": "hegemonizar",
    "hegemonizamos": "hegemonizar",
    "hegemonizando": "hegemonizar",
    "hegemonizara": "hegemonizar",
    "hegemonizaram": "hegemonizar",
    "hegemonizaras": "hegemonizar",
    "hegemonizarde": "hegemonizar",
    "hegemonizardes": "hegemonizar",
    "hegemonizare": "hegemonizar",
    "hegemonizarei": "hegemonizar",
    "hegemonizareis": "hegemonizar",
    "hegemonizarem": "hegemonizar",
    "hegemonizaremos": "hegemonizar",
    "hegemonizares": "hegemonizar",
    "hegemonizaria": "hegemonizar",
    "hegemonizariam": "hegemonizar",
    "hegemonizarias": "hegemonizar",
    "hegemonizarmo": "hegemonizar",
    "hegemonizarmos": "hegemonizar",
    "hegemonizará": "hegemonizar",
    "hegemonizarás": "hegemonizar",
    "hegemonizarão": "hegemonizar",
    "hegemonizaríamos": "hegemonizar",
    "hegemonizaríeis": "hegemonizar",
    "hegemonizas": "hegemonizar",
    "hegemonizasse": "hegemonizar",
    "hegemonizassem": "hegemonizar",
    "hegemonizasses": "hegemonizar",
    "hegemonizaste": "hegemonizar",
    "hegemonizastes": "hegemonizar",
    "hegemonizava": "hegemonizar",
    "hegemonizavam": "hegemonizar",
    "hegemonizavas": "hegemonizar",
    "hegemonizações": "hegemonização",
    "hegemonize": "hegemonizar",
    "hegemonizei": "hegemonizar",
    "hegemonizeis": "hegemonizar",
    "hegemonizem": "hegemonizar",
    "hegemonizemo": "hegemonizar",
    "hegemonizemos": "hegemonizar",
    "hegemonizes": "hegemonizar",
    "hegemonizo": "hegemonizar",
    "hegemonizou": "hegemonizar",
    "hegemonizá": "hegemonizar",
    "hegemonizámo": "hegemonizar",
    "hegemonizámos": "hegemonizar",
    "hegemonizáramo": "hegemonizar",
    "hegemonizáramos": "hegemonizar",
    "hegemonizárei": "hegemonizar",
    "hegemonizáreis": "hegemonizar",
    "hegemonizásseis": "hegemonizar",
    "hegemonizássemos": "hegemonizar",
    "hegemonizávamo": "hegemonizar",
    "hegemonizávamos": "hegemonizar",
    "hegemonizávei": "hegemonizar",
    "hegemonizáveis": "hegemonizar",
    "hegemónica": "hegemónico",
    "hegemónicas": "hegemónico",
    "hegemónicos": "hegemónico",
    "hei": "haver",
    "heis": "haver",
    "helcologias": "helcologia",
    "helcoses": "helcose",
    "heleborinhas": "heleborinha",
    "heleborismos": "heleborismo",
    "helena": "heleno",
    "helenas": "heleno",
    "helenismos": "helenismo",
    "helenistas": "helenista",
    "heleniza": "helenizar",
    "helenizada": "helenizar",
    "helenizadas": "helenizar",
    "helenizado": "helenizar",
    "helenizados": "helenizar",
    "helenizai": "helenizar",
    "helenizais": "helenizar",
    "helenizam": "helenizar",
    "helenizamo": "helenizar",
    "helenizamos": "helenizar",
    "helenizando": "helenizar",
    "helenizantes": "helenizante",
    "helenizara": "helenizar",
    "helenizaram": "helenizar",
    "helenizaras": "helenizar",
    "helenizarde": "helenizar",
    "helenizardes": "helenizar",
    "helenizare": "helenizar",
    "helenizarei": "helenizar",
    "helenizareis": "helenizar",
    "helenizarem": "helenizar",
    "helenizaremos": "helenizar",
    "helenizares": "helenizar",
    "helenizaria": "helenizar",
    "helenizariam": "helenizar",
    "helenizarias": "helenizar",
    "helenizarmo": "helenizar",
    "helenizarmos": "helenizar",
    "helenizará": "helenizar",
    "helenizarás": "helenizar",
    "helenizarão": "helenizar",
    "helenizaríamos": "helenizar",
    "helenizaríeis": "helenizar",
    "helenizas": "helenizar",
    "helenizasse": "helenizar",
    "helenizassem": "helenizar",
    "helenizasses": "helenizar",
    "helenizaste": "helenizar",
    "helenizastes": "helenizar",
    "helenizava": "helenizar",
    "helenizavam": "helenizar",
    "helenizavas": "helenizar",
    "helenizações": "helenização",
    "helenize": "helenizar",
    "helenizei": "helenizar",
    "helenizeis": "helenizar",
    "helenizem": "helenizar",
    "helenizemo": "helenizar",
    "helenizemos": "helenizar",
    "helenizes": "helenizar",
    "helenizo": "helenizar",
    "helenizou": "helenizar",
    "helenizá": "helenizar",
    "helenizámo": "helenizar",
    "helenizámos": "helenizar",
    "helenizáramo": "helenizar",
    "helenizáramos": "helenizar",
    "helenizárei": "helenizar",
    "helenizáreis": "helenizar",
    "helenizásseis": "helenizar",
    "helenizássemos": "helenizar",
    "helenizávamo": "helenizar",
    "helenizávamos": "helenizar",
    "helenizávei": "helenizar",
    "helenizáveis": "helenizável",
    "helenos": "heleno",
    "helenística": "helenístico",
    "helenísticas": "helenístico",
    "helenísticos": "helenístico",
    "helespontíaca": "helespontíaco",
    "helespontíacas": "helespontíaco",
    "helespontíacos": "helespontíaco",
    "helespôntica": "helespôntico",
    "helespônticas": "helespôntico",
    "helespônticos": "helespôntico",
    "heliantinas": "heliantina",
    "heliantos": "helianto",
    "heliantíneas": "heliantínea",
    "heliastas": "heliasta",
    "helicicultora": "helicicultor",
    "helicicultoras": "helicicultor",
    "helicicultores": "helicicultor",
    "heliciculturas": "helicicultura",
    "heliciformes": "heliciforme",
    "helicoidais": "helicoidal",
    "heliconiana": "heliconiano",
    "heliconianas": "heliconiano",
    "heliconianos": "heliconiano",
    "helicídeos": "helicídeo",
    "helicóides": "helicóide",
    "helicómetros": "helicómetro",
    "helicónia": "helicónio",
    "helicónias": "helicónio",
    "helicónios": "helicónio",
    "helicópodes": "helicópode",
    "helicópteros": "helicóptero",
    "heliocentrismos": "heliocentrismo",
    "heliocometas": "heliocometa",
    "heliocromias": "heliocromia",
    "heliocrómica": "heliocrómico",
    "heliocrómicas": "heliocrómico",
    "heliocrómicos": "heliocrómico",
    "heliocêntrica": "heliocêntrico",
    "heliocêntricas": "heliocêntrico",
    "heliocêntricos": "heliocêntrico",
    "heliofilias": "heliofilia",
    "heliofobias": "heliofobia",
    "heliofotómetros": "heliofotómetro",
    "heliofíleas": "heliofílea",
    "heliofísicas": "heliofísica",
    "heliografias": "heliografia",
    "heliogravadora": "heliogravador",
    "heliogravadoras": "heliogravador",
    "heliogravadores": "heliogravador",
    "heliogravuras": "heliogravura",
    "heliográfica": "heliográfico",
    "heliográficas": "heliográfico",
    "heliográficos": "heliográfico",
    "heliolatrias": "heliolatria",
    "helioloxodromias": "helioloxodromia",
    "heliomotores": "heliomotor",
    "heliométrica": "heliométrico",
    "heliométricas": "heliométrico",
    "heliométricos": "heliométrico",
    "helioplastias": "helioplastia",
    "helioscopias": "helioscopia",
    "helioscópios": "helioscópio",
    "helioses": "heliose",
    "heliostática": "heliostático",
    "heliostáticas": "heliostático",
    "heliostáticos": "heliostático",
    "helioterapias": "helioterapia",
    "heliotermómetros": "heliotermómetro",
    "heliotropias": "heliotropia",
    "heliotropinas": "heliotropina",
    "heliotropismos": "heliotropismo",
    "heliotrópica": "heliotrópico",
    "heliotrópicas": "heliotrópico",
    "heliotrópicos": "heliotrópico",
    "heliotrópios": "heliotrópio",
    "heliozoários": "heliozoário",
    "heliportos": "heliporto",
    "helis": "heli",
    "heliófila": "heliófilo",
    "heliófilas": "heliófilo",
    "heliófilos": "heliófilo",
    "heliófoba": "heliófobo",
    "heliófobas": "heliófobo",
    "heliófobos": "heliófobo",
    "heliófuga": "heliófugo",
    "heliófugas": "heliófugo",
    "heliófugos": "heliófugo",
    "heliógrafos": "heliógrafo",
    "heliólatras": "heliólatra",
    "heliómetros": "heliómetro",
    "helióstata": "helióstato",
    "helióstatas": "helióstato",
    "helióstatos": "helióstato",
    "heliões": "helião",
    "helmintologias": "helmintologia",
    "helmintologistas": "helmintologista",
    "helmintológica": "helmintológico",
    "helmintológicas": "helmintológico",
    "helmintológicos": "helmintológico",
    "helmintos": "helminto",
    "helmintíases": "helmintíase",
    "helmintóides": "helmintóide",
    "helmíntica": "helmíntico",
    "helmínticas": "helmíntico",
    "helmínticos": "helmíntico",
    "helvecianos": "helveciano",
    "helvécia": "helvécio",
    "helvécias": "helvécio",
    "helvécios": "helvécio",
    "helvética": "helvético",
    "helvéticas": "helvético",
    "helvéticos": "helvético",
    "heléboros": "heléboro",
    "helénica": "helénico",
    "helénicas": "helénico",
    "helénicos": "helénico",
    "helépoles": "helépole",
    "helíaca": "helíaco",
    "helíacas": "helíaco",
    "helíacos": "helíaco",
    "helícidas": "helícida",
    "helículas": "helícula",
    "hemais": "hemal",
    "hemalopias": "hemalopia",
    "hemangiomas": "hemangioma",
    "hemartroses": "hemartrose",
    "hemateínas": "hemateína",
    "hematias": "hematia",
    "hematinas": "hematina",
    "hematites": "hematite",
    "hematoblastos": "hematoblasto",
    "hematocarpa": "hematocarpo",
    "hematocarpas": "hematocarpo",
    "hematocarpos": "hematocarpo",
    "hematoceles": "hematocele",
    "hematocolpos": "hematocolpo",
    "hematofila": "hematofilo",
    "hematofilas": "hematofilo",
    "hematofilos": "hematofilo",
    "hematofobias": "hematofobia",
    "hematografias": "hematografia",
    "hematologias": "hematologia",
    "hematologistas": "hematologista",
    "hematolítica": "hematolítico",
    "hematolíticas": "hematolítico",
    "hematolíticos": "hematolítico",
    "hematológica": "hematológico",
    "hematológicas": "hematológico",
    "hematológicos": "hematológico",
    "hematomas": "hematoma",
    "hematometrias": "hematometria",
    "hematométrica": "hematométrico",
    "hematométricas": "hematométrico",
    "hematométricos": "hematométrico",
    "hematopoeses": "hematopoese",
    "hematopoética": "hematopoético",
    "hematopoéticas": "hematopoético",
    "hematopoéticos": "hematopoético",
    "hematosa": "hematosar",
    "hematosada": "hematosar",
    "hematosadas": "hematosar",
    "hematosado": "hematosar",
    "hematosados": "hematosar",
    "hematosai": "hematosar",
    "hematosais": "hematosar",
    "hematosam": "hematosar",
    "hematosamo": "hematosar",
    "hematosamos": "hematosar",
    "hematosando": "hematosar",
    "hematosara": "hematosar",
    "hematosaram": "hematosar",
    "hematosaras": "hematosar",
    "hematosarde": "hematosar",
    "hematosardes": "hematosar",
    "hematosare": "hematosar",
    "hematosarei": "hematosar",
    "hematosareis": "hematosar",
    "hematosarem": "hematosar",
    "hematosaremos": "hematosar",
    "hematosares": "hematosar",
    "hematosaria": "hematosar",
    "hematosariam": "hematosar",
    "hematosarias": "hematosar",
    "hematosarmo": "hematosar",
    "hematosarmos": "hematosar",
    "hematosará": "hematosar",
    "hematosarás": "hematosar",
    "hematosarão": "hematosar",
    "hematosaríamos": "hematosar",
    "hematosaríeis": "hematosar",
    "hematosas": "hematosar",
    "hematosasse": "hematosar",
    "hematosassem": "hematosar",
    "hematosasses": "hematosar",
    "hematosaste": "hematosar",
    "hematosastes": "hematosar",
    "hematosava": "hematosar",
    "hematosavam": "hematosar",
    "hematosavas": "hematosar",
    "hematose": "hematosar",
    "hematosei": "hematosar",
    "hematoseis": "hematosar",
    "hematosem": "hematosar",
    "hematosemo": "hematosar",
    "hematosemos": "hematosar",
    "hematoses": "hematose",
    "hematosinas": "hematosina",
    "hematoso": "hematosar",
    "hematosou": "hematosar",
    "hematospermias": "hematospermia",
    "hematospérmica": "hematospérmico",
    "hematospérmicas": "hematospérmico",
    "hematospérmicos": "hematospérmico",
    "hematosá": "hematosar",
    "hematosámo": "hematosar",
    "hematosámos": "hematosar",
    "hematosáramo": "hematosar",
    "hematosáramos": "hematosar",
    "hematosárei": "hematosar",
    "hematosáreis": "hematosar",
    "hematosásseis": "hematosar",
    "hematosássemos": "hematosar",
    "hematosávamo": "hematosar",
    "hematosávamos": "hematosar",
    "hematosávei": "hematosar",
    "hematosáveis": "hematosar",
    "hematoxilinas": "hematoxilina",
    "hematozoária": "hematozoário",
    "hematozoárias": "hematozoário",
    "hematozoários": "hematozoário",
    "hematurias": "hematuria",
    "hematémeses": "hematémese",
    "hematócritos": "hematócrito",
    "hematófaga": "hematófago",
    "hematófagas": "hematófago",
    "hematófagos": "hematófago",
    "hematófila": "hematófilo",
    "hematófilas": "hematófilo",
    "hematófilos": "hematófilo",
    "hematófoba": "hematófobo",
    "hematófobas": "hematófobo",
    "hematófobos": "hematófobo",
    "hematóides": "hematóide",
    "hematólises": "hematólise",
    "hematóloga": "hematólogo",
    "hematólogas": "hematólogo",
    "hematólogos": "hematólogo",
    "hematúrias": "hematúria",
    "hematúrica": "hematúrico",
    "hematúricas": "hematúrico",
    "hematúricos": "hematúrico",
    "hemeralopes": "hemeralope",
    "hemeralopias": "hemeralopia",
    "hemeralópica": "hemeralópico",
    "hemeralópicas": "hemeralópico",
    "hemeralópicos": "hemeralópico",
    "hemeranopsias": "hemeranopsia",
    "hemeras": "hemera",
    "hemerologias": "hemerologia",
    "hemerológios": "hemerológio",
    "hemeropatas": "hemeropata",
    "hemeropatias": "hemeropatia",
    "hemerotecas": "hemeroteca",
    "hemeródromos": "hemeródromo",
    "hemeróloga": "hemerólogo",
    "hemerólogas": "hemerólogo",
    "hemerólogos": "hemerólogo",
    "hemes": "heme",
    "hemiacefalias": "hemiacefalia",
    "hemiacéfala": "hemiacéfalo",
    "hemiacéfalas": "hemiacéfalo",
    "hemiacéfalos": "hemiacéfalo",
    "hemiagnosias": "hemiagnosia",
    "hemialgias": "hemialgia",
    "hemianestesias": "hemianestesia",
    "hemianopsias": "hemianopsia",
    "hemibraquidomas": "hemibraquidoma",
    "hemicarpos": "hemicarpo",
    "hemiceluloses": "hemicelulose",
    "hemiciclos": "hemiciclo",
    "hemicilindros": "hemicilindro",
    "hemicordados": "hemicordado",
    "hemicranias": "hemicrania",
    "hemicrânica": "hemicrânico",
    "hemicrânicas": "hemicrânico",
    "hemicrânicos": "hemicrânico",
    "hemicíclica": "hemicíclico",
    "hemicíclicas": "hemicíclico",
    "hemicíclicos": "hemicíclico",
    "hemiedrias": "hemiedria",
    "hemiedros": "hemiedro",
    "hemifaciais": "hemifacial",
    "hemiglobinúrica": "hemiglobinúrico",
    "hemiglobinúricas": "hemiglobinúrico",
    "hemiglobinúricos": "hemiglobinúrico",
    "hemilabiais": "hemilabial",
    "hemimacrodomas": "hemimacrodoma",
    "hemimetabólica": "hemimetabólico",
    "hemimetabólicas": "hemimetabólico",
    "hemimetabólicos": "hemimetabólico",
    "hemimorfias": "hemimorfia",
    "hemimorfites": "hemimorfite",
    "hemimórfica": "hemimórfico",
    "hemimórficas": "hemimórfico",
    "hemimórficos": "hemimórfico",
    "hemioctaedros": "hemioctaedro",
    "hemiopias": "hemiopia",
    "hemiortodomas": "hemiortodoma",
    "hemiparasitas": "hemiparasita",
    "hemiparasitismos": "hemiparasitismo",
    "hemiparesias": "hemiparesia",
    "hemipirâmides": "hemipirâmide",
    "hemiplegias": "hemiplegia",
    "hemiplexias": "hemiplexia",
    "hemiplégica": "hemiplégico",
    "hemiplégicas": "hemiplégico",
    "hemiplégicos": "hemiplégico",
    "hemiprismas": "hemiprisma",
    "hemiprismática": "hemiprismático",
    "hemiprismáticas": "hemiprismático",
    "hemiprismáticos": "hemiprismático",
    "hemisferoidais": "hemisferoidal",
    "hemisferóides": "hemisferóide",
    "hemisférica": "hemisférico",
    "hemisféricas": "hemisférico",
    "hemisféricos": "hemisférico",
    "hemisférios": "hemisfério",
    "hemistíquios": "hemistíquio",
    "hemiterapias": "hemiterapia",
    "hemiteratias": "hemiteratia",
    "hemiterias": "hemiteria",
    "hemitropa": "hemitropo",
    "hemitropas": "hemitropo",
    "hemitropias": "hemitropia",
    "hemitropos": "hemitropo",
    "hemiédrica": "hemiédrico",
    "hemiédricas": "hemiédrico",
    "hemiédricos": "hemiédrico",
    "hemiélitros": "hemiélitro",
    "hemo": "haver",
    "hemocianinas": "hemocianina",
    "hemoculturas": "hemocultura",
    "hemodiagnóstica": "hemodiagnóstico",
    "hemodiagnósticas": "hemodiagnóstico",
    "hemodiagnósticos": "hemodiagnóstico",
    "hemodialisada": "hemodialisado",
    "hemodialisadas": "hemodialisado",
    "hemodialisados": "hemodialisado",
    "hemodias": "hemodia",
    "hemodinamómetros": "hemodinamómetro",
    "hemodinamômetros": "hemodinamômetro",
    "hemodinâmicas": "hemodinâmica",
    "hemodiálises": "hemodiálise",
    "hemofilias": "hemofilia",
    "hemoflagelada": "hemoflagelado",
    "hemoflageladas": "hemoflagelado",
    "hemoflagelados": "hemoflagelado",
    "hemofobias": "hemofobia",
    "hemoftalmias": "hemoftalmia",
    "hemoftalmos": "hemoftalmo",
    "hemofílica": "hemofílico",
    "hemofílicas": "hemofílico",
    "hemofílicos": "hemofílico",
    "hemoglobinas": "hemoglobina",
    "hemoglobinurias": "hemoglobinuria",
    "hemoglobinómetros": "hemoglobinómetro",
    "hemoglobinúrias": "hemoglobinúria",
    "hemogramas": "hemograma",
    "hemolinfas": "hemolinfa",
    "hemolítica": "hemolítico",
    "hemolíticas": "hemolítico",
    "hemolíticos": "hemolítico",
    "hemopatias": "hemopatia",
    "hemoplástica": "hemoplástico",
    "hemoplásticas": "hemoplástico",
    "hemoplásticos": "hemoplástico",
    "hemoptises": "hemoptise",
    "hemoptóica": "hemoptóico",
    "hemoptóicas": "hemoptóico",
    "hemoptóicos": "hemoptóico",
    "hemorragias": "hemorragia",
    "hemorroidosa": "hemorroidoso",
    "hemorroidosas": "hemorroidoso",
    "hemorroidosos": "hemorroidoso",
    "hemorroidária": "hemorroidário",
    "hemorroidárias": "hemorroidário",
    "hemorroidários": "hemorroidário",
    "hemorrágica": "hemorrágico",
    "hemorrágicas": "hemorrágico",
    "hemorrágicos": "hemorrágico",
    "hemorróidais": "hemorróidal",
    "hemos": "haver",
    "hemoscopias": "hemoscopia",
    "hemospasias": "hemospasia",
    "hemosporídeos": "hemosporídeo",
    "hemospóridas": "hemospórida",
    "hemostasias": "hemostasia",
    "hemostática": "hemostático",
    "hemostáticas": "hemostático",
    "hemostáticos": "hemostático",
    "hemoterapeutas": "hemoterapeuta",
    "hemoterapias": "hemoterapia",
    "hemotexias": "hemotexia",
    "hemotoxias": "hemotoxia",
    "hemotoxinas": "hemotoxina",
    "hemotóxica": "hemotóxico",
    "hemotóxicas": "hemotóxico",
    "hemotóxicos": "hemotóxico",
    "hemulídeos": "hemulídeo",
    "hemácias": "hemácia",
    "hemíonos": "hemíono",
    "hemíptera": "hemíptero",
    "hemípteras": "hemíptero",
    "hemípteros": "hemíptero",
    "hemólises": "hemólise",
    "hemómetros": "hemómetro",
    "hemóstases": "hemóstase",
    "hemúlidas": "hemúlida",
    "henas": "hena",
    "hendecadrias": "hendecadria",
    "hendecaedros": "hendecaedro",
    "hendecagonais": "hendecagonal",
    "hendecandra": "hendecandro",
    "hendecandras": "hendecandro",
    "hendecandros": "hendecandro",
    "hendecanos": "hendecano",
    "hendecassilábica": "hendecassilábico",
    "hendecassilábicas": "hendecassilábico",
    "hendecassilábicos": "hendecassilábico",
    "hendecassílabos": "hendecassílabo",
    "hendecosaedros": "hendecosaedro",
    "hendecoságonos": "hendecoságono",
    "hendecágonos": "hendecágono",
    "hendecândrias": "hendecândria",
    "hendriacontaedros": "hendriacontaedro",
    "hendriacontágonos": "hendriacontágono",
    "henequéns": "henequém",
    "henoteísmos": "henoteísmo",
    "henriquina": "henriquino",
    "henriquinas": "henriquino",
    "henriquinos": "henriquino",
    "henrys": "henry",
    "heortonímias": "heortonímia",
    "heortónimos": "heortónimo",
    "hepatais": "hepatal",
    "hepatargias": "hepatargia",
    "hepatites": "hepatite",
    "hepatiza": "hepatizar",
    "hepatizada": "hepatizar",
    "hepatizadas": "hepatizar",
    "hepatizado": "hepatizar",
    "hepatizados": "hepatizar",
    "hepatizai": "hepatizar",
    "hepatizais": "hepatizar",
    "hepatizam": "hepatizar",
    "hepatizamo": "hepatizar",
    "hepatizamos": "hepatizar",
    "hepatizando": "hepatizar",
    "hepatizara": "hepatizar",
    "hepatizaram": "hepatizar",
    "hepatizaras": "hepatizar",
    "hepatizarde": "hepatizar",
    "hepatizardes": "hepatizar",
    "hepatizare": "hepatizar",
    "hepatizarei": "hepatizar",
    "hepatizareis": "hepatizar",
    "hepatizarem": "hepatizar",
    "hepatizaremos": "hepatizar",
    "hepatizares": "hepatizar",
    "hepatizaria": "hepatizar",
    "hepatizariam": "hepatizar",
    "hepatizarias": "hepatizar",
    "hepatizarmo": "hepatizar",
    "hepatizarmos": "hepatizar",
    "hepatizará": "hepatizar",
    "hepatizarás": "hepatizar",
    "hepatizarão": "hepatizar",
    "hepatizaríamos": "hepatizar",
    "hepatizaríeis": "hepatizar",
    "hepatizas": "hepatizar",
    "hepatizasse": "hepatizar",
    "hepatizassem": "hepatizar",
    "hepatizasses": "hepatizar",
    "hepatizaste": "hepatizar",
    "hepatizastes": "hepatizar",
    "hepatizava": "hepatizar",
    "hepatizavam": "hepatizar",
    "hepatizavas": "hepatizar",
    "hepatizações": "hepatização",
    "hepatize": "hepatizar",
    "hepatizei": "hepatizar",
    "hepatizeis": "hepatizar",
    "hepatizem": "hepatizar",
    "hepatizemo": "hepatizar",
    "hepatizemos": "hepatizar",
    "hepatizes": "hepatizar",
    "hepatizo": "hepatizar",
    "hepatizou": "hepatizar",
    "hepatizá": "hepatizar",
    "hepatizámo": "hepatizar",
    "hepatizámos": "hepatizar",
    "hepatizáramo": "hepatizar",
    "hepatizáramos": "hepatizar",
    "hepatizárei": "hepatizar",
    "hepatizáreis": "hepatizar",
    "hepatizásseis": "hepatizar",
    "hepatizássemos": "hepatizar",
    "hepatizávamo": "hepatizar",
    "hepatizávamos": "hepatizar",
    "hepatizávei": "hepatizar",
    "hepatizáveis": "hepatizar",
    "hepatoceles": "hepatocele",
    "hepatogastrites": "hepatogastrite",
    "hepatogástrica": "hepatogástrico",
    "hepatogástricas": "hepatogástrico",
    "hepatogástricos": "hepatogástrico",
    "hepatologias": "hepatologia",
    "hepatomegalias": "hepatomegalia",
    "hepatorragias": "hepatorragia",
    "hepatotomias": "hepatotomia",
    "hepatálgias": "hepatálgia",
    "hepatálgica": "hepatálgico",
    "hepatálgicas": "hepatálgico",
    "hepatálgicos": "hepatálgico",
    "heptacorda": "heptacordo",
    "heptacordas": "heptacordo",
    "heptacordos": "heptacordo",
    "heptacórdios": "heptacórdio",
    "heptadáctila": "heptadáctilo",
    "heptadáctilas": "heptadáctilo",
    "heptadáctilos": "heptadáctilo",
    "heptaedros": "heptaedro",
    "heptagonais": "heptagonal",
    "heptandra": "heptandro",
    "heptandras": "heptandro",
    "heptandrias": "heptandria",
    "heptandros": "heptandro",
    "heptanema": "heptanemo",
    "heptanemas": "heptanemo",
    "heptanemos": "heptanemo",
    "heptanos": "heptano",
    "heptapétala": "heptapétalo",
    "heptapétalas": "heptapétalo",
    "heptapétalos": "heptapétalo",
    "heptarcas": "heptarca",
    "heptarquias": "heptarquia",
    "heptassilábica": "heptassilábico",
    "heptassilábicas": "heptassilábico",
    "heptassilábicos": "heptassilábico",
    "heptassépala": "heptassépalo",
    "heptassépalas": "heptassépalo",
    "heptassépalos": "heptassépalo",
    "heptassílabos": "heptassílabo",
    "heptateucos": "heptateuco",
    "heptatlos": "heptatlo",
    "heptaédrica": "heptaédrico",
    "heptaédricas": "heptaédrico",
    "heptaédricos": "heptaédrico",
    "heptágona": "heptágono",
    "heptágonas": "heptágono",
    "heptágonos": "heptágono",
    "heptárquica": "heptárquico",
    "heptárquicas": "heptárquico",
    "heptárquicos": "heptárquico",
    "heptâmetros": "heptâmetro",
    "heptândrias": "heptândria",
    "hepática": "hepático",
    "hepáticas": "hepático",
    "hepáticos": "hepático",
    "heracleias": "heracleia",
    "heraclidas": "heraclida",
    "heraclitismos": "heraclitismo",
    "heraldistas": "heraldista",
    "heranças": "herança",
    "heras": "hera",
    "herbanária": "herbanário",
    "herbanárias": "herbanário",
    "herbanários": "herbanário",
    "herbicidas": "herbicida",
    "herbiformes": "herbiforme",
    "herbolária": "herbolário",
    "herbolárias": "herbolário",
    "herbolários": "herbolário",
    "herboristas": "herborista",
    "herboriza": "herborizar",
    "herborizada": "herborizar",
    "herborizadas": "herborizar",
    "herborizado": "herborizar",
    "herborizadora": "herborizador",
    "herborizadoras": "herborizador",
    "herborizadores": "herborizador",
    "herborizados": "herborizar",
    "herborizai": "herborizar",
    "herborizais": "herborizar",
    "herborizam": "herborizar",
    "herborizamo": "herborizar",
    "herborizamos": "herborizar",
    "herborizando": "herborizar",
    "herborizantes": "herborizante",
    "herborizara": "herborizar",
    "herborizaram": "herborizar",
    "herborizaras": "herborizar",
    "herborizarde": "herborizar",
    "herborizardes": "herborizar",
    "herborizare": "herborizar",
    "herborizarei": "herborizar",
    "herborizareis": "herborizar",
    "herborizarem": "herborizar",
    "herborizaremos": "herborizar",
    "herborizares": "herborizar",
    "herborizaria": "herborizar",
    "herborizariam": "herborizar",
    "herborizarias": "herborizar",
    "herborizarmo": "herborizar",
    "herborizarmos": "herborizar",
    "herborizará": "herborizar",
    "herborizarás": "herborizar",
    "herborizarão": "herborizar",
    "herborizaríamos": "herborizar",
    "herborizaríeis": "herborizar",
    "herborizas": "herborizar",
    "herborizasse": "herborizar",
    "herborizassem": "herborizar",
    "herborizasses": "herborizar",
    "herborizaste": "herborizar",
    "herborizastes": "herborizar",
    "herborizava": "herborizar",
    "herborizavam": "herborizar",
    "herborizavas": "herborizar",
    "herborizações": "herborização",
    "herborize": "herborizar",
    "herborizei": "herborizar",
    "herborizeis": "herborizar",
    "herborizem": "herborizar",
    "herborizemo": "herborizar",
    "herborizemos": "herborizar",
    "herborizes": "herborizar",
    "herborizo": "herborizar",
    "herborizou": "herborizar",
    "herborizá": "herborizar",
    "herborizámo": "herborizar",
    "herborizámos": "herborizar",
    "herborizáramo": "herborizar",
    "herborizáramos": "herborizar",
    "herborizárei": "herborizar",
    "herborizáreis": "herborizar",
    "herborizásseis": "herborizar",
    "herborizássemos": "herborizar",
    "herborizávamo": "herborizar",
    "herborizávamos": "herborizar",
    "herborizávei": "herborizar",
    "herborizáveis": "herborizar",
    "herbosa": "herboso",
    "herbosas": "herboso",
    "herbosos": "herboso",
    "herbácea": "herbáceo",
    "herbáceas": "herbáceo",
    "herbáceos": "herbáceo",
    "herbários": "herbário",
    "herbática": "herbático",
    "herbáticas": "herbático",
    "herbáticos": "herbático",
    "herbícolas": "herbícola",
    "herbífera": "herbífero",
    "herbíferas": "herbífero",
    "herbíferos": "herbífero",
    "herbívora": "herbívoro",
    "herbívoras": "herbívoro",
    "herbívoros": "herbívoro",
    "herbórea": "herbóreo",
    "herbóreas": "herbóreo",
    "herbóreos": "herbóreo",
    "hercliteísmos": "hercliteísmo",
    "hercotectónicas": "hercotectónica",
    "herculana": "herculano",
    "herculanas": "herculano",
    "herculanos": "herculano",
    "hercínia": "hercínio",
    "hercínias": "hercínio",
    "hercínios": "hercínio",
    "hercúlea": "hercúleo",
    "hercúleas": "hercúleo",
    "hercúleos": "hercúleo",
    "herda": "herdar",
    "herdada": "herdar",
    "herdadas": "herdar",
    "herdades": "herdade",
    "herdado": "herdar",
    "herdados": "herdar",
    "herdai": "herdar",
    "herdais": "herdar",
    "herdam": "herdar",
    "herdamo": "herdar",
    "herdamos": "herdar",
    "herdando": "herdar",
    "herdanças": "herdança",
    "herdara": "herdar",
    "herdaram": "herdar",
    "herdaras": "herdar",
    "herdarde": "herdar",
    "herdardes": "herdar",
    "herdare": "herdar",
    "herdarei": "herdar",
    "herdareis": "herdar",
    "herdarem": "herdar",
    "herdaremos": "herdar",
    "herdares": "herdar",
    "herdaria": "herdar",
    "herdariam": "herdar",
    "herdarias": "herdar",
    "herdarmo": "herdar",
    "herdarmos": "herdar",
    "herdará": "herdar",
    "herdarás": "herdar",
    "herdarão": "herdar",
    "herdaríamos": "herdar",
    "herdaríeis": "herdar",
    "herdas": "herdar",
    "herdasse": "herdar",
    "herdassem": "herdar",
    "herdasses": "herdar",
    "herdaste": "herdar",
    "herdastes": "herdar",
    "herdava": "herdar",
    "herdavam": "herdar",
    "herdavas": "herdar",
    "herde": "herdar",
    "herdei": "herdar",
    "herdeira": "herdeiro",
    "herdeiras": "herdeiro",
    "herdeiros": "herdeiro",
    "herdeis": "herdar",
    "herdem": "herdar",
    "herdemo": "herdar",
    "herdemos": "herdar",
    "herdes": "herdar",
    "herdo": "herdar",
    "herdou": "herdar",
    "herdá": "herdar",
    "herdámo": "herdar",
    "herdámos": "herdar",
    "herdáramo": "herdar",
    "herdáramos": "herdar",
    "herdárei": "herdar",
    "herdáreis": "herdar",
    "herdásseis": "herdar",
    "herdássemos": "herdar",
    "herdávamo": "herdar",
    "herdávamos": "herdar",
    "herdávei": "herdar",
    "herdáveis": "herdar",
    "hereditariedades": "hereditariedade",
    "hereditária": "hereditário",
    "hereditárias": "hereditário",
    "hereditários": "hereditário",
    "heredossífilítica": "heredossífilítico",
    "heredossífilíticas": "heredossífilítico",
    "heredossífilíticos": "heredossífilítico",
    "hereges": "herege",
    "heregezinha": "herege",
    "heregezinhas": "herege",
    "heregezinho": "herege",
    "heregezinhos": "herege",
    "heregezita": "herege",
    "heregezitas": "herege",
    "heregezito": "herege",
    "heregezitos": "herege",
    "heresiarcas": "heresiarca",
    "heresias": "heresia",
    "hereticidades": "hereticidade",
    "heris": "heril",
    "hermafrodita": "hermafrodito",
    "hermafroditas": "hermafrodito",
    "hermafroditismos": "hermafroditismo",
    "hermafroditos": "hermafrodito",
    "hermas": "herma",
    "hermeneutas": "hermeneuta",
    "hermenêutica": "hermenêutico",
    "hermenêuticas": "hermenêutico",
    "hermenêuticos": "hermenêutico",
    "hermesiana": "hermesiano",
    "hermesianas": "hermesiano",
    "hermesianismos": "hermesianismo",
    "hermesianos": "hermesiano",
    "hermetismos": "hermetismo",
    "hermetistas": "hermetista",
    "herminiazinha": "hermínio",
    "herminiazinhas": "hermínio",
    "herminiazita": "hermínio",
    "herminiazitas": "hermínio",
    "herminiozinho": "hermínio",
    "herminiozinhos": "hermínio",
    "herminiozito": "hermínio",
    "herminiozitos": "hermínio",
    "herminismos": "herminismo",
    "herministas": "herminista",
    "hermiticidades": "hermiticidade",
    "hermodáctilos": "hermodáctilo",
    "hermografias": "hermografia",
    "hermética": "hermético",
    "herméticas": "hermético",
    "herméticos": "hermético",
    "hermínia": "hermínio",
    "hermínias": "hermínio",
    "hermínios": "hermínio",
    "herniada": "herniado",
    "herniadas": "herniado",
    "herniados": "herniado",
    "herniais": "hernial",
    "herniosa": "hernioso",
    "herniosas": "hernioso",
    "herniosos": "hernioso",
    "herniária": "herniário",
    "herniárias": "herniário",
    "herniários": "herniário",
    "herodiana": "herodiano",
    "herodianas": "herodiano",
    "herodianos": "herodiano",
    "heroicidades": "heroicidade",
    "heroiciza": "heroicizar",
    "heroicizada": "heroicizar",
    "heroicizadas": "heroicizar",
    "heroicizado": "heroicizar",
    "heroicizados": "heroicizar",
    "heroicizai": "heroicizar",
    "heroicizais": "heroicizar",
    "heroicizam": "heroicizar",
    "heroicizamo": "heroicizar",
    "heroicizamos": "heroicizar",
    "heroicizando": "heroicizar",
    "heroicizara": "heroicizar",
    "heroicizaram": "heroicizar",
    "heroicizaras": "heroicizar",
    "heroicizarde": "heroicizar",
    "heroicizardes": "heroicizar",
    "heroicizare": "heroicizar",
    "heroicizarei": "heroicizar",
    "heroicizareis": "heroicizar",
    "heroicizarem": "heroicizar",
    "heroicizaremos": "heroicizar",
    "heroicizares": "heroicizar",
    "heroicizaria": "heroicizar",
    "heroicizariam": "heroicizar",
    "heroicizarias": "heroicizar",
    "heroicizarmo": "heroicizar",
    "heroicizarmos": "heroicizar",
    "heroicizará": "heroicizar",
    "heroicizarás": "heroicizar",
    "heroicizarão": "heroicizar",
    "heroicizaríamos": "heroicizar",
    "heroicizaríeis": "heroicizar",
    "heroicizas": "heroicizar",
    "heroicizasse": "heroicizar",
    "heroicizassem": "heroicizar",
    "heroicizasses": "heroicizar",
    "heroicizaste": "heroicizar",
    "heroicizastes": "heroicizar",
    "heroicizava": "heroicizar",
    "heroicizavam": "heroicizar",
    "heroicizavas": "heroicizar",
    "heroicize": "heroicizar",
    "heroicizei": "heroicizar",
    "heroicizeis": "heroicizar",
    "heroicizem": "heroicizar",
    "heroicizemo": "heroicizar",
    "heroicizemos": "heroicizar",
    "heroicizes": "heroicizar",
    "heroicizo": "heroicizar",
    "heroicizou": "heroicizar",
    "heroicizá": "heroicizar",
    "heroicizámo": "heroicizar",
    "heroicizámos": "heroicizar",
    "heroicizáramo": "heroicizar",
    "heroicizáramos": "heroicizar",
    "heroicizárei": "heroicizar",
    "heroicizáreis": "heroicizar",
    "heroicizásseis": "heroicizar",
    "heroicizássemos": "heroicizar",
    "heroicizávamo": "heroicizar",
    "heroicizávamos": "heroicizar",
    "heroicizávei": "heroicizar",
    "heroicizáveis": "heroicizar",
    "heroifica": "heroificar",
    "heroificada": "heroificar",
    "heroificadas": "heroificar",
    "heroificado": "heroificar",
    "heroificados": "heroificar",
    "heroificai": "heroificar",
    "heroificais": "heroificar",
    "heroificam": "heroificar",
    "heroificamo": "heroificar",
    "heroificamos": "heroificar",
    "heroificando": "heroificar",
    "heroificara": "heroificar",
    "heroificaram": "heroificar",
    "heroificaras": "heroificar",
    "heroificarde": "heroificar",
    "heroificardes": "heroificar",
    "heroificare": "heroificar",
    "heroificarei": "heroificar",
    "heroificareis": "heroificar",
    "heroificarem": "heroificar",
    "heroificaremos": "heroificar",
    "heroificares": "heroificar",
    "heroificaria": "heroificar",
    "heroificariam": "heroificar",
    "heroificarias": "heroificar",
    "heroificarmo": "heroificar",
    "heroificarmos": "heroificar",
    "heroificará": "heroificar",
    "heroificarás": "heroificar",
    "heroificarão": "heroificar",
    "heroificaríamos": "heroificar",
    "heroificaríeis": "heroificar",
    "heroificas": "heroificar",
    "heroificasse": "heroificar",
    "heroificassem": "heroificar",
    "heroificasses": "heroificar",
    "heroificaste": "heroificar",
    "heroificastes": "heroificar",
    "heroificava": "heroificar",
    "heroificavam": "heroificar",
    "heroificavas": "heroificar",
    "heroifico": "heroificar",
    "heroificou": "heroificar",
    "heroificá": "heroificar",
    "heroificámo": "heroificar",
    "heroificámos": "heroificar",
    "heroificáramo": "heroificar",
    "heroificáramos": "heroificar",
    "heroificárei": "heroificar",
    "heroificáreis": "heroificar",
    "heroificásseis": "heroificar",
    "heroificássemos": "heroificar",
    "heroificávamo": "heroificar",
    "heroificávamos": "heroificar",
    "heroificávei": "heroificar",
    "heroificáveis": "heroificar",
    "heroifique": "heroificar",
    "heroifiquei": "heroificar",
    "heroifiqueis": "heroificar",
    "heroifiquem": "heroificar",
    "heroifiquemo": "heroificar",
    "heroifiquemos": "heroificar",
    "heroifiques": "heroificar",
    "heroinomanias": "heroinomania",
    "heroinómana": "heroinómano",
    "heroinómanas": "heroinómano",
    "heroinómanos": "heroinómano",
    "heroína": "herói",
    "heroínas": "heroína",
    "heroísmos": "heroísmo",
    "herpetismos": "herpetismo",
    "herpética": "herpético",
    "herpéticas": "herpético",
    "herpéticos": "herpético",
    "hertzes": "hertz",
    "hertziana": "hertziano",
    "hertzianas": "hertziano",
    "hertzianos": "hertziano",
    "heráldica": "heráldico",
    "heráldicas": "heráldico",
    "heráldicos": "heráldico",
    "herética": "herético",
    "heréticas": "herético",
    "heréticos": "herético",
    "herífugas": "herífuga",
    "heróica": "heróico",
    "heróicas": "heróico",
    "heróicos": "heróico",
    "heróides": "heróide",
    "heróis": "herói",
    "hesita": "hesitar",
    "hesitada": "hesitar",
    "hesitadas": "hesitar",
    "hesitado": "hesitar",
    "hesitados": "hesitar",
    "hesitai": "hesitar",
    "hesitais": "hesitar",
    "hesitam": "hesitar",
    "hesitamo": "hesitar",
    "hesitamos": "hesitar",
    "hesitando": "hesitar",
    "hesitantes": "hesitante",
    "hesitara": "hesitar",
    "hesitaram": "hesitar",
    "hesitaras": "hesitar",
    "hesitardes": "hesitar",
    "hesitarei": "hesitar",
    "hesitareis": "hesitar",
    "hesitarem": "hesitar",
    "hesitaremos": "hesitar",
    "hesitares": "hesitar",
    "hesitaria": "hesitar",
    "hesitariam": "hesitar",
    "hesitarias": "hesitar",
    "hesitarmo": "hesitar",
    "hesitarmos": "hesitar",
    "hesitará": "hesitar",
    "hesitarás": "hesitar",
    "hesitarão": "hesitar",
    "hesitaríamos": "hesitar",
    "hesitaríeis": "hesitar",
    "hesitas": "hesitar",
    "hesitasse": "hesitar",
    "hesitassem": "hesitar",
    "hesitasses": "hesitar",
    "hesitaste": "hesitar",
    "hesitastes": "hesitar",
    "hesitava": "hesitar",
    "hesitavam": "hesitar",
    "hesitavas": "hesitar",
    "hesitações": "hesitação",
    "hesite": "hesitar",
    "hesitei": "hesitar",
    "hesiteis": "hesitar",
    "hesitem": "hesitar",
    "hesitemo": "hesitar",
    "hesitemos": "hesitar",
    "hesites": "hesitar",
    "hesito": "hesitar",
    "hesitou": "hesitar",
    "hesitámo": "hesitar",
    "hesitámos": "hesitar",
    "hesitáramo": "hesitar",
    "hesitáramos": "hesitar",
    "hesitáreis": "hesitar",
    "hesitásseis": "hesitar",
    "hesitássemos": "hesitar",
    "hesitávamo": "hesitar",
    "hesitávamos": "hesitar",
    "hesitáveis": "hesitar",
    "hesiódica": "hesiódico",
    "hesiódicas": "hesiódico",
    "hesiódicos": "hesiódico",
    "hesperiídeos": "hesperiídeo",
    "hesperídea": "hesperídeo",
    "hesperídeas": "hesperídeo",
    "hesperídeos": "hesperídeo",
    "hesperídios": "hesperídio",
    "hesperíidas": "hesperíida",
    "hespéridas": "hespérida",
    "hessianos": "hessiano",
    "hesteres": "hester",
    "hesterna": "hesterno",
    "hesternas": "hesterno",
    "hesternos": "hesterno",
    "hetangianos": "hetangiano",
    "heteras": "hetera",
    "heteriarcas": "heteriarca",
    "heterias": "heteria",
    "heterinfecções": "heterinfecção",
    "heterismos": "heterismo",
    "heteristas": "heterista",
    "heterobrânquia": "heterobrânquio",
    "heterobrânquias": "heterobrânquio",
    "heterobrânquios": "heterobrânquio",
    "heterocarpa": "heterocarpo",
    "heterocarpas": "heterocarpo",
    "heterocarpos": "heterocarpo",
    "heteroceca": "heteroceco",
    "heterocecas": "heteroceco",
    "heterocecos": "heteroceco",
    "heterocistos": "heterocisto",
    "heterocromatinas": "heterocromatina",
    "heterocromias": "heterocromia",
    "heterocromossomos": "heterocromossomo",
    "heterocronias": "heterocronia",
    "heterocíclica": "heterocíclico",
    "heterocíclicas": "heterocíclico",
    "heterocíclicos": "heterocíclico",
    "heteroderma": "heterodermo",
    "heterodermas": "heterodermo",
    "heterodermos": "heterodermo",
    "heterodinâmica": "heterodinâmico",
    "heterodinâmicas": "heterodinâmico",
    "heterodinâmicos": "heterodinâmico",
    "heterodontes": "heterodonte",
    "heterodoxa": "heterodoxo",
    "heterodoxas": "heterodoxo",
    "heterodoxias": "heterodoxia",
    "heterodoxos": "heterodoxo",
    "heterodáctila": "heterodáctilo",
    "heterodáctilas": "heterodáctilo",
    "heterodáctilos": "heterodáctilo",
    "heterodésmica": "heterodésmico",
    "heterodésmicas": "heterodésmico",
    "heterodésmicos": "heterodésmico",
    "heteroerotismos": "heteroerotismo",
    "heterofila": "heterofilo",
    "heterofilas": "heterofilo",
    "heterofilias": "heterofilia",
    "heterofilos": "heterofilo",
    "heterofonias": "heterofonia",
    "heteroforias": "heteroforia",
    "heteroftalmias": "heteroftalmia",
    "heterofónica": "heterofónico",
    "heterofónicas": "heterofónico",
    "heterofónicos": "heterofónico",
    "heterogamias": "heterogamia",
    "heterogeneidades": "heterogeneidade",
    "heterogenesias": "heterogenesia",
    "heterogenias": "heterogenia",
    "heterogina": "heterogino",
    "heteroginas": "heterogino",
    "heteroginos": "heterogino",
    "heterogonias": "heterogonia",
    "heterogradias": "heterogradia",
    "heterogâmica": "heterogâmico",
    "heterogâmicas": "heterogâmico",
    "heterogâmicos": "heterogâmico",
    "heterogénea": "heterogéneo",
    "heterogéneas": "heterogéneo",
    "heterogéneos": "heterogéneo",
    "heterogéneses": "heterogénese",
    "heteroinfecções": "heteroinfecção",
    "heterologias": "heterologia",
    "heteromaquias": "heteromaquia",
    "heteromorfa": "heteromorfo",
    "heteromorfas": "heteromorfo",
    "heteromorfias": "heteromorfia",
    "heteromorfismos": "heteromorfismo",
    "heteromorfos": "heteromorfo",
    "heteromórfica": "heteromórfico",
    "heteromórficas": "heteromórfico",
    "heteromórficos": "heteromórfico",
    "heteronomias": "heteronomia",
    "heteronucleares": "heteronuclear",
    "heteronímias": "heteronímia",
    "heteronómica": "heteronómico",
    "heteronómicas": "heteronómico",
    "heteronómicos": "heteronómico",
    "heteropatias": "heteropatia",
    "heteroplasias": "heteroplasia",
    "heteroplasmas": "heteroplasma",
    "heteroplastias": "heteroplastia",
    "heteropoemas": "heteropoema",
    "heteropolares": "heteropolar",
    "heteropétala": "heteropétalo",
    "heteropétalas": "heteropétalo",
    "heteropétalos": "heteropétalo",
    "heteroscopias": "heteroscopia",
    "heteroses": "heterose",
    "heterospórea": "heterospóreo",
    "heterospóreas": "heterospóreo",
    "heterospóreos": "heterospóreo",
    "heterospórica": "heterospórico",
    "heterospóricas": "heterospórico",
    "heterospóricos": "heterospórico",
    "heterossexuais": "heterossexual",
    "heterossexualidades": "heterossexualidade",
    "heterotalismos": "heterotalismo",
    "heterotaxias": "heterotaxia",
    "heterotipias": "heterotipia",
    "heterotropias": "heterotropia",
    "heterotálica": "heterotálico",
    "heterotálicas": "heterotálico",
    "heterotálicos": "heterotálico",
    "heterotérmica": "heterotérmico",
    "heterotérmicas": "heterotérmico",
    "heterotérmicos": "heterotérmico",
    "heterotética": "heterotético",
    "heterotéticas": "heterotético",
    "heterotéticos": "heterotético",
    "heterotípica": "heterotípico",
    "heterotípicas": "heterotípico",
    "heterotípicos": "heterotípico",
    "heteroxias": "heteroxia",
    "heterozigotos": "heterozigoto",
    "heterozigótica": "heterozigótico",
    "heterozigóticas": "heterozigótico",
    "heterozigóticos": "heterozigótico",
    "heterozoários": "heterozoário",
    "heteróceros": "heterócero",
    "heteróclises": "heteróclise",
    "heteróclita": "heteróclito",
    "heteróclitas": "heteróclito",
    "heteróclitos": "heteróclito",
    "heteródina": "heteródino",
    "heteródinas": "heteródino",
    "heteródinos": "heteródino",
    "heterófonos": "heterófono",
    "heterógama": "heterógamo",
    "heterógamas": "heterógamo",
    "heterógamos": "heterógamo",
    "heterógona": "heterógono",
    "heterógonas": "heterógono",
    "heterógonos": "heterógono",
    "heterónima": "heterónimo",
    "heterónimas": "heterónimo",
    "heterónimos": "heterónimo",
    "heterópica": "heterópico",
    "heterópicas": "heterópico",
    "heterópicos": "heterópico",
    "heterópodes": "heterópode",
    "heteróptera": "heteróptero",
    "heterópteras": "heteróptero",
    "heterópteros": "heteróptero",
    "heteróscios": "heteróscio",
    "heterósidos": "heterósido",
    "heterótipa": "heterótipo",
    "heterótipas": "heterótipo",
    "heterótipos": "heterótipo",
    "heterótrica": "heterótrico",
    "heterótricas": "heterótrico",
    "heterótricos": "heterótrico",
    "heteus": "heteu",
    "heuremas": "heurema",
    "heuremáticas": "heuremática",
    "heurética": "heurético",
    "heuréticas": "heurético",
    "heuréticos": "heurético",
    "heurística": "heurístico",
    "heurísticas": "heurístico",
    "heurísticos": "heurístico",
    "heus": "heu",
    "hexacontaedros": "hexacontaedro",
    "hexacontágonos": "hexacontágono",
    "hexacoraliária": "hexacoraliário",
    "hexacoraliárias": "hexacoraliário",
    "hexacoraliários": "hexacoraliário",
    "hexacordes": "hexacorde",
    "hexacordos": "hexacordo",
    "hexactinelídea": "hexactinelídeo",
    "hexactinelídeas": "hexactinelídeo",
    "hexactinelídeos": "hexactinelídeo",
    "hexadactilias": "hexadactilia",
    "hexadecaedros": "hexadecaedro",
    "hexadecimais": "hexadecimal",
    "hexadecágonos": "hexadecágono",
    "hexadáctila": "hexadáctilo",
    "hexadáctilas": "hexadáctilo",
    "hexadáctilos": "hexadáctilo",
    "hexaedros": "hexaedro",
    "hexafila": "hexafilo",
    "hexafilas": "hexafilo",
    "hexafilos": "hexafilo",
    "hexagonais": "hexagonal",
    "hexagramas": "hexagrama",
    "hexandra": "hexandro",
    "hexandras": "hexandro",
    "hexandrias": "hexandria",
    "hexandros": "hexandro",
    "hexanos": "hexano",
    "hexantérea": "hexantéreo",
    "hexantéreas": "hexantéreo",
    "hexantéreos": "hexantéreo",
    "hexaoctaedros": "hexaoctaedro",
    "hexapétala": "hexapétalo",
    "hexapétalas": "hexapétalo",
    "hexapétalos": "hexapétalo",
    "hexasperma": "hexaspermo",
    "hexaspermas": "hexaspermo",
    "hexaspermos": "hexaspermo",
    "hexassilábica": "hexassilábico",
    "hexassilábicas": "hexassilábico",
    "hexassilábicos": "hexassilábico",
    "hexassépala": "hexassépalo",
    "hexassépalas": "hexassépalo",
    "hexassépalos": "hexassépalo",
    "hexassílabos": "hexassílabo",
    "hexastilos": "hexastilo",
    "hexastémones": "hexastémone",
    "hexaédrica": "hexaédrico",
    "hexaédricas": "hexaédrico",
    "hexaédricos": "hexaédrico",
    "hexis": "hexil",
    "hexoses": "hexose",
    "hexáforos": "hexáforo",
    "hexágina": "hexágino",
    "hexáginas": "hexágino",
    "hexáginos": "hexágino",
    "hexágonos": "hexágono",
    "hexápodes": "hexápode",
    "hexáptera": "hexáptero",
    "hexápteras": "hexáptero",
    "hexápteros": "hexáptero",
    "hexástica": "hexástico",
    "hexásticas": "hexástico",
    "hexásticos": "hexástico",
    "hexâmetra": "hexâmetro",
    "hexâmetras": "hexâmetro",
    "hexâmetros": "hexâmetro",
    "hexândrias": "hexândria",
    "hexógenos": "hexógeno",
    "hh": "h",
    "hiacintina": "hiacintino",
    "hiacintinas": "hiacintino",
    "hiacintinos": "hiacintino",
    "hiacintos": "hiacinto",
    "hiais": "hial",
    "hialina": "hialino",
    "hialinas": "hialino",
    "hialinos": "hialino",
    "hialites": "hialite",
    "hialografias": "hialografia",
    "hialoidites": "hialoidite",
    "hialoplasmas": "hialoplasma",
    "hialotecnias": "hialotecnia",
    "hialotécnica": "hialotécnico",
    "hialotécnicas": "hialotécnico",
    "hialotécnicos": "hialotécnico",
    "hialurgias": "hialurgia",
    "hialógrafos": "hialógrafo",
    "hialóidea": "hialóideo",
    "hialóideas": "hialóideo",
    "hialóideos": "hialóideo",
    "hialóides": "hialóide",
    "hialúrgica": "hialúrgico",
    "hialúrgicas": "hialúrgico",
    "hialúrgicos": "hialúrgico",
    "hiantes": "hiante",
    "hiatos": "hiato",
    "hiberna": "hiberno",
    "hibernada": "hibernar",
    "hibernadas": "hibernar",
    "hibernado": "hibernar",
    "hibernados": "hibernar",
    "hibernai": "hibernar",
    "hibernais": "hibernar",
    "hibernam": "hibernar",
    "hibernamo": "hibernar",
    "hibernamos": "hibernar",
    "hibernando": "hibernar",
    "hibernantes": "hibernante",
    "hibernara": "hibernar",
    "hibernaram": "hibernar",
    "hibernaras": "hibernar",
    "hibernarde": "hibernar",
    "hibernardes": "hibernar",
    "hibernare": "hibernar",
    "hibernarei": "hibernar",
    "hibernareis": "hibernar",
    "hibernarem": "hibernar",
    "hibernaremos": "hibernar",
    "hibernares": "hibernar",
    "hibernaria": "hibernar",
    "hibernariam": "hibernar",
    "hibernarias": "hibernar",
    "hibernarmo": "hibernar",
    "hibernarmos": "hibernar",
    "hibernará": "hibernar",
    "hibernarás": "hibernar",
    "hibernarão": "hibernar",
    "hibernaríamos": "hibernar",
    "hibernaríeis": "hibernar",
    "hibernas": "hiberno",
    "hibernasse": "hibernar",
    "hibernassem": "hibernar",
    "hibernasses": "hibernar",
    "hibernaste": "hibernar",
    "hibernastes": "hibernar",
    "hibernava": "hibernar",
    "hibernavam": "hibernar",
    "hibernavas": "hibernar",
    "hibernações": "hibernação",
    "hiberne": "hibernar",
    "hibernei": "hibernar",
    "hiberneis": "hibernar",
    "hibernem": "hibernar",
    "hibernemo": "hibernar",
    "hibernemos": "hibernar",
    "hibernes": "hibernar",
    "hiberno": "hibernar",
    "hibernos": "hiberno",
    "hibernoterapias": "hibernoterapia",
    "hibernou": "hibernar",
    "hiberná": "hibernar",
    "hibernáculos": "hibernáculo",
    "hibernámo": "hibernar",
    "hibernámos": "hibernar",
    "hibernáramo": "hibernar",
    "hibernáramos": "hibernar",
    "hibernárei": "hibernar",
    "hibernáreis": "hibernar",
    "hibernásseis": "hibernar",
    "hibernássemos": "hibernar",
    "hibernávamo": "hibernar",
    "hibernávamos": "hibernar",
    "hibernávei": "hibernar",
    "hibernáveis": "hibernar",
    "hibiscos": "hibisco",
    "hibrida": "hibridar",
    "hibridada": "hibridar",
    "hibridadas": "hibridar",
    "hibridades": "hibridade",
    "hibridado": "hibridar",
    "hibridados": "hibridar",
    "hibridai": "hibridar",
    "hibridais": "hibridar",
    "hibridam": "hibridar",
    "hibridamo": "hibridar",
    "hibridamos": "hibridar",
    "hibridando": "hibridar",
    "hibridara": "hibridar",
    "hibridaram": "hibridar",
    "hibridaras": "hibridar",
    "hibridarde": "hibridar",
    "hibridardes": "hibridar",
    "hibridare": "hibridar",
    "hibridarei": "hibridar",
    "hibridareis": "hibridar",
    "hibridarem": "hibridar",
    "hibridaremos": "hibridar",
    "hibridares": "hibridar",
    "hibridaria": "hibridar",
    "hibridariam": "hibridar",
    "hibridarias": "hibridar",
    "hibridarmo": "hibridar",
    "hibridarmos": "hibridar",
    "hibridará": "hibridar",
    "hibridarás": "hibridar",
    "hibridarão": "hibridar",
    "hibridaríamos": "hibridar",
    "hibridaríeis": "hibridar",
    "hibridas": "hibridar",
    "hibridasse": "hibridar",
    "hibridassem": "hibridar",
    "hibridasses": "hibridar",
    "hibridaste": "hibridar",
    "hibridastes": "hibridar",
    "hibridava": "hibridar",
    "hibridavam": "hibridar",
    "hibridavas": "hibridar",
    "hibridações": "hibridação",
    "hibride": "hibridar",
    "hibridei": "hibridar",
    "hibrideis": "hibridar",
    "hibridem": "hibridar",
    "hibridemo": "hibridar",
    "hibridemos": "hibridar",
    "hibrides": "hibridar",
    "hibridezes": "hibridez",
    "hibridismos": "hibridismo",
    "hibridistas": "hibridista",
    "hibrido": "hibridar",
    "hibridou": "hibridar",
    "hibridá": "hibridar",
    "hibridámo": "hibridar",
    "hibridámos": "hibridar",
    "hibridáramo": "hibridar",
    "hibridáramos": "hibridar",
    "hibridárei": "hibridar",
    "hibridáreis": "hibridar",
    "hibridásseis": "hibridar",
    "hibridássemos": "hibridar",
    "hibridávamo": "hibridar",
    "hibridávamos": "hibridar",
    "hibridávei": "hibridar",
    "hibridáveis": "hibridar",
    "hibérnica": "hibérnico",
    "hibérnicas": "hibérnico",
    "hibérnicos": "hibérnico",
    "hibérnios": "hibérnio",
    "hidatidoceles": "hidatidocele",
    "hidatidoses": "hidatidose",
    "hidatismos": "hidatismo",
    "hidatogénica": "hidatogénico",
    "hidatogénicas": "hidatogénico",
    "hidatogénicos": "hidatogénico",
    "hidatologias": "hidatologia",
    "hidatoscopias": "hidatoscopia",
    "hidatídica": "hidatídico",
    "hidatídicas": "hidatídico",
    "hidatídicos": "hidatídico",
    "hidatódios": "hidatódio",
    "hidradenites": "hidradenite",
    "hidraeroplanos": "hidraeroplano",
    "hidragoga": "hidragogo",
    "hidragogas": "hidragogo",
    "hidragogos": "hidragogo",
    "hidrangeáceas": "hidrangeácea",
    "hidranjas": "hidranja",
    "hidranoses": "hidranose",
    "hidrargilites": "hidrargilite",
    "hidrargirias": "hidrargiria",
    "hidrargirismos": "hidrargirismo",
    "hidrargiroses": "hidrargirose",
    "hidrargírica": "hidrargírico",
    "hidrargíricas": "hidrargírico",
    "hidrargíricos": "hidrargírico",
    "hidrargírios": "hidrargírio",
    "hidras": "hidra",
    "hidrastes": "hidraste",
    "hidrata": "hidratar",
    "hidratada": "hidratar",
    "hidratadas": "hidratar",
    "hidratado": "hidratar",
    "hidratadors": "hidratador",
    "hidratados": "hidratar",
    "hidratai": "hidratar",
    "hidratais": "hidratar",
    "hidratam": "hidratar",
    "hidratamo": "hidratar",
    "hidratamos": "hidratar",
    "hidratando": "hidratar",
    "hidratantes": "hidratante",
    "hidratara": "hidratar",
    "hidrataram": "hidratar",
    "hidrataras": "hidratar",
    "hidratarde": "hidratar",
    "hidratardes": "hidratar",
    "hidratare": "hidratar",
    "hidratarei": "hidratar",
    "hidratareis": "hidratar",
    "hidratarem": "hidratar",
    "hidrataremos": "hidratar",
    "hidratares": "hidratar",
    "hidrataria": "hidratar",
    "hidratariam": "hidratar",
    "hidratarias": "hidratar",
    "hidratarmo": "hidratar",
    "hidratarmos": "hidratar",
    "hidratará": "hidratar",
    "hidratarás": "hidratar",
    "hidratarão": "hidratar",
    "hidrataríamos": "hidratar",
    "hidrataríeis": "hidratar",
    "hidratas": "hidratar",
    "hidratasse": "hidratar",
    "hidratassem": "hidratar",
    "hidratasses": "hidratar",
    "hidrataste": "hidratar",
    "hidratastes": "hidratar",
    "hidratava": "hidratar",
    "hidratavam": "hidratar",
    "hidratavas": "hidratar",
    "hidratações": "hidratação",
    "hidrate": "hidratar",
    "hidratei": "hidratar",
    "hidrateis": "hidratar",
    "hidratem": "hidratar",
    "hidratemo": "hidratar",
    "hidratemos": "hidratar",
    "hidrates": "hidratar",
    "hidrato": "hidratar",
    "hidratos": "hidrato",
    "hidratou": "hidratar",
    "hidratá": "hidratar",
    "hidratámo": "hidratar",
    "hidratámos": "hidratar",
    "hidratáramo": "hidratar",
    "hidratáramos": "hidratar",
    "hidratárei": "hidratar",
    "hidratáreis": "hidratar",
    "hidratásseis": "hidratar",
    "hidratássemos": "hidratar",
    "hidratávamo": "hidratar",
    "hidratávamos": "hidratar",
    "hidratávei": "hidratar",
    "hidratáveis": "hidratável",
    "hidraucidades": "hidraucidade",
    "hidraulos": "hidraulo",
    "hidraviões": "hidravião",
    "hidrazinas": "hidrazina",
    "hidraérea": "hidraéreo",
    "hidraéreas": "hidraéreo",
    "hidraéreos": "hidraéreo",
    "hidreléctrica": "hidreléctrico",
    "hidreléctricas": "hidreléctrico",
    "hidreléctricos": "hidreléctrico",
    "hidremias": "hidremia",
    "hidretos": "hidreto",
    "hidriatrias": "hidriatria",
    "hidroaeroplanos": "hidroaeroplano",
    "hidroaviões": "hidroavião",
    "hidrocarbonatos": "hidrocarbonato",
    "hidrocarbonetos": "hidrocarboneto",
    "hidrocaridáceas": "hidrocaridácea",
    "hidrocaules": "hidrocaule",
    "hidrocefalias": "hidrocefalia",
    "hidroceles": "hidrocele",
    "hidrocistos": "hidrocisto",
    "hidrocoralinos": "hidrocoralino",
    "hidrocoraliária": "hidrocoraliário",
    "hidrocoraliárias": "hidrocoraliário",
    "hidrocoraliários": "hidrocoraliário",
    "hidrocéfala": "hidrocéfalo",
    "hidrocéfalas": "hidrocéfalo",
    "hidrocéfalos": "hidrocéfalo",
    "hidrocórias": "hidrocória",
    "hidrodinâmica": "hidrodinâmico",
    "hidrodinâmicas": "hidrodinâmico",
    "hidrodinâmicos": "hidrodinâmico",
    "hidroeléctrica": "hidroeléctrico",
    "hidroeléctricas": "hidroeléctrico",
    "hidroeléctricos": "hidroeléctrico",
    "hidroferas": "hidrofera",
    "hidrofiláceas": "hidrofilácea",
    "hidrofilídeos": "hidrofilídeo",
    "hidrofobias": "hidrofobia",
    "hidrofones": "hidrofone",
    "hidroformações": "hidroformação",
    "hidrofânios": "hidrofânio",
    "hidrofílica": "hidrofílico",
    "hidrofílicas": "hidrofílico",
    "hidrofílicos": "hidrofílico",
    "hidrofílidas": "hidrofílida",
    "hidrofóbica": "hidrofóbico",
    "hidrofóbicas": "hidrofóbico",
    "hidrofóbicos": "hidrofóbico",
    "hidrogena": "hidrogenar",
    "hidrogenada": "hidrogenar",
    "hidrogenadas": "hidrogenar",
    "hidrogenado": "hidrogenar",
    "hidrogenados": "hidrogenar",
    "hidrogenai": "hidrogenar",
    "hidrogenais": "hidrogenar",
    "hidrogenam": "hidrogenar",
    "hidrogenamo": "hidrogenar",
    "hidrogenamos": "hidrogenar",
    "hidrogenando": "hidrogenar",
    "hidrogenara": "hidrogenar",
    "hidrogenaram": "hidrogenar",
    "hidrogenaras": "hidrogenar",
    "hidrogenarde": "hidrogenar",
    "hidrogenardes": "hidrogenar",
    "hidrogenare": "hidrogenar",
    "hidrogenarei": "hidrogenar",
    "hidrogenareis": "hidrogenar",
    "hidrogenarem": "hidrogenar",
    "hidrogenaremos": "hidrogenar",
    "hidrogenares": "hidrogenar",
    "hidrogenaria": "hidrogenar",
    "hidrogenariam": "hidrogenar",
    "hidrogenarias": "hidrogenar",
    "hidrogenarmo": "hidrogenar",
    "hidrogenarmos": "hidrogenar",
    "hidrogenará": "hidrogenar",
    "hidrogenarás": "hidrogenar",
    "hidrogenarão": "hidrogenar",
    "hidrogenaríamos": "hidrogenar",
    "hidrogenaríeis": "hidrogenar",
    "hidrogenas": "hidrogenar",
    "hidrogenasse": "hidrogenar",
    "hidrogenassem": "hidrogenar",
    "hidrogenasses": "hidrogenar",
    "hidrogenaste": "hidrogenar",
    "hidrogenastes": "hidrogenar",
    "hidrogenava": "hidrogenar",
    "hidrogenavam": "hidrogenar",
    "hidrogenavas": "hidrogenar",
    "hidrogenações": "hidrogenação",
    "hidrogene": "hidrogenar",
    "hidrogenei": "hidrogenar",
    "hidrogeneis": "hidrogenar",
    "hidrogenem": "hidrogenar",
    "hidrogenemo": "hidrogenar",
    "hidrogenemos": "hidrogenar",
    "hidrogenes": "hidrogenar",
    "hidrogenias": "hidrogenia",
    "hidrogeniónica": "hidrogeniónico",
    "hidrogeniónicas": "hidrogeniónico",
    "hidrogeniónicos": "hidrogeniónico",
    "hidrogeniões": "hidrogenião",
    "hidrogeno": "hidrogenar",
    "hidrogenou": "hidrogenar",
    "hidrogená": "hidrogenar",
    "hidrogenámo": "hidrogenar",
    "hidrogenámos": "hidrogenar",
    "hidrogenáramo": "hidrogenar",
    "hidrogenáramos": "hidrogenar",
    "hidrogenárei": "hidrogenar",
    "hidrogenáreis": "hidrogenar",
    "hidrogenásseis": "hidrogenar",
    "hidrogenássemos": "hidrogenar",
    "hidrogenávamo": "hidrogenar",
    "hidrogenávamos": "hidrogenar",
    "hidrogenávei": "hidrogenar",
    "hidrogenáveis": "hidrogenável",
    "hidrogeologias": "hidrogeologia",
    "hidrogeologistas": "hidrogeologista",
    "hidrognomonias": "hidrognomonia",
    "hidrognosias": "hidrognosia",
    "hidrografias": "hidrografia",
    "hidrográfica": "hidrográfico",
    "hidrográficas": "hidrográfico",
    "hidrográficos": "hidrográfico",
    "hidrogéis": "hidrogel",
    "hidrogénios": "hidrogénio",
    "hidrolatos": "hidrolato",
    "hidrolatrias": "hidrolatria",
    "hidrologias": "hidrologia",
    "hidrológica": "hidrológico",
    "hidrológicas": "hidrológico",
    "hidrológicos": "hidrológico",
    "hidromancias": "hidromancia",
    "hidromanias": "hidromania",
    "hidromantes": "hidromante",
    "hidromassagens": "hidromassagem",
    "hidromassagistas": "hidromassagista",
    "hidromecânica": "hidromecânico",
    "hidromecânicas": "hidromecânico",
    "hidromecânicos": "hidromecânico",
    "hidromedusas": "hidromedusa",
    "hidrometalurgias": "hidrometalurgia",
    "hidrometeoros": "hidrometeoro",
    "hidrometrias": "hidrometria",
    "hidromicas": "hidromica",
    "hidrominerais": "hidromineral",
    "hidromotora": "hidromotor",
    "hidromotoras": "hidromotor",
    "hidromotores": "hidromotor",
    "hidromântica": "hidromântico",
    "hidromânticas": "hidromântico",
    "hidromânticos": "hidromântico",
    "hidroméis": "hidromel",
    "hidrométrica": "hidrométrico",
    "hidrométricas": "hidrométrico",
    "hidrométricos": "hidrométrico",
    "hidropatas": "hidropata",
    "hidropatias": "hidropatia",
    "hidropirética": "hidropirético",
    "hidropiréticas": "hidropirético",
    "hidropiréticos": "hidropirético",
    "hidropisias": "hidropisia",
    "hidropisinas": "hidropisina",
    "hidroplanadora": "hidroplanador",
    "hidroplanadoras": "hidroplanador",
    "hidroplanadores": "hidroplanador",
    "hidroplanos": "hidroplano",
    "hidroplasmas": "hidroplasma",
    "hidropneumática": "hidropneumático",
    "hidropneumáticas": "hidropneumático",
    "hidropneumáticos": "hidropneumático",
    "hidropírica": "hidropírico",
    "hidropíricas": "hidropírico",
    "hidropíricos": "hidropírico",
    "hidroquinonas": "hidroquinona",
    "hidroquistos": "hidroquisto",
    "hidrorragias": "hidrorragia",
    "hidrorreias": "hidrorreia",
    "hidros": "hidro",
    "hidroscopias": "hidroscopia",
    "hidroscópica": "hidroscópico",
    "hidroscópicas": "hidroscópico",
    "hidroscópicos": "hidroscópico",
    "hidroscópios": "hidroscópio",
    "hidroses": "hidrose",
    "hidrosferas": "hidrosfera",
    "hidrosférica": "hidrosférico",
    "hidrosféricas": "hidrosférico",
    "hidrosféricos": "hidrosférico",
    "hidrosseparadores": "hidrosseparador",
    "hidrossáurios": "hidrossáurio",
    "hidrossóis": "hidrossol",
    "hidrostática": "hidrostático",
    "hidrostáticas": "hidrostático",
    "hidrostáticos": "hidrostático",
    "hidrotactismos": "hidrotactismo",
    "hidrotecnias": "hidrotecnia",
    "hidroterapias": "hidroterapia",
    "hidrotermais": "hidrotermal",
    "hidroterápica": "hidroterápico",
    "hidroterápicas": "hidroterápico",
    "hidroterápicos": "hidroterápico",
    "hidrotimetrias": "hidrotimetria",
    "hidrotimétrica": "hidrotimétrico",
    "hidrotimétricas": "hidrotimétrico",
    "hidrotimétricos": "hidrotimétrico",
    "hidrotropismos": "hidrotropismo",
    "hidrotécnica": "hidrotécnico",
    "hidrotécnicas": "hidrotécnico",
    "hidrotécnicos": "hidrotécnico",
    "hidrotérmica": "hidrotérmico",
    "hidrotérmicas": "hidrotérmico",
    "hidrotérmicos": "hidrotérmico",
    "hidrotímetros": "hidrotímetro",
    "hidrotóraxes": "hidrotórax",
    "hidrovasculares": "hidrovascular",
    "hidroxiliões": "hidroxilião",
    "hidroxilos": "hidroxilo",
    "hidrozoária": "hidrozoário",
    "hidrozoárias": "hidrozoário",
    "hidrozoários": "hidrozoário",
    "hidrácidos": "hidrácido",
    "hidrática": "hidrático",
    "hidráticas": "hidrático",
    "hidráticos": "hidrático",
    "hidráulica": "hidráulico",
    "hidráulicas": "hidráulico",
    "hidráulicos": "hidráulico",
    "hidrângeas": "hidrângea",
    "hidróbia": "hidróbio",
    "hidróbias": "hidróbio",
    "hidróbios": "hidróbio",
    "hidróferos": "hidrófero",
    "hidrófila": "hidrófilo",
    "hidrófilas": "hidrófilo",
    "hidrófilos": "hidrófilo",
    "hidrófita": "hidrófito",
    "hidrófitas": "hidrófito",
    "hidrófitos": "hidrófito",
    "hidrófoba": "hidrófobo",
    "hidrófobas": "hidrófobo",
    "hidrófobos": "hidrófobo",
    "hidrófora": "hidróforo",
    "hidróforas": "hidróforo",
    "hidróforos": "hidróforo",
    "hidrófuga": "hidrófugo",
    "hidrófugas": "hidrófugo",
    "hidrófugos": "hidrófugo",
    "hidrógona": "hidrógono",
    "hidrógonas": "hidrógono",
    "hidrógonos": "hidrógono",
    "hidrógrafos": "hidrógrafo",
    "hidróides": "hidróide",
    "hidrólases": "hidrólase",
    "hidrólatras": "hidrólatra",
    "hidrólises": "hidrólise",
    "hidrólitos": "hidrólito",
    "hidróloga": "hidrólogo",
    "hidrólogas": "hidrólogo",
    "hidrólogos": "hidrólogo",
    "hidrómetros": "hidrómetro",
    "hidrónios": "hidrónio",
    "hidrópica": "hidrópico",
    "hidrópicas": "hidrópico",
    "hidrópicos": "hidrópico",
    "hidrópotas": "hidrópota",
    "hidróscopa": "hidróscopo",
    "hidróscopas": "hidróscopo",
    "hidróscopos": "hidróscopo",
    "hidróstatos": "hidróstato",
    "hidróxidos": "hidróxido",
    "hidrônfalos": "hidrônfalo",
    "hidrúrias": "hidrúria",
    "hidrúrica": "hidrúrico",
    "hidrúricas": "hidrúrico",
    "hidrúricos": "hidrúrico",
    "hidática": "hidático",
    "hidáticas": "hidático",
    "hidáticos": "hidático",
    "hidátides": "hidátide",
    "hidátodos": "hidátodo",
    "hiemais": "hiemal",
    "hiemações": "hiemação",
    "hienas": "hiena",
    "hienídeos": "hienídeo",
    "hieracites": "hieracite",
    "hieralgias": "hieralgia",
    "hieranoses": "hieranose",
    "hierarcas": "hierarca",
    "hierarquias": "hierarquia",
    "hierarquismos": "hierarquismo",
    "hierarquiza": "hierarquizar",
    "hierarquizada": "hierarquizar",
    "hierarquizadas": "hierarquizar",
    "hierarquizado": "hierarquizar",
    "hierarquizados": "hierarquizar",
    "hierarquizai": "hierarquizar",
    "hierarquizais": "hierarquizar",
    "hierarquizam": "hierarquizar",
    "hierarquizamo": "hierarquizar",
    "hierarquizamos": "hierarquizar",
    "hierarquizando": "hierarquizar",
    "hierarquizara": "hierarquizar",
    "hierarquizaram": "hierarquizar",
    "hierarquizaras": "hierarquizar",
    "hierarquizarde": "hierarquizar",
    "hierarquizardes": "hierarquizar",
    "hierarquizare": "hierarquizar",
    "hierarquizarei": "hierarquizar",
    "hierarquizareis": "hierarquizar",
    "hierarquizarem": "hierarquizar",
    "hierarquizaremos": "hierarquizar",
    "hierarquizares": "hierarquizar",
    "hierarquizaria": "hierarquizar",
    "hierarquizariam": "hierarquizar",
    "hierarquizarias": "hierarquizar",
    "hierarquizarmo": "hierarquizar",
    "hierarquizarmos": "hierarquizar",
    "hierarquizará": "hierarquizar",
    "hierarquizarás": "hierarquizar",
    "hierarquizarão": "hierarquizar",
    "hierarquizaríamos": "hierarquizar",
    "hierarquizaríeis": "hierarquizar",
    "hierarquizas": "hierarquizar",
    "hierarquizasse": "hierarquizar",
    "hierarquizassem": "hierarquizar",
    "hierarquizasses": "hierarquizar",
    "hierarquizaste": "hierarquizar",
    "hierarquizastes": "hierarquizar",
    "hierarquizava": "hierarquizar",
    "hierarquizavam": "hierarquizar",
    "hierarquizavas": "hierarquizar",
    "hierarquizações": "hierarquização",
    "hierarquize": "hierarquizar",
    "hierarquizei": "hierarquizar",
    "hierarquizeis": "hierarquizar",
    "hierarquizem": "hierarquizar",
    "hierarquizemo": "hierarquizar",
    "hierarquizemos": "hierarquizar",
    "hierarquizes": "hierarquizar",
    "hierarquizo": "hierarquizar",
    "hierarquizou": "hierarquizar",
    "hierarquizá": "hierarquizar",
    "hierarquizámo": "hierarquizar",
    "hierarquizámos": "hierarquizar",
    "hierarquizáramo": "hierarquizar",
    "hierarquizáramos": "hierarquizar",
    "hierarquizárei": "hierarquizar",
    "hierarquizáreis": "hierarquizar",
    "hierarquizásseis": "hierarquizar",
    "hierarquizássemos": "hierarquizar",
    "hierarquizávamo": "hierarquizar",
    "hierarquizávamos": "hierarquizar",
    "hierarquizávei": "hierarquizar",
    "hierarquizáveis": "hierarquizável",
    "hieratismos": "hieratismo",
    "hierocracias": "hierocracia",
    "hierodramas": "hierodrama",
    "hierodula": "hierodulo",
    "hierodulas": "hierodulo",
    "hierodulos": "hierodulo",
    "hierofantas": "hierofanta",
    "hierofantes": "hierofante",
    "hierofântides": "hierofântide",
    "hierogeografias": "hierogeografia",
    "hieroglífica": "hieroglífico",
    "hieroglíficas": "hieroglífico",
    "hieroglíficos": "hieroglífico",
    "hierografias": "hierografia",
    "hierogramas": "hierograma",
    "hierogramatistas": "hierogramatista",
    "hierogramática": "hierogramático",
    "hierogramáticas": "hierogramático",
    "hierogramáticos": "hierogramático",
    "hierologias": "hierologia",
    "hierológica": "hierológico",
    "hierológicas": "hierológico",
    "hierológicos": "hierológico",
    "hieromancias": "hieromancia",
    "hieromantes": "hieromante",
    "hieromaníaca": "hieromaníaco",
    "hieromaníacas": "hieromaníaco",
    "hieromaníacos": "hieromaníaco",
    "hieromântica": "hieromântico",
    "hieromânticas": "hieromântico",
    "hieromânticos": "hieromântico",
    "hieronimistas": "hieronimista",
    "hieronímias": "hieronímia",
    "hieronímica": "hieronímico",
    "hieronímicas": "hieronímico",
    "hieronímicos": "hieronímico",
    "hieroscopias": "hieroscopia",
    "hierosolimitana": "hierosolimitano",
    "hierosolimitanas": "hierosolimitano",
    "hierosolimitanos": "hierosolimitano",
    "hierosolimitas": "hierosolimita",
    "hieroterapias": "hieroterapia",
    "hierácios": "hierácio",
    "hierárquica": "hierárquico",
    "hierárquicas": "hierárquico",
    "hierárquicos": "hierárquico",
    "hierática": "hierático",
    "hieráticas": "hierático",
    "hieráticos": "hierático",
    "hieróglifos": "hieróglifo",
    "hieróloga": "hierólogo",
    "hierólogas": "hierólogo",
    "hierólogos": "hierólogo",
    "hierónimos": "hierónimo",
    "hietómetros": "hietómetro",
    "hifas": "hifa",
    "hifemas": "hifema",
    "hifeniza": "hifenizar",
    "hifenizada": "hifenizar",
    "hifenizadas": "hifenizar",
    "hifenizado": "hifenizar",
    "hifenizados": "hifenizar",
    "hifenizai": "hifenizar",
    "hifenizais": "hifenizar",
    "hifenizam": "hifenizar",
    "hifenizamo": "hifenizar",
    "hifenizamos": "hifenizar",
    "hifenizando": "hifenizar",
    "hifenizara": "hifenizar",
    "hifenizaram": "hifenizar",
    "hifenizaras": "hifenizar",
    "hifenizarde": "hifenizar",
    "hifenizardes": "hifenizar",
    "hifenizare": "hifenizar",
    "hifenizarei": "hifenizar",
    "hifenizareis": "hifenizar",
    "hifenizarem": "hifenizar",
    "hifenizaremos": "hifenizar",
    "hifenizares": "hifenizar",
    "hifenizaria": "hifenizar",
    "hifenizariam": "hifenizar",
    "hifenizarias": "hifenizar",
    "hifenizarmo": "hifenizar",
    "hifenizarmos": "hifenizar",
    "hifenizará": "hifenizar",
    "hifenizarás": "hifenizar",
    "hifenizarão": "hifenizar",
    "hifenizaríamos": "hifenizar",
    "hifenizaríeis": "hifenizar",
    "hifenizas": "hifenizar",
    "hifenizasse": "hifenizar",
    "hifenizassem": "hifenizar",
    "hifenizasses": "hifenizar",
    "hifenizaste": "hifenizar",
    "hifenizastes": "hifenizar",
    "hifenizava": "hifenizar",
    "hifenizavam": "hifenizar",
    "hifenizavas": "hifenizar",
    "hifenizações": "hifenização",
    "hifenize": "hifenizar",
    "hifenizei": "hifenizar",
    "hifenizeis": "hifenizar",
    "hifenizem": "hifenizar",
    "hifenizemo": "hifenizar",
    "hifenizemos": "hifenizar",
    "hifenizes": "hifenizar",
    "hifenizo": "hifenizar",
    "hifenizou": "hifenizar",
    "hifenizá": "hifenizar",
    "hifenizámo": "hifenizar",
    "hifenizámos": "hifenizar",
    "hifenizáramo": "hifenizar",
    "hifenizáramos": "hifenizar",
    "hifenizárei": "hifenizar",
    "hifenizáreis": "hifenizar",
    "hifenizásseis": "hifenizar",
    "hifenizássemos": "hifenizar",
    "hifenizávamo": "hifenizar",
    "hifenizávamos": "hifenizar",
    "hifenizávei": "hifenizar",
    "hifenizáveis": "hifenizável",
    "hiféreses": "hiférese",
    "hifênquimas": "hifênquima",
    "higidezes": "higidez",
    "higienes": "higiene",
    "higienistas": "higienista",
    "higieniza": "higienizar",
    "higienizada": "higienizar",
    "higienizadas": "higienizar",
    "higienizado": "higienizar",
    "higienizados": "higienizar",
    "higienizai": "higienizar",
    "higienizais": "higienizar",
    "higienizam": "higienizar",
    "higienizamo": "higienizar",
    "higienizamos": "higienizar",
    "higienizando": "higienizar",
    "higienizara": "higienizar",
    "higienizaram": "higienizar",
    "higienizaras": "higienizar",
    "higienizarde": "higienizar",
    "higienizardes": "higienizar",
    "higienizare": "higienizar",
    "higienizarei": "higienizar",
    "higienizareis": "higienizar",
    "higienizarem": "higienizar",
    "higienizaremos": "higienizar",
    "higienizares": "higienizar",
    "higienizaria": "higienizar",
    "higienizariam": "higienizar",
    "higienizarias": "higienizar",
    "higienizarmo": "higienizar",
    "higienizarmos": "higienizar",
    "higienizará": "higienizar",
    "higienizarás": "higienizar",
    "higienizarão": "higienizar",
    "higienizaríamos": "higienizar",
    "higienizaríeis": "higienizar",
    "higienizas": "higienizar",
    "higienizasse": "higienizar",
    "higienizassem": "higienizar",
    "higienizasses": "higienizar",
    "higienizaste": "higienizar",
    "higienizastes": "higienizar",
    "higienizava": "higienizar",
    "higienizavam": "higienizar",
    "higienizavas": "higienizar",
    "higienize": "higienizar",
    "higienizei": "higienizar",
    "higienizeis": "higienizar",
    "higienizem": "higienizar",
    "higienizemo": "higienizar",
    "higienizemos": "higienizar",
    "higienizes": "higienizar",
    "higienizo": "higienizar",
    "higienizou": "higienizar",
    "higienizá": "higienizar",
    "higienizámo": "higienizar",
    "higienizámos": "higienizar",
    "higienizáramo": "higienizar",
    "higienizáramos": "higienizar",
    "higienizárei": "higienizar",
    "higienizáreis": "higienizar",
    "higienizásseis": "higienizar",
    "higienizássemos": "higienizar",
    "higienizávamo": "higienizar",
    "higienizávamos": "higienizar",
    "higienizávei": "higienizar",
    "higienizáveis": "higienizar",
    "higiologias": "higiologia",
    "higioterapias": "higioterapia",
    "higiénica": "higiénico",
    "higiénicas": "higiénico",
    "higiénicos": "higiénico",
    "higrofilias": "higrofilia",
    "higrofilismos": "higrofilismo",
    "higrofobias": "higrofobia",
    "higrologias": "higrologia",
    "higrológica": "higrológico",
    "higrológicas": "higrológico",
    "higrológicos": "higrológico",
    "higromas": "higroma",
    "higrometrias": "higrometria",
    "higrometricidades": "higrometricidade",
    "higrométrica": "higrométrico",
    "higrométricas": "higrométrico",
    "higrométricos": "higrométrico",
    "higroscopias": "higroscopia",
    "higroscopicidades": "higroscopicidade",
    "higroscópica": "higroscópico",
    "higroscópicas": "higroscópico",
    "higroscópicos": "higroscópico",
    "higroscópios": "higroscópio",
    "higrotropismos": "higrotropismo",
    "higróbia": "higróbio",
    "higróbias": "higróbio",
    "higróbios": "higróbio",
    "higrófila": "higrófilo",
    "higrófilas": "higrófilo",
    "higrófilos": "higrófilo",
    "higrófita": "higrófito",
    "higrófitas": "higrófito",
    "higrófitos": "higrófito",
    "higrófoba": "higrófobo",
    "higrófobas": "higrófobo",
    "higrófobos": "higrófobo",
    "higrógrafos": "higrógrafo",
    "higrómetros": "higrómetro",
    "hilares": "hilar",
    "hilariantes": "hilariante",
    "hilaridades": "hilaridade",
    "hilariza": "hilarizar",
    "hilarizada": "hilarizar",
    "hilarizadas": "hilarizar",
    "hilarizado": "hilarizar",
    "hilarizados": "hilarizar",
    "hilarizai": "hilarizar",
    "hilarizais": "hilarizar",
    "hilarizam": "hilarizar",
    "hilarizamo": "hilarizar",
    "hilarizamos": "hilarizar",
    "hilarizando": "hilarizar",
    "hilarizara": "hilarizar",
    "hilarizaram": "hilarizar",
    "hilarizaras": "hilarizar",
    "hilarizarde": "hilarizar",
    "hilarizardes": "hilarizar",
    "hilarizare": "hilarizar",
    "hilarizarei": "hilarizar",
    "hilarizareis": "hilarizar",
    "hilarizarem": "hilarizar",
    "hilarizaremos": "hilarizar",
    "hilarizares": "hilarizar",
    "hilarizaria": "hilarizar",
    "hilarizariam": "hilarizar",
    "hilarizarias": "hilarizar",
    "hilarizarmo": "hilarizar",
    "hilarizarmos": "hilarizar",
    "hilarizará": "hilarizar",
    "hilarizarás": "hilarizar",
    "hilarizarão": "hilarizar",
    "hilarizaríamos": "hilarizar",
    "hilarizaríeis": "hilarizar",
    "hilarizas": "hilarizar",
    "hilarizasse": "hilarizar",
    "hilarizassem": "hilarizar",
    "hilarizasses": "hilarizar",
    "hilarizaste": "hilarizar",
    "hilarizastes": "hilarizar",
    "hilarizava": "hilarizar",
    "hilarizavam": "hilarizar",
    "hilarizavas": "hilarizar",
    "hilarize": "hilarizar",
    "hilarizei": "hilarizar",
    "hilarizeis": "hilarizar",
    "hilarizem": "hilarizar",
    "hilarizemo": "hilarizar",
    "hilarizemos": "hilarizar",
    "hilarizes": "hilarizar",
    "hilarizo": "hilarizar",
    "hilarizou": "hilarizar",
    "hilarizá": "hilarizar",
    "hilarizámo": "hilarizar",
    "hilarizámos": "hilarizar",
    "hilarizáramo": "hilarizar",
    "hilarizáramos": "hilarizar",
    "hilarizárei": "hilarizar",
    "hilarizáreis": "hilarizar",
    "hilarizásseis": "hilarizar",
    "hilarizássemos": "hilarizar",
    "hilarizávamo": "hilarizar",
    "hilarizávamos": "hilarizar",
    "hilarizávei": "hilarizar",
    "hilarizáveis": "hilarizar",
    "hilemorfismos": "hilemorfismo",
    "hilobatídeos": "hilobatídeo",
    "hilobátidas": "hilobátida",
    "hilogenias": "hilogenia",
    "hilomorfismos": "hilomorfismo",
    "hilos": "hilo",
    "hilotas": "hilota",
    "hilotismos": "hilotismo",
    "hilozoísmos": "hilozoísmo",
    "hilozoístas": "hilozoísta",
    "hilozóica": "hilozóico",
    "hilozóicas": "hilozóico",
    "hilozóicos": "hilozóico",
    "hilária": "hilário",
    "hilárias": "hilário",
    "hilários": "hilário",
    "hilárquica": "hilárquico",
    "hilárquicas": "hilárquico",
    "hilárquicos": "hilárquico",
    "hilés": "hilé",
    "hilética": "hilético",
    "hiléticas": "hilético",
    "hiléticos": "hilético",
    "hilídeos": "hilídeo",
    "hilífera": "hilífero",
    "hilíferas": "hilífero",
    "hilíferos": "hilífero",
    "hilófaga": "hilófago",
    "hilófagas": "hilófago",
    "hilófagos": "hilófago",
    "hilótomos": "hilótomo",
    "himalaica": "himalaico",
    "himalaicas": "himalaico",
    "himalaicos": "himalaico",
    "himalaítes": "himalaíte",
    "himenais": "himenal",
    "himeneus": "himeneu",
    "himeniais": "himenial",
    "himenocarpa": "himenocarpo",
    "himenocarpas": "himenocarpo",
    "himenocarpos": "himenocarpo",
    "himenofiláceas": "himenofilácea",
    "himenotomias": "himenotomia",
    "himenotómica": "himenotómico",
    "himenotómicas": "himenotómico",
    "himenotómicos": "himenotómico",
    "himenófora": "himenóforo",
    "himenóforas": "himenóforo",
    "himenóforos": "himenóforo",
    "himenópodes": "himenópode",
    "himenóptera": "himenóptero",
    "himenópteras": "himenóptero",
    "himenópteros": "himenóptero",
    "himenótomos": "himenótomo",
    "himénios": "himénio",
    "hindis": "hindi",
    "hindus": "hindu",
    "hindustanis": "hindustani",
    "hindustanos": "hindustano",
    "hinduísmos": "hinduísmo",
    "hinduístas": "hinduísta",
    "hinistas": "hinista",
    "hinodos": "hinodo",
    "hinografias": "hinografia",
    "hinologias": "hinologia",
    "hinologistas": "hinologista",
    "hinos": "hino",
    "hinterlândias": "hinterlândia",
    "hinários": "hinário",
    "hinógrafa": "hinógrafo",
    "hinógrafas": "hinógrafo",
    "hinógrafos": "hinógrafo",
    "hinóloga": "hinólogo",
    "hinólogas": "hinólogo",
    "hinólogos": "hinólogo",
    "hioglossos": "hioglosso",
    "hiomandibulares": "hiomandibular",
    "hiosciaminas": "hiosciamina",
    "hiostílica": "hiostílico",
    "hiostílicas": "hiostílico",
    "hiostílicos": "hiostílico",
    "hipacusias": "hipacusia",
    "hipalgesias": "hipalgesia",
    "hipalgias": "hipalgia",
    "hipantos": "hipanto",
    "hipantropias": "hipantropia",
    "hipantódios": "hipantódio",
    "hiparcas": "hiparca",
    "hiparcos": "hiparco",
    "hiparcurias": "hiparcuria",
    "hiperacidezes": "hiperacidez",
    "hiperactividades": "hiperactividade",
    "hiperacusias": "hiperacusia",
    "hiperafrodisias": "hiperafrodisia",
    "hiperalbuminoses": "hiperalbuminose",
    "hiperalgesias": "hiperalgesia",
    "hiperalgias": "hiperalgia",
    "hiperalgotimias": "hiperalgotimia",
    "hiperalimentações": "hiperalimentação",
    "hiperandrismos": "hiperandrismo",
    "hiperazotúrias": "hiperazotúria",
    "hiperbibasmos": "hiperbibasmo",
    "hiperboliformes": "hiperboliforme",
    "hiperbolismos": "hiperbolismo",
    "hiperboliza": "hiperbolizar",
    "hiperbolizada": "hiperbolizar",
    "hiperbolizadas": "hiperbolizar",
    "hiperbolizado": "hiperbolizar",
    "hiperbolizados": "hiperbolizar",
    "hiperbolizai": "hiperbolizar",
    "hiperbolizais": "hiperbolizar",
    "hiperbolizam": "hiperbolizar",
    "hiperbolizamo": "hiperbolizar",
    "hiperbolizamos": "hiperbolizar",
    "hiperbolizando": "hiperbolizar",
    "hiperbolizara": "hiperbolizar",
    "hiperbolizaram": "hiperbolizar",
    "hiperbolizaras": "hiperbolizar",
    "hiperbolizarde": "hiperbolizar",
    "hiperbolizardes": "hiperbolizar",
    "hiperbolizare": "hiperbolizar",
    "hiperbolizarei": "hiperbolizar",
    "hiperbolizareis": "hiperbolizar",
    "hiperbolizarem": "hiperbolizar",
    "hiperbolizaremos": "hiperbolizar",
    "hiperbolizares": "hiperbolizar",
    "hiperbolizaria": "hiperbolizar",
    "hiperbolizariam": "hiperbolizar",
    "hiperbolizarias": "hiperbolizar",
    "hiperbolizarmo": "hiperbolizar",
    "hiperbolizarmos": "hiperbolizar",
    "hiperbolizará": "hiperbolizar",
    "hiperbolizarás": "hiperbolizar",
    "hiperbolizarão": "hiperbolizar",
    "hiperbolizaríamos": "hiperbolizar",
    "hiperbolizaríeis": "hiperbolizar",
    "hiperbolizas": "hiperbolizar",
    "hiperbolizasse": "hiperbolizar",
    "hiperbolizassem": "hiperbolizar",
    "hiperbolizasses": "hiperbolizar",
    "hiperbolizaste": "hiperbolizar",
    "hiperbolizastes": "hiperbolizar",
    "hiperbolizava": "hiperbolizar",
    "hiperbolizavam": "hiperbolizar",
    "hiperbolizavas": "hiperbolizar",
    "hiperbolize": "hiperbolizar",
    "hiperbolizei": "hiperbolizar",
    "hiperbolizeis": "hiperbolizar",
    "hiperbolizem": "hiperbolizar",
    "hiperbolizemo": "hiperbolizar",
    "hiperbolizemos": "hiperbolizar",
    "hiperbolizes": "hiperbolizar",
    "hiperbolizo": "hiperbolizar",
    "hiperbolizou": "hiperbolizar",
    "hiperbolizá": "hiperbolizar",
    "hiperbolizámo": "hiperbolizar",
    "hiperbolizámos": "hiperbolizar",
    "hiperbolizáramo": "hiperbolizar",
    "hiperbolizáramos": "hiperbolizar",
    "hiperbolizárei": "hiperbolizar",
    "hiperbolizáreis": "hiperbolizar",
    "hiperbolizásseis": "hiperbolizar",
    "hiperbolizássemos": "hiperbolizar",
    "hiperbolizávamo": "hiperbolizar",
    "hiperbolizávamos": "hiperbolizar",
    "hiperbolizávei": "hiperbolizar",
    "hiperbolizáveis": "hiperbolizar",
    "hiperbolóides": "hiperbolóide",
    "hiperbólica": "hiperbólico",
    "hiperbólicas": "hiperbólico",
    "hiperbólicos": "hiperbólico",
    "hiperbórea": "hiperbóreo",
    "hiperbóreas": "hiperbóreo",
    "hiperbóreos": "hiperbóreo",
    "hipercargas": "hipercarga",
    "hiperceratoses": "hiperceratose",
    "hipercerebrações": "hipercerebração",
    "hipercloridrias": "hipercloridria",
    "hipercolias": "hipercolia",
    "hiperconservadora": "hiperconservador",
    "hiperconservadoras": "hiperconservador",
    "hiperconservadores": "hiperconservador",
    "hipercritica": "hipercriticar",
    "hipercriticada": "hipercriticar",
    "hipercriticadas": "hipercriticar",
    "hipercriticado": "hipercriticar",
    "hipercriticados": "hipercriticar",
    "hipercriticai": "hipercriticar",
    "hipercriticais": "hipercriticar",
    "hipercriticam": "hipercriticar",
    "hipercriticamo": "hipercriticar",
    "hipercriticamos": "hipercriticar",
    "hipercriticando": "hipercriticar",
    "hipercriticara": "hipercriticar",
    "hipercriticaram": "hipercriticar",
    "hipercriticaras": "hipercriticar",
    "hipercriticarde": "hipercriticar",
    "hipercriticardes": "hipercriticar",
    "hipercriticare": "hipercriticar",
    "hipercriticarei": "hipercriticar",
    "hipercriticareis": "hipercriticar",
    "hipercriticarem": "hipercriticar",
    "hipercriticaremos": "hipercriticar",
    "hipercriticares": "hipercriticar",
    "hipercriticaria": "hipercriticar",
    "hipercriticariam": "hipercriticar",
    "hipercriticarias": "hipercriticar",
    "hipercriticarmo": "hipercriticar",
    "hipercriticarmos": "hipercriticar",
    "hipercriticará": "hipercriticar",
    "hipercriticarás": "hipercriticar",
    "hipercriticarão": "hipercriticar",
    "hipercriticaríamos": "hipercriticar",
    "hipercriticaríeis": "hipercriticar",
    "hipercriticas": "hipercriticar",
    "hipercriticasse": "hipercriticar",
    "hipercriticassem": "hipercriticar",
    "hipercriticasses": "hipercriticar",
    "hipercriticaste": "hipercriticar",
    "hipercriticastes": "hipercriticar",
    "hipercriticava": "hipercriticar",
    "hipercriticavam": "hipercriticar",
    "hipercriticavas": "hipercriticar",
    "hipercriticismos": "hipercriticismo",
    "hipercritico": "hipercriticar",
    "hipercriticou": "hipercriticar",
    "hipercriticá": "hipercriticar",
    "hipercriticámo": "hipercriticar",
    "hipercriticámos": "hipercriticar",
    "hipercriticáramo": "hipercriticar",
    "hipercriticáramos": "hipercriticar",
    "hipercriticárei": "hipercriticar",
    "hipercriticáreis": "hipercriticar",
    "hipercriticásseis": "hipercriticar",
    "hipercriticássemos": "hipercriticar",
    "hipercriticávamo": "hipercriticar",
    "hipercriticávamos": "hipercriticar",
    "hipercriticávei": "hipercriticar",
    "hipercriticáveis": "hipercriticar",
    "hipercritique": "hipercriticar",
    "hipercritiquei": "hipercriticar",
    "hipercritiqueis": "hipercriticar",
    "hipercritiquem": "hipercriticar",
    "hipercritiquemo": "hipercriticar",
    "hipercritiquemos": "hipercriticar",
    "hipercritiques": "hipercriticar",
    "hipercromas": "hipercroma",
    "hipercromias": "hipercromia",
    "hipercrítica": "hipercrítico",
    "hipercríticas": "hipercrítico",
    "hipercríticos": "hipercrítico",
    "hipercubos": "hipercubo",
    "hiperculta": "hiperculto",
    "hipercultas": "hiperculto",
    "hipercultos": "hiperculto",
    "hiperdemias": "hiperdemia",
    "hiperdesenvolvimentos": "hiperdesenvolvimento",
    "hiperdipsias": "hiperdipsia",
    "hiperdosagens": "hiperdosagem",
    "hiperdotada": "hiperdotado",
    "hiperdotadas": "hiperdotado",
    "hiperdotados": "hiperdotado",
    "hiperdulias": "hiperdulia",
    "hiperemias": "hiperemia",
    "hiperemotividades": "hiperemotividade",
    "hiperentoses": "hiperentose",
    "hiperespaços": "hiperespaço",
    "hiperestesias": "hiperestesia",
    "hiperestésica": "hiperestésico",
    "hiperestésicas": "hiperestésico",
    "hiperestésicos": "hiperestésico",
    "hiperestética": "hiperestético",
    "hiperestéticas": "hiperestético",
    "hiperestéticos": "hiperestético",
    "hiperexcitabilidades": "hiperexcitabilidade",
    "hiperfagias": "hiperfagia",
    "hiperforias": "hiperforia",
    "hiperfunções": "hiperfunção",
    "hiperfágica": "hiperfágico",
    "hiperfágicas": "hiperfágico",
    "hiperfágicos": "hiperfágico",
    "hiperfísica": "hiperfísico",
    "hiperfísicas": "hiperfísico",
    "hiperfísicos": "hiperfísico",
    "hipergaláxias": "hipergaláxia",
    "hipergenesias": "hipergenesia",
    "hipergenética": "hipergenético",
    "hipergenéticas": "hipergenético",
    "hipergenéticos": "hipergenético",
    "hiperginismos": "hiperginismo",
    "hiperglotes": "hiperglote",
    "hipericos": "hiperico",
    "hipericáceas": "hipericácea",
    "hipericões": "hipericão",
    "hiperidroses": "hiperidrose",
    "hiperinoses": "hiperinose",
    "hiperintelectualidades": "hiperintelectualidade",
    "hipermenorreias": "hipermenorreia",
    "hipermercados": "hipermercado",
    "hipermetrias": "hipermetria",
    "hipermetropes": "hipermetrope",
    "hipermetropias": "hipermetropia",
    "hipermisticismos": "hipermisticismo",
    "hipermnésias": "hipermnésia",
    "hipermística": "hipermístico",
    "hipermísticas": "hipermístico",
    "hipermísticos": "hipermístico",
    "hipernúcleos": "hipernúcleo",
    "hiperopias": "hiperopia",
    "hiperorexias": "hiperorexia",
    "hiperortografismos": "hiperortografismo",
    "hiperosmias": "hiperosmia",
    "hiperosteoses": "hiperosteose",
    "hiperpatias": "hiperpatia",
    "hiperpieses": "hiperpiese",
    "hiperpirexias": "hiperpirexia",
    "hiperplanos": "hiperplano",
    "hiperplasias": "hiperplasia",
    "hiperplástica": "hiperplástico",
    "hiperplásticas": "hiperplástico",
    "hiperplásticos": "hiperplástico",
    "hiperproteccionismos": "hiperproteccionismo",
    "hipersalina": "hipersalino",
    "hipersalinas": "hipersalino",
    "hipersalinos": "hipersalino",
    "hipersarcoses": "hipersarcose",
    "hipersecreções": "hipersecreção",
    "hipersensibilidades": "hipersensibilidade",
    "hipersensíveis": "hipersensível",
    "hipersentimentalidades": "hipersentimentalidade",
    "hipersexualismos": "hipersexualismo",
    "hipersonora": "hipersonoro",
    "hipersonoras": "hipersonoro",
    "hipersonoros": "hipersonoro",
    "hiperstenas": "hiperstena",
    "hiperstílica": "hiperstílico",
    "hiperstílicas": "hiperstílico",
    "hiperstílicos": "hiperstílico",
    "hiperstómica": "hiperstómico",
    "hiperstómicas": "hiperstómico",
    "hiperstómicos": "hiperstómico",
    "hipersónica": "hipersónico",
    "hipersónicas": "hipersónico",
    "hipersónicos": "hipersónico",
    "hipertensa": "hipertenso",
    "hipertensas": "hipertenso",
    "hipertensiva": "hipertensivo",
    "hipertensivas": "hipertensivo",
    "hipertensivos": "hipertensivo",
    "hipertensores": "hipertensor",
    "hipertensos": "hipertenso",
    "hipertensões": "hipertensão",
    "hipertermias": "hipertermia",
    "hipertextos": "hipertexto",
    "hipertimias": "hipertimia",
    "hipertiroidismos": "hipertiroidismo",
    "hipertonias": "hipertonia",
    "hipertricoses": "hipertricose",
    "hipertrofia": "hipertrofiar",
    "hipertrofiada": "hipertrofiar",
    "hipertrofiadas": "hipertrofiar",
    "hipertrofiado": "hipertrofiar",
    "hipertrofiados": "hipertrofiar",
    "hipertrofiai": "hipertrofiar",
    "hipertrofiais": "hipertrofiar",
    "hipertrofiam": "hipertrofiar",
    "hipertrofiamo": "hipertrofiar",
    "hipertrofiamos": "hipertrofiar",
    "hipertrofiando": "hipertrofiar",
    "hipertrofiara": "hipertrofiar",
    "hipertrofiaram": "hipertrofiar",
    "hipertrofiaras": "hipertrofiar",
    "hipertrofiarde": "hipertrofiar",
    "hipertrofiardes": "hipertrofiar",
    "hipertrofiare": "hipertrofiar",
    "hipertrofiarei": "hipertrofiar",
    "hipertrofiareis": "hipertrofiar",
    "hipertrofiarem": "hipertrofiar",
    "hipertrofiaremos": "hipertrofiar",
    "hipertrofiares": "hipertrofiar",
    "hipertrofiaria": "hipertrofiar",
    "hipertrofiariam": "hipertrofiar",
    "hipertrofiarias": "hipertrofiar",
    "hipertrofiarmo": "hipertrofiar",
    "hipertrofiarmos": "hipertrofiar",
    "hipertrofiará": "hipertrofiar",
    "hipertrofiarás": "hipertrofiar",
    "hipertrofiarão": "hipertrofiar",
    "hipertrofiaríamos": "hipertrofiar",
    "hipertrofiaríeis": "hipertrofiar",
    "hipertrofias": "hipertrofiar",
    "hipertrofiasse": "hipertrofiar",
    "hipertrofiassem": "hipertrofiar",
    "hipertrofiasses": "hipertrofiar",
    "hipertrofiaste": "hipertrofiar",
    "hipertrofiastes": "hipertrofiar",
    "hipertrofiava": "hipertrofiar",
    "hipertrofiavam": "hipertrofiar",
    "hipertrofiavas": "hipertrofiar",
    "hipertrofie": "hipertrofiar",
    "hipertrofiei": "hipertrofiar",
    "hipertrofieis": "hipertrofiar",
    "hipertrofiem": "hipertrofiar",
    "hipertrofiemo": "hipertrofiar",
    "hipertrofiemos": "hipertrofiar",
    "hipertrofies": "hipertrofiar",
    "hipertrofio": "hipertrofiar",
    "hipertrofiou": "hipertrofiar",
    "hipertrofiá": "hipertrofiar",
    "hipertrofiámo": "hipertrofiar",
    "hipertrofiámos": "hipertrofiar",
    "hipertrofiáramo": "hipertrofiar",
    "hipertrofiáramos": "hipertrofiar",
    "hipertrofiárei": "hipertrofiar",
    "hipertrofiáreis": "hipertrofiar",
    "hipertrofiásseis": "hipertrofiar",
    "hipertrofiássemos": "hipertrofiar",
    "hipertrofiávamo": "hipertrofiar",
    "hipertrofiávamos": "hipertrofiar",
    "hipertrofiávei": "hipertrofiar",
    "hipertrofiáveis": "hipertrofiar",
    "hipertírios": "hipertírio",
    "hipertónica": "hipertónico",
    "hipertónicas": "hipertónico",
    "hipertónicos": "hipertónico",
    "hiperurbanismos": "hiperurbanismo",
    "hipervaidades": "hipervaidade",
    "hipervalorizações": "hipervalorização",
    "hipervitaminoses": "hipervitaminose",
    "hiperácida": "hiperácido",
    "hiperácidas": "hiperácido",
    "hiperácidos": "hiperácido",
    "hiperões": "hiperão",
    "hipestesias": "hipestesia",
    "hipiatra": "hipiatro",
    "hipiatras": "hipiatro",
    "hipiatrias": "hipiatria",
    "hipiatros": "hipiatro",
    "hipismos": "hipismo",
    "hipistas": "hipista",
    "hipiátrica": "hipiátrico",
    "hipiátricas": "hipiátrico",
    "hipiátricos": "hipiátrico",
    "hipnagógica": "hipnagógico",
    "hipnagógicas": "hipnagógico",
    "hipnagógicos": "hipnagógico",
    "hipnoanálises": "hipnoanálise",
    "hipnofobias": "hipnofobia",
    "hipnografias": "hipnografia",
    "hipnogénea": "hipnogéneo",
    "hipnogéneas": "hipnogéneo",
    "hipnogéneos": "hipnogéneo",
    "hipnolepsias": "hipnolepsia",
    "hipnologias": "hipnologia",
    "hipnomanias": "hipnomania",
    "hipnopatias": "hipnopatia",
    "hipnopedias": "hipnopedia",
    "hipnoses": "hipnose",
    "hipnosias": "hipnosia",
    "hipnoterapias": "hipnoterapia",
    "hipnotismos": "hipnotismo",
    "hipnotistas": "hipnotista",
    "hipnotiza": "hipnotizar",
    "hipnotizada": "hipnotizar",
    "hipnotizadas": "hipnotizar",
    "hipnotizado": "hipnotizar",
    "hipnotizadora": "hipnotizador",
    "hipnotizadoras": "hipnotizador",
    "hipnotizadores": "hipnotizador",
    "hipnotizados": "hipnotizar",
    "hipnotizai": "hipnotizar",
    "hipnotizais": "hipnotizar",
    "hipnotizam": "hipnotizar",
    "hipnotizamo": "hipnotizar",
    "hipnotizamos": "hipnotizar",
    "hipnotizando": "hipnotizar",
    "hipnotizara": "hipnotizar",
    "hipnotizaram": "hipnotizar",
    "hipnotizaras": "hipnotizar",
    "hipnotizarde": "hipnotizar",
    "hipnotizardes": "hipnotizar",
    "hipnotizare": "hipnotizar",
    "hipnotizarei": "hipnotizar",
    "hipnotizareis": "hipnotizar",
    "hipnotizarem": "hipnotizar",
    "hipnotizaremos": "hipnotizar",
    "hipnotizares": "hipnotizar",
    "hipnotizaria": "hipnotizar",
    "hipnotizariam": "hipnotizar",
    "hipnotizarias": "hipnotizar",
    "hipnotizarmo": "hipnotizar",
    "hipnotizarmos": "hipnotizar",
    "hipnotizará": "hipnotizar",
    "hipnotizarás": "hipnotizar",
    "hipnotizarão": "hipnotizar",
    "hipnotizaríamos": "hipnotizar",
    "hipnotizaríeis": "hipnotizar",
    "hipnotizas": "hipnotizar",
    "hipnotizasse": "hipnotizar",
    "hipnotizassem": "hipnotizar",
    "hipnotizasses": "hipnotizar",
    "hipnotizaste": "hipnotizar",
    "hipnotizastes": "hipnotizar",
    "hipnotizava": "hipnotizar",
    "hipnotizavam": "hipnotizar",
    "hipnotizavas": "hipnotizar",
    "hipnotizações": "hipnotização",
    "hipnotize": "hipnotizar",
    "hipnotizei": "hipnotizar",
    "hipnotizeis": "hipnotizar",
    "hipnotizem": "hipnotizar",
    "hipnotizemo": "hipnotizar",
    "hipnotizemos": "hipnotizar",
    "hipnotizes": "hipnotizar",
    "hipnotizo": "hipnotizar",
    "hipnotizou": "hipnotizar",
    "hipnotizá": "hipnotizar",
    "hipnotizámo": "hipnotizar",
    "hipnotizámos": "hipnotizar",
    "hipnotizáramo": "hipnotizar",
    "hipnotizáramos": "hipnotizar",
    "hipnotizárei": "hipnotizar",
    "hipnotizáreis": "hipnotizar",
    "hipnotizásseis": "hipnotizar",
    "hipnotizássemos": "hipnotizar",
    "hipnotizávamo": "hipnotizar",
    "hipnotizávamos": "hipnotizar",
    "hipnotizávei": "hipnotizar",
    "hipnotizáveis": "hipnotizável",
    "hipnófoba": "hipnófobo",
    "hipnófobas": "hipnófobo",
    "hipnófobos": "hipnófobo",
    "hipnóides": "hipnóide",
    "hipnóloga": "hipnólogo",
    "hipnólogas": "hipnólogo",
    "hipnólogos": "hipnólogo",
    "hipnótica": "hipnótico",
    "hipnóticas": "hipnótico",
    "hipnóticos": "hipnótico",
    "hipoacusias": "hipoacusia",
    "hipoalgesias": "hipoalgesia",
    "hipoandrismos": "hipoandrismo",
    "hipoazotosa": "hipoazotoso",
    "hipoazotosas": "hipoazotoso",
    "hipoazotosos": "hipoazotoso",
    "hipoblastos": "hipoblasto",
    "hipobrânquia": "hipobrânquio",
    "hipobrânquias": "hipobrânquio",
    "hipobrânquios": "hipobrânquio",
    "hipocampos": "hipocampo",
    "hipocaustos": "hipocausto",
    "hipocentauros": "hipocentauro",
    "hipocentros": "hipocentro",
    "hipociclóides": "hipociclóide",
    "hipocloridrias": "hipocloridria",
    "hipoclorinas": "hipoclorina",
    "hipocloritos": "hipoclorito",
    "hipoclorosa": "hipocloroso",
    "hipoclorosas": "hipocloroso",
    "hipoclorosos": "hipocloroso",
    "hipocolias": "hipocolia",
    "hipocondrias": "hipocondria",
    "hipocondríaca": "hipocondríaco",
    "hipocondríacas": "hipocondríaco",
    "hipocondríacos": "hipocondríaco",
    "hipocorística": "hipocorístico",
    "hipocorísticas": "hipocorístico",
    "hipocorísticos": "hipocorístico",
    "hipocraniana": "hipocraniano",
    "hipocranianas": "hipocraniano",
    "hipocranianos": "hipocraniano",
    "hipocratismos": "hipocratismo",
    "hipocrazes": "hipocraz",
    "hipocrisias": "hipocrisia",
    "hipocótilos": "hipocótilo",
    "hipocôndrios": "hipocôndrio",
    "hipodermatomias": "hipodermatomia",
    "hipodermes": "hipoderme",
    "hipodermoterapias": "hipodermoterapia",
    "hipodermíases": "hipodermíase",
    "hipodesenvolvimentos": "hipodesenvolvimento",
    "hipodipsias": "hipodipsia",
    "hipodromias": "hipodromia",
    "hipodáctilos": "hipodáctilo",
    "hipodérmica": "hipodérmico",
    "hipodérmicas": "hipodérmico",
    "hipodérmicos": "hipodérmico",
    "hipoepatias": "hipoepatia",
    "hipoestesias": "hipoestesia",
    "hipofagias": "hipofagia",
    "hipofaringes": "hipofaringe",
    "hipofila": "hipofilo",
    "hipofilas": "hipofilo",
    "hipofilos": "hipofilo",
    "hipofosfatos": "hipofosfato",
    "hipofosfitos": "hipofosfito",
    "hipofosforosa": "hipofosforoso",
    "hipofosforosas": "hipofosforoso",
    "hipofosforosos": "hipofosforoso",
    "hipofosfórica": "hipofosfórico",
    "hipofosfóricas": "hipofosfórico",
    "hipofosfóricos": "hipofosfórico",
    "hipoftalmias": "hipoftalmia",
    "hipogeias": "hipogeia",
    "hipogeus": "hipogeu",
    "hipoginias": "hipoginia",
    "hipoginismos": "hipoginismo",
    "hipoglicémias": "hipoglicémia",
    "hipoglobulias": "hipoglobulia",
    "hipoglossa": "hipoglosso",
    "hipoglossas": "hipoglosso",
    "hipoglossos": "hipoglosso",
    "hipognatias": "hipognatia",
    "hipogrifos": "hipogrifo",
    "hipogástrica": "hipogástrico",
    "hipogástricas": "hipogástrico",
    "hipogástricos": "hipogástrico",
    "hipogástrios": "hipogástrio",
    "hipogínica": "hipogínico",
    "hipogínicas": "hipogínico",
    "hipogínicos": "hipogínico",
    "hipologias": "hipologia",
    "hipomancias": "hipomancia",
    "hipomanias": "hipomania",
    "hipomaníana": "hipomaníano",
    "hipomaníanas": "hipomaníano",
    "hipomaníanos": "hipomaníano",
    "hipomóveis": "hipomóvel",
    "hiponóides": "hiponóide",
    "hipopieses": "hipopiese",
    "hipoplasias": "hipoplasia",
    "hipopotamídeos": "hipopotamídeo",
    "hipopotâmidas": "hipopotâmida",
    "hipoprosexias": "hipoprosexia",
    "hipopígios": "hipopígio",
    "hipopódios": "hipopódio",
    "hipopótamos": "hipopótamo",
    "hiposcénios": "hiposcénio",
    "hiposmias": "hiposmia",
    "hipospadias": "hipospadia",
    "hipossulfatos": "hipossulfato",
    "hipossulfitos": "hipossulfito",
    "hipossulfurosa": "hipossulfuroso",
    "hipossulfurosas": "hipossulfuroso",
    "hipossulfurosos": "hipossulfuroso",
    "hipossulfúrica": "hipossulfúrico",
    "hipossulfúricas": "hipossulfúrico",
    "hipossulfúricos": "hipossulfúrico",
    "hipostenias": "hipostenia",
    "hipostila": "hipostilo",
    "hipostilas": "hipostilo",
    "hipostilos": "hipostilo",
    "hipostromas": "hipostroma",
    "hipostática": "hipostático",
    "hipostáticas": "hipostático",
    "hipostáticos": "hipostático",
    "hiposténica": "hiposténico",
    "hiposténicas": "hiposténico",
    "hiposténicos": "hiposténico",
    "hipotalássica": "hipotalássico",
    "hipotalássicas": "hipotalássico",
    "hipotalássicos": "hipotalássico",
    "hipotaxes": "hipotaxe",
    "hipoteca": "hipotecar",
    "hipotecada": "hipotecar",
    "hipotecadas": "hipotecar",
    "hipotecado": "hipotecar",
    "hipotecados": "hipotecar",
    "hipotecai": "hipotecar",
    "hipotecais": "hipotecar",
    "hipotecam": "hipotecar",
    "hipotecamo": "hipotecar",
    "hipotecamos": "hipotecar",
    "hipotecando": "hipotecar",
    "hipotecara": "hipotecar",
    "hipotecaram": "hipotecar",
    "hipotecaras": "hipotecar",
    "hipotecarde": "hipotecar",
    "hipotecardes": "hipotecar",
    "hipotecare": "hipotecar",
    "hipotecarei": "hipotecar",
    "hipotecareis": "hipotecar",
    "hipotecarem": "hipotecar",
    "hipotecaremos": "hipotecar",
    "hipotecares": "hipotecar",
    "hipotecaria": "hipotecar",
    "hipotecariam": "hipotecar",
    "hipotecarias": "hipotecar",
    "hipotecarmo": "hipotecar",
    "hipotecarmos": "hipotecar",
    "hipotecará": "hipotecar",
    "hipotecarás": "hipotecar",
    "hipotecarão": "hipotecar",
    "hipotecaríamos": "hipotecar",
    "hipotecaríeis": "hipotecar",
    "hipotecas": "hipotecar",
    "hipotecasse": "hipotecar",
    "hipotecassem": "hipotecar",
    "hipotecasses": "hipotecar",
    "hipotecaste": "hipotecar",
    "hipotecastes": "hipotecar",
    "hipotecava": "hipotecar",
    "hipotecavam": "hipotecar",
    "hipotecavas": "hipotecar",
    "hipoteco": "hipotecar",
    "hipotecou": "hipotecar",
    "hipotecá": "hipotecar",
    "hipotecámo": "hipotecar",
    "hipotecámos": "hipotecar",
    "hipotecáramo": "hipotecar",
    "hipotecáramos": "hipotecar",
    "hipotecárei": "hipotecar",
    "hipotecáreis": "hipotecar",
    "hipotecária": "hipotecário",
    "hipotecárias": "hipotecário",
    "hipotecários": "hipotecário",
    "hipotecásseis": "hipotecar",
    "hipotecássemos": "hipotecar",
    "hipotecávamo": "hipotecar",
    "hipotecávamos": "hipotecar",
    "hipotecávei": "hipotecar",
    "hipotecáveis": "hipotecável",
    "hipotensa": "hipotenso",
    "hipotensas": "hipotenso",
    "hipotensiva": "hipotensivo",
    "hipotensivas": "hipotensivo",
    "hipotensivos": "hipotensivo",
    "hipotensora": "hipotensor",
    "hipotensoras": "hipotensor",
    "hipotensores": "hipotensor",
    "hipotensos": "hipotenso",
    "hipotensões": "hipotensão",
    "hipotenusas": "hipotenusa",
    "hipoteque": "hipotecar",
    "hipotequei": "hipotecar",
    "hipotequeis": "hipotecar",
    "hipotequem": "hipotecar",
    "hipotequemo": "hipotecar",
    "hipotequemos": "hipotecar",
    "hipoteques": "hipotecar",
    "hipotermais": "hipotermal",
    "hipotermias": "hipotermia",
    "hipotimias": "hipotimia",
    "hipotiposes": "hipotipose",
    "hipotomias": "hipotomia",
    "hipotonias": "hipotonia",
    "hipotrofias": "hipotrofia",
    "hipotropias": "hipotropia",
    "hipotrófica": "hipotrófico",
    "hipotróficas": "hipotrófico",
    "hipotróficos": "hipotrófico",
    "hipotálamos": "hipotálamo",
    "hipotética": "hipotético",
    "hipotéticas": "hipotético",
    "hipotéticos": "hipotético",
    "hipotónica": "hipotónico",
    "hipotónicas": "hipotónico",
    "hipotónicos": "hipotónico",
    "hipoxias": "hipoxia",
    "hipozóides": "hipozóide",
    "hippies": "hippie",
    "hipsobatimetrias": "hipsobatimetria",
    "hipsobatimétrica": "hipsobatimétrico",
    "hipsobatimétricas": "hipsobatimétrico",
    "hipsobatimétricos": "hipsobatimétrico",
    "hipsocefalias": "hipsocefalia",
    "hipsocéfala": "hipsocéfalo",
    "hipsocéfalas": "hipsocéfalo",
    "hipsocéfalos": "hipsocéfalo",
    "hipsografias": "hipsografia",
    "hipsográfica": "hipsográfico",
    "hipsográficas": "hipsográfico",
    "hipsográficos": "hipsográfico",
    "hipsometrias": "hipsometria",
    "hipsométrica": "hipsométrico",
    "hipsométricas": "hipsométrico",
    "hipsométricos": "hipsométrico",
    "hipsómetros": "hipsómetro",
    "hipurais": "hipural",
    "hipuratos": "hipurato",
    "hipálages": "hipálage",
    "hipérbatons": "hipérbaton",
    "hipérbatos": "hipérbato",
    "hipérboles": "hipérbole",
    "hipérmetros": "hipérmetro",
    "hipérteses": "hipértese",
    "hipértiros": "hipértiro",
    "hipídeos": "hipídeo",
    "hipócritas": "hipócrita",
    "hipódromos": "hipódromo",
    "hipófaga": "hipófago",
    "hipófagas": "hipófago",
    "hipófagos": "hipófago",
    "hipófases": "hipófase",
    "hipófises": "hipófise",
    "hipógea": "hipógeo",
    "hipógeas": "hipógeo",
    "hipógeos": "hipógeo",
    "hipógina": "hipógino",
    "hipóginas": "hipógino",
    "hipóginos": "hipógino",
    "hipógnata": "hipógnato",
    "hipógnatas": "hipógnato",
    "hipógnatos": "hipógnato",
    "hipómetros": "hipómetro",
    "hipópios": "hipópio",
    "hipópodes": "hipópode",
    "hipóspada": "hipóspado",
    "hipóspadas": "hipóspado",
    "hipóspados": "hipóspado",
    "hipóstases": "hipóstase",
    "hipóstomos": "hipóstomo",
    "hipóteses": "hipótese",
    "hipótrica": "hipótrico",
    "hipótricas": "hipótrico",
    "hipótricos": "hipótrico",
    "hipúrias": "hipúria",
    "hipúrica": "hipúrico",
    "hipúricas": "hipúrico",
    "hipúricos": "hipúrico",
    "hiraranas": "hirarana",
    "hiraras": "hirara",
    "hircina": "hircino",
    "hircinas": "hircino",
    "hircinos": "hircino",
    "hircismos": "hircismo",
    "hircos": "hirco",
    "hircosa": "hircoso",
    "hircosas": "hircoso",
    "hircosos": "hircoso",
    "hirculações": "hirculação",
    "hircânia": "hircânio",
    "hircânias": "hircânio",
    "hircânios": "hircânio",
    "hirsuta": "hirsuto",
    "hirsutas": "hirsuto",
    "hirsutezes": "hirsutez",
    "hirsutos": "hirsuto",
    "hirta": "hirto",
    "hirtas": "hirto",
    "hirtezas": "hirteza",
    "hirtos": "hirto",
    "hirudinicultora": "hirudinicultor",
    "hirudinicultoras": "hirudinicultor",
    "hirudinicultores": "hirudinicultor",
    "hirudiniculturas": "hirudinicultura",
    "hirudínea": "hirudíneo",
    "hirudíneas": "hirudíneo",
    "hirudíneos": "hirudíneo",
    "hirundina": "hirundino",
    "hirundinas": "hirundino",
    "hirundinos": "hirundino",
    "hirundinídeos": "hirundinídeo",
    "hirundínidas": "hirundínida",
    "hispa": "hispar",
    "hispada": "hispar",
    "hispadas": "hispar",
    "hispado": "hispar",
    "hispados": "hispar",
    "hispai": "hispar",
    "hispais": "hispar",
    "hispalenses": "hispalense",
    "hispam": "hispar",
    "hispamo": "hispar",
    "hispamos": "hispar",
    "hispana": "hispano",
    "hispanas": "hispano",
    "hispando": "hispar",
    "hispanienses": "hispaniense",
    "hispanistas": "hispanista",
    "hispaniza": "hispanizar",
    "hispanizada": "hispanizar",
    "hispanizadas": "hispanizar",
    "hispanizado": "hispanizar",
    "hispanizados": "hispanizar",
    "hispanizai": "hispanizar",
    "hispanizais": "hispanizar",
    "hispanizam": "hispanizar",
    "hispanizamo": "hispanizar",
    "hispanizamos": "hispanizar",
    "hispanizando": "hispanizar",
    "hispanizara": "hispanizar",
    "hispanizaram": "hispanizar",
    "hispanizaras": "hispanizar",
    "hispanizarde": "hispanizar",
    "hispanizardes": "hispanizar",
    "hispanizare": "hispanizar",
    "hispanizarei": "hispanizar",
    "hispanizareis": "hispanizar",
    "hispanizarem": "hispanizar",
    "hispanizaremos": "hispanizar",
    "hispanizares": "hispanizar",
    "hispanizaria": "hispanizar",
    "hispanizariam": "hispanizar",
    "hispanizarias": "hispanizar",
    "hispanizarmo": "hispanizar",
    "hispanizarmos": "hispanizar",
    "hispanizará": "hispanizar",
    "hispanizarás": "hispanizar",
    "hispanizarão": "hispanizar",
    "hispanizaríamos": "hispanizar",
    "hispanizaríeis": "hispanizar",
    "hispanizas": "hispanizar",
    "hispanizasse": "hispanizar",
    "hispanizassem": "hispanizar",
    "hispanizasses": "hispanizar",
    "hispanizaste": "hispanizar",
    "hispanizastes": "hispanizar",
    "hispanizava": "hispanizar",
    "hispanizavam": "hispanizar",
    "hispanizavas": "hispanizar",
    "hispanize": "hispanizar",
    "hispanizei": "hispanizar",
    "hispanizeis": "hispanizar",
    "hispanizem": "hispanizar",
    "hispanizemo": "hispanizar",
    "hispanizemos": "hispanizar",
    "hispanizes": "hispanizar",
    "hispanizo": "hispanizar",
    "hispanizou": "hispanizar",
    "hispanizá": "hispanizar",
    "hispanizámo": "hispanizar",
    "hispanizámos": "hispanizar",
    "hispanizáramo": "hispanizar",
    "hispanizáramos": "hispanizar",
    "hispanizárei": "hispanizar",
    "hispanizáreis": "hispanizar",
    "hispanizásseis": "hispanizar",
    "hispanizássemos": "hispanizar",
    "hispanizávamo": "hispanizar",
    "hispanizávamos": "hispanizar",
    "hispanizávei": "hispanizar",
    "hispanizáveis": "hispanizável",
    "hispanofilias": "hispanofilia",
    "hispanofobias": "hispanofobia",
    "hispanofonias": "hispanofonia",
    "hispanologa": "hispanologo",
    "hispanologas": "hispanologo",
    "hispanologias": "hispanologia",
    "hispanologos": "hispanologo",
    "hispanos": "hispano",
    "hispanófila": "hispanófilo",
    "hispanófilas": "hispanófilo",
    "hispanófilos": "hispanófilo",
    "hispanófoba": "hispanófobo",
    "hispanófobas": "hispanófobo",
    "hispanófobos": "hispanófobo",
    "hispanófona": "hispanófono",
    "hispanófonas": "hispanófono",
    "hispanófonos": "hispanófono",
    "hispara": "hispar",
    "hisparam": "hispar",
    "hisparas": "hispar",
    "hisparde": "hispar",
    "hispardes": "hispar",
    "hispare": "hispar",
    "hisparei": "hispar",
    "hispareis": "hispar",
    "hisparem": "hispar",
    "hisparemos": "hispar",
    "hispares": "hispar",
    "hisparia": "hispar",
    "hispariam": "hispar",
    "hisparias": "hispar",
    "hisparmo": "hispar",
    "hisparmos": "hispar",
    "hispará": "hispar",
    "hisparás": "hispar",
    "hisparão": "hispar",
    "hisparíamos": "hispar",
    "hisparíeis": "hispar",
    "hispas": "hispar",
    "hispasse": "hispar",
    "hispassem": "hispar",
    "hispasses": "hispar",
    "hispaste": "hispar",
    "hispastes": "hispar",
    "hispava": "hispar",
    "hispavam": "hispar",
    "hispavas": "hispar",
    "hispe": "hispar",
    "hispei": "hispar",
    "hispeis": "hispar",
    "hispem": "hispar",
    "hispemo": "hispar",
    "hispemos": "hispar",
    "hispes": "hispar",
    "hispida": "hispidar",
    "hispidada": "hispidar",
    "hispidadas": "hispidar",
    "hispidado": "hispidar",
    "hispidados": "hispidar",
    "hispidai": "hispidar",
    "hispidais": "hispidar",
    "hispidam": "hispidar",
    "hispidamo": "hispidar",
    "hispidamos": "hispidar",
    "hispidando": "hispidar",
    "hispidara": "hispidar",
    "hispidaram": "hispidar",
    "hispidaras": "hispidar",
    "hispidarde": "hispidar",
    "hispidardes": "hispidar",
    "hispidare": "hispidar",
    "hispidarei": "hispidar",
    "hispidareis": "hispidar",
    "hispidarem": "hispidar",
    "hispidaremos": "hispidar",
    "hispidares": "hispidar",
    "hispidaria": "hispidar",
    "hispidariam": "hispidar",
    "hispidarias": "hispidar",
    "hispidarmo": "hispidar",
    "hispidarmos": "hispidar",
    "hispidará": "hispidar",
    "hispidarás": "hispidar",
    "hispidarão": "hispidar",
    "hispidaríamos": "hispidar",
    "hispidaríeis": "hispidar",
    "hispidas": "hispidar",
    "hispidasse": "hispidar",
    "hispidassem": "hispidar",
    "hispidasses": "hispidar",
    "hispidaste": "hispidar",
    "hispidastes": "hispidar",
    "hispidava": "hispidar",
    "hispidavam": "hispidar",
    "hispidavas": "hispidar",
    "hispide": "hispidar",
    "hispidei": "hispidar",
    "hispideis": "hispidar",
    "hispidem": "hispidar",
    "hispidemo": "hispidar",
    "hispidemos": "hispidar",
    "hispides": "hispidar",
    "hispidezes": "hispidez",
    "hispido": "hispidar",
    "hispidou": "hispidar",
    "hispidá": "hispidar",
    "hispidámo": "hispidar",
    "hispidámos": "hispidar",
    "hispidáramo": "hispidar",
    "hispidáramos": "hispidar",
    "hispidárei": "hispidar",
    "hispidáreis": "hispidar",
    "hispidásseis": "hispidar",
    "hispidássemos": "hispidar",
    "hispidávamo": "hispidar",
    "hispidávamos": "hispidar",
    "hispidávei": "hispidar",
    "hispidáveis": "hispidar",
    "hispo": "hispar",
    "hispou": "hispar",
    "hispá": "hispar",
    "hispálica": "hispálico",
    "hispálicas": "hispálico",
    "hispálicos": "hispálico",
    "hispámo": "hispar",
    "hispámos": "hispar",
    "hispáramo": "hispar",
    "hispáramos": "hispar",
    "hispárei": "hispar",
    "hispáreis": "hispar",
    "hispásseis": "hispar",
    "hispássemos": "hispar",
    "hispávamo": "hispar",
    "hispávamos": "hispar",
    "hispávei": "hispar",
    "hispáveis": "hispar",
    "hispânica": "hispânico",
    "hispânicas": "hispânico",
    "hispânicos": "hispânico",
    "hissons": "hissom",
    "hissopa": "hissopar",
    "hissopada": "hissopar",
    "hissopadas": "hissopar",
    "hissopado": "hissopar",
    "hissopados": "hissopar",
    "hissopai": "hissopar",
    "hissopais": "hissopar",
    "hissopam": "hissopar",
    "hissopamo": "hissopar",
    "hissopamos": "hissopar",
    "hissopando": "hissopar",
    "hissopara": "hissopar",
    "hissoparam": "hissopar",
    "hissoparas": "hissopar",
    "hissoparde": "hissopar",
    "hissopardes": "hissopar",
    "hissopare": "hissopar",
    "hissoparei": "hissopar",
    "hissopareis": "hissopar",
    "hissoparem": "hissopar",
    "hissoparemos": "hissopar",
    "hissopares": "hissopar",
    "hissoparia": "hissopar",
    "hissopariam": "hissopar",
    "hissoparias": "hissopar",
    "hissoparmo": "hissopar",
    "hissoparmos": "hissopar",
    "hissopará": "hissopar",
    "hissoparás": "hissopar",
    "hissoparão": "hissopar",
    "hissoparíamos": "hissopar",
    "hissoparíeis": "hissopar",
    "hissopas": "hissopar",
    "hissopasse": "hissopar",
    "hissopassem": "hissopar",
    "hissopasses": "hissopar",
    "hissopaste": "hissopar",
    "hissopastes": "hissopar",
    "hissopava": "hissopar",
    "hissopavam": "hissopar",
    "hissopavas": "hissopar",
    "hissope": "hissopar",
    "hissopei": "hissopar",
    "hissopeis": "hissopar",
    "hissopem": "hissopar",
    "hissopemo": "hissopar",
    "hissopemos": "hissopar",
    "hissopes": "hissope",
    "hissopinas": "hissopina",
    "hissopo": "hissopar",
    "hissopos": "hissopo",
    "hissopou": "hissopar",
    "hissopá": "hissopar",
    "hissopámo": "hissopar",
    "hissopámos": "hissopar",
    "hissopáramo": "hissopar",
    "hissopáramos": "hissopar",
    "hissopárei": "hissopar",
    "hissopáreis": "hissopar",
    "hissopásseis": "hissopar",
    "hissopássemos": "hissopar",
    "hissopávamo": "hissopar",
    "hissopávamos": "hissopar",
    "hissopávei": "hissopar",
    "hissopáveis": "hissopar",
    "histaminas": "histamina",
    "histamínica": "histamínico",
    "histamínicas": "histamínico",
    "histamínicos": "histamínico",
    "histeralgias": "histeralgia",
    "histeranta": "histeranto",
    "histerantas": "histeranto",
    "histerantos": "histeranto",
    "histerectomias": "histerectomia",
    "histereses": "histerese",
    "histerias": "histeria",
    "histericismos": "histericismo",
    "histerismos": "histerismo",
    "histeroceles": "histerocele",
    "histerofisas": "histerofisa",
    "histerografias": "histerografia",
    "histerologias": "histerologia",
    "histeroloxias": "histeroloxia",
    "histeromanias": "histeromania",
    "histeropatias": "histeropatia",
    "histeroptoses": "histeroptose",
    "histeroscopias": "histeroscopia",
    "histeroscópios": "histeroscópio",
    "histerotomias": "histerotomia",
    "histerésica": "histerésico",
    "histerésicas": "histerésico",
    "histerésicos": "histerésico",
    "histerólitos": "histerólito",
    "histeróloga": "histerólogo",
    "histerólogas": "histerólogo",
    "histerólogos": "histerólogo",
    "histerómana": "histerómano",
    "histerómanas": "histerómano",
    "histerómanos": "histerómano",
    "histerómetros": "histerómetro",
    "histerótomos": "histerótomo",
    "histocompatibilidades": "histocompatibilidade",
    "histofisiologias": "histofisiologia",
    "histofisiológica": "histofisiológico",
    "histofisiológicas": "histofisiológico",
    "histofisiológicos": "histofisiológico",
    "histogenias": "histogenia",
    "histogenética": "histogenético",
    "histogenéticas": "histogenético",
    "histogenéticos": "histogenético",
    "histografias": "histografia",
    "histogramas": "histograma",
    "histogénea": "histogéneo",
    "histogéneas": "histogéneo",
    "histogéneos": "histogéneo",
    "histogéneses": "histogénese",
    "histogénica": "histogénico",
    "histogénicas": "histogénico",
    "histogénicos": "histogénico",
    "histologias": "histologia",
    "histologistas": "histologista",
    "histológica": "histológico",
    "histológicas": "histológico",
    "histológicos": "histológico",
    "histomas": "histoma",
    "histonas": "histona",
    "histoneurologias": "histoneurologia",
    "histoneutológica": "histoneutológico",
    "histoneutológicas": "histoneutológico",
    "histoneutológicos": "histoneutológico",
    "histonomias": "histonomia",
    "histonómica": "histonómico",
    "histonómicas": "histonómico",
    "histonómicos": "histonómico",
    "histopatológica": "histopatológico",
    "histopatológicas": "histopatológico",
    "histopatológicos": "histopatológico",
    "historia": "historiar",
    "historiada": "historiar",
    "historiadas": "historiar",
    "historiado": "historiar",
    "historiadora": "historiador",
    "historiadoras": "historiador",
    "historiadores": "historiador",
    "historiados": "historiar",
    "historiai": "historiar",
    "historiais": "historiar",
    "historiam": "historiar",
    "historiamo": "historiar",
    "historiamos": "historiar",
    "historiando": "historiar",
    "historiara": "historiar",
    "historiaram": "historiar",
    "historiaras": "historiar",
    "historiarde": "historiar",
    "historiardes": "historiar",
    "historiare": "historiar",
    "historiarei": "historiar",
    "historiareis": "historiar",
    "historiarem": "historiar",
    "historiaremos": "historiar",
    "historiares": "historiar",
    "historiaria": "historiar",
    "historiariam": "historiar",
    "historiarias": "historiar",
    "historiarmo": "historiar",
    "historiarmos": "historiar",
    "historiará": "historiar",
    "historiarás": "historiar",
    "historiarão": "historiar",
    "historiaríamos": "historiar",
    "historiaríeis": "historiar",
    "historias": "historiar",
    "historiasse": "historiar",
    "historiassem": "historiar",
    "historiasses": "historiar",
    "historiaste": "historiar",
    "historiastes": "historiar",
    "historiava": "historiar",
    "historiavam": "historiar",
    "historiavas": "historiar",
    "historicidades": "historicidade",
    "historicismos": "historicismo",
    "historicistas": "historicista",
    "historie": "historiar",
    "historiei": "historiar",
    "historieis": "historiar",
    "historiem": "historiar",
    "historiemo": "historiar",
    "historiemos": "historiar",
    "histories": "historiar",
    "historietas": "historieta",
    "historio": "historiar",
    "historiografias": "historiografia",
    "historiográfica": "historiográfico",
    "historiográficas": "historiográfico",
    "historiográficos": "historiográfico",
    "historiologias": "historiologia",
    "historiou": "historiar",
    "historismos": "historismo",
    "historiunculas": "historiuncula",
    "historiá": "historiar",
    "historiámo": "historiar",
    "historiámos": "historiar",
    "historiáramo": "historiar",
    "historiáramos": "historiar",
    "historiárei": "historiar",
    "historiáreis": "historiar",
    "historiásseis": "historiar",
    "historiássemos": "historiar",
    "historiávamo": "historiar",
    "historiávamos": "historiar",
    "historiávei": "historiar",
    "historiáveis": "historiável",
    "historiógrafa": "historiógrafo",
    "historiógrafas": "historiógrafo",
    "historiógrafos": "historiógrafo",
    "historíolas": "historíola",
    "histotomias": "histotomia",
    "histotomistas": "histotomista",
    "histotripsias": "histotripsia",
    "histotromias": "histotromia",
    "histricídeos": "histricídeo",
    "histrionias": "histrionia",
    "histriónica": "histriónico",
    "histriónicas": "histriónico",
    "histriónicos": "histriónico",
    "histriões": "histrião",
    "histrícidas": "histrícida",
    "histérica": "histérico",
    "histéricas": "histérico",
    "histéricos": "histérico",
    "histórias": "história",
    "histórica": "histórico",
    "históricas": "histórico",
    "históricos": "histórico",
    "hititas": "hitita",
    "hitleriana": "hitleriano",
    "hitlerianas": "hitleriano",
    "hitlerianos": "hitleriano",
    "hitlerismos": "hitlerismo",
    "hitleristas": "hitlerista",
    "hits": "hit",
    "hiulca": "hiulco",
    "hiulcas": "hiulco",
    "hiulcos": "hiulco",
    "hiálitos": "hiálito",
    "hiénidas": "hiénida",
    "hióidea": "hióideo",
    "hióideas": "hióideo",
    "hióideos": "hióideo",
    "hióides": "hióide",
    "hmms": "hmm",
    "hobbies": "hobby",
    "hodierna": "hodierno",
    "hodiernas": "hodierno",
    "hodiernidades": "hodiernidade",
    "hodiernos": "hodierno",
    "hodometrias": "hodometria",
    "hodométrica": "hodométrico",
    "hodométricas": "hodométrico",
    "hodométricos": "hodométrico",
    "hodoscópios": "hodoscópio",
    "hodógrafos": "hodógrafo",
    "hodómetros": "hodómetro",
    "hoffmânica": "hoffmânico",
    "hoffmânicas": "hoffmânico",
    "hoffmânicos": "hoffmânico",
    "holandas": "holanda",
    "holandesa": "holandês",
    "holandesas": "holandês",
    "holandeses": "holandês",
    "holandilhas": "holandilha",
    "holandilheira": "holandilheiro",
    "holandilheiras": "holandilheiro",
    "holandilheiros": "holandilheiro",
    "holandiza": "holandizar",
    "holandizada": "holandizar",
    "holandizadas": "holandizar",
    "holandizado": "holandizar",
    "holandizados": "holandizar",
    "holandizai": "holandizar",
    "holandizais": "holandizar",
    "holandizam": "holandizar",
    "holandizamo": "holandizar",
    "holandizamos": "holandizar",
    "holandizando": "holandizar",
    "holandizara": "holandizar",
    "holandizaram": "holandizar",
    "holandizaras": "holandizar",
    "holandizarde": "holandizar",
    "holandizardes": "holandizar",
    "holandizare": "holandizar",
    "holandizarei": "holandizar",
    "holandizareis": "holandizar",
    "holandizarem": "holandizar",
    "holandizaremos": "holandizar",
    "holandizares": "holandizar",
    "holandizaria": "holandizar",
    "holandizariam": "holandizar",
    "holandizarias": "holandizar",
    "holandizarmo": "holandizar",
    "holandizarmos": "holandizar",
    "holandizará": "holandizar",
    "holandizarás": "holandizar",
    "holandizarão": "holandizar",
    "holandizaríamos": "holandizar",
    "holandizaríeis": "holandizar",
    "holandizas": "holandizar",
    "holandizasse": "holandizar",
    "holandizassem": "holandizar",
    "holandizasses": "holandizar",
    "holandizaste": "holandizar",
    "holandizastes": "holandizar",
    "holandizava": "holandizar",
    "holandizavam": "holandizar",
    "holandizavas": "holandizar",
    "holandize": "holandizar",
    "holandizei": "holandizar",
    "holandizeis": "holandizar",
    "holandizem": "holandizar",
    "holandizemo": "holandizar",
    "holandizemos": "holandizar",
    "holandizes": "holandizar",
    "holandizo": "holandizar",
    "holandizou": "holandizar",
    "holandizá": "holandizar",
    "holandizámo": "holandizar",
    "holandizámos": "holandizar",
    "holandizáramo": "holandizar",
    "holandizáramos": "holandizar",
    "holandizárei": "holandizar",
    "holandizáreis": "holandizar",
    "holandizásseis": "holandizar",
    "holandizássemos": "holandizar",
    "holandizávamo": "holandizar",
    "holandizávamos": "holandizar",
    "holandizávei": "holandizar",
    "holandizáveis": "holandizável",
    "holdings": "holding",
    "holicismos": "holicismo",
    "holismos": "holismo",
    "hollywoodesca": "hollywoodesco",
    "hollywoodescas": "hollywoodesco",
    "hollywoodescos": "hollywoodesco",
    "holoblástica": "holoblástico",
    "holoblásticas": "holoblástico",
    "holoblásticos": "holoblástico",
    "holobrânquia": "holobrânquio",
    "holobrânquias": "holobrânquio",
    "holobrânquios": "holobrânquio",
    "holocarpa": "holocarpo",
    "holocarpas": "holocarpo",
    "holocarpos": "holocarpo",
    "holocaustos": "holocausto",
    "holocenos": "holoceno",
    "holocristalina": "holocristalino",
    "holocristalinas": "holocristalino",
    "holocristalinos": "holocristalino",
    "holocrínica": "holocrínico",
    "holocrínicas": "holocrínico",
    "holocrínicos": "holocrínico",
    "holocéfala": "holocéfalo",
    "holocéfalas": "holocéfalo",
    "holocéfalos": "holocéfalo",
    "holocénicos": "holocénico",
    "holoedrias": "holoedria",
    "holoedros": "holoedro",
    "holofotes": "holofote",
    "holofrástica": "holofrástico",
    "holofrásticas": "holofrástico",
    "holofrásticos": "holofrástico",
    "holofítica": "holofítico",
    "holofíticas": "holofítico",
    "holofíticos": "holofítico",
    "hologamias": "hologamia",
    "holografias": "holografia",
    "hologramas": "holograma",
    "holográfica": "holográfico",
    "holográficas": "holográfico",
    "holográficos": "holográfico",
    "hologéneses": "hologénese",
    "holometabólica": "holometabólico",
    "holometabólicas": "holometabólico",
    "holometabólicos": "holometabólico",
    "holomorfismos": "holomorfismo",
    "holométrica": "holométrico",
    "holométricas": "holométrico",
    "holométricos": "holométrico",
    "holomórfica": "holomórfico",
    "holomórficas": "holomórfico",
    "holomórficos": "holomórfico",
    "holonomias": "holonomia",
    "holopatias": "holopatia",
    "holotomias": "holotomia",
    "holoturióides": "holoturióide",
    "holoturídeos": "holoturídeo",
    "holoturóides": "holoturóide",
    "holotúrias": "holotúria",
    "holozóica": "holozóico",
    "holozóicas": "holozóico",
    "holozóicos": "holozóico",
    "holoédrica": "holoédrico",
    "holoédricas": "holoédrico",
    "holoédricos": "holoédrico",
    "holócrina": "holócrino",
    "holócrinas": "holócrino",
    "holócrinos": "holócrino",
    "hológrafa": "hológrafo",
    "hológrafas": "hológrafo",
    "hológrafos": "hológrafo",
    "holómetros": "holómetro",
    "holósidos": "holósido",
    "holótipos": "holótipo",
    "holótrica": "holótrico",
    "holótricas": "holótrico",
    "holótricos": "holótrico",
    "homalofila": "homalofilo",
    "homalofilas": "homalofilo",
    "homalofilos": "homalofilo",
    "homalográfica": "homalográfico",
    "homalográficas": "homalográfico",
    "homalográficos": "homalográfico",
    "homaloidais": "homaloidal",
    "hombos": "hombo",
    "hombridades": "hombridade",
    "homenageada": "homenagear",
    "homenageadas": "homenagear",
    "homenageado": "homenagear",
    "homenageados": "homenagear",
    "homenageai": "homenagear",
    "homenageais": "homenagear",
    "homenageamo": "homenagear",
    "homenageamos": "homenagear",
    "homenageando": "homenagear",
    "homenageara": "homenagear",
    "homenagearam": "homenagear",
    "homenagearas": "homenagear",
    "homenagearde": "homenagear",
    "homenageardes": "homenagear",
    "homenageare": "homenagear",
    "homenagearei": "homenagear",
    "homenageareis": "homenagear",
    "homenagearem": "homenagear",
    "homenagearemos": "homenagear",
    "homenageares": "homenagear",
    "homenagearia": "homenagear",
    "homenageariam": "homenagear",
    "homenagearias": "homenagear",
    "homenagearmo": "homenagear",
    "homenagearmos": "homenagear",
    "homenageará": "homenagear",
    "homenagearás": "homenagear",
    "homenagearão": "homenagear",
    "homenagearíamos": "homenagear",
    "homenagearíeis": "homenagear",
    "homenageasse": "homenagear",
    "homenageassem": "homenagear",
    "homenageasses": "homenagear",
    "homenageaste": "homenagear",
    "homenageastes": "homenagear",
    "homenageava": "homenagear",
    "homenageavam": "homenagear",
    "homenageavas": "homenagear",
    "homenageei": "homenagear",
    "homenageeis": "homenagear",
    "homenageemo": "homenagear",
    "homenageemos": "homenagear",
    "homenageia": "homenagear",
    "homenageiam": "homenagear",
    "homenageias": "homenagear",
    "homenageie": "homenagear",
    "homenageiem": "homenagear",
    "homenageies": "homenagear",
    "homenageio": "homenagear",
    "homenagens": "homenagem",
    "homenageou": "homenagear",
    "homenageá": "homenagear",
    "homenageámo": "homenagear",
    "homenageámos": "homenagear",
    "homenageáramo": "homenagear",
    "homenageáramos": "homenagear",
    "homenageárei": "homenagear",
    "homenageáreis": "homenagear",
    "homenageásseis": "homenagear",
    "homenageássemos": "homenagear",
    "homenageávamo": "homenagear",
    "homenageávamos": "homenagear",
    "homenageávei": "homenagear",
    "homenageáveis": "homenagear",
    "homens": "homem",
    "homenzarrões": "homenzarrão",
    "homenzinho": "homem",
    "homenzinhos": "homem",
    "homenzito": "homem",
    "homenzitos": "homem",
    "homeometrias": "homeometria",
    "homeomorfa": "homeomorfo",
    "homeomorfas": "homeomorfo",
    "homeomorfismos": "homeomorfismo",
    "homeomorfos": "homeomorfo",
    "homeopatas": "homeopata",
    "homeopatias": "homeopatia",
    "homeoptota": "homeoptoto",
    "homeoptotas": "homeoptoto",
    "homeoptotos": "homeoptoto",
    "homeoptótons": "homeoptóton",
    "homeopática": "homeopático",
    "homeopáticas": "homeopático",
    "homeopáticos": "homeopático",
    "homeoses": "homeose",
    "homeostases": "homeostase",
    "homeoteleutos": "homeoteleuto",
    "homeotelêutons": "homeotelêuton",
    "homeoterma": "homeotermo",
    "homeotermas": "homeotermo",
    "homeotermos": "homeotermo",
    "homeotropias": "homeotropia",
    "homeotérmica": "homeotérmico",
    "homeotérmicas": "homeotérmico",
    "homeotérmicos": "homeotérmico",
    "homeozóica": "homeozóico",
    "homeozóicas": "homeozóico",
    "homeozóicos": "homeozóico",
    "homeómera": "homeómero",
    "homeómeras": "homeómero",
    "homeómeres": "homeómere",
    "homeómeros": "homeómero",
    "homeóstases": "homeóstase",
    "homeótropa": "homeótropo",
    "homeótropas": "homeótropo",
    "homeótropos": "homeótropo",
    "homicidas": "homicida",
    "homicídios": "homicídio",
    "homilia": "homiliar",
    "homiliada": "homiliar",
    "homiliadas": "homiliar",
    "homiliado": "homiliar",
    "homiliados": "homiliar",
    "homiliai": "homiliar",
    "homiliais": "homiliar",
    "homiliam": "homiliar",
    "homiliamo": "homiliar",
    "homiliamos": "homiliar",
    "homiliando": "homiliar",
    "homiliara": "homiliar",
    "homiliaram": "homiliar",
    "homiliaras": "homiliar",
    "homiliarde": "homiliar",
    "homiliardes": "homiliar",
    "homiliare": "homiliar",
    "homiliarei": "homiliar",
    "homiliareis": "homiliar",
    "homiliarem": "homiliar",
    "homiliaremos": "homiliar",
    "homiliares": "homiliar",
    "homiliaria": "homiliar",
    "homiliariam": "homiliar",
    "homiliarias": "homiliar",
    "homiliarmo": "homiliar",
    "homiliarmos": "homiliar",
    "homiliará": "homiliar",
    "homiliarás": "homiliar",
    "homiliarão": "homiliar",
    "homiliaríamos": "homiliar",
    "homiliaríeis": "homiliar",
    "homilias": "homiliar",
    "homiliasse": "homiliar",
    "homiliassem": "homiliar",
    "homiliasses": "homiliar",
    "homiliastas": "homiliasta",
    "homiliaste": "homiliar",
    "homiliastes": "homiliar",
    "homiliava": "homiliar",
    "homiliavam": "homiliar",
    "homiliavas": "homiliar",
    "homilie": "homiliar",
    "homiliei": "homiliar",
    "homilieis": "homiliar",
    "homiliem": "homiliar",
    "homiliemo": "homiliar",
    "homiliemos": "homiliar",
    "homilies": "homiliar",
    "homilio": "homiliar",
    "homiliou": "homiliar",
    "homiliá": "homiliar",
    "homiliámo": "homiliar",
    "homiliámos": "homiliar",
    "homiliáramo": "homiliar",
    "homiliáramos": "homiliar",
    "homiliárei": "homiliar",
    "homiliáreis": "homiliar",
    "homiliários": "homiliário",
    "homiliásseis": "homiliar",
    "homiliássemos": "homiliar",
    "homiliávamo": "homiliar",
    "homiliávamos": "homiliar",
    "homiliávei": "homiliar",
    "homiliáveis": "homiliar",
    "hominais": "hominal",
    "hominalidades": "hominalidade",
    "hominiculturas": "hominicultura",
    "hominizações": "hominização",
    "hominícolas": "hominícola",
    "hominídea": "hominídeo",
    "hominídeas": "hominídeo",
    "hominídeos": "hominídeo",
    "hominívora": "hominívoro",
    "hominívoras": "hominívoro",
    "hominívoros": "hominívoro",
    "homizia": "homiziar",
    "homiziada": "homiziar",
    "homiziadas": "homiziar",
    "homiziado": "homiziar",
    "homiziados": "homiziar",
    "homiziai": "homiziar",
    "homiziais": "homiziar",
    "homiziam": "homiziar",
    "homiziamo": "homiziar",
    "homiziamos": "homiziar",
    "homiziando": "homiziar",
    "homiziara": "homiziar",
    "homiziaram": "homiziar",
    "homiziaras": "homiziar",
    "homiziarde": "homiziar",
    "homiziardes": "homiziar",
    "homiziare": "homiziar",
    "homiziarei": "homiziar",
    "homiziareis": "homiziar",
    "homiziarem": "homiziar",
    "homiziaremos": "homiziar",
    "homiziares": "homiziar",
    "homiziaria": "homiziar",
    "homiziariam": "homiziar",
    "homiziarias": "homiziar",
    "homiziarmo": "homiziar",
    "homiziarmos": "homiziar",
    "homiziará": "homiziar",
    "homiziarás": "homiziar",
    "homiziarão": "homiziar",
    "homiziaríamos": "homiziar",
    "homiziaríeis": "homiziar",
    "homizias": "homiziar",
    "homiziasse": "homiziar",
    "homiziassem": "homiziar",
    "homiziasses": "homiziar",
    "homiziaste": "homiziar",
    "homiziastes": "homiziar",
    "homiziava": "homiziar",
    "homiziavam": "homiziar",
    "homiziavas": "homiziar",
    "homiziações": "homiziação",
    "homizie": "homiziar",
    "homiziei": "homiziar",
    "homizieis": "homiziar",
    "homiziem": "homiziar",
    "homiziemo": "homiziar",
    "homiziemos": "homiziar",
    "homizies": "homiziar",
    "homizio": "homiziar",
    "homizios": "homizio",
    "homiziou": "homiziar",
    "homiziá": "homiziar",
    "homiziámo": "homiziar",
    "homiziámos": "homiziar",
    "homiziáramo": "homiziar",
    "homiziáramos": "homiziar",
    "homiziárei": "homiziar",
    "homiziáreis": "homiziar",
    "homiziásseis": "homiziar",
    "homiziássemos": "homiziar",
    "homiziávamo": "homiziar",
    "homiziávamos": "homiziar",
    "homiziávei": "homiziar",
    "homiziáveis": "homiziar",
    "homocatalexias": "homocatalexia",
    "homocentricidades": "homocentricidade",
    "homocentros": "homocentro",
    "homocerca": "homocerco",
    "homocercas": "homocerco",
    "homocercos": "homocerco",
    "homocroma": "homocromo",
    "homocromas": "homocromo",
    "homocromias": "homocromia",
    "homocromos": "homocromo",
    "homocêntrica": "homocêntrico",
    "homocêntricas": "homocêntrico",
    "homocêntricos": "homocêntrico",
    "homocíclica": "homocíclico",
    "homocíclicas": "homocíclico",
    "homocíclicos": "homocíclico",
    "homoderma": "homodermo",
    "homodermas": "homodermo",
    "homodermos": "homodermo",
    "homodontes": "homodonte",
    "homodésmica": "homodésmico",
    "homodésmicas": "homodésmico",
    "homodésmicos": "homodésmico",
    "homofagias": "homofagia",
    "homofila": "homofilo",
    "homofilas": "homofilo",
    "homofilos": "homofilo",
    "homofonias": "homofonia",
    "homofonismos": "homofonismo",
    "homofonologias": "homofonologia",
    "homofonógrafa": "homofonógrafo",
    "homofonógrafas": "homofonógrafo",
    "homofonógrafos": "homofonógrafo",
    "homofónica": "homofónico",
    "homofónicas": "homofónico",
    "homofónicos": "homofónico",
    "homogamias": "homogamia",
    "homogeneidades": "homogeneidade",
    "homogeneiza": "homogeneizar",
    "homogeneizada": "homogeneizar",
    "homogeneizadas": "homogeneizar",
    "homogeneizado": "homogeneizar",
    "homogeneizadores": "homogeneizador",
    "homogeneizados": "homogeneizar",
    "homogeneizai": "homogeneizar",
    "homogeneizais": "homogeneizar",
    "homogeneizam": "homogeneizar",
    "homogeneizamo": "homogeneizar",
    "homogeneizamos": "homogeneizar",
    "homogeneizando": "homogeneizar",
    "homogeneizara": "homogeneizar",
    "homogeneizaram": "homogeneizar",
    "homogeneizaras": "homogeneizar",
    "homogeneizarde": "homogeneizar",
    "homogeneizardes": "homogeneizar",
    "homogeneizare": "homogeneizar",
    "homogeneizarei": "homogeneizar",
    "homogeneizareis": "homogeneizar",
    "homogeneizarem": "homogeneizar",
    "homogeneizaremos": "homogeneizar",
    "homogeneizares": "homogeneizar",
    "homogeneizaria": "homogeneizar",
    "homogeneizariam": "homogeneizar",
    "homogeneizarias": "homogeneizar",
    "homogeneizarmo": "homogeneizar",
    "homogeneizarmos": "homogeneizar",
    "homogeneizará": "homogeneizar",
    "homogeneizarás": "homogeneizar",
    "homogeneizarão": "homogeneizar",
    "homogeneizaríamos": "homogeneizar",
    "homogeneizaríeis": "homogeneizar",
    "homogeneizas": "homogeneizar",
    "homogeneizasse": "homogeneizar",
    "homogeneizassem": "homogeneizar",
    "homogeneizasses": "homogeneizar",
    "homogeneizaste": "homogeneizar",
    "homogeneizastes": "homogeneizar",
    "homogeneizava": "homogeneizar",
    "homogeneizavam": "homogeneizar",
    "homogeneizavas": "homogeneizar",
    "homogeneizações": "homogeneização",
    "homogeneize": "homogeneizar",
    "homogeneizei": "homogeneizar",
    "homogeneizeis": "homogeneizar",
    "homogeneizem": "homogeneizar",
    "homogeneizemo": "homogeneizar",
    "homogeneizemos": "homogeneizar",
    "homogeneizes": "homogeneizar",
    "homogeneizo": "homogeneizar",
    "homogeneizou": "homogeneizar",
    "homogeneizá": "homogeneizar",
    "homogeneizámo": "homogeneizar",
    "homogeneizámos": "homogeneizar",
    "homogeneizáramo": "homogeneizar",
    "homogeneizáramos": "homogeneizar",
    "homogeneizárei": "homogeneizar",
    "homogeneizáreis": "homogeneizar",
    "homogeneizásseis": "homogeneizar",
    "homogeneizássemos": "homogeneizar",
    "homogeneizávamo": "homogeneizar",
    "homogeneizávamos": "homogeneizar",
    "homogeneizávei": "homogeneizar",
    "homogeneizáveis": "homogeneizável",
    "homogenesias": "homogenesia",
    "homogenias": "homogenia",
    "homografias": "homografia",
    "homográfica": "homográfico",
    "homográficas": "homográfico",
    "homográficos": "homográfico",
    "homogénea": "homogéneo",
    "homogéneas": "homogéneo",
    "homogéneos": "homogéneo",
    "homogéneses": "homogénese",
    "homolecítica": "homolecítico",
    "homolecíticas": "homolecítico",
    "homolecíticos": "homolecítico",
    "homologa": "homologar",
    "homologada": "homologar",
    "homologadas": "homologar",
    "homologado": "homologar",
    "homologados": "homologar",
    "homologai": "homologar",
    "homologais": "homologar",
    "homologam": "homologar",
    "homologamo": "homologar",
    "homologamos": "homologar",
    "homologando": "homologar",
    "homologara": "homologar",
    "homologaram": "homologar",
    "homologaras": "homologar",
    "homologarde": "homologar",
    "homologardes": "homologar",
    "homologare": "homologar",
    "homologarei": "homologar",
    "homologareis": "homologar",
    "homologarem": "homologar",
    "homologaremos": "homologar",
    "homologares": "homologar",
    "homologaria": "homologar",
    "homologariam": "homologar",
    "homologarias": "homologar",
    "homologarmo": "homologar",
    "homologarmos": "homologar",
    "homologará": "homologar",
    "homologarás": "homologar",
    "homologarão": "homologar",
    "homologaríamos": "homologar",
    "homologaríeis": "homologar",
    "homologas": "homologar",
    "homologasse": "homologar",
    "homologassem": "homologar",
    "homologasses": "homologar",
    "homologaste": "homologar",
    "homologastes": "homologar",
    "homologatória": "homologatório",
    "homologatórias": "homologatório",
    "homologatórios": "homologatório",
    "homologava": "homologar",
    "homologavam": "homologar",
    "homologavas": "homologar",
    "homologações": "homologação",
    "homologias": "homologia",
    "homologo": "homologar",
    "homologou": "homologar",
    "homologue": "homologar",
    "homologuei": "homologar",
    "homologueis": "homologar",
    "homologuem": "homologar",
    "homologuemo": "homologar",
    "homologuemos": "homologar",
    "homologues": "homologar",
    "homologá": "homologar",
    "homologámo": "homologar",
    "homologámos": "homologar",
    "homologáramo": "homologar",
    "homologáramos": "homologar",
    "homologárei": "homologar",
    "homologáreis": "homologar",
    "homologásseis": "homologar",
    "homologássemos": "homologar",
    "homologávamo": "homologar",
    "homologávamos": "homologar",
    "homologávei": "homologar",
    "homologáveis": "homologar",
    "homolítica": "homolítico",
    "homolíticas": "homolítico",
    "homolíticos": "homolítico",
    "homológica": "homológico",
    "homológicas": "homológico",
    "homológicos": "homológico",
    "homomerias": "homomeria",
    "homomerologias": "homomerologia",
    "homomorfa": "homomorfo",
    "homomorfas": "homomorfo",
    "homomorfismos": "homomorfismo",
    "homomorfos": "homomorfo",
    "homométrica": "homométrico",
    "homométricas": "homométrico",
    "homométricos": "homométrico",
    "homonomias": "homonomia",
    "homonucleares": "homonuclear",
    "homonímias": "homonímia",
    "homonímica": "homonímico",
    "homonímicas": "homonímico",
    "homonímicos": "homonímico",
    "homonómica": "homonómico",
    "homonómicas": "homonómico",
    "homonómicos": "homonómico",
    "homoplanasias": "homoplanasia",
    "homoplasias": "homoplasia",
    "homoplástica": "homoplástico",
    "homoplásticas": "homoplástico",
    "homoplásticos": "homoplástico",
    "homopolares": "homopolar",
    "homoptotos": "homoptoto",
    "homoptótons": "homoptóton",
    "homopétala": "homopétalo",
    "homopétalas": "homopétalo",
    "homopétalos": "homopétalo",
    "homorgânica": "homorgânico",
    "homorgânicas": "homorgânico",
    "homorgânicos": "homorgânico",
    "homoses": "homose",
    "homossexuais": "homossexual",
    "homossexualidades": "homossexualidade",
    "homossexualismos": "homossexualismo",
    "homotalismos": "homotalismo",
    "homotaxias": "homotaxia",
    "homoterma": "homotermo",
    "homotermais": "homotermal",
    "homotermas": "homotermo",
    "homotermos": "homotermo",
    "homotesias": "homotesia",
    "homotetias": "homotetia",
    "homotipias": "homotipia",
    "homotropias": "homotropia",
    "homotálica": "homotálico",
    "homotálicas": "homotálico",
    "homotálicos": "homotálico",
    "homotérmica": "homotérmico",
    "homotérmicas": "homotérmico",
    "homotérmicos": "homotérmico",
    "homotética": "homotético",
    "homotéticas": "homotético",
    "homotéticos": "homotético",
    "homotípica": "homotípico",
    "homotípicas": "homotípico",
    "homotípicos": "homotípico",
    "homozigótica": "homozigótico",
    "homozigóticas": "homozigótico",
    "homozigóticos": "homozigótico",
    "homuns": "homum",
    "homérica": "homérico",
    "homéricas": "homérico",
    "homéricos": "homérico",
    "homéridas": "homérida",
    "homílias": "homília",
    "homínidas": "homínida",
    "homódroma": "homódromo",
    "homódromas": "homódromo",
    "homódromos": "homódromo",
    "homófona": "homófono",
    "homófonas": "homófono",
    "homófonos": "homófono",
    "homógama": "homógamo",
    "homógamas": "homógamo",
    "homógamos": "homógamo",
    "homógrafa": "homógrafo",
    "homógrafas": "homógrafo",
    "homógrafos": "homógrafo",
    "homóloga": "homólogo",
    "homólogas": "homólogo",
    "homólogos": "homólogo",
    "homónima": "homónimo",
    "homónimas": "homónimo",
    "homónimos": "homónimo",
    "homópodes": "homópode",
    "homóptera": "homóptero",
    "homópteras": "homóptero",
    "homópteros": "homóptero",
    "homótipa": "homótipo",
    "homótipas": "homótipo",
    "homótipos": "homótipo",
    "homótona": "homótono",
    "homótonas": "homótono",
    "homótonos": "homótono",
    "homótropa": "homótropo",
    "homótropas": "homótropo",
    "homótropos": "homótropo",
    "homúncula": "homúnculo",
    "homúnculas": "homúnculo",
    "homúnculos": "homúnculo",
    "hondurenha": "hondurenho",
    "hondurenhas": "hondurenho",
    "hondurenhos": "hondurenho",
    "honesta": "honesto",
    "honestada": "honestar",
    "honestadas": "honestar",
    "honestado": "honestar",
    "honestadora": "honestador",
    "honestadoras": "honestador",
    "honestadores": "honestador",
    "honestados": "honestar",
    "honestai": "honestar",
    "honestais": "honestar",
    "honestam": "honestar",
    "honestamo": "honestar",
    "honestamos": "honestar",
    "honestando": "honestar",
    "honestara": "honestar",
    "honestaram": "honestar",
    "honestaras": "honestar",
    "honestarde": "honestar",
    "honestardes": "honestar",
    "honestare": "honestar",
    "honestarei": "honestar",
    "honestareis": "honestar",
    "honestarem": "honestar",
    "honestaremos": "honestar",
    "honestares": "honestar",
    "honestaria": "honestar",
    "honestariam": "honestar",
    "honestarias": "honestar",
    "honestarmo": "honestar",
    "honestarmos": "honestar",
    "honestará": "honestar",
    "honestarás": "honestar",
    "honestarão": "honestar",
    "honestaríamos": "honestar",
    "honestaríeis": "honestar",
    "honestas": "honesto",
    "honestasse": "honestar",
    "honestassem": "honestar",
    "honestasses": "honestar",
    "honestaste": "honestar",
    "honestastes": "honestar",
    "honestava": "honestar",
    "honestavam": "honestar",
    "honestavas": "honestar",
    "honeste": "honestar",
    "honestei": "honestar",
    "honesteis": "honestar",
    "honestem": "honestar",
    "honestemo": "honestar",
    "honestemos": "honestar",
    "honestes": "honestar",
    "honestidades": "honestidade",
    "honestiza": "honestizar",
    "honestizada": "honestizar",
    "honestizadas": "honestizar",
    "honestizado": "honestizar",
    "honestizados": "honestizar",
    "honestizai": "honestizar",
    "honestizais": "honestizar",
    "honestizam": "honestizar",
    "honestizamo": "honestizar",
    "honestizamos": "honestizar",
    "honestizando": "honestizar",
    "honestizara": "honestizar",
    "honestizaram": "honestizar",
    "honestizaras": "honestizar",
    "honestizarde": "honestizar",
    "honestizardes": "honestizar",
    "honestizare": "honestizar",
    "honestizarei": "honestizar",
    "honestizareis": "honestizar",
    "honestizarem": "honestizar",
    "honestizaremos": "honestizar",
    "honestizares": "honestizar",
    "honestizaria": "honestizar",
    "honestizariam": "honestizar",
    "honestizarias": "honestizar",
    "honestizarmo": "honestizar",
    "honestizarmos": "honestizar",
    "honestizará": "honestizar",
    "honestizarás": "honestizar",
    "honestizarão": "honestizar",
    "honestizaríamos": "honestizar",
    "honestizaríeis": "honestizar",
    "honestizas": "honestizar",
    "honestizasse": "honestizar",
    "honestizassem": "honestizar",
    "honestizasses": "honestizar",
    "honestizaste": "honestizar",
    "honestizastes": "honestizar",
    "honestizava": "honestizar",
    "honestizavam": "honestizar",
    "honestizavas": "honestizar",
    "honestize": "honestizar",
    "honestizei": "honestizar",
    "honestizeis": "honestizar",
    "honestizem": "honestizar",
    "honestizemo": "honestizar",
    "honestizemos": "honestizar",
    "honestizes": "honestizar",
    "honestizo": "honestizar",
    "honestizou": "honestizar",
    "honestizá": "honestizar",
    "honestizámo": "honestizar",
    "honestizámos": "honestizar",
    "honestizáramo": "honestizar",
    "honestizáramos": "honestizar",
    "honestizárei": "honestizar",
    "honestizáreis": "honestizar",
    "honestizásseis": "honestizar",
    "honestizássemos": "honestizar",
    "honestizávamo": "honestizar",
    "honestizávamos": "honestizar",
    "honestizávei": "honestizar",
    "honestizáveis": "honestizar",
    "honesto": "honestar",
    "honestos": "honesto",
    "honestou": "honestar",
    "honestá": "honestar",
    "honestámo": "honestar",
    "honestámos": "honestar",
    "honestáramo": "honestar",
    "honestáramos": "honestar",
    "honestárei": "honestar",
    "honestáreis": "honestar",
    "honestásseis": "honestar",
    "honestássemos": "honestar",
    "honestávamo": "honestar",
    "honestávamos": "honestar",
    "honestávei": "honestar",
    "honestáveis": "honestar",
    "honorabilidades": "honorabilidade",
    "honores": "honor",
    "honorifica": "honorificar",
    "honorificada": "honorificar",
    "honorificadas": "honorificar",
    "honorificado": "honorificar",
    "honorificados": "honorificar",
    "honorificai": "honorificar",
    "honorificais": "honorificar",
    "honorificam": "honorificar",
    "honorificamo": "honorificar",
    "honorificamos": "honorificar",
    "honorificando": "honorificar",
    "honorificara": "honorificar",
    "honorificaram": "honorificar",
    "honorificaras": "honorificar",
    "honorificarde": "honorificar",
    "honorificardes": "honorificar",
    "honorificare": "honorificar",
    "honorificarei": "honorificar",
    "honorificareis": "honorificar",
    "honorificarem": "honorificar",
    "honorificaremos": "honorificar",
    "honorificares": "honorificar",
    "honorificaria": "honorificar",
    "honorificariam": "honorificar",
    "honorificarias": "honorificar",
    "honorificarmo": "honorificar",
    "honorificarmos": "honorificar",
    "honorificará": "honorificar",
    "honorificarás": "honorificar",
    "honorificarão": "honorificar",
    "honorificaríamos": "honorificar",
    "honorificaríeis": "honorificar",
    "honorificas": "honorificar",
    "honorificasse": "honorificar",
    "honorificassem": "honorificar",
    "honorificasses": "honorificar",
    "honorificaste": "honorificar",
    "honorificastes": "honorificar",
    "honorificava": "honorificar",
    "honorificavam": "honorificar",
    "honorificavas": "honorificar",
    "honorifico": "honorificar",
    "honorificou": "honorificar",
    "honorificá": "honorificar",
    "honorificámo": "honorificar",
    "honorificámos": "honorificar",
    "honorificáramo": "honorificar",
    "honorificáramos": "honorificar",
    "honorificárei": "honorificar",
    "honorificáreis": "honorificar",
    "honorificásseis": "honorificar",
    "honorificássemos": "honorificar",
    "honorificávamo": "honorificar",
    "honorificávamos": "honorificar",
    "honorificávei": "honorificar",
    "honorificáveis": "honorificar",
    "honorificências": "honorificência",
    "honorifique": "honorificar",
    "honorifiquei": "honorificar",
    "honorifiqueis": "honorificar",
    "honorifiquem": "honorificar",
    "honorifiquemo": "honorificar",
    "honorifiquemos": "honorificar",
    "honorifiques": "honorificar",
    "honorária": "honorário",
    "honorárias": "honorário",
    "honorários": "honorário",
    "honoráveis": "honorável",
    "honorífica": "honorífico",
    "honoríficas": "honorífico",
    "honoríficos": "honorífico",
    "honra": "honrar",
    "honrada": "honrar",
    "honradas": "honrar",
    "honradezes": "honradez",
    "honrado": "honrar",
    "honrados": "honrar",
    "honrai": "honrar",
    "honrais": "honrar",
    "honram": "honrar",
    "honramo": "honrar",
    "honramos": "honrar",
    "honrando": "honrar",
    "honrara": "honrar",
    "honraram": "honrar",
    "honraras": "honrar",
    "honrarde": "honrar",
    "honrardes": "honrar",
    "honrare": "honrar",
    "honrarei": "honrar",
    "honrareis": "honrar",
    "honrarem": "honrar",
    "honraremos": "honrar",
    "honrares": "honrar",
    "honraria": "honrar",
    "honrariam": "honrar",
    "honrarias": "honraria",
    "honrarmo": "honrar",
    "honrarmos": "honrar",
    "honrará": "honrar",
    "honrarás": "honrar",
    "honrarão": "honrar",
    "honraríamos": "honrar",
    "honraríeis": "honrar",
    "honras": "honrar",
    "honrasse": "honrar",
    "honrassem": "honrar",
    "honrasses": "honrar",
    "honraste": "honrar",
    "honrastes": "honrar",
    "honrava": "honrar",
    "honravam": "honrar",
    "honravas": "honrar",
    "honre": "honrar",
    "honrei": "honrar",
    "honreis": "honrar",
    "honrem": "honrar",
    "honremo": "honrar",
    "honremos": "honrar",
    "honres": "honrar",
    "honro": "honrar",
    "honrosa": "honroso",
    "honrosas": "honroso",
    "honrosos": "honroso",
    "honrou": "honrar",
    "honrá": "honrar",
    "honrámo": "honrar",
    "honrámos": "honrar",
    "honráramo": "honrar",
    "honráramos": "honrar",
    "honrárei": "honrar",
    "honráreis": "honrar",
    "honrásseis": "honrar",
    "honrássemos": "honrar",
    "honrávamo": "honrar",
    "honrávamos": "honrar",
    "honrávei": "honrar",
    "honráveis": "honrar",
    "hooligans": "hooligan",
    "hoplitas": "hoplita",
    "hoplotecas": "hoploteca",
    "hoplómacos": "hoplómaco",
    "hora": "horar",
    "horaciana": "horaciano",
    "horacianas": "horaciano",
    "horacianos": "horaciano",
    "horada": "horar",
    "horadas": "horar",
    "horado": "horar",
    "horados": "horar",
    "horai": "horar",
    "horais": "horar",
    "horam": "horar",
    "horamo": "horar",
    "horamos": "horar",
    "horando": "horar",
    "horara": "horar",
    "horaram": "horar",
    "horaras": "horar",
    "horardes": "horar",
    "horarei": "horar",
    "horareis": "horar",
    "horarem": "horar",
    "horaremos": "horar",
    "horares": "horar",
    "horaria": "horar",
    "horariam": "horar",
    "horarias": "horar",
    "horarmo": "horar",
    "horarmos": "horar",
    "horará": "horar",
    "horarás": "horar",
    "horarão": "horar",
    "horaríamos": "horar",
    "horaríeis": "horar",
    "horas": "horar",
    "horasse": "horar",
    "horassem": "horar",
    "horasses": "horar",
    "horaste": "horar",
    "horastes": "horar",
    "horava": "horar",
    "horavam": "horar",
    "horavas": "horar",
    "horazinha": "hora",
    "horazinhas": "hora",
    "horazita": "hora",
    "horazitas": "hora",
    "hordas": "horda",
    "hordeácea": "hordeáceo",
    "hordeáceas": "hordeáceo",
    "hordeáceos": "hordeáceo",
    "hordéolos": "hordéolo",
    "hore": "horar",
    "horei": "horar",
    "horeis": "horar",
    "horem": "horar",
    "horemo": "horar",
    "horemos": "horar",
    "hores": "horar",
    "horinha": "hora",
    "horinhas": "hora",
    "horita": "hora",
    "horitas": "hora",
    "horizontais": "horizontal",
    "horizontalidades": "horizontalidade",
    "horizontalismos": "horizontalismo",
    "horizontes": "horizonte",
    "hormogónios": "hormogónio",
    "hormonais": "hormonal",
    "hormonas": "hormona",
    "hormonoterapias": "hormonoterapia",
    "hornaveques": "hornaveque",
    "hornblendas": "hornblenda",
    "horneblendas": "horneblenda",
    "horo": "horar",
    "horografias": "horografia",
    "horográfica": "horográfico",
    "horográficas": "horográfico",
    "horográficos": "horográfico",
    "horologiais": "horologial",
    "horológios": "horológio",
    "horoscopias": "horoscopia",
    "horoscopistas": "horoscopista",
    "horoscópios": "horoscópio",
    "horou": "horar",
    "horrenda": "horrendo",
    "horrendas": "horrendo",
    "horrendos": "horrendo",
    "horrentes": "horrente",
    "horribilidades": "horribilidade",
    "horripila": "horripilar",
    "horripilada": "horripilar",
    "horripiladas": "horripilar",
    "horripilado": "horripilar",
    "horripiladores": "horripilador",
    "horripilados": "horripilar",
    "horripilai": "horripilar",
    "horripilais": "horripilar",
    "horripilam": "horripilar",
    "horripilamo": "horripilar",
    "horripilamos": "horripilar",
    "horripilando": "horripilar",
    "horripilantes": "horripilante",
    "horripilara": "horripilar",
    "horripilaram": "horripilar",
    "horripilaras": "horripilar",
    "horripilarde": "horripilar",
    "horripilardes": "horripilar",
    "horripilare": "horripilar",
    "horripilarei": "horripilar",
    "horripilareis": "horripilar",
    "horripilarem": "horripilar",
    "horripilaremos": "horripilar",
    "horripilares": "horripilar",
    "horripilaria": "horripilar",
    "horripilariam": "horripilar",
    "horripilarias": "horripilar",
    "horripilarmo": "horripilar",
    "horripilarmos": "horripilar",
    "horripilará": "horripilar",
    "horripilarás": "horripilar",
    "horripilarão": "horripilar",
    "horripilaríamos": "horripilar",
    "horripilaríeis": "horripilar",
    "horripilas": "horripilar",
    "horripilasse": "horripilar",
    "horripilassem": "horripilar",
    "horripilasses": "horripilar",
    "horripilaste": "horripilar",
    "horripilastes": "horripilar",
    "horripilava": "horripilar",
    "horripilavam": "horripilar",
    "horripilavas": "horripilar",
    "horripilações": "horripilação",
    "horripile": "horripilar",
    "horripilei": "horripilar",
    "horripileis": "horripilar",
    "horripilem": "horripilar",
    "horripilemo": "horripilar",
    "horripilemos": "horripilar",
    "horripiles": "horripilar",
    "horripilo": "horripilar",
    "horripilou": "horripilar",
    "horripilá": "horripilar",
    "horripilámo": "horripilar",
    "horripilámos": "horripilar",
    "horripiláramo": "horripilar",
    "horripiláramos": "horripilar",
    "horripilárei": "horripilar",
    "horripiláreis": "horripilar",
    "horripilásseis": "horripilar",
    "horripilássemos": "horripilar",
    "horripilávamo": "horripilar",
    "horripilávamos": "horripilar",
    "horripilávei": "horripilar",
    "horripiláveis": "horripilar",
    "horritroantes": "horritroante",
    "horrores": "horror",
    "horroriza": "horrorizar",
    "horrorizada": "horrorizar",
    "horrorizadas": "horrorizar",
    "horrorizado": "horrorizar",
    "horrorizados": "horrorizar",
    "horrorizai": "horrorizar",
    "horrorizais": "horrorizar",
    "horrorizam": "horrorizar",
    "horrorizamo": "horrorizar",
    "horrorizamos": "horrorizar",
    "horrorizando": "horrorizar",
    "horrorizara": "horrorizar",
    "horrorizaram": "horrorizar",
    "horrorizaras": "horrorizar",
    "horrorizarde": "horrorizar",
    "horrorizardes": "horrorizar",
    "horrorizare": "horrorizar",
    "horrorizarei": "horrorizar",
    "horrorizareis": "horrorizar",
    "horrorizarem": "horrorizar",
    "horrorizaremos": "horrorizar",
    "horrorizares": "horrorizar",
    "horrorizaria": "horrorizar",
    "horrorizariam": "horrorizar",
    "horrorizarias": "horrorizar",
    "horrorizarmo": "horrorizar",
    "horrorizarmos": "horrorizar",
    "horrorizará": "horrorizar",
    "horrorizarás": "horrorizar",
    "horrorizarão": "horrorizar",
    "horrorizaríamos": "horrorizar",
    "horrorizaríeis": "horrorizar",
    "horrorizas": "horrorizar",
    "horrorizasse": "horrorizar",
    "horrorizassem": "horrorizar",
    "horrorizasses": "horrorizar",
    "horrorizaste": "horrorizar",
    "horrorizastes": "horrorizar",
    "horrorizava": "horrorizar",
    "horrorizavam": "horrorizar",
    "horrorizavas": "horrorizar",
    "horrorize": "horrorizar",
    "horrorizei": "horrorizar",
    "horrorizeis": "horrorizar",
    "horrorizem": "horrorizar",
    "horrorizemo": "horrorizar",
    "horrorizemos": "horrorizar",
    "horrorizes": "horrorizar",
    "horrorizo": "horrorizar",
    "horrorizou": "horrorizar",
    "horrorizá": "horrorizar",
    "horrorizámo": "horrorizar",
    "horrorizámos": "horrorizar",
    "horrorizáramo": "horrorizar",
    "horrorizáramos": "horrorizar",
    "horrorizárei": "horrorizar",
    "horrorizáreis": "horrorizar",
    "horrorizásseis": "horrorizar",
    "horrorizássemos": "horrorizar",
    "horrorizávamo": "horrorizar",
    "horrorizávamos": "horrorizar",
    "horrorizávei": "horrorizar",
    "horrorizáveis": "horrorizar",
    "horrorosa": "horroroso",
    "horrorosas": "horroroso",
    "horrorosos": "horroroso",
    "horrorífica": "horrorífico",
    "horroríficas": "horrorífico",
    "horroríficos": "horrorífico",
    "horrífera": "horrífero",
    "horríferas": "horrífero",
    "horríferos": "horrífero",
    "horrífica": "horrífico",
    "horríficas": "horrífico",
    "horríficos": "horrífico",
    "horríssona": "horríssono",
    "horríssonas": "horríssono",
    "horríssonos": "horríssono",
    "horríveis": "horrível",
    "horsas": "horsa",
    "horta": "hortar",
    "hortada": "hortar",
    "hortadas": "hortar",
    "hortado": "hortar",
    "hortados": "hortar",
    "hortai": "hortar",
    "hortais": "hortar",
    "hortaliceira": "hortaliceiro",
    "hortaliceiras": "hortaliceiro",
    "hortaliceiros": "hortaliceiro",
    "hortaliças": "hortaliça",
    "hortaliçazinha": "hortaliça",
    "hortaliçazinhas": "hortaliça",
    "hortaliçazita": "hortaliça",
    "hortaliçazitas": "hortaliça",
    "hortam": "hortar",
    "hortamo": "hortar",
    "hortamos": "hortar",
    "hortando": "hortar",
    "hortara": "hortar",
    "hortaram": "hortar",
    "hortaras": "hortar",
    "hortarde": "hortar",
    "hortardes": "hortar",
    "hortare": "hortar",
    "hortarei": "hortar",
    "hortareis": "hortar",
    "hortarem": "hortar",
    "hortaremos": "hortar",
    "hortares": "hortar",
    "hortaria": "hortar",
    "hortariam": "hortar",
    "hortarias": "hortar",
    "hortarmo": "hortar",
    "hortarmos": "hortar",
    "hortará": "hortar",
    "hortarás": "hortar",
    "hortarão": "hortar",
    "hortaríamos": "hortar",
    "hortaríeis": "hortar",
    "hortas": "hortar",
    "hortasse": "hortar",
    "hortassem": "hortar",
    "hortasses": "hortar",
    "hortaste": "hortar",
    "hortastes": "hortar",
    "hortativa": "hortativo",
    "hortativas": "hortativo",
    "hortativos": "hortativo",
    "hortava": "hortar",
    "hortavam": "hortar",
    "hortavas": "hortar",
    "horte": "hortar",
    "hortei": "hortar",
    "horteis": "hortar",
    "hortejos": "hortejo",
    "horteloa": "hortelão",
    "horteloas": "hortelão",
    "hortelãs": "hortelã",
    "hortelões": "hortelão",
    "hortem": "hortar",
    "hortemo": "hortar",
    "hortemos": "hortar",
    "hortenses": "hortense",
    "hortes": "hortar",
    "horticultora": "horticultor",
    "horticultoras": "horticultor",
    "horticultores": "horticultor",
    "horticulturas": "horticultura",
    "hortifrutícolas": "hortifrutícola",
    "horto": "hortar",
    "hortos": "horto",
    "hortou": "hortar",
    "hortulanas": "hortulana",
    "hortá": "hortar",
    "hortámo": "hortar",
    "hortámos": "hortar",
    "hortáramo": "hortar",
    "hortáramos": "hortar",
    "hortárei": "hortar",
    "hortáreis": "hortar",
    "hortásseis": "hortar",
    "hortássemos": "hortar",
    "hortávamo": "hortar",
    "hortávamos": "hortar",
    "hortávei": "hortar",
    "hortáveis": "hortar",
    "hortênsias": "hortênsia",
    "hortícolas": "hortícola",
    "horámo": "horar",
    "horámos": "horar",
    "horáramo": "horar",
    "horáramos": "horar",
    "horáreis": "horar",
    "horária": "horário",
    "horárias": "horário",
    "horários": "horário",
    "horásseis": "horar",
    "horássemos": "horar",
    "horávamo": "horar",
    "horávamos": "horar",
    "horáveis": "horar",
    "horóscopos": "horóscopo",
    "hosanas": "hosana",
    "hosca": "hosco",
    "hoscas": "hosco",
    "hoscos": "hosco",
    "hospeda": "hospedar",
    "hospedada": "hospedar",
    "hospedadas": "hospedar",
    "hospedado": "hospedar",
    "hospedadora": "hospedador",
    "hospedadoras": "hospedador",
    "hospedadores": "hospedador",
    "hospedados": "hospedar",
    "hospedagens": "hospedagem",
    "hospedai": "hospedar",
    "hospedais": "hospedar",
    "hospedam": "hospedar",
    "hospedamo": "hospedar",
    "hospedamos": "hospedar",
    "hospedando": "hospedar",
    "hospedara": "hospedar",
    "hospedaram": "hospedar",
    "hospedaras": "hospedar",
    "hospedarde": "hospedar",
    "hospedardes": "hospedar",
    "hospedare": "hospedar",
    "hospedarei": "hospedar",
    "hospedareis": "hospedar",
    "hospedarem": "hospedar",
    "hospedaremos": "hospedar",
    "hospedares": "hospedar",
    "hospedaria": "hospedar",
    "hospedariam": "hospedar",
    "hospedarias": "hospedar",
    "hospedarmo": "hospedar",
    "hospedarmos": "hospedar",
    "hospedará": "hospedar",
    "hospedarás": "hospedar",
    "hospedarão": "hospedar",
    "hospedaríamos": "hospedar",
    "hospedaríeis": "hospedar",
    "hospedas": "hospedar",
    "hospedasse": "hospedar",
    "hospedassem": "hospedar",
    "hospedasses": "hospedar",
    "hospedaste": "hospedar",
    "hospedastes": "hospedar",
    "hospedava": "hospedar",
    "hospedavam": "hospedar",
    "hospedavas": "hospedar",
    "hospede": "hospedar",
    "hospedei": "hospedar",
    "hospedeira": "hospedeiro",
    "hospedeiras": "hospedeiro",
    "hospedeiros": "hospedeiro",
    "hospedeis": "hospedar",
    "hospedem": "hospedar",
    "hospedemo": "hospedar",
    "hospedemos": "hospedar",
    "hospedes": "hospedar",
    "hospedo": "hospedar",
    "hospedou": "hospedar",
    "hospedá": "hospedar",
    "hospedámo": "hospedar",
    "hospedámos": "hospedar",
    "hospedáramo": "hospedar",
    "hospedáramos": "hospedar",
    "hospedárei": "hospedar",
    "hospedáreis": "hospedar",
    "hospedásseis": "hospedar",
    "hospedássemos": "hospedar",
    "hospedávamo": "hospedar",
    "hospedávamos": "hospedar",
    "hospedávei": "hospedar",
    "hospedáveis": "hospedável",
    "hospitaes": "hospita",
    "hospitais": "hospital",
    "hospitalara": "hospitalar",
    "hospitalaras": "hospitalar",
    "hospitalares": "hospitalar",
    "hospitaleira": "hospitaleiro",
    "hospitaleiras": "hospitaleiro",
    "hospitaleiros": "hospitaleiro",
    "hospitalidades": "hospitalidade",
    "hospitaliza": "hospitalizar",
    "hospitalizada": "hospitalizar",
    "hospitalizadas": "hospitalizar",
    "hospitalizado": "hospitalizar",
    "hospitalizados": "hospitalizar",
    "hospitalizai": "hospitalizar",
    "hospitalizais": "hospitalizar",
    "hospitalizam": "hospitalizar",
    "hospitalizamo": "hospitalizar",
    "hospitalizamos": "hospitalizar",
    "hospitalizando": "hospitalizar",
    "hospitalizara": "hospitalizar",
    "hospitalizaram": "hospitalizar",
    "hospitalizaras": "hospitalizar",
    "hospitalizarde": "hospitalizar",
    "hospitalizardes": "hospitalizar",
    "hospitalizare": "hospitalizar",
    "hospitalizarei": "hospitalizar",
    "hospitalizareis": "hospitalizar",
    "hospitalizarem": "hospitalizar",
    "hospitalizaremos": "hospitalizar",
    "hospitalizares": "hospitalizar",
    "hospitalizaria": "hospitalizar",
    "hospitalizariam": "hospitalizar",
    "hospitalizarias": "hospitalizar",
    "hospitalizarmo": "hospitalizar",
    "hospitalizarmos": "hospitalizar",
    "hospitalizará": "hospitalizar",
    "hospitalizarás": "hospitalizar",
    "hospitalizarão": "hospitalizar",
    "hospitalizaríamos": "hospitalizar",
    "hospitalizaríeis": "hospitalizar",
    "hospitalizas": "hospitalizar",
    "hospitalizasse": "hospitalizar",
    "hospitalizassem": "hospitalizar",
    "hospitalizasses": "hospitalizar",
    "hospitalizaste": "hospitalizar",
    "hospitalizastes": "hospitalizar",
    "hospitalizava": "hospitalizar",
    "hospitalizavam": "hospitalizar",
    "hospitalizavas": "hospitalizar",
    "hospitalizações": "hospitalização",
    "hospitalize": "hospitalizar",
    "hospitalizei": "hospitalizar",
    "hospitalizeis": "hospitalizar",
    "hospitalizem": "hospitalizar",
    "hospitalizemo": "hospitalizar",
    "hospitalizemos": "hospitalizar",
    "hospitalizes": "hospitalizar",
    "hospitalizo": "hospitalizar",
    "hospitalizou": "hospitalizar",
    "hospitalizá": "hospitalizar",
    "hospitalizámo": "hospitalizar",
    "hospitalizámos": "hospitalizar",
    "hospitalizáramo": "hospitalizar",
    "hospitalizáramos": "hospitalizar",
    "hospitalizárei": "hospitalizar",
    "hospitalizáreis": "hospitalizar",
    "hospitalizásseis": "hospitalizar",
    "hospitalizássemos": "hospitalizar",
    "hospitalizávamo": "hospitalizar",
    "hospitalizávamos": "hospitalizar",
    "hospitalizávei": "hospitalizar",
    "hospitalizáveis": "hospitalizar",
    "hospitalária": "hospitalário",
    "hospitalárias": "hospitalário",
    "hospitalários": "hospitalário",
    "hospitações": "hospitação",
    "hospitálias": "hospitália",
    "hospícios": "hospício",
    "hossanas": "hossana",
    "hostes": "hoste",
    "hostilidades": "hostilidade",
    "hostiliza": "hostilizar",
    "hostilizada": "hostilizar",
    "hostilizadas": "hostilizar",
    "hostilizado": "hostilizar",
    "hostilizados": "hostilizar",
    "hostilizai": "hostilizar",
    "hostilizais": "hostilizar",
    "hostilizam": "hostilizar",
    "hostilizamo": "hostilizar",
    "hostilizamos": "hostilizar",
    "hostilizando": "hostilizar",
    "hostilizara": "hostilizar",
    "hostilizaram": "hostilizar",
    "hostilizaras": "hostilizar",
    "hostilizarde": "hostilizar",
    "hostilizardes": "hostilizar",
    "hostilizare": "hostilizar",
    "hostilizarei": "hostilizar",
    "hostilizareis": "hostilizar",
    "hostilizarem": "hostilizar",
    "hostilizaremos": "hostilizar",
    "hostilizares": "hostilizar",
    "hostilizaria": "hostilizar",
    "hostilizariam": "hostilizar",
    "hostilizarias": "hostilizar",
    "hostilizarmo": "hostilizar",
    "hostilizarmos": "hostilizar",
    "hostilizará": "hostilizar",
    "hostilizarás": "hostilizar",
    "hostilizarão": "hostilizar",
    "hostilizaríamos": "hostilizar",
    "hostilizaríeis": "hostilizar",
    "hostilizas": "hostilizar",
    "hostilizasse": "hostilizar",
    "hostilizassem": "hostilizar",
    "hostilizasses": "hostilizar",
    "hostilizaste": "hostilizar",
    "hostilizastes": "hostilizar",
    "hostilizava": "hostilizar",
    "hostilizavam": "hostilizar",
    "hostilizavas": "hostilizar",
    "hostilize": "hostilizar",
    "hostilizei": "hostilizar",
    "hostilizeis": "hostilizar",
    "hostilizem": "hostilizar",
    "hostilizemo": "hostilizar",
    "hostilizemos": "hostilizar",
    "hostilizes": "hostilizar",
    "hostilizo": "hostilizar",
    "hostilizou": "hostilizar",
    "hostilizá": "hostilizar",
    "hostilizámo": "hostilizar",
    "hostilizámos": "hostilizar",
    "hostilizáramo": "hostilizar",
    "hostilizáramos": "hostilizar",
    "hostilizárei": "hostilizar",
    "hostilizáreis": "hostilizar",
    "hostilizásseis": "hostilizar",
    "hostilizássemos": "hostilizar",
    "hostilizávamo": "hostilizar",
    "hostilizávamos": "hostilizar",
    "hostilizávei": "hostilizar",
    "hostilizáveis": "hostilizar",
    "hostis": "hostil",
    "hostiários": "hostiário",
    "hotelarias": "hotelaria",
    "hoteleira": "hoteleiro",
    "hoteleiras": "hoteleiro",
    "hoteleiros": "hoteleiro",
    "hotelerias": "hoteleria",
    "hotentotes": "hotentote",
    "hotentotismos": "hotentotismo",
    "hotéis": "hotel",
    "houve": "haver",
    "houvemo": "haver",
    "houvemos": "haver",
    "houver": "haver",
    "houvera": "haver",
    "houveram": "haver",
    "houveras": "haver",
    "houverdes": "haver",
    "houverem": "haver",
    "houveres": "haver",
    "houvermos": "haver",
    "houvesse": "haver",
    "houvessem": "haver",
    "houvesses": "haver",
    "houveste": "haver",
    "houvestes": "haver",
    "houvéramo": "haver",
    "houvéramos": "haver",
    "houvérei": "haver",
    "houvéreis": "haver",
    "houvésseis": "haver",
    "houvéssemos": "haver",
    "hovercrafts": "hovercraft",
    "huamba": "huambo",
    "huambas": "huambo",
    "huambos": "huambo",
    "hubnerites": "hubnerite",
    "huguenotes": "huguenote",
    "hulhas": "hulha",
    "hulheira": "hulheiro",
    "hulheiras": "hulheiro",
    "hulheiros": "hulheiro",
    "hulhífera": "hulhífero",
    "hulhíferas": "hulhífero",
    "hulhíferos": "hulhífero",
    "humana": "humano",
    "humanada": "humanar",
    "humanadas": "humanar",
    "humanado": "humanar",
    "humanados": "humanar",
    "humanai": "humanar",
    "humanais": "humanar",
    "humanam": "humanar",
    "humanamo": "humanar",
    "humanamos": "humanar",
    "humanando": "humanar",
    "humanara": "humanar",
    "humanaram": "humanar",
    "humanaras": "humanar",
    "humanarde": "humanar",
    "humanardes": "humanar",
    "humanare": "humanar",
    "humanarei": "humanar",
    "humanareis": "humanar",
    "humanarem": "humanar",
    "humanaremos": "humanar",
    "humanares": "humanar",
    "humanaria": "humanar",
    "humanariam": "humanar",
    "humanarias": "humanar",
    "humanarmo": "humanar",
    "humanarmos": "humanar",
    "humanará": "humanar",
    "humanarás": "humanar",
    "humanarão": "humanar",
    "humanaríamos": "humanar",
    "humanaríeis": "humanar",
    "humanas": "humano",
    "humanasse": "humanar",
    "humanassem": "humanar",
    "humanasses": "humanar",
    "humanaste": "humanar",
    "humanastes": "humanar",
    "humanava": "humanar",
    "humanavam": "humanar",
    "humanavas": "humanar",
    "humane": "humanar",
    "humanei": "humanar",
    "humaneis": "humanar",
    "humanem": "humanar",
    "humanemo": "humanar",
    "humanemos": "humanar",
    "humanes": "humanar",
    "humanidades": "humanidade",
    "humanismos": "humanismo",
    "humanistas": "humanista",
    "humanitarismos": "humanitarismo",
    "humanitaristas": "humanitarista",
    "humanitária": "humanitário",
    "humanitárias": "humanitário",
    "humanitários": "humanitário",
    "humaniza": "humanizar",
    "humanizada": "humanizar",
    "humanizadas": "humanizar",
    "humanizado": "humanizar",
    "humanizados": "humanizar",
    "humanizai": "humanizar",
    "humanizais": "humanizar",
    "humanizam": "humanizar",
    "humanizamo": "humanizar",
    "humanizamos": "humanizar",
    "humanizando": "humanizar",
    "humanizara": "humanizar",
    "humanizaram": "humanizar",
    "humanizaras": "humanizar",
    "humanizarde": "humanizar",
    "humanizardes": "humanizar",
    "humanizare": "humanizar",
    "humanizarei": "humanizar",
    "humanizareis": "humanizar",
    "humanizarem": "humanizar",
    "humanizaremos": "humanizar",
    "humanizares": "humanizar",
    "humanizaria": "humanizar",
    "humanizariam": "humanizar",
    "humanizarias": "humanizar",
    "humanizarmo": "humanizar",
    "humanizarmos": "humanizar",
    "humanizará": "humanizar",
    "humanizarás": "humanizar",
    "humanizarão": "humanizar",
    "humanizaríamos": "humanizar",
    "humanizaríeis": "humanizar",
    "humanizas": "humanizar",
    "humanizasse": "humanizar",
    "humanizassem": "humanizar",
    "humanizasses": "humanizar",
    "humanizaste": "humanizar",
    "humanizastes": "humanizar",
    "humanizava": "humanizar",
    "humanizavam": "humanizar",
    "humanizavas": "humanizar",
    "humanizações": "humanização",
    "humanize": "humanizar",
    "humanizei": "humanizar",
    "humanizeis": "humanizar",
    "humanizem": "humanizar",
    "humanizemo": "humanizar",
    "humanizemos": "humanizar",
    "humanizes": "humanizar",
    "humanizo": "humanizar",
    "humanizou": "humanizar",
    "humanizá": "humanizar",
    "humanizámo": "humanizar",
    "humanizámos": "humanizar",
    "humanizáramo": "humanizar",
    "humanizáramos": "humanizar",
    "humanizárei": "humanizar",
    "humanizáreis": "humanizar",
    "humanizásseis": "humanizar",
    "humanizássemos": "humanizar",
    "humanizávamo": "humanizar",
    "humanizávamos": "humanizar",
    "humanizávei": "humanizar",
    "humanizáveis": "humanizável",
    "humano": "humanar",
    "humanos": "humano",
    "humanou": "humanar",
    "humaná": "humanar",
    "humanámo": "humanar",
    "humanámos": "humanar",
    "humanáramo": "humanar",
    "humanáramos": "humanar",
    "humanárei": "humanar",
    "humanáreis": "humanar",
    "humanásseis": "humanar",
    "humanássemos": "humanar",
    "humanávamo": "humanar",
    "humanávamos": "humanar",
    "humanávei": "humanar",
    "humanáveis": "humanar",
    "humanística": "humanístico",
    "humanísticas": "humanístico",
    "humanísticos": "humanístico",
    "humecta": "humectar",
    "humectada": "humectar",
    "humectadas": "humectar",
    "humectado": "humectar",
    "humectados": "humectar",
    "humectai": "humectar",
    "humectais": "humectar",
    "humectam": "humectar",
    "humectamo": "humectar",
    "humectamos": "humectar",
    "humectando": "humectar",
    "humectantes": "humectante",
    "humectara": "humectar",
    "humectaram": "humectar",
    "humectaras": "humectar",
    "humectarde": "humectar",
    "humectardes": "humectar",
    "humectare": "humectar",
    "humectarei": "humectar",
    "humectareis": "humectar",
    "humectarem": "humectar",
    "humectaremos": "humectar",
    "humectares": "humectar",
    "humectaria": "humectar",
    "humectariam": "humectar",
    "humectarias": "humectar",
    "humectarmo": "humectar",
    "humectarmos": "humectar",
    "humectará": "humectar",
    "humectarás": "humectar",
    "humectarão": "humectar",
    "humectaríamos": "humectar",
    "humectaríeis": "humectar",
    "humectas": "humectar",
    "humectasse": "humectar",
    "humectassem": "humectar",
    "humectasses": "humectar",
    "humectaste": "humectar",
    "humectastes": "humectar",
    "humectativa": "humectativo",
    "humectativas": "humectativo",
    "humectativos": "humectativo",
    "humectava": "humectar",
    "humectavam": "humectar",
    "humectavas": "humectar",
    "humectações": "humectação",
    "humecte": "humectar",
    "humectei": "humectar",
    "humecteis": "humectar",
    "humectem": "humectar",
    "humectemo": "humectar",
    "humectemos": "humectar",
    "humectes": "humectar",
    "humecto": "humectar",
    "humectou": "humectar",
    "humectá": "humectar",
    "humectámo": "humectar",
    "humectámos": "humectar",
    "humectáramo": "humectar",
    "humectáramos": "humectar",
    "humectárei": "humectar",
    "humectáreis": "humectar",
    "humectásseis": "humectar",
    "humectássemos": "humectar",
    "humectávamo": "humectar",
    "humectávamos": "humectar",
    "humectávei": "humectar",
    "humectáveis": "humectar",
    "humedece": "humedecer",
    "humedecei": "humedecer",
    "humedeceis": "humedecer",
    "humedecem": "humedecer",
    "humedecemo": "humedecer",
    "humedecemos": "humedecer",
    "humedecendo": "humedecer",
    "humedecera": "humedecer",
    "humedeceram": "humedecer",
    "humedeceras": "humedecer",
    "humedecerde": "humedecer",
    "humedecerdes": "humedecer",
    "humedecere": "humedecer",
    "humedecerei": "humedecer",
    "humedecereis": "humedecer",
    "humedecerem": "humedecer",
    "humedeceremos": "humedecer",
    "humedeceres": "humedecer",
    "humedeceria": "humedecer",
    "humedeceriam": "humedecer",
    "humedecerias": "humedecer",
    "humedecermo": "humedecer",
    "humedecermos": "humedecer",
    "humedecerá": "humedecer",
    "humedecerás": "humedecer",
    "humedecerão": "humedecer",
    "humedeceríamos": "humedecer",
    "humedeceríeis": "humedecer",
    "humedeces": "humedecer",
    "humedecesse": "humedecer",
    "humedecessem": "humedecer",
    "humedecesses": "humedecer",
    "humedeceste": "humedecer",
    "humedecestes": "humedecer",
    "humedeceu": "humedecer",
    "humedeci": "humedecer",
    "humedecia": "humedecer",
    "humedeciam": "humedecer",
    "humedecias": "humedecer",
    "humedecida": "humedecido",
    "humedecidas": "humedecido",
    "humedecido": "humedecer",
    "humedecidos": "humedecido",
    "humedecimentos": "humedecimento",
    "humedecê": "humedecer",
    "humedecêramo": "humedecer",
    "humedecêramos": "humedecer",
    "humedecêrei": "humedecer",
    "humedecêreis": "humedecer",
    "humedecêsseis": "humedecer",
    "humedecêssemos": "humedecer",
    "humedecíamo": "humedecer",
    "humedecíamos": "humedecer",
    "humedecíei": "humedecer",
    "humedecíeis": "humedecer",
    "humedecíveis": "humedecível",
    "humedeça": "humedecer",
    "humedeçais": "humedecer",
    "humedeçam": "humedecer",
    "humedeçamo": "humedecer",
    "humedeçamos": "humedecer",
    "humedeças": "humedecer",
    "humedeço": "humedecer",
    "humentes": "humente",
    "humidades": "humidade",
    "humidificadores": "humidificador",
    "humidificações": "humidificação",
    "humidífoba": "humidífobo",
    "humidífobas": "humidífobo",
    "humidífobos": "humidífobo",
    "humidífuga": "humidífugo",
    "humidífugas": "humidífugo",
    "humidífugos": "humidífugo",
    "humificações": "humificação",
    "humilda": "humildar",
    "humildada": "humildar",
    "humildadas": "humildar",
    "humildades": "humildade",
    "humildado": "humildar",
    "humildados": "humildar",
    "humildai": "humildar",
    "humildais": "humildar",
    "humildam": "humildar",
    "humildamo": "humildar",
    "humildamos": "humildar",
    "humildando": "humildar",
    "humildara": "humildar",
    "humildaram": "humildar",
    "humildaras": "humildar",
    "humildarde": "humildar",
    "humildardes": "humildar",
    "humildare": "humildar",
    "humildarei": "humildar",
    "humildareis": "humildar",
    "humildarem": "humildar",
    "humildaremos": "humildar",
    "humildares": "humildar",
    "humildaria": "humildar",
    "humildariam": "humildar",
    "humildarias": "humildar",
    "humildarmo": "humildar",
    "humildarmos": "humildar",
    "humildará": "humildar",
    "humildarás": "humildar",
    "humildarão": "humildar",
    "humildaríamos": "humildar",
    "humildaríeis": "humildar",
    "humildas": "humildar",
    "humildasse": "humildar",
    "humildassem": "humildar",
    "humildasses": "humildar",
    "humildaste": "humildar",
    "humildastes": "humildar",
    "humildava": "humildar",
    "humildavam": "humildar",
    "humildavas": "humildar",
    "humildações": "humildação",
    "humilde": "humildar",
    "humildei": "humildar",
    "humildeis": "humildar",
    "humildem": "humildar",
    "humildemo": "humildar",
    "humildemos": "humildar",
    "humildes": "humilde",
    "humildo": "humildar",
    "humildosa": "humildoso",
    "humildosas": "humildoso",
    "humildosos": "humildoso",
    "humildou": "humildar",
    "humildá": "humildar",
    "humildámo": "humildar",
    "humildámos": "humildar",
    "humildáramo": "humildar",
    "humildáramos": "humildar",
    "humildárei": "humildar",
    "humildáreis": "humildar",
    "humildásseis": "humildar",
    "humildássemos": "humildar",
    "humildávamo": "humildar",
    "humildávamos": "humildar",
    "humildávei": "humildar",
    "humildáveis": "humildar",
    "humilha": "humilhar",
    "humilhada": "humilhar",
    "humilhadas": "humilhar",
    "humilhado": "humilhar",
    "humilhadora": "humilhador",
    "humilhadoras": "humilhador",
    "humilhadores": "humilhador",
    "humilhados": "humilhar",
    "humilhai": "humilhar",
    "humilhais": "humilhar",
    "humilham": "humilhar",
    "humilhamo": "humilhar",
    "humilhamos": "humilhar",
    "humilhando": "humilhar",
    "humilhantes": "humilhante",
    "humilhara": "humilhar",
    "humilharam": "humilhar",
    "humilharas": "humilhar",
    "humilharde": "humilhar",
    "humilhardes": "humilhar",
    "humilhare": "humilhar",
    "humilharei": "humilhar",
    "humilhareis": "humilhar",
    "humilharem": "humilhar",
    "humilharemos": "humilhar",
    "humilhares": "humilhar",
    "humilharia": "humilhar",
    "humilhariam": "humilhar",
    "humilharias": "humilhar",
    "humilharmo": "humilhar",
    "humilharmos": "humilhar",
    "humilhará": "humilhar",
    "humilharás": "humilhar",
    "humilharão": "humilhar",
    "humilharíamos": "humilhar",
    "humilharíeis": "humilhar",
    "humilhas": "humilhar",
    "humilhasse": "humilhar",
    "humilhassem": "humilhar",
    "humilhasses": "humilhar",
    "humilhaste": "humilhar",
    "humilhastes": "humilhar",
    "humilhava": "humilhar",
    "humilhavam": "humilhar",
    "humilhavas": "humilhar",
    "humilhações": "humilhação",
    "humilhe": "humilhar",
    "humilhei": "humilhar",
    "humilheis": "humilhar",
    "humilhem": "humilhar",
    "humilhemo": "humilhar",
    "humilhemos": "humilhar",
    "humilhes": "humilhar",
    "humilho": "humilhar",
    "humilhosa": "humilhoso",
    "humilhosas": "humilhoso",
    "humilhosos": "humilhoso",
    "humilhou": "humilhar",
    "humilhá": "humilhar",
    "humilhámo": "humilhar",
    "humilhámos": "humilhar",
    "humilháramo": "humilhar",
    "humilháramos": "humilhar",
    "humilhárei": "humilhar",
    "humilháreis": "humilhar",
    "humilhásseis": "humilhar",
    "humilhássemos": "humilhar",
    "humilhávamo": "humilhar",
    "humilhávamos": "humilhar",
    "humilhávei": "humilhar",
    "humilháveis": "humilhável",
    "humiliantes": "humiliante",
    "humiliações": "humiliação",
    "humorada": "humorado",
    "humoradas": "humorado",
    "humorados": "humorado",
    "humorais": "humoral",
    "humores": "humor",
    "humorismos": "humorismo",
    "humoristas": "humorista",
    "humorosa": "humoroso",
    "humorosas": "humoroso",
    "humorosos": "humoroso",
    "humorística": "humorístico",
    "humorísticas": "humorístico",
    "humorísticos": "humorístico",
    "humos": "humo",
    "humosa": "humoso",
    "humosas": "humoso",
    "humosos": "humoso",
    "humulácea": "humuláceo",
    "humuláceas": "humuláceo",
    "humuláceos": "humuláceo",
    "humícolas": "humícola",
    "humífera": "humífero",
    "humíferas": "humífero",
    "humíferos": "humífero",
    "humílima": "humilde",
    "humílimas": "humilde",
    "humílimo": "humilde",
    "humílimos": "humilde",
    "huna": "huno",
    "hunas": "huno",
    "hungarazinha": "húngaro",
    "hungarazinhas": "húngaro",
    "hungarazita": "húngaro",
    "hungarazitas": "húngaro",
    "hungarozinho": "húngaro",
    "hungarozinhos": "húngaro",
    "hungarozito": "húngaro",
    "hungarozitos": "húngaro",
    "hungos": "hungo",
    "hunos": "huno",
    "huris": "huri",
    "huronianos": "huroniano",
    "hurras": "hurra",
    "husas": "husa",
    "husmas": "husma",
    "hussardos": "hussardo",
    "hussitas": "hussita",
    "hutus": "hutu",
    "há": "haver",
    "hábeis": "hábil",
    "hábitos": "hábito",
    "háfnios": "háfnio",
    "hájibes": "hájibe",
    "hálitos": "hálito",
    "hárpagas": "hárpaga",
    "hás": "haver",
    "hástias": "hástia",
    "hâlmios": "hâlmio",
    "hão": "haver",
    "héctica": "héctico",
    "hécticas": "héctico",
    "hécticos": "héctico",
    "héderas": "hédera",
    "hégiras": "hégira",
    "hélices": "hélice",
    "hélios": "hélio",
    "héptodos": "héptodo",
    "hérnias": "hérnia",
    "hérnica": "hérnico",
    "hérnicas": "hérnico",
    "hérnicos": "hérnico",
    "hésteros": "héstero",
    "hétega": "hétego",
    "hétegas": "hétego",
    "hétegos": "hétego",
    "héxodos": "héxodo",
    "híbrida": "híbrido",
    "híbridas": "híbrido",
    "híbridos": "híbrido",
    "hídrias": "hídria",
    "hídrica": "hídrico",
    "hídricas": "hídrico",
    "hídricos": "hídrico",
    "hífens": "hífen",
    "hígida": "hígido",
    "hígidas": "hígido",
    "hígidos": "hígido",
    "hílares": "hílare",
    "hílidas": "hílida",
    "hímens": "hímen",
    "hínica": "hínico",
    "hínicas": "hínico",
    "hínicos": "hínico",
    "hípica": "hípico",
    "hípicas": "hípico",
    "hípicos": "hípico",
    "híspida": "híspido",
    "híspidas": "híspido",
    "híspidos": "híspido",
    "hólmios": "hólmio",
    "hóqueis": "hóquei",
    "hórmica": "hórmico",
    "hórmicas": "hórmico",
    "hórmicos": "hórmico",
    "hórrida": "hórrido",
    "hórridas": "hórrido",
    "hórridos": "hórrido",
    "hóspedes": "hóspede",
    "hóstias": "hóstia",
    "húmica": "húmico",
    "húmicas": "húmico",
    "húmicos": "húmico",
    "húmida": "húmido",
    "húmidas": "húmido",
    "húmidos": "húmido",
    "húmiles": "húmile",
    "húmis": "húmil",
    "húngara": "húngaro",
    "húngaras": "húngaro",
    "húngaros": "húngaro",
    "hússares": "hússar",
    "i": "ir",
    "ia": "ir",
    "iacus": "iacu",
    "iagos": "iago",
    "iam": "ir",
    "iambos": "iambo",
    "iamologias": "iamologia",
    "iamológica": "iamológico",
    "iamológicas": "iamológico",
    "iamológicos": "iamológico",
    "iamotecnias": "iamotecnia",
    "iamotécnica": "iamotécnico",
    "iamotécnicas": "iamotécnico",
    "iamotécnicos": "iamotécnico",
    "iandibacabas": "iandibacaba",
    "ianques": "ianque",
    "iantras": "iantra",
    "iapoques": "iapoque",
    "iapus": "iapu",
    "iapuças": "iapuça",
    "iaques": "iaque",
    "ias": "ir",
    "iatagãs": "iatagã",
    "iatais": "iatai",
    "iataís": "iataí",
    "iates": "iate",
    "iatraliptas": "iatralipta",
    "iatralíptica": "iatralíptico",
    "iatralípticas": "iatralíptico",
    "iatralípticos": "iatralíptico",
    "iatrias": "iatria",
    "iatrofísica": "iatrofísico",
    "iatrofísicas": "iatrofísico",
    "iatrofísicos": "iatrofísico",
    "iatrologias": "iatrologia",
    "iatromatemáticas": "iatromatemática",
    "iatromecânicas": "iatromecânica",
    "iatroquímica": "iatroquímico",
    "iatroquímicas": "iatroquímico",
    "iatroquímicos": "iatroquímico",
    "iaôs": "iaô",
    "ibera": "ibero",
    "iberas": "ibero",
    "iberismos": "iberismo",
    "iberistas": "iberista",
    "iberiza": "iberizar",
    "iberizada": "iberizar",
    "iberizadas": "iberizar",
    "iberizado": "iberizar",
    "iberizados": "iberizar",
    "iberizai": "iberizar",
    "iberizais": "iberizar",
    "iberizam": "iberizar",
    "iberizamo": "iberizar",
    "iberizamos": "iberizar",
    "iberizando": "iberizar",
    "iberizara": "iberizar",
    "iberizaram": "iberizar",
    "iberizaras": "iberizar",
    "iberizarde": "iberizar",
    "iberizardes": "iberizar",
    "iberizare": "iberizar",
    "iberizarei": "iberizar",
    "iberizareis": "iberizar",
    "iberizarem": "iberizar",
    "iberizaremos": "iberizar",
    "iberizares": "iberizar",
    "iberizaria": "iberizar",
    "iberizariam": "iberizar",
    "iberizarias": "iberizar",
    "iberizarmo": "iberizar",
    "iberizarmos": "iberizar",
    "iberizará": "iberizar",
    "iberizarás": "iberizar",
    "iberizarão": "iberizar",
    "iberizaríamos": "iberizar",
    "iberizaríeis": "iberizar",
    "iberizas": "iberizar",
    "iberizasse": "iberizar",
    "iberizassem": "iberizar",
    "iberizasses": "iberizar",
    "iberizaste": "iberizar",
    "iberizastes": "iberizar",
    "iberizava": "iberizar",
    "iberizavam": "iberizar",
    "iberizavas": "iberizar",
    "iberizações": "iberização",
    "iberize": "iberizar",
    "iberizei": "iberizar",
    "iberizeis": "iberizar",
    "iberizem": "iberizar",
    "iberizemo": "iberizar",
    "iberizemos": "iberizar",
    "iberizes": "iberizar",
    "iberizo": "iberizar",
    "iberizou": "iberizar",
    "iberizá": "iberizar",
    "iberizámo": "iberizar",
    "iberizámos": "iberizar",
    "iberizáramo": "iberizar",
    "iberizáramos": "iberizar",
    "iberizárei": "iberizar",
    "iberizáreis": "iberizar",
    "iberizásseis": "iberizar",
    "iberizássemos": "iberizar",
    "iberizávamo": "iberizar",
    "iberizávamos": "iberizar",
    "iberizávei": "iberizar",
    "iberizáveis": "iberizável",
    "iberos": "ibero",
    "iberíaca": "iberíaco",
    "iberíacas": "iberíaco",
    "iberíacos": "iberíaco",
    "ibidas": "ibida",
    "ibidídeos": "ibidídeo",
    "ibirapitangas": "ibirapitanga",
    "ibiraremas": "ibirarema",
    "ibogas": "iboga",
    "ibogaínas": "ibogaína",
    "ibseniana": "ibseniano",
    "ibsenianas": "ibseniano",
    "ibsenianos": "ibseniano",
    "ibéria": "ibério",
    "ibérias": "ibério",
    "ibérica": "ibérico",
    "ibéricas": "ibérico",
    "ibéricos": "ibérico",
    "ibérios": "ibério",
    "ibídeos": "ibídeo",
    "ibídidas": "ibídida",
    "ice": "içar",
    "icebergs": "iceberg",
    "icebergues": "icebergue",
    "icei": "içar",
    "iceis": "içar",
    "icem": "içar",
    "icemo": "içar",
    "icemos": "içar",
    "ices": "içar",
    "ichós": "ichó",
    "icipós": "icipó",
    "icnografias": "icnografia",
    "icnógrafos": "icnógrafo",
    "iconhenses": "iconhense",
    "iconidades": "iconidade",
    "iconoclastas": "iconoclasta",
    "iconoclastias": "iconoclastia",
    "iconografias": "iconografia",
    "iconográfica": "iconográfico",
    "iconográficas": "iconográfico",
    "iconográficos": "iconográfico",
    "iconolatrias": "iconolatria",
    "iconologias": "iconologia",
    "iconologistas": "iconologista",
    "iconolóloga": "iconolólogo",
    "iconolólogas": "iconolólogo",
    "iconolólogos": "iconolólogo",
    "iconomanias": "iconomania",
    "iconoscópios": "iconoscópio",
    "iconotecas": "iconoteca",
    "iconómetros": "iconómetro",
    "iconóstases": "iconóstase",
    "icore": "icor",
    "icores": "icor",
    "icosaedros": "icosaedro",
    "icosandra": "icosandro",
    "icosandras": "icosandro",
    "icosandrias": "icosandria",
    "icosandros": "icosandro",
    "icositetraedros": "icositetraedro",
    "icoságonos": "icoságono",
    "icosândrias": "icosândria",
    "icterícias": "icterícia",
    "icteróides": "icteróide",
    "ictiocolas": "ictiocola",
    "ictiofagias": "ictiofagia",
    "ictiografias": "ictiografia",
    "ictiográfica": "ictiográfico",
    "ictiográficas": "ictiográfico",
    "ictiográficos": "ictiográfico",
    "ictiologias": "ictiologia",
    "ictiomacias": "ictiomacia",
    "ictiomorfa": "ictiomorfo",
    "ictiomorfas": "ictiomorfo",
    "ictiomorfos": "ictiomorfo",
    "ictioses": "ictiose",
    "ictiosismos": "ictiosismo",
    "ictiossauros": "ictiossauro",
    "ictiófaga": "ictiófago",
    "ictiófagas": "ictiófago",
    "ictiófagos": "ictiófago",
    "ictiógrafa": "ictiógrafo",
    "ictiógrafas": "ictiógrafo",
    "ictiógrafos": "ictiógrafo",
    "ictióides": "ictióide",
    "ictióis": "ictiol",
    "ictiólitos": "ictiólito",
    "ictióloga": "ictiólogo",
    "ictiólogas": "ictiólogo",
    "ictiólogos": "ictiólogo",
    "ictos": "icto",
    "ictérica": "ictérico",
    "ictéricas": "ictérico",
    "ictéricos": "ictérico",
    "ictíaca": "ictíaco",
    "ictíacas": "ictíaco",
    "ictíacos": "ictíaco",
    "ictíica": "ictíico",
    "ictíicas": "ictíico",
    "ictíicos": "ictíico",
    "icária": "icário",
    "icárias": "icário",
    "icários": "icário",
    "icástica": "icástico",
    "icásticas": "icástico",
    "icásticos": "icástico",
    "icérias": "icéria",
    "icónica": "icónico",
    "icónicas": "icónico",
    "icónicos": "icónico",
    "ida": "ir",
    "idades": "idade",
    "idas": "ir",
    "ide": "ir",
    "ideada": "idear",
    "ideadas": "idear",
    "ideado": "idear",
    "ideados": "idear",
    "ideai": "idear",
    "ideais": "idear",
    "idealidades": "idealidade",
    "idealismos": "idealismo",
    "idealistas": "idealista",
    "idealiza": "idealizar",
    "idealizada": "idealizar",
    "idealizadas": "idealizar",
    "idealizado": "idealizar",
    "idealizadora": "idealizador",
    "idealizadoras": "idealizador",
    "idealizadores": "idealizador",
    "idealizados": "idealizar",
    "idealizai": "idealizar",
    "idealizais": "idealizar",
    "idealizam": "idealizar",
    "idealizamo": "idealizar",
    "idealizamos": "idealizar",
    "idealizando": "idealizar",
    "idealizara": "idealizar",
    "idealizaram": "idealizar",
    "idealizaras": "idealizar",
    "idealizarde": "idealizar",
    "idealizardes": "idealizar",
    "idealizare": "idealizar",
    "idealizarei": "idealizar",
    "idealizareis": "idealizar",
    "idealizarem": "idealizar",
    "idealizaremos": "idealizar",
    "idealizares": "idealizar",
    "idealizaria": "idealizar",
    "idealizariam": "idealizar",
    "idealizarias": "idealizar",
    "idealizarmo": "idealizar",
    "idealizarmos": "idealizar",
    "idealizará": "idealizar",
    "idealizarás": "idealizar",
    "idealizarão": "idealizar",
    "idealizaríamos": "idealizar",
    "idealizaríeis": "idealizar",
    "idealizas": "idealizar",
    "idealizasse": "idealizar",
    "idealizassem": "idealizar",
    "idealizasses": "idealizar",
    "idealizaste": "idealizar",
    "idealizastes": "idealizar",
    "idealizava": "idealizar",
    "idealizavam": "idealizar",
    "idealizavas": "idealizar",
    "idealizações": "idealização",
    "idealize": "idealizar",
    "idealizei": "idealizar",
    "idealizeis": "idealizar",
    "idealizem": "idealizar",
    "idealizemo": "idealizar",
    "idealizemos": "idealizar",
    "idealizes": "idealizar",
    "idealizo": "idealizar",
    "idealizou": "idealizar",
    "idealizá": "idealizar",
    "idealizámo": "idealizar",
    "idealizámos": "idealizar",
    "idealizáramo": "idealizar",
    "idealizáramos": "idealizar",
    "idealizárei": "idealizar",
    "idealizáreis": "idealizar",
    "idealizásseis": "idealizar",
    "idealizássemos": "idealizar",
    "idealizávamo": "idealizar",
    "idealizávamos": "idealizar",
    "idealizávei": "idealizar",
    "idealizáveis": "idealizável",
    "idealística": "idealístico",
    "idealísticas": "idealístico",
    "idealísticos": "idealístico",
    "ideamo": "idear",
    "ideamos": "idear",
    "ideando": "idear",
    "ideara": "idear",
    "idearam": "idear",
    "idearas": "idear",
    "idearde": "idear",
    "ideardes": "idear",
    "ideare": "idear",
    "idearei": "idear",
    "ideareis": "idear",
    "idearem": "idear",
    "idearemos": "idear",
    "ideares": "idear",
    "idearia": "idear",
    "ideariam": "idear",
    "idearias": "idear",
    "idearmo": "idear",
    "idearmos": "idear",
    "ideará": "idear",
    "idearás": "idear",
    "idearão": "idear",
    "idearíamos": "idear",
    "idearíeis": "idear",
    "ideasse": "idear",
    "ideassem": "idear",
    "ideasses": "idear",
    "ideaste": "idear",
    "ideastes": "idear",
    "ideava": "idear",
    "ideavam": "idear",
    "ideavas": "idear",
    "ideações": "ideação",
    "ideei": "idear",
    "ideeis": "idear",
    "ideemo": "idear",
    "ideemos": "idear",
    "ideia": "idear",
    "ideiam": "idear",
    "ideias": "ideia",
    "ideie": "idear",
    "ideiem": "idear",
    "ideies": "idear",
    "ideio": "idear",
    "identidades": "identidade",
    "identifica": "identificar",
    "identificada": "identificar",
    "identificadas": "identificar",
    "identificado": "identificar",
    "identificadora": "identificador",
    "identificadoras": "identificador",
    "identificadores": "identificador",
    "identificados": "identificar",
    "identificai": "identificar",
    "identificais": "identificar",
    "identificam": "identificar",
    "identificamo": "identificar",
    "identificamos": "identificar",
    "identificando": "identificar",
    "identificara": "identificar",
    "identificaram": "identificar",
    "identificaras": "identificar",
    "identificarde": "identificar",
    "identificardes": "identificar",
    "identificare": "identificar",
    "identificarei": "identificar",
    "identificareis": "identificar",
    "identificarem": "identificar",
    "identificaremos": "identificar",
    "identificares": "identificar",
    "identificaria": "identificar",
    "identificariam": "identificar",
    "identificarias": "identificar",
    "identificarmo": "identificar",
    "identificarmos": "identificar",
    "identificará": "identificar",
    "identificarás": "identificar",
    "identificarão": "identificar",
    "identificaríamos": "identificar",
    "identificaríeis": "identificar",
    "identificas": "identificar",
    "identificasse": "identificar",
    "identificassem": "identificar",
    "identificasses": "identificar",
    "identificaste": "identificar",
    "identificastes": "identificar",
    "identificativos": "identificativo",
    "identificava": "identificar",
    "identificavam": "identificar",
    "identificavas": "identificar",
    "identificações": "identificação",
    "identifico": "identificar",
    "identificou": "identificar",
    "identificá": "identificar",
    "identificámo": "identificar",
    "identificámos": "identificar",
    "identificáramo": "identificar",
    "identificáramos": "identificar",
    "identificárei": "identificar",
    "identificáreis": "identificar",
    "identificásseis": "identificar",
    "identificássemos": "identificar",
    "identificávamo": "identificar",
    "identificávamos": "identificar",
    "identificávei": "identificar",
    "identificáveis": "identificável",
    "identifique": "identificar",
    "identifiquei": "identificar",
    "identifiqueis": "identificar",
    "identifiquem": "identificar",
    "identifiquemo": "identificar",
    "identifiquemos": "identificar",
    "identifiques": "identificar",
    "ideofrenias": "ideofrenia",
    "ideofrénica": "ideofrénico",
    "ideofrénicas": "ideofrénico",
    "ideofrénicos": "ideofrénico",
    "ideogenias": "ideogenia",
    "ideografias": "ideografia",
    "ideografismos": "ideografismo",
    "ideogramas": "ideograma",
    "ideográfica": "ideográfico",
    "ideográficas": "ideográfico",
    "ideográficos": "ideográfico",
    "ideogénica": "ideogénico",
    "ideogénicas": "ideogénico",
    "ideogénicos": "ideogénico",
    "ideologias": "ideologia",
    "ideológica": "ideológico",
    "ideológicas": "ideológico",
    "ideológicos": "ideológico",
    "ideosferas": "ideosfera",
    "ideou": "idear",
    "ides": "ir",
    "ideá": "idear",
    "ideámo": "idear",
    "ideámos": "idear",
    "ideáramo": "idear",
    "ideáramos": "idear",
    "ideárei": "idear",
    "ideáreis": "idear",
    "ideários": "ideário",
    "ideásseis": "idear",
    "ideássemos": "idear",
    "ideávamo": "idear",
    "ideávamos": "idear",
    "ideávei": "idear",
    "ideáveis": "ideável",
    "ideógrafa": "ideógrafo",
    "ideógrafas": "ideógrafo",
    "ideógrafos": "ideógrafo",
    "ideóloga": "ideólogo",
    "ideólogas": "ideólogo",
    "ideólogos": "ideólogo",
    "idiches": "idiche",
    "idilistas": "idilista",
    "idiocromossomos": "idiocromossomo",
    "idiocromática": "idiocromático",
    "idiocromáticas": "idiocromático",
    "idiocromáticos": "idiocromático",
    "idioginias": "idioginia",
    "idiolatrias": "idiolatria",
    "idioletos": "idioleto",
    "idiolátrica": "idiolátrico",
    "idiolátricas": "idiolátrico",
    "idiolátricos": "idiolátrico",
    "idiomas": "idioma",
    "idiomografias": "idiomografia",
    "idiomográfica": "idiomográfico",
    "idiomográficas": "idiomográfico",
    "idiomográficos": "idiomográfico",
    "idiomorfa": "idiomorfo",
    "idiomorfas": "idiomorfo",
    "idiomorfos": "idiomorfo",
    "idiomática": "idiomático",
    "idiomáticas": "idiomático",
    "idiomáticos": "idiomático",
    "idiomórfica": "idiomórfico",
    "idiomórficas": "idiomórfico",
    "idiomórficos": "idiomórfico",
    "idionomias": "idionomia",
    "idionómica": "idionómico",
    "idionómicas": "idionómico",
    "idionómicos": "idionómico",
    "idiopatias": "idiopatia",
    "idioplasmas": "idioplasma",
    "idiopática": "idiopático",
    "idiopáticas": "idiopático",
    "idiopáticos": "idiopático",
    "idioscópica": "idioscópico",
    "idioscópicas": "idioscópico",
    "idioscópicos": "idioscópico",
    "idiossincrasias": "idiossincrasia",
    "idiossincrásica": "idiossincrásico",
    "idiossincrásicas": "idiossincrásico",
    "idiossincrásicos": "idiossincrásico",
    "idiossincrática": "idiossincrático",
    "idiossincráticas": "idiossincrático",
    "idiossincráticos": "idiossincrático",
    "idiotas": "idiota",
    "idiotias": "idiotia",
    "idiotices": "idiotice",
    "idiotismos": "idiotismo",
    "idiotiza": "idiotizar",
    "idiotizada": "idiotizar",
    "idiotizadas": "idiotizar",
    "idiotizado": "idiotizar",
    "idiotizados": "idiotizar",
    "idiotizai": "idiotizar",
    "idiotizais": "idiotizar",
    "idiotizam": "idiotizar",
    "idiotizamo": "idiotizar",
    "idiotizamos": "idiotizar",
    "idiotizando": "idiotizar",
    "idiotizara": "idiotizar",
    "idiotizaram": "idiotizar",
    "idiotizaras": "idiotizar",
    "idiotizarde": "idiotizar",
    "idiotizardes": "idiotizar",
    "idiotizare": "idiotizar",
    "idiotizarei": "idiotizar",
    "idiotizareis": "idiotizar",
    "idiotizarem": "idiotizar",
    "idiotizaremos": "idiotizar",
    "idiotizares": "idiotizar",
    "idiotizaria": "idiotizar",
    "idiotizariam": "idiotizar",
    "idiotizarias": "idiotizar",
    "idiotizarmo": "idiotizar",
    "idiotizarmos": "idiotizar",
    "idiotizará": "idiotizar",
    "idiotizarás": "idiotizar",
    "idiotizarão": "idiotizar",
    "idiotizaríamos": "idiotizar",
    "idiotizaríeis": "idiotizar",
    "idiotizas": "idiotizar",
    "idiotizasse": "idiotizar",
    "idiotizassem": "idiotizar",
    "idiotizasses": "idiotizar",
    "idiotizaste": "idiotizar",
    "idiotizastes": "idiotizar",
    "idiotizava": "idiotizar",
    "idiotizavam": "idiotizar",
    "idiotizavas": "idiotizar",
    "idiotize": "idiotizar",
    "idiotizei": "idiotizar",
    "idiotizeis": "idiotizar",
    "idiotizem": "idiotizar",
    "idiotizemo": "idiotizar",
    "idiotizemos": "idiotizar",
    "idiotizes": "idiotizar",
    "idiotizo": "idiotizar",
    "idiotizou": "idiotizar",
    "idiotizá": "idiotizar",
    "idiotizámo": "idiotizar",
    "idiotizámos": "idiotizar",
    "idiotizáramo": "idiotizar",
    "idiotizáramos": "idiotizar",
    "idiotizárei": "idiotizar",
    "idiotizáreis": "idiotizar",
    "idiotizásseis": "idiotizar",
    "idiotizássemos": "idiotizar",
    "idiotizávamo": "idiotizar",
    "idiotizávamos": "idiotizar",
    "idiotizávei": "idiotizar",
    "idiotizáveis": "idiotizar",
    "idiógina": "idiógino",
    "idióginas": "idiógino",
    "idióginos": "idiógino",
    "idiólatras": "idiólatra",
    "idiótica": "idiótico",
    "idióticas": "idiótico",
    "idióticos": "idiótico",
    "ido": "ir",
    "idolatra": "idolatrar",
    "idolatrada": "idolatrar",
    "idolatradas": "idolatrar",
    "idolatrado": "idolatrar",
    "idolatrados": "idolatrar",
    "idolatrai": "idolatrar",
    "idolatrais": "idolatrar",
    "idolatram": "idolatrar",
    "idolatramo": "idolatrar",
    "idolatramos": "idolatrar",
    "idolatrando": "idolatrar",
    "idolatrara": "idolatrar",
    "idolatraram": "idolatrar",
    "idolatraras": "idolatrar",
    "idolatrarde": "idolatrar",
    "idolatrardes": "idolatrar",
    "idolatrare": "idolatrar",
    "idolatrarei": "idolatrar",
    "idolatrareis": "idolatrar",
    "idolatrarem": "idolatrar",
    "idolatraremos": "idolatrar",
    "idolatrares": "idolatrar",
    "idolatraria": "idolatrar",
    "idolatrariam": "idolatrar",
    "idolatrarias": "idolatrar",
    "idolatrarmo": "idolatrar",
    "idolatrarmos": "idolatrar",
    "idolatrará": "idolatrar",
    "idolatrarás": "idolatrar",
    "idolatrarão": "idolatrar",
    "idolatraríamos": "idolatrar",
    "idolatraríeis": "idolatrar",
    "idolatras": "idolatrar",
    "idolatrasse": "idolatrar",
    "idolatrassem": "idolatrar",
    "idolatrasses": "idolatrar",
    "idolatraste": "idolatrar",
    "idolatrastes": "idolatrar",
    "idolatrava": "idolatrar",
    "idolatravam": "idolatrar",
    "idolatravas": "idolatrar",
    "idolatre": "idolatrar",
    "idolatrei": "idolatrar",
    "idolatreis": "idolatrar",
    "idolatrem": "idolatrar",
    "idolatremo": "idolatrar",
    "idolatremos": "idolatrar",
    "idolatres": "idolatrar",
    "idolatrias": "idolatria",
    "idolatriza": "idolatrizar",
    "idolatrizada": "idolatrizar",
    "idolatrizadas": "idolatrizar",
    "idolatrizado": "idolatrizar",
    "idolatrizados": "idolatrizar",
    "idolatrizai": "idolatrizar",
    "idolatrizais": "idolatrizar",
    "idolatrizam": "idolatrizar",
    "idolatrizamo": "idolatrizar",
    "idolatrizamos": "idolatrizar",
    "idolatrizando": "idolatrizar",
    "idolatrizara": "idolatrizar",
    "idolatrizaram": "idolatrizar",
    "idolatrizaras": "idolatrizar",
    "idolatrizarde": "idolatrizar",
    "idolatrizardes": "idolatrizar",
    "idolatrizare": "idolatrizar",
    "idolatrizarei": "idolatrizar",
    "idolatrizareis": "idolatrizar",
    "idolatrizarem": "idolatrizar",
    "idolatrizaremos": "idolatrizar",
    "idolatrizares": "idolatrizar",
    "idolatrizaria": "idolatrizar",
    "idolatrizariam": "idolatrizar",
    "idolatrizarias": "idolatrizar",
    "idolatrizarmo": "idolatrizar",
    "idolatrizarmos": "idolatrizar",
    "idolatrizará": "idolatrizar",
    "idolatrizarás": "idolatrizar",
    "idolatrizarão": "idolatrizar",
    "idolatrizaríamos": "idolatrizar",
    "idolatrizaríeis": "idolatrizar",
    "idolatrizas": "idolatrizar",
    "idolatrizasse": "idolatrizar",
    "idolatrizassem": "idolatrizar",
    "idolatrizasses": "idolatrizar",
    "idolatrizaste": "idolatrizar",
    "idolatrizastes": "idolatrizar",
    "idolatrizava": "idolatrizar",
    "idolatrizavam": "idolatrizar",
    "idolatrizavas": "idolatrizar",
    "idolatrize": "idolatrizar",
    "idolatrizei": "idolatrizar",
    "idolatrizeis": "idolatrizar",
    "idolatrizem": "idolatrizar",
    "idolatrizemo": "idolatrizar",
    "idolatrizemos": "idolatrizar",
    "idolatrizes": "idolatrizar",
    "idolatrizo": "idolatrizar",
    "idolatrizou": "idolatrizar",
    "idolatrizá": "idolatrizar",
    "idolatrizámo": "idolatrizar",
    "idolatrizámos": "idolatrizar",
    "idolatrizáramo": "idolatrizar",
    "idolatrizáramos": "idolatrizar",
    "idolatrizárei": "idolatrizar",
    "idolatrizáreis": "idolatrizar",
    "idolatrizásseis": "idolatrizar",
    "idolatrizássemos": "idolatrizar",
    "idolatrizávamo": "idolatrizar",
    "idolatrizávamos": "idolatrizar",
    "idolatrizávei": "idolatrizar",
    "idolatrizáveis": "idolatrizável",
    "idolatro": "idolatrar",
    "idolatrou": "idolatrar",
    "idolatrá": "idolatrar",
    "idolatrámo": "idolatrar",
    "idolatrámos": "idolatrar",
    "idolatráramo": "idolatrar",
    "idolatráramos": "idolatrar",
    "idolatrárei": "idolatrar",
    "idolatráreis": "idolatrar",
    "idolatrásseis": "idolatrar",
    "idolatrássemos": "idolatrar",
    "idolatrávamo": "idolatrar",
    "idolatrávamos": "idolatrar",
    "idolatrávei": "idolatrar",
    "idolatráveis": "idolatrável",
    "idoletos": "idoleto",
    "idolopeias": "idolopeia",
    "idolátrica": "idolátrico",
    "idolátricas": "idolátrico",
    "idolátricos": "idolátrico",
    "idoneidades": "idoneidade",
    "idoneísmos": "idoneísmo",
    "idos": "ir",
    "idosa": "idoso",
    "idosas": "idoso",
    "idoscópica": "idoscópico",
    "idoscópicas": "idoscópico",
    "idoscópicos": "idoscópico",
    "idosos": "idoso",
    "idumeia": "idumeu",
    "idumeias": "idumeu",
    "idumeus": "idumeu",
    "idália": "idálio",
    "idálias": "idálio",
    "idálica": "idálico",
    "idálicas": "idálico",
    "idálicos": "idálico",
    "idálios": "idálio",
    "idêntica": "idêntico",
    "idênticas": "idêntico",
    "idênticos": "idêntico",
    "idílica": "idílico",
    "idílicas": "idílico",
    "idílicos": "idílico",
    "idílios": "idílio",
    "idócrases": "idócrase",
    "idólatras": "idólatra",
    "idónea": "idóneo",
    "idóneas": "idóneo",
    "idóneos": "idóneo",
    "ienes": "iene",
    "igaras": "igara",
    "igeditana": "igeditano",
    "igeditanas": "igeditano",
    "igeditanienses": "igeditaniense",
    "igeditanos": "igeditano",
    "ignara": "ignaro",
    "ignaras": "ignaro",
    "ignaros": "ignaro",
    "ignava": "ignavo",
    "ignavas": "ignavo",
    "ignavos": "ignavo",
    "ignescentes": "ignescente",
    "ignifica": "ignificar",
    "ignificada": "ignificar",
    "ignificadas": "ignificar",
    "ignificado": "ignificar",
    "ignificados": "ignificar",
    "ignificai": "ignificar",
    "ignificais": "ignificar",
    "ignificam": "ignificar",
    "ignificamo": "ignificar",
    "ignificamos": "ignificar",
    "ignificando": "ignificar",
    "ignificara": "ignificar",
    "ignificaram": "ignificar",
    "ignificaras": "ignificar",
    "ignificarde": "ignificar",
    "ignificardes": "ignificar",
    "ignificare": "ignificar",
    "ignificarei": "ignificar",
    "ignificareis": "ignificar",
    "ignificarem": "ignificar",
    "ignificaremos": "ignificar",
    "ignificares": "ignificar",
    "ignificaria": "ignificar",
    "ignificariam": "ignificar",
    "ignificarias": "ignificar",
    "ignificarmo": "ignificar",
    "ignificarmos": "ignificar",
    "ignificará": "ignificar",
    "ignificarás": "ignificar",
    "ignificarão": "ignificar",
    "ignificaríamos": "ignificar",
    "ignificaríeis": "ignificar",
    "ignificas": "ignificar",
    "ignificasse": "ignificar",
    "ignificassem": "ignificar",
    "ignificasses": "ignificar",
    "ignificaste": "ignificar",
    "ignificastes": "ignificar",
    "ignificava": "ignificar",
    "ignificavam": "ignificar",
    "ignificavas": "ignificar",
    "ignificações": "ignificação",
    "ignifico": "ignificar",
    "ignificou": "ignificar",
    "ignificá": "ignificar",
    "ignificámo": "ignificar",
    "ignificámos": "ignificar",
    "ignificáramo": "ignificar",
    "ignificáramos": "ignificar",
    "ignificárei": "ignificar",
    "ignificáreis": "ignificar",
    "ignificásseis": "ignificar",
    "ignificássemos": "ignificar",
    "ignificávamo": "ignificar",
    "ignificávamos": "ignificar",
    "ignificávei": "ignificar",
    "ignificáveis": "ignificável",
    "ignifique": "ignificar",
    "ignifiquei": "ignificar",
    "ignifiqueis": "ignificar",
    "ignifiquem": "ignificar",
    "ignifiquemo": "ignificar",
    "ignifiquemos": "ignificar",
    "ignifiques": "ignificar",
    "ignimbritos": "ignimbrito",
    "ignipotentes": "ignipotente",
    "ignipuncturas": "ignipunctura",
    "ignispícios": "ignispício",
    "ignitrões": "ignitrão",
    "igniza": "ignizar",
    "ignizada": "ignizar",
    "ignizadas": "ignizar",
    "ignizado": "ignizar",
    "ignizados": "ignizar",
    "ignizai": "ignizar",
    "ignizais": "ignizar",
    "ignizam": "ignizar",
    "ignizamo": "ignizar",
    "ignizamos": "ignizar",
    "ignizando": "ignizar",
    "ignizara": "ignizar",
    "ignizaram": "ignizar",
    "ignizaras": "ignizar",
    "ignizarde": "ignizar",
    "ignizardes": "ignizar",
    "ignizare": "ignizar",
    "ignizarei": "ignizar",
    "ignizareis": "ignizar",
    "ignizarem": "ignizar",
    "ignizaremos": "ignizar",
    "ignizares": "ignizar",
    "ignizaria": "ignizar",
    "ignizariam": "ignizar",
    "ignizarias": "ignizar",
    "ignizarmo": "ignizar",
    "ignizarmos": "ignizar",
    "ignizará": "ignizar",
    "ignizarás": "ignizar",
    "ignizarão": "ignizar",
    "ignizaríamos": "ignizar",
    "ignizaríeis": "ignizar",
    "ignizas": "ignizar",
    "ignizasse": "ignizar",
    "ignizassem": "ignizar",
    "ignizasses": "ignizar",
    "ignizaste": "ignizar",
    "ignizastes": "ignizar",
    "ignizava": "ignizar",
    "ignizavam": "ignizar",
    "ignizavas": "ignizar",
    "ignize": "ignizar",
    "ignizei": "ignizar",
    "ignizeis": "ignizar",
    "ignizem": "ignizar",
    "ignizemo": "ignizar",
    "ignizemos": "ignizar",
    "ignizes": "ignizar",
    "ignizo": "ignizar",
    "ignizou": "ignizar",
    "ignizá": "ignizar",
    "ignizámo": "ignizar",
    "ignizámos": "ignizar",
    "ignizáramo": "ignizar",
    "ignizáramos": "ignizar",
    "ignizárei": "ignizar",
    "ignizáreis": "ignizar",
    "ignizásseis": "ignizar",
    "ignizássemos": "ignizar",
    "ignizávamo": "ignizar",
    "ignizávamos": "ignizar",
    "ignizávei": "ignizar",
    "ignizáveis": "ignizar",
    "ignições": "ignição",
    "ignobilidades": "ignobilidade",
    "ignominia": "ignominiar",
    "ignominiada": "ignominiar",
    "ignominiadas": "ignominiar",
    "ignominiado": "ignominiar",
    "ignominiados": "ignominiar",
    "ignominiai": "ignominiar",
    "ignominiais": "ignominiar",
    "ignominiam": "ignominiar",
    "ignominiamo": "ignominiar",
    "ignominiamos": "ignominiar",
    "ignominiando": "ignominiar",
    "ignominiara": "ignominiar",
    "ignominiaram": "ignominiar",
    "ignominiaras": "ignominiar",
    "ignominiarde": "ignominiar",
    "ignominiardes": "ignominiar",
    "ignominiare": "ignominiar",
    "ignominiarei": "ignominiar",
    "ignominiareis": "ignominiar",
    "ignominiarem": "ignominiar",
    "ignominiaremos": "ignominiar",
    "ignominiares": "ignominiar",
    "ignominiaria": "ignominiar",
    "ignominiariam": "ignominiar",
    "ignominiarias": "ignominiar",
    "ignominiarmo": "ignominiar",
    "ignominiarmos": "ignominiar",
    "ignominiará": "ignominiar",
    "ignominiarás": "ignominiar",
    "ignominiarão": "ignominiar",
    "ignominiaríamos": "ignominiar",
    "ignominiaríeis": "ignominiar",
    "ignominias": "ignominiar",
    "ignominiasse": "ignominiar",
    "ignominiassem": "ignominiar",
    "ignominiasses": "ignominiar",
    "ignominiaste": "ignominiar",
    "ignominiastes": "ignominiar",
    "ignominiava": "ignominiar",
    "ignominiavam": "ignominiar",
    "ignominiavas": "ignominiar",
    "ignominie": "ignominiar",
    "ignominiei": "ignominiar",
    "ignominieis": "ignominiar",
    "ignominiem": "ignominiar",
    "ignominiemo": "ignominiar",
    "ignominiemos": "ignominiar",
    "ignominies": "ignominiar",
    "ignominio": "ignominiar",
    "ignominiosa": "ignominioso",
    "ignominiosas": "ignominioso",
    "ignominiosos": "ignominioso",
    "ignominiou": "ignominiar",
    "ignominiá": "ignominiar",
    "ignominiámo": "ignominiar",
    "ignominiámos": "ignominiar",
    "ignominiáramo": "ignominiar",
    "ignominiáramos": "ignominiar",
    "ignominiárei": "ignominiar",
    "ignominiáreis": "ignominiar",
    "ignominiásseis": "ignominiar",
    "ignominiássemos": "ignominiar",
    "ignominiávamo": "ignominiar",
    "ignominiávamos": "ignominiar",
    "ignominiávei": "ignominiar",
    "ignominiáveis": "ignominiar",
    "ignomínias": "ignomínia",
    "ignora": "ignorar",
    "ignorada": "ignorar",
    "ignoradas": "ignorar",
    "ignorado": "ignorar",
    "ignorados": "ignorar",
    "ignorai": "ignorar",
    "ignorais": "ignorar",
    "ignoram": "ignorar",
    "ignoramo": "ignorar",
    "ignoramos": "ignorar",
    "ignorando": "ignorar",
    "ignorantes": "ignorante",
    "ignorantezinha": "ignorante",
    "ignorantezinhas": "ignorante",
    "ignorantezinho": "ignorante",
    "ignorantezinhos": "ignorante",
    "ignorantezita": "ignorante",
    "ignorantezitas": "ignorante",
    "ignorantezito": "ignorante",
    "ignorantezitos": "ignorante",
    "ignorantinhos": "ignorantinho",
    "ignorantismos": "ignorantismo",
    "ignorantistas": "ignorantista",
    "ignorantona": "ignorantão",
    "ignorantonas": "ignorantão",
    "ignorantíssima": "ignorante",
    "ignorantíssimas": "ignorante",
    "ignorantíssimo": "ignorante",
    "ignorantíssimos": "ignorante",
    "ignorantões": "ignorantão",
    "ignorara": "ignorar",
    "ignoraram": "ignorar",
    "ignoraras": "ignorar",
    "ignorarde": "ignorar",
    "ignorardes": "ignorar",
    "ignorare": "ignorar",
    "ignorarei": "ignorar",
    "ignorareis": "ignorar",
    "ignorarem": "ignorar",
    "ignoraremos": "ignorar",
    "ignorares": "ignorar",
    "ignoraria": "ignorar",
    "ignorariam": "ignorar",
    "ignorarias": "ignorar",
    "ignorarmo": "ignorar",
    "ignorarmos": "ignorar",
    "ignorará": "ignorar",
    "ignorarás": "ignorar",
    "ignorarão": "ignorar",
    "ignoraríamos": "ignorar",
    "ignoraríeis": "ignorar",
    "ignoras": "ignorar",
    "ignorasse": "ignorar",
    "ignorassem": "ignorar",
    "ignorasses": "ignorar",
    "ignoraste": "ignorar",
    "ignorastes": "ignorar",
    "ignorava": "ignorar",
    "ignoravam": "ignorar",
    "ignoravas": "ignorar",
    "ignore": "ignorar",
    "ignorei": "ignorar",
    "ignoreis": "ignorar",
    "ignorem": "ignorar",
    "ignoremo": "ignorar",
    "ignoremos": "ignorar",
    "ignores": "ignorar",
    "ignoro": "ignorar",
    "ignorou": "ignorar",
    "ignorá": "ignorar",
    "ignorámo": "ignorar",
    "ignorámos": "ignorar",
    "ignoráramo": "ignorar",
    "ignoráramos": "ignorar",
    "ignorárei": "ignorar",
    "ignoráreis": "ignorar",
    "ignorásseis": "ignorar",
    "ignorássemos": "ignorar",
    "ignorávamo": "ignorar",
    "ignorávamos": "ignorar",
    "ignorávei": "ignorar",
    "ignoráveis": "ignorável",
    "ignorâncias": "ignorância",
    "ignota": "ignoto",
    "ignotas": "ignoto",
    "ignotos": "ignoto",
    "ignávias": "ignávia",
    "ignícolas": "ignícola",
    "ignífera": "ignífero",
    "igníferas": "ignífero",
    "igníferos": "ignífero",
    "ignífuga": "ignífugo",
    "ignífugas": "ignífugo",
    "ignífugos": "ignífugo",
    "ignígera": "ignígero",
    "ignígeras": "ignígero",
    "ignígeros": "ignígero",
    "ignípedes": "ignípede",
    "ignívoma": "ignívomo",
    "ignívomas": "ignívomo",
    "ignívomos": "ignívomo",
    "ignívora": "ignívoro",
    "ignívoras": "ignívoro",
    "ignívoros": "ignívoro",
    "ignóbeis": "ignóbil",
    "igrejas": "igreja",
    "igrejeira": "igrejeiro",
    "igrejeiras": "igrejeiro",
    "igrejeiros": "igrejeiro",
    "igrejinha": "igreja",
    "igrejinhas": "igreja",
    "igrejita": "igreja",
    "igrejitas": "igreja",
    "igrejolas": "igrejola",
    "igrejários": "igrejário",
    "iguais": "igual",
    "iguaizinhas": "igual",
    "iguaizinhos": "igual",
    "iguaizitas": "igual",
    "iguaizitos": "igual",
    "iguala": "igualar",
    "igualada": "igualar",
    "igualadas": "igualar",
    "igualado": "igualar",
    "igualadora": "igualador",
    "igualadoras": "igualador",
    "igualadores": "igualador",
    "igualados": "igualar",
    "igualai": "igualar",
    "igualais": "igualar",
    "igualam": "igualar",
    "igualamentos": "igualamento",
    "igualamo": "igualar",
    "igualamos": "igualar",
    "igualando": "igualar",
    "igualara": "igualar",
    "igualaram": "igualar",
    "igualaras": "igualar",
    "igualarde": "igualar",
    "igualardes": "igualar",
    "igualare": "igualar",
    "igualarei": "igualar",
    "igualareis": "igualar",
    "igualarem": "igualar",
    "igualaremos": "igualar",
    "igualares": "igualar",
    "igualaria": "igualar",
    "igualariam": "igualar",
    "igualarias": "igualar",
    "igualarmo": "igualar",
    "igualarmos": "igualar",
    "igualará": "igualar",
    "igualarás": "igualar",
    "igualarão": "igualar",
    "igualaríamos": "igualar",
    "igualaríeis": "igualar",
    "igualas": "igualar",
    "igualasse": "igualar",
    "igualassem": "igualar",
    "igualasses": "igualar",
    "igualaste": "igualar",
    "igualastes": "igualar",
    "igualava": "igualar",
    "igualavam": "igualar",
    "igualavas": "igualar",
    "igualações": "igualação",
    "igualdades": "igualdade",
    "iguale": "igualar",
    "igualei": "igualar",
    "igualeis": "igualar",
    "igualem": "igualar",
    "igualemo": "igualar",
    "igualemos": "igualar",
    "iguales": "igualar",
    "igualhas": "igualha",
    "igualitarismos": "igualitarismo",
    "igualitaristas": "igualitarista",
    "igualitária": "igualitário",
    "igualitárias": "igualitário",
    "igualitários": "igualitário",
    "igualiza": "igualizar",
    "igualizada": "igualizar",
    "igualizadas": "igualizar",
    "igualizado": "igualizar",
    "igualizados": "igualizar",
    "igualizai": "igualizar",
    "igualizais": "igualizar",
    "igualizam": "igualizar",
    "igualizamo": "igualizar",
    "igualizamos": "igualizar",
    "igualizando": "igualizar",
    "igualizara": "igualizar",
    "igualizaram": "igualizar",
    "igualizaras": "igualizar",
    "igualizarde": "igualizar",
    "igualizardes": "igualizar",
    "igualizare": "igualizar",
    "igualizarei": "igualizar",
    "igualizareis": "igualizar",
    "igualizarem": "igualizar",
    "igualizaremos": "igualizar",
    "igualizares": "igualizar",
    "igualizaria": "igualizar",
    "igualizariam": "igualizar",
    "igualizarias": "igualizar",
    "igualizarmo": "igualizar",
    "igualizarmos": "igualizar",
    "igualizará": "igualizar",
    "igualizarás": "igualizar",
    "igualizarão": "igualizar",
    "igualizaríamos": "igualizar",
    "igualizaríeis": "igualizar",
    "igualizas": "igualizar",
    "igualizasse": "igualizar",
    "igualizassem": "igualizar",
    "igualizasses": "igualizar",
    "igualizaste": "igualizar",
    "igualizastes": "igualizar",
    "igualizava": "igualizar",
    "igualizavam": "igualizar",
    "igualizavas": "igualizar",
    "igualizações": "igualização",
    "igualize": "igualizar",
    "igualizei": "igualizar",
    "igualizeis": "igualizar",
    "igualizem": "igualizar",
    "igualizemo": "igualizar",
    "igualizemos": "igualizar",
    "igualizes": "igualizar",
    "igualizo": "igualizar",
    "igualizou": "igualizar",
    "igualizá": "igualizar",
    "igualizámo": "igualizar",
    "igualizámos": "igualizar",
    "igualizáramo": "igualizar",
    "igualizáramos": "igualizar",
    "igualizárei": "igualizar",
    "igualizáreis": "igualizar",
    "igualizásseis": "igualizar",
    "igualizássemos": "igualizar",
    "igualizávamo": "igualizar",
    "igualizávamos": "igualizar",
    "igualizávei": "igualizar",
    "igualizáveis": "igualizável",
    "igualo": "igualar",
    "igualou": "igualar",
    "igualzinha": "igual",
    "igualzinho": "igual",
    "igualzita": "igual",
    "igualzito": "igual",
    "igualá": "igualar",
    "igualámo": "igualar",
    "igualámos": "igualar",
    "igualáramo": "igualar",
    "igualáramos": "igualar",
    "igualárei": "igualar",
    "igualáreis": "igualar",
    "igualásseis": "igualar",
    "igualássemos": "igualar",
    "igualávamo": "igualar",
    "igualávamos": "igualar",
    "igualávei": "igualar",
    "igualáveis": "igualável",
    "iguanas": "iguana",
    "iguanos": "iguano",
    "iguanídeos": "iguanídeo",
    "iguarias": "iguaria",
    "iguânidas": "iguânida",
    "ii": "i",
    "ijolitos": "ijolito",
    "ilaceráveis": "ilacerável",
    "ilacrimáveis": "ilacrimável",
    "ilapsos": "ilapso",
    "ilaqueada": "ilaquear",
    "ilaqueadas": "ilaquear",
    "ilaqueado": "ilaquear",
    "ilaqueados": "ilaquear",
    "ilaqueai": "ilaquear",
    "ilaqueais": "ilaquear",
    "ilaqueamo": "ilaquear",
    "ilaqueamos": "ilaquear",
    "ilaqueando": "ilaquear",
    "ilaqueara": "ilaquear",
    "ilaquearam": "ilaquear",
    "ilaquearas": "ilaquear",
    "ilaquearde": "ilaquear",
    "ilaqueardes": "ilaquear",
    "ilaqueare": "ilaquear",
    "ilaquearei": "ilaquear",
    "ilaqueareis": "ilaquear",
    "ilaquearem": "ilaquear",
    "ilaquearemos": "ilaquear",
    "ilaqueares": "ilaquear",
    "ilaquearia": "ilaquear",
    "ilaqueariam": "ilaquear",
    "ilaquearias": "ilaquear",
    "ilaquearmo": "ilaquear",
    "ilaquearmos": "ilaquear",
    "ilaqueará": "ilaquear",
    "ilaquearás": "ilaquear",
    "ilaquearão": "ilaquear",
    "ilaquearíamos": "ilaquear",
    "ilaquearíeis": "ilaquear",
    "ilaqueasse": "ilaquear",
    "ilaqueassem": "ilaquear",
    "ilaqueasses": "ilaquear",
    "ilaqueaste": "ilaquear",
    "ilaqueastes": "ilaquear",
    "ilaqueava": "ilaquear",
    "ilaqueavam": "ilaquear",
    "ilaqueavas": "ilaquear",
    "ilaqueações": "ilaqueação",
    "ilaqueei": "ilaquear",
    "ilaqueeis": "ilaquear",
    "ilaqueemo": "ilaquear",
    "ilaqueemos": "ilaquear",
    "ilaqueia": "ilaquear",
    "ilaqueiam": "ilaquear",
    "ilaqueias": "ilaquear",
    "ilaqueie": "ilaquear",
    "ilaqueiem": "ilaquear",
    "ilaqueies": "ilaquear",
    "ilaqueio": "ilaquear",
    "ilaqueou": "ilaquear",
    "ilaqueá": "ilaquear",
    "ilaqueámo": "ilaquear",
    "ilaqueámos": "ilaquear",
    "ilaqueáramo": "ilaquear",
    "ilaqueáramos": "ilaquear",
    "ilaqueárei": "ilaquear",
    "ilaqueáreis": "ilaquear",
    "ilaqueásseis": "ilaquear",
    "ilaqueássemos": "ilaquear",
    "ilaqueávamo": "ilaquear",
    "ilaqueávamos": "ilaquear",
    "ilaqueávei": "ilaquear",
    "ilaqueáveis": "ilaquear",
    "ilativa": "ilativo",
    "ilativas": "ilativo",
    "ilativos": "ilativo",
    "ilações": "ilação",
    "ileadelfos": "ileadelfo",
    "ilectomias": "ilectomia",
    "ilegais": "ilegal",
    "ilegalidades": "ilegalidade",
    "ilegaliza": "ilegalizar",
    "ilegalizada": "ilegalizar",
    "ilegalizadas": "ilegalizar",
    "ilegalizado": "ilegalizar",
    "ilegalizados": "ilegalizar",
    "ilegalizai": "ilegalizar",
    "ilegalizais": "ilegalizar",
    "ilegalizam": "ilegalizar",
    "ilegalizamo": "ilegalizar",
    "ilegalizamos": "ilegalizar",
    "ilegalizando": "ilegalizar",
    "ilegalizara": "ilegalizar",
    "ilegalizaram": "ilegalizar",
    "ilegalizaras": "ilegalizar",
    "ilegalizarde": "ilegalizar",
    "ilegalizardes": "ilegalizar",
    "ilegalizare": "ilegalizar",
    "ilegalizarei": "ilegalizar",
    "ilegalizareis": "ilegalizar",
    "ilegalizarem": "ilegalizar",
    "ilegalizaremos": "ilegalizar",
    "ilegalizares": "ilegalizar",
    "ilegalizaria": "ilegalizar",
    "ilegalizariam": "ilegalizar",
    "ilegalizarias": "ilegalizar",
    "ilegalizarmo": "ilegalizar",
    "ilegalizarmos": "ilegalizar",
    "ilegalizará": "ilegalizar",
    "ilegalizarás": "ilegalizar",
    "ilegalizarão": "ilegalizar",
    "ilegalizaríamos": "ilegalizar",
    "ilegalizaríeis": "ilegalizar",
    "ilegalizas": "ilegalizar",
    "ilegalizasse": "ilegalizar",
    "ilegalizassem": "ilegalizar",
    "ilegalizasses": "ilegalizar",
    "ilegalizaste": "ilegalizar",
    "ilegalizastes": "ilegalizar",
    "ilegalizava": "ilegalizar",
    "ilegalizavam": "ilegalizar",
    "ilegalizavas": "ilegalizar",
    "ilegalizações": "ilegalização",
    "ilegalize": "ilegalizar",
    "ilegalizei": "ilegalizar",
    "ilegalizeis": "ilegalizar",
    "ilegalizem": "ilegalizar",
    "ilegalizemo": "ilegalizar",
    "ilegalizemos": "ilegalizar",
    "ilegalizes": "ilegalizar",
    "ilegalizo": "ilegalizar",
    "ilegalizou": "ilegalizar",
    "ilegalizá": "ilegalizar",
    "ilegalizámo": "ilegalizar",
    "ilegalizámos": "ilegalizar",
    "ilegalizáramo": "ilegalizar",
    "ilegalizáramos": "ilegalizar",
    "ilegalizárei": "ilegalizar",
    "ilegalizáreis": "ilegalizar",
    "ilegalizásseis": "ilegalizar",
    "ilegalizássemos": "ilegalizar",
    "ilegalizávamo": "ilegalizar",
    "ilegalizávamos": "ilegalizar",
    "ilegalizávei": "ilegalizar",
    "ilegalizáveis": "ilegalizável",
    "ilegibilidades": "ilegibilidade",
    "ilegitima": "ilegitimar",
    "ilegitimada": "ilegitimar",
    "ilegitimadas": "ilegitimar",
    "ilegitimado": "ilegitimar",
    "ilegitimados": "ilegitimar",
    "ilegitimai": "ilegitimar",
    "ilegitimais": "ilegitimar",
    "ilegitimam": "ilegitimar",
    "ilegitimamo": "ilegitimar",
    "ilegitimamos": "ilegitimar",
    "ilegitimando": "ilegitimar",
    "ilegitimara": "ilegitimar",
    "ilegitimaram": "ilegitimar",
    "ilegitimaras": "ilegitimar",
    "ilegitimarde": "ilegitimar",
    "ilegitimardes": "ilegitimar",
    "ilegitimare": "ilegitimar",
    "ilegitimarei": "ilegitimar",
    "ilegitimareis": "ilegitimar",
    "ilegitimarem": "ilegitimar",
    "ilegitimaremos": "ilegitimar",
    "ilegitimares": "ilegitimar",
    "ilegitimaria": "ilegitimar",
    "ilegitimariam": "ilegitimar",
    "ilegitimarias": "ilegitimar",
    "ilegitimarmo": "ilegitimar",
    "ilegitimarmos": "ilegitimar",
    "ilegitimará": "ilegitimar",
    "ilegitimarás": "ilegitimar",
    "ilegitimarão": "ilegitimar",
    "ilegitimaríamos": "ilegitimar",
    "ilegitimaríeis": "ilegitimar",
    "ilegitimas": "ilegitimar",
    "ilegitimasse": "ilegitimar",
    "ilegitimassem": "ilegitimar",
    "ilegitimasses": "ilegitimar",
    "ilegitimaste": "ilegitimar",
    "ilegitimastes": "ilegitimar",
    "ilegitimava": "ilegitimar",
    "ilegitimavam": "ilegitimar",
    "ilegitimavas": "ilegitimar",
    "ilegitime": "ilegitimar",
    "ilegitimei": "ilegitimar",
    "ilegitimeis": "ilegitimar",
    "ilegitimem": "ilegitimar",
    "ilegitimemo": "ilegitimar",
    "ilegitimemos": "ilegitimar",
    "ilegitimes": "ilegitimar",
    "ilegitimidades": "ilegitimidade",
    "ilegitimo": "ilegitimar",
    "ilegitimou": "ilegitimar",
    "ilegitimá": "ilegitimar",
    "ilegitimámo": "ilegitimar",
    "ilegitimámos": "ilegitimar",
    "ilegitimáramo": "ilegitimar",
    "ilegitimáramos": "ilegitimar",
    "ilegitimárei": "ilegitimar",
    "ilegitimáreis": "ilegitimar",
    "ilegitimásseis": "ilegitimar",
    "ilegitimássemos": "ilegitimar",
    "ilegitimávamo": "ilegitimar",
    "ilegitimávamos": "ilegitimar",
    "ilegitimávei": "ilegitimar",
    "ilegitimáveis": "ilegitimável",
    "ilegítima": "ilegítimo",
    "ilegítimas": "ilegítimo",
    "ilegítimos": "ilegítimo",
    "ilegíveis": "ilegível",
    "ileocecais": "ileocecal",
    "ileocolites": "ileocolite",
    "ileografias": "ileografia",
    "ileostomias": "ileostomia",
    "ilesa": "ileso",
    "ilesas": "ileso",
    "ilesos": "ileso",
    "iletrada": "iletrado",
    "iletradas": "iletrado",
    "iletrados": "iletrado",
    "ilha": "ilhar",
    "ilhada": "ilhar",
    "ilhadas": "ilhar",
    "ilhado": "ilhar",
    "ilhados": "ilhar",
    "ilhai": "ilhar",
    "ilhais": "ilhar",
    "ilham": "ilhar",
    "ilhamo": "ilhar",
    "ilhamos": "ilhar",
    "ilhando": "ilhar",
    "ilhapas": "ilhapa",
    "ilhara": "ilhar",
    "ilharam": "ilhar",
    "ilharas": "ilhar",
    "ilharde": "ilhar",
    "ilhardes": "ilhar",
    "ilhare": "ilhar",
    "ilharei": "ilhar",
    "ilhareis": "ilhar",
    "ilharem": "ilhar",
    "ilharemos": "ilhar",
    "ilhares": "ilhar",
    "ilhargas": "ilharga",
    "ilhargueira": "ilhargueiro",
    "ilhargueiras": "ilhargueiro",
    "ilhargueiros": "ilhargueiro",
    "ilharia": "ilhar",
    "ilhariam": "ilhar",
    "ilharias": "ilhar",
    "ilharmo": "ilhar",
    "ilharmos": "ilhar",
    "ilhará": "ilhar",
    "ilharás": "ilhar",
    "ilharão": "ilhar",
    "ilharíamos": "ilhar",
    "ilharíeis": "ilhar",
    "ilhas": "ilhar",
    "ilhasse": "ilhar",
    "ilhassem": "ilhar",
    "ilhasses": "ilhar",
    "ilhaste": "ilhar",
    "ilhastes": "ilhar",
    "ilhava": "ilhar",
    "ilhavam": "ilhar",
    "ilhavas": "ilhar",
    "ilhe": "ilhar",
    "ilhei": "ilhar",
    "ilheis": "ilhar",
    "ilhem": "ilhar",
    "ilhemo": "ilhar",
    "ilhemos": "ilhar",
    "ilhes": "ilhar",
    "ilhetas": "ilheta",
    "ilho": "ilhar",
    "ilhoa": "ilhéu",
    "ilhoas": "ilhéu",
    "ilhoses": "ilhós",
    "ilhotas": "ilhota",
    "ilhotes": "ilhote",
    "ilhou": "ilhar",
    "ilhá": "ilhar",
    "ilhámo": "ilhar",
    "ilhámos": "ilhar",
    "ilháramo": "ilhar",
    "ilháramos": "ilhar",
    "ilhárei": "ilhar",
    "ilháreis": "ilhar",
    "ilhásseis": "ilhar",
    "ilhássemos": "ilhar",
    "ilhávamo": "ilhar",
    "ilhávamos": "ilhar",
    "ilhávei": "ilhar",
    "ilháveis": "ilhar",
    "ilhéus": "ilhéu",
    "ilhós": "ilhó",
    "iliba": "ilibar",
    "ilibada": "ilibar",
    "ilibadas": "ilibar",
    "ilibado": "ilibar",
    "ilibados": "ilibar",
    "ilibai": "ilibar",
    "ilibais": "ilibar",
    "ilibam": "ilibar",
    "ilibamo": "ilibar",
    "ilibamos": "ilibar",
    "ilibando": "ilibar",
    "ilibara": "ilibar",
    "ilibaram": "ilibar",
    "ilibaras": "ilibar",
    "ilibarde": "ilibar",
    "ilibardes": "ilibar",
    "ilibare": "ilibar",
    "ilibarei": "ilibar",
    "ilibareis": "ilibar",
    "ilibarem": "ilibar",
    "ilibaremos": "ilibar",
    "ilibares": "ilibar",
    "ilibaria": "ilibar",
    "ilibariam": "ilibar",
    "ilibarias": "ilibar",
    "ilibarmo": "ilibar",
    "ilibarmos": "ilibar",
    "ilibará": "ilibar",
    "ilibarás": "ilibar",
    "ilibarão": "ilibar",
    "ilibaríamos": "ilibar",
    "ilibaríeis": "ilibar",
    "ilibas": "ilibar",
    "ilibasse": "ilibar",
    "ilibassem": "ilibar",
    "ilibasses": "ilibar",
    "ilibaste": "ilibar",
    "ilibastes": "ilibar",
    "ilibava": "ilibar",
    "ilibavam": "ilibar",
    "ilibavas": "ilibar",
    "ilibações": "ilibação",
    "ilibe": "ilibar",
    "ilibei": "ilibar",
    "ilibeis": "ilibar",
    "ilibem": "ilibar",
    "ilibemo": "ilibar",
    "ilibemos": "ilibar",
    "iliberais": "iliberal",
    "iliberalidades": "iliberalidade",
    "iliberalismos": "iliberalismo",
    "ilibes": "ilibar",
    "ilibo": "ilibar",
    "ilibou": "ilibar",
    "ilibá": "ilibar",
    "ilibámo": "ilibar",
    "ilibámos": "ilibar",
    "ilibáramo": "ilibar",
    "ilibáramos": "ilibar",
    "ilibárei": "ilibar",
    "ilibáreis": "ilibar",
    "ilibásseis": "ilibar",
    "ilibássemos": "ilibar",
    "ilibávamo": "ilibar",
    "ilibávamos": "ilibar",
    "ilibávei": "ilibar",
    "ilibáveis": "ilibável",
    "ilice": "iliçar",
    "ilicei": "iliçar",
    "iliceis": "iliçar",
    "ilicem": "iliçar",
    "ilicemo": "iliçar",
    "ilicemos": "iliçar",
    "ilices": "iliçar",
    "ilicitudes": "ilicitude",
    "ilicáceas": "ilicácea",
    "ilida": "ilidir",
    "ilidais": "ilidir",
    "ilidam": "ilidir",
    "ilidamo": "ilidir",
    "ilidamos": "ilidir",
    "ilidas": "ilidir",
    "ilide": "ilidir",
    "ilidem": "ilidir",
    "ilides": "ilidir",
    "ilidi": "ilidir",
    "ilidia": "ilidir",
    "ilidiam": "ilidir",
    "ilidias": "ilidir",
    "ilidida": "ilidir",
    "ilididas": "ilidir",
    "ilidido": "ilidir",
    "ilididos": "ilidir",
    "ilidimo": "ilidir",
    "ilidimos": "ilidir",
    "ilidindo": "ilidir",
    "ilidira": "ilidir",
    "ilidiram": "ilidir",
    "ilidiras": "ilidir",
    "ilidirde": "ilidir",
    "ilidirdes": "ilidir",
    "ilidire": "ilidir",
    "ilidirei": "ilidir",
    "ilidireis": "ilidir",
    "ilidirem": "ilidir",
    "ilidiremos": "ilidir",
    "ilidires": "ilidir",
    "ilidiria": "ilidir",
    "ilidiriam": "ilidir",
    "ilidirias": "ilidir",
    "ilidirmo": "ilidir",
    "ilidirmos": "ilidir",
    "ilidirá": "ilidir",
    "ilidirás": "ilidir",
    "ilidirão": "ilidir",
    "ilidiríamos": "ilidir",
    "ilidiríeis": "ilidir",
    "ilidis": "ilidir",
    "ilidisse": "ilidir",
    "ilidissem": "ilidir",
    "ilidisses": "ilidir",
    "ilidiste": "ilidir",
    "ilidistes": "ilidir",
    "ilidiu": "ilidir",
    "ilido": "ilidir",
    "ilidíamo": "ilidir",
    "ilidíamos": "ilidir",
    "ilidíei": "ilidir",
    "ilidíeis": "ilidir",
    "ilidíramo": "ilidir",
    "ilidíramos": "ilidir",
    "ilidírei": "ilidir",
    "ilidíreis": "ilidir",
    "ilidísseis": "ilidir",
    "ilidíssemos": "ilidir",
    "ilidíveis": "ilidível",
    "ilienses": "iliense",
    "iliga": "iligar",
    "iligada": "iligar",
    "iligadas": "iligar",
    "iligado": "iligar",
    "iligados": "iligar",
    "iligai": "iligar",
    "iligais": "iligar",
    "iligam": "iligar",
    "iligamo": "iligar",
    "iligamos": "iligar",
    "iligando": "iligar",
    "iligara": "iligar",
    "iligaram": "iligar",
    "iligaras": "iligar",
    "iligarde": "iligar",
    "iligardes": "iligar",
    "iligare": "iligar",
    "iligarei": "iligar",
    "iligareis": "iligar",
    "iligarem": "iligar",
    "iligaremos": "iligar",
    "iligares": "iligar",
    "iligaria": "iligar",
    "iligariam": "iligar",
    "iligarias": "iligar",
    "iligarmo": "iligar",
    "iligarmos": "iligar",
    "iligará": "iligar",
    "iligarás": "iligar",
    "iligarão": "iligar",
    "iligaríamos": "iligar",
    "iligaríeis": "iligar",
    "iligas": "iligar",
    "iligasse": "iligar",
    "iligassem": "iligar",
    "iligasses": "iligar",
    "iligaste": "iligar",
    "iligastes": "iligar",
    "iligava": "iligar",
    "iligavam": "iligar",
    "iligavas": "iligar",
    "iligo": "iligar",
    "iligou": "iligar",
    "iligue": "iligar",
    "iliguei": "iligar",
    "iligueis": "iligar",
    "iliguem": "iligar",
    "iliguemo": "iligar",
    "iliguemos": "iligar",
    "iligues": "iligar",
    "iligá": "iligar",
    "iligámo": "iligar",
    "iligámos": "iligar",
    "iligáramo": "iligar",
    "iligáramos": "iligar",
    "iligárei": "iligar",
    "iligáreis": "iligar",
    "iligásseis": "iligar",
    "iligássemos": "iligar",
    "iligávamo": "iligar",
    "iligávamos": "iligar",
    "iligávei": "iligar",
    "iligáveis": "iligar",
    "iliinguinais": "iliinguinal",
    "ilimitada": "ilimitado",
    "ilimitadas": "ilimitado",
    "ilimitados": "ilimitado",
    "ilimitações": "ilimitação",
    "ilimitáveis": "ilimitável",
    "iliocostais": "iliocostal",
    "iliolombares": "iliolombar",
    "iliospinais": "iliospinal",
    "iliosquiática": "iliosquiático",
    "iliosquiáticas": "iliosquiático",
    "iliosquiáticos": "iliosquiático",
    "iliossacra": "iliossacro",
    "iliossacras": "iliossacro",
    "iliossacros": "iliossacro",
    "iliossagrada": "iliossagrado",
    "iliossagradas": "iliossagrado",
    "iliossagrados": "iliossagrado",
    "iliotibiais": "iliotibial",
    "iliotrocanteriana": "iliotrocanteriano",
    "iliotrocanterianas": "iliotrocanteriano",
    "iliotrocanterianos": "iliotrocanteriano",
    "iliotrocantiniana": "iliotrocantiniano",
    "iliotrocantinianas": "iliotrocantiniano",
    "iliotrocantinianos": "iliotrocantiniano",
    "iliterata": "iliterato",
    "iliteratas": "iliterato",
    "iliteratos": "iliterato",
    "ilites": "ilite",
    "iliça": "iliçar",
    "iliçada": "iliçar",
    "iliçadas": "iliçar",
    "iliçado": "iliçar",
    "iliçadora": "iliçador",
    "iliçadoras": "iliçador",
    "iliçadores": "iliçador",
    "iliçados": "iliçar",
    "iliçai": "iliçar",
    "iliçais": "iliçar",
    "iliçam": "iliçar",
    "iliçamo": "iliçar",
    "iliçamos": "iliçar",
    "iliçando": "iliçar",
    "iliçara": "iliçar",
    "iliçaram": "iliçar",
    "iliçaras": "iliçar",
    "iliçarde": "iliçar",
    "iliçardes": "iliçar",
    "iliçare": "iliçar",
    "iliçarei": "iliçar",
    "iliçareis": "iliçar",
    "iliçarem": "iliçar",
    "iliçaremos": "iliçar",
    "iliçares": "iliçar",
    "iliçaria": "iliçar",
    "iliçariam": "iliçar",
    "iliçarias": "iliçar",
    "iliçarmo": "iliçar",
    "iliçarmos": "iliçar",
    "iliçará": "iliçar",
    "iliçarás": "iliçar",
    "iliçarão": "iliçar",
    "iliçaríamos": "iliçar",
    "iliçaríeis": "iliçar",
    "iliças": "iliçar",
    "iliçasse": "iliçar",
    "iliçassem": "iliçar",
    "iliçasses": "iliçar",
    "iliçaste": "iliçar",
    "iliçastes": "iliçar",
    "iliçava": "iliçar",
    "iliçavam": "iliçar",
    "iliçavas": "iliçar",
    "iliço": "iliçar",
    "iliçou": "iliçar",
    "iliçá": "iliçar",
    "iliçámo": "iliçar",
    "iliçámos": "iliçar",
    "iliçáramo": "iliçar",
    "iliçáramos": "iliçar",
    "iliçárei": "iliçar",
    "iliçáreis": "iliçar",
    "iliçásseis": "iliçar",
    "iliçássemos": "iliçar",
    "iliçávamo": "iliçar",
    "iliçávamos": "iliçar",
    "iliçávei": "iliçar",
    "iliçáveis": "iliçar",
    "ilições": "ilição",
    "ilmenites": "ilmenite",
    "ilocáveis": "ilocável",
    "ilogismos": "ilogismo",
    "iluda": "iludir",
    "iludais": "iludir",
    "iludam": "iludir",
    "iludamo": "iludir",
    "iludamos": "iludir",
    "iludas": "iludir",
    "ilude": "iludir",
    "iludem": "iludir",
    "iludentes": "iludente",
    "iludes": "iludir",
    "iludi": "iludir",
    "iludia": "iludir",
    "iludiam": "iludir",
    "iludias": "iludir",
    "iludida": "iludir",
    "iludidas": "iludir",
    "iludido": "iludir",
    "iludidos": "iludir",
    "iludimo": "iludir",
    "iludimos": "iludir",
    "iludindo": "iludir",
    "iludira": "iludir",
    "iludiram": "iludir",
    "iludiras": "iludir",
    "iludirde": "iludir",
    "iludirdes": "iludir",
    "iludire": "iludir",
    "iludirei": "iludir",
    "iludireis": "iludir",
    "iludirem": "iludir",
    "iludiremos": "iludir",
    "iludires": "iludir",
    "iludiria": "iludir",
    "iludiriam": "iludir",
    "iludirias": "iludir",
    "iludirmo": "iludir",
    "iludirmos": "iludir",
    "iludirá": "iludir",
    "iludirás": "iludir",
    "iludirão": "iludir",
    "iludiríamos": "iludir",
    "iludiríeis": "iludir",
    "iludis": "iludir",
    "iludisse": "iludir",
    "iludissem": "iludir",
    "iludisses": "iludir",
    "iludiste": "iludir",
    "iludistes": "iludir",
    "iludiu": "iludir",
    "iludo": "iludir",
    "iludíamo": "iludir",
    "iludíamos": "iludir",
    "iludíei": "iludir",
    "iludíeis": "iludir",
    "iludíramo": "iludir",
    "iludíramos": "iludir",
    "iludírei": "iludir",
    "iludíreis": "iludir",
    "iludísseis": "iludir",
    "iludíssemos": "iludir",
    "iludíveis": "iludível",
    "ilumina": "iluminar",
    "iluminada": "iluminar",
    "iluminadas": "iluminar",
    "iluminado": "iluminar",
    "iluminadora": "iluminador",
    "iluminadoras": "iluminador",
    "iluminadores": "iluminador",
    "iluminados": "iluminar",
    "iluminai": "iluminar",
    "iluminais": "iluminar",
    "iluminam": "iluminar",
    "iluminamo": "iluminar",
    "iluminamos": "iluminar",
    "iluminando": "iluminar",
    "iluminantes": "iluminante",
    "iluminara": "iluminar",
    "iluminaram": "iluminar",
    "iluminaras": "iluminar",
    "iluminarde": "iluminar",
    "iluminardes": "iluminar",
    "iluminare": "iluminar",
    "iluminarei": "iluminar",
    "iluminareis": "iluminar",
    "iluminarem": "iluminar",
    "iluminaremos": "iluminar",
    "iluminares": "iluminar",
    "iluminaria": "iluminar",
    "iluminariam": "iluminar",
    "iluminarias": "iluminar",
    "iluminarmo": "iluminar",
    "iluminarmos": "iluminar",
    "iluminará": "iluminar",
    "iluminarás": "iluminar",
    "iluminarão": "iluminar",
    "iluminaríamos": "iluminar",
    "iluminaríeis": "iluminar",
    "iluminas": "iluminar",
    "iluminasse": "iluminar",
    "iluminassem": "iluminar",
    "iluminasses": "iluminar",
    "iluminaste": "iluminar",
    "iluminastes": "iluminar",
    "iluminativa": "iluminativo",
    "iluminativas": "iluminativo",
    "iluminativos": "iluminativo",
    "iluminava": "iluminar",
    "iluminavam": "iluminar",
    "iluminavas": "iluminar",
    "iluminações": "iluminação",
    "ilumine": "iluminar",
    "iluminei": "iluminar",
    "ilumineis": "iluminar",
    "iluminem": "iluminar",
    "iluminemo": "iluminar",
    "iluminemos": "iluminar",
    "ilumines": "iluminar",
    "iluminismos": "iluminismo",
    "iluministas": "iluminista",
    "ilumino": "iluminar",
    "iluminou": "iluminar",
    "iluminuras": "iluminura",
    "iluminá": "iluminar",
    "iluminámo": "iluminar",
    "iluminámos": "iluminar",
    "ilumináramo": "iluminar",
    "ilumináramos": "iluminar",
    "iluminárei": "iluminar",
    "ilumináreis": "iluminar",
    "iluminásseis": "iluminar",
    "iluminássemos": "iluminar",
    "iluminávamo": "iluminar",
    "iluminávamos": "iluminar",
    "iluminávei": "iluminar",
    "ilumináveis": "iluminável",
    "iluminâncias": "iluminância",
    "ilusa": "iluso",
    "ilusas": "iluso",
    "ilusiona": "ilusionar",
    "ilusionada": "ilusionar",
    "ilusionadas": "ilusionar",
    "ilusionado": "ilusionar",
    "ilusionados": "ilusionar",
    "ilusionai": "ilusionar",
    "ilusionais": "ilusionar",
    "ilusionam": "ilusionar",
    "ilusionamo": "ilusionar",
    "ilusionamos": "ilusionar",
    "ilusionando": "ilusionar",
    "ilusionara": "ilusionar",
    "ilusionaram": "ilusionar",
    "ilusionaras": "ilusionar",
    "ilusionarde": "ilusionar",
    "ilusionardes": "ilusionar",
    "ilusionare": "ilusionar",
    "ilusionarei": "ilusionar",
    "ilusionareis": "ilusionar",
    "ilusionarem": "ilusionar",
    "ilusionaremos": "ilusionar",
    "ilusionares": "ilusionar",
    "ilusionaria": "ilusionar",
    "ilusionariam": "ilusionar",
    "ilusionarias": "ilusionar",
    "ilusionarmo": "ilusionar",
    "ilusionarmos": "ilusionar",
    "ilusionará": "ilusionar",
    "ilusionarás": "ilusionar",
    "ilusionarão": "ilusionar",
    "ilusionaríamos": "ilusionar",
    "ilusionaríeis": "ilusionar",
    "ilusionas": "ilusionar",
    "ilusionasse": "ilusionar",
    "ilusionassem": "ilusionar",
    "ilusionasses": "ilusionar",
    "ilusionaste": "ilusionar",
    "ilusionastes": "ilusionar",
    "ilusionava": "ilusionar",
    "ilusionavam": "ilusionar",
    "ilusionavas": "ilusionar",
    "ilusione": "ilusionar",
    "ilusionei": "ilusionar",
    "ilusioneis": "ilusionar",
    "ilusionem": "ilusionar",
    "ilusionemo": "ilusionar",
    "ilusionemos": "ilusionar",
    "ilusiones": "ilusionar",
    "ilusionismos": "ilusionismo",
    "ilusionistas": "ilusionista",
    "ilusiono": "ilusionar",
    "ilusionou": "ilusionar",
    "ilusioná": "ilusionar",
    "ilusionámo": "ilusionar",
    "ilusionámos": "ilusionar",
    "ilusionáramo": "ilusionar",
    "ilusionáramos": "ilusionar",
    "ilusionárei": "ilusionar",
    "ilusionáreis": "ilusionar",
    "ilusionásseis": "ilusionar",
    "ilusionássemos": "ilusionar",
    "ilusionávamo": "ilusionar",
    "ilusionávamos": "ilusionar",
    "ilusionávei": "ilusionar",
    "ilusionáveis": "ilusionar",
    "ilusiva": "ilusivo",
    "ilusivas": "ilusivo",
    "ilusivos": "ilusivo",
    "ilusores": "ilusor",
    "ilusos": "iluso",
    "ilustra": "ilustrar",
    "ilustrada": "ilustrar",
    "ilustradas": "ilustrar",
    "ilustrado": "ilustrar",
    "ilustradora": "ilustrador",
    "ilustradoras": "ilustrador",
    "ilustradores": "ilustrador",
    "ilustrados": "ilustrar",
    "ilustradíssima": "ilustrado",
    "ilustradíssimas": "ilustrado",
    "ilustradíssimo": "ilustrado",
    "ilustradíssimos": "ilustrado",
    "ilustrai": "ilustrar",
    "ilustrais": "ilustrar",
    "ilustram": "ilustrar",
    "ilustramo": "ilustrar",
    "ilustramos": "ilustrar",
    "ilustrando": "ilustrar",
    "ilustrara": "ilustrar",
    "ilustraram": "ilustrar",
    "ilustraras": "ilustrar",
    "ilustrarde": "ilustrar",
    "ilustrardes": "ilustrar",
    "ilustrare": "ilustrar",
    "ilustrarei": "ilustrar",
    "ilustrareis": "ilustrar",
    "ilustrarem": "ilustrar",
    "ilustraremos": "ilustrar",
    "ilustrares": "ilustrar",
    "ilustraria": "ilustrar",
    "ilustrariam": "ilustrar",
    "ilustrarias": "ilustrar",
    "ilustrarmo": "ilustrar",
    "ilustrarmos": "ilustrar",
    "ilustrará": "ilustrar",
    "ilustrarás": "ilustrar",
    "ilustrarão": "ilustrar",
    "ilustraríamos": "ilustrar",
    "ilustraríeis": "ilustrar",
    "ilustras": "ilustrar",
    "ilustrasse": "ilustrar",
    "ilustrassem": "ilustrar",
    "ilustrasses": "ilustrar",
    "ilustraste": "ilustrar",
    "ilustrastes": "ilustrar",
    "ilustrativa": "ilustrativo",
    "ilustrativas": "ilustrativo",
    "ilustrativos": "ilustrativo",
    "ilustrava": "ilustrar",
    "ilustravam": "ilustrar",
    "ilustravas": "ilustrar",
    "ilustrações": "ilustração",
    "ilustre": "ilustrar",
    "ilustrei": "ilustrar",
    "ilustreis": "ilustrar",
    "ilustrem": "ilustrar",
    "ilustremo": "ilustrar",
    "ilustremos": "ilustrar",
    "ilustres": "ilustre",
    "ilustro": "ilustrar",
    "ilustrou": "ilustrar",
    "ilustrá": "ilustrar",
    "ilustrámo": "ilustrar",
    "ilustrámos": "ilustrar",
    "ilustráramo": "ilustrar",
    "ilustráramos": "ilustrar",
    "ilustrárei": "ilustrar",
    "ilustráreis": "ilustrar",
    "ilustrásseis": "ilustrar",
    "ilustrássemos": "ilustrar",
    "ilustrávamo": "ilustrar",
    "ilustrávamos": "ilustrar",
    "ilustrávei": "ilustrar",
    "ilustráveis": "ilustrável",
    "ilustríssima": "ilustre",
    "ilustríssimas": "ilustre",
    "ilustríssimo": "ilustre",
    "ilustríssimos": "ilustre",
    "ilusória": "ilusório",
    "ilusórias": "ilusório",
    "ilusórios": "ilusório",
    "ilusões": "ilusão",
    "iluta": "ilutar",
    "ilutada": "ilutar",
    "ilutadas": "ilutar",
    "ilutado": "ilutar",
    "ilutados": "ilutar",
    "ilutai": "ilutar",
    "ilutais": "ilutar",
    "ilutam": "ilutar",
    "ilutamo": "ilutar",
    "ilutamos": "ilutar",
    "ilutando": "ilutar",
    "ilutara": "ilutar",
    "ilutaram": "ilutar",
    "ilutaras": "ilutar",
    "ilutarde": "ilutar",
    "ilutardes": "ilutar",
    "ilutare": "ilutar",
    "ilutarei": "ilutar",
    "ilutareis": "ilutar",
    "ilutarem": "ilutar",
    "ilutaremos": "ilutar",
    "ilutares": "ilutar",
    "ilutaria": "ilutar",
    "ilutariam": "ilutar",
    "ilutarias": "ilutar",
    "ilutarmo": "ilutar",
    "ilutarmos": "ilutar",
    "ilutará": "ilutar",
    "ilutarás": "ilutar",
    "ilutarão": "ilutar",
    "ilutaríamos": "ilutar",
    "ilutaríeis": "ilutar",
    "ilutas": "ilutar",
    "ilutasse": "ilutar",
    "ilutassem": "ilutar",
    "ilutasses": "ilutar",
    "ilutaste": "ilutar",
    "ilutastes": "ilutar",
    "ilutava": "ilutar",
    "ilutavam": "ilutar",
    "ilutavas": "ilutar",
    "ilutações": "ilutação",
    "ilute": "ilutar",
    "ilutei": "ilutar",
    "iluteis": "ilutar",
    "ilutem": "ilutar",
    "ilutemo": "ilutar",
    "ilutemos": "ilutar",
    "ilutes": "ilutar",
    "iluto": "ilutar",
    "ilutou": "ilutar",
    "ilutá": "ilutar",
    "ilutámo": "ilutar",
    "ilutámos": "ilutar",
    "ilutáramo": "ilutar",
    "ilutáramos": "ilutar",
    "ilutárei": "ilutar",
    "ilutáreis": "ilutar",
    "ilutásseis": "ilutar",
    "ilutássemos": "ilutar",
    "ilutávamo": "ilutar",
    "ilutávamos": "ilutar",
    "ilutávei": "ilutar",
    "ilutáveis": "ilutar",
    "iluviações": "iluviação",
    "ilíaca": "ilíaco",
    "ilíacas": "ilíaco",
    "ilíacos": "ilíaco",
    "ilíadas": "ilíada",
    "ilícios": "ilício",
    "ilícita": "ilícito",
    "ilícitas": "ilícito",
    "ilícitos": "ilícito",
    "ilídima": "ilídimo",
    "ilídimas": "ilídimo",
    "ilídimos": "ilídimo",
    "ilíquida": "ilíquido",
    "ilíquidas": "ilíquido",
    "ilíquidos": "ilíquido",
    "ilíria": "ilírio",
    "ilírias": "ilírio",
    "ilírica": "ilírico",
    "ilíricas": "ilírico",
    "ilíricos": "ilírico",
    "ilírios": "ilírio",
    "ilógica": "ilógico",
    "ilógicas": "ilógico",
    "ilógicos": "ilógico",
    "ima": "imo",
    "imaculabilidades": "imaculabilidade",
    "imaculada": "imaculado",
    "imaculadas": "imaculado",
    "imaculados": "imaculado",
    "imaculadíssima": "imaculado",
    "imaculadíssimas": "imaculado",
    "imaculadíssimo": "imaculado",
    "imaculadíssimos": "imaculado",
    "imaculatismos": "imaculatismo",
    "imaculidades": "imaculidade",
    "imaculáveis": "imaculável",
    "imagens": "imagem",
    "imagina": "imaginar",
    "imaginada": "imaginar",
    "imaginadas": "imaginar",
    "imaginado": "imaginar",
    "imaginadora": "imaginador",
    "imaginadoras": "imaginador",
    "imaginadores": "imaginador",
    "imaginados": "imaginar",
    "imaginai": "imaginar",
    "imaginais": "imaginar",
    "imaginam": "imaginar",
    "imaginamo": "imaginar",
    "imaginamos": "imaginar",
    "imaginando": "imaginar",
    "imaginantes": "imaginante",
    "imaginara": "imaginar",
    "imaginaram": "imaginar",
    "imaginaras": "imaginar",
    "imaginarde": "imaginar",
    "imaginardes": "imaginar",
    "imaginare": "imaginar",
    "imaginarei": "imaginar",
    "imaginareis": "imaginar",
    "imaginarem": "imaginar",
    "imaginaremos": "imaginar",
    "imaginares": "imaginar",
    "imaginaria": "imaginar",
    "imaginariam": "imaginar",
    "imaginarias": "imaginaria",
    "imaginarmo": "imaginar",
    "imaginarmos": "imaginar",
    "imaginará": "imaginar",
    "imaginarás": "imaginar",
    "imaginarão": "imaginar",
    "imaginaríamos": "imaginar",
    "imaginaríeis": "imaginar",
    "imaginas": "imaginar",
    "imaginasse": "imaginar",
    "imaginassem": "imaginar",
    "imaginasses": "imaginar",
    "imaginaste": "imaginar",
    "imaginastes": "imaginar",
    "imaginativa": "imaginativo",
    "imaginativas": "imaginativo",
    "imaginativos": "imaginativo",
    "imaginava": "imaginar",
    "imaginavam": "imaginar",
    "imaginavas": "imaginar",
    "imaginações": "imaginação",
    "imagine": "imaginar",
    "imaginei": "imaginar",
    "imagineis": "imaginar",
    "imaginem": "imaginar",
    "imaginemo": "imaginar",
    "imaginemos": "imaginar",
    "imagines": "imaginar",
    "imaginismos": "imaginismo",
    "imagino": "imaginar",
    "imaginosa": "imaginoso",
    "imaginosas": "imaginoso",
    "imaginosos": "imaginoso",
    "imaginou": "imaginar",
    "imaginá": "imaginar",
    "imaginámo": "imaginar",
    "imaginámos": "imaginar",
    "imagináramo": "imaginar",
    "imagináramos": "imaginar",
    "imaginárei": "imaginar",
    "imagináreis": "imaginar",
    "imaginária": "imaginário",
    "imaginárias": "imaginário",
    "imaginários": "imaginário",
    "imaginásseis": "imaginar",
    "imaginássemos": "imaginar",
    "imaginávamo": "imaginar",
    "imaginávamos": "imaginar",
    "imaginávei": "imaginar",
    "imagináveis": "imaginável",
    "imagos": "imago",
    "imagética": "imagético",
    "imagéticas": "imagético",
    "imagéticos": "imagético",
    "imalas": "imala",
    "imaleabilidades": "imaleabilidade",
    "imaleáveis": "imaleável",
    "imames": "imame",
    "imamos": "imamo",
    "imana": "imanar",
    "imanada": "imanar",
    "imanadas": "imanar",
    "imanado": "imanar",
    "imanados": "imanar",
    "imanai": "imanar",
    "imanais": "imanar",
    "imanam": "imanar",
    "imanamo": "imanar",
    "imanamos": "imanar",
    "imanando": "imanar",
    "imanara": "imanar",
    "imanaram": "imanar",
    "imanaras": "imanar",
    "imanarde": "imanar",
    "imanardes": "imanar",
    "imanare": "imanar",
    "imanarei": "imanar",
    "imanareis": "imanar",
    "imanarem": "imanar",
    "imanaremos": "imanar",
    "imanares": "imanar",
    "imanaria": "imanar",
    "imanariam": "imanar",
    "imanarias": "imanar",
    "imanarmo": "imanar",
    "imanarmos": "imanar",
    "imanará": "imanar",
    "imanarás": "imanar",
    "imanarão": "imanar",
    "imanaríamos": "imanar",
    "imanaríeis": "imanar",
    "imanas": "imanar",
    "imanasse": "imanar",
    "imanassem": "imanar",
    "imanasses": "imanar",
    "imanaste": "imanar",
    "imanastes": "imanar",
    "imanava": "imanar",
    "imanavam": "imanar",
    "imanavas": "imanar",
    "imane": "imanar",
    "imanei": "imanar",
    "imaneis": "imanar",
    "imanejáveis": "imanejável",
    "imanem": "imanar",
    "imanemo": "imanar",
    "imanemos": "imanar",
    "imanentes": "imanente",
    "imanentismos": "imanentismo",
    "imanes": "imane",
    "imanidades": "imanidade",
    "imaniza": "imanizar",
    "imanizada": "imanizar",
    "imanizadas": "imanizar",
    "imanizado": "imanizar",
    "imanizados": "imanizar",
    "imanizai": "imanizar",
    "imanizais": "imanizar",
    "imanizam": "imanizar",
    "imanizamo": "imanizar",
    "imanizamos": "imanizar",
    "imanizando": "imanizar",
    "imanizara": "imanizar",
    "imanizaram": "imanizar",
    "imanizaras": "imanizar",
    "imanizarde": "imanizar",
    "imanizardes": "imanizar",
    "imanizare": "imanizar",
    "imanizarei": "imanizar",
    "imanizareis": "imanizar",
    "imanizarem": "imanizar",
    "imanizaremos": "imanizar",
    "imanizares": "imanizar",
    "imanizaria": "imanizar",
    "imanizariam": "imanizar",
    "imanizarias": "imanizar",
    "imanizarmo": "imanizar",
    "imanizarmos": "imanizar",
    "imanizará": "imanizar",
    "imanizarás": "imanizar",
    "imanizarão": "imanizar",
    "imanizaríamos": "imanizar",
    "imanizaríeis": "imanizar",
    "imanizas": "imanizar",
    "imanizasse": "imanizar",
    "imanizassem": "imanizar",
    "imanizasses": "imanizar",
    "imanizaste": "imanizar",
    "imanizastes": "imanizar",
    "imanizava": "imanizar",
    "imanizavam": "imanizar",
    "imanizavas": "imanizar",
    "imanizações": "imanização",
    "imanize": "imanizar",
    "imanizei": "imanizar",
    "imanizeis": "imanizar",
    "imanizem": "imanizar",
    "imanizemo": "imanizar",
    "imanizemos": "imanizar",
    "imanizes": "imanizar",
    "imanizo": "imanizar",
    "imanizou": "imanizar",
    "imanizá": "imanizar",
    "imanizámo": "imanizar",
    "imanizámos": "imanizar",
    "imanizáramo": "imanizar",
    "imanizáramos": "imanizar",
    "imanizárei": "imanizar",
    "imanizáreis": "imanizar",
    "imanizásseis": "imanizar",
    "imanizássemos": "imanizar",
    "imanizávamo": "imanizar",
    "imanizávamos": "imanizar",
    "imanizávei": "imanizar",
    "imanizáveis": "imanizar",
    "imano": "imanar",
    "imanou": "imanar",
    "imaná": "imanar",
    "imanámo": "imanar",
    "imanámos": "imanar",
    "imanáramo": "imanar",
    "imanáramos": "imanar",
    "imanárei": "imanar",
    "imanáreis": "imanar",
    "imanásseis": "imanar",
    "imanássemos": "imanar",
    "imanávamo": "imanar",
    "imanávamos": "imanar",
    "imanávei": "imanar",
    "imanáveis": "imanável",
    "imanências": "imanência",
    "imarcescibilidades": "imarcescibilidade",
    "imarcescíveis": "imarcescível",
    "imareada": "imareado",
    "imareadas": "imareado",
    "imareados": "imareado",
    "imareáveis": "imareável",
    "imarginada": "imarginado",
    "imarginadas": "imarginado",
    "imarginados": "imarginado",
    "imaruienses": "imaruiense",
    "imas": "imo",
    "imateriais": "imaterial",
    "imaterialidades": "imaterialidade",
    "imaterialismos": "imaterialismo",
    "imaterialistas": "imaterialista",
    "imaterializa": "imaterializar",
    "imaterializada": "imaterializar",
    "imaterializadas": "imaterializar",
    "imaterializado": "imaterializar",
    "imaterializados": "imaterializar",
    "imaterializai": "imaterializar",
    "imaterializais": "imaterializar",
    "imaterializam": "imaterializar",
    "imaterializamo": "imaterializar",
    "imaterializamos": "imaterializar",
    "imaterializando": "imaterializar",
    "imaterializara": "imaterializar",
    "imaterializaram": "imaterializar",
    "imaterializaras": "imaterializar",
    "imaterializarde": "imaterializar",
    "imaterializardes": "imaterializar",
    "imaterializare": "imaterializar",
    "imaterializarei": "imaterializar",
    "imaterializareis": "imaterializar",
    "imaterializarem": "imaterializar",
    "imaterializaremos": "imaterializar",
    "imaterializares": "imaterializar",
    "imaterializaria": "imaterializar",
    "imaterializariam": "imaterializar",
    "imaterializarias": "imaterializar",
    "imaterializarmo": "imaterializar",
    "imaterializarmos": "imaterializar",
    "imaterializará": "imaterializar",
    "imaterializarás": "imaterializar",
    "imaterializarão": "imaterializar",
    "imaterializaríamos": "imaterializar",
    "imaterializaríeis": "imaterializar",
    "imaterializas": "imaterializar",
    "imaterializasse": "imaterializar",
    "imaterializassem": "imaterializar",
    "imaterializasses": "imaterializar",
    "imaterializaste": "imaterializar",
    "imaterializastes": "imaterializar",
    "imaterializava": "imaterializar",
    "imaterializavam": "imaterializar",
    "imaterializavas": "imaterializar",
    "imaterialize": "imaterializar",
    "imaterializei": "imaterializar",
    "imaterializeis": "imaterializar",
    "imaterializem": "imaterializar",
    "imaterializemo": "imaterializar",
    "imaterializemos": "imaterializar",
    "imaterializes": "imaterializar",
    "imaterializo": "imaterializar",
    "imaterializou": "imaterializar",
    "imaterializá": "imaterializar",
    "imaterializámo": "imaterializar",
    "imaterializámos": "imaterializar",
    "imaterializáramo": "imaterializar",
    "imaterializáramos": "imaterializar",
    "imaterializárei": "imaterializar",
    "imaterializáreis": "imaterializar",
    "imaterializásseis": "imaterializar",
    "imaterializássemos": "imaterializar",
    "imaterializávamo": "imaterializar",
    "imaterializávamos": "imaterializar",
    "imaterializávei": "imaterializar",
    "imaterializáveis": "imaterializar",
    "imatura": "imaturo",
    "imaturas": "imaturo",
    "imaturidades": "imaturidade",
    "imaturos": "imaturo",
    "imbaníveis": "imbanível",
    "imbaralháveis": "imbaralhável",
    "imbatíveis": "imbatível",
    "imbaíbas": "imbaíba",
    "imbaúbas": "imbaúba",
    "imbebíveis": "imbebível",
    "imbecilidades": "imbecilidade",
    "imbeciliza": "imbecilizar",
    "imbecilizada": "imbecilizar",
    "imbecilizadas": "imbecilizar",
    "imbecilizado": "imbecilizar",
    "imbecilizados": "imbecilizar",
    "imbecilizai": "imbecilizar",
    "imbecilizais": "imbecilizar",
    "imbecilizam": "imbecilizar",
    "imbecilizamo": "imbecilizar",
    "imbecilizamos": "imbecilizar",
    "imbecilizando": "imbecilizar",
    "imbecilizara": "imbecilizar",
    "imbecilizaram": "imbecilizar",
    "imbecilizaras": "imbecilizar",
    "imbecilizarde": "imbecilizar",
    "imbecilizardes": "imbecilizar",
    "imbecilizare": "imbecilizar",
    "imbecilizarei": "imbecilizar",
    "imbecilizareis": "imbecilizar",
    "imbecilizarem": "imbecilizar",
    "imbecilizaremos": "imbecilizar",
    "imbecilizares": "imbecilizar",
    "imbecilizaria": "imbecilizar",
    "imbecilizariam": "imbecilizar",
    "imbecilizarias": "imbecilizar",
    "imbecilizarmo": "imbecilizar",
    "imbecilizarmos": "imbecilizar",
    "imbecilizará": "imbecilizar",
    "imbecilizarás": "imbecilizar",
    "imbecilizarão": "imbecilizar",
    "imbecilizaríamos": "imbecilizar",
    "imbecilizaríeis": "imbecilizar",
    "imbecilizas": "imbecilizar",
    "imbecilizasse": "imbecilizar",
    "imbecilizassem": "imbecilizar",
    "imbecilizasses": "imbecilizar",
    "imbecilizaste": "imbecilizar",
    "imbecilizastes": "imbecilizar",
    "imbecilizava": "imbecilizar",
    "imbecilizavam": "imbecilizar",
    "imbecilizavas": "imbecilizar",
    "imbecilize": "imbecilizar",
    "imbecilizei": "imbecilizar",
    "imbecilizeis": "imbecilizar",
    "imbecilizem": "imbecilizar",
    "imbecilizemo": "imbecilizar",
    "imbecilizemos": "imbecilizar",
    "imbecilizes": "imbecilizar",
    "imbecilizo": "imbecilizar",
    "imbecilizou": "imbecilizar",
    "imbecilizá": "imbecilizar",
    "imbecilizámo": "imbecilizar",
    "imbecilizámos": "imbecilizar",
    "imbecilizáramo": "imbecilizar",
    "imbecilizáramos": "imbecilizar",
    "imbecilizárei": "imbecilizar",
    "imbecilizáreis": "imbecilizar",
    "imbecilizásseis": "imbecilizar",
    "imbecilizássemos": "imbecilizar",
    "imbecilizávamo": "imbecilizar",
    "imbecilizávamos": "imbecilizar",
    "imbecilizávei": "imbecilizar",
    "imbecilizáveis": "imbecilizável",
    "imbecilíssima": "imbecil",
    "imbecilíssimas": "imbecil",
    "imbecilíssimo": "imbecil",
    "imbecilíssimos": "imbecil",
    "imbecis": "imbecil",
    "imbeles": "imbele",
    "imbeneficiáveis": "imbeneficiável",
    "imberbes": "imberbe",
    "imbibições": "imbibição",
    "imbica": "imbicar",
    "imbicada": "imbicar",
    "imbicadas": "imbicar",
    "imbicado": "imbicar",
    "imbicados": "imbicar",
    "imbicais": "imbicar",
    "imbicam": "imbicar",
    "imbicamo": "imbicar",
    "imbicamos": "imbicar",
    "imbicando": "imbicar",
    "imbicara": "imbicar",
    "imbicaram": "imbicar",
    "imbicaras": "imbicar",
    "imbicardes": "imbicar",
    "imbicarei": "imbicar",
    "imbicareis": "imbicar",
    "imbicarem": "imbicar",
    "imbicaremos": "imbicar",
    "imbicares": "imbicar",
    "imbicaria": "imbicar",
    "imbicariam": "imbicar",
    "imbicarias": "imbicar",
    "imbicarmo": "imbicar",
    "imbicarmos": "imbicar",
    "imbicará": "imbicar",
    "imbicarás": "imbicar",
    "imbicarão": "imbicar",
    "imbicaríamos": "imbicar",
    "imbicaríeis": "imbicar",
    "imbicas": "imbicar",
    "imbicasse": "imbicar",
    "imbicassem": "imbicar",
    "imbicasses": "imbicar",
    "imbicaste": "imbicar",
    "imbicastes": "imbicar",
    "imbicava": "imbicar",
    "imbicavam": "imbicar",
    "imbicavas": "imbicar",
    "imbico": "imbicar",
    "imbicou": "imbicar",
    "imbicámo": "imbicar",
    "imbicámos": "imbicar",
    "imbicáramo": "imbicar",
    "imbicáramos": "imbicar",
    "imbicáreis": "imbicar",
    "imbicásseis": "imbicar",
    "imbicássemos": "imbicar",
    "imbicávamo": "imbicar",
    "imbicávamos": "imbicar",
    "imbicáveis": "imbicar",
    "imbilas": "imbila",
    "imbique": "imbicar",
    "imbiquei": "imbicar",
    "imbiqueis": "imbicar",
    "imbiquem": "imbicar",
    "imbiquemos": "imbicar",
    "imbiques": "imbicar",
    "imbiras": "imbira",
    "imbloqueáveis": "imbloqueável",
    "imboicotáveis": "imboicotável",
    "imbombardeáveis": "imbombardeável",
    "imborãs": "imborã",
    "imbranqueáveis": "imbranqueável",
    "imbrica": "imbricar",
    "imbricada": "imbricar",
    "imbricadas": "imbricar",
    "imbricado": "imbricar",
    "imbricados": "imbricar",
    "imbricadíssima": "imbricado",
    "imbricadíssimas": "imbricado",
    "imbricadíssimo": "imbricado",
    "imbricadíssimos": "imbricado",
    "imbricai": "imbricar",
    "imbricais": "imbricar",
    "imbricam": "imbricar",
    "imbricamo": "imbricar",
    "imbricamos": "imbricar",
    "imbricando": "imbricar",
    "imbricantes": "imbricante",
    "imbricara": "imbricar",
    "imbricaram": "imbricar",
    "imbricaras": "imbricar",
    "imbricarde": "imbricar",
    "imbricardes": "imbricar",
    "imbricare": "imbricar",
    "imbricarei": "imbricar",
    "imbricareis": "imbricar",
    "imbricarem": "imbricar",
    "imbricaremos": "imbricar",
    "imbricares": "imbricar",
    "imbricaria": "imbricar",
    "imbricariam": "imbricar",
    "imbricarias": "imbricar",
    "imbricarmo": "imbricar",
    "imbricarmos": "imbricar",
    "imbricará": "imbricar",
    "imbricarás": "imbricar",
    "imbricarão": "imbricar",
    "imbricaríamos": "imbricar",
    "imbricaríeis": "imbricar",
    "imbricas": "imbricar",
    "imbricasse": "imbricar",
    "imbricassem": "imbricar",
    "imbricasses": "imbricar",
    "imbricaste": "imbricar",
    "imbricastes": "imbricar",
    "imbricava": "imbricar",
    "imbricavam": "imbricar",
    "imbricavas": "imbricar",
    "imbricações": "imbricação",
    "imbrico": "imbricar",
    "imbricou": "imbricar",
    "imbricá": "imbricar",
    "imbricámo": "imbricar",
    "imbricámos": "imbricar",
    "imbricáramo": "imbricar",
    "imbricáramos": "imbricar",
    "imbricárei": "imbricar",
    "imbricáreis": "imbricar",
    "imbricásseis": "imbricar",
    "imbricássemos": "imbricar",
    "imbricávamo": "imbricar",
    "imbricávamos": "imbricar",
    "imbricávei": "imbricar",
    "imbricáveis": "imbricável",
    "imbrincada": "imbrincado",
    "imbrincadas": "imbrincado",
    "imbrincados": "imbrincado",
    "imbrique": "imbricar",
    "imbriquei": "imbricar",
    "imbriqueis": "imbricar",
    "imbriquem": "imbricar",
    "imbriquemo": "imbricar",
    "imbriquemos": "imbricar",
    "imbriques": "imbricar",
    "imbrífera": "imbrífero",
    "imbríferas": "imbrífero",
    "imbríferos": "imbrífero",
    "imbrífuga": "imbrífugo",
    "imbrífugas": "imbrífugo",
    "imbrífugos": "imbrífugo",
    "imbróglios": "imbróglio",
    "imbua": "imbuir",
    "imbuais": "imbuir",
    "imbuam": "imbuir",
    "imbuamo": "imbuir",
    "imbuamos": "imbuir",
    "imbuas": "imbuir",
    "imbuem": "imbuir",
    "imbui": "imbuir",
    "imbuindo": "imbuir",
    "imbuirde": "imbuir",
    "imbuirdes": "imbuir",
    "imbuirei": "imbuir",
    "imbuireis": "imbuir",
    "imbuiremos": "imbuir",
    "imbuiria": "imbuir",
    "imbuiriam": "imbuir",
    "imbuirias": "imbuir",
    "imbuirmo": "imbuir",
    "imbuirmos": "imbuir",
    "imbuirá": "imbuir",
    "imbuirás": "imbuir",
    "imbuirão": "imbuir",
    "imbuiríamos": "imbuir",
    "imbuiríeis": "imbuir",
    "imbuis": "imbuir",
    "imbuiu": "imbuir",
    "imbuições": "imbuição",
    "imbundes": "imbunde",
    "imbuo": "imbuir",
    "imburláveis": "imburlável",
    "imbuí": "imbuir",
    "imbuía": "imbuir",
    "imbuíam": "imbuir",
    "imbuíamo": "imbuir",
    "imbuíamos": "imbuir",
    "imbuías": "imbuir",
    "imbuída": "imbuir",
    "imbuídas": "imbuir",
    "imbuído": "imbuir",
    "imbuídos": "imbuir",
    "imbuíei": "imbuir",
    "imbuíeis": "imbuir",
    "imbuímo": "imbuir",
    "imbuímos": "imbuir",
    "imbuíra": "imbuir",
    "imbuíram": "imbuir",
    "imbuíramo": "imbuir",
    "imbuíramos": "imbuir",
    "imbuíras": "imbuir",
    "imbuíre": "imbuir",
    "imbuírei": "imbuir",
    "imbuíreis": "imbuir",
    "imbuírem": "imbuir",
    "imbuíres": "imbuir",
    "imbuís": "imbuir",
    "imbuísse": "imbuir",
    "imbuísseis": "imbuir",
    "imbuíssem": "imbuir",
    "imbuíssemos": "imbuir",
    "imbuísses": "imbuir",
    "imbuíste": "imbuir",
    "imbuístes": "imbuir",
    "imbuíveis": "imbuível",
    "imediata": "imediato",
    "imediatas": "imediato",
    "imediatezes": "imediatez",
    "imediatismos": "imediatismo",
    "imediatistas": "imediatista",
    "imediatiza": "imediatizar",
    "imediatizada": "imediatizar",
    "imediatizadas": "imediatizar",
    "imediatizado": "imediatizar",
    "imediatizados": "imediatizar",
    "imediatizai": "imediatizar",
    "imediatizais": "imediatizar",
    "imediatizam": "imediatizar",
    "imediatizamo": "imediatizar",
    "imediatizamos": "imediatizar",
    "imediatizando": "imediatizar",
    "imediatizara": "imediatizar",
    "imediatizaram": "imediatizar",
    "imediatizaras": "imediatizar",
    "imediatizarde": "imediatizar",
    "imediatizardes": "imediatizar",
    "imediatizare": "imediatizar",
    "imediatizarei": "imediatizar",
    "imediatizareis": "imediatizar",
    "imediatizarem": "imediatizar",
    "imediatizaremos": "imediatizar",
    "imediatizares": "imediatizar",
    "imediatizaria": "imediatizar",
    "imediatizariam": "imediatizar",
    "imediatizarias": "imediatizar",
    "imediatizarmo": "imediatizar",
    "imediatizarmos": "imediatizar",
    "imediatizará": "imediatizar",
    "imediatizarás": "imediatizar",
    "imediatizarão": "imediatizar",
    "imediatizaríamos": "imediatizar",
    "imediatizaríeis": "imediatizar",
    "imediatizas": "imediatizar",
    "imediatizasse": "imediatizar",
    "imediatizassem": "imediatizar",
    "imediatizasses": "imediatizar",
    "imediatizaste": "imediatizar",
    "imediatizastes": "imediatizar",
    "imediatizava": "imediatizar",
    "imediatizavam": "imediatizar",
    "imediatizavas": "imediatizar",
    "imediatize": "imediatizar",
    "imediatizei": "imediatizar",
    "imediatizeis": "imediatizar",
    "imediatizem": "imediatizar",
    "imediatizemo": "imediatizar",
    "imediatizemos": "imediatizar",
    "imediatizes": "imediatizar",
    "imediatizo": "imediatizar",
    "imediatizou": "imediatizar",
    "imediatizá": "imediatizar",
    "imediatizámo": "imediatizar",
    "imediatizámos": "imediatizar",
    "imediatizáramo": "imediatizar",
    "imediatizáramos": "imediatizar",
    "imediatizárei": "imediatizar",
    "imediatizáreis": "imediatizar",
    "imediatizásseis": "imediatizar",
    "imediatizássemos": "imediatizar",
    "imediatizávamo": "imediatizar",
    "imediatizávamos": "imediatizar",
    "imediatizávei": "imediatizar",
    "imediatizáveis": "imediatizar",
    "imediatos": "imediato",
    "imediações": "imediação",
    "imedicáveis": "imedicável",
    "imemorabilidades": "imemorabilidade",
    "imemorada": "imemorado",
    "imemoradas": "imemorado",
    "imemorados": "imemorado",
    "imemoriais": "imemorial",
    "imemoriáveis": "imemoriável",
    "imemoráveis": "imemorável",
    "imensa": "imenso",
    "imensas": "imenso",
    "imensidades": "imensidade",
    "imensidões": "imensidão",
    "imensos": "imenso",
    "imensurabilidades": "imensurabilidade",
    "imensuráveis": "imensurável",
    "imerecida": "imerecido",
    "imerecidas": "imerecido",
    "imerecidos": "imerecido",
    "imerge": "imergir",
    "imergem": "imergir",
    "imergentes": "imergente",
    "imerges": "imergir",
    "imergi": "imergir",
    "imergia": "imergir",
    "imergiam": "imergir",
    "imergias": "imergir",
    "imergida": "imergir",
    "imergidas": "imergir",
    "imergido": "imergir",
    "imergidos": "imergir",
    "imergimo": "imergir",
    "imergimos": "imergir",
    "imergindo": "imergir",
    "imergira": "imergir",
    "imergiram": "imergir",
    "imergiras": "imergir",
    "imergirde": "imergir",
    "imergirdes": "imergir",
    "imergire": "imergir",
    "imergirei": "imergir",
    "imergireis": "imergir",
    "imergirem": "imergir",
    "imergiremos": "imergir",
    "imergires": "imergir",
    "imergiria": "imergir",
    "imergiriam": "imergir",
    "imergirias": "imergir",
    "imergirmo": "imergir",
    "imergirmos": "imergir",
    "imergirá": "imergir",
    "imergirás": "imergir",
    "imergirão": "imergir",
    "imergiríamos": "imergir",
    "imergiríeis": "imergir",
    "imergis": "imergir",
    "imergisse": "imergir",
    "imergissem": "imergir",
    "imergisses": "imergir",
    "imergiste": "imergir",
    "imergistes": "imergir",
    "imergiu": "imergir",
    "imergências": "imergência",
    "imergíamo": "imergir",
    "imergíamos": "imergir",
    "imergíei": "imergir",
    "imergíeis": "imergir",
    "imergíramo": "imergir",
    "imergíramos": "imergir",
    "imergírei": "imergir",
    "imergíreis": "imergir",
    "imergísseis": "imergir",
    "imergíssemos": "imergir",
    "imersa": "imerso",
    "imersas": "imerso",
    "imersionismos": "imersionismo",
    "imersionistas": "imersionista",
    "imersiva": "imersivo",
    "imersivas": "imersivo",
    "imersivos": "imersivo",
    "imersora": "imersor",
    "imersoras": "imersor",
    "imersores": "imersor",
    "imersos": "imerso",
    "imersíveis": "imersível",
    "imersões": "imersão",
    "imidas": "imida",
    "imidogénios": "imidogénio",
    "imiga": "imigo",
    "imigas": "imigo",
    "imigos": "imigo",
    "imigra": "imigrar",
    "imigrada": "imigrar",
    "imigradas": "imigrar",
    "imigrado": "imigrar",
    "imigrados": "imigrar",
    "imigrai": "imigrar",
    "imigrais": "imigrar",
    "imigram": "imigrar",
    "imigramo": "imigrar",
    "imigramos": "imigrar",
    "imigrando": "imigrar",
    "imigrantes": "imigrante",
    "imigrantistas": "imigrantista",
    "imigrara": "imigrar",
    "imigraram": "imigrar",
    "imigraras": "imigrar",
    "imigrardes": "imigrar",
    "imigrarei": "imigrar",
    "imigrareis": "imigrar",
    "imigrarem": "imigrar",
    "imigraremos": "imigrar",
    "imigrares": "imigrar",
    "imigraria": "imigrar",
    "imigrariam": "imigrar",
    "imigrarias": "imigrar",
    "imigrarmo": "imigrar",
    "imigrarmos": "imigrar",
    "imigrará": "imigrar",
    "imigrarás": "imigrar",
    "imigrarão": "imigrar",
    "imigraríamos": "imigrar",
    "imigraríeis": "imigrar",
    "imigras": "imigrar",
    "imigrasse": "imigrar",
    "imigrassem": "imigrar",
    "imigrasses": "imigrar",
    "imigraste": "imigrar",
    "imigrastes": "imigrar",
    "imigratória": "imigratório",
    "imigratórias": "imigratório",
    "imigratórios": "imigratório",
    "imigrava": "imigrar",
    "imigravam": "imigrar",
    "imigravas": "imigrar",
    "imigrações": "imigração",
    "imigre": "imigrar",
    "imigrei": "imigrar",
    "imigreis": "imigrar",
    "imigrem": "imigrar",
    "imigremo": "imigrar",
    "imigremos": "imigrar",
    "imigres": "imigrar",
    "imigro": "imigrar",
    "imigrou": "imigrar",
    "imigrámo": "imigrar",
    "imigrámos": "imigrar",
    "imigráramo": "imigrar",
    "imigráramos": "imigrar",
    "imigráreis": "imigrar",
    "imigrásseis": "imigrar",
    "imigrássemos": "imigrar",
    "imigrávamo": "imigrar",
    "imigrávamos": "imigrar",
    "imigráveis": "imigrar",
    "iminentes": "iminente",
    "iminências": "iminência",
    "imirja": "imergir",
    "imirjais": "imergir",
    "imirjam": "imergir",
    "imirjamo": "imergir",
    "imirjamos": "imergir",
    "imirjas": "imergir",
    "imirjo": "imergir",
    "imiscibilidades": "imiscibilidade",
    "imiscua": "imiscuir",
    "imiscuais": "imiscuir",
    "imiscuam": "imiscuir",
    "imiscuamo": "imiscuir",
    "imiscuamos": "imiscuir",
    "imiscuas": "imiscuir",
    "imiscuem": "imiscuir",
    "imiscui": "imiscuir",
    "imiscuindo": "imiscuir",
    "imiscuirdes": "imiscuir",
    "imiscuirei": "imiscuir",
    "imiscuireis": "imiscuir",
    "imiscuiremos": "imiscuir",
    "imiscuiria": "imiscuir",
    "imiscuiriam": "imiscuir",
    "imiscuirias": "imiscuir",
    "imiscuirmo": "imiscuir",
    "imiscuirmos": "imiscuir",
    "imiscuirá": "imiscuir",
    "imiscuirás": "imiscuir",
    "imiscuirão": "imiscuir",
    "imiscuiríamos": "imiscuir",
    "imiscuiríeis": "imiscuir",
    "imiscuis": "imiscuir",
    "imiscuiu": "imiscuir",
    "imiscuições": "imiscuição",
    "imiscuo": "imiscuir",
    "imiscuí": "imiscuir",
    "imiscuía": "imiscuir",
    "imiscuíam": "imiscuir",
    "imiscuíamo": "imiscuir",
    "imiscuíamos": "imiscuir",
    "imiscuías": "imiscuir",
    "imiscuída": "imiscuir",
    "imiscuídas": "imiscuir",
    "imiscuído": "imiscuir",
    "imiscuídos": "imiscuir",
    "imiscuíeis": "imiscuir",
    "imiscuímo": "imiscuir",
    "imiscuímos": "imiscuir",
    "imiscuíra": "imiscuir",
    "imiscuíram": "imiscuir",
    "imiscuíramo": "imiscuir",
    "imiscuíramos": "imiscuir",
    "imiscuíras": "imiscuir",
    "imiscuíreis": "imiscuir",
    "imiscuírem": "imiscuir",
    "imiscuíres": "imiscuir",
    "imiscuís": "imiscuir",
    "imiscuísse": "imiscuir",
    "imiscuísseis": "imiscuir",
    "imiscuíssem": "imiscuir",
    "imiscuíssemos": "imiscuir",
    "imiscuísses": "imiscuir",
    "imiscuíste": "imiscuir",
    "imiscuístes": "imiscuir",
    "imiscíveis": "imiscível",
    "imisericordiosa": "imisericordioso",
    "imisericordiosas": "imisericordioso",
    "imisericordiosos": "imisericordioso",
    "imisericórdias": "imisericórdia",
    "imissa": "imisso",
    "imissas": "imisso",
    "imissos": "imisso",
    "imissões": "imissão",
    "imisções": "imisção",
    "imita": "imitir",
    "imitabilidades": "imitabilidade",
    "imitada": "imitar",
    "imitadas": "imitar",
    "imitado": "imitar",
    "imitadora": "imitador",
    "imitadoras": "imitador",
    "imitadores": "imitador",
    "imitados": "imitar",
    "imitadíssima": "imitado",
    "imitadíssimas": "imitado",
    "imitadíssimo": "imitado",
    "imitadíssimos": "imitado",
    "imitai": "imitar",
    "imitais": "imitir",
    "imitam": "imitir",
    "imitamo": "imitir",
    "imitamos": "imitir",
    "imitando": "imitar",
    "imitara": "imitar",
    "imitaram": "imitar",
    "imitaras": "imitar",
    "imitarde": "imitar",
    "imitardes": "imitar",
    "imitare": "imitar",
    "imitarei": "imitar",
    "imitareis": "imitar",
    "imitarem": "imitar",
    "imitaremos": "imitar",
    "imitares": "imitar",
    "imitaria": "imitar",
    "imitariam": "imitar",
    "imitarias": "imitar",
    "imitarmo": "imitar",
    "imitarmos": "imitar",
    "imitará": "imitar",
    "imitarás": "imitar",
    "imitarão": "imitar",
    "imitaríamos": "imitar",
    "imitaríeis": "imitar",
    "imitas": "imitir",
    "imitasse": "imitar",
    "imitassem": "imitar",
    "imitasses": "imitar",
    "imitaste": "imitar",
    "imitastes": "imitar",
    "imitativa": "imitativo",
    "imitativas": "imitativo",
    "imitativos": "imitativo",
    "imitava": "imitar",
    "imitavam": "imitar",
    "imitavas": "imitar",
    "imitações": "imitação",
    "imite": "imitir",
    "imitei": "imitar",
    "imiteis": "imitar",
    "imitem": "imitir",
    "imitemo": "imitar",
    "imitemos": "imitar",
    "imites": "imitir",
    "imiti": "imitir",
    "imitia": "imitir",
    "imitiam": "imitir",
    "imitias": "imitir",
    "imitida": "imitir",
    "imitidas": "imitir",
    "imitido": "imitir",
    "imitidos": "imitir",
    "imitimo": "imitir",
    "imitimos": "imitir",
    "imitindo": "imitir",
    "imitira": "imitir",
    "imitiram": "imitir",
    "imitiras": "imitir",
    "imitirde": "imitir",
    "imitirdes": "imitir",
    "imitire": "imitir",
    "imitirei": "imitir",
    "imitireis": "imitir",
    "imitirem": "imitir",
    "imitiremos": "imitir",
    "imitires": "imitir",
    "imitiria": "imitir",
    "imitiriam": "imitir",
    "imitirias": "imitir",
    "imitirmo": "imitir",
    "imitirmos": "imitir",
    "imitirá": "imitir",
    "imitirás": "imitir",
    "imitirão": "imitir",
    "imitiríamos": "imitir",
    "imitiríeis": "imitir",
    "imitis": "imitir",
    "imitisse": "imitir",
    "imitissem": "imitir",
    "imitisses": "imitir",
    "imitiste": "imitir",
    "imitistes": "imitir",
    "imitiu": "imitir",
    "imito": "imitir",
    "imitou": "imitar",
    "imitá": "imitar",
    "imitámo": "imitar",
    "imitámos": "imitar",
    "imitáramo": "imitar",
    "imitáramos": "imitar",
    "imitárei": "imitar",
    "imitáreis": "imitar",
    "imitásseis": "imitar",
    "imitássemos": "imitar",
    "imitávamo": "imitar",
    "imitávamos": "imitar",
    "imitávei": "imitar",
    "imitáveis": "imitável",
    "imitâncias": "imitância",
    "imitíamo": "imitir",
    "imitíamos": "imitir",
    "imitíei": "imitir",
    "imitíeis": "imitir",
    "imitíramo": "imitir",
    "imitíramos": "imitir",
    "imitírei": "imitir",
    "imitíreis": "imitir",
    "imitísseis": "imitir",
    "imitíssemos": "imitir",
    "imitíveis": "imitível",
    "imobilidades": "imobilidade",
    "imobilismos": "imobilismo",
    "imobilistas": "imobilista",
    "imobiliza": "imobilizar",
    "imobilizada": "imobilizar",
    "imobilizadas": "imobilizar",
    "imobilizado": "imobilizar",
    "imobilizados": "imobilizar",
    "imobilizai": "imobilizar",
    "imobilizais": "imobilizar",
    "imobilizam": "imobilizar",
    "imobilizamo": "imobilizar",
    "imobilizamos": "imobilizar",
    "imobilizando": "imobilizar",
    "imobilizara": "imobilizar",
    "imobilizaram": "imobilizar",
    "imobilizaras": "imobilizar",
    "imobilizarde": "imobilizar",
    "imobilizardes": "imobilizar",
    "imobilizare": "imobilizar",
    "imobilizarei": "imobilizar",
    "imobilizareis": "imobilizar",
    "imobilizarem": "imobilizar",
    "imobilizaremos": "imobilizar",
    "imobilizares": "imobilizar",
    "imobilizaria": "imobilizar",
    "imobilizariam": "imobilizar",
    "imobilizarias": "imobilizar",
    "imobilizarmo": "imobilizar",
    "imobilizarmos": "imobilizar",
    "imobilizará": "imobilizar",
    "imobilizarás": "imobilizar",
    "imobilizarão": "imobilizar",
    "imobilizaríamos": "imobilizar",
    "imobilizaríeis": "imobilizar",
    "imobilizas": "imobilizar",
    "imobilizasse": "imobilizar",
    "imobilizassem": "imobilizar",
    "imobilizasses": "imobilizar",
    "imobilizaste": "imobilizar",
    "imobilizastes": "imobilizar",
    "imobilizava": "imobilizar",
    "imobilizavam": "imobilizar",
    "imobilizavas": "imobilizar",
    "imobilizações": "imobilização",
    "imobilize": "imobilizar",
    "imobilizei": "imobilizar",
    "imobilizeis": "imobilizar",
    "imobilizem": "imobilizar",
    "imobilizemo": "imobilizar",
    "imobilizemos": "imobilizar",
    "imobilizes": "imobilizar",
    "imobilizo": "imobilizar",
    "imobilizou": "imobilizar",
    "imobilizá": "imobilizar",
    "imobilizámo": "imobilizar",
    "imobilizámos": "imobilizar",
    "imobilizáramo": "imobilizar",
    "imobilizáramos": "imobilizar",
    "imobilizárei": "imobilizar",
    "imobilizáreis": "imobilizar",
    "imobilizásseis": "imobilizar",
    "imobilizássemos": "imobilizar",
    "imobilizávamo": "imobilizar",
    "imobilizávamos": "imobilizar",
    "imobilizávei": "imobilizar",
    "imobilizáveis": "imobilizável",
    "imobiliária": "imobiliário",
    "imobiliárias": "imobiliário",
    "imobiliários": "imobiliário",
    "imoderada": "imoderado",
    "imoderadas": "imoderado",
    "imoderados": "imoderado",
    "imoderações": "imoderação",
    "imodesta": "imodesto",
    "imodestas": "imodesto",
    "imodestos": "imodesto",
    "imodestíssima": "imodesto",
    "imodestíssimas": "imodesto",
    "imodestíssimo": "imodesto",
    "imodestíssimos": "imodesto",
    "imodicidades": "imodicidade",
    "imodificáveis": "imodificável",
    "imodéstias": "imodéstia",
    "imola": "imolar",
    "imolada": "imolar",
    "imoladas": "imolar",
    "imolado": "imolar",
    "imoladora": "imolador",
    "imoladoras": "imolador",
    "imoladores": "imolador",
    "imolados": "imolar",
    "imolai": "imolar",
    "imolais": "imolar",
    "imolam": "imolar",
    "imolamo": "imolar",
    "imolamos": "imolar",
    "imolanda": "imolando",
    "imolandas": "imolando",
    "imolando": "imolar",
    "imolandos": "imolando",
    "imolantes": "imolante",
    "imolara": "imolar",
    "imolaram": "imolar",
    "imolaras": "imolar",
    "imolarde": "imolar",
    "imolardes": "imolar",
    "imolare": "imolar",
    "imolarei": "imolar",
    "imolareis": "imolar",
    "imolarem": "imolar",
    "imolaremos": "imolar",
    "imolares": "imolar",
    "imolaria": "imolar",
    "imolariam": "imolar",
    "imolarias": "imolar",
    "imolarmo": "imolar",
    "imolarmos": "imolar",
    "imolará": "imolar",
    "imolarás": "imolar",
    "imolarão": "imolar",
    "imolaríamos": "imolar",
    "imolaríeis": "imolar",
    "imolas": "imolar",
    "imolasse": "imolar",
    "imolassem": "imolar",
    "imolasses": "imolar",
    "imolaste": "imolar",
    "imolastes": "imolar",
    "imolava": "imolar",
    "imolavam": "imolar",
    "imolavas": "imolar",
    "imolações": "imolação",
    "imole": "imolar",
    "imolei": "imolar",
    "imoleis": "imolar",
    "imolem": "imolar",
    "imolemo": "imolar",
    "imolemos": "imolar",
    "imoles": "imolar",
    "imolo": "imolar",
    "imolou": "imolar",
    "imolá": "imolar",
    "imolámo": "imolar",
    "imolámos": "imolar",
    "imoláramo": "imolar",
    "imoláramos": "imolar",
    "imolárei": "imolar",
    "imoláreis": "imolar",
    "imolásseis": "imolar",
    "imolássemos": "imolar",
    "imolávamo": "imolar",
    "imolávamos": "imolar",
    "imolávei": "imolar",
    "imoláveis": "imolável",
    "imorais": "imoral",
    "imoralidades": "imoralidade",
    "imoralismos": "imoralismo",
    "imoralistas": "imoralista",
    "imorals": "imoral",
    "imorigerada": "imorigerado",
    "imorigeradas": "imorigerado",
    "imorigerados": "imorigerado",
    "imorredoira": "imorredoiro",
    "imorredoiras": "imorredoiro",
    "imorredoiros": "imorredoiro",
    "imorredoura": "imorredouro",
    "imorredouras": "imorredouro",
    "imorredouros": "imorredouro",
    "imortais": "imortal",
    "imortalidades": "imortalidade",
    "imortaliza": "imortalizar",
    "imortalizada": "imortalizar",
    "imortalizadas": "imortalizar",
    "imortalizado": "imortalizar",
    "imortalizadora": "imortalizador",
    "imortalizadoras": "imortalizador",
    "imortalizadores": "imortalizador",
    "imortalizados": "imortalizar",
    "imortalizai": "imortalizar",
    "imortalizais": "imortalizar",
    "imortalizam": "imortalizar",
    "imortalizamo": "imortalizar",
    "imortalizamos": "imortalizar",
    "imortalizando": "imortalizar",
    "imortalizara": "imortalizar",
    "imortalizaram": "imortalizar",
    "imortalizaras": "imortalizar",
    "imortalizarde": "imortalizar",
    "imortalizardes": "imortalizar",
    "imortalizare": "imortalizar",
    "imortalizarei": "imortalizar",
    "imortalizareis": "imortalizar",
    "imortalizarem": "imortalizar",
    "imortalizaremos": "imortalizar",
    "imortalizares": "imortalizar",
    "imortalizaria": "imortalizar",
    "imortalizariam": "imortalizar",
    "imortalizarias": "imortalizar",
    "imortalizarmo": "imortalizar",
    "imortalizarmos": "imortalizar",
    "imortalizará": "imortalizar",
    "imortalizarás": "imortalizar",
    "imortalizarão": "imortalizar",
    "imortalizaríamos": "imortalizar",
    "imortalizaríeis": "imortalizar",
    "imortalizas": "imortalizar",
    "imortalizasse": "imortalizar",
    "imortalizassem": "imortalizar",
    "imortalizasses": "imortalizar",
    "imortalizaste": "imortalizar",
    "imortalizastes": "imortalizar",
    "imortalizava": "imortalizar",
    "imortalizavam": "imortalizar",
    "imortalizavas": "imortalizar",
    "imortalizações": "imortalização",
    "imortalize": "imortalizar",
    "imortalizei": "imortalizar",
    "imortalizeis": "imortalizar",
    "imortalizem": "imortalizar",
    "imortalizemo": "imortalizar",
    "imortalizemos": "imortalizar",
    "imortalizes": "imortalizar",
    "imortalizo": "imortalizar",
    "imortalizou": "imortalizar",
    "imortalizá": "imortalizar",
    "imortalizámo": "imortalizar",
    "imortalizámos": "imortalizar",
    "imortalizáramo": "imortalizar",
    "imortalizáramos": "imortalizar",
    "imortalizárei": "imortalizar",
    "imortalizáreis": "imortalizar",
    "imortalizásseis": "imortalizar",
    "imortalizássemos": "imortalizar",
    "imortalizávamo": "imortalizar",
    "imortalizávamos": "imortalizar",
    "imortalizávei": "imortalizar",
    "imortalizáveis": "imortalizável",
    "imortificada": "imortificado",
    "imortificadas": "imortificado",
    "imortificados": "imortificado",
    "imortificações": "imortificação",
    "imos": "imo",
    "imota": "imoto",
    "imotas": "imoto",
    "imotos": "imoto",
    "impacienta": "impacientar",
    "impacientada": "impacientar",
    "impacientadas": "impacientar",
    "impacientado": "impacientar",
    "impacientadora": "impacientador",
    "impacientadoras": "impacientador",
    "impacientadores": "impacientador",
    "impacientados": "impacientar",
    "impacientai": "impacientar",
    "impacientais": "impacientar",
    "impacientam": "impacientar",
    "impacientamo": "impacientar",
    "impacientamos": "impacientar",
    "impacientando": "impacientar",
    "impacientara": "impacientar",
    "impacientaram": "impacientar",
    "impacientaras": "impacientar",
    "impacientarde": "impacientar",
    "impacientardes": "impacientar",
    "impacientare": "impacientar",
    "impacientarei": "impacientar",
    "impacientareis": "impacientar",
    "impacientarem": "impacientar",
    "impacientaremos": "impacientar",
    "impacientares": "impacientar",
    "impacientaria": "impacientar",
    "impacientariam": "impacientar",
    "impacientarias": "impacientar",
    "impacientarmo": "impacientar",
    "impacientarmos": "impacientar",
    "impacientará": "impacientar",
    "impacientarás": "impacientar",
    "impacientarão": "impacientar",
    "impacientaríamos": "impacientar",
    "impacientaríeis": "impacientar",
    "impacientas": "impacientar",
    "impacientasse": "impacientar",
    "impacientassem": "impacientar",
    "impacientasses": "impacientar",
    "impacientaste": "impacientar",
    "impacientastes": "impacientar",
    "impacientava": "impacientar",
    "impacientavam": "impacientar",
    "impacientavas": "impacientar",
    "impaciente": "impacientar",
    "impacientei": "impacientar",
    "impacienteis": "impacientar",
    "impacientem": "impacientar",
    "impacientemo": "impacientar",
    "impacientemos": "impacientar",
    "impacientes": "impaciente",
    "impaciento": "impacientar",
    "impacientou": "impacientar",
    "impacientá": "impacientar",
    "impacientámo": "impacientar",
    "impacientámos": "impacientar",
    "impacientáramo": "impacientar",
    "impacientáramos": "impacientar",
    "impacientárei": "impacientar",
    "impacientáreis": "impacientar",
    "impacientásseis": "impacientar",
    "impacientássemos": "impacientar",
    "impacientávamo": "impacientar",
    "impacientávamos": "impacientar",
    "impacientávei": "impacientar",
    "impacientáveis": "impacientar",
    "impaciências": "impaciência",
    "impacta": "impacto",
    "impactada": "impactar",
    "impactadas": "impactar",
    "impactado": "impactar",
    "impactados": "impactar",
    "impactai": "impactar",
    "impactais": "impactar",
    "impactam": "impactar",
    "impactamo": "impactar",
    "impactamos": "impactar",
    "impactando": "impactar",
    "impactara": "impactar",
    "impactaram": "impactar",
    "impactaras": "impactar",
    "impactarde": "impactar",
    "impactardes": "impactar",
    "impactare": "impactar",
    "impactarei": "impactar",
    "impactareis": "impactar",
    "impactarem": "impactar",
    "impactaremos": "impactar",
    "impactares": "impactar",
    "impactaria": "impactar",
    "impactariam": "impactar",
    "impactarias": "impactar",
    "impactarmo": "impactar",
    "impactarmos": "impactar",
    "impactará": "impactar",
    "impactarás": "impactar",
    "impactarão": "impactar",
    "impactaríamos": "impactar",
    "impactaríeis": "impactar",
    "impactas": "impacto",
    "impactasse": "impactar",
    "impactassem": "impactar",
    "impactasses": "impactar",
    "impactaste": "impactar",
    "impactastes": "impactar",
    "impactava": "impactar",
    "impactavam": "impactar",
    "impactavas": "impactar",
    "impacte": "impactar",
    "impactei": "impactar",
    "impacteis": "impactar",
    "impactem": "impactar",
    "impactemo": "impactar",
    "impactemos": "impactar",
    "impactes": "impacte",
    "impacto": "impactar",
    "impactos": "impacto",
    "impactou": "impactar",
    "impactá": "impactar",
    "impactámo": "impactar",
    "impactámos": "impactar",
    "impactáramo": "impactar",
    "impactáramos": "impactar",
    "impactárei": "impactar",
    "impactáreis": "impactar",
    "impactásseis": "impactar",
    "impactássemos": "impactar",
    "impactávamo": "impactar",
    "impactávamos": "impactar",
    "impactávei": "impactar",
    "impactáveis": "impactar",
    "impacções": "impacção",
    "impagáveis": "impagável",
    "impalas": "impala",
    "impalpabilidades": "impalpabilidade",
    "impalpáveis": "impalpável",
    "impaluda": "impaludar",
    "impaludada": "impaludar",
    "impaludadas": "impaludar",
    "impaludado": "impaludar",
    "impaludados": "impaludar",
    "impaludai": "impaludar",
    "impaludais": "impaludar",
    "impaludam": "impaludar",
    "impaludamo": "impaludar",
    "impaludamos": "impaludar",
    "impaludando": "impaludar",
    "impaludara": "impaludar",
    "impaludaram": "impaludar",
    "impaludaras": "impaludar",
    "impaludarde": "impaludar",
    "impaludardes": "impaludar",
    "impaludare": "impaludar",
    "impaludarei": "impaludar",
    "impaludareis": "impaludar",
    "impaludarem": "impaludar",
    "impaludaremos": "impaludar",
    "impaludares": "impaludar",
    "impaludaria": "impaludar",
    "impaludariam": "impaludar",
    "impaludarias": "impaludar",
    "impaludarmo": "impaludar",
    "impaludarmos": "impaludar",
    "impaludará": "impaludar",
    "impaludarás": "impaludar",
    "impaludarão": "impaludar",
    "impaludaríamos": "impaludar",
    "impaludaríeis": "impaludar",
    "impaludas": "impaludar",
    "impaludasse": "impaludar",
    "impaludassem": "impaludar",
    "impaludasses": "impaludar",
    "impaludaste": "impaludar",
    "impaludastes": "impaludar",
    "impaludava": "impaludar",
    "impaludavam": "impaludar",
    "impaludavas": "impaludar",
    "impaludações": "impaludação",
    "impalude": "impaludar",
    "impaludei": "impaludar",
    "impaludeis": "impaludar",
    "impaludem": "impaludar",
    "impaludemo": "impaludar",
    "impaludemos": "impaludar",
    "impaludes": "impaludar",
    "impaludismos": "impaludismo",
    "impaludo": "impaludar",
    "impaludou": "impaludar",
    "impaludá": "impaludar",
    "impaludámo": "impaludar",
    "impaludámos": "impaludar",
    "impaludáramo": "impaludar",
    "impaludáramos": "impaludar",
    "impaludárei": "impaludar",
    "impaludáreis": "impaludar",
    "impaludásseis": "impaludar",
    "impaludássemos": "impaludar",
    "impaludávamo": "impaludar",
    "impaludávamos": "impaludar",
    "impaludávei": "impaludar",
    "impaludáveis": "impaludar",
    "impantes": "impante",
    "imparciais": "imparcial",
    "imparcialidades": "imparcialidade",
    "imparcializa": "imparcializar",
    "imparcializada": "imparcializar",
    "imparcializadas": "imparcializar",
    "imparcializado": "imparcializar",
    "imparcializados": "imparcializar",
    "imparcializai": "imparcializar",
    "imparcializais": "imparcializar",
    "imparcializam": "imparcializar",
    "imparcializamo": "imparcializar",
    "imparcializamos": "imparcializar",
    "imparcializando": "imparcializar",
    "imparcializara": "imparcializar",
    "imparcializaram": "imparcializar",
    "imparcializaras": "imparcializar",
    "imparcializarde": "imparcializar",
    "imparcializardes": "imparcializar",
    "imparcializare": "imparcializar",
    "imparcializarei": "imparcializar",
    "imparcializareis": "imparcializar",
    "imparcializarem": "imparcializar",
    "imparcializaremos": "imparcializar",
    "imparcializares": "imparcializar",
    "imparcializaria": "imparcializar",
    "imparcializariam": "imparcializar",
    "imparcializarias": "imparcializar",
    "imparcializarmo": "imparcializar",
    "imparcializarmos": "imparcializar",
    "imparcializará": "imparcializar",
    "imparcializarás": "imparcializar",
    "imparcializarão": "imparcializar",
    "imparcializaríamos": "imparcializar",
    "imparcializaríeis": "imparcializar",
    "imparcializas": "imparcializar",
    "imparcializasse": "imparcializar",
    "imparcializassem": "imparcializar",
    "imparcializasses": "imparcializar",
    "imparcializaste": "imparcializar",
    "imparcializastes": "imparcializar",
    "imparcializava": "imparcializar",
    "imparcializavam": "imparcializar",
    "imparcializavas": "imparcializar",
    "imparcialize": "imparcializar",
    "imparcializei": "imparcializar",
    "imparcializeis": "imparcializar",
    "imparcializem": "imparcializar",
    "imparcializemo": "imparcializar",
    "imparcializemos": "imparcializar",
    "imparcializes": "imparcializar",
    "imparcializo": "imparcializar",
    "imparcializou": "imparcializar",
    "imparcializá": "imparcializar",
    "imparcializámo": "imparcializar",
    "imparcializámos": "imparcializar",
    "imparcializáramo": "imparcializar",
    "imparcializáramos": "imparcializar",
    "imparcializárei": "imparcializar",
    "imparcializáreis": "imparcializar",
    "imparcializásseis": "imparcializar",
    "imparcializássemos": "imparcializar",
    "imparcializávamo": "imparcializar",
    "imparcializávamos": "imparcializar",
    "imparcializávei": "imparcializar",
    "imparcializáveis": "imparcializar",
    "imparidades": "imparidade",
    "imparipinulada": "imparipinulado",
    "imparipinuladas": "imparipinulado",
    "imparipinulados": "imparipinulado",
    "imparissilábica": "imparissilábico",
    "imparissilábicas": "imparissilábico",
    "imparissilábicos": "imparissilábico",
    "imparissílaba": "imparissílabo",
    "imparissílabas": "imparissílabo",
    "imparissílabos": "imparissílabo",
    "impartíveis": "impartível",
    "imparáveis": "imparável",
    "impasses": "impasse",
    "impassibilidades": "impassibilidade",
    "impassibiliza": "impassibilizar",
    "impassibilizada": "impassibilizar",
    "impassibilizadas": "impassibilizar",
    "impassibilizado": "impassibilizar",
    "impassibilizados": "impassibilizar",
    "impassibilizai": "impassibilizar",
    "impassibilizais": "impassibilizar",
    "impassibilizam": "impassibilizar",
    "impassibilizamo": "impassibilizar",
    "impassibilizamos": "impassibilizar",
    "impassibilizando": "impassibilizar",
    "impassibilizara": "impassibilizar",
    "impassibilizaram": "impassibilizar",
    "impassibilizaras": "impassibilizar",
    "impassibilizarde": "impassibilizar",
    "impassibilizardes": "impassibilizar",
    "impassibilizare": "impassibilizar",
    "impassibilizarei": "impassibilizar",
    "impassibilizareis": "impassibilizar",
    "impassibilizarem": "impassibilizar",
    "impassibilizaremos": "impassibilizar",
    "impassibilizares": "impassibilizar",
    "impassibilizaria": "impassibilizar",
    "impassibilizariam": "impassibilizar",
    "impassibilizarias": "impassibilizar",
    "impassibilizarmo": "impassibilizar",
    "impassibilizarmos": "impassibilizar",
    "impassibilizará": "impassibilizar",
    "impassibilizarás": "impassibilizar",
    "impassibilizarão": "impassibilizar",
    "impassibilizaríamos": "impassibilizar",
    "impassibilizaríeis": "impassibilizar",
    "impassibilizas": "impassibilizar",
    "impassibilizasse": "impassibilizar",
    "impassibilizassem": "impassibilizar",
    "impassibilizasses": "impassibilizar",
    "impassibilizaste": "impassibilizar",
    "impassibilizastes": "impassibilizar",
    "impassibilizava": "impassibilizar",
    "impassibilizavam": "impassibilizar",
    "impassibilizavas": "impassibilizar",
    "impassibilize": "impassibilizar",
    "impassibilizei": "impassibilizar",
    "impassibilizeis": "impassibilizar",
    "impassibilizem": "impassibilizar",
    "impassibilizemo": "impassibilizar",
    "impassibilizemos": "impassibilizar",
    "impassibilizes": "impassibilizar",
    "impassibilizo": "impassibilizar",
    "impassibilizou": "impassibilizar",
    "impassibilizá": "impassibilizar",
    "impassibilizámo": "impassibilizar",
    "impassibilizámos": "impassibilizar",
    "impassibilizáramo": "impassibilizar",
    "impassibilizáramos": "impassibilizar",
    "impassibilizárei": "impassibilizar",
    "impassibilizáreis": "impassibilizar",
    "impassibilizásseis": "impassibilizar",
    "impassibilizássemos": "impassibilizar",
    "impassibilizávamo": "impassibilizar",
    "impassibilizávamos": "impassibilizar",
    "impassibilizávei": "impassibilizar",
    "impassibilizáveis": "impassibilizar",
    "impassíveis": "impassível",
    "impatriotas": "impatriota",
    "impatriotismos": "impatriotismo",
    "impatriótica": "impatriótico",
    "impatrióticas": "impatriótico",
    "impatrióticos": "impatriótico",
    "impavidezes": "impavidez",
    "impações": "impação",
    "impecabilidades": "impecabilidade",
    "impeciolada": "impeciolado",
    "impecioladas": "impeciolado",
    "impeciolados": "impeciolado",
    "impecuniosa": "impecunioso",
    "impecuniosas": "impecunioso",
    "impecuniosos": "impecunioso",
    "impecáveis": "impecável",
    "impede": "impedir",
    "impedem": "impedir",
    "impedes": "impedir",
    "impedi": "impedir",
    "impedia": "impedir",
    "impediam": "impedir",
    "impedias": "impedir",
    "impedida": "impedir",
    "impedidas": "impedir",
    "impedido": "impedir",
    "impedidora": "impedidor",
    "impedidoras": "impedidor",
    "impedidores": "impedidor",
    "impedidos": "impedir",
    "impedientes": "impediente",
    "impedimentos": "impedimento",
    "impedimo": "impedir",
    "impedimos": "impedir",
    "impedindo": "impedir",
    "impedira": "impedir",
    "impediram": "impedir",
    "impediras": "impedir",
    "impedirde": "impedir",
    "impedirdes": "impedir",
    "impedire": "impedir",
    "impedirei": "impedir",
    "impedireis": "impedir",
    "impedirem": "impedir",
    "impediremos": "impedir",
    "impedires": "impedir",
    "impediria": "impedir",
    "impediriam": "impedir",
    "impedirias": "impedir",
    "impedirmo": "impedir",
    "impedirmos": "impedir",
    "impedirá": "impedir",
    "impedirás": "impedir",
    "impedirão": "impedir",
    "impediríamos": "impedir",
    "impediríeis": "impedir",
    "impedis": "impedir",
    "impedisse": "impedir",
    "impedissem": "impedir",
    "impedisses": "impedir",
    "impediste": "impedir",
    "impedistes": "impedir",
    "impeditiva": "impeditivo",
    "impeditivas": "impeditivo",
    "impeditivos": "impeditivo",
    "impediu": "impedir",
    "impedições": "impedição",
    "impediências": "impediência",
    "impedâncias": "impedância",
    "impedíamo": "impedir",
    "impedíamos": "impedir",
    "impedíei": "impedir",
    "impedíeis": "impedir",
    "impedíramo": "impedir",
    "impedíramos": "impedir",
    "impedírei": "impedir",
    "impedíreis": "impedir",
    "impedísseis": "impedir",
    "impedíssemos": "impedir",
    "impedíveis": "impedível",
    "impele": "impelir",
    "impelem": "impelir",
    "impelentes": "impelente",
    "impeles": "impelir",
    "impeli": "impelir",
    "impelia": "impelir",
    "impeliam": "impelir",
    "impelias": "impelir",
    "impelida": "impelir",
    "impelidas": "impelir",
    "impelido": "impelir",
    "impelidos": "impelir",
    "impelimo": "impelir",
    "impelimos": "impelir",
    "impelindo": "impelir",
    "impelira": "impelir",
    "impeliram": "impelir",
    "impeliras": "impelir",
    "impelirde": "impelir",
    "impelirdes": "impelir",
    "impelire": "impelir",
    "impelirei": "impelir",
    "impelireis": "impelir",
    "impelirem": "impelir",
    "impeliremos": "impelir",
    "impelires": "impelir",
    "impeliria": "impelir",
    "impeliriam": "impelir",
    "impelirias": "impelir",
    "impelirmo": "impelir",
    "impelirmos": "impelir",
    "impelirá": "impelir",
    "impelirás": "impelir",
    "impelirão": "impelir",
    "impeliríamos": "impelir",
    "impeliríeis": "impelir",
    "impelis": "impelir",
    "impelisse": "impelir",
    "impelissem": "impelir",
    "impelisses": "impelir",
    "impeliste": "impelir",
    "impelistes": "impelir",
    "impeliu": "impelir",
    "impelíamo": "impelir",
    "impelíamos": "impelir",
    "impelíei": "impelir",
    "impelíeis": "impelir",
    "impelíramo": "impelir",
    "impelíramos": "impelir",
    "impelírei": "impelir",
    "impelíreis": "impelir",
    "impelísseis": "impelir",
    "impelíssemos": "impelir",
    "impelíveis": "impelível",
    "impenda": "impender",
    "impendais": "impender",
    "impendam": "impender",
    "impendamo": "impender",
    "impendamos": "impender",
    "impendas": "impender",
    "impende": "impender",
    "impendei": "impender",
    "impendeis": "impender",
    "impendem": "impender",
    "impendemo": "impender",
    "impendemos": "impender",
    "impendendo": "impender",
    "impendentes": "impendente",
    "impendera": "impender",
    "impenderam": "impender",
    "impenderas": "impender",
    "impenderdes": "impender",
    "impenderei": "impender",
    "impendereis": "impender",
    "impenderem": "impender",
    "impenderemos": "impender",
    "impenderes": "impender",
    "impenderia": "impender",
    "impenderiam": "impender",
    "impenderias": "impender",
    "impendermo": "impender",
    "impendermos": "impender",
    "impenderá": "impender",
    "impenderás": "impender",
    "impenderão": "impender",
    "impenderíamos": "impender",
    "impenderíeis": "impender",
    "impendes": "impender",
    "impendesse": "impender",
    "impendessem": "impender",
    "impendesses": "impender",
    "impendeste": "impender",
    "impendestes": "impender",
    "impendeu": "impender",
    "impendi": "impender",
    "impendia": "impender",
    "impendiam": "impender",
    "impendias": "impender",
    "impendida": "impender",
    "impendidas": "impender",
    "impendido": "impender",
    "impendidos": "impender",
    "impendo": "impender",
    "impendêramo": "impender",
    "impendêramos": "impender",
    "impendêreis": "impender",
    "impendêsseis": "impender",
    "impendêssemos": "impender",
    "impendíamo": "impender",
    "impendíamos": "impender",
    "impendíeis": "impender",
    "impenes": "impene",
    "impenetrabilidades": "impenetrabilidade",
    "impenetráveis": "impenetrável",
    "impenhoráveis": "impenhorável",
    "impenitentes": "impenitente",
    "impenitências": "impenitência",
    "impensada": "impensado",
    "impensadas": "impensado",
    "impensados": "impensado",
    "impensáveis": "impensável",
    "impera": "imperar",
    "imperada": "imperar",
    "imperadas": "imperar",
    "imperado": "imperar",
    "imperadores": "imperador",
    "imperados": "imperar",
    "imperai": "imperar",
    "imperais": "imperar",
    "imperam": "imperar",
    "imperamo": "imperar",
    "imperamos": "imperar",
    "imperando": "imperar",
    "imperantes": "imperante",
    "imperara": "imperar",
    "imperaram": "imperar",
    "imperaras": "imperar",
    "imperarde": "imperar",
    "imperardes": "imperar",
    "imperare": "imperar",
    "imperarei": "imperar",
    "imperareis": "imperar",
    "imperarem": "imperar",
    "imperaremos": "imperar",
    "imperares": "imperar",
    "imperaria": "imperar",
    "imperariam": "imperar",
    "imperarias": "imperar",
    "imperarmo": "imperar",
    "imperarmos": "imperar",
    "imperará": "imperar",
    "imperarás": "imperar",
    "imperarão": "imperar",
    "imperaríamos": "imperar",
    "imperaríeis": "imperar",
    "imperas": "imperar",
    "imperasse": "imperar",
    "imperassem": "imperar",
    "imperasses": "imperar",
    "imperaste": "imperar",
    "imperastes": "imperar",
    "imperativa": "imperativo",
    "imperativas": "imperativo",
    "imperativos": "imperativo",
    "imperatriz": "imperador",
    "imperatrizes": "imperador",
    "imperatória": "imperatório",
    "imperatórias": "imperatório",
    "imperatórios": "imperatório",
    "imperava": "imperar",
    "imperavam": "imperar",
    "imperavas": "imperar",
    "impercebíveis": "impercebível",
    "imperceptibilidades": "imperceptibilidade",
    "imperceptíveis": "imperceptível",
    "imperdoada": "imperdoado",
    "imperdoadas": "imperdoado",
    "imperdoados": "imperdoado",
    "imperdoáveis": "imperdoável",
    "imperdíveis": "imperdível",
    "impere": "imperar",
    "imperecedoira": "imperecedoiro",
    "imperecedoiras": "imperecedoiro",
    "imperecedoiros": "imperecedoiro",
    "imperecedoura": "imperecedouro",
    "imperecedouras": "imperecedouro",
    "imperecedouros": "imperecedouro",
    "imperecíveis": "imperecível",
    "imperei": "imperar",
    "impereis": "imperar",
    "imperem": "imperar",
    "imperemo": "imperar",
    "imperemos": "imperar",
    "imperes": "imperar",
    "imperfectibilidades": "imperfectibilidade",
    "imperfectíveis": "imperfectível",
    "imperfeita": "imperfeito",
    "imperfeitas": "imperfeito",
    "imperfeitos": "imperfeito",
    "imperfeitíssima": "imperfeito",
    "imperfeitíssimas": "imperfeito",
    "imperfeitíssimo": "imperfeito",
    "imperfeitíssimos": "imperfeito",
    "imperfeiçoa": "imperfeiçoar",
    "imperfeiçoada": "imperfeiçoar",
    "imperfeiçoadas": "imperfeiçoar",
    "imperfeiçoado": "imperfeiçoar",
    "imperfeiçoados": "imperfeiçoar",
    "imperfeiçoai": "imperfeiçoar",
    "imperfeiçoais": "imperfeiçoar",
    "imperfeiçoam": "imperfeiçoar",
    "imperfeiçoamo": "imperfeiçoar",
    "imperfeiçoamos": "imperfeiçoar",
    "imperfeiçoando": "imperfeiçoar",
    "imperfeiçoara": "imperfeiçoar",
    "imperfeiçoaram": "imperfeiçoar",
    "imperfeiçoaras": "imperfeiçoar",
    "imperfeiçoarde": "imperfeiçoar",
    "imperfeiçoardes": "imperfeiçoar",
    "imperfeiçoare": "imperfeiçoar",
    "imperfeiçoarei": "imperfeiçoar",
    "imperfeiçoareis": "imperfeiçoar",
    "imperfeiçoarem": "imperfeiçoar",
    "imperfeiçoaremos": "imperfeiçoar",
    "imperfeiçoares": "imperfeiçoar",
    "imperfeiçoaria": "imperfeiçoar",
    "imperfeiçoariam": "imperfeiçoar",
    "imperfeiçoarias": "imperfeiçoar",
    "imperfeiçoarmo": "imperfeiçoar",
    "imperfeiçoarmos": "imperfeiçoar",
    "imperfeiçoará": "imperfeiçoar",
    "imperfeiçoarás": "imperfeiçoar",
    "imperfeiçoarão": "imperfeiçoar",
    "imperfeiçoaríamos": "imperfeiçoar",
    "imperfeiçoaríeis": "imperfeiçoar",
    "imperfeiçoas": "imperfeiçoar",
    "imperfeiçoasse": "imperfeiçoar",
    "imperfeiçoassem": "imperfeiçoar",
    "imperfeiçoasses": "imperfeiçoar",
    "imperfeiçoaste": "imperfeiçoar",
    "imperfeiçoastes": "imperfeiçoar",
    "imperfeiçoava": "imperfeiçoar",
    "imperfeiçoavam": "imperfeiçoar",
    "imperfeiçoavas": "imperfeiçoar",
    "imperfeiçoe": "imperfeiçoar",
    "imperfeiçoei": "imperfeiçoar",
    "imperfeiçoeis": "imperfeiçoar",
    "imperfeiçoem": "imperfeiçoar",
    "imperfeiçoemo": "imperfeiçoar",
    "imperfeiçoemos": "imperfeiçoar",
    "imperfeiçoes": "imperfeiçoar",
    "imperfeiçoo": "imperfeiçoar",
    "imperfeiçoou": "imperfeiçoar",
    "imperfeiçoá": "imperfeiçoar",
    "imperfeiçoámo": "imperfeiçoar",
    "imperfeiçoámos": "imperfeiçoar",
    "imperfeiçoáramo": "imperfeiçoar",
    "imperfeiçoáramos": "imperfeiçoar",
    "imperfeiçoárei": "imperfeiçoar",
    "imperfeiçoáreis": "imperfeiçoar",
    "imperfeiçoásseis": "imperfeiçoar",
    "imperfeiçoássemos": "imperfeiçoar",
    "imperfeiçoávamo": "imperfeiçoar",
    "imperfeiçoávamos": "imperfeiçoar",
    "imperfeiçoávei": "imperfeiçoar",
    "imperfeiçoáveis": "imperfeiçoar",
    "imperfeições": "imperfeição",
    "imperfurada": "imperfurado",
    "imperfuradas": "imperfurado",
    "imperfurados": "imperfurado",
    "imperiais": "imperial",
    "imperialismos": "imperialismo",
    "imperialistas": "imperialista",
    "imperiosa": "imperioso",
    "imperiosas": "imperioso",
    "imperiosidades": "imperiosidade",
    "imperiosos": "imperioso",
    "imperita": "imperito",
    "imperitas": "imperito",
    "imperitos": "imperito",
    "impermanentes": "impermanente",
    "impermanências": "impermanência",
    "impermeabilidades": "impermeabilidade",
    "impermeabiliza": "impermeabilizar",
    "impermeabilizada": "impermeabilizar",
    "impermeabilizadas": "impermeabilizar",
    "impermeabilizado": "impermeabilizar",
    "impermeabilizados": "impermeabilizar",
    "impermeabilizai": "impermeabilizar",
    "impermeabilizais": "impermeabilizar",
    "impermeabilizam": "impermeabilizar",
    "impermeabilizamo": "impermeabilizar",
    "impermeabilizamos": "impermeabilizar",
    "impermeabilizando": "impermeabilizar",
    "impermeabilizara": "impermeabilizar",
    "impermeabilizaram": "impermeabilizar",
    "impermeabilizaras": "impermeabilizar",
    "impermeabilizarde": "impermeabilizar",
    "impermeabilizardes": "impermeabilizar",
    "impermeabilizare": "impermeabilizar",
    "impermeabilizarei": "impermeabilizar",
    "impermeabilizareis": "impermeabilizar",
    "impermeabilizarem": "impermeabilizar",
    "impermeabilizaremos": "impermeabilizar",
    "impermeabilizares": "impermeabilizar",
    "impermeabilizaria": "impermeabilizar",
    "impermeabilizariam": "impermeabilizar",
    "impermeabilizarias": "impermeabilizar",
    "impermeabilizarmo": "impermeabilizar",
    "impermeabilizarmos": "impermeabilizar",
    "impermeabilizará": "impermeabilizar",
    "impermeabilizarás": "impermeabilizar",
    "impermeabilizarão": "impermeabilizar",
    "impermeabilizaríamos": "impermeabilizar",
    "impermeabilizaríeis": "impermeabilizar",
    "impermeabilizas": "impermeabilizar",
    "impermeabilizasse": "impermeabilizar",
    "impermeabilizassem": "impermeabilizar",
    "impermeabilizasses": "impermeabilizar",
    "impermeabilizaste": "impermeabilizar",
    "impermeabilizastes": "impermeabilizar",
    "impermeabilizava": "impermeabilizar",
    "impermeabilizavam": "impermeabilizar",
    "impermeabilizavas": "impermeabilizar",
    "impermeabilizações": "impermeabilização",
    "impermeabilize": "impermeabilizar",
    "impermeabilizei": "impermeabilizar",
    "impermeabilizeis": "impermeabilizar",
    "impermeabilizem": "impermeabilizar",
    "impermeabilizemo": "impermeabilizar",
    "impermeabilizemos": "impermeabilizar",
    "impermeabilizes": "impermeabilizar",
    "impermeabilizo": "impermeabilizar",
    "impermeabilizou": "impermeabilizar",
    "impermeabilizá": "impermeabilizar",
    "impermeabilizámo": "impermeabilizar",
    "impermeabilizámos": "impermeabilizar",
    "impermeabilizáramo": "impermeabilizar",
    "impermeabilizáramos": "impermeabilizar",
    "impermeabilizárei": "impermeabilizar",
    "impermeabilizáreis": "impermeabilizar",
    "impermeabilizásseis": "impermeabilizar",
    "impermeabilizássemos": "impermeabilizar",
    "impermeabilizávamo": "impermeabilizar",
    "impermeabilizávamos": "impermeabilizar",
    "impermeabilizávei": "impermeabilizar",
    "impermeabilizáveis": "impermeabilizável",
    "impermeáveis": "impermeável",
    "impermista": "impermisto",
    "impermistas": "impermisto",
    "impermistos": "impermisto",
    "impermutabilidades": "impermutabilidade",
    "impermutáveis": "impermutável",
    "impero": "imperar",
    "imperou": "imperar",
    "imperscrutáveis": "imperscrutável",
    "impersistentes": "impersistente",
    "impersonalidades": "impersonalidade",
    "impertinencia": "impertinenciar",
    "impertinenciada": "impertinenciar",
    "impertinenciadas": "impertinenciar",
    "impertinenciado": "impertinenciar",
    "impertinenciados": "impertinenciar",
    "impertinenciai": "impertinenciar",
    "impertinenciais": "impertinenciar",
    "impertinenciam": "impertinenciar",
    "impertinenciamo": "impertinenciar",
    "impertinenciamos": "impertinenciar",
    "impertinenciando": "impertinenciar",
    "impertinenciara": "impertinenciar",
    "impertinenciaram": "impertinenciar",
    "impertinenciaras": "impertinenciar",
    "impertinenciarde": "impertinenciar",
    "impertinenciardes": "impertinenciar",
    "impertinenciare": "impertinenciar",
    "impertinenciarei": "impertinenciar",
    "impertinenciareis": "impertinenciar",
    "impertinenciarem": "impertinenciar",
    "impertinenciaremos": "impertinenciar",
    "impertinenciares": "impertinenciar",
    "impertinenciaria": "impertinenciar",
    "impertinenciariam": "impertinenciar",
    "impertinenciarias": "impertinenciar",
    "impertinenciarmo": "impertinenciar",
    "impertinenciarmos": "impertinenciar",
    "impertinenciará": "impertinenciar",
    "impertinenciarás": "impertinenciar",
    "impertinenciarão": "impertinenciar",
    "impertinenciaríamos": "impertinenciar",
    "impertinenciaríeis": "impertinenciar",
    "impertinencias": "impertinenciar",
    "impertinenciasse": "impertinenciar",
    "impertinenciassem": "impertinenciar",
    "impertinenciasses": "impertinenciar",
    "impertinenciaste": "impertinenciar",
    "impertinenciastes": "impertinenciar",
    "impertinenciava": "impertinenciar",
    "impertinenciavam": "impertinenciar",
    "impertinenciavas": "impertinenciar",
    "impertinencie": "impertinenciar",
    "impertinenciei": "impertinenciar",
    "impertinencieis": "impertinenciar",
    "impertinenciem": "impertinenciar",
    "impertinenciemo": "impertinenciar",
    "impertinenciemos": "impertinenciar",
    "impertinencies": "impertinenciar",
    "impertinencio": "impertinenciar",
    "impertinenciou": "impertinenciar",
    "impertinenciá": "impertinenciar",
    "impertinenciámo": "impertinenciar",
    "impertinenciámos": "impertinenciar",
    "impertinenciáramo": "impertinenciar",
    "impertinenciáramos": "impertinenciar",
    "impertinenciárei": "impertinenciar",
    "impertinenciáreis": "impertinenciar",
    "impertinenciásseis": "impertinenciar",
    "impertinenciássemos": "impertinenciar",
    "impertinenciávamo": "impertinenciar",
    "impertinenciávamos": "impertinenciar",
    "impertinenciávei": "impertinenciar",
    "impertinenciáveis": "impertinenciar",
    "impertinentes": "impertinente",
    "impertinências": "impertinência",
    "imperturbabilidades": "imperturbabilidade",
    "imperturbada": "imperturbado",
    "imperturbadas": "imperturbado",
    "imperturbados": "imperturbado",
    "imperturbáveis": "imperturbável",
    "impertérrita": "impertérrito",
    "impertérritas": "impertérrito",
    "impertérritos": "impertérrito",
    "imperá": "imperar",
    "imperámo": "imperar",
    "imperámos": "imperar",
    "imperáramo": "imperar",
    "imperáramos": "imperar",
    "imperárei": "imperar",
    "imperáreis": "imperar",
    "imperásseis": "imperar",
    "imperássemos": "imperar",
    "imperávamo": "imperar",
    "imperávamos": "imperar",
    "imperávei": "imperar",
    "imperáveis": "imperar",
    "imperícias": "imperícia",
    "impessoais": "impessoal",
    "impessoalidades": "impessoalidade",
    "impetica": "impeticar",
    "impeticada": "impeticar",
    "impeticadas": "impeticar",
    "impeticado": "impeticar",
    "impeticados": "impeticar",
    "impeticai": "impeticar",
    "impeticais": "impeticar",
    "impeticam": "impeticar",
    "impeticamo": "impeticar",
    "impeticamos": "impeticar",
    "impeticando": "impeticar",
    "impeticara": "impeticar",
    "impeticaram": "impeticar",
    "impeticaras": "impeticar",
    "impeticarde": "impeticar",
    "impeticardes": "impeticar",
    "impeticare": "impeticar",
    "impeticarei": "impeticar",
    "impeticareis": "impeticar",
    "impeticarem": "impeticar",
    "impeticaremos": "impeticar",
    "impeticares": "impeticar",
    "impeticaria": "impeticar",
    "impeticariam": "impeticar",
    "impeticarias": "impeticar",
    "impeticarmo": "impeticar",
    "impeticarmos": "impeticar",
    "impeticará": "impeticar",
    "impeticarás": "impeticar",
    "impeticarão": "impeticar",
    "impeticaríamos": "impeticar",
    "impeticaríeis": "impeticar",
    "impeticas": "impeticar",
    "impeticasse": "impeticar",
    "impeticassem": "impeticar",
    "impeticasses": "impeticar",
    "impeticaste": "impeticar",
    "impeticastes": "impeticar",
    "impeticava": "impeticar",
    "impeticavam": "impeticar",
    "impeticavas": "impeticar",
    "impetico": "impeticar",
    "impeticou": "impeticar",
    "impeticá": "impeticar",
    "impeticámo": "impeticar",
    "impeticámos": "impeticar",
    "impeticáramo": "impeticar",
    "impeticáramos": "impeticar",
    "impeticárei": "impeticar",
    "impeticáreis": "impeticar",
    "impeticásseis": "impeticar",
    "impeticássemos": "impeticar",
    "impeticávamo": "impeticar",
    "impeticávamos": "impeticar",
    "impeticávei": "impeticar",
    "impeticáveis": "impeticar",
    "impetigens": "impetigem",
    "impetiginosa": "impetiginoso",
    "impetiginosas": "impetiginoso",
    "impetiginosos": "impetiginoso",
    "impetigos": "impetigo",
    "impetilha": "impetilhar",
    "impetilhada": "impetilhar",
    "impetilhadas": "impetilhar",
    "impetilhado": "impetilhar",
    "impetilhados": "impetilhar",
    "impetilhai": "impetilhar",
    "impetilhais": "impetilhar",
    "impetilham": "impetilhar",
    "impetilhamo": "impetilhar",
    "impetilhamos": "impetilhar",
    "impetilhando": "impetilhar",
    "impetilhara": "impetilhar",
    "impetilharam": "impetilhar",
    "impetilharas": "impetilhar",
    "impetilhardes": "impetilhar",
    "impetilharei": "impetilhar",
    "impetilhareis": "impetilhar",
    "impetilharem": "impetilhar",
    "impetilharemos": "impetilhar",
    "impetilhares": "impetilhar",
    "impetilharia": "impetilhar",
    "impetilhariam": "impetilhar",
    "impetilharias": "impetilhar",
    "impetilharmo": "impetilhar",
    "impetilharmos": "impetilhar",
    "impetilhará": "impetilhar",
    "impetilharás": "impetilhar",
    "impetilharão": "impetilhar",
    "impetilharíamos": "impetilhar",
    "impetilharíeis": "impetilhar",
    "impetilhas": "impetilhar",
    "impetilhasse": "impetilhar",
    "impetilhassem": "impetilhar",
    "impetilhasses": "impetilhar",
    "impetilhaste": "impetilhar",
    "impetilhastes": "impetilhar",
    "impetilhava": "impetilhar",
    "impetilhavam": "impetilhar",
    "impetilhavas": "impetilhar",
    "impetilhe": "impetilhar",
    "impetilhei": "impetilhar",
    "impetilheis": "impetilhar",
    "impetilhem": "impetilhar",
    "impetilhemo": "impetilhar",
    "impetilhemos": "impetilhar",
    "impetilhes": "impetilhar",
    "impetilho": "impetilhar",
    "impetilhou": "impetilhar",
    "impetilhámo": "impetilhar",
    "impetilhámos": "impetilhar",
    "impetilháramo": "impetilhar",
    "impetilháramos": "impetilhar",
    "impetilháreis": "impetilhar",
    "impetilhásseis": "impetilhar",
    "impetilhássemos": "impetilhar",
    "impetilhávamo": "impetilhar",
    "impetilhávamos": "impetilhar",
    "impetilháveis": "impetilhar",
    "impetique": "impeticar",
    "impetiquei": "impeticar",
    "impetiqueis": "impeticar",
    "impetiquem": "impeticar",
    "impetiquemo": "impeticar",
    "impetiquemos": "impeticar",
    "impetiques": "impeticar",
    "impetra": "impetrar",
    "impetrabilidades": "impetrabilidade",
    "impetrada": "impetrar",
    "impetradas": "impetrar",
    "impetrado": "impetrar",
    "impetrados": "impetrar",
    "impetrai": "impetrar",
    "impetrais": "impetrar",
    "impetram": "impetrar",
    "impetramo": "impetrar",
    "impetramos": "impetrar",
    "impetrando": "impetrar",
    "impetrantes": "impetrante",
    "impetrara": "impetrar",
    "impetraram": "impetrar",
    "impetraras": "impetrar",
    "impetrarde": "impetrar",
    "impetrardes": "impetrar",
    "impetrare": "impetrar",
    "impetrarei": "impetrar",
    "impetrareis": "impetrar",
    "impetrarem": "impetrar",
    "impetraremos": "impetrar",
    "impetrares": "impetrar",
    "impetraria": "impetrar",
    "impetrariam": "impetrar",
    "impetrarias": "impetrar",
    "impetrarmo": "impetrar",
    "impetrarmos": "impetrar",
    "impetrará": "impetrar",
    "impetrarás": "impetrar",
    "impetrarão": "impetrar",
    "impetraríamos": "impetrar",
    "impetraríeis": "impetrar",
    "impetras": "impetrar",
    "impetrasse": "impetrar",
    "impetrassem": "impetrar",
    "impetrasses": "impetrar",
    "impetraste": "impetrar",
    "impetrastes": "impetrar",
    "impetrativa": "impetrativo",
    "impetrativas": "impetrativo",
    "impetrativos": "impetrativo",
    "impetratória": "impetratório",
    "impetratórias": "impetratório",
    "impetratórios": "impetratório",
    "impetrava": "impetrar",
    "impetravam": "impetrar",
    "impetravas": "impetrar",
    "impetrações": "impetração",
    "impetre": "impetrar",
    "impetrei": "impetrar",
    "impetreis": "impetrar",
    "impetrem": "impetrar",
    "impetremo": "impetrar",
    "impetremos": "impetrar",
    "impetres": "impetrar",
    "impetro": "impetrar",
    "impetrou": "impetrar",
    "impetrá": "impetrar",
    "impetrámo": "impetrar",
    "impetrámos": "impetrar",
    "impetráramo": "impetrar",
    "impetráramos": "impetrar",
    "impetrárei": "impetrar",
    "impetráreis": "impetrar",
    "impetrásseis": "impetrar",
    "impetrássemos": "impetrar",
    "impetrávamo": "impetrar",
    "impetrávamos": "impetrar",
    "impetrávei": "impetrar",
    "impetráveis": "impetrável",
    "impetuosa": "impetuoso",
    "impetuosas": "impetuoso",
    "impetuosidades": "impetuosidade",
    "impetuosos": "impetuoso",
    "impeça": "impedir",
    "impeçais": "impedir",
    "impeçam": "impedir",
    "impeçamo": "impedir",
    "impeçamos": "impedir",
    "impeças": "impedir",
    "impeço": "impedir",
    "impia": "impio",
    "impias": "impio",
    "impiedades": "impiedade",
    "impiedosa": "impiedoso",
    "impiedosas": "impiedoso",
    "impiedosos": "impiedoso",
    "impigens": "impigem",
    "impila": "impelir",
    "impilais": "impelir",
    "impilam": "impelir",
    "impilamo": "impelir",
    "impilamos": "impelir",
    "impilas": "impelir",
    "impilo": "impelir",
    "impinge": "impingir",
    "impingem": "impingir",
    "impingens": "impingem",
    "impinges": "impingir",
    "impingi": "impingir",
    "impingia": "impingir",
    "impingiam": "impingir",
    "impingias": "impingir",
    "impingida": "impingir",
    "impingidas": "impingir",
    "impingidelas": "impingidela",
    "impingido": "impingir",
    "impingidos": "impingir",
    "impingimo": "impingir",
    "impingimos": "impingir",
    "impingindo": "impingir",
    "impingira": "impingir",
    "impingiram": "impingir",
    "impingiras": "impingir",
    "impingirde": "impingir",
    "impingirdes": "impingir",
    "impingire": "impingir",
    "impingirei": "impingir",
    "impingireis": "impingir",
    "impingirem": "impingir",
    "impingiremos": "impingir",
    "impingires": "impingir",
    "impingiria": "impingir",
    "impingiriam": "impingir",
    "impingirias": "impingir",
    "impingirmo": "impingir",
    "impingirmos": "impingir",
    "impingirá": "impingir",
    "impingirás": "impingir",
    "impingirão": "impingir",
    "impingiríamos": "impingir",
    "impingiríeis": "impingir",
    "impingis": "impingir",
    "impingisse": "impingir",
    "impingissem": "impingir",
    "impingisses": "impingir",
    "impingiste": "impingir",
    "impingistes": "impingir",
    "impingiu": "impingir",
    "impingíamo": "impingir",
    "impingíamos": "impingir",
    "impingíei": "impingir",
    "impingíeis": "impingir",
    "impingíramo": "impingir",
    "impingíramos": "impingir",
    "impingírei": "impingir",
    "impingíreis": "impingir",
    "impingísseis": "impingir",
    "impingíssemos": "impingir",
    "impingíveis": "impingível",
    "impinja": "impingir",
    "impinjais": "impingir",
    "impinjam": "impingir",
    "impinjamo": "impingir",
    "impinjamos": "impingir",
    "impinjas": "impingir",
    "impinjo": "impingir",
    "impios": "impio",
    "implacabilidades": "implacabilidade",
    "implacidezes": "implacidez",
    "implacáveis": "implacável",
    "implanta": "implantar",
    "implantada": "implantar",
    "implantadas": "implantar",
    "implantado": "implantar",
    "implantados": "implantar",
    "implantadíssima": "implantado",
    "implantadíssimas": "implantado",
    "implantadíssimo": "implantado",
    "implantadíssimos": "implantado",
    "implantai": "implantar",
    "implantais": "implantar",
    "implantam": "implantar",
    "implantamo": "implantar",
    "implantamos": "implantar",
    "implantando": "implantar",
    "implantara": "implantar",
    "implantaram": "implantar",
    "implantaras": "implantar",
    "implantarde": "implantar",
    "implantardes": "implantar",
    "implantare": "implantar",
    "implantarei": "implantar",
    "implantareis": "implantar",
    "implantarem": "implantar",
    "implantaremos": "implantar",
    "implantares": "implantar",
    "implantaria": "implantar",
    "implantariam": "implantar",
    "implantarias": "implantar",
    "implantarmo": "implantar",
    "implantarmos": "implantar",
    "implantará": "implantar",
    "implantarás": "implantar",
    "implantarão": "implantar",
    "implantaríamos": "implantar",
    "implantaríeis": "implantar",
    "implantas": "implantar",
    "implantasse": "implantar",
    "implantassem": "implantar",
    "implantasses": "implantar",
    "implantaste": "implantar",
    "implantastes": "implantar",
    "implantava": "implantar",
    "implantavam": "implantar",
    "implantavas": "implantar",
    "implantações": "implantação",
    "implante": "implantar",
    "implantei": "implantar",
    "implanteis": "implantar",
    "implantem": "implantar",
    "implantemo": "implantar",
    "implantemos": "implantar",
    "implantes": "implante",
    "implanto": "implantar",
    "implantou": "implantar",
    "implantá": "implantar",
    "implantámo": "implantar",
    "implantámos": "implantar",
    "implantáramo": "implantar",
    "implantáramos": "implantar",
    "implantárei": "implantar",
    "implantáreis": "implantar",
    "implantásseis": "implantar",
    "implantássemos": "implantar",
    "implantávamo": "implantar",
    "implantávamos": "implantar",
    "implantávei": "implantar",
    "implantáveis": "implantável",
    "implementa": "implementar",
    "implementada": "implementar",
    "implementadas": "implementar",
    "implementado": "implementar",
    "implementados": "implementar",
    "implementai": "implementar",
    "implementais": "implementar",
    "implementam": "implementar",
    "implementamo": "implementar",
    "implementamos": "implementar",
    "implementando": "implementar",
    "implementara": "implementar",
    "implementaram": "implementar",
    "implementaras": "implementar",
    "implementarde": "implementar",
    "implementardes": "implementar",
    "implementare": "implementar",
    "implementarei": "implementar",
    "implementareis": "implementar",
    "implementarem": "implementar",
    "implementaremos": "implementar",
    "implementares": "implementar",
    "implementaria": "implementar",
    "implementariam": "implementar",
    "implementarias": "implementar",
    "implementarmo": "implementar",
    "implementarmos": "implementar",
    "implementará": "implementar",
    "implementarás": "implementar",
    "implementarão": "implementar",
    "implementaríamos": "implementar",
    "implementaríeis": "implementar",
    "implementas": "implementar",
    "implementasse": "implementar",
    "implementassem": "implementar",
    "implementasses": "implementar",
    "implementaste": "implementar",
    "implementastes": "implementar",
    "implementava": "implementar",
    "implementavam": "implementar",
    "implementavas": "implementar",
    "implementações": "implementação",
    "implemente": "implementar",
    "implementei": "implementar",
    "implementeis": "implementar",
    "implementem": "implementar",
    "implementemo": "implementar",
    "implementemos": "implementar",
    "implementes": "implementar",
    "implemento": "implementar",
    "implementos": "implemento",
    "implementou": "implementar",
    "implementá": "implementar",
    "implementámo": "implementar",
    "implementámos": "implementar",
    "implementáramo": "implementar",
    "implementáramos": "implementar",
    "implementárei": "implementar",
    "implementáreis": "implementar",
    "implementásseis": "implementar",
    "implementássemos": "implementar",
    "implementávamo": "implementar",
    "implementávamos": "implementar",
    "implementávei": "implementar",
    "implementáveis": "implementar",
    "implexa": "implexo",
    "implexas": "implexo",
    "implexos": "implexo",
    "implica": "implicar",
    "implicada": "implicar",
    "implicadas": "implicar",
    "implicado": "implicar",
    "implicadora": "implicador",
    "implicadoras": "implicador",
    "implicadores": "implicador",
    "implicados": "implicar",
    "implicadíssima": "implicado",
    "implicadíssimas": "implicado",
    "implicadíssimo": "implicado",
    "implicadíssimos": "implicado",
    "implicai": "implicar",
    "implicais": "implicar",
    "implicam": "implicar",
    "implicamo": "implicar",
    "implicamos": "implicar",
    "implicando": "implicar",
    "implicantes": "implicante",
    "implicara": "implicar",
    "implicaram": "implicar",
    "implicaras": "implicar",
    "implicarde": "implicar",
    "implicardes": "implicar",
    "implicare": "implicar",
    "implicarei": "implicar",
    "implicareis": "implicar",
    "implicarem": "implicar",
    "implicaremos": "implicar",
    "implicares": "implicar",
    "implicaria": "implicar",
    "implicariam": "implicar",
    "implicarias": "implicar",
    "implicarmo": "implicar",
    "implicarmos": "implicar",
    "implicará": "implicar",
    "implicarás": "implicar",
    "implicarão": "implicar",
    "implicaríamos": "implicar",
    "implicaríeis": "implicar",
    "implicas": "implicar",
    "implicasse": "implicar",
    "implicassem": "implicar",
    "implicasses": "implicar",
    "implicaste": "implicar",
    "implicastes": "implicar",
    "implicativa": "implicativo",
    "implicativas": "implicativo",
    "implicativos": "implicativo",
    "implicatória": "implicatório",
    "implicatórias": "implicatório",
    "implicatórios": "implicatório",
    "implicava": "implicar",
    "implicavam": "implicar",
    "implicavas": "implicar",
    "implicações": "implicação",
    "implico": "implicar",
    "implicou": "implicar",
    "implicá": "implicar",
    "implicámo": "implicar",
    "implicámos": "implicar",
    "implicáramo": "implicar",
    "implicáramos": "implicar",
    "implicárei": "implicar",
    "implicáreis": "implicar",
    "implicásseis": "implicar",
    "implicássemos": "implicar",
    "implicávamo": "implicar",
    "implicávamos": "implicar",
    "implicávei": "implicar",
    "implicáveis": "implicável",
    "implicâncias": "implicância",
    "implique": "implicar",
    "impliquei": "implicar",
    "impliqueis": "implicar",
    "impliquem": "implicar",
    "impliquemo": "implicar",
    "impliquemos": "implicar",
    "impliques": "implicar",
    "implode": "implodir",
    "implodem": "implodir",
    "implodes": "implodir",
    "implodi": "implodir",
    "implodia": "implodir",
    "implodiam": "implodir",
    "implodias": "implodir",
    "implodida": "implodir",
    "implodidas": "implodir",
    "implodido": "implodir",
    "implodidos": "implodir",
    "implodimo": "implodir",
    "implodimos": "implodir",
    "implodindo": "implodir",
    "implodira": "implodir",
    "implodiram": "implodir",
    "implodiras": "implodir",
    "implodirde": "implodir",
    "implodirdes": "implodir",
    "implodire": "implodir",
    "implodirei": "implodir",
    "implodireis": "implodir",
    "implodirem": "implodir",
    "implodiremos": "implodir",
    "implodires": "implodir",
    "implodiria": "implodir",
    "implodiriam": "implodir",
    "implodirias": "implodir",
    "implodirmo": "implodir",
    "implodirmos": "implodir",
    "implodirá": "implodir",
    "implodirás": "implodir",
    "implodirão": "implodir",
    "implodiríamos": "implodir",
    "implodiríeis": "implodir",
    "implodis": "implodir",
    "implodisse": "implodir",
    "implodissem": "implodir",
    "implodisses": "implodir",
    "implodiste": "implodir",
    "implodistes": "implodir",
    "implodiu": "implodir",
    "implodíamo": "implodir",
    "implodíamos": "implodir",
    "implodíei": "implodir",
    "implodíeis": "implodir",
    "implodíramo": "implodir",
    "implodíramos": "implodir",
    "implodírei": "implodir",
    "implodíreis": "implodir",
    "implodísseis": "implodir",
    "implodíssemos": "implodir",
    "implora": "implorar",
    "implorada": "implorar",
    "imploradas": "implorar",
    "implorado": "implorar",
    "implorados": "implorar",
    "implorai": "implorar",
    "implorais": "implorar",
    "imploram": "implorar",
    "imploramo": "implorar",
    "imploramos": "implorar",
    "implorando": "implorar",
    "implorantes": "implorante",
    "implorara": "implorar",
    "imploraram": "implorar",
    "imploraras": "implorar",
    "implorarde": "implorar",
    "implorardes": "implorar",
    "implorare": "implorar",
    "implorarei": "implorar",
    "implorareis": "implorar",
    "implorarem": "implorar",
    "imploraremos": "implorar",
    "implorares": "implorar",
    "imploraria": "implorar",
    "implorariam": "implorar",
    "implorarias": "implorar",
    "implorarmo": "implorar",
    "implorarmos": "implorar",
    "implorará": "implorar",
    "implorarás": "implorar",
    "implorarão": "implorar",
    "imploraríamos": "implorar",
    "imploraríeis": "implorar",
    "imploras": "implorar",
    "implorasse": "implorar",
    "implorassem": "implorar",
    "implorasses": "implorar",
    "imploraste": "implorar",
    "implorastes": "implorar",
    "implorativa": "implorativo",
    "implorativas": "implorativo",
    "implorativos": "implorativo",
    "implorava": "implorar",
    "imploravam": "implorar",
    "imploravas": "implorar",
    "implorações": "imploração",
    "implore": "implorar",
    "implorei": "implorar",
    "imploreis": "implorar",
    "implorem": "implorar",
    "imploremo": "implorar",
    "imploremos": "implorar",
    "implores": "implorar",
    "imploro": "implorar",
    "implorou": "implorar",
    "implorá": "implorar",
    "implorámo": "implorar",
    "implorámos": "implorar",
    "imploráramo": "implorar",
    "imploráramos": "implorar",
    "implorárei": "implorar",
    "imploráreis": "implorar",
    "implorásseis": "implorar",
    "implorássemos": "implorar",
    "implorávamo": "implorar",
    "implorávamos": "implorar",
    "implorávei": "implorar",
    "imploráveis": "implorável",
    "implosãos": "implosão",
    "impluda": "implodir",
    "impludais": "implodir",
    "impludam": "implodir",
    "impludamo": "implodir",
    "impludamos": "implodir",
    "impludas": "implodir",
    "impludo": "implodir",
    "implumes": "implume",
    "implícita": "implícito",
    "implícitas": "implícito",
    "implícitos": "implícito",
    "implúvias": "implúvia",
    "implúvios": "implúvio",
    "impolarizáveis": "impolarizável",
    "impolida": "impolido",
    "impolidas": "impolido",
    "impolidezes": "impolidez",
    "impolidos": "impolido",
    "impoluta": "impoluto",
    "impolutas": "impoluto",
    "impolutos": "impoluto",
    "impoluíveis": "impoluível",
    "impolítica": "impolítico",
    "impolíticas": "impolítico",
    "impolíticos": "impolítico",
    "impomo": "impor",
    "impomos": "impor",
    "imponde": "impor",
    "imponderabilidades": "imponderabilidade",
    "imponderada": "imponderado",
    "imponderadas": "imponderado",
    "imponderados": "imponderado",
    "imponderações": "imponderação",
    "imponderáveis": "imponderável",
    "impondes": "impor",
    "impondo": "impor",
    "imponentes": "imponente",
    "imponha": "impor",
    "imponhais": "impor",
    "imponham": "impor",
    "imponhamo": "impor",
    "imponhamos": "impor",
    "imponhas": "impor",
    "imponho": "impor",
    "imponta": "impontar",
    "impontada": "impontar",
    "impontadas": "impontar",
    "impontado": "impontar",
    "impontados": "impontar",
    "impontai": "impontar",
    "impontais": "impontar",
    "impontam": "impontar",
    "impontamo": "impontar",
    "impontamos": "impontar",
    "impontando": "impontar",
    "impontara": "impontar",
    "impontaram": "impontar",
    "impontaras": "impontar",
    "impontarde": "impontar",
    "impontardes": "impontar",
    "impontare": "impontar",
    "impontarei": "impontar",
    "impontareis": "impontar",
    "impontarem": "impontar",
    "impontaremos": "impontar",
    "impontares": "impontar",
    "impontaria": "impontar",
    "impontariam": "impontar",
    "impontarias": "impontar",
    "impontarmo": "impontar",
    "impontarmos": "impontar",
    "impontará": "impontar",
    "impontarás": "impontar",
    "impontarão": "impontar",
    "impontaríamos": "impontar",
    "impontaríeis": "impontar",
    "impontas": "impontar",
    "impontasse": "impontar",
    "impontassem": "impontar",
    "impontasses": "impontar",
    "impontaste": "impontar",
    "impontastes": "impontar",
    "impontava": "impontar",
    "impontavam": "impontar",
    "impontavas": "impontar",
    "imponte": "impontar",
    "impontei": "impontar",
    "imponteis": "impontar",
    "impontem": "impontar",
    "impontemo": "impontar",
    "impontemos": "impontar",
    "impontes": "impontar",
    "imponto": "impontar",
    "impontou": "impontar",
    "impontuais": "impontual",
    "impontualidades": "impontualidade",
    "impontá": "impontar",
    "impontámo": "impontar",
    "impontámos": "impontar",
    "impontáramo": "impontar",
    "impontáramos": "impontar",
    "impontárei": "impontar",
    "impontáreis": "impontar",
    "impontásseis": "impontar",
    "impontássemos": "impontar",
    "impontávamo": "impontar",
    "impontávamos": "impontar",
    "impontávei": "impontar",
    "impontáveis": "impontar",
    "impontões": "impontão",
    "imponências": "imponência",
    "impopulares": "impopular",
    "impopularidades": "impopularidade",
    "impopulariza": "impopularizar",
    "impopularizada": "impopularizar",
    "impopularizadas": "impopularizar",
    "impopularizado": "impopularizar",
    "impopularizados": "impopularizar",
    "impopularizai": "impopularizar",
    "impopularizais": "impopularizar",
    "impopularizam": "impopularizar",
    "impopularizamo": "impopularizar",
    "impopularizamos": "impopularizar",
    "impopularizando": "impopularizar",
    "impopularizara": "impopularizar",
    "impopularizaram": "impopularizar",
    "impopularizaras": "impopularizar",
    "impopularizarde": "impopularizar",
    "impopularizardes": "impopularizar",
    "impopularizare": "impopularizar",
    "impopularizarei": "impopularizar",
    "impopularizareis": "impopularizar",
    "impopularizarem": "impopularizar",
    "impopularizaremos": "impopularizar",
    "impopularizares": "impopularizar",
    "impopularizaria": "impopularizar",
    "impopularizariam": "impopularizar",
    "impopularizarias": "impopularizar",
    "impopularizarmo": "impopularizar",
    "impopularizarmos": "impopularizar",
    "impopularizará": "impopularizar",
    "impopularizarás": "impopularizar",
    "impopularizarão": "impopularizar",
    "impopularizaríamos": "impopularizar",
    "impopularizaríeis": "impopularizar",
    "impopularizas": "impopularizar",
    "impopularizasse": "impopularizar",
    "impopularizassem": "impopularizar",
    "impopularizasses": "impopularizar",
    "impopularizaste": "impopularizar",
    "impopularizastes": "impopularizar",
    "impopularizava": "impopularizar",
    "impopularizavam": "impopularizar",
    "impopularizavas": "impopularizar",
    "impopularize": "impopularizar",
    "impopularizei": "impopularizar",
    "impopularizeis": "impopularizar",
    "impopularizem": "impopularizar",
    "impopularizemo": "impopularizar",
    "impopularizemos": "impopularizar",
    "impopularizes": "impopularizar",
    "impopularizo": "impopularizar",
    "impopularizou": "impopularizar",
    "impopularizá": "impopularizar",
    "impopularizámo": "impopularizar",
    "impopularizámos": "impopularizar",
    "impopularizáramo": "impopularizar",
    "impopularizáramos": "impopularizar",
    "impopularizárei": "impopularizar",
    "impopularizáreis": "impopularizar",
    "impopularizásseis": "impopularizar",
    "impopularizássemos": "impopularizar",
    "impopularizávamo": "impopularizar",
    "impopularizávamos": "impopularizar",
    "impopularizávei": "impopularizar",
    "impopularizáveis": "impopularizar",
    "imporde": "impor",
    "impordes": "impor",
    "impore": "impor",
    "imporei": "impor",
    "imporeis": "impor",
    "imporem": "impor",
    "imporemos": "impor",
    "impores": "impor",
    "imporia": "impor",
    "imporiam": "impor",
    "imporias": "impor",
    "impormo": "impor",
    "impormos": "impor",
    "importa": "importar",
    "importada": "importar",
    "importadas": "importar",
    "importado": "importar",
    "importadora": "importador",
    "importadoras": "importador",
    "importadores": "importador",
    "importados": "importar",
    "importai": "importar",
    "importais": "importar",
    "importam": "importar",
    "importamo": "importar",
    "importamos": "importar",
    "importando": "importar",
    "importantes": "importante",
    "importantíssima": "importante",
    "importantíssimas": "importante",
    "importantíssimo": "importante",
    "importantíssimos": "importante",
    "importara": "importar",
    "importaram": "importar",
    "importaras": "importar",
    "importarde": "importar",
    "importardes": "importar",
    "importare": "importar",
    "importarei": "importar",
    "importareis": "importar",
    "importarem": "importar",
    "importaremos": "importar",
    "importares": "importar",
    "importaria": "importar",
    "importariam": "importar",
    "importarias": "importar",
    "importarmo": "importar",
    "importarmos": "importar",
    "importará": "importar",
    "importarás": "importar",
    "importarão": "importar",
    "importaríamos": "importar",
    "importaríeis": "importar",
    "importas": "importar",
    "importasse": "importar",
    "importassem": "importar",
    "importasses": "importar",
    "importaste": "importar",
    "importastes": "importar",
    "importava": "importar",
    "importavam": "importar",
    "importavas": "importar",
    "importações": "importação",
    "importe": "importar",
    "importei": "importar",
    "importeis": "importar",
    "importem": "importar",
    "importemo": "importar",
    "importemos": "importar",
    "importes": "importe",
    "importo": "importar",
    "importou": "importar",
    "importuna": "importuno",
    "importunada": "importunar",
    "importunadas": "importunar",
    "importunado": "importunar",
    "importunadora": "importunador",
    "importunadoras": "importunador",
    "importunadores": "importunador",
    "importunados": "importunar",
    "importunai": "importunar",
    "importunais": "importunar",
    "importunam": "importunar",
    "importunamo": "importunar",
    "importunamos": "importunar",
    "importunando": "importunar",
    "importunara": "importunar",
    "importunaram": "importunar",
    "importunaras": "importunar",
    "importunarde": "importunar",
    "importunardes": "importunar",
    "importunare": "importunar",
    "importunarei": "importunar",
    "importunareis": "importunar",
    "importunarem": "importunar",
    "importunaremos": "importunar",
    "importunares": "importunar",
    "importunaria": "importunar",
    "importunariam": "importunar",
    "importunarias": "importunar",
    "importunarmo": "importunar",
    "importunarmos": "importunar",
    "importunará": "importunar",
    "importunarás": "importunar",
    "importunarão": "importunar",
    "importunaríamos": "importunar",
    "importunaríeis": "importunar",
    "importunas": "importuno",
    "importunasse": "importunar",
    "importunassem": "importunar",
    "importunasses": "importunar",
    "importunaste": "importunar",
    "importunastes": "importunar",
    "importunava": "importunar",
    "importunavam": "importunar",
    "importunavas": "importunar",
    "importunações": "importunação",
    "importune": "importunar",
    "importunei": "importunar",
    "importuneis": "importunar",
    "importunem": "importunar",
    "importunemo": "importunar",
    "importunemos": "importunar",
    "importunes": "importunar",
    "importunidades": "importunidade",
    "importuno": "importunar",
    "importunos": "importuno",
    "importunou": "importunar",
    "importuná": "importunar",
    "importunámo": "importunar",
    "importunámos": "importunar",
    "importunáramo": "importunar",
    "importunáramos": "importunar",
    "importunárei": "importunar",
    "importunáreis": "importunar",
    "importunásseis": "importunar",
    "importunássemos": "importunar",
    "importunávamo": "importunar",
    "importunávamos": "importunar",
    "importunávei": "importunar",
    "importunáveis": "importunável",
    "importunâncias": "importunância",
    "importá": "importar",
    "importámo": "importar",
    "importámos": "importar",
    "importáramo": "importar",
    "importáramos": "importar",
    "importárei": "importar",
    "importáreis": "importar",
    "importásseis": "importar",
    "importássemos": "importar",
    "importávamo": "importar",
    "importávamos": "importar",
    "importávei": "importar",
    "importáveis": "importável",
    "importâncias": "importância",
    "imporá": "impor",
    "imporás": "impor",
    "imporão": "impor",
    "imporéns": "imporém",
    "imporíamos": "impor",
    "imporíeis": "impor",
    "impos": "impo",
    "impositiva": "impositivo",
    "impositivas": "impositivo",
    "impositivos": "impositivo",
    "impositora": "impositor",
    "impositoras": "impositor",
    "impositores": "impositor",
    "imposições": "imposição",
    "impossibilidades": "impossibilidade",
    "impossibilita": "impossibilitar",
    "impossibilitada": "impossibilitar",
    "impossibilitadas": "impossibilitar",
    "impossibilitado": "impossibilitar",
    "impossibilitados": "impossibilitar",
    "impossibilitai": "impossibilitar",
    "impossibilitais": "impossibilitar",
    "impossibilitam": "impossibilitar",
    "impossibilitamo": "impossibilitar",
    "impossibilitamos": "impossibilitar",
    "impossibilitando": "impossibilitar",
    "impossibilitara": "impossibilitar",
    "impossibilitaram": "impossibilitar",
    "impossibilitaras": "impossibilitar",
    "impossibilitarde": "impossibilitar",
    "impossibilitardes": "impossibilitar",
    "impossibilitare": "impossibilitar",
    "impossibilitarei": "impossibilitar",
    "impossibilitareis": "impossibilitar",
    "impossibilitarem": "impossibilitar",
    "impossibilitaremos": "impossibilitar",
    "impossibilitares": "impossibilitar",
    "impossibilitaria": "impossibilitar",
    "impossibilitariam": "impossibilitar",
    "impossibilitarias": "impossibilitar",
    "impossibilitarmo": "impossibilitar",
    "impossibilitarmos": "impossibilitar",
    "impossibilitará": "impossibilitar",
    "impossibilitarás": "impossibilitar",
    "impossibilitarão": "impossibilitar",
    "impossibilitaríamos": "impossibilitar",
    "impossibilitaríeis": "impossibilitar",
    "impossibilitas": "impossibilitar",
    "impossibilitasse": "impossibilitar",
    "impossibilitassem": "impossibilitar",
    "impossibilitasses": "impossibilitar",
    "impossibilitaste": "impossibilitar",
    "impossibilitastes": "impossibilitar",
    "impossibilitava": "impossibilitar",
    "impossibilitavam": "impossibilitar",
    "impossibilitavas": "impossibilitar",
    "impossibilite": "impossibilitar",
    "impossibilitei": "impossibilitar",
    "impossibiliteis": "impossibilitar",
    "impossibilitem": "impossibilitar",
    "impossibilitemo": "impossibilitar",
    "impossibilitemos": "impossibilitar",
    "impossibilites": "impossibilitar",
    "impossibilito": "impossibilitar",
    "impossibilitou": "impossibilitar",
    "impossibilitá": "impossibilitar",
    "impossibilitámo": "impossibilitar",
    "impossibilitámos": "impossibilitar",
    "impossibilitáramo": "impossibilitar",
    "impossibilitáramos": "impossibilitar",
    "impossibilitárei": "impossibilitar",
    "impossibilitáreis": "impossibilitar",
    "impossibilitásseis": "impossibilitar",
    "impossibilitássemos": "impossibilitar",
    "impossibilitávamo": "impossibilitar",
    "impossibilitávamos": "impossibilitar",
    "impossibilitávei": "impossibilitar",
    "impossibilitáveis": "impossibilitar",
    "impossíveis": "impossível",
    "imposta": "imposto",
    "impostas": "imposto",
    "impostações": "impostação",
    "imposto": "impor",
    "impostora": "impostor",
    "impostoras": "impostor",
    "impostoraça": "impostoraço",
    "impostoraças": "impostoraço",
    "impostoraços": "impostoraço",
    "impostores": "impostor",
    "impostos": "imposto",
    "impostura": "imposturar",
    "imposturada": "imposturar",
    "imposturadas": "imposturar",
    "imposturado": "imposturar",
    "imposturados": "imposturar",
    "imposturai": "imposturar",
    "imposturais": "imposturar",
    "imposturam": "imposturar",
    "imposturamo": "imposturar",
    "imposturamos": "imposturar",
    "imposturando": "imposturar",
    "imposturara": "imposturar",
    "imposturaram": "imposturar",
    "imposturaras": "imposturar",
    "imposturardes": "imposturar",
    "imposturarei": "imposturar",
    "imposturareis": "imposturar",
    "imposturarem": "imposturar",
    "imposturaremos": "imposturar",
    "imposturares": "imposturar",
    "imposturaria": "imposturar",
    "imposturariam": "imposturar",
    "imposturarias": "imposturar",
    "imposturarmo": "imposturar",
    "imposturarmos": "imposturar",
    "imposturará": "imposturar",
    "imposturarás": "imposturar",
    "imposturarão": "imposturar",
    "imposturaríamos": "imposturar",
    "imposturaríeis": "imposturar",
    "imposturas": "imposturar",
    "imposturasse": "imposturar",
    "imposturassem": "imposturar",
    "imposturasses": "imposturar",
    "imposturaste": "imposturar",
    "imposturastes": "imposturar",
    "imposturava": "imposturar",
    "imposturavam": "imposturar",
    "imposturavas": "imposturar",
    "imposture": "imposturar",
    "imposturei": "imposturar",
    "impostureis": "imposturar",
    "imposturem": "imposturar",
    "imposturemo": "imposturar",
    "imposturemos": "imposturar",
    "impostures": "imposturar",
    "imposturias": "imposturia",
    "imposturices": "imposturice",
    "imposturo": "imposturar",
    "imposturou": "imposturar",
    "imposturámo": "imposturar",
    "imposturámos": "imposturar",
    "imposturáramo": "imposturar",
    "imposturáramos": "imposturar",
    "imposturáreis": "imposturar",
    "imposturásseis": "imposturar",
    "imposturássemos": "imposturar",
    "imposturávamo": "imposturar",
    "imposturávamos": "imposturar",
    "imposturáveis": "imposturar",
    "impotabilidades": "impotabilidade",
    "impotentes": "impotente",
    "impotáveis": "impotável",
    "impotências": "impotência",
    "impraticabilidades": "impraticabilidade",
    "impraticada": "impraticado",
    "impraticadas": "impraticado",
    "impraticados": "impraticado",
    "impraticáveis": "impraticável",
    "impreca": "imprecar",
    "imprecada": "imprecar",
    "imprecadas": "imprecar",
    "imprecado": "imprecar",
    "imprecados": "imprecar",
    "imprecai": "imprecar",
    "imprecais": "imprecar",
    "imprecam": "imprecar",
    "imprecamo": "imprecar",
    "imprecamos": "imprecar",
    "imprecando": "imprecar",
    "imprecara": "imprecar",
    "imprecaram": "imprecar",
    "imprecaras": "imprecar",
    "imprecarde": "imprecar",
    "imprecardes": "imprecar",
    "imprecare": "imprecar",
    "imprecarei": "imprecar",
    "imprecareis": "imprecar",
    "imprecarem": "imprecar",
    "imprecaremos": "imprecar",
    "imprecares": "imprecar",
    "imprecaria": "imprecar",
    "imprecariam": "imprecar",
    "imprecarias": "imprecar",
    "imprecarmo": "imprecar",
    "imprecarmos": "imprecar",
    "imprecará": "imprecar",
    "imprecarás": "imprecar",
    "imprecarão": "imprecar",
    "imprecaríamos": "imprecar",
    "imprecaríeis": "imprecar",
    "imprecas": "imprecar",
    "imprecasse": "imprecar",
    "imprecassem": "imprecar",
    "imprecasses": "imprecar",
    "imprecaste": "imprecar",
    "imprecastes": "imprecar",
    "imprecatada": "imprecatado",
    "imprecatadas": "imprecatado",
    "imprecatados": "imprecatado",
    "imprecativa": "imprecativo",
    "imprecativas": "imprecativo",
    "imprecativos": "imprecativo",
    "imprecatória": "imprecatório",
    "imprecatórias": "imprecatório",
    "imprecatórios": "imprecatório",
    "imprecauções": "imprecaução",
    "imprecava": "imprecar",
    "imprecavam": "imprecar",
    "imprecavas": "imprecar",
    "imprecações": "imprecação",
    "imprecisa": "impreciso",
    "imprecisas": "impreciso",
    "imprecisos": "impreciso",
    "imprecisões": "imprecisão",
    "impreco": "imprecar",
    "imprecou": "imprecar",
    "imprecá": "imprecar",
    "imprecámo": "imprecar",
    "imprecámos": "imprecar",
    "imprecáramo": "imprecar",
    "imprecáramos": "imprecar",
    "imprecárei": "imprecar",
    "imprecáreis": "imprecar",
    "imprecásseis": "imprecar",
    "imprecássemos": "imprecar",
    "imprecávamo": "imprecar",
    "imprecávamos": "imprecar",
    "imprecávei": "imprecar",
    "imprecáveis": "imprecar",
    "impreenchíveis": "impreenchível",
    "impregna": "impregnar",
    "impregnada": "impregnar",
    "impregnadas": "impregnar",
    "impregnado": "impregnar",
    "impregnados": "impregnar",
    "impregnai": "impregnar",
    "impregnais": "impregnar",
    "impregnam": "impregnar",
    "impregnamo": "impregnar",
    "impregnamos": "impregnar",
    "impregnando": "impregnar",
    "impregnara": "impregnar",
    "impregnaram": "impregnar",
    "impregnaras": "impregnar",
    "impregnarde": "impregnar",
    "impregnardes": "impregnar",
    "impregnare": "impregnar",
    "impregnarei": "impregnar",
    "impregnareis": "impregnar",
    "impregnarem": "impregnar",
    "impregnaremos": "impregnar",
    "impregnares": "impregnar",
    "impregnaria": "impregnar",
    "impregnariam": "impregnar",
    "impregnarias": "impregnar",
    "impregnarmo": "impregnar",
    "impregnarmos": "impregnar",
    "impregnará": "impregnar",
    "impregnarás": "impregnar",
    "impregnarão": "impregnar",
    "impregnaríamos": "impregnar",
    "impregnaríeis": "impregnar",
    "impregnas": "impregnar",
    "impregnasse": "impregnar",
    "impregnassem": "impregnar",
    "impregnasses": "impregnar",
    "impregnaste": "impregnar",
    "impregnastes": "impregnar",
    "impregnava": "impregnar",
    "impregnavam": "impregnar",
    "impregnavas": "impregnar",
    "impregnações": "impregnação",
    "impregne": "impregnar",
    "impregnei": "impregnar",
    "impregneis": "impregnar",
    "impregnem": "impregnar",
    "impregnemo": "impregnar",
    "impregnemos": "impregnar",
    "impregnes": "impregnar",
    "impregno": "impregnar",
    "impregnou": "impregnar",
    "impregná": "impregnar",
    "impregnámo": "impregnar",
    "impregnámos": "impregnar",
    "impregnáramo": "impregnar",
    "impregnáramos": "impregnar",
    "impregnárei": "impregnar",
    "impregnáreis": "impregnar",
    "impregnásseis": "impregnar",
    "impregnássemos": "impregnar",
    "impregnávamo": "impregnar",
    "impregnávamos": "impregnar",
    "impregnávei": "impregnar",
    "impregnáveis": "impregnável",
    "impremeabilizações": "impremeabilização",
    "impremeditada": "impremeditado",
    "impremeditadas": "impremeditado",
    "impremeditados": "impremeditado",
    "imprensa": "imprensar",
    "imprensada": "imprensar",
    "imprensadas": "imprensar",
    "imprensado": "imprensar",
    "imprensadora": "imprensador",
    "imprensadoras": "imprensador",
    "imprensadores": "imprensador",
    "imprensados": "imprensar",
    "imprensai": "imprensar",
    "imprensais": "imprensar",
    "imprensam": "imprensar",
    "imprensamo": "imprensar",
    "imprensamos": "imprensar",
    "imprensando": "imprensar",
    "imprensara": "imprensar",
    "imprensaram": "imprensar",
    "imprensaras": "imprensar",
    "imprensarde": "imprensar",
    "imprensardes": "imprensar",
    "imprensare": "imprensar",
    "imprensarei": "imprensar",
    "imprensareis": "imprensar",
    "imprensarem": "imprensar",
    "imprensaremos": "imprensar",
    "imprensares": "imprensar",
    "imprensaria": "imprensar",
    "imprensariam": "imprensar",
    "imprensarias": "imprensar",
    "imprensarmo": "imprensar",
    "imprensarmos": "imprensar",
    "imprensará": "imprensar",
    "imprensarás": "imprensar",
    "imprensarão": "imprensar",
    "imprensaríamos": "imprensar",
    "imprensaríeis": "imprensar",
    "imprensas": "imprensar",
    "imprensasse": "imprensar",
    "imprensassem": "imprensar",
    "imprensasses": "imprensar",
    "imprensaste": "imprensar",
    "imprensastes": "imprensar",
    "imprensava": "imprensar",
    "imprensavam": "imprensar",
    "imprensavas": "imprensar",
    "imprense": "imprensar",
    "imprensei": "imprensar",
    "imprenseis": "imprensar",
    "imprensem": "imprensar",
    "imprensemo": "imprensar",
    "imprensemos": "imprensar",
    "imprenses": "imprensar",
    "imprenso": "imprensar",
    "imprensou": "imprensar",
    "imprensá": "imprensar",
    "imprensámo": "imprensar",
    "imprensámos": "imprensar",
    "imprensáramo": "imprensar",
    "imprensáramos": "imprensar",
    "imprensárei": "imprensar",
    "imprensáreis": "imprensar",
    "imprensásseis": "imprensar",
    "imprensássemos": "imprensar",
    "imprensávamo": "imprensar",
    "imprensávamos": "imprensar",
    "imprensávei": "imprensar",
    "imprensáveis": "imprensar",
    "impreparada": "impreparado",
    "impreparadas": "impreparado",
    "impreparados": "impreparado",
    "impreparações": "impreparação",
    "impreque": "imprecar",
    "imprequei": "imprecar",
    "imprequeis": "imprecar",
    "imprequem": "imprecar",
    "imprequemo": "imprecar",
    "imprequemos": "imprecar",
    "impreques": "imprecar",
    "imprescindibilidades": "imprescindibilidade",
    "imprescindíveis": "imprescindível",
    "impresciências": "impresciência",
    "imprescritibilidades": "imprescritibilidade",
    "imprescritíveis": "imprescritível",
    "impressa": "impresso",
    "impressas": "impresso",
    "impressibilidades": "impressibilidade",
    "impressiona": "impressionar",
    "impressionabilidades": "impressionabilidade",
    "impressionada": "impressionar",
    "impressionadas": "impressionar",
    "impressionado": "impressionar",
    "impressionados": "impressionar",
    "impressionadíssima": "impressionado",
    "impressionadíssimas": "impressionado",
    "impressionadíssimo": "impressionado",
    "impressionadíssimos": "impressionado",
    "impressionai": "impressionar",
    "impressionais": "impressionar",
    "impressionam": "impressionar",
    "impressionamo": "impressionar",
    "impressionamos": "impressionar",
    "impressionando": "impressionar",
    "impressionantes": "impressionante",
    "impressionara": "impressionar",
    "impressionaram": "impressionar",
    "impressionaras": "impressionar",
    "impressionarde": "impressionar",
    "impressionardes": "impressionar",
    "impressionare": "impressionar",
    "impressionarei": "impressionar",
    "impressionareis": "impressionar",
    "impressionarem": "impressionar",
    "impressionaremos": "impressionar",
    "impressionares": "impressionar",
    "impressionaria": "impressionar",
    "impressionariam": "impressionar",
    "impressionarias": "impressionar",
    "impressionarmo": "impressionar",
    "impressionarmos": "impressionar",
    "impressionará": "impressionar",
    "impressionarás": "impressionar",
    "impressionarão": "impressionar",
    "impressionaríamos": "impressionar",
    "impressionaríeis": "impressionar",
    "impressionas": "impressionar",
    "impressionasse": "impressionar",
    "impressionassem": "impressionar",
    "impressionasses": "impressionar",
    "impressionaste": "impressionar",
    "impressionastes": "impressionar",
    "impressionava": "impressionar",
    "impressionavam": "impressionar",
    "impressionavas": "impressionar",
    "impressione": "impressionar",
    "impressionei": "impressionar",
    "impressioneis": "impressionar",
    "impressionem": "impressionar",
    "impressionemo": "impressionar",
    "impressionemos": "impressionar",
    "impressiones": "impressionar",
    "impressionismos": "impressionismo",
    "impressionistas": "impressionista",
    "impressiono": "impressionar",
    "impressionou": "impressionar",
    "impressioná": "impressionar",
    "impressionámo": "impressionar",
    "impressionámos": "impressionar",
    "impressionáramo": "impressionar",
    "impressionáramos": "impressionar",
    "impressionárei": "impressionar",
    "impressionáreis": "impressionar",
    "impressionásseis": "impressionar",
    "impressionássemos": "impressionar",
    "impressionávamo": "impressionar",
    "impressionávamos": "impressionar",
    "impressionávei": "impressionar",
    "impressionáveis": "impressionável",
    "impressiva": "impressivo",
    "impressivas": "impressivo",
    "impressivos": "impressivo",
    "impressora": "impressor",
    "impressoras": "impressora",
    "impressores": "impressor",
    "impressors": "impressor",
    "impressos": "impresso",
    "impressíveis": "impressível",
    "impressões": "impressão",
    "imprestabilidades": "imprestabilidade",
    "imprestáveis": "imprestável",
    "impreteríveis": "impreterível",
    "imprevidentes": "imprevidente",
    "imprevidências": "imprevidência",
    "imprevisibilidades": "imprevisibilidade",
    "imprevista": "imprevisto",
    "imprevistas": "imprevisto",
    "imprevistos": "imprevisto",
    "imprevisíveis": "imprevisível",
    "imprevisões": "imprevisão",
    "imprima": "imprimir",
    "imprimada": "imprimar",
    "imprimadas": "imprimar",
    "imprimado": "imprimar",
    "imprimados": "imprimar",
    "imprimaduras": "imprimadura",
    "imprimai": "imprimar",
    "imprimais": "imprimir",
    "imprimam": "imprimir",
    "imprimamo": "imprimir",
    "imprimamos": "imprimir",
    "imprimando": "imprimar",
    "imprimara": "imprimar",
    "imprimaram": "imprimar",
    "imprimaras": "imprimar",
    "imprimarde": "imprimar",
    "imprimardes": "imprimar",
    "imprimare": "imprimar",
    "imprimarei": "imprimar",
    "imprimareis": "imprimar",
    "imprimarem": "imprimar",
    "imprimaremos": "imprimar",
    "imprimares": "imprimar",
    "imprimaria": "imprimar",
    "imprimariam": "imprimar",
    "imprimarias": "imprimar",
    "imprimarmo": "imprimar",
    "imprimarmos": "imprimar",
    "imprimará": "imprimar",
    "imprimarás": "imprimar",
    "imprimarão": "imprimar",
    "imprimaríamos": "imprimar",
    "imprimaríeis": "imprimar",
    "imprimas": "imprimir",
    "imprimasse": "imprimar",
    "imprimassem": "imprimar",
    "imprimasses": "imprimar",
    "imprimaste": "imprimar",
    "imprimastes": "imprimar",
    "imprimava": "imprimar",
    "imprimavam": "imprimar",
    "imprimavas": "imprimar",
    "imprimações": "imprimação",
    "imprime": "imprimir",
    "imprimei": "imprimar",
    "imprimeis": "imprimar",
    "imprimem": "imprimir",
    "imprimemo": "imprimar",
    "imprimemos": "imprimar",
    "imprimes": "imprimir",
    "imprimi": "imprimir",
    "imprimia": "imprimir",
    "imprimiam": "imprimir",
    "imprimias": "imprimir",
    "imprimibilidades": "imprimibilidade",
    "imprimida": "imprimir",
    "imprimidas": "imprimir",
    "imprimido": "imprimir",
    "imprimidos": "imprimir",
    "imprimimo": "imprimir",
    "imprimimos": "imprimir",
    "imprimindo": "imprimir",
    "imprimira": "imprimir",
    "imprimiram": "imprimir",
    "imprimiras": "imprimir",
    "imprimirde": "imprimir",
    "imprimirdes": "imprimir",
    "imprimire": "imprimir",
    "imprimirei": "imprimir",
    "imprimireis": "imprimir",
    "imprimirem": "imprimir",
    "imprimiremos": "imprimir",
    "imprimires": "imprimir",
    "imprimiria": "imprimir",
    "imprimiriam": "imprimir",
    "imprimirias": "imprimir",
    "imprimirmo": "imprimir",
    "imprimirmos": "imprimir",
    "imprimirá": "imprimir",
    "imprimirás": "imprimir",
    "imprimirão": "imprimir",
    "imprimiríamos": "imprimir",
    "imprimiríeis": "imprimir",
    "imprimis": "imprimir",
    "imprimisse": "imprimir",
    "imprimissem": "imprimir",
    "imprimisses": "imprimir",
    "imprimiste": "imprimir",
    "imprimistes": "imprimir",
    "imprimiu": "imprimir",
    "imprimo": "imprimir",
    "imprimou": "imprimar",
    "imprimá": "imprimar",
    "imprimámo": "imprimar",
    "imprimámos": "imprimar",
    "imprimáramo": "imprimar",
    "imprimáramos": "imprimar",
    "imprimárei": "imprimar",
    "imprimáreis": "imprimar",
    "imprimásseis": "imprimar",
    "imprimássemos": "imprimar",
    "imprimátures": "imprimátur",
    "imprimávamo": "imprimar",
    "imprimávamos": "imprimar",
    "imprimávei": "imprimar",
    "imprimáveis": "imprimar",
    "imprimíamo": "imprimir",
    "imprimíamos": "imprimir",
    "imprimíei": "imprimir",
    "imprimíeis": "imprimir",
    "imprimíramo": "imprimir",
    "imprimíramos": "imprimir",
    "imprimírei": "imprimir",
    "imprimíreis": "imprimir",
    "imprimísseis": "imprimir",
    "imprimíssemos": "imprimir",
    "imprimíveis": "imprimível",
    "improba": "improbar",
    "improbabilidades": "improbabilidade",
    "improbada": "improbar",
    "improbadas": "improbar",
    "improbado": "improbar",
    "improbados": "improbar",
    "improbai": "improbar",
    "improbais": "improbar",
    "improbam": "improbar",
    "improbamo": "improbar",
    "improbamos": "improbar",
    "improbando": "improbar",
    "improbara": "improbar",
    "improbaram": "improbar",
    "improbaras": "improbar",
    "improbarde": "improbar",
    "improbardes": "improbar",
    "improbare": "improbar",
    "improbarei": "improbar",
    "improbareis": "improbar",
    "improbarem": "improbar",
    "improbaremos": "improbar",
    "improbares": "improbar",
    "improbaria": "improbar",
    "improbariam": "improbar",
    "improbarias": "improbar",
    "improbarmo": "improbar",
    "improbarmos": "improbar",
    "improbará": "improbar",
    "improbarás": "improbar",
    "improbarão": "improbar",
    "improbaríamos": "improbar",
    "improbaríeis": "improbar",
    "improbas": "improbar",
    "improbasse": "improbar",
    "improbassem": "improbar",
    "improbasses": "improbar",
    "improbaste": "improbar",
    "improbastes": "improbar",
    "improbava": "improbar",
    "improbavam": "improbar",
    "improbavas": "improbar",
    "improbações": "improbação",
    "improbe": "improbar",
    "improbei": "improbar",
    "improbeis": "improbar",
    "improbem": "improbar",
    "improbemo": "improbar",
    "improbemos": "improbar",
    "improbes": "improbar",
    "improbidades": "improbidade",
    "improbo": "improbar",
    "improbou": "improbar",
    "improbá": "improbar",
    "improbámo": "improbar",
    "improbámos": "improbar",
    "improbáramo": "improbar",
    "improbáramos": "improbar",
    "improbárei": "improbar",
    "improbáreis": "improbar",
    "improbásseis": "improbar",
    "improbássemos": "improbar",
    "improbávamo": "improbar",
    "improbávamos": "improbar",
    "improbávei": "improbar",
    "improbáveis": "improbável",
    "improceda": "improceder",
    "improcedais": "improceder",
    "improcedam": "improceder",
    "improcedamo": "improceder",
    "improcedamos": "improceder",
    "improcedas": "improceder",
    "improcede": "improceder",
    "improcedei": "improceder",
    "improcedeis": "improceder",
    "improcedem": "improceder",
    "improcedemo": "improceder",
    "improcedemos": "improceder",
    "improcedendo": "improceder",
    "improcedentes": "improcedente",
    "improcedera": "improceder",
    "improcederam": "improceder",
    "improcederas": "improceder",
    "improcederdes": "improceder",
    "improcederei": "improceder",
    "improcedereis": "improceder",
    "improcederem": "improceder",
    "improcederemos": "improceder",
    "improcederes": "improceder",
    "improcederia": "improceder",
    "improcederiam": "improceder",
    "improcederias": "improceder",
    "improcedermo": "improceder",
    "improcedermos": "improceder",
    "improcederá": "improceder",
    "improcederás": "improceder",
    "improcederão": "improceder",
    "improcederíamos": "improceder",
    "improcederíeis": "improceder",
    "improcedes": "improceder",
    "improcedesse": "improceder",
    "improcedessem": "improceder",
    "improcedesses": "improceder",
    "improcedeste": "improceder",
    "improcedestes": "improceder",
    "improcedeu": "improceder",
    "improcedi": "improceder",
    "improcedia": "improceder",
    "improcediam": "improceder",
    "improcedias": "improceder",
    "improcedida": "improceder",
    "improcedidas": "improceder",
    "improcedido": "improceder",
    "improcedidos": "improceder",
    "improcedo": "improceder",
    "improcedências": "improcedência",
    "improcedêramo": "improceder",
    "improcedêramos": "improceder",
    "improcedêreis": "improceder",
    "improcedêsseis": "improceder",
    "improcedêssemos": "improceder",
    "improcedíamo": "improceder",
    "improcedíamos": "improceder",
    "improcedíeis": "improceder",
    "improcrastináveis": "improcrastinável",
    "improducentes": "improducente",
    "improdutibilidades": "improdutibilidade",
    "improdutiva": "improdutivo",
    "improdutivas": "improdutivo",
    "improdutividades": "improdutividade",
    "improdutivos": "improdutivo",
    "improdutíveis": "improdutível",
    "improduções": "improdução",
    "improferíveis": "improferível",
    "improficientes": "improficiente",
    "improficiências": "improficiência",
    "improficuidades": "improficuidade",
    "improfundáveis": "improfundável",
    "improfícua": "improfícuo",
    "improfícuas": "improfícuo",
    "improfícuos": "improfícuo",
    "improgressiva": "improgressivo",
    "improgressivas": "improgressivo",
    "improgressivos": "improgressivo",
    "improlífica": "improlífico",
    "improlíficas": "improlífico",
    "improlíficos": "improlífico",
    "impronunciáveis": "impronunciável",
    "impropera": "improperar",
    "improperada": "improperar",
    "improperadas": "improperar",
    "improperado": "improperar",
    "improperados": "improperar",
    "improperai": "improperar",
    "improperais": "improperar",
    "improperam": "improperar",
    "improperamo": "improperar",
    "improperamos": "improperar",
    "improperando": "improperar",
    "improperara": "improperar",
    "improperaram": "improperar",
    "improperaras": "improperar",
    "improperarde": "improperar",
    "improperardes": "improperar",
    "improperare": "improperar",
    "improperarei": "improperar",
    "improperareis": "improperar",
    "improperarem": "improperar",
    "improperaremos": "improperar",
    "improperares": "improperar",
    "improperaria": "improperar",
    "improperariam": "improperar",
    "improperarias": "improperar",
    "improperarmo": "improperar",
    "improperarmos": "improperar",
    "improperará": "improperar",
    "improperarás": "improperar",
    "improperarão": "improperar",
    "improperaríamos": "improperar",
    "improperaríeis": "improperar",
    "improperas": "improperar",
    "improperasse": "improperar",
    "improperassem": "improperar",
    "improperasses": "improperar",
    "improperaste": "improperar",
    "improperastes": "improperar",
    "improperava": "improperar",
    "improperavam": "improperar",
    "improperavas": "improperar",
    "impropere": "improperar",
    "improperei": "improperar",
    "impropereis": "improperar",
    "improperem": "improperar",
    "improperemo": "improperar",
    "improperemos": "improperar",
    "improperes": "improperar",
    "impropero": "improperar",
    "improperou": "improperar",
    "improperá": "improperar",
    "improperámo": "improperar",
    "improperámos": "improperar",
    "improperáramo": "improperar",
    "improperáramos": "improperar",
    "improperárei": "improperar",
    "improperáreis": "improperar",
    "improperásseis": "improperar",
    "improperássemos": "improperar",
    "improperávamo": "improperar",
    "improperávamos": "improperar",
    "improperávei": "improperar",
    "improperáveis": "improperar",
    "improporcionada": "improporcionado",
    "improporcionadas": "improporcionado",
    "improporcionados": "improporcionado",
    "improporcionalidades": "improporcionalidade",
    "impropria": "impropriar",
    "impropriada": "impropriar",
    "impropriadas": "impropriar",
    "impropriado": "impropriar",
    "impropriados": "impropriar",
    "impropriai": "impropriar",
    "impropriais": "impropriar",
    "impropriam": "impropriar",
    "impropriamo": "impropriar",
    "impropriamos": "impropriar",
    "impropriando": "impropriar",
    "impropriara": "impropriar",
    "impropriaram": "impropriar",
    "impropriaras": "impropriar",
    "impropriarde": "impropriar",
    "impropriardes": "impropriar",
    "impropriare": "impropriar",
    "impropriarei": "impropriar",
    "impropriareis": "impropriar",
    "impropriarem": "impropriar",
    "impropriaremos": "impropriar",
    "impropriares": "impropriar",
    "impropriaria": "impropriar",
    "impropriariam": "impropriar",
    "impropriarias": "impropriar",
    "impropriarmo": "impropriar",
    "impropriarmos": "impropriar",
    "impropriará": "impropriar",
    "impropriarás": "impropriar",
    "impropriarão": "impropriar",
    "impropriaríamos": "impropriar",
    "impropriaríeis": "impropriar",
    "improprias": "impropriar",
    "impropriasse": "impropriar",
    "impropriassem": "impropriar",
    "impropriasses": "impropriar",
    "impropriaste": "impropriar",
    "impropriastes": "impropriar",
    "impropriava": "impropriar",
    "impropriavam": "impropriar",
    "impropriavas": "impropriar",
    "improprie": "impropriar",
    "impropriedades": "impropriedade",
    "impropriei": "impropriar",
    "improprieis": "impropriar",
    "impropriem": "impropriar",
    "impropriemo": "impropriar",
    "impropriemos": "impropriar",
    "impropries": "impropriar",
    "improprio": "impropriar",
    "impropriou": "impropriar",
    "impropriá": "impropriar",
    "impropriámo": "impropriar",
    "impropriámos": "impropriar",
    "impropriáramo": "impropriar",
    "impropriáramos": "impropriar",
    "impropriárei": "impropriar",
    "impropriáreis": "impropriar",
    "impropriásseis": "impropriar",
    "impropriássemos": "impropriar",
    "impropriávamo": "impropriar",
    "impropriávamos": "impropriar",
    "impropriávei": "impropriar",
    "impropriáveis": "impropriar",
    "impropérios": "impropério",
    "improrrogabilidades": "improrrogabilidade",
    "improrrogáveis": "improrrogável",
    "improteláveis": "improtelável",
    "improva": "improvar",
    "improvada": "improvar",
    "improvadas": "improvar",
    "improvado": "improvar",
    "improvadora": "improvador",
    "improvadoras": "improvador",
    "improvadores": "improvador",
    "improvados": "improvar",
    "improvai": "improvar",
    "improvais": "improvar",
    "improvam": "improvar",
    "improvamo": "improvar",
    "improvamos": "improvar",
    "improvando": "improvar",
    "improvara": "improvar",
    "improvaram": "improvar",
    "improvaras": "improvar",
    "improvarde": "improvar",
    "improvardes": "improvar",
    "improvare": "improvar",
    "improvarei": "improvar",
    "improvareis": "improvar",
    "improvarem": "improvar",
    "improvaremos": "improvar",
    "improvares": "improvar",
    "improvaria": "improvar",
    "improvariam": "improvar",
    "improvarias": "improvar",
    "improvarmo": "improvar",
    "improvarmos": "improvar",
    "improvará": "improvar",
    "improvarás": "improvar",
    "improvarão": "improvar",
    "improvaríamos": "improvar",
    "improvaríeis": "improvar",
    "improvas": "improvar",
    "improvasse": "improvar",
    "improvassem": "improvar",
    "improvasses": "improvar",
    "improvaste": "improvar",
    "improvastes": "improvar",
    "improvava": "improvar",
    "improvavam": "improvar",
    "improvavas": "improvar",
    "improvações": "improvação",
    "improve": "improvar",
    "improvei": "improvar",
    "improveis": "improvar",
    "improvem": "improvar",
    "improvemo": "improvar",
    "improvemos": "improvar",
    "improves": "improvar",
    "improvida": "improvido",
    "improvidas": "improvido",
    "improvidentes": "improvidente",
    "improvidos": "improvido",
    "improvidências": "improvidência",
    "improvisa": "improviso",
    "improvisada": "improvisar",
    "improvisadas": "improvisar",
    "improvisado": "improvisar",
    "improvisadora": "improvisador",
    "improvisadoras": "improvisador",
    "improvisadorazinha": "improvisador",
    "improvisadorazinhas": "improvisador",
    "improvisadorazita": "improvisador",
    "improvisadorazitas": "improvisador",
    "improvisadores": "improvisador",
    "improvisadorzinho": "improvisador",
    "improvisadorzinhos": "improvisador",
    "improvisadorzito": "improvisador",
    "improvisadorzitos": "improvisador",
    "improvisados": "improvisar",
    "improvisadíssima": "improvisado",
    "improvisadíssimas": "improvisado",
    "improvisadíssimo": "improvisado",
    "improvisadíssimos": "improvisado",
    "improvisai": "improvisar",
    "improvisais": "improvisar",
    "improvisam": "improvisar",
    "improvisamo": "improvisar",
    "improvisamos": "improvisar",
    "improvisando": "improvisar",
    "improvisara": "improvisar",
    "improvisaram": "improvisar",
    "improvisaras": "improvisar",
    "improvisarde": "improvisar",
    "improvisardes": "improvisar",
    "improvisare": "improvisar",
    "improvisarei": "improvisar",
    "improvisareis": "improvisar",
    "improvisarem": "improvisar",
    "improvisaremos": "improvisar",
    "improvisares": "improvisar",
    "improvisaria": "improvisar",
    "improvisariam": "improvisar",
    "improvisarias": "improvisar",
    "improvisarmo": "improvisar",
    "improvisarmos": "improvisar",
    "improvisará": "improvisar",
    "improvisarás": "improvisar",
    "improvisarão": "improvisar",
    "improvisaríamos": "improvisar",
    "improvisaríeis": "improvisar",
    "improvisas": "improviso",
    "improvisasse": "improvisar",
    "improvisassem": "improvisar",
    "improvisasses": "improvisar",
    "improvisaste": "improvisar",
    "improvisastes": "improvisar",
    "improvisatas": "improvisata",
    "improvisava": "improvisar",
    "improvisavam": "improvisar",
    "improvisavas": "improvisar",
    "improvisações": "improvisação",
    "improvise": "improvisar",
    "improvisei": "improvisar",
    "improviseis": "improvisar",
    "improvisem": "improvisar",
    "improvisemo": "improvisar",
    "improvisemos": "improvisar",
    "improvises": "improvisar",
    "improviso": "improvisar",
    "improvisos": "improviso",
    "improvisou": "improvisar",
    "improvisá": "improvisar",
    "improvisámo": "improvisar",
    "improvisámos": "improvisar",
    "improvisáramo": "improvisar",
    "improvisáramos": "improvisar",
    "improvisárei": "improvisar",
    "improvisáreis": "improvisar",
    "improvisásseis": "improvisar",
    "improvisássemos": "improvisar",
    "improvisávamo": "improvisar",
    "improvisávamos": "improvisar",
    "improvisávei": "improvisar",
    "improvisáveis": "improvisável",
    "improvo": "improvar",
    "improvou": "improvar",
    "imprová": "improvar",
    "improvámo": "improvar",
    "improvámos": "improvar",
    "improváramo": "improvar",
    "improváramos": "improvar",
    "improvárei": "improvar",
    "improváreis": "improvar",
    "improvásseis": "improvar",
    "improvássemos": "improvar",
    "improvávamo": "improvar",
    "improvávamos": "improvar",
    "improvávei": "improvar",
    "improváveis": "improvável",
    "imprudentes": "imprudente",
    "imprudências": "imprudência",
    "imprópria": "impróprio",
    "impróprias": "impróprio",
    "impróprios": "impróprio",
    "impróvida": "impróvido",
    "impróvidas": "impróvido",
    "impróvidos": "impróvido",
    "impuberdades": "impuberdade",
    "impubescentes": "impubescente",
    "impubescências": "impubescência",
    "impublicáveis": "impublicável",
    "impudentes": "impudente",
    "impudica": "impudico",
    "impudicas": "impudico",
    "impudicos": "impudico",
    "impudicícias": "impudicícia",
    "impudores": "impudor",
    "impudências": "impudência",
    "impugna": "impugnar",
    "impugnabilidades": "impugnabilidade",
    "impugnada": "impugnar",
    "impugnadas": "impugnar",
    "impugnado": "impugnar",
    "impugnadora": "impugnador",
    "impugnadoras": "impugnador",
    "impugnadores": "impugnador",
    "impugnados": "impugnar",
    "impugnai": "impugnar",
    "impugnais": "impugnar",
    "impugnam": "impugnar",
    "impugnamo": "impugnar",
    "impugnamos": "impugnar",
    "impugnando": "impugnar",
    "impugnara": "impugnar",
    "impugnaram": "impugnar",
    "impugnaras": "impugnar",
    "impugnarde": "impugnar",
    "impugnardes": "impugnar",
    "impugnare": "impugnar",
    "impugnarei": "impugnar",
    "impugnareis": "impugnar",
    "impugnarem": "impugnar",
    "impugnaremos": "impugnar",
    "impugnares": "impugnar",
    "impugnaria": "impugnar",
    "impugnariam": "impugnar",
    "impugnarias": "impugnar",
    "impugnarmo": "impugnar",
    "impugnarmos": "impugnar",
    "impugnará": "impugnar",
    "impugnarás": "impugnar",
    "impugnarão": "impugnar",
    "impugnaríamos": "impugnar",
    "impugnaríeis": "impugnar",
    "impugnas": "impugnar",
    "impugnasse": "impugnar",
    "impugnassem": "impugnar",
    "impugnasses": "impugnar",
    "impugnaste": "impugnar",
    "impugnastes": "impugnar",
    "impugnativa": "impugnativo",
    "impugnativas": "impugnativo",
    "impugnativos": "impugnativo",
    "impugnava": "impugnar",
    "impugnavam": "impugnar",
    "impugnavas": "impugnar",
    "impugnações": "impugnação",
    "impugne": "impugnar",
    "impugnei": "impugnar",
    "impugneis": "impugnar",
    "impugnem": "impugnar",
    "impugnemo": "impugnar",
    "impugnemos": "impugnar",
    "impugnes": "impugnar",
    "impugno": "impugnar",
    "impugnou": "impugnar",
    "impugná": "impugnar",
    "impugnámo": "impugnar",
    "impugnámos": "impugnar",
    "impugnáramo": "impugnar",
    "impugnáramos": "impugnar",
    "impugnárei": "impugnar",
    "impugnáreis": "impugnar",
    "impugnásseis": "impugnar",
    "impugnássemos": "impugnar",
    "impugnávamo": "impugnar",
    "impugnávamos": "impugnar",
    "impugnávei": "impugnar",
    "impugnáveis": "impugnável",
    "impulsiona": "impulsionar",
    "impulsionada": "impulsionar",
    "impulsionadas": "impulsionar",
    "impulsionado": "impulsionar",
    "impulsionadora": "impulsionador",
    "impulsionadoras": "impulsionador",
    "impulsionadores": "impulsionador",
    "impulsionados": "impulsionar",
    "impulsionai": "impulsionar",
    "impulsionais": "impulsionar",
    "impulsionam": "impulsionar",
    "impulsionamo": "impulsionar",
    "impulsionamos": "impulsionar",
    "impulsionando": "impulsionar",
    "impulsionara": "impulsionar",
    "impulsionaram": "impulsionar",
    "impulsionaras": "impulsionar",
    "impulsionarde": "impulsionar",
    "impulsionardes": "impulsionar",
    "impulsionare": "impulsionar",
    "impulsionarei": "impulsionar",
    "impulsionareis": "impulsionar",
    "impulsionarem": "impulsionar",
    "impulsionaremos": "impulsionar",
    "impulsionares": "impulsionar",
    "impulsionaria": "impulsionar",
    "impulsionariam": "impulsionar",
    "impulsionarias": "impulsionar",
    "impulsionarmo": "impulsionar",
    "impulsionarmos": "impulsionar",
    "impulsionará": "impulsionar",
    "impulsionarás": "impulsionar",
    "impulsionarão": "impulsionar",
    "impulsionaríamos": "impulsionar",
    "impulsionaríeis": "impulsionar",
    "impulsionas": "impulsionar",
    "impulsionasse": "impulsionar",
    "impulsionassem": "impulsionar",
    "impulsionasses": "impulsionar",
    "impulsionaste": "impulsionar",
    "impulsionastes": "impulsionar",
    "impulsionava": "impulsionar",
    "impulsionavam": "impulsionar",
    "impulsionavas": "impulsionar",
    "impulsione": "impulsionar",
    "impulsionei": "impulsionar",
    "impulsioneis": "impulsionar",
    "impulsionem": "impulsionar",
    "impulsionemo": "impulsionar",
    "impulsionemos": "impulsionar",
    "impulsiones": "impulsionar",
    "impulsiono": "impulsionar",
    "impulsionou": "impulsionar",
    "impulsioná": "impulsionar",
    "impulsionámo": "impulsionar",
    "impulsionámos": "impulsionar",
    "impulsionáramo": "impulsionar",
    "impulsionáramos": "impulsionar",
    "impulsionárei": "impulsionar",
    "impulsionáreis": "impulsionar",
    "impulsionásseis": "impulsionar",
    "impulsionássemos": "impulsionar",
    "impulsionávamo": "impulsionar",
    "impulsionávamos": "impulsionar",
    "impulsionávei": "impulsionar",
    "impulsionáveis": "impulsionar",
    "impulsiva": "impulsivo",
    "impulsivas": "impulsivo",
    "impulsividades": "impulsividade",
    "impulsivismos": "impulsivismo",
    "impulsivos": "impulsivo",
    "impulsora": "impulsor",
    "impulsoras": "impulsor",
    "impulsores": "impulsor",
    "impulsos": "impulso",
    "impulsões": "impulsão",
    "impunes": "impune",
    "impunha": "impor",
    "impunham": "impor",
    "impunhas": "impor",
    "impunidades": "impunidade",
    "impuníveis": "impunível",
    "impura": "impuro",
    "impuras": "impuro",
    "impurezas": "impureza",
    "impuridades": "impuridade",
    "impurifica": "impurificar",
    "impurificada": "impurificar",
    "impurificadas": "impurificar",
    "impurificado": "impurificar",
    "impurificados": "impurificar",
    "impurificai": "impurificar",
    "impurificais": "impurificar",
    "impurificam": "impurificar",
    "impurificamo": "impurificar",
    "impurificamos": "impurificar",
    "impurificando": "impurificar",
    "impurificara": "impurificar",
    "impurificaram": "impurificar",
    "impurificaras": "impurificar",
    "impurificarde": "impurificar",
    "impurificardes": "impurificar",
    "impurificare": "impurificar",
    "impurificarei": "impurificar",
    "impurificareis": "impurificar",
    "impurificarem": "impurificar",
    "impurificaremos": "impurificar",
    "impurificares": "impurificar",
    "impurificaria": "impurificar",
    "impurificariam": "impurificar",
    "impurificarias": "impurificar",
    "impurificarmo": "impurificar",
    "impurificarmos": "impurificar",
    "impurificará": "impurificar",
    "impurificarás": "impurificar",
    "impurificarão": "impurificar",
    "impurificaríamos": "impurificar",
    "impurificaríeis": "impurificar",
    "impurificas": "impurificar",
    "impurificasse": "impurificar",
    "impurificassem": "impurificar",
    "impurificasses": "impurificar",
    "impurificaste": "impurificar",
    "impurificastes": "impurificar",
    "impurificava": "impurificar",
    "impurificavam": "impurificar",
    "impurificavas": "impurificar",
    "impurifico": "impurificar",
    "impurificou": "impurificar",
    "impurificá": "impurificar",
    "impurificámo": "impurificar",
    "impurificámos": "impurificar",
    "impurificáramo": "impurificar",
    "impurificáramos": "impurificar",
    "impurificárei": "impurificar",
    "impurificáreis": "impurificar",
    "impurificásseis": "impurificar",
    "impurificássemos": "impurificar",
    "impurificávamo": "impurificar",
    "impurificávamos": "impurificar",
    "impurificávei": "impurificar",
    "impurificáveis": "impurificar",
    "impurifique": "impurificar",
    "impurifiquei": "impurificar",
    "impurifiqueis": "impurificar",
    "impurifiquem": "impurificar",
    "impurifiquemo": "impurificar",
    "impurifiquemos": "impurificar",
    "impurifiques": "impurificar",
    "impuros": "impuro",
    "impus": "impor",
    "impusemo": "impor",
    "impusemos": "impor",
    "impuser": "impor",
    "impusera": "impor",
    "impuseram": "impor",
    "impuseras": "impor",
    "impuserdes": "impor",
    "impuserem": "impor",
    "impuseres": "impor",
    "impusermos": "impor",
    "impusesse": "impor",
    "impusessem": "impor",
    "impusesses": "impor",
    "impuseste": "impor",
    "impusestes": "impor",
    "impuséramo": "impor",
    "impuséramos": "impor",
    "impusérei": "impor",
    "impuséreis": "impor",
    "impusésseis": "impor",
    "impuséssemos": "impor",
    "imputa": "imputar",
    "imputabilidades": "imputabilidade",
    "imputada": "imputar",
    "imputadas": "imputar",
    "imputado": "imputar",
    "imputadora": "imputador",
    "imputadoras": "imputador",
    "imputadores": "imputador",
    "imputados": "imputar",
    "imputai": "imputar",
    "imputais": "imputar",
    "imputam": "imputar",
    "imputamo": "imputar",
    "imputamos": "imputar",
    "imputando": "imputar",
    "imputara": "imputar",
    "imputaram": "imputar",
    "imputaras": "imputar",
    "imputarde": "imputar",
    "imputardes": "imputar",
    "imputare": "imputar",
    "imputarei": "imputar",
    "imputareis": "imputar",
    "imputarem": "imputar",
    "imputaremos": "imputar",
    "imputares": "imputar",
    "imputaria": "imputar",
    "imputariam": "imputar",
    "imputarias": "imputar",
    "imputarmo": "imputar",
    "imputarmos": "imputar",
    "imputará": "imputar",
    "imputarás": "imputar",
    "imputarão": "imputar",
    "imputaríamos": "imputar",
    "imputaríeis": "imputar",
    "imputas": "imputar",
    "imputasse": "imputar",
    "imputassem": "imputar",
    "imputasses": "imputar",
    "imputaste": "imputar",
    "imputastes": "imputar",
    "imputava": "imputar",
    "imputavam": "imputar",
    "imputavas": "imputar",
    "imputações": "imputação",
    "impute": "imputar",
    "imputei": "imputar",
    "imputeis": "imputar",
    "imputem": "imputar",
    "imputemo": "imputar",
    "imputemos": "imputar",
    "imputes": "imputar",
    "imputo": "imputar",
    "imputou": "imputar",
    "imputrefacções": "imputrefacção",
    "imputrescibilidades": "imputrescibilidade",
    "imputrescíveis": "imputrescível",
    "imputá": "imputar",
    "imputámo": "imputar",
    "imputámos": "imputar",
    "imputáramo": "imputar",
    "imputáramos": "imputar",
    "imputárei": "imputar",
    "imputáreis": "imputar",
    "imputásseis": "imputar",
    "imputássemos": "imputar",
    "imputávamo": "imputar",
    "imputávamos": "imputar",
    "imputávei": "imputar",
    "imputáveis": "imputável",
    "impávida": "impávido",
    "impávidas": "impávido",
    "impávidos": "impávido",
    "impérios": "império",
    "impérvia": "impérvio",
    "impérvias": "impérvio",
    "impérvios": "impérvio",
    "impíveis": "impível",
    "impô": "impor",
    "impôs": "impor",
    "impõe": "impor",
    "impõem": "impor",
    "impões": "impor",
    "impúberes": "impúbere",
    "impúnhamo": "impor",
    "impúnhamos": "impor",
    "impúnhei": "impor",
    "impúnheis": "impor",
    "imudáveis": "imudável",
    "imunda": "imundo",
    "imundas": "imundo",
    "imundices": "imundice",
    "imundos": "imundo",
    "imundícias": "imundícia",
    "imundícies": "imundície",
    "imunes": "imune",
    "imunidades": "imunidade",
    "imunitária": "imunitário",
    "imunitárias": "imunitário",
    "imunitários": "imunitário",
    "imuniza": "imunizar",
    "imunizada": "imunizar",
    "imunizadas": "imunizar",
    "imunizado": "imunizar",
    "imunizadora": "imunizador",
    "imunizadoras": "imunizador",
    "imunizadores": "imunizador",
    "imunizados": "imunizar",
    "imunizai": "imunizar",
    "imunizais": "imunizar",
    "imunizam": "imunizar",
    "imunizamo": "imunizar",
    "imunizamos": "imunizar",
    "imunizando": "imunizar",
    "imunizantes": "imunizante",
    "imunizara": "imunizar",
    "imunizaram": "imunizar",
    "imunizaras": "imunizar",
    "imunizarde": "imunizar",
    "imunizardes": "imunizar",
    "imunizare": "imunizar",
    "imunizarei": "imunizar",
    "imunizareis": "imunizar",
    "imunizarem": "imunizar",
    "imunizaremos": "imunizar",
    "imunizares": "imunizar",
    "imunizaria": "imunizar",
    "imunizariam": "imunizar",
    "imunizarias": "imunizar",
    "imunizarmo": "imunizar",
    "imunizarmos": "imunizar",
    "imunizará": "imunizar",
    "imunizarás": "imunizar",
    "imunizarão": "imunizar",
    "imunizaríamos": "imunizar",
    "imunizaríeis": "imunizar",
    "imunizas": "imunizar",
    "imunizasse": "imunizar",
    "imunizassem": "imunizar",
    "imunizasses": "imunizar",
    "imunizaste": "imunizar",
    "imunizastes": "imunizar",
    "imunizava": "imunizar",
    "imunizavam": "imunizar",
    "imunizavas": "imunizar",
    "imunizações": "imunização",
    "imunize": "imunizar",
    "imunizei": "imunizar",
    "imunizeis": "imunizar",
    "imunizem": "imunizar",
    "imunizemo": "imunizar",
    "imunizemos": "imunizar",
    "imunizes": "imunizar",
    "imunizo": "imunizar",
    "imunizou": "imunizar",
    "imunizá": "imunizar",
    "imunizámo": "imunizar",
    "imunizámos": "imunizar",
    "imunizáramo": "imunizar",
    "imunizáramos": "imunizar",
    "imunizárei": "imunizar",
    "imunizáreis": "imunizar",
    "imunizásseis": "imunizar",
    "imunizássemos": "imunizar",
    "imunizávamo": "imunizar",
    "imunizávamos": "imunizar",
    "imunizávei": "imunizar",
    "imunizáveis": "imunizável",
    "imunodeficiências": "imunodeficiência",
    "imunodepressões": "imunodepressão",
    "imunoglobulinas": "imunoglobulina",
    "imunologias": "imunologia",
    "imunologistas": "imunologista",
    "imunológica": "imunológico",
    "imunológicas": "imunológico",
    "imunológicos": "imunológico",
    "imunopatologias": "imunopatologia",
    "imunorreações": "imunorreação",
    "imunossupressões": "imunossupressão",
    "imunosupressões": "imunosupressão",
    "imunoterapias": "imunoterapia",
    "imuta": "imutar",
    "imutabilidades": "imutabilidade",
    "imutada": "imutar",
    "imutadas": "imutar",
    "imutado": "imutar",
    "imutados": "imutar",
    "imutai": "imutar",
    "imutais": "imutar",
    "imutam": "imutar",
    "imutamo": "imutar",
    "imutamos": "imutar",
    "imutando": "imutar",
    "imutara": "imutar",
    "imutaram": "imutar",
    "imutaras": "imutar",
    "imutarde": "imutar",
    "imutardes": "imutar",
    "imutare": "imutar",
    "imutarei": "imutar",
    "imutareis": "imutar",
    "imutarem": "imutar",
    "imutaremos": "imutar",
    "imutares": "imutar",
    "imutaria": "imutar",
    "imutariam": "imutar",
    "imutarias": "imutar",
    "imutarmo": "imutar",
    "imutarmos": "imutar",
    "imutará": "imutar",
    "imutarás": "imutar",
    "imutarão": "imutar",
    "imutaríamos": "imutar",
    "imutaríeis": "imutar",
    "imutas": "imutar",
    "imutasse": "imutar",
    "imutassem": "imutar",
    "imutasses": "imutar",
    "imutaste": "imutar",
    "imutastes": "imutar",
    "imutava": "imutar",
    "imutavam": "imutar",
    "imutavas": "imutar",
    "imutações": "imutação",
    "imute": "imutar",
    "imutei": "imutar",
    "imuteis": "imutar",
    "imutem": "imutar",
    "imutemo": "imutar",
    "imutemos": "imutar",
    "imutes": "imutar",
    "imuto": "imutar",
    "imutou": "imutar",
    "imutá": "imutar",
    "imutámo": "imutar",
    "imutámos": "imutar",
    "imutáramo": "imutar",
    "imutáramos": "imutar",
    "imutárei": "imutar",
    "imutáreis": "imutar",
    "imutásseis": "imutar",
    "imutássemos": "imutar",
    "imutávamo": "imutar",
    "imutávamos": "imutar",
    "imutávei": "imutar",
    "imutáveis": "imutável",
    "imãs": "imã",
    "imémores": "imémore",
    "imérita": "imérito",
    "iméritas": "imérito",
    "iméritos": "imérito",
    "imóbis": "imóbil",
    "imódica": "imódico",
    "imódicas": "imódico",
    "imódicos": "imódico",
    "imóveis": "imóvel",
    "inabafáveis": "inabafável",
    "inabalroáveis": "inabalroável",
    "inabaláveis": "inabalável",
    "inabanáveis": "inabanável",
    "inabarcáveis": "inabarcável",
    "inabatíveis": "inabatível",
    "inabdicáveis": "inabdicável",
    "inabilidades": "inabilidade",
    "inabilita": "inabilitar",
    "inabilitada": "inabilitar",
    "inabilitadas": "inabilitar",
    "inabilitado": "inabilitar",
    "inabilitados": "inabilitar",
    "inabilitai": "inabilitar",
    "inabilitais": "inabilitar",
    "inabilitam": "inabilitar",
    "inabilitamo": "inabilitar",
    "inabilitamos": "inabilitar",
    "inabilitando": "inabilitar",
    "inabilitara": "inabilitar",
    "inabilitaram": "inabilitar",
    "inabilitaras": "inabilitar",
    "inabilitarde": "inabilitar",
    "inabilitardes": "inabilitar",
    "inabilitare": "inabilitar",
    "inabilitarei": "inabilitar",
    "inabilitareis": "inabilitar",
    "inabilitarem": "inabilitar",
    "inabilitaremos": "inabilitar",
    "inabilitares": "inabilitar",
    "inabilitaria": "inabilitar",
    "inabilitariam": "inabilitar",
    "inabilitarias": "inabilitar",
    "inabilitarmo": "inabilitar",
    "inabilitarmos": "inabilitar",
    "inabilitará": "inabilitar",
    "inabilitarás": "inabilitar",
    "inabilitarão": "inabilitar",
    "inabilitaríamos": "inabilitar",
    "inabilitaríeis": "inabilitar",
    "inabilitas": "inabilitar",
    "inabilitasse": "inabilitar",
    "inabilitassem": "inabilitar",
    "inabilitasses": "inabilitar",
    "inabilitaste": "inabilitar",
    "inabilitastes": "inabilitar",
    "inabilitava": "inabilitar",
    "inabilitavam": "inabilitar",
    "inabilitavas": "inabilitar",
    "inabilitações": "inabilitação",
    "inabilite": "inabilitar",
    "inabilitei": "inabilitar",
    "inabiliteis": "inabilitar",
    "inabilitem": "inabilitar",
    "inabilitemo": "inabilitar",
    "inabilitemos": "inabilitar",
    "inabilites": "inabilitar",
    "inabilito": "inabilitar",
    "inabilitou": "inabilitar",
    "inabilitá": "inabilitar",
    "inabilitámo": "inabilitar",
    "inabilitámos": "inabilitar",
    "inabilitáramo": "inabilitar",
    "inabilitáramos": "inabilitar",
    "inabilitárei": "inabilitar",
    "inabilitáreis": "inabilitar",
    "inabilitásseis": "inabilitar",
    "inabilitássemos": "inabilitar",
    "inabilitávamo": "inabilitar",
    "inabilitávamos": "inabilitar",
    "inabilitávei": "inabilitar",
    "inabilitáveis": "inabilitar",
    "inabitada": "inabitado",
    "inabitadas": "inabitado",
    "inabitados": "inabitado",
    "inabituais": "inabitual",
    "inabitáveis": "inabitável",
    "inabjudicáveis": "inabjudicável",
    "inabjuráveis": "inabjurável",
    "inabolíveis": "inabolível",
    "inabonáveis": "inabonável",
    "inabordáveis": "inabordável",
    "inaborrecíveis": "inaborrecível",
    "inabrandáveis": "inabrandável",
    "inabrangíveis": "inabrangível",
    "inabreviáveis": "inabreviável",
    "inabsoluta": "inabsoluto",
    "inabsolutas": "inabsoluto",
    "inabsolutos": "inabsoluto",
    "inabsolvíveis": "inabsolvível",
    "inabsorvíveis": "inabsorvível",
    "inacabada": "inacabado",
    "inacabadas": "inacabado",
    "inacabados": "inacabado",
    "inacabamentos": "inacabamento",
    "inacabáveis": "inacabável",
    "inacalentáveis": "inacalentável",
    "inacatáveis": "inacatável",
    "inaccessibilidades": "inaccessibilidade",
    "inaccionáveis": "inaccionável",
    "inaceitáveis": "inaceitável",
    "inacendíveis": "inacendível",
    "inacessibilidades": "inacessibilidade",
    "inacessíveis": "inacessível",
    "inacolhíveis": "inacolhível",
    "inacomodáveis": "inacomodável",
    "inacostumada": "inacostumado",
    "inacostumadas": "inacostumado",
    "inacostumados": "inacostumado",
    "inacostáveis": "inacostável",
    "inacreditáveis": "inacreditável",
    "inacrescentáveis": "inacrescentável",
    "inactiva": "inactivo",
    "inactivada": "inactivar",
    "inactivadas": "inactivar",
    "inactivado": "inactivar",
    "inactivados": "inactivar",
    "inactivai": "inactivar",
    "inactivais": "inactivar",
    "inactivam": "inactivar",
    "inactivamo": "inactivar",
    "inactivamos": "inactivar",
    "inactivando": "inactivar",
    "inactivara": "inactivar",
    "inactivaram": "inactivar",
    "inactivaras": "inactivar",
    "inactivarde": "inactivar",
    "inactivardes": "inactivar",
    "inactivare": "inactivar",
    "inactivarei": "inactivar",
    "inactivareis": "inactivar",
    "inactivarem": "inactivar",
    "inactivaremos": "inactivar",
    "inactivares": "inactivar",
    "inactivaria": "inactivar",
    "inactivariam": "inactivar",
    "inactivarias": "inactivar",
    "inactivarmo": "inactivar",
    "inactivarmos": "inactivar",
    "inactivará": "inactivar",
    "inactivarás": "inactivar",
    "inactivarão": "inactivar",
    "inactivaríamos": "inactivar",
    "inactivaríeis": "inactivar",
    "inactivas": "inactivo",
    "inactivasse": "inactivar",
    "inactivassem": "inactivar",
    "inactivasses": "inactivar",
    "inactivaste": "inactivar",
    "inactivastes": "inactivar",
    "inactivava": "inactivar",
    "inactivavam": "inactivar",
    "inactivavas": "inactivar",
    "inactivações": "inactivação",
    "inactive": "inactivar",
    "inactivei": "inactivar",
    "inactiveis": "inactivar",
    "inactivem": "inactivar",
    "inactivemo": "inactivar",
    "inactivemos": "inactivar",
    "inactives": "inactivar",
    "inactividades": "inactividade",
    "inactivo": "inactivar",
    "inactivos": "inactivo",
    "inactivou": "inactivar",
    "inactivá": "inactivar",
    "inactivámo": "inactivar",
    "inactivámos": "inactivar",
    "inactiváramo": "inactivar",
    "inactiváramos": "inactivar",
    "inactivárei": "inactivar",
    "inactiváreis": "inactivar",
    "inactivásseis": "inactivar",
    "inactivássemos": "inactivar",
    "inactivávamo": "inactivar",
    "inactivávamos": "inactivar",
    "inactivávei": "inactivar",
    "inactiváveis": "inactivável",
    "inactuais": "inactual",
    "inactualizáveis": "inactualizável",
    "inacumulações": "inacumulação",
    "inacumuláveis": "inacumulável",
    "inacusáveis": "inacusável",
    "inacções": "inacção",
    "inadaptabilidades": "inadaptabilidade",
    "inadaptada": "inadaptado",
    "inadaptadas": "inadaptado",
    "inadaptados": "inadaptado",
    "inadaptações": "inadaptação",
    "inadaptáveis": "inadaptável",
    "inadequabilidades": "inadequabilidade",
    "inadequada": "inadequado",
    "inadequadas": "inadequado",
    "inadequados": "inadequado",
    "inadequações": "inadequação",
    "inaderentes": "inaderente",
    "inadiantáveis": "inadiantável",
    "inadicionáveis": "inadicionável",
    "inadimplementos": "inadimplemento",
    "inadivinháveis": "inadivinhável",
    "inadiáveis": "inadiável",
    "inadministráveis": "inadministrável",
    "inadmissibilidades": "inadmissibilidade",
    "inadmissíveis": "inadmissível",
    "inadmissões": "inadmissão",
    "inadquiríveis": "inadquirível",
    "inadulteráveis": "inadulterável",
    "inadvertida": "inadvertido",
    "inadvertidas": "inadvertido",
    "inadvertidos": "inadvertido",
    "inadvertências": "inadvertência",
    "inadvogáveis": "inadvogável",
    "inafastáveis": "inafastável",
    "inafectáveis": "inafectável",
    "inafiançabilidades": "inafiançabilidade",
    "inafináveis": "inafinável",
    "inafixáveis": "inafixável",
    "inafligíveis": "inafligível",
    "inafugentáveis": "inafugentável",
    "inagarráveis": "inagarrável",
    "inagitáveis": "inagitável",
    "inagradecíveis": "inagradecível",
    "inagraváveis": "inagravável",
    "inagricultáveis": "inagricultável",
    "inagrupáveis": "inagrupável",
    "inaguentáveis": "inaguentável",
    "inajardináveis": "inajardinável",
    "inajavardáveis": "inajavardável",
    "inajudáveis": "inajudável",
    "inajuizáveis": "inajuizável",
    "inajustáveis": "inajustável",
    "inala": "inalar",
    "inalada": "inalar",
    "inaladas": "inalar",
    "inalado": "inalar",
    "inaladores": "inalador",
    "inalados": "inalar",
    "inalagáveis": "inalagável",
    "inalai": "inalar",
    "inalais": "inalar",
    "inalam": "inalar",
    "inalamo": "inalar",
    "inalamos": "inalar",
    "inalando": "inalar",
    "inalantes": "inalante",
    "inalara": "inalar",
    "inalaram": "inalar",
    "inalaras": "inalar",
    "inalarde": "inalar",
    "inalardes": "inalar",
    "inalare": "inalar",
    "inalarei": "inalar",
    "inalareis": "inalar",
    "inalarem": "inalar",
    "inalaremos": "inalar",
    "inalares": "inalar",
    "inalaria": "inalar",
    "inalariam": "inalar",
    "inalarias": "inalar",
    "inalarmo": "inalar",
    "inalarmos": "inalar",
    "inalará": "inalar",
    "inalarás": "inalar",
    "inalarão": "inalar",
    "inalaríamos": "inalar",
    "inalaríeis": "inalar",
    "inalas": "inalar",
    "inalasse": "inalar",
    "inalassem": "inalar",
    "inalasses": "inalar",
    "inalaste": "inalar",
    "inalastes": "inalar",
    "inalava": "inalar",
    "inalavam": "inalar",
    "inalavas": "inalar",
    "inalações": "inalação",
    "inalcançáveis": "inalcançável",
    "inaldrabáveis": "inaldrabável",
    "inale": "inalar",
    "inalegráveis": "inalegrável",
    "inalegáveis": "inalegável",
    "inalei": "inalar",
    "inaleis": "inalar",
    "inalem": "inalar",
    "inalemo": "inalar",
    "inalemos": "inalar",
    "inales": "inalar",
    "inalfabetizáveis": "inalfabetizável",
    "inaliciáveis": "inaliciável",
    "inalienabilidades": "inalienabilidade",
    "inalienações": "inalienação",
    "inalienáveis": "inalienável",
    "inalinháveis": "inalinhável",
    "inalisáveis": "inalisável",
    "inaliviáveis": "inaliviável",
    "inaliáveis": "inaliável",
    "inalo": "inalar",
    "inalojáveis": "inalojável",
    "inalongáveis": "inalongável",
    "inalou": "inalar",
    "inalterabilidades": "inalterabilidade",
    "inalterada": "inalterado",
    "inalteradas": "inalterado",
    "inalterados": "inalterado",
    "inalterações": "inalteração",
    "inalternáveis": "inalternável",
    "inalteráveis": "inalterável",
    "inalugáveis": "inalugável",
    "inalvejáveis": "inalvejável",
    "inalá": "inalar",
    "inalámo": "inalar",
    "inalámos": "inalar",
    "inaláramo": "inalar",
    "inaláramos": "inalar",
    "inalárei": "inalar",
    "inaláreis": "inalar",
    "inalásseis": "inalar",
    "inalássemos": "inalar",
    "inalávamo": "inalar",
    "inalávamos": "inalar",
    "inalávei": "inalar",
    "inaláveis": "inalável",
    "inamachucáveis": "inamachucável",
    "inamarrotáveis": "inamarrotável",
    "inambulações": "inambulação",
    "inamissibilidades": "inamissibilidade",
    "inamissíveis": "inamissível",
    "inamnistiáveis": "inamnistiável",
    "inamoedáveis": "inamoedável",
    "inamoldáveis": "inamoldável",
    "inamolgáveis": "inamolgável",
    "inamontoáveis": "inamontoável",
    "inamovibilidades": "inamovibilidade",
    "inamovíveis": "inamovível",
    "inamplificáveis": "inamplificável",
    "inampliáveis": "inampliável",
    "inana": "inanir",
    "inanais": "inanir",
    "inanalisáveis": "inanalisável",
    "inanam": "inanir",
    "inanamo": "inanir",
    "inanamos": "inanir",
    "inanas": "inanir",
    "inane": "inanir",
    "inanem": "inanir",
    "inanes": "inanir",
    "inani": "inanir",
    "inania": "inanir",
    "inaniam": "inanir",
    "inanias": "inanir",
    "inanida": "inanir",
    "inanidades": "inanidade",
    "inanidas": "inanir",
    "inanido": "inanir",
    "inanidos": "inanir",
    "inanimada": "inanimado",
    "inanimadas": "inanimado",
    "inanimados": "inanimado",
    "inanimo": "inanir",
    "inanimos": "inanir",
    "inanindo": "inanir",
    "inaniquiláveis": "inaniquilável",
    "inanira": "inanir",
    "inaniram": "inanir",
    "inaniras": "inanir",
    "inanirde": "inanir",
    "inanirdes": "inanir",
    "inanire": "inanir",
    "inanirei": "inanir",
    "inanireis": "inanir",
    "inanirem": "inanir",
    "inaniremos": "inanir",
    "inanires": "inanir",
    "inaniria": "inanir",
    "inaniriam": "inanir",
    "inanirias": "inanir",
    "inanirmo": "inanir",
    "inanirmos": "inanir",
    "inanirá": "inanir",
    "inanirás": "inanir",
    "inanirão": "inanir",
    "inaniríamos": "inanir",
    "inaniríeis": "inanir",
    "inanis": "inanir",
    "inanisse": "inanir",
    "inanissem": "inanir",
    "inanisses": "inanir",
    "inaniste": "inanir",
    "inanistes": "inanir",
    "inaniu": "inanir",
    "inanições": "inanição",
    "inano": "inanir",
    "inanotáveis": "inanotável",
    "inantecipáveis": "inantecipável",
    "inantérea": "inantéreo",
    "inantéreas": "inantéreo",
    "inantéreos": "inantéreo",
    "inanunciáveis": "inanunciável",
    "inaníamo": "inanir",
    "inaníamos": "inanir",
    "inaníei": "inanir",
    "inaníeis": "inanir",
    "inaníramo": "inanir",
    "inaníramos": "inanir",
    "inanírei": "inanir",
    "inaníreis": "inanir",
    "inanísseis": "inanir",
    "inaníssemos": "inanir",
    "inapalpáveis": "inapalpável",
    "inaparentes": "inaparente",
    "inapaziguáveis": "inapaziguável",
    "inapelabilidades": "inapelabilidade",
    "inapeláveis": "inapelável",
    "inapendiculada": "inapendiculado",
    "inapendiculadas": "inapendiculado",
    "inapendiculados": "inapendiculado",
    "inaperfeiçoáveis": "inaperfeiçoável",
    "inapertáveis": "inapertável",
    "inapetências": "inapetência",
    "inaplacáveis": "inaplacável",
    "inaplaináveis": "inaplainável",
    "inaplaudíveis": "inaplaudível",
    "inaplicabilidades": "inaplicabilidade",
    "inaplicada": "inaplicado",
    "inaplicadas": "inaplicado",
    "inaplicados": "inaplicado",
    "inaplicáveis": "inaplicável",
    "inapoiáveis": "inapoiável",
    "inapontáveis": "inapontável",
    "inapreciada": "inapreciado",
    "inapreciadas": "inapreciado",
    "inapreciados": "inapreciado",
    "inapreciáveis": "inapreciável",
    "inapreensíveis": "inapreensível",
    "inapregoáveis": "inapregoável",
    "inaprendíveis": "inaprendível",
    "inapresentáveis": "inapresentável",
    "inaprofundáveis": "inaprofundável",
    "inapropriada": "inapropriado",
    "inapropriadas": "inapropriado",
    "inapropriados": "inapropriado",
    "inaproveitada": "inaproveitado",
    "inaproveitadas": "inaproveitado",
    "inaproveitados": "inaproveitado",
    "inaproveitáveis": "inaproveitável",
    "inapta": "inapto",
    "inaptas": "inapto",
    "inaptidões": "inaptidão",
    "inaptos": "inapto",
    "inapuráveis": "inapurável",
    "inarguíveis": "inarguível",
    "inarmonias": "inarmonia",
    "inarmónica": "inarmónico",
    "inarmónicas": "inarmónico",
    "inarmónicos": "inarmónico",
    "inarquiváveis": "inarquivável",
    "inarranjáveis": "inarranjável",
    "inarrecadáveis": "inarrecadável",
    "inarrematáveis": "inarrematável",
    "inarrombáveis": "inarrombável",
    "inarráveis": "inarrável",
    "inarticulada": "inarticulado",
    "inarticuladas": "inarticulado",
    "inarticulados": "inarticulado",
    "inarticuláveis": "inarticulável",
    "inartificiais": "inartificial",
    "inartificiosa": "inartificioso",
    "inartificiosas": "inartificioso",
    "inartificiosos": "inartificioso",
    "inartística": "inartístico",
    "inartísticas": "inartístico",
    "inartísticos": "inartístico",
    "inascíveis": "inascível",
    "inaspiráveis": "inaspirável",
    "inassiduidades": "inassiduidade",
    "inassimiláveis": "inassimilável",
    "inassinaláveis": "inassinalável",
    "inassináveis": "inassinável",
    "inassumíveis": "inassumível",
    "inata": "inato",
    "inatacabilidades": "inatacabilidade",
    "inatacada": "inatacado",
    "inatacadas": "inatacado",
    "inatacados": "inatacado",
    "inatacáveis": "inatacável",
    "inatas": "inato",
    "inatendíveis": "inatendível",
    "inatenuáveis": "inatenuável",
    "inatenções": "inatenção",
    "inatingíveis": "inatingível",
    "inatismos": "inatismo",
    "inatomizáveis": "inatomizável",
    "inatos": "inato",
    "inatraiçoáveis": "inatraiçoável",
    "inatravessáveis": "inatravessável",
    "inatraíveis": "inatraível",
    "inatreláveis": "inatrelável",
    "inatribuíveis": "inatribuível",
    "inaturáveis": "inaturável",
    "inaudita": "inaudito",
    "inauditas": "inaudito",
    "inauditos": "inaudito",
    "inaudíveis": "inaudível",
    "inauferíveis": "inauferível",
    "inaufragáveis": "inaufragável",
    "inaugura": "inaugurar",
    "inaugurada": "inaugurar",
    "inauguradas": "inaugurar",
    "inaugurado": "inaugurar",
    "inauguradora": "inaugurador",
    "inauguradoras": "inaugurador",
    "inauguradores": "inaugurador",
    "inaugurados": "inaugurar",
    "inaugurai": "inaugurar",
    "inaugurais": "inaugurar",
    "inauguram": "inaugurar",
    "inauguramo": "inaugurar",
    "inauguramos": "inaugurar",
    "inaugurando": "inaugurar",
    "inaugurara": "inaugurar",
    "inauguraram": "inaugurar",
    "inauguraras": "inaugurar",
    "inaugurarde": "inaugurar",
    "inaugurardes": "inaugurar",
    "inaugurare": "inaugurar",
    "inaugurarei": "inaugurar",
    "inaugurareis": "inaugurar",
    "inaugurarem": "inaugurar",
    "inauguraremos": "inaugurar",
    "inaugurares": "inaugurar",
    "inauguraria": "inaugurar",
    "inaugurariam": "inaugurar",
    "inaugurarias": "inaugurar",
    "inaugurarmo": "inaugurar",
    "inaugurarmos": "inaugurar",
    "inaugurará": "inaugurar",
    "inaugurarás": "inaugurar",
    "inaugurarão": "inaugurar",
    "inauguraríamos": "inaugurar",
    "inauguraríeis": "inaugurar",
    "inauguras": "inaugurar",
    "inaugurasse": "inaugurar",
    "inaugurassem": "inaugurar",
    "inaugurasses": "inaugurar",
    "inauguraste": "inaugurar",
    "inaugurastes": "inaugurar",
    "inaugurava": "inaugurar",
    "inauguravam": "inaugurar",
    "inauguravas": "inaugurar",
    "inaugurações": "inauguração",
    "inaugure": "inaugurar",
    "inaugurei": "inaugurar",
    "inaugureis": "inaugurar",
    "inaugurem": "inaugurar",
    "inauguremo": "inaugurar",
    "inauguremos": "inaugurar",
    "inaugures": "inaugurar",
    "inauguro": "inaugurar",
    "inaugurou": "inaugurar",
    "inaugurá": "inaugurar",
    "inaugurámo": "inaugurar",
    "inaugurámos": "inaugurar",
    "inauguráramo": "inaugurar",
    "inauguráramos": "inaugurar",
    "inaugurárei": "inaugurar",
    "inauguráreis": "inaugurar",
    "inaugurásseis": "inaugurar",
    "inaugurássemos": "inaugurar",
    "inaugurávamo": "inaugurar",
    "inaugurávamos": "inaugurar",
    "inaugurávei": "inaugurar",
    "inauguráveis": "inaugurável",
    "inaumentáveis": "inaumentável",
    "inautenticidades": "inautenticidade",
    "inautentificáveis": "inautentificável",
    "inautêntica": "inautêntico",
    "inautênticas": "inautêntico",
    "inautênticos": "inautêntico",
    "inavalizáveis": "inavalizável",
    "inavaliáveis": "inavaliável",
    "inavegabilidades": "inavegabilidade",
    "inavegáveis": "inavegável",
    "inaveriguáveis": "inaveriguável",
    "inavistáveis": "inavistável",
    "inazotáveis": "inazotável",
    "incalafetáveis": "incalafetável",
    "incalcináveis": "incalcinável",
    "incalculada": "incalculado",
    "incalculadas": "incalculado",
    "incalculados": "incalculado",
    "incalculáveis": "incalculável",
    "incalibráveis": "incalibrável",
    "incaláveis": "incalável",
    "incambiáveis": "incambiável",
    "incamera": "incamerar",
    "incamerada": "incamerar",
    "incameradas": "incamerar",
    "incamerado": "incamerar",
    "incamerados": "incamerar",
    "incamerai": "incamerar",
    "incamerais": "incamerar",
    "incameram": "incamerar",
    "incameramo": "incamerar",
    "incameramos": "incamerar",
    "incamerando": "incamerar",
    "incamerara": "incamerar",
    "incameraram": "incamerar",
    "incameraras": "incamerar",
    "incamerarde": "incamerar",
    "incamerardes": "incamerar",
    "incamerare": "incamerar",
    "incamerarei": "incamerar",
    "incamerareis": "incamerar",
    "incamerarem": "incamerar",
    "incameraremos": "incamerar",
    "incamerares": "incamerar",
    "incameraria": "incamerar",
    "incamerariam": "incamerar",
    "incamerarias": "incamerar",
    "incamerarmo": "incamerar",
    "incamerarmos": "incamerar",
    "incamerará": "incamerar",
    "incamerarás": "incamerar",
    "incamerarão": "incamerar",
    "incameraríamos": "incamerar",
    "incameraríeis": "incamerar",
    "incameras": "incamerar",
    "incamerasse": "incamerar",
    "incamerassem": "incamerar",
    "incamerasses": "incamerar",
    "incameraste": "incamerar",
    "incamerastes": "incamerar",
    "incamerava": "incamerar",
    "incameravam": "incamerar",
    "incameravas": "incamerar",
    "incamerações": "incameração",
    "incamere": "incamerar",
    "incamerei": "incamerar",
    "incamereis": "incamerar",
    "incamerem": "incamerar",
    "incameremo": "incamerar",
    "incameremos": "incamerar",
    "incameres": "incamerar",
    "incamero": "incamerar",
    "incamerou": "incamerar",
    "incamerá": "incamerar",
    "incamerámo": "incamerar",
    "incamerámos": "incamerar",
    "incameráramo": "incamerar",
    "incameráramos": "incamerar",
    "incamerárei": "incamerar",
    "incameráreis": "incamerar",
    "incamerásseis": "incamerar",
    "incamerássemos": "incamerar",
    "incamerávamo": "incamerar",
    "incamerávamos": "incamerar",
    "incamerávei": "incamerar",
    "incameráveis": "incamerar",
    "incanceláveis": "incancelável",
    "incandesce": "incandescer",
    "incandescei": "incandescer",
    "incandesceis": "incandescer",
    "incandescem": "incandescer",
    "incandescemo": "incandescer",
    "incandescemos": "incandescer",
    "incandescendo": "incandescer",
    "incandescentes": "incandescente",
    "incandescera": "incandescer",
    "incandesceram": "incandescer",
    "incandesceras": "incandescer",
    "incandescerdes": "incandescer",
    "incandescerei": "incandescer",
    "incandescereis": "incandescer",
    "incandescerem": "incandescer",
    "incandesceremos": "incandescer",
    "incandesceres": "incandescer",
    "incandesceria": "incandescer",
    "incandesceriam": "incandescer",
    "incandescerias": "incandescer",
    "incandescermo": "incandescer",
    "incandescermos": "incandescer",
    "incandescerá": "incandescer",
    "incandescerás": "incandescer",
    "incandescerão": "incandescer",
    "incandesceríamos": "incandescer",
    "incandesceríeis": "incandescer",
    "incandesces": "incandescer",
    "incandescesse": "incandescer",
    "incandescessem": "incandescer",
    "incandescesses": "incandescer",
    "incandesceste": "incandescer",
    "incandescestes": "incandescer",
    "incandesceu": "incandescer",
    "incandesci": "incandescer",
    "incandescia": "incandescer",
    "incandesciam": "incandescer",
    "incandescias": "incandescer",
    "incandescida": "incandescer",
    "incandescidas": "incandescer",
    "incandescido": "incandescer",
    "incandescidos": "incandescer",
    "incandescências": "incandescência",
    "incandescêramo": "incandescer",
    "incandescêramos": "incandescer",
    "incandescêreis": "incandescer",
    "incandescêsseis": "incandescer",
    "incandescêssemos": "incandescer",
    "incandescíamo": "incandescer",
    "incandescíamos": "incandescer",
    "incandescíeis": "incandescer",
    "incandescíveis": "incandescível",
    "incandesça": "incandescer",
    "incandesçais": "incandescer",
    "incandesçam": "incandescer",
    "incandesçamo": "incandescer",
    "incandesçamos": "incandescer",
    "incandesças": "incandescer",
    "incandesço": "incandescer",
    "incansabilidades": "incansabilidade",
    "incansáveis": "incansável",
    "incapacidades": "incapacidade",
    "incapacita": "incapacitar",
    "incapacitada": "incapacitar",
    "incapacitadas": "incapacitar",
    "incapacitado": "incapacitar",
    "incapacitados": "incapacitar",
    "incapacitai": "incapacitar",
    "incapacitais": "incapacitar",
    "incapacitam": "incapacitar",
    "incapacitamo": "incapacitar",
    "incapacitamos": "incapacitar",
    "incapacitando": "incapacitar",
    "incapacitara": "incapacitar",
    "incapacitaram": "incapacitar",
    "incapacitaras": "incapacitar",
    "incapacitarde": "incapacitar",
    "incapacitardes": "incapacitar",
    "incapacitare": "incapacitar",
    "incapacitarei": "incapacitar",
    "incapacitareis": "incapacitar",
    "incapacitarem": "incapacitar",
    "incapacitaremos": "incapacitar",
    "incapacitares": "incapacitar",
    "incapacitaria": "incapacitar",
    "incapacitariam": "incapacitar",
    "incapacitarias": "incapacitar",
    "incapacitarmo": "incapacitar",
    "incapacitarmos": "incapacitar",
    "incapacitará": "incapacitar",
    "incapacitarás": "incapacitar",
    "incapacitarão": "incapacitar",
    "incapacitaríamos": "incapacitar",
    "incapacitaríeis": "incapacitar",
    "incapacitas": "incapacitar",
    "incapacitasse": "incapacitar",
    "incapacitassem": "incapacitar",
    "incapacitasses": "incapacitar",
    "incapacitaste": "incapacitar",
    "incapacitastes": "incapacitar",
    "incapacitava": "incapacitar",
    "incapacitavam": "incapacitar",
    "incapacitavas": "incapacitar",
    "incapacitações": "incapacitação",
    "incapacite": "incapacitar",
    "incapacitei": "incapacitar",
    "incapaciteis": "incapacitar",
    "incapacitem": "incapacitar",
    "incapacitemo": "incapacitar",
    "incapacitemos": "incapacitar",
    "incapacites": "incapacitar",
    "incapacito": "incapacitar",
    "incapacitou": "incapacitar",
    "incapacitá": "incapacitar",
    "incapacitámo": "incapacitar",
    "incapacitámos": "incapacitar",
    "incapacitáramo": "incapacitar",
    "incapacitáramos": "incapacitar",
    "incapacitárei": "incapacitar",
    "incapacitáreis": "incapacitar",
    "incapacitásseis": "incapacitar",
    "incapacitássemos": "incapacitar",
    "incapacitávamo": "incapacitar",
    "incapacitávamos": "incapacitar",
    "incapacitávei": "incapacitar",
    "incapacitáveis": "incapacitável",
    "incapazes": "incapaz",
    "incapturada": "incapturado",
    "incapturadas": "incapturado",
    "incapturados": "incapturado",
    "incaptáveis": "incaptável",
    "incaracterística": "incaracterístico",
    "incaracterísticas": "incaracterístico",
    "incaracterísticos": "incaracterístico",
    "incardina": "incardinar",
    "incardinada": "incardinar",
    "incardinadas": "incardinar",
    "incardinado": "incardinar",
    "incardinados": "incardinar",
    "incardinai": "incardinar",
    "incardinais": "incardinar",
    "incardinam": "incardinar",
    "incardinamo": "incardinar",
    "incardinamos": "incardinar",
    "incardinando": "incardinar",
    "incardinara": "incardinar",
    "incardinaram": "incardinar",
    "incardinaras": "incardinar",
    "incardinardes": "incardinar",
    "incardinarei": "incardinar",
    "incardinareis": "incardinar",
    "incardinarem": "incardinar",
    "incardinaremos": "incardinar",
    "incardinares": "incardinar",
    "incardinaria": "incardinar",
    "incardinariam": "incardinar",
    "incardinarias": "incardinar",
    "incardinarmo": "incardinar",
    "incardinarmos": "incardinar",
    "incardinará": "incardinar",
    "incardinarás": "incardinar",
    "incardinarão": "incardinar",
    "incardinaríamos": "incardinar",
    "incardinaríeis": "incardinar",
    "incardinas": "incardinar",
    "incardinasse": "incardinar",
    "incardinassem": "incardinar",
    "incardinasses": "incardinar",
    "incardinaste": "incardinar",
    "incardinastes": "incardinar",
    "incardinava": "incardinar",
    "incardinavam": "incardinar",
    "incardinavas": "incardinar",
    "incardinações": "incardinação",
    "incardine": "incardinar",
    "incardinei": "incardinar",
    "incardineis": "incardinar",
    "incardinem": "incardinar",
    "incardinemo": "incardinar",
    "incardinemos": "incardinar",
    "incardines": "incardinar",
    "incardino": "incardinar",
    "incardinou": "incardinar",
    "incardinámo": "incardinar",
    "incardinámos": "incardinar",
    "incardináramo": "incardinar",
    "incardináramos": "incardinar",
    "incardináreis": "incardinar",
    "incardinásseis": "incardinar",
    "incardinássemos": "incardinar",
    "incardinávamo": "incardinar",
    "incardinávamos": "incardinar",
    "incardináveis": "incardinável",
    "incarna": "incarnar",
    "incarnada": "incarnar",
    "incarnadas": "incarnar",
    "incarnado": "incarnar",
    "incarnados": "incarnar",
    "incarnai": "incarnar",
    "incarnais": "incarnar",
    "incarnam": "incarnar",
    "incarnamo": "incarnar",
    "incarnamos": "incarnar",
    "incarnando": "incarnar",
    "incarnara": "incarnar",
    "incarnaram": "incarnar",
    "incarnaras": "incarnar",
    "incarnarde": "incarnar",
    "incarnardes": "incarnar",
    "incarnare": "incarnar",
    "incarnarei": "incarnar",
    "incarnareis": "incarnar",
    "incarnarem": "incarnar",
    "incarnaremos": "incarnar",
    "incarnares": "incarnar",
    "incarnaria": "incarnar",
    "incarnariam": "incarnar",
    "incarnarias": "incarnar",
    "incarnarmo": "incarnar",
    "incarnarmos": "incarnar",
    "incarnará": "incarnar",
    "incarnarás": "incarnar",
    "incarnarão": "incarnar",
    "incarnaríamos": "incarnar",
    "incarnaríeis": "incarnar",
    "incarnas": "incarnar",
    "incarnasse": "incarnar",
    "incarnassem": "incarnar",
    "incarnasses": "incarnar",
    "incarnaste": "incarnar",
    "incarnastes": "incarnar",
    "incarnava": "incarnar",
    "incarnavam": "incarnar",
    "incarnavas": "incarnar",
    "incarnações": "incarnação",
    "incarne": "incarnar",
    "incarnei": "incarnar",
    "incarneis": "incarnar",
    "incarnem": "incarnar",
    "incarnemo": "incarnar",
    "incarnemos": "incarnar",
    "incarnes": "incarnar",
    "incarno": "incarnar",
    "incarnou": "incarnar",
    "incarná": "incarnar",
    "incarnámo": "incarnar",
    "incarnámos": "incarnar",
    "incarnáramo": "incarnar",
    "incarnáramos": "incarnar",
    "incarnárei": "incarnar",
    "incarnáreis": "incarnar",
    "incarnásseis": "incarnar",
    "incarnássemos": "incarnar",
    "incarnávamo": "incarnar",
    "incarnávamos": "incarnar",
    "incarnávei": "incarnar",
    "incarnáveis": "incarnar",
    "incas": "inca",
    "incasta": "incasto",
    "incastas": "incasto",
    "incastos": "incasto",
    "incauta": "incauto",
    "incautas": "incauto",
    "incautos": "incauto",
    "ince": "inçar",
    "incei": "inçar",
    "inceis": "inçar",
    "incem": "inçar",
    "incemo": "inçar",
    "incemos": "inçar",
    "incenda": "incender",
    "incendais": "incender",
    "incendam": "incender",
    "incendamo": "incender",
    "incendamos": "incender",
    "incendas": "incender",
    "incende": "incender",
    "incendei": "incender",
    "incendeia": "incendiar",
    "incendeiam": "incendiar",
    "incendeias": "incendiar",
    "incendeie": "incendiar",
    "incendeiem": "incendiar",
    "incendeies": "incendiar",
    "incendeio": "incendiar",
    "incendeis": "incender",
    "incendem": "incender",
    "incendemo": "incender",
    "incendemos": "incender",
    "incendendo": "incender",
    "incendera": "incender",
    "incenderam": "incender",
    "incenderas": "incender",
    "incenderde": "incender",
    "incenderdes": "incender",
    "incendere": "incender",
    "incenderei": "incender",
    "incendereis": "incender",
    "incenderem": "incender",
    "incenderemos": "incender",
    "incenderes": "incender",
    "incenderia": "incender",
    "incenderiam": "incender",
    "incenderias": "incender",
    "incendermo": "incender",
    "incendermos": "incender",
    "incenderá": "incender",
    "incenderás": "incender",
    "incenderão": "incender",
    "incenderíamos": "incender",
    "incenderíeis": "incender",
    "incendes": "incender",
    "incendesse": "incender",
    "incendessem": "incender",
    "incendesses": "incender",
    "incendeste": "incender",
    "incendestes": "incender",
    "incendeu": "incender",
    "incendi": "incender",
    "incendia": "incender",
    "incendiada": "incendiar",
    "incendiadas": "incendiar",
    "incendiado": "incendiar",
    "incendiados": "incendiar",
    "incendiai": "incendiar",
    "incendiais": "incendiar",
    "incendiam": "incender",
    "incendiamo": "incendiar",
    "incendiamos": "incendiar",
    "incendiando": "incendiar",
    "incendiara": "incendiar",
    "incendiaram": "incendiar",
    "incendiaras": "incendiar",
    "incendiarde": "incendiar",
    "incendiardes": "incendiar",
    "incendiare": "incendiar",
    "incendiarei": "incendiar",
    "incendiareis": "incendiar",
    "incendiarem": "incendiar",
    "incendiaremos": "incendiar",
    "incendiares": "incendiar",
    "incendiaria": "incendiar",
    "incendiariam": "incendiar",
    "incendiarias": "incendiar",
    "incendiarmo": "incendiar",
    "incendiarmos": "incendiar",
    "incendiará": "incendiar",
    "incendiarás": "incendiar",
    "incendiarão": "incendiar",
    "incendiaríamos": "incendiar",
    "incendiaríeis": "incendiar",
    "incendias": "incender",
    "incendiasse": "incendiar",
    "incendiassem": "incendiar",
    "incendiasses": "incendiar",
    "incendiaste": "incendiar",
    "incendiastes": "incendiar",
    "incendiava": "incendiar",
    "incendiavam": "incendiar",
    "incendiavas": "incendiar",
    "incendida": "incendido",
    "incendidas": "incendido",
    "incendido": "incender",
    "incendidos": "incendido",
    "incendiei": "incendiar",
    "incendieis": "incendiar",
    "incendiemo": "incendiar",
    "incendiemos": "incendiar",
    "incendimentos": "incendimento",
    "incendiou": "incendiar",
    "incendiá": "incendiar",
    "incendiámo": "incendiar",
    "incendiámos": "incendiar",
    "incendiáramo": "incendiar",
    "incendiáramos": "incendiar",
    "incendiárei": "incendiar",
    "incendiáreis": "incendiar",
    "incendiária": "incendiário",
    "incendiárias": "incendiário",
    "incendiários": "incendiário",
    "incendiásseis": "incendiar",
    "incendiássemos": "incendiar",
    "incendiávamo": "incendiar",
    "incendiávamos": "incendiar",
    "incendiávei": "incendiar",
    "incendiáveis": "incendiável",
    "incendo": "incender",
    "incendê": "incender",
    "incendêramo": "incender",
    "incendêramos": "incender",
    "incendêrei": "incender",
    "incendêreis": "incender",
    "incendêsseis": "incender",
    "incendêssemos": "incender",
    "incendíamo": "incender",
    "incendíamos": "incender",
    "incendíei": "incender",
    "incendíeis": "incender",
    "incensa": "incensar",
    "incensada": "incensar",
    "incensadas": "incensar",
    "incensado": "incensar",
    "incensadora": "incensador",
    "incensadoras": "incensador",
    "incensadores": "incensador",
    "incensados": "incensar",
    "incensai": "incensar",
    "incensais": "incensar",
    "incensam": "incensar",
    "incensamo": "incensar",
    "incensamos": "incensar",
    "incensando": "incensar",
    "incensara": "incensar",
    "incensaram": "incensar",
    "incensaras": "incensar",
    "incensarde": "incensar",
    "incensardes": "incensar",
    "incensare": "incensar",
    "incensarei": "incensar",
    "incensareis": "incensar",
    "incensarem": "incensar",
    "incensaremos": "incensar",
    "incensares": "incensar",
    "incensaria": "incensar",
    "incensariam": "incensar",
    "incensarias": "incensar",
    "incensarmo": "incensar",
    "incensarmos": "incensar",
    "incensará": "incensar",
    "incensarás": "incensar",
    "incensarão": "incensar",
    "incensaríamos": "incensar",
    "incensaríeis": "incensar",
    "incensas": "incensar",
    "incensasse": "incensar",
    "incensassem": "incensar",
    "incensasses": "incensar",
    "incensaste": "incensar",
    "incensastes": "incensar",
    "incensava": "incensar",
    "incensavam": "incensar",
    "incensavas": "incensar",
    "incensações": "incensação",
    "incense": "incensar",
    "incensei": "incensar",
    "incenseis": "incensar",
    "incensem": "incensar",
    "incensemo": "incensar",
    "incensemos": "incensar",
    "incenses": "incensar",
    "incenso": "incensar",
    "incensos": "incenso",
    "incensou": "incensar",
    "incensuráveis": "incensurável",
    "incensá": "incensar",
    "incensámo": "incensar",
    "incensámos": "incensar",
    "incensáramo": "incensar",
    "incensáramos": "incensar",
    "incensárei": "incensar",
    "incensáreis": "incensar",
    "incensários": "incensário",
    "incensásseis": "incensar",
    "incensássemos": "incensar",
    "incensávamo": "incensar",
    "incensávamos": "incensar",
    "incensávei": "incensar",
    "incensáveis": "incensar",
    "incensórios": "incensório",
    "incentiva": "incentivo",
    "incentivada": "incentivar",
    "incentivadas": "incentivar",
    "incentivado": "incentivar",
    "incentivadora": "incentivador",
    "incentivadoras": "incentivador",
    "incentivadores": "incentivador",
    "incentivados": "incentivar",
    "incentivai": "incentivar",
    "incentivais": "incentivar",
    "incentivam": "incentivar",
    "incentivamo": "incentivar",
    "incentivamos": "incentivar",
    "incentivando": "incentivar",
    "incentivara": "incentivar",
    "incentivaram": "incentivar",
    "incentivaras": "incentivar",
    "incentivarde": "incentivar",
    "incentivardes": "incentivar",
    "incentivare": "incentivar",
    "incentivarei": "incentivar",
    "incentivareis": "incentivar",
    "incentivarem": "incentivar",
    "incentivaremos": "incentivar",
    "incentivares": "incentivar",
    "incentivaria": "incentivar",
    "incentivariam": "incentivar",
    "incentivarias": "incentivar",
    "incentivarmo": "incentivar",
    "incentivarmos": "incentivar",
    "incentivará": "incentivar",
    "incentivarás": "incentivar",
    "incentivarão": "incentivar",
    "incentivaríamos": "incentivar",
    "incentivaríeis": "incentivar",
    "incentivas": "incentivo",
    "incentivasse": "incentivar",
    "incentivassem": "incentivar",
    "incentivasses": "incentivar",
    "incentivaste": "incentivar",
    "incentivastes": "incentivar",
    "incentivava": "incentivar",
    "incentivavam": "incentivar",
    "incentivavas": "incentivar",
    "incentive": "incentivar",
    "incentivei": "incentivar",
    "incentiveis": "incentivar",
    "incentivem": "incentivar",
    "incentivemo": "incentivar",
    "incentivemos": "incentivar",
    "incentives": "incentivar",
    "incentivo": "incentivar",
    "incentivos": "incentivo",
    "incentivou": "incentivar",
    "incentivá": "incentivar",
    "incentivámo": "incentivar",
    "incentivámos": "incentivar",
    "incentiváramo": "incentivar",
    "incentiváramos": "incentivar",
    "incentivárei": "incentivar",
    "incentiváreis": "incentivar",
    "incentivásseis": "incentivar",
    "incentivássemos": "incentivar",
    "incentivávamo": "incentivar",
    "incentivávamos": "incentivar",
    "incentivávei": "incentivar",
    "incentiváveis": "incentivável",
    "incentora": "incentor",
    "incentoras": "incentor",
    "incentores": "incentor",
    "incentros": "incentro",
    "incerimoniosa": "incerimonioso",
    "incerimoniosas": "incerimonioso",
    "incerimoniosos": "incerimonioso",
    "incernes": "incerne",
    "incerta": "incerto",
    "incertas": "incerto",
    "incertezas": "incerteza",
    "incertos": "incerto",
    "inces": "inçar",
    "incessantes": "incessante",
    "incessibilidades": "incessibilidade",
    "incessáveis": "incessável",
    "incessíveis": "incessível",
    "incesta": "incestar",
    "incestada": "incestar",
    "incestadas": "incestar",
    "incestado": "incestar",
    "incestados": "incestar",
    "incestai": "incestar",
    "incestais": "incestar",
    "incestam": "incestar",
    "incestamo": "incestar",
    "incestamos": "incestar",
    "incestando": "incestar",
    "incestara": "incestar",
    "incestaram": "incestar",
    "incestaras": "incestar",
    "incestarde": "incestar",
    "incestardes": "incestar",
    "incestare": "incestar",
    "incestarei": "incestar",
    "incestareis": "incestar",
    "incestarem": "incestar",
    "incestaremos": "incestar",
    "incestares": "incestar",
    "incestaria": "incestar",
    "incestariam": "incestar",
    "incestarias": "incestar",
    "incestarmo": "incestar",
    "incestarmos": "incestar",
    "incestará": "incestar",
    "incestarás": "incestar",
    "incestarão": "incestar",
    "incestaríamos": "incestar",
    "incestaríeis": "incestar",
    "incestas": "incestar",
    "incestasse": "incestar",
    "incestassem": "incestar",
    "incestasses": "incestar",
    "incestaste": "incestar",
    "incestastes": "incestar",
    "incestava": "incestar",
    "incestavam": "incestar",
    "incestavas": "incestar",
    "inceste": "incestar",
    "incestei": "incestar",
    "incesteis": "incestar",
    "incestem": "incestar",
    "incestemo": "incestar",
    "incestemos": "incestar",
    "incestes": "incestar",
    "incesto": "incestar",
    "incestos": "incesto",
    "incestou": "incestar",
    "incestuosa": "incestuoso",
    "incestuosas": "incestuoso",
    "incestuosos": "incestuoso",
    "incestá": "incestar",
    "incestámo": "incestar",
    "incestámos": "incestar",
    "incestáramo": "incestar",
    "incestáramos": "incestar",
    "incestárei": "incestar",
    "incestáreis": "incestar",
    "incestásseis": "incestar",
    "incestássemos": "incestar",
    "incestávamo": "incestar",
    "incestávamos": "incestar",
    "incestávei": "incestar",
    "incestáveis": "incestável",
    "incha": "inchar",
    "inchada": "inchar",
    "inchadas": "inchar",
    "inchado": "inchar",
    "inchados": "inchar",
    "inchaduras": "inchadura",
    "inchadíssima": "inchado",
    "inchadíssimas": "inchado",
    "inchadíssimo": "inchado",
    "inchadíssimos": "inchado",
    "inchai": "inchar",
    "inchais": "inchar",
    "incham": "inchar",
    "inchamentos": "inchamento",
    "inchamo": "inchar",
    "inchamos": "inchar",
    "inchando": "inchar",
    "inchara": "inchar",
    "incharam": "inchar",
    "incharas": "inchar",
    "incharde": "inchar",
    "inchardes": "inchar",
    "inchare": "inchar",
    "incharei": "inchar",
    "inchareis": "inchar",
    "incharem": "inchar",
    "incharemos": "inchar",
    "inchares": "inchar",
    "incharia": "inchar",
    "inchariam": "inchar",
    "incharias": "inchar",
    "incharmo": "inchar",
    "incharmos": "inchar",
    "inchará": "inchar",
    "incharás": "inchar",
    "incharão": "inchar",
    "incharíamos": "inchar",
    "incharíeis": "inchar",
    "inchas": "inchar",
    "inchasse": "inchar",
    "inchassem": "inchar",
    "inchasses": "inchar",
    "inchaste": "inchar",
    "inchastes": "inchar",
    "inchava": "inchar",
    "inchavam": "inchar",
    "inchavas": "inchar",
    "inchazinha": "incha",
    "inchazinhas": "incha",
    "inchazita": "incha",
    "inchazitas": "incha",
    "inchaços": "inchaço",
    "inchações": "inchação",
    "inche": "inchar",
    "inchei": "inchar",
    "incheis": "inchar",
    "inchem": "inchar",
    "inchemo": "inchar",
    "inchemos": "inchar",
    "inches": "inchar",
    "incho": "inchar",
    "inchou": "inchar",
    "inchá": "inchar",
    "inchámo": "inchar",
    "inchámos": "inchar",
    "incháramo": "inchar",
    "incháramos": "inchar",
    "inchárei": "inchar",
    "incháreis": "inchar",
    "inchásseis": "inchar",
    "inchássemos": "inchar",
    "inchávamo": "inchar",
    "inchávamos": "inchar",
    "inchávei": "inchar",
    "incháveis": "inchável",
    "incicatrizáveis": "incicatrizável",
    "incida": "incidir",
    "incidais": "incidir",
    "incidam": "incidir",
    "incidamo": "incidir",
    "incidamos": "incidir",
    "incidas": "incidir",
    "incide": "incidir",
    "incidem": "incidir",
    "incidentada": "incidentado",
    "incidentadas": "incidentado",
    "incidentados": "incidentado",
    "incidentais": "incidental",
    "incidentes": "incidente",
    "incides": "incidir",
    "incidi": "incidir",
    "incidia": "incidir",
    "incidiam": "incidir",
    "incidias": "incidir",
    "incidida": "incidir",
    "incididas": "incidir",
    "incidido": "incidir",
    "incididos": "incidir",
    "incidimo": "incidir",
    "incidimos": "incidir",
    "incidindo": "incidir",
    "incidira": "incidir",
    "incidiram": "incidir",
    "incidiras": "incidir",
    "incidirdes": "incidir",
    "incidirei": "incidir",
    "incidireis": "incidir",
    "incidirem": "incidir",
    "incidiremos": "incidir",
    "incidires": "incidir",
    "incidiria": "incidir",
    "incidiriam": "incidir",
    "incidirias": "incidir",
    "incidirmo": "incidir",
    "incidirmos": "incidir",
    "incidirá": "incidir",
    "incidirás": "incidir",
    "incidirão": "incidir",
    "incidiríamos": "incidir",
    "incidiríeis": "incidir",
    "incidis": "incidir",
    "incidisse": "incidir",
    "incidissem": "incidir",
    "incidisses": "incidir",
    "incidiste": "incidir",
    "incidistes": "incidir",
    "incidiu": "incidir",
    "incido": "incidir",
    "incidências": "incidência",
    "incidíamo": "incidir",
    "incidíamos": "incidir",
    "incidíeis": "incidir",
    "incidíramo": "incidir",
    "incidíramos": "incidir",
    "incidíreis": "incidir",
    "incidísseis": "incidir",
    "incidíssemos": "incidir",
    "incinera": "incinerar",
    "incinerada": "incinerar",
    "incineradas": "incinerar",
    "incinerado": "incinerar",
    "incineradora": "incinerador",
    "incineradoras": "incineradora",
    "incineradores": "incinerador",
    "incinerados": "incinerar",
    "incinerai": "incinerar",
    "incinerais": "incinerar",
    "incineram": "incinerar",
    "incineramo": "incinerar",
    "incineramos": "incinerar",
    "incinerando": "incinerar",
    "incinerara": "incinerar",
    "incineraram": "incinerar",
    "incineraras": "incinerar",
    "incinerarde": "incinerar",
    "incinerardes": "incinerar",
    "incinerare": "incinerar",
    "incinerarei": "incinerar",
    "incinerareis": "incinerar",
    "incinerarem": "incinerar",
    "incineraremos": "incinerar",
    "incinerares": "incinerar",
    "incineraria": "incinerar",
    "incinerariam": "incinerar",
    "incinerarias": "incinerar",
    "incinerarmo": "incinerar",
    "incinerarmos": "incinerar",
    "incinerará": "incinerar",
    "incinerarás": "incinerar",
    "incinerarão": "incinerar",
    "incineraríamos": "incinerar",
    "incineraríeis": "incinerar",
    "incineras": "incinerar",
    "incinerasse": "incinerar",
    "incinerassem": "incinerar",
    "incinerasses": "incinerar",
    "incineraste": "incinerar",
    "incinerastes": "incinerar",
    "incinerava": "incinerar",
    "incineravam": "incinerar",
    "incineravas": "incinerar",
    "incinerações": "incineração",
    "incinere": "incinerar",
    "incinerei": "incinerar",
    "incinereis": "incinerar",
    "incinerem": "incinerar",
    "incineremo": "incinerar",
    "incineremos": "incinerar",
    "incineres": "incinerar",
    "incinerizações": "incinerização",
    "incinero": "incinerar",
    "incinerou": "incinerar",
    "incinerá": "incinerar",
    "incinerámo": "incinerar",
    "incinerámos": "incinerar",
    "incineráramo": "incinerar",
    "incineráramos": "incinerar",
    "incinerárei": "incinerar",
    "incineráreis": "incinerar",
    "incinerásseis": "incinerar",
    "incinerássemos": "incinerar",
    "incinerávamo": "incinerar",
    "incinerávamos": "incinerar",
    "incinerávei": "incinerar",
    "incineráveis": "incinerável",
    "incipientes": "incipiente",
    "incipiências": "incipiência",
    "incircuncidada": "incircuncidado",
    "incircuncidadas": "incircuncidado",
    "incircuncidados": "incircuncidado",
    "incircuncisa": "incircunciso",
    "incircuncisas": "incircunciso",
    "incircuncisos": "incircunciso",
    "incircuncisões": "incircuncisão",
    "incircunscritíveis": "incircunscritível",
    "incisa": "inciso",
    "incisada": "incisar",
    "incisadas": "incisar",
    "incisado": "incisar",
    "incisadores": "incisador",
    "incisados": "incisar",
    "incisai": "incisar",
    "incisais": "incisar",
    "incisam": "incisar",
    "incisamo": "incisar",
    "incisamos": "incisar",
    "incisando": "incisar",
    "incisara": "incisar",
    "incisaram": "incisar",
    "incisaras": "incisar",
    "incisarde": "incisar",
    "incisardes": "incisar",
    "incisare": "incisar",
    "incisarei": "incisar",
    "incisareis": "incisar",
    "incisarem": "incisar",
    "incisaremos": "incisar",
    "incisares": "incisar",
    "incisaria": "incisar",
    "incisariam": "incisar",
    "incisarias": "incisar",
    "incisarmo": "incisar",
    "incisarmos": "incisar",
    "incisará": "incisar",
    "incisarás": "incisar",
    "incisarão": "incisar",
    "incisaríamos": "incisar",
    "incisaríeis": "incisar",
    "incisas": "inciso",
    "incisasse": "incisar",
    "incisassem": "incisar",
    "incisasses": "incisar",
    "incisaste": "incisar",
    "incisastes": "incisar",
    "incisava": "incisar",
    "incisavam": "incisar",
    "incisavas": "incisar",
    "incise": "incisar",
    "incisei": "incisar",
    "inciseis": "incisar",
    "incisem": "incisar",
    "incisemo": "incisar",
    "incisemos": "incisar",
    "incises": "incisar",
    "incisiva": "incisivo",
    "incisivas": "incisivo",
    "incisividades": "incisividade",
    "incisivos": "incisivo",
    "inciso": "incisar",
    "incisora": "incisor",
    "incisoras": "incisor",
    "incisores": "incisor",
    "incisos": "inciso",
    "incisou": "incisar",
    "incisuras": "incisura",
    "incisá": "incisar",
    "incisámo": "incisar",
    "incisámos": "incisar",
    "incisáramo": "incisar",
    "incisáramos": "incisar",
    "incisárei": "incisar",
    "incisáreis": "incisar",
    "incisásseis": "incisar",
    "incisássemos": "incisar",
    "incisávamo": "incisar",
    "incisávamos": "incisar",
    "incisávei": "incisar",
    "incisáveis": "incisar",
    "incisória": "incisório",
    "incisórias": "incisório",
    "incisórios": "incisório",
    "incisões": "incisão",
    "incita": "incitar",
    "incitabilidades": "incitabilidade",
    "incitada": "incitar",
    "incitadas": "incitar",
    "incitado": "incitar",
    "incitadora": "incitador",
    "incitadoras": "incitador",
    "incitadores": "incitador",
    "incitados": "incitar",
    "incitai": "incitar",
    "incitais": "incitar",
    "incitam": "incitar",
    "incitamentos": "incitamento",
    "incitamo": "incitar",
    "incitamos": "incitar",
    "incitando": "incitar",
    "incitantes": "incitante",
    "incitara": "incitar",
    "incitaram": "incitar",
    "incitaras": "incitar",
    "incitarde": "incitar",
    "incitardes": "incitar",
    "incitare": "incitar",
    "incitarei": "incitar",
    "incitareis": "incitar",
    "incitarem": "incitar",
    "incitaremos": "incitar",
    "incitares": "incitar",
    "incitaria": "incitar",
    "incitariam": "incitar",
    "incitarias": "incitar",
    "incitarmo": "incitar",
    "incitarmos": "incitar",
    "incitará": "incitar",
    "incitarás": "incitar",
    "incitarão": "incitar",
    "incitaríamos": "incitar",
    "incitaríeis": "incitar",
    "incitas": "incitar",
    "incitasse": "incitar",
    "incitassem": "incitar",
    "incitasses": "incitar",
    "incitaste": "incitar",
    "incitastes": "incitar",
    "incitativa": "incitativo",
    "incitativas": "incitativo",
    "incitativos": "incitativo",
    "incitava": "incitar",
    "incitavam": "incitar",
    "incitavas": "incitar",
    "incitações": "incitação",
    "incite": "incitar",
    "incitei": "incitar",
    "inciteis": "incitar",
    "incitem": "incitar",
    "incitemo": "incitar",
    "incitemos": "incitar",
    "incites": "incitar",
    "incito": "incitar",
    "incitou": "incitar",
    "incitá": "incitar",
    "incitámo": "incitar",
    "incitámos": "incitar",
    "incitáramo": "incitar",
    "incitáramos": "incitar",
    "incitárei": "incitar",
    "incitáreis": "incitar",
    "incitásseis": "incitar",
    "incitássemos": "incitar",
    "incitávamo": "incitar",
    "incitávamos": "incitar",
    "incitávei": "incitar",
    "incitáveis": "incitável",
    "incivilidades": "incivilidade",
    "incivilizada": "incivilizado",
    "incivilizadas": "incivilizado",
    "incivilizados": "incivilizado",
    "incivilizáveis": "incivilizável",
    "incivis": "incivil",
    "incivismos": "incivismo",
    "inclarificáveis": "inclarificável",
    "inclassificada": "inclassificado",
    "inclassificadas": "inclassificado",
    "inclassificados": "inclassificado",
    "inclassificáveis": "inclassificável",
    "inclementes": "inclemente",
    "inclemências": "inclemência",
    "inclina": "inclinar",
    "inclinada": "inclinar",
    "inclinadas": "inclinar",
    "inclinado": "inclinar",
    "inclinados": "inclinar",
    "inclinadíssima": "inclinado",
    "inclinadíssimas": "inclinado",
    "inclinadíssimo": "inclinado",
    "inclinadíssimos": "inclinado",
    "inclinai": "inclinar",
    "inclinais": "inclinar",
    "inclinam": "inclinar",
    "inclinamo": "inclinar",
    "inclinamos": "inclinar",
    "inclinando": "inclinar",
    "inclinara": "inclinar",
    "inclinaram": "inclinar",
    "inclinaras": "inclinar",
    "inclinarde": "inclinar",
    "inclinardes": "inclinar",
    "inclinare": "inclinar",
    "inclinarei": "inclinar",
    "inclinareis": "inclinar",
    "inclinarem": "inclinar",
    "inclinaremos": "inclinar",
    "inclinares": "inclinar",
    "inclinaria": "inclinar",
    "inclinariam": "inclinar",
    "inclinarias": "inclinar",
    "inclinarmo": "inclinar",
    "inclinarmos": "inclinar",
    "inclinará": "inclinar",
    "inclinarás": "inclinar",
    "inclinarão": "inclinar",
    "inclinaríamos": "inclinar",
    "inclinaríeis": "inclinar",
    "inclinas": "inclinar",
    "inclinasse": "inclinar",
    "inclinassem": "inclinar",
    "inclinasses": "inclinar",
    "inclinaste": "inclinar",
    "inclinastes": "inclinar",
    "inclinava": "inclinar",
    "inclinavam": "inclinar",
    "inclinavas": "inclinar",
    "inclinações": "inclinação",
    "incline": "inclinar",
    "inclinei": "inclinar",
    "inclineis": "inclinar",
    "inclinem": "inclinar",
    "inclinemo": "inclinar",
    "inclinemos": "inclinar",
    "inclines": "inclinar",
    "inclino": "inclinar",
    "inclinou": "inclinar",
    "incliná": "inclinar",
    "inclinámo": "inclinar",
    "inclinámos": "inclinar",
    "inclináramo": "inclinar",
    "inclináramos": "inclinar",
    "inclinárei": "inclinar",
    "inclináreis": "inclinar",
    "inclinásseis": "inclinar",
    "inclinássemos": "inclinar",
    "inclinávamo": "inclinar",
    "inclinávamos": "inclinar",
    "inclinávei": "inclinar",
    "inclináveis": "inclinável",
    "inclinómetros": "inclinómetro",
    "inclua": "incluir",
    "incluais": "incluir",
    "incluam": "incluir",
    "incluamo": "incluir",
    "incluamos": "incluir",
    "incluas": "incluir",
    "incluem": "incluir",
    "inclui": "incluir",
    "incluindo": "incluir",
    "incluirde": "incluir",
    "incluirdes": "incluir",
    "incluirei": "incluir",
    "incluireis": "incluir",
    "incluiremos": "incluir",
    "incluiria": "incluir",
    "incluiriam": "incluir",
    "incluirias": "incluir",
    "incluirmo": "incluir",
    "incluirmos": "incluir",
    "incluirá": "incluir",
    "incluirás": "incluir",
    "incluirão": "incluir",
    "incluiríamos": "incluir",
    "incluiríeis": "incluir",
    "incluis": "incluir",
    "incluiu": "incluir",
    "incluo": "incluir",
    "inclusa": "incluso",
    "inclusas": "incluso",
    "inclusiva": "inclusivo",
    "inclusivas": "inclusivo",
    "inclusivos": "inclusivo",
    "inclusos": "incluso",
    "inclusões": "inclusão",
    "incluí": "incluir",
    "incluía": "incluir",
    "incluíam": "incluir",
    "incluíamo": "incluir",
    "incluíamos": "incluir",
    "incluías": "incluir",
    "incluída": "incluir",
    "incluídas": "incluir",
    "incluído": "incluir",
    "incluídos": "incluir",
    "incluíei": "incluir",
    "incluíeis": "incluir",
    "incluímo": "incluir",
    "incluímos": "incluir",
    "incluíra": "incluir",
    "incluíram": "incluir",
    "incluíramo": "incluir",
    "incluíramos": "incluir",
    "incluíras": "incluir",
    "incluíre": "incluir",
    "incluírei": "incluir",
    "incluíreis": "incluir",
    "incluírem": "incluir",
    "incluíres": "incluir",
    "incluís": "incluir",
    "incluísse": "incluir",
    "incluísseis": "incluir",
    "incluíssem": "incluir",
    "incluíssemos": "incluir",
    "incluísses": "incluir",
    "incluíste": "incluir",
    "incluístes": "incluir",
    "incluíveis": "incluível",
    "incoa": "incoar",
    "incoada": "incoar",
    "incoadas": "incoar",
    "incoado": "incoar",
    "incoados": "incoar",
    "incoadunáveis": "incoadunável",
    "incoaguláveis": "incoagulável",
    "incoai": "incoar",
    "incoais": "incoar",
    "incoam": "incoar",
    "incoamo": "incoar",
    "incoamos": "incoar",
    "incoando": "incoar",
    "incoara": "incoar",
    "incoaram": "incoar",
    "incoaras": "incoar",
    "incoarde": "incoar",
    "incoardes": "incoar",
    "incoare": "incoar",
    "incoarei": "incoar",
    "incoareis": "incoar",
    "incoarem": "incoar",
    "incoaremos": "incoar",
    "incoares": "incoar",
    "incoaria": "incoar",
    "incoariam": "incoar",
    "incoarias": "incoar",
    "incoarmo": "incoar",
    "incoarmos": "incoar",
    "incoará": "incoar",
    "incoarás": "incoar",
    "incoarão": "incoar",
    "incoaríamos": "incoar",
    "incoaríeis": "incoar",
    "incoas": "incoar",
    "incoasse": "incoar",
    "incoassem": "incoar",
    "incoasses": "incoar",
    "incoaste": "incoar",
    "incoastes": "incoar",
    "incoativa": "incoativo",
    "incoativas": "incoativo",
    "incoativos": "incoativo",
    "incoava": "incoar",
    "incoavam": "incoar",
    "incoavas": "incoar",
    "incoações": "incoação",
    "incobrada": "incobrado",
    "incobradas": "incobrado",
    "incobrados": "incobrado",
    "incobráveis": "incobrável",
    "incoctíveis": "incoctível",
    "incoe": "incoar",
    "incoei": "incoar",
    "incoeis": "incoar",
    "incoem": "incoar",
    "incoemo": "incoar",
    "incoemos": "incoar",
    "incoercibilidades": "incoercibilidade",
    "incoercíveis": "incoercível",
    "incoerentes": "incoerente",
    "incoerções": "incoerção",
    "incoerências": "incoerência",
    "incoes": "incoar",
    "incoesões": "incoesão",
    "incoexistentes": "incoexistente",
    "incoexistências": "incoexistência",
    "incognoscíveis": "incognoscível",
    "incolectáveis": "incolectável",
    "incolonizáveis": "incolonizável",
    "incolores": "incolor",
    "incolumidades": "incolumidade",
    "incombentes": "incombente",
    "incombináveis": "incombinável",
    "incomburentes": "incomburente",
    "incomburências": "incomburência",
    "incombusta": "incombusto",
    "incombustas": "incombusto",
    "incombustibilidades": "incombustibilidade",
    "incombustos": "incombusto",
    "incombustíveis": "incombustível",
    "incombustões": "incombustão",
    "incomemoráveis": "incomemorável",
    "incomensurabilidades": "incomensurabilidade",
    "incomensuráveis": "incomensurável",
    "incomercializáveis": "incomercializável",
    "incomerciáveis": "incomerciável",
    "incomestíveis": "incomestível",
    "incometíveis": "incometível",
    "incomoda": "incomodar",
    "incomodada": "incomodar",
    "incomodadas": "incomodar",
    "incomodado": "incomodar",
    "incomodadora": "incomodador",
    "incomodadoras": "incomodador",
    "incomodadores": "incomodador",
    "incomodados": "incomodar",
    "incomodadíssima": "incomodado",
    "incomodadíssimas": "incomodado",
    "incomodadíssimo": "incomodado",
    "incomodadíssimos": "incomodado",
    "incomodai": "incomodar",
    "incomodais": "incomodar",
    "incomodam": "incomodar",
    "incomodamo": "incomodar",
    "incomodamos": "incomodar",
    "incomodando": "incomodar",
    "incomodantes": "incomodante",
    "incomodara": "incomodar",
    "incomodaram": "incomodar",
    "incomodaras": "incomodar",
    "incomodarde": "incomodar",
    "incomodardes": "incomodar",
    "incomodare": "incomodar",
    "incomodarei": "incomodar",
    "incomodareis": "incomodar",
    "incomodarem": "incomodar",
    "incomodaremos": "incomodar",
    "incomodares": "incomodar",
    "incomodaria": "incomodar",
    "incomodariam": "incomodar",
    "incomodarias": "incomodar",
    "incomodarmo": "incomodar",
    "incomodarmos": "incomodar",
    "incomodará": "incomodar",
    "incomodarás": "incomodar",
    "incomodarão": "incomodar",
    "incomodaríamos": "incomodar",
    "incomodaríeis": "incomodar",
    "incomodas": "incomodar",
    "incomodasse": "incomodar",
    "incomodassem": "incomodar",
    "incomodasses": "incomodar",
    "incomodaste": "incomodar",
    "incomodastes": "incomodar",
    "incomodativa": "incomodativo",
    "incomodativas": "incomodativo",
    "incomodativos": "incomodativo",
    "incomodava": "incomodar",
    "incomodavam": "incomodar",
    "incomodavas": "incomodar",
    "incomode": "incomodar",
    "incomodei": "incomodar",
    "incomodeis": "incomodar",
    "incomodem": "incomodar",
    "incomodemo": "incomodar",
    "incomodemos": "incomodar",
    "incomodes": "incomodar",
    "incomodidades": "incomodidade",
    "incomodo": "incomodar",
    "incomodou": "incomodar",
    "incomodá": "incomodar",
    "incomodámo": "incomodar",
    "incomodámos": "incomodar",
    "incomodáramo": "incomodar",
    "incomodáramos": "incomodar",
    "incomodárei": "incomodar",
    "incomodáreis": "incomodar",
    "incomodásseis": "incomodar",
    "incomodássemos": "incomodar",
    "incomodávamo": "incomodar",
    "incomodávamos": "incomodar",
    "incomodávei": "incomodar",
    "incomodáveis": "incomodável",
    "incomparabilidades": "incomparabilidade",
    "incomparáveis": "incomparável",
    "incompassiva": "incompassivo",
    "incompassivas": "incompassivo",
    "incompassivos": "incompassivo",
    "incompassíveis": "incompassível",
    "incompatibilidades": "incompatibilidade",
    "incompatibiliza": "incompatibilizar",
    "incompatibilizada": "incompatibilizar",
    "incompatibilizadas": "incompatibilizar",
    "incompatibilizado": "incompatibilizar",
    "incompatibilizados": "incompatibilizar",
    "incompatibilizai": "incompatibilizar",
    "incompatibilizais": "incompatibilizar",
    "incompatibilizam": "incompatibilizar",
    "incompatibilizamo": "incompatibilizar",
    "incompatibilizamos": "incompatibilizar",
    "incompatibilizando": "incompatibilizar",
    "incompatibilizara": "incompatibilizar",
    "incompatibilizaram": "incompatibilizar",
    "incompatibilizaras": "incompatibilizar",
    "incompatibilizarde": "incompatibilizar",
    "incompatibilizardes": "incompatibilizar",
    "incompatibilizare": "incompatibilizar",
    "incompatibilizarei": "incompatibilizar",
    "incompatibilizareis": "incompatibilizar",
    "incompatibilizarem": "incompatibilizar",
    "incompatibilizaremos": "incompatibilizar",
    "incompatibilizares": "incompatibilizar",
    "incompatibilizaria": "incompatibilizar",
    "incompatibilizariam": "incompatibilizar",
    "incompatibilizarias": "incompatibilizar",
    "incompatibilizarmo": "incompatibilizar",
    "incompatibilizarmos": "incompatibilizar",
    "incompatibilizará": "incompatibilizar",
    "incompatibilizarás": "incompatibilizar",
    "incompatibilizarão": "incompatibilizar",
    "incompatibilizaríamos": "incompatibilizar",
    "incompatibilizaríeis": "incompatibilizar",
    "incompatibilizas": "incompatibilizar",
    "incompatibilizasse": "incompatibilizar",
    "incompatibilizassem": "incompatibilizar",
    "incompatibilizasses": "incompatibilizar",
    "incompatibilizaste": "incompatibilizar",
    "incompatibilizastes": "incompatibilizar",
    "incompatibilizava": "incompatibilizar",
    "incompatibilizavam": "incompatibilizar",
    "incompatibilizavas": "incompatibilizar",
    "incompatibilize": "incompatibilizar",
    "incompatibilizei": "incompatibilizar",
    "incompatibilizeis": "incompatibilizar",
    "incompatibilizem": "incompatibilizar",
    "incompatibilizemo": "incompatibilizar",
    "incompatibilizemos": "incompatibilizar",
    "incompatibilizes": "incompatibilizar",
    "incompatibilizo": "incompatibilizar",
    "incompatibilizou": "incompatibilizar",
    "incompatibilizá": "incompatibilizar",
    "incompatibilizámo": "incompatibilizar",
    "incompatibilizámos": "incompatibilizar",
    "incompatibilizáramo": "incompatibilizar",
    "incompatibilizáramos": "incompatibilizar",
    "incompatibilizárei": "incompatibilizar",
    "incompatibilizáreis": "incompatibilizar",
    "incompatibilizásseis": "incompatibilizar",
    "incompatibilizássemos": "incompatibilizar",
    "incompatibilizávamo": "incompatibilizar",
    "incompatibilizávamos": "incompatibilizar",
    "incompatibilizávei": "incompatibilizar",
    "incompatibilizáveis": "incompatibilizável",
    "incompatíveis": "incompatível",
    "incompensáveis": "incompensável",
    "incompetentes": "incompetente",
    "incompetências": "incompetência",
    "incomplacentes": "incomplacente",
    "incomplacências": "incomplacência",
    "incompleta": "incompleto",
    "incompletas": "incompleto",
    "incompletos": "incompleto",
    "incompletudes": "incompletude",
    "incompletáveis": "incompletável",
    "incomplexa": "incomplexo",
    "incomplexas": "incomplexo",
    "incomplexidades": "incomplexidade",
    "incomplexos": "incomplexo",
    "incomponíveis": "incomponível",
    "incomportáveis": "incomportável",
    "incompreendida": "incompreendido",
    "incompreendidas": "incompreendido",
    "incompreendidazinha": "incompreendido",
    "incompreendidazinhas": "incompreendido",
    "incompreendidazita": "incompreendido",
    "incompreendidazitas": "incompreendido",
    "incompreendidos": "incompreendido",
    "incompreendidozinho": "incompreendido",
    "incompreendidozinhos": "incompreendido",
    "incompreendidozito": "incompreendido",
    "incompreendidozitos": "incompreendido",
    "incompreensibilidades": "incompreensibilidade",
    "incompreensíveis": "incompreensível",
    "incompreensões": "incompreensão",
    "incompressibilidades": "incompressibilidade",
    "incompressíveis": "incompressível",
    "incomprovada": "incomprovado",
    "incomprovadas": "incomprovado",
    "incomprovados": "incomprovado",
    "incompta": "incompto",
    "incomptas": "incompto",
    "incomptos": "incompto",
    "incomputáveis": "incomputável",
    "incomunica": "incomunicar",
    "incomunicabilidades": "incomunicabilidade",
    "incomunicada": "incomunicar",
    "incomunicadas": "incomunicar",
    "incomunicado": "incomunicar",
    "incomunicados": "incomunicar",
    "incomunicai": "incomunicar",
    "incomunicais": "incomunicar",
    "incomunicam": "incomunicar",
    "incomunicamo": "incomunicar",
    "incomunicamos": "incomunicar",
    "incomunicando": "incomunicar",
    "incomunicantes": "incomunicante",
    "incomunicara": "incomunicar",
    "incomunicaram": "incomunicar",
    "incomunicaras": "incomunicar",
    "incomunicarde": "incomunicar",
    "incomunicardes": "incomunicar",
    "incomunicare": "incomunicar",
    "incomunicarei": "incomunicar",
    "incomunicareis": "incomunicar",
    "incomunicarem": "incomunicar",
    "incomunicaremos": "incomunicar",
    "incomunicares": "incomunicar",
    "incomunicaria": "incomunicar",
    "incomunicariam": "incomunicar",
    "incomunicarias": "incomunicar",
    "incomunicarmo": "incomunicar",
    "incomunicarmos": "incomunicar",
    "incomunicará": "incomunicar",
    "incomunicarás": "incomunicar",
    "incomunicarão": "incomunicar",
    "incomunicaríamos": "incomunicar",
    "incomunicaríeis": "incomunicar",
    "incomunicas": "incomunicar",
    "incomunicasse": "incomunicar",
    "incomunicassem": "incomunicar",
    "incomunicasses": "incomunicar",
    "incomunicaste": "incomunicar",
    "incomunicastes": "incomunicar",
    "incomunicava": "incomunicar",
    "incomunicavam": "incomunicar",
    "incomunicavas": "incomunicar",
    "incomunicações": "incomunicação",
    "incomunico": "incomunicar",
    "incomunicou": "incomunicar",
    "incomunicá": "incomunicar",
    "incomunicámo": "incomunicar",
    "incomunicámos": "incomunicar",
    "incomunicáramo": "incomunicar",
    "incomunicáramos": "incomunicar",
    "incomunicárei": "incomunicar",
    "incomunicáreis": "incomunicar",
    "incomunicásseis": "incomunicar",
    "incomunicássemos": "incomunicar",
    "incomunicávamo": "incomunicar",
    "incomunicávamos": "incomunicar",
    "incomunicávei": "incomunicar",
    "incomunicáveis": "incomunicável",
    "incomunique": "incomunicar",
    "incomuniquei": "incomunicar",
    "incomuniqueis": "incomunicar",
    "incomuniquem": "incomunicar",
    "incomuniquemo": "incomunicar",
    "incomuniquemos": "incomunicar",
    "incomuniques": "incomunicar",
    "incomuns": "incomum",
    "incomutabilidades": "incomutabilidade",
    "incomutáveis": "incomutável",
    "inconcebíveis": "inconcebível",
    "inconcedíveis": "inconcedível",
    "inconcepta": "inconcepto",
    "inconceptas": "inconcepto",
    "inconceptos": "inconcepto",
    "inconceptíveis": "inconceptível",
    "inconcessa": "inconcesso",
    "inconcessas": "inconcesso",
    "inconcessos": "inconcesso",
    "inconcessíveis": "inconcessível",
    "inconciliabilidades": "inconciliabilidade",
    "inconciliações": "inconciliação",
    "inconciliáveis": "inconciliável",
    "inconcludentes": "inconcludente",
    "inconclusiva": "inconclusivo",
    "inconclusivas": "inconclusivo",
    "inconclusivos": "inconclusivo",
    "inconcussa": "inconcusso",
    "inconcussas": "inconcusso",
    "inconcussos": "inconcusso",
    "inconcutíveis": "inconcutível",
    "incondicionada": "incondicionado",
    "incondicionadas": "incondicionado",
    "incondicionados": "incondicionado",
    "incondicionais": "incondicional",
    "incondicionalidades": "incondicionalidade",
    "incondicionalismos": "incondicionalismo",
    "inconexões": "inconexão",
    "inconfessa": "inconfesso",
    "inconfessada": "inconfessado",
    "inconfessadas": "inconfessado",
    "inconfessados": "inconfessado",
    "inconfessas": "inconfesso",
    "inconfessos": "inconfesso",
    "inconfessáveis": "inconfessável",
    "inconfidenciada": "inconfidenciado",
    "inconfidenciadas": "inconfidenciado",
    "inconfidenciados": "inconfidenciado",
    "inconfidenciais": "inconfidencial",
    "inconfidenciáveis": "inconfidenciável",
    "inconfidentes": "inconfidente",
    "inconfidências": "inconfidência",
    "inconfiscáveis": "inconfiscável",
    "inconformada": "inconformado",
    "inconformadas": "inconformado",
    "inconformados": "inconformado",
    "inconformadíssima": "inconformado",
    "inconformadíssimas": "inconformado",
    "inconformadíssimo": "inconformado",
    "inconformadíssimos": "inconformado",
    "inconformações": "inconformação",
    "inconformidades": "inconformidade",
    "inconformismos": "inconformismo",
    "inconformistas": "inconformista",
    "inconformáveis": "inconformável",
    "inconfortada": "inconfortado",
    "inconfortadas": "inconfortado",
    "inconfortados": "inconfortado",
    "inconfortáveis": "inconfortável",
    "inconfrontáveis": "inconfrontável",
    "inconfundíveis": "inconfundível",
    "incongeláveis": "incongelável",
    "incongruentes": "incongruente",
    "incongruidades": "incongruidade",
    "incongruências": "incongruência",
    "inconha": "inconho",
    "inconhas": "inconho",
    "inconhos": "inconho",
    "inconiventes": "inconivente",
    "inconjugáveis": "inconjugável",
    "inconjuráveis": "inconjurável",
    "inconquistabilidades": "inconquistabilidade",
    "inconquistada": "inconquistado",
    "inconquistadas": "inconquistado",
    "inconquistados": "inconquistado",
    "inconquistáveis": "inconquistável",
    "inconsagráveis": "inconsagrável",
    "inconscienciosa": "inconsciencioso",
    "inconscienciosas": "inconsciencioso",
    "inconscienciosos": "inconsciencioso",
    "inconscientes": "inconsciente",
    "inconsciências": "inconsciência",
    "inconseguíveis": "inconseguível",
    "inconsequentes": "inconsequente",
    "inconsequências": "inconsequência",
    "inconserváveis": "inconservável",
    "inconsiderada": "inconsiderado",
    "inconsideradas": "inconsiderado",
    "inconsiderados": "inconsiderado",
    "inconsiderações": "inconsideração",
    "inconsistentes": "inconsistente",
    "inconsistências": "inconsistência",
    "inconsolabilidades": "inconsolabilidade",
    "inconsolada": "inconsolado",
    "inconsoladas": "inconsolado",
    "inconsolados": "inconsolado",
    "inconsoláveis": "inconsolável",
    "inconsonantes": "inconsonante",
    "inconsonâncias": "inconsonância",
    "inconstantes": "inconstante",
    "inconstitucionais": "inconstitucional",
    "inconstitucionalidades": "inconstitucionalidade",
    "inconstâncias": "inconstância",
    "inconsulta": "inconsulto",
    "inconsultas": "inconsulto",
    "inconsultos": "inconsulto",
    "inconsultáveis": "inconsultável",
    "inconsumpta": "inconsumpto",
    "inconsumptas": "inconsumpto",
    "inconsumptos": "inconsumpto",
    "inconsumptíveis": "inconsumptível",
    "inconsumíveis": "inconsumível",
    "inconsútis": "inconsútil",
    "incontabilizáveis": "incontabilizável",
    "incontactáveis": "incontactável",
    "incontagiáveis": "incontagiável",
    "incontaminada": "incontaminado",
    "incontaminadas": "incontaminado",
    "incontaminados": "incontaminado",
    "incontamináveis": "incontaminável",
    "incontentáveis": "incontentável",
    "incontestabilidades": "incontestabilidade",
    "incontestada": "incontestado",
    "incontestadas": "incontestado",
    "incontestados": "incontestado",
    "incontestáveis": "incontestável",
    "incontida": "incontido",
    "incontidas": "incontido",
    "incontidos": "incontido",
    "incontinentes": "incontinente",
    "incontingentes": "incontingente",
    "incontingências": "incontingência",
    "incontinuidades": "incontinuidade",
    "incontinências": "incontinência",
    "incontornáveis": "incontornável",
    "incontraditáveis": "incontraditável",
    "incontrariáveis": "incontrariável",
    "incontrastáveis": "incontrastável",
    "incontratáveis": "incontratável",
    "incontraíveis": "incontraível",
    "incontrita": "incontrito",
    "incontritas": "incontrito",
    "incontritos": "incontrito",
    "incontrolada": "incontrolado",
    "incontroladas": "incontrolado",
    "incontrolados": "incontrolado",
    "incontroláveis": "incontrolável",
    "incontroversa": "incontroverso",
    "incontroversas": "incontroverso",
    "incontroversos": "incontroverso",
    "incontrovertíveis": "incontrovertível",
    "incontáveis": "incontável",
    "incontínua": "incontínuo",
    "incontínuas": "incontínuo",
    "incontínuos": "incontínuo",
    "inconvencíveis": "inconvencível",
    "inconvenientes": "inconveniente",
    "inconveniências": "inconveniência",
    "inconversibilidades": "inconversibilidade",
    "inconversáveis": "inconversável",
    "inconversíveis": "inconversível",
    "inconvertíveis": "inconvertível",
    "inconvicta": "inconvicto",
    "inconvictas": "inconvicto",
    "inconvictos": "inconvicto",
    "inconvulsa": "inconvulso",
    "inconvulsas": "inconvulso",
    "inconvulsos": "inconvulso",
    "incoo": "incoar",
    "incoordenações": "incoordenação",
    "incoou": "incoar",
    "incorpora": "incorporar",
    "incorporada": "incorporar",
    "incorporadas": "incorporar",
    "incorporado": "incorporar",
    "incorporados": "incorporar",
    "incorporai": "incorporar",
    "incorporais": "incorporar",
    "incorporalidades": "incorporalidade",
    "incorporam": "incorporar",
    "incorporamo": "incorporar",
    "incorporamos": "incorporar",
    "incorporando": "incorporar",
    "incorporara": "incorporar",
    "incorporaram": "incorporar",
    "incorporaras": "incorporar",
    "incorporarde": "incorporar",
    "incorporardes": "incorporar",
    "incorporare": "incorporar",
    "incorporarei": "incorporar",
    "incorporareis": "incorporar",
    "incorporarem": "incorporar",
    "incorporaremos": "incorporar",
    "incorporares": "incorporar",
    "incorporaria": "incorporar",
    "incorporariam": "incorporar",
    "incorporarias": "incorporar",
    "incorporarmo": "incorporar",
    "incorporarmos": "incorporar",
    "incorporará": "incorporar",
    "incorporarás": "incorporar",
    "incorporarão": "incorporar",
    "incorporaríamos": "incorporar",
    "incorporaríeis": "incorporar",
    "incorporas": "incorporar",
    "incorporasse": "incorporar",
    "incorporassem": "incorporar",
    "incorporasses": "incorporar",
    "incorporaste": "incorporar",
    "incorporastes": "incorporar",
    "incorporativa": "incorporativo",
    "incorporativas": "incorporativo",
    "incorporativos": "incorporativo",
    "incorporava": "incorporar",
    "incorporavam": "incorporar",
    "incorporavas": "incorporar",
    "incorporações": "incorporação",
    "incorpore": "incorporar",
    "incorporei": "incorporar",
    "incorporeidades": "incorporeidade",
    "incorporeis": "incorporar",
    "incorporem": "incorporar",
    "incorporemo": "incorporar",
    "incorporemos": "incorporar",
    "incorpores": "incorporar",
    "incorporo": "incorporar",
    "incorporou": "incorporar",
    "incorporá": "incorporar",
    "incorporámo": "incorporar",
    "incorporámos": "incorporar",
    "incorporáramo": "incorporar",
    "incorporáramos": "incorporar",
    "incorporárei": "incorporar",
    "incorporáreis": "incorporar",
    "incorporásseis": "incorporar",
    "incorporássemos": "incorporar",
    "incorporávamo": "incorporar",
    "incorporávamos": "incorporar",
    "incorporávei": "incorporar",
    "incorporáveis": "incorporável",
    "incorpórea": "incorpóreo",
    "incorpóreas": "incorpóreo",
    "incorpóreos": "incorpóreo",
    "incorra": "incorrer",
    "incorrais": "incorrer",
    "incorram": "incorrer",
    "incorramo": "incorrer",
    "incorramos": "incorrer",
    "incorras": "incorrer",
    "incorre": "incorrer",
    "incorrecta": "incorrecto",
    "incorrectas": "incorrecto",
    "incorrectos": "incorrecto",
    "incorrectíssima": "incorrecto",
    "incorrectíssimas": "incorrecto",
    "incorrectíssimo": "incorrecto",
    "incorrectíssimos": "incorrecto",
    "incorrecções": "incorrecção",
    "incorrei": "incorrer",
    "incorreis": "incorrer",
    "incorrem": "incorrer",
    "incorremo": "incorrer",
    "incorremos": "incorrer",
    "incorrendo": "incorrer",
    "incorrera": "incorrer",
    "incorreram": "incorrer",
    "incorreras": "incorrer",
    "incorrerdes": "incorrer",
    "incorrerei": "incorrer",
    "incorrereis": "incorrer",
    "incorrerem": "incorrer",
    "incorreremos": "incorrer",
    "incorreres": "incorrer",
    "incorreria": "incorrer",
    "incorreriam": "incorrer",
    "incorrerias": "incorrer",
    "incorrermo": "incorrer",
    "incorrermos": "incorrer",
    "incorrerá": "incorrer",
    "incorrerás": "incorrer",
    "incorrerão": "incorrer",
    "incorreríamos": "incorrer",
    "incorreríeis": "incorrer",
    "incorres": "incorrer",
    "incorresse": "incorrer",
    "incorressem": "incorrer",
    "incorresses": "incorrer",
    "incorreste": "incorrer",
    "incorrestes": "incorrer",
    "incorreu": "incorrer",
    "incorri": "incorrer",
    "incorria": "incorrer",
    "incorriam": "incorrer",
    "incorrias": "incorrer",
    "incorrida": "incorrer",
    "incorridas": "incorrer",
    "incorrido": "incorrer",
    "incorridos": "incorrer",
    "incorrigibilidades": "incorrigibilidade",
    "incorrigíveis": "incorrigível",
    "incorrimentos": "incorrimento",
    "incorro": "incorrer",
    "incorrompida": "incorrompido",
    "incorrompidas": "incorrompido",
    "incorrompidos": "incorrompido",
    "incorrompíveis": "incorrompível",
    "incorrupta": "incorrupto",
    "incorruptas": "incorrupto",
    "incorruptibilidades": "incorruptibilidade",
    "incorruptiva": "incorruptivo",
    "incorruptivas": "incorruptivo",
    "incorruptivos": "incorruptivo",
    "incorruptos": "incorrupto",
    "incorruptíveis": "incorruptível",
    "incorrupções": "incorrupção",
    "incorrêramo": "incorrer",
    "incorrêramos": "incorrer",
    "incorrêreis": "incorrer",
    "incorrêsseis": "incorrer",
    "incorrêssemos": "incorrer",
    "incorríamo": "incorrer",
    "incorríamos": "incorrer",
    "incorríeis": "incorrer",
    "incoá": "incoar",
    "incoámo": "incoar",
    "incoámos": "incoar",
    "incoáramo": "incoar",
    "incoáramos": "incoar",
    "incoárei": "incoar",
    "incoáreis": "incoar",
    "incoásseis": "incoar",
    "incoássemos": "incoar",
    "incoávamo": "incoar",
    "incoávamos": "incoar",
    "incoávei": "incoar",
    "incoáveis": "incoar",
    "incrassa": "incrassar",
    "incrassada": "incrassar",
    "incrassadas": "incrassar",
    "incrassado": "incrassar",
    "incrassados": "incrassar",
    "incrassai": "incrassar",
    "incrassais": "incrassar",
    "incrassam": "incrassar",
    "incrassamo": "incrassar",
    "incrassamos": "incrassar",
    "incrassando": "incrassar",
    "incrassara": "incrassar",
    "incrassaram": "incrassar",
    "incrassaras": "incrassar",
    "incrassarde": "incrassar",
    "incrassardes": "incrassar",
    "incrassare": "incrassar",
    "incrassarei": "incrassar",
    "incrassareis": "incrassar",
    "incrassarem": "incrassar",
    "incrassaremos": "incrassar",
    "incrassares": "incrassar",
    "incrassaria": "incrassar",
    "incrassariam": "incrassar",
    "incrassarias": "incrassar",
    "incrassarmo": "incrassar",
    "incrassarmos": "incrassar",
    "incrassará": "incrassar",
    "incrassarás": "incrassar",
    "incrassarão": "incrassar",
    "incrassaríamos": "incrassar",
    "incrassaríeis": "incrassar",
    "incrassas": "incrassar",
    "incrassasse": "incrassar",
    "incrassassem": "incrassar",
    "incrassasses": "incrassar",
    "incrassaste": "incrassar",
    "incrassastes": "incrassar",
    "incrassava": "incrassar",
    "incrassavam": "incrassar",
    "incrassavas": "incrassar",
    "incrasse": "incrassar",
    "incrassei": "incrassar",
    "incrasseis": "incrassar",
    "incrassem": "incrassar",
    "incrassemo": "incrassar",
    "incrassemos": "incrassar",
    "incrasses": "incrassar",
    "incrasso": "incrassar",
    "incrassou": "incrassar",
    "incrassá": "incrassar",
    "incrassámo": "incrassar",
    "incrassámos": "incrassar",
    "incrassáramo": "incrassar",
    "incrassáramos": "incrassar",
    "incrassárei": "incrassar",
    "incrassáreis": "incrassar",
    "incrassásseis": "incrassar",
    "incrassássemos": "incrassar",
    "incrassávamo": "incrassar",
    "incrassávamos": "incrassar",
    "incrassávei": "incrassar",
    "incrassáveis": "incrassar",
    "increais": "increr",
    "increamo": "increr",
    "increamos": "increr",
    "increde": "increr",
    "incredes": "increr",
    "incredibilidades": "incredibilidade",
    "incredulidades": "incredulidade",
    "increia": "increr",
    "increiam": "increr",
    "increias": "increr",
    "increio": "increr",
    "incrementa": "incrementar",
    "incrementada": "incrementar",
    "incrementadas": "incrementar",
    "incrementado": "incrementar",
    "incrementados": "incrementar",
    "incrementai": "incrementar",
    "incrementais": "incrementar",
    "incrementam": "incrementar",
    "incrementamo": "incrementar",
    "incrementamos": "incrementar",
    "incrementando": "incrementar",
    "incrementara": "incrementar",
    "incrementaram": "incrementar",
    "incrementaras": "incrementar",
    "incrementarde": "incrementar",
    "incrementardes": "incrementar",
    "incrementare": "incrementar",
    "incrementarei": "incrementar",
    "incrementareis": "incrementar",
    "incrementarem": "incrementar",
    "incrementaremos": "incrementar",
    "incrementares": "incrementar",
    "incrementaria": "incrementar",
    "incrementariam": "incrementar",
    "incrementarias": "incrementar",
    "incrementarmo": "incrementar",
    "incrementarmos": "incrementar",
    "incrementará": "incrementar",
    "incrementarás": "incrementar",
    "incrementarão": "incrementar",
    "incrementaríamos": "incrementar",
    "incrementaríeis": "incrementar",
    "incrementas": "incrementar",
    "incrementasse": "incrementar",
    "incrementassem": "incrementar",
    "incrementasses": "incrementar",
    "incrementaste": "incrementar",
    "incrementastes": "incrementar",
    "incrementava": "incrementar",
    "incrementavam": "incrementar",
    "incrementavas": "incrementar",
    "incremente": "incrementar",
    "incrementei": "incrementar",
    "incrementeis": "incrementar",
    "incrementem": "incrementar",
    "incrementemo": "incrementar",
    "incrementemos": "incrementar",
    "incrementes": "incrementar",
    "incremento": "incrementar",
    "incrementos": "incremento",
    "incrementou": "incrementar",
    "incrementá": "incrementar",
    "incrementámo": "incrementar",
    "incrementámos": "incrementar",
    "incrementáramo": "incrementar",
    "incrementáramos": "incrementar",
    "incrementárei": "incrementar",
    "incrementáreis": "incrementar",
    "incrementásseis": "incrementar",
    "incrementássemos": "incrementar",
    "incrementávamo": "incrementar",
    "incrementávamos": "incrementar",
    "incrementávei": "incrementar",
    "incrementáveis": "incrementável",
    "incrementícia": "incrementício",
    "incrementícias": "incrementício",
    "incrementícios": "incrementício",
    "incremo": "increr",
    "incremos": "increr",
    "increndo": "increr",
    "increpa": "increpar",
    "increpada": "increpar",
    "increpadas": "increpar",
    "increpado": "increpar",
    "increpadora": "increpador",
    "increpadoras": "increpador",
    "increpadores": "increpador",
    "increpados": "increpar",
    "increpai": "increpar",
    "increpais": "increpar",
    "increpam": "increpar",
    "increpamentos": "increpamento",
    "increpamo": "increpar",
    "increpamos": "increpar",
    "increpando": "increpar",
    "increpantes": "increpante",
    "increpara": "increpar",
    "increparam": "increpar",
    "increparas": "increpar",
    "increparde": "increpar",
    "increpardes": "increpar",
    "increpare": "increpar",
    "increparei": "increpar",
    "increpareis": "increpar",
    "increparem": "increpar",
    "increparemos": "increpar",
    "increpares": "increpar",
    "increparia": "increpar",
    "increpariam": "increpar",
    "increparias": "increpar",
    "increparmo": "increpar",
    "increparmos": "increpar",
    "increpará": "increpar",
    "increparás": "increpar",
    "increparão": "increpar",
    "increparíamos": "increpar",
    "increparíeis": "increpar",
    "increpas": "increpar",
    "increpasse": "increpar",
    "increpassem": "increpar",
    "increpasses": "increpar",
    "increpaste": "increpar",
    "increpastes": "increpar",
    "increpava": "increpar",
    "increpavam": "increpar",
    "increpavas": "increpar",
    "increpações": "increpação",
    "increpe": "increpar",
    "increpei": "increpar",
    "increpeis": "increpar",
    "increpem": "increpar",
    "increpemo": "increpar",
    "increpemos": "increpar",
    "increpes": "increpar",
    "increpo": "increpar",
    "increpou": "increpar",
    "increpá": "increpar",
    "increpámo": "increpar",
    "increpámos": "increpar",
    "increpáramo": "increpar",
    "increpáramos": "increpar",
    "increpárei": "increpar",
    "increpáreis": "increpar",
    "increpásseis": "increpar",
    "increpássemos": "increpar",
    "increpávamo": "increpar",
    "increpávamos": "increpar",
    "increpávei": "increpar",
    "increpáveis": "increpar",
    "increra": "increr",
    "increram": "increr",
    "increras": "increr",
    "increrde": "increr",
    "increrdes": "increr",
    "increre": "increr",
    "increrei": "increr",
    "increreis": "increr",
    "increrem": "increr",
    "increremos": "increr",
    "increres": "increr",
    "increria": "increr",
    "increriam": "increr",
    "increrias": "increr",
    "incrermo": "increr",
    "incrermos": "increr",
    "increrá": "increr",
    "increrás": "increr",
    "increrão": "increr",
    "increríamos": "increr",
    "increríeis": "increr",
    "increspada": "increspado",
    "increspadas": "increspado",
    "increspados": "increspado",
    "increspadíssima": "increspado",
    "increspadíssimas": "increspado",
    "increspadíssimo": "increspado",
    "increspadíssimos": "increspado",
    "incresse": "increr",
    "incressem": "increr",
    "incresses": "increr",
    "increste": "increr",
    "increstes": "increr",
    "increu": "increr",
    "incri": "increr",
    "incria": "increr",
    "incriada": "incriado",
    "incriadas": "incriado",
    "incriados": "incriado",
    "incriam": "increr",
    "incrias": "increr",
    "incrida": "increr",
    "incridas": "increr",
    "incrido": "increr",
    "incridos": "increr",
    "incrimina": "incriminar",
    "incriminada": "incriminar",
    "incriminadas": "incriminar",
    "incriminado": "incriminar",
    "incriminados": "incriminar",
    "incriminai": "incriminar",
    "incriminais": "incriminar",
    "incriminam": "incriminar",
    "incriminamo": "incriminar",
    "incriminamos": "incriminar",
    "incriminando": "incriminar",
    "incriminara": "incriminar",
    "incriminaram": "incriminar",
    "incriminaras": "incriminar",
    "incriminarde": "incriminar",
    "incriminardes": "incriminar",
    "incriminare": "incriminar",
    "incriminarei": "incriminar",
    "incriminareis": "incriminar",
    "incriminarem": "incriminar",
    "incriminaremos": "incriminar",
    "incriminares": "incriminar",
    "incriminaria": "incriminar",
    "incriminariam": "incriminar",
    "incriminarias": "incriminar",
    "incriminarmo": "incriminar",
    "incriminarmos": "incriminar",
    "incriminará": "incriminar",
    "incriminarás": "incriminar",
    "incriminarão": "incriminar",
    "incriminaríamos": "incriminar",
    "incriminaríeis": "incriminar",
    "incriminas": "incriminar",
    "incriminasse": "incriminar",
    "incriminassem": "incriminar",
    "incriminasses": "incriminar",
    "incriminaste": "incriminar",
    "incriminastes": "incriminar",
    "incriminatória": "incriminatório",
    "incriminatórias": "incriminatório",
    "incriminatórios": "incriminatório",
    "incriminava": "incriminar",
    "incriminavam": "incriminar",
    "incriminavas": "incriminar",
    "incriminações": "incriminação",
    "incrimine": "incriminar",
    "incriminei": "incriminar",
    "incrimineis": "incriminar",
    "incriminem": "incriminar",
    "incriminemo": "incriminar",
    "incriminemos": "incriminar",
    "incrimines": "incriminar",
    "incrimino": "incriminar",
    "incriminou": "incriminar",
    "incriminá": "incriminar",
    "incriminámo": "incriminar",
    "incriminámos": "incriminar",
    "incrimináramo": "incriminar",
    "incrimináramos": "incriminar",
    "incriminárei": "incriminar",
    "incrimináreis": "incriminar",
    "incriminásseis": "incriminar",
    "incriminássemos": "incriminar",
    "incriminávamo": "incriminar",
    "incriminávamos": "incriminar",
    "incriminávei": "incriminar",
    "incrimináveis": "incriminável",
    "incristalizáveis": "incristalizável",
    "incriticáveis": "incriticável",
    "incriáveis": "incriável",
    "incruenta": "incruento",
    "incruentas": "incruento",
    "incruentos": "incruento",
    "incrusta": "incrustar",
    "incrustada": "incrustar",
    "incrustadas": "incrustar",
    "incrustado": "incrustar",
    "incrustadora": "incrustador",
    "incrustadoras": "incrustador",
    "incrustadores": "incrustador",
    "incrustados": "incrustar",
    "incrustai": "incrustar",
    "incrustais": "incrustar",
    "incrustam": "incrustar",
    "incrustamo": "incrustar",
    "incrustamos": "incrustar",
    "incrustando": "incrustar",
    "incrustara": "incrustar",
    "incrustaram": "incrustar",
    "incrustaras": "incrustar",
    "incrustarde": "incrustar",
    "incrustardes": "incrustar",
    "incrustare": "incrustar",
    "incrustarei": "incrustar",
    "incrustareis": "incrustar",
    "incrustarem": "incrustar",
    "incrustaremos": "incrustar",
    "incrustares": "incrustar",
    "incrustaria": "incrustar",
    "incrustariam": "incrustar",
    "incrustarias": "incrustar",
    "incrustarmo": "incrustar",
    "incrustarmos": "incrustar",
    "incrustará": "incrustar",
    "incrustarás": "incrustar",
    "incrustarão": "incrustar",
    "incrustaríamos": "incrustar",
    "incrustaríeis": "incrustar",
    "incrustas": "incrustar",
    "incrustasse": "incrustar",
    "incrustassem": "incrustar",
    "incrustasses": "incrustar",
    "incrustaste": "incrustar",
    "incrustastes": "incrustar",
    "incrustava": "incrustar",
    "incrustavam": "incrustar",
    "incrustavas": "incrustar",
    "incrustações": "incrustação",
    "incruste": "incrustar",
    "incrustei": "incrustar",
    "incrusteis": "incrustar",
    "incrustem": "incrustar",
    "incrustemo": "incrustar",
    "incrustemos": "incrustar",
    "incrustes": "incrustar",
    "incrusto": "incrustar",
    "incrustou": "incrustar",
    "incrustá": "incrustar",
    "incrustámo": "incrustar",
    "incrustámos": "incrustar",
    "incrustáramo": "incrustar",
    "incrustáramos": "incrustar",
    "incrustárei": "incrustar",
    "incrustáreis": "incrustar",
    "incrustásseis": "incrustar",
    "incrustássemos": "incrustar",
    "incrustávamo": "incrustar",
    "incrustávamos": "incrustar",
    "incrustávei": "incrustar",
    "incrustáveis": "incrustável",
    "incrédula": "incrédulo",
    "incrédulas": "incrédulo",
    "incrédulos": "incrédulo",
    "incréus": "incréu",
    "incrê": "increr",
    "incrêem": "increr",
    "incrêramo": "increr",
    "incrêramos": "increr",
    "incrêrei": "increr",
    "incrêreis": "increr",
    "incrês": "increr",
    "incrêsseis": "increr",
    "incrêssemos": "increr",
    "incríamo": "increr",
    "incríamos": "increr",
    "incríei": "increr",
    "incríeis": "increr",
    "incríveis": "incrível",
    "incuba": "incubar",
    "incubada": "incubar",
    "incubadas": "incubar",
    "incubadeira": "incubador",
    "incubadeiras": "incubador",
    "incubado": "incubar",
    "incubadora": "incubador",
    "incubadoras": "incubadora",
    "incubadores": "incubador",
    "incubados": "incubar",
    "incubai": "incubar",
    "incubais": "incubar",
    "incubam": "incubar",
    "incubamo": "incubar",
    "incubamos": "incubar",
    "incubando": "incubar",
    "incubara": "incubar",
    "incubaram": "incubar",
    "incubaras": "incubar",
    "incubarde": "incubar",
    "incubardes": "incubar",
    "incubare": "incubar",
    "incubarei": "incubar",
    "incubareis": "incubar",
    "incubarem": "incubar",
    "incubaremos": "incubar",
    "incubares": "incubar",
    "incubaria": "incubar",
    "incubariam": "incubar",
    "incubarias": "incubar",
    "incubarmo": "incubar",
    "incubarmos": "incubar",
    "incubará": "incubar",
    "incubarás": "incubar",
    "incubarão": "incubar",
    "incubaríamos": "incubar",
    "incubaríeis": "incubar",
    "incubas": "incubar",
    "incubasse": "incubar",
    "incubassem": "incubar",
    "incubasses": "incubar",
    "incubaste": "incubar",
    "incubastes": "incubar",
    "incubatos": "incubato",
    "incubava": "incubar",
    "incubavam": "incubar",
    "incubavas": "incubar",
    "incubações": "incubação",
    "incube": "incubar",
    "incubei": "incubar",
    "incubeis": "incubar",
    "incubem": "incubar",
    "incubemo": "incubar",
    "incubemos": "incubar",
    "incubes": "incubar",
    "incubo": "incubar",
    "incubou": "incubar",
    "incubá": "incubar",
    "incubámo": "incubar",
    "incubámos": "incubar",
    "incubáramo": "incubar",
    "incubáramos": "incubar",
    "incubárei": "incubar",
    "incubáreis": "incubar",
    "incubásseis": "incubar",
    "incubássemos": "incubar",
    "incubávamo": "incubar",
    "incubávamos": "incubar",
    "incubávei": "incubar",
    "incubáveis": "incubável",
    "incudes": "incude",
    "inculca": "inculcar",
    "inculcada": "inculcar",
    "inculcadas": "inculcar",
    "inculcadeiras": "inculcadeira",
    "inculcado": "inculcar",
    "inculcadora": "inculcador",
    "inculcadoras": "inculcador",
    "inculcadores": "inculcador",
    "inculcados": "inculcar",
    "inculcai": "inculcar",
    "inculcais": "inculcar",
    "inculcam": "inculcar",
    "inculcamo": "inculcar",
    "inculcamos": "inculcar",
    "inculcando": "inculcar",
    "inculcara": "inculcar",
    "inculcaram": "inculcar",
    "inculcaras": "inculcar",
    "inculcarde": "inculcar",
    "inculcardes": "inculcar",
    "inculcare": "inculcar",
    "inculcarei": "inculcar",
    "inculcareis": "inculcar",
    "inculcarem": "inculcar",
    "inculcaremos": "inculcar",
    "inculcares": "inculcar",
    "inculcaria": "inculcar",
    "inculcariam": "inculcar",
    "inculcarias": "inculcar",
    "inculcarmo": "inculcar",
    "inculcarmos": "inculcar",
    "inculcará": "inculcar",
    "inculcarás": "inculcar",
    "inculcarão": "inculcar",
    "inculcaríamos": "inculcar",
    "inculcaríeis": "inculcar",
    "inculcas": "inculcar",
    "inculcasse": "inculcar",
    "inculcassem": "inculcar",
    "inculcasses": "inculcar",
    "inculcaste": "inculcar",
    "inculcastes": "inculcar",
    "inculcava": "inculcar",
    "inculcavam": "inculcar",
    "inculcavas": "inculcar",
    "inculco": "inculcar",
    "inculcou": "inculcar",
    "inculcá": "inculcar",
    "inculcámo": "inculcar",
    "inculcámos": "inculcar",
    "inculcáramo": "inculcar",
    "inculcáramos": "inculcar",
    "inculcárei": "inculcar",
    "inculcáreis": "inculcar",
    "inculcásseis": "inculcar",
    "inculcássemos": "inculcar",
    "inculcávamo": "inculcar",
    "inculcávamos": "inculcar",
    "inculcávei": "inculcar",
    "inculcáveis": "inculcável",
    "inculpa": "inculpar",
    "inculpabilidades": "inculpabilidade",
    "inculpada": "inculpar",
    "inculpadas": "inculpar",
    "inculpado": "inculpar",
    "inculpados": "inculpar",
    "inculpai": "inculpar",
    "inculpais": "inculpar",
    "inculpam": "inculpar",
    "inculpamo": "inculpar",
    "inculpamos": "inculpar",
    "inculpando": "inculpar",
    "inculpara": "inculpar",
    "inculparam": "inculpar",
    "inculparas": "inculpar",
    "inculparde": "inculpar",
    "inculpardes": "inculpar",
    "inculpare": "inculpar",
    "inculparei": "inculpar",
    "inculpareis": "inculpar",
    "inculparem": "inculpar",
    "inculparemos": "inculpar",
    "inculpares": "inculpar",
    "inculparia": "inculpar",
    "inculpariam": "inculpar",
    "inculparias": "inculpar",
    "inculparmo": "inculpar",
    "inculparmos": "inculpar",
    "inculpará": "inculpar",
    "inculparás": "inculpar",
    "inculparão": "inculpar",
    "inculparíamos": "inculpar",
    "inculparíeis": "inculpar",
    "inculpas": "inculpar",
    "inculpasse": "inculpar",
    "inculpassem": "inculpar",
    "inculpasses": "inculpar",
    "inculpaste": "inculpar",
    "inculpastes": "inculpar",
    "inculpava": "inculpar",
    "inculpavam": "inculpar",
    "inculpavas": "inculpar",
    "inculpações": "inculpação",
    "inculpe": "inculpar",
    "inculpei": "inculpar",
    "inculpeis": "inculpar",
    "inculpem": "inculpar",
    "inculpemo": "inculpar",
    "inculpemos": "inculpar",
    "inculpes": "inculpar",
    "inculpo": "inculpar",
    "inculposa": "inculposo",
    "inculposas": "inculposo",
    "inculposos": "inculposo",
    "inculpou": "inculpar",
    "inculpá": "inculpar",
    "inculpámo": "inculpar",
    "inculpámos": "inculpar",
    "inculpáramo": "inculpar",
    "inculpáramos": "inculpar",
    "inculpárei": "inculpar",
    "inculpáreis": "inculpar",
    "inculpásseis": "inculpar",
    "inculpássemos": "inculpar",
    "inculpávamo": "inculpar",
    "inculpávamos": "inculpar",
    "inculpávei": "inculpar",
    "inculpáveis": "inculpável",
    "inculque": "inculcar",
    "inculquei": "inculcar",
    "inculqueis": "inculcar",
    "inculquem": "inculcar",
    "inculquemo": "inculcar",
    "inculquemos": "inculcar",
    "inculques": "inculcar",
    "inculta": "inculto",
    "incultas": "inculto",
    "incultivada": "incultivado",
    "incultivadas": "incultivado",
    "incultivados": "incultivado",
    "incultiváveis": "incultivável",
    "incultos": "inculto",
    "inculturas": "incultura",
    "incumba": "incumbir",
    "incumbais": "incumbir",
    "incumbam": "incumbir",
    "incumbamo": "incumbir",
    "incumbamos": "incumbir",
    "incumbas": "incumbir",
    "incumbe": "incumbir",
    "incumbem": "incumbir",
    "incumbentes": "incumbente",
    "incumbes": "incumbir",
    "incumbi": "incumbir",
    "incumbia": "incumbir",
    "incumbiam": "incumbir",
    "incumbias": "incumbir",
    "incumbida": "incumbir",
    "incumbidas": "incumbir",
    "incumbido": "incumbir",
    "incumbidos": "incumbir",
    "incumbimo": "incumbir",
    "incumbimos": "incumbir",
    "incumbindo": "incumbir",
    "incumbira": "incumbir",
    "incumbiram": "incumbir",
    "incumbiras": "incumbir",
    "incumbirde": "incumbir",
    "incumbirdes": "incumbir",
    "incumbire": "incumbir",
    "incumbirei": "incumbir",
    "incumbireis": "incumbir",
    "incumbirem": "incumbir",
    "incumbiremos": "incumbir",
    "incumbires": "incumbir",
    "incumbiria": "incumbir",
    "incumbiriam": "incumbir",
    "incumbirias": "incumbir",
    "incumbirmo": "incumbir",
    "incumbirmos": "incumbir",
    "incumbirá": "incumbir",
    "incumbirás": "incumbir",
    "incumbirão": "incumbir",
    "incumbiríamos": "incumbir",
    "incumbiríeis": "incumbir",
    "incumbis": "incumbir",
    "incumbisse": "incumbir",
    "incumbissem": "incumbir",
    "incumbisses": "incumbir",
    "incumbiste": "incumbir",
    "incumbistes": "incumbir",
    "incumbiu": "incumbir",
    "incumbo": "incumbir",
    "incumbências": "incumbência",
    "incumbíamo": "incumbir",
    "incumbíamos": "incumbir",
    "incumbíei": "incumbir",
    "incumbíeis": "incumbir",
    "incumbíramo": "incumbir",
    "incumbíramos": "incumbir",
    "incumbírei": "incumbir",
    "incumbíreis": "incumbir",
    "incumbísseis": "incumbir",
    "incumbíssemos": "incumbir",
    "incumbíveis": "incumbível",
    "incumpridora": "incumpridor",
    "incumpridoras": "incumpridor",
    "incumpridores": "incumpridor",
    "incumprimentos": "incumprimento",
    "incunábulos": "incunábulo",
    "incurabilidades": "incurabilidade",
    "incuriais": "incurial",
    "incurialidades": "incurialidade",
    "incuriosa": "incurioso",
    "incuriosas": "incurioso",
    "incuriosidades": "incuriosidade",
    "incuriosos": "incurioso",
    "incursa": "incurso",
    "incursas": "incurso",
    "incursos": "incurso",
    "incursões": "incursão",
    "incuráveis": "incurável",
    "incusa": "incuso",
    "incusas": "incuso",
    "incusos": "incuso",
    "incuta": "incutir",
    "incutais": "incutir",
    "incutam": "incutir",
    "incutamo": "incutir",
    "incutamos": "incutir",
    "incutas": "incutir",
    "incute": "incutir",
    "incutem": "incutir",
    "incutes": "incutir",
    "incuti": "incutir",
    "incutia": "incutir",
    "incutiam": "incutir",
    "incutias": "incutir",
    "incutida": "incutir",
    "incutidas": "incutir",
    "incutido": "incutir",
    "incutidos": "incutir",
    "incutimo": "incutir",
    "incutimos": "incutir",
    "incutindo": "incutir",
    "incutira": "incutir",
    "incutiram": "incutir",
    "incutiras": "incutir",
    "incutirde": "incutir",
    "incutirdes": "incutir",
    "incutire": "incutir",
    "incutirei": "incutir",
    "incutireis": "incutir",
    "incutirem": "incutir",
    "incutiremos": "incutir",
    "incutires": "incutir",
    "incutiria": "incutir",
    "incutiriam": "incutir",
    "incutirias": "incutir",
    "incutirmo": "incutir",
    "incutirmos": "incutir",
    "incutirá": "incutir",
    "incutirás": "incutir",
    "incutirão": "incutir",
    "incutiríamos": "incutir",
    "incutiríeis": "incutir",
    "incutis": "incutir",
    "incutisse": "incutir",
    "incutissem": "incutir",
    "incutisses": "incutir",
    "incutiste": "incutir",
    "incutistes": "incutir",
    "incutiu": "incutir",
    "incuto": "incutir",
    "incutíamo": "incutir",
    "incutíamos": "incutir",
    "incutíei": "incutir",
    "incutíeis": "incutir",
    "incutíramo": "incutir",
    "incutíramos": "incutir",
    "incutírei": "incutir",
    "incutíreis": "incutir",
    "incutísseis": "incutir",
    "incutíssemos": "incutir",
    "incutíveis": "incutível",
    "incêndios": "incêndio",
    "incógnita": "incógnito",
    "incógnitas": "incógnito",
    "incógnitos": "incógnito",
    "incólumes": "incólume",
    "incómoda": "incómodo",
    "incómodas": "incómodo",
    "incómodos": "incómodo",
    "incôndita": "incôndito",
    "incônditas": "incôndito",
    "incônditos": "incôndito",
    "incôngrua": "incôngruo",
    "incôngruas": "incôngruo",
    "incôngruos": "incôngruo",
    "incônscia": "incônscio",
    "incônscias": "incônscio",
    "incônscios": "incônscio",
    "incúrias": "incúria",
    "indaga": "indagar",
    "indagada": "indagar",
    "indagadas": "indagar",
    "indagado": "indagar",
    "indagadora": "indagador",
    "indagadoras": "indagador",
    "indagadores": "indagador",
    "indagados": "indagar",
    "indagai": "indagar",
    "indagais": "indagar",
    "indagam": "indagar",
    "indagamo": "indagar",
    "indagamos": "indagar",
    "indagando": "indagar",
    "indagara": "indagar",
    "indagaram": "indagar",
    "indagaras": "indagar",
    "indagarde": "indagar",
    "indagardes": "indagar",
    "indagare": "indagar",
    "indagarei": "indagar",
    "indagareis": "indagar",
    "indagarem": "indagar",
    "indagaremos": "indagar",
    "indagares": "indagar",
    "indagaria": "indagar",
    "indagariam": "indagar",
    "indagarias": "indagar",
    "indagarmo": "indagar",
    "indagarmos": "indagar",
    "indagará": "indagar",
    "indagarás": "indagar",
    "indagarão": "indagar",
    "indagaríamos": "indagar",
    "indagaríeis": "indagar",
    "indagas": "indagar",
    "indagasse": "indagar",
    "indagassem": "indagar",
    "indagasses": "indagar",
    "indagaste": "indagar",
    "indagastes": "indagar",
    "indagativa": "indagativo",
    "indagativas": "indagativo",
    "indagativos": "indagativo",
    "indagatória": "indagatório",
    "indagatórias": "indagatório",
    "indagatórios": "indagatório",
    "indagava": "indagar",
    "indagavam": "indagar",
    "indagavas": "indagar",
    "indagações": "indagação",
    "indago": "indagar",
    "indagou": "indagar",
    "indague": "indagar",
    "indaguei": "indagar",
    "indagueis": "indagar",
    "indaguem": "indagar",
    "indaguemo": "indagar",
    "indaguemos": "indagar",
    "indagues": "indagar",
    "indagá": "indagar",
    "indagámo": "indagar",
    "indagámos": "indagar",
    "indagáramo": "indagar",
    "indagáramos": "indagar",
    "indagárei": "indagar",
    "indagáreis": "indagar",
    "indagásseis": "indagar",
    "indagássemos": "indagar",
    "indagávamo": "indagar",
    "indagávamos": "indagar",
    "indagávei": "indagar",
    "indagáveis": "indagável",
    "indebatíveis": "indebatível",
    "indecentes": "indecente",
    "indecidida": "indecidido",
    "indecididas": "indecidido",
    "indecididos": "indecidido",
    "indecifrada": "indecifrado",
    "indecifradas": "indecifrado",
    "indecifrados": "indecifrado",
    "indecifráveis": "indecifrável",
    "indecisa": "indeciso",
    "indecisas": "indeciso",
    "indecisos": "indeciso",
    "indecisões": "indecisão",
    "indeclaráveis": "indeclarável",
    "indeclinabilidades": "indeclinabilidade",
    "indeclináveis": "indeclinável",
    "indecomponíveis": "indecomponível",
    "indecoros": "indecoro",
    "indecorosa": "indecoroso",
    "indecorosas": "indecoroso",
    "indecorosos": "indecoroso",
    "indecoráveis": "indecorável",
    "indecretáveis": "indecretável",
    "indecências": "indecência",
    "indedutíveis": "indedutível",
    "indeduzíveis": "indeduzível",
    "indefectibilidades": "indefectibilidade",
    "indefectíveis": "indefectível",
    "indefendíveis": "indefendível",
    "indefensa": "indefenso",
    "indefensas": "indefenso",
    "indefensos": "indefenso",
    "indefensáveis": "indefensável",
    "indefensíveis": "indefensível",
    "indefere": "indeferir",
    "indeferem": "indeferir",
    "indeferes": "indeferir",
    "indeferi": "indeferir",
    "indeferia": "indeferir",
    "indeferiam": "indeferir",
    "indeferias": "indeferir",
    "indeferida": "indeferir",
    "indeferidas": "indeferir",
    "indeferido": "indeferir",
    "indeferidos": "indeferir",
    "indeferimentos": "indeferimento",
    "indeferimo": "indeferir",
    "indeferimos": "indeferir",
    "indeferindo": "indeferir",
    "indeferira": "indeferir",
    "indeferiram": "indeferir",
    "indeferiras": "indeferir",
    "indeferirde": "indeferir",
    "indeferirdes": "indeferir",
    "indeferire": "indeferir",
    "indeferirei": "indeferir",
    "indeferireis": "indeferir",
    "indeferirem": "indeferir",
    "indeferiremos": "indeferir",
    "indeferires": "indeferir",
    "indeferiria": "indeferir",
    "indefeririam": "indeferir",
    "indeferirias": "indeferir",
    "indeferirmo": "indeferir",
    "indeferirmos": "indeferir",
    "indeferirá": "indeferir",
    "indeferirás": "indeferir",
    "indeferirão": "indeferir",
    "indeferiríamos": "indeferir",
    "indeferiríeis": "indeferir",
    "indeferis": "indeferir",
    "indeferisse": "indeferir",
    "indeferissem": "indeferir",
    "indeferisses": "indeferir",
    "indeferiste": "indeferir",
    "indeferistes": "indeferir",
    "indeferiu": "indeferir",
    "indeferíamo": "indeferir",
    "indeferíamos": "indeferir",
    "indeferíei": "indeferir",
    "indeferíeis": "indeferir",
    "indeferíramo": "indeferir",
    "indeferíramos": "indeferir",
    "indeferírei": "indeferir",
    "indeferíreis": "indeferir",
    "indeferísseis": "indeferir",
    "indeferíssemos": "indeferir",
    "indeferíveis": "indeferível",
    "indefesa": "indefeso",
    "indefesas": "indefeso",
    "indefesazinha": "indefeso",
    "indefesazinhas": "indefeso",
    "indefesazita": "indefeso",
    "indefesazitas": "indefeso",
    "indefesos": "indefeso",
    "indefesozinho": "indefeso",
    "indefesozinhos": "indefeso",
    "indefesozito": "indefeso",
    "indefesozitos": "indefeso",
    "indefessa": "indefesso",
    "indefessas": "indefesso",
    "indefessos": "indefesso",
    "indeficientes": "indeficiente",
    "indefinida": "indefinido",
    "indefinidas": "indefinido",
    "indefinidos": "indefinido",
    "indefinições": "indefinição",
    "indefiníveis": "indefinível",
    "indefira": "indeferir",
    "indefirais": "indeferir",
    "indefiram": "indeferir",
    "indefiramo": "indeferir",
    "indefiramos": "indeferir",
    "indefiras": "indeferir",
    "indefiro": "indeferir",
    "indeformáveis": "indeformável",
    "indeiscentes": "indeiscente",
    "indeiscências": "indeiscência",
    "indelebilidades": "indelebilidade",
    "indelegáveis": "indelegável",
    "indeliberada": "indeliberado",
    "indeliberadas": "indeliberado",
    "indeliberados": "indeliberado",
    "indeliberações": "indeliberação",
    "indelicada": "indelicado",
    "indelicadas": "indelicado",
    "indelicadezas": "indelicadeza",
    "indelicados": "indelicado",
    "indelimitáveis": "indelimitável",
    "indelineáveis": "indelineável",
    "indeléveis": "indelével",
    "indemarcáveis": "indemarcável",
    "indemnes": "indemne",
    "indemnidades": "indemnidade",
    "indemniza": "indemnizar",
    "indemnizada": "indemnizar",
    "indemnizadas": "indemnizar",
    "indemnizado": "indemnizar",
    "indemnizadora": "indemnizador",
    "indemnizadoras": "indemnizador",
    "indemnizadores": "indemnizador",
    "indemnizados": "indemnizar",
    "indemnizai": "indemnizar",
    "indemnizais": "indemnizar",
    "indemnizam": "indemnizar",
    "indemnizamo": "indemnizar",
    "indemnizamos": "indemnizar",
    "indemnizando": "indemnizar",
    "indemnizara": "indemnizar",
    "indemnizaram": "indemnizar",
    "indemnizaras": "indemnizar",
    "indemnizarde": "indemnizar",
    "indemnizardes": "indemnizar",
    "indemnizare": "indemnizar",
    "indemnizarei": "indemnizar",
    "indemnizareis": "indemnizar",
    "indemnizarem": "indemnizar",
    "indemnizaremos": "indemnizar",
    "indemnizares": "indemnizar",
    "indemnizaria": "indemnizar",
    "indemnizariam": "indemnizar",
    "indemnizarias": "indemnizar",
    "indemnizarmo": "indemnizar",
    "indemnizarmos": "indemnizar",
    "indemnizará": "indemnizar",
    "indemnizarás": "indemnizar",
    "indemnizarão": "indemnizar",
    "indemnizaríamos": "indemnizar",
    "indemnizaríeis": "indemnizar",
    "indemnizas": "indemnizar",
    "indemnizasse": "indemnizar",
    "indemnizassem": "indemnizar",
    "indemnizasses": "indemnizar",
    "indemnizaste": "indemnizar",
    "indemnizastes": "indemnizar",
    "indemnizava": "indemnizar",
    "indemnizavam": "indemnizar",
    "indemnizavas": "indemnizar",
    "indemnizações": "indemnização",
    "indemnize": "indemnizar",
    "indemnizei": "indemnizar",
    "indemnizeis": "indemnizar",
    "indemnizem": "indemnizar",
    "indemnizemo": "indemnizar",
    "indemnizemos": "indemnizar",
    "indemnizes": "indemnizar",
    "indemnizo": "indemnizar",
    "indemnizou": "indemnizar",
    "indemnizá": "indemnizar",
    "indemnizámo": "indemnizar",
    "indemnizámos": "indemnizar",
    "indemnizáramo": "indemnizar",
    "indemnizáramos": "indemnizar",
    "indemnizárei": "indemnizar",
    "indemnizáreis": "indemnizar",
    "indemnizásseis": "indemnizar",
    "indemnizássemos": "indemnizar",
    "indemnizávamo": "indemnizar",
    "indemnizávamos": "indemnizar",
    "indemnizávei": "indemnizar",
    "indemnizáveis": "indemnizável",
    "indemocratizáveis": "indemocratizável",
    "indemolíveis": "indemolível",
    "indemonstrada": "indemonstrado",
    "indemonstradas": "indemonstrado",
    "indemonstrados": "indemonstrado",
    "indemonstráveis": "indemonstrável",
    "indemovíveis": "indemovível",
    "indenomináveis": "indenominável",
    "independentes": "independente",
    "independentistas": "independentista",
    "independências": "independência",
    "indeportáveis": "indeportável",
    "indepositáveis": "indepositável",
    "inderrotáveis": "inderrotável",
    "inderrubáveis": "inderrubável",
    "indescascáveis": "indescascável",
    "indescentralizáveis": "indescentralizável",
    "indescontáveis": "indescontável",
    "indescortináveis": "indescortinável",
    "indescritíveis": "indescritível",
    "indesculpáveis": "indesculpável",
    "indesdobráveis": "indesdobrável",
    "indesejada": "indesejado",
    "indesejadas": "indesejado",
    "indesejados": "indesejado",
    "indesejáveis": "indesejável",
    "indesfrutáveis": "indesfrutável",
    "indesignáveis": "indesignável",
    "indeslocáveis": "indeslocável",
    "indesmancháveis": "indesmanchável",
    "indesmanteláveis": "indesmantelável",
    "indesmascaráveis": "indesmascarável",
    "indesmembráveis": "indesmembrável",
    "indesmentida": "indesmentido",
    "indesmentidas": "indesmentido",
    "indesmentidos": "indesmentido",
    "indesmentíveis": "indesmentível",
    "indesmontáveis": "indesmontável",
    "indespegáveis": "indespegável",
    "indespistáveis": "indespistável",
    "indespojáveis": "indespojável",
    "indestacáveis": "indestacável",
    "indestiláveis": "indestilável",
    "indestituíveis": "indestituível",
    "indestrinçáveis": "indestrinçável",
    "indestronizáveis": "indestronizável",
    "indestronáveis": "indestronável",
    "indestruida": "indestruido",
    "indestruidas": "indestruido",
    "indestruidos": "indestruido",
    "indestrutibilidades": "indestrutibilidade",
    "indestrutíveis": "indestrutível",
    "indestruíveis": "indestruível",
    "indesvendáveis": "indesvendável",
    "indesviáveis": "indesviável",
    "indetectáveis": "indetectável",
    "indetermina": "indeterminar",
    "indeterminabilidades": "indeterminabilidade",
    "indeterminada": "indeterminar",
    "indeterminadas": "indeterminar",
    "indeterminado": "indeterminar",
    "indeterminados": "indeterminar",
    "indeterminai": "indeterminar",
    "indeterminais": "indeterminar",
    "indeterminam": "indeterminar",
    "indeterminamo": "indeterminar",
    "indeterminamos": "indeterminar",
    "indeterminando": "indeterminar",
    "indeterminara": "indeterminar",
    "indeterminaram": "indeterminar",
    "indeterminaras": "indeterminar",
    "indeterminarde": "indeterminar",
    "indeterminardes": "indeterminar",
    "indeterminare": "indeterminar",
    "indeterminarei": "indeterminar",
    "indeterminareis": "indeterminar",
    "indeterminarem": "indeterminar",
    "indeterminaremos": "indeterminar",
    "indeterminares": "indeterminar",
    "indeterminaria": "indeterminar",
    "indeterminariam": "indeterminar",
    "indeterminarias": "indeterminar",
    "indeterminarmo": "indeterminar",
    "indeterminarmos": "indeterminar",
    "indeterminará": "indeterminar",
    "indeterminarás": "indeterminar",
    "indeterminarão": "indeterminar",
    "indeterminaríamos": "indeterminar",
    "indeterminaríeis": "indeterminar",
    "indeterminas": "indeterminar",
    "indeterminasse": "indeterminar",
    "indeterminassem": "indeterminar",
    "indeterminasses": "indeterminar",
    "indeterminaste": "indeterminar",
    "indeterminastes": "indeterminar",
    "indeterminativa": "indeterminativo",
    "indeterminativas": "indeterminativo",
    "indeterminativos": "indeterminativo",
    "indeterminava": "indeterminar",
    "indeterminavam": "indeterminar",
    "indeterminavas": "indeterminar",
    "indeterminações": "indeterminação",
    "indetermine": "indeterminar",
    "indeterminei": "indeterminar",
    "indetermineis": "indeterminar",
    "indeterminem": "indeterminar",
    "indeterminemo": "indeterminar",
    "indeterminemos": "indeterminar",
    "indetermines": "indeterminar",
    "indeterminismos": "indeterminismo",
    "indetermino": "indeterminar",
    "indeterminou": "indeterminar",
    "indeterminá": "indeterminar",
    "indeterminámo": "indeterminar",
    "indeterminámos": "indeterminar",
    "indetermináramo": "indeterminar",
    "indetermináramos": "indeterminar",
    "indeterminárei": "indeterminar",
    "indetermináreis": "indeterminar",
    "indeterminásseis": "indeterminar",
    "indeterminássemos": "indeterminar",
    "indeterminávamo": "indeterminar",
    "indeterminávamos": "indeterminar",
    "indeterminávei": "indeterminar",
    "indetermináveis": "indeterminável",
    "indetexa": "indetexar",
    "indetexada": "indetexar",
    "indetexadas": "indetexar",
    "indetexado": "indetexar",
    "indetexados": "indetexar",
    "indetexai": "indetexar",
    "indetexais": "indetexar",
    "indetexam": "indetexar",
    "indetexamo": "indetexar",
    "indetexamos": "indetexar",
    "indetexando": "indetexar",
    "indetexara": "indetexar",
    "indetexaram": "indetexar",
    "indetexaras": "indetexar",
    "indetexarde": "indetexar",
    "indetexardes": "indetexar",
    "indetexare": "indetexar",
    "indetexarei": "indetexar",
    "indetexareis": "indetexar",
    "indetexarem": "indetexar",
    "indetexaremos": "indetexar",
    "indetexares": "indetexar",
    "indetexaria": "indetexar",
    "indetexariam": "indetexar",
    "indetexarias": "indetexar",
    "indetexarmo": "indetexar",
    "indetexarmos": "indetexar",
    "indetexará": "indetexar",
    "indetexarás": "indetexar",
    "indetexarão": "indetexar",
    "indetexaríamos": "indetexar",
    "indetexaríeis": "indetexar",
    "indetexas": "indetexar",
    "indetexasse": "indetexar",
    "indetexassem": "indetexar",
    "indetexasses": "indetexar",
    "indetexaste": "indetexar",
    "indetexastes": "indetexar",
    "indetexava": "indetexar",
    "indetexavam": "indetexar",
    "indetexavas": "indetexar",
    "indetexe": "indetexar",
    "indetexei": "indetexar",
    "indetexeis": "indetexar",
    "indetexem": "indetexar",
    "indetexemo": "indetexar",
    "indetexemos": "indetexar",
    "indetexes": "indetexar",
    "indetexo": "indetexar",
    "indetexou": "indetexar",
    "indetexá": "indetexar",
    "indetexámo": "indetexar",
    "indetexámos": "indetexar",
    "indetexáramo": "indetexar",
    "indetexáramos": "indetexar",
    "indetexárei": "indetexar",
    "indetexáreis": "indetexar",
    "indetexásseis": "indetexar",
    "indetexássemos": "indetexar",
    "indetexávamo": "indetexar",
    "indetexávamos": "indetexar",
    "indetexávei": "indetexar",
    "indetexáveis": "indetexar",
    "indeturpáveis": "indeturpável",
    "indevassáveis": "indevassável",
    "indevida": "indevido",
    "indevidas": "indevido",
    "indevidos": "indevido",
    "indevota": "indevoto",
    "indevotas": "indevoto",
    "indevotos": "indevoto",
    "indevoções": "indevoção",
    "indexada": "indexado",
    "indexadas": "indexado",
    "indexados": "indexado",
    "indexações": "indexação",
    "indezes": "indez",
    "indiagnosticáveis": "indiagnosticável",
    "indiana": "indiano",
    "indianas": "indiano",
    "indianismos": "indianismo",
    "indianistas": "indianista",
    "indianiza": "indianizar",
    "indianizada": "indianizar",
    "indianizadas": "indianizar",
    "indianizado": "indianizar",
    "indianizados": "indianizar",
    "indianizai": "indianizar",
    "indianizais": "indianizar",
    "indianizam": "indianizar",
    "indianizamo": "indianizar",
    "indianizamos": "indianizar",
    "indianizando": "indianizar",
    "indianizara": "indianizar",
    "indianizaram": "indianizar",
    "indianizaras": "indianizar",
    "indianizarde": "indianizar",
    "indianizardes": "indianizar",
    "indianizare": "indianizar",
    "indianizarei": "indianizar",
    "indianizareis": "indianizar",
    "indianizarem": "indianizar",
    "indianizaremos": "indianizar",
    "indianizares": "indianizar",
    "indianizaria": "indianizar",
    "indianizariam": "indianizar",
    "indianizarias": "indianizar",
    "indianizarmo": "indianizar",
    "indianizarmos": "indianizar",
    "indianizará": "indianizar",
    "indianizarás": "indianizar",
    "indianizarão": "indianizar",
    "indianizaríamos": "indianizar",
    "indianizaríeis": "indianizar",
    "indianizas": "indianizar",
    "indianizasse": "indianizar",
    "indianizassem": "indianizar",
    "indianizasses": "indianizar",
    "indianizaste": "indianizar",
    "indianizastes": "indianizar",
    "indianizava": "indianizar",
    "indianizavam": "indianizar",
    "indianizavas": "indianizar",
    "indianize": "indianizar",
    "indianizei": "indianizar",
    "indianizeis": "indianizar",
    "indianizem": "indianizar",
    "indianizemo": "indianizar",
    "indianizemos": "indianizar",
    "indianizes": "indianizar",
    "indianizo": "indianizar",
    "indianizou": "indianizar",
    "indianizá": "indianizar",
    "indianizámo": "indianizar",
    "indianizámos": "indianizar",
    "indianizáramo": "indianizar",
    "indianizáramos": "indianizar",
    "indianizárei": "indianizar",
    "indianizáreis": "indianizar",
    "indianizásseis": "indianizar",
    "indianizássemos": "indianizar",
    "indianizávamo": "indianizar",
    "indianizávamos": "indianizar",
    "indianizávei": "indianizar",
    "indianizáveis": "indianizável",
    "indianos": "indiano",
    "indianóloga": "indianólogo",
    "indianólogas": "indianólogo",
    "indianólogos": "indianólogo",
    "indiarobenses": "indiarobense",
    "indica": "indicar",
    "indicada": "indicar",
    "indicadas": "indicar",
    "indicado": "indicar",
    "indicadora": "indicador",
    "indicadoras": "indicador",
    "indicadores": "indicador",
    "indicados": "indicar",
    "indicadíssima": "indicado",
    "indicadíssimas": "indicado",
    "indicadíssimo": "indicado",
    "indicadíssimos": "indicado",
    "indicai": "indicar",
    "indicais": "indicar",
    "indicam": "indicar",
    "indicamo": "indicar",
    "indicamos": "indicar",
    "indicanas": "indicana",
    "indicando": "indicar",
    "indicanúrias": "indicanúria",
    "indicara": "indicar",
    "indicaram": "indicar",
    "indicaras": "indicar",
    "indicarde": "indicar",
    "indicardes": "indicar",
    "indicare": "indicar",
    "indicarei": "indicar",
    "indicareis": "indicar",
    "indicarem": "indicar",
    "indicaremos": "indicar",
    "indicares": "indicar",
    "indicaria": "indicar",
    "indicariam": "indicar",
    "indicarias": "indicar",
    "indicarmo": "indicar",
    "indicarmos": "indicar",
    "indicará": "indicar",
    "indicarás": "indicar",
    "indicarão": "indicar",
    "indicaríamos": "indicar",
    "indicaríeis": "indicar",
    "indicas": "indicar",
    "indicasse": "indicar",
    "indicassem": "indicar",
    "indicasses": "indicar",
    "indicaste": "indicar",
    "indicastes": "indicar",
    "indicativa": "indicativo",
    "indicativas": "indicativo",
    "indicativos": "indicativo",
    "indicatória": "indicatório",
    "indicatórias": "indicatório",
    "indicatórios": "indicatório",
    "indicava": "indicar",
    "indicavam": "indicar",
    "indicavas": "indicar",
    "indicações": "indicação",
    "indicia": "indiciar",
    "indiciada": "indiciar",
    "indiciadas": "indiciar",
    "indiciado": "indiciar",
    "indiciadora": "indiciador",
    "indiciadoras": "indiciador",
    "indiciadores": "indiciador",
    "indiciados": "indiciar",
    "indiciai": "indiciar",
    "indiciais": "indiciar",
    "indiciam": "indiciar",
    "indiciamentos": "indiciamento",
    "indiciamo": "indiciar",
    "indiciamos": "indiciar",
    "indiciando": "indiciar",
    "indiciantes": "indiciante",
    "indiciara": "indiciar",
    "indiciaram": "indiciar",
    "indiciaras": "indiciar",
    "indiciarde": "indiciar",
    "indiciardes": "indiciar",
    "indiciare": "indiciar",
    "indiciarei": "indiciar",
    "indiciareis": "indiciar",
    "indiciarem": "indiciar",
    "indiciaremos": "indiciar",
    "indiciares": "indiciar",
    "indiciaria": "indiciar",
    "indiciariam": "indiciar",
    "indiciarias": "indiciar",
    "indiciarmo": "indiciar",
    "indiciarmos": "indiciar",
    "indiciará": "indiciar",
    "indiciarás": "indiciar",
    "indiciarão": "indiciar",
    "indiciaríamos": "indiciar",
    "indiciaríeis": "indiciar",
    "indicias": "indiciar",
    "indiciasse": "indiciar",
    "indiciassem": "indiciar",
    "indiciasses": "indiciar",
    "indiciaste": "indiciar",
    "indiciastes": "indiciar",
    "indiciava": "indiciar",
    "indiciavam": "indiciar",
    "indiciavas": "indiciar",
    "indiciações": "indiciação",
    "indicie": "indiciar",
    "indiciei": "indiciar",
    "indicieis": "indiciar",
    "indiciem": "indiciar",
    "indiciemo": "indiciar",
    "indiciemos": "indiciar",
    "indicies": "indiciar",
    "indicio": "indiciar",
    "indicionarizáveis": "indicionarizável",
    "indiciosa": "indicioso",
    "indiciosas": "indicioso",
    "indiciosos": "indicioso",
    "indiciou": "indiciar",
    "indiciá": "indiciar",
    "indiciámo": "indiciar",
    "indiciámos": "indiciar",
    "indiciáramo": "indiciar",
    "indiciáramos": "indiciar",
    "indiciárei": "indiciar",
    "indiciáreis": "indiciar",
    "indiciária": "indiciário",
    "indiciárias": "indiciário",
    "indiciários": "indiciário",
    "indiciásseis": "indiciar",
    "indiciássemos": "indiciar",
    "indiciávamo": "indiciar",
    "indiciávamos": "indiciar",
    "indiciávei": "indiciar",
    "indiciáveis": "indiciar",
    "indico": "indicar",
    "indicou": "indicar",
    "indicá": "indicar",
    "indicámo": "indicar",
    "indicámos": "indicar",
    "indicáramo": "indicar",
    "indicáramos": "indicar",
    "indicárei": "indicar",
    "indicáreis": "indicar",
    "indicásseis": "indicar",
    "indicássemos": "indicar",
    "indicávamo": "indicar",
    "indicávamos": "indicar",
    "indicávei": "indicar",
    "indicáveis": "indicar",
    "indicãs": "indicã",
    "indicções": "indicção",
    "indifamáveis": "indifamável",
    "indiferenciada": "indiferenciado",
    "indiferenciadas": "indiferenciado",
    "indiferenciados": "indiferenciado",
    "indiferenciáveis": "indiferenciável",
    "indiferentes": "indiferente",
    "indiferentismos": "indiferentismo",
    "indiferentistas": "indiferentista",
    "indiferenças": "indiferença",
    "indiferençáveis": "indiferençável",
    "indifundíveis": "indifundível",
    "indigenatos": "indigenato",
    "indigentes": "indigente",
    "indigeríveis": "indigerível",
    "indigesta": "indigesto",
    "indigestas": "indigesto",
    "indigestibilidades": "indigestibilidade",
    "indigestos": "indigesto",
    "indigestíveis": "indigestível",
    "indigestões": "indigestão",
    "indigita": "indigitar",
    "indigitada": "indigitar",
    "indigitadas": "indigitar",
    "indigitado": "indigitar",
    "indigitados": "indigitar",
    "indigitai": "indigitar",
    "indigitais": "indigitar",
    "indigitam": "indigitar",
    "indigitamentos": "indigitamento",
    "indigitamo": "indigitar",
    "indigitamos": "indigitar",
    "indigitando": "indigitar",
    "indigitara": "indigitar",
    "indigitaram": "indigitar",
    "indigitaras": "indigitar",
    "indigitarde": "indigitar",
    "indigitardes": "indigitar",
    "indigitare": "indigitar",
    "indigitarei": "indigitar",
    "indigitareis": "indigitar",
    "indigitarem": "indigitar",
    "indigitaremos": "indigitar",
    "indigitares": "indigitar",
    "indigitaria": "indigitar",
    "indigitariam": "indigitar",
    "indigitarias": "indigitar",
    "indigitarmo": "indigitar",
    "indigitarmos": "indigitar",
    "indigitará": "indigitar",
    "indigitarás": "indigitar",
    "indigitarão": "indigitar",
    "indigitaríamos": "indigitar",
    "indigitaríeis": "indigitar",
    "indigitas": "indigitar",
    "indigitasse": "indigitar",
    "indigitassem": "indigitar",
    "indigitasses": "indigitar",
    "indigitaste": "indigitar",
    "indigitastes": "indigitar",
    "indigitava": "indigitar",
    "indigitavam": "indigitar",
    "indigitavas": "indigitar",
    "indigitações": "indigitação",
    "indigite": "indigitar",
    "indigitei": "indigitar",
    "indigiteis": "indigitar",
    "indigitem": "indigitar",
    "indigitemo": "indigitar",
    "indigitemos": "indigitar",
    "indigites": "indigitar",
    "indigito": "indigitar",
    "indigitou": "indigitar",
    "indigitá": "indigitar",
    "indigitámo": "indigitar",
    "indigitámos": "indigitar",
    "indigitáramo": "indigitar",
    "indigitáramos": "indigitar",
    "indigitárei": "indigitar",
    "indigitáreis": "indigitar",
    "indigitásseis": "indigitar",
    "indigitássemos": "indigitar",
    "indigitávamo": "indigitar",
    "indigitávamos": "indigitar",
    "indigitávei": "indigitar",
    "indigitáveis": "indigitável",
    "indigna": "indigno",
    "indignada": "indignar",
    "indignadas": "indignar",
    "indignado": "indignar",
    "indignados": "indignar",
    "indignadíssima": "indignado",
    "indignadíssimas": "indignado",
    "indignadíssimo": "indignado",
    "indignadíssimos": "indignado",
    "indignai": "indignar",
    "indignais": "indignar",
    "indignam": "indignar",
    "indignamo": "indignar",
    "indignamos": "indignar",
    "indignando": "indignar",
    "indignantes": "indignante",
    "indignara": "indignar",
    "indignaram": "indignar",
    "indignaras": "indignar",
    "indignarde": "indignar",
    "indignardes": "indignar",
    "indignare": "indignar",
    "indignarei": "indignar",
    "indignareis": "indignar",
    "indignarem": "indignar",
    "indignaremos": "indignar",
    "indignares": "indignar",
    "indignaria": "indignar",
    "indignariam": "indignar",
    "indignarias": "indignar",
    "indignarmo": "indignar",
    "indignarmos": "indignar",
    "indignará": "indignar",
    "indignarás": "indignar",
    "indignarão": "indignar",
    "indignaríamos": "indignar",
    "indignaríeis": "indignar",
    "indignas": "indigno",
    "indignasse": "indignar",
    "indignassem": "indignar",
    "indignasses": "indignar",
    "indignaste": "indignar",
    "indignastes": "indignar",
    "indignativa": "indignativo",
    "indignativas": "indignativo",
    "indignativos": "indignativo",
    "indignava": "indignar",
    "indignavam": "indignar",
    "indignavas": "indignar",
    "indignações": "indignação",
    "indigne": "indignar",
    "indignei": "indignar",
    "indigneis": "indignar",
    "indignem": "indignar",
    "indignemo": "indignar",
    "indignemos": "indignar",
    "indignes": "indignar",
    "indignidades": "indignidade",
    "indigno": "indignar",
    "indignos": "indigno",
    "indignou": "indignar",
    "indigná": "indignar",
    "indignámo": "indignar",
    "indignámos": "indignar",
    "indignáramo": "indignar",
    "indignáramos": "indignar",
    "indignárei": "indignar",
    "indignáreis": "indignar",
    "indignásseis": "indignar",
    "indignássemos": "indignar",
    "indignávamo": "indignar",
    "indignávamos": "indignar",
    "indignávei": "indignar",
    "indignáveis": "indignar",
    "indigoteiros": "indigoteiro",
    "indigueiros": "indigueiro",
    "indigências": "indigência",
    "indilatáveis": "indilatável",
    "indiligentes": "indiligente",
    "indiligências": "indiligência",
    "indiluíveis": "indiluível",
    "indimensionáveis": "indimensionável",
    "indinamitáveis": "indinamitável",
    "indinamizáveis": "indinamizável",
    "indinos": "indino",
    "indique": "indicar",
    "indiquei": "indicar",
    "indiqueis": "indicar",
    "indiquem": "indicar",
    "indiquemo": "indicar",
    "indiquemos": "indicar",
    "indiques": "indicar",
    "indirecta": "indirecto",
    "indirectas": "indirecto",
    "indirectos": "indirecto",
    "indirigíveis": "indirigível",
    "indiscernibilidades": "indiscernibilidade",
    "indiscernimentos": "indiscernimento",
    "indiscerníveis": "indiscernível",
    "indisciplina": "indisciplinar",
    "indisciplinabilidades": "indisciplinabilidade",
    "indisciplinada": "indisciplinar",
    "indisciplinadas": "indisciplinar",
    "indisciplinado": "indisciplinar",
    "indisciplinados": "indisciplinar",
    "indisciplinai": "indisciplinar",
    "indisciplinais": "indisciplinar",
    "indisciplinam": "indisciplinar",
    "indisciplinamo": "indisciplinar",
    "indisciplinamos": "indisciplinar",
    "indisciplinando": "indisciplinar",
    "indisciplinara": "indisciplinar",
    "indisciplinaram": "indisciplinar",
    "indisciplinaras": "indisciplinar",
    "indisciplinarde": "indisciplinar",
    "indisciplinardes": "indisciplinar",
    "indisciplinare": "indisciplinar",
    "indisciplinarei": "indisciplinar",
    "indisciplinareis": "indisciplinar",
    "indisciplinarem": "indisciplinar",
    "indisciplinaremos": "indisciplinar",
    "indisciplinares": "indisciplinar",
    "indisciplinaria": "indisciplinar",
    "indisciplinariam": "indisciplinar",
    "indisciplinarias": "indisciplinar",
    "indisciplinarmo": "indisciplinar",
    "indisciplinarmos": "indisciplinar",
    "indisciplinará": "indisciplinar",
    "indisciplinarás": "indisciplinar",
    "indisciplinarão": "indisciplinar",
    "indisciplinaríamos": "indisciplinar",
    "indisciplinaríeis": "indisciplinar",
    "indisciplinas": "indisciplinar",
    "indisciplinasse": "indisciplinar",
    "indisciplinassem": "indisciplinar",
    "indisciplinasses": "indisciplinar",
    "indisciplinaste": "indisciplinar",
    "indisciplinastes": "indisciplinar",
    "indisciplinava": "indisciplinar",
    "indisciplinavam": "indisciplinar",
    "indisciplinavas": "indisciplinar",
    "indisciplinações": "indisciplinação",
    "indiscipline": "indisciplinar",
    "indisciplinei": "indisciplinar",
    "indisciplineis": "indisciplinar",
    "indisciplinem": "indisciplinar",
    "indisciplinemo": "indisciplinar",
    "indisciplinemos": "indisciplinar",
    "indisciplines": "indisciplinar",
    "indisciplino": "indisciplinar",
    "indisciplinou": "indisciplinar",
    "indiscipliná": "indisciplinar",
    "indisciplinámo": "indisciplinar",
    "indisciplinámos": "indisciplinar",
    "indisciplináramo": "indisciplinar",
    "indisciplináramos": "indisciplinar",
    "indisciplinárei": "indisciplinar",
    "indisciplináreis": "indisciplinar",
    "indisciplinásseis": "indisciplinar",
    "indisciplinássemos": "indisciplinar",
    "indisciplinávamo": "indisciplinar",
    "indisciplinávamos": "indisciplinar",
    "indisciplinávei": "indisciplinar",
    "indisciplináveis": "indisciplinável",
    "indiscreta": "indiscreto",
    "indiscretas": "indiscreto",
    "indiscretos": "indiscreto",
    "indiscriminada": "indiscriminado",
    "indiscriminadas": "indiscriminado",
    "indiscriminados": "indiscriminado",
    "indiscriminações": "indiscriminação",
    "indiscrimináveis": "indiscriminável",
    "indiscrições": "indiscrição",
    "indiscutibilidades": "indiscutibilidade",
    "indiscutíveis": "indiscutível",
    "indisfarçada": "indisfarçado",
    "indisfarçadas": "indisfarçado",
    "indisfarçados": "indisfarçado",
    "indisfarçáveis": "indisfarçável",
    "indisparáveis": "indisparável",
    "indispensabilidades": "indispensabilidade",
    "indispensáveis": "indispensável",
    "indispomo": "indispor",
    "indispomos": "indispor",
    "indisponde": "indispor",
    "indispondes": "indispor",
    "indispondo": "indispor",
    "indisponha": "indispor",
    "indisponhais": "indispor",
    "indisponham": "indispor",
    "indisponhamo": "indispor",
    "indisponhamos": "indispor",
    "indisponhas": "indispor",
    "indisponho": "indispor",
    "indisponibilidades": "indisponibilidade",
    "indisponíveis": "indisponível",
    "indisporde": "indispor",
    "indispordes": "indispor",
    "indispore": "indispor",
    "indisporei": "indispor",
    "indisporeis": "indispor",
    "indisporem": "indispor",
    "indisporemos": "indispor",
    "indispores": "indispor",
    "indisporia": "indispor",
    "indisporiam": "indispor",
    "indisporias": "indispor",
    "indispormo": "indispor",
    "indispormos": "indispor",
    "indisporá": "indispor",
    "indisporás": "indispor",
    "indisporão": "indispor",
    "indisporíamos": "indispor",
    "indisporíeis": "indispor",
    "indisposições": "indisposição",
    "indisposta": "indisposto",
    "indispostas": "indisposto",
    "indisposto": "indispor",
    "indispostos": "indisposto",
    "indispunha": "indispor",
    "indispunham": "indispor",
    "indispunhas": "indispor",
    "indispus": "indispor",
    "indispusemo": "indispor",
    "indispusemos": "indispor",
    "indispuser": "indispor",
    "indispusera": "indispor",
    "indispuseram": "indispor",
    "indispuseras": "indispor",
    "indispuserdes": "indispor",
    "indispuserem": "indispor",
    "indispuseres": "indispor",
    "indispusermos": "indispor",
    "indispusesse": "indispor",
    "indispusessem": "indispor",
    "indispusesses": "indispor",
    "indispuseste": "indispor",
    "indispusestes": "indispor",
    "indispuséramo": "indispor",
    "indispuséramos": "indispor",
    "indispusérei": "indispor",
    "indispuséreis": "indispor",
    "indispusésseis": "indispor",
    "indispuséssemos": "indispor",
    "indisputabilidades": "indisputabilidade",
    "indisputada": "indisputado",
    "indisputadas": "indisputado",
    "indisputados": "indisputado",
    "indisputáveis": "indisputável",
    "indispíveis": "indispível",
    "indispô": "indispor",
    "indispôs": "indispor",
    "indispõe": "indispor",
    "indispõem": "indispor",
    "indispões": "indispor",
    "indispúnhamo": "indispor",
    "indispúnhamos": "indispor",
    "indispúnhei": "indispor",
    "indispúnheis": "indispor",
    "indissemináveis": "indisseminável",
    "indissimuláveis": "indissimulável",
    "indissipáveis": "indissipável",
    "indissociabilidades": "indissociabilidade",
    "indissociáveis": "indissociável",
    "indissolubilidades": "indissolubilidade",
    "indissoluções": "indissolução",
    "indissolúveis": "indissolúvel",
    "indistensíveis": "indistensível",
    "indistinguíveis": "indistinguível",
    "indistinta": "indistinto",
    "indistintas": "indistinto",
    "indistintos": "indistinto",
    "indistinções": "indistinção",
    "indistorcíveis": "indistorcível",
    "indistribuíveis": "indistribuível",
    "inditosa": "inditoso",
    "inditosas": "inditoso",
    "inditosos": "inditoso",
    "individua": "individuar",
    "individuada": "individuar",
    "individuadas": "individuar",
    "individuado": "individuar",
    "individuadora": "individuador",
    "individuadoras": "individuador",
    "individuadores": "individuador",
    "individuados": "individuar",
    "individuai": "individuar",
    "individuais": "individuar",
    "individualidades": "individualidade",
    "individualismos": "individualismo",
    "individualistas": "individualista",
    "individualiza": "individualizar",
    "individualizada": "individualizar",
    "individualizadas": "individualizar",
    "individualizado": "individualizar",
    "individualizados": "individualizar",
    "individualizai": "individualizar",
    "individualizais": "individualizar",
    "individualizam": "individualizar",
    "individualizamo": "individualizar",
    "individualizamos": "individualizar",
    "individualizando": "individualizar",
    "individualizantes": "individualizante",
    "individualizara": "individualizar",
    "individualizaram": "individualizar",
    "individualizaras": "individualizar",
    "individualizarde": "individualizar",
    "individualizardes": "individualizar",
    "individualizare": "individualizar",
    "individualizarei": "individualizar",
    "individualizareis": "individualizar",
    "individualizarem": "individualizar",
    "individualizaremos": "individualizar",
    "individualizares": "individualizar",
    "individualizaria": "individualizar",
    "individualizariam": "individualizar",
    "individualizarias": "individualizar",
    "individualizarmo": "individualizar",
    "individualizarmos": "individualizar",
    "individualizará": "individualizar",
    "individualizarás": "individualizar",
    "individualizarão": "individualizar",
    "individualizaríamos": "individualizar",
    "individualizaríeis": "individualizar",
    "individualizas": "individualizar",
    "individualizasse": "individualizar",
    "individualizassem": "individualizar",
    "individualizasses": "individualizar",
    "individualizaste": "individualizar",
    "individualizastes": "individualizar",
    "individualizava": "individualizar",
    "individualizavam": "individualizar",
    "individualizavas": "individualizar",
    "individualizações": "individualização",
    "individualize": "individualizar",
    "individualizei": "individualizar",
    "individualizeis": "individualizar",
    "individualizem": "individualizar",
    "individualizemo": "individualizar",
    "individualizemos": "individualizar",
    "individualizes": "individualizar",
    "individualizo": "individualizar",
    "individualizou": "individualizar",
    "individualizá": "individualizar",
    "individualizámo": "individualizar",
    "individualizámos": "individualizar",
    "individualizáramo": "individualizar",
    "individualizáramos": "individualizar",
    "individualizárei": "individualizar",
    "individualizáreis": "individualizar",
    "individualizásseis": "individualizar",
    "individualizássemos": "individualizar",
    "individualizávamo": "individualizar",
    "individualizávamos": "individualizar",
    "individualizávei": "individualizar",
    "individualizáveis": "individualizável",
    "individuam": "individuar",
    "individuamo": "individuar",
    "individuamos": "individuar",
    "individuando": "individuar",
    "individuantes": "individuante",
    "individuara": "individuar",
    "individuaram": "individuar",
    "individuaras": "individuar",
    "individuarde": "individuar",
    "individuardes": "individuar",
    "individuare": "individuar",
    "individuarei": "individuar",
    "individuareis": "individuar",
    "individuarem": "individuar",
    "individuaremos": "individuar",
    "individuares": "individuar",
    "individuaria": "individuar",
    "individuariam": "individuar",
    "individuarias": "individuar",
    "individuarmo": "individuar",
    "individuarmos": "individuar",
    "individuará": "individuar",
    "individuarás": "individuar",
    "individuarão": "individuar",
    "individuaríamos": "individuar",
    "individuaríeis": "individuar",
    "individuas": "individuar",
    "individuasse": "individuar",
    "individuassem": "individuar",
    "individuasses": "individuar",
    "individuaste": "individuar",
    "individuastes": "individuar",
    "individuava": "individuar",
    "individuavam": "individuar",
    "individuavas": "individuar",
    "individuações": "individuação",
    "individue": "individuar",
    "individuei": "individuar",
    "individueis": "individuar",
    "individuem": "individuar",
    "individuemo": "individuar",
    "individuemos": "individuar",
    "individues": "individuar",
    "individuo": "individuar",
    "individuou": "individuar",
    "individuá": "individuar",
    "individuámo": "individuar",
    "individuámos": "individuar",
    "individuáramo": "individuar",
    "individuáramos": "individuar",
    "individuárei": "individuar",
    "individuáreis": "individuar",
    "individuásseis": "individuar",
    "individuássemos": "individuar",
    "individuávamo": "individuar",
    "individuávamos": "individuar",
    "individuávei": "individuar",
    "individuáveis": "individuável",
    "indivisa": "indiviso",
    "indivisas": "indiviso",
    "indivisibilidades": "indivisibilidade",
    "indivisos": "indiviso",
    "indivisíveis": "indivisível",
    "indivisões": "indivisão",
    "indivulgáveis": "indivulgável",
    "indivídua": "indivíduo",
    "indivíduas": "indivíduo",
    "indivíduos": "indivíduo",
    "indizíveis": "indizível",
    "indiática": "indiático",
    "indiáticas": "indiático",
    "indiáticos": "indiático",
    "indo": "ir",
    "indobráveis": "indobrável",
    "indochinas": "indochina",
    "indochinesa": "indochinês",
    "indochinesas": "indochinês",
    "indochineses": "indochinês",
    "indochins": "indochim",
    "indocilidades": "indocilidade",
    "indociliza": "indocilizar",
    "indocilizada": "indocilizar",
    "indocilizadas": "indocilizar",
    "indocilizado": "indocilizar",
    "indocilizados": "indocilizar",
    "indocilizai": "indocilizar",
    "indocilizais": "indocilizar",
    "indocilizam": "indocilizar",
    "indocilizamo": "indocilizar",
    "indocilizamos": "indocilizar",
    "indocilizando": "indocilizar",
    "indocilizara": "indocilizar",
    "indocilizaram": "indocilizar",
    "indocilizaras": "indocilizar",
    "indocilizarde": "indocilizar",
    "indocilizardes": "indocilizar",
    "indocilizare": "indocilizar",
    "indocilizarei": "indocilizar",
    "indocilizareis": "indocilizar",
    "indocilizarem": "indocilizar",
    "indocilizaremos": "indocilizar",
    "indocilizares": "indocilizar",
    "indocilizaria": "indocilizar",
    "indocilizariam": "indocilizar",
    "indocilizarias": "indocilizar",
    "indocilizarmo": "indocilizar",
    "indocilizarmos": "indocilizar",
    "indocilizará": "indocilizar",
    "indocilizarás": "indocilizar",
    "indocilizarão": "indocilizar",
    "indocilizaríamos": "indocilizar",
    "indocilizaríeis": "indocilizar",
    "indocilizas": "indocilizar",
    "indocilizasse": "indocilizar",
    "indocilizassem": "indocilizar",
    "indocilizasses": "indocilizar",
    "indocilizaste": "indocilizar",
    "indocilizastes": "indocilizar",
    "indocilizava": "indocilizar",
    "indocilizavam": "indocilizar",
    "indocilizavas": "indocilizar",
    "indocilize": "indocilizar",
    "indocilizei": "indocilizar",
    "indocilizeis": "indocilizar",
    "indocilizem": "indocilizar",
    "indocilizemo": "indocilizar",
    "indocilizemos": "indocilizar",
    "indocilizes": "indocilizar",
    "indocilizo": "indocilizar",
    "indocilizou": "indocilizar",
    "indocilizá": "indocilizar",
    "indocilizámo": "indocilizar",
    "indocilizámos": "indocilizar",
    "indocilizáramo": "indocilizar",
    "indocilizáramos": "indocilizar",
    "indocilizárei": "indocilizar",
    "indocilizáreis": "indocilizar",
    "indocilizásseis": "indocilizar",
    "indocilizássemos": "indocilizar",
    "indocilizávamo": "indocilizar",
    "indocilizávamos": "indocilizar",
    "indocilizávei": "indocilizar",
    "indocilizáveis": "indocilizar",
    "indocumentada": "indocumentado",
    "indocumentadas": "indocumentado",
    "indocumentados": "indocumentado",
    "indocumentáveis": "indocumentável",
    "indolentes": "indolente",
    "indologias": "indologia",
    "indolores": "indolor",
    "indolências": "indolência",
    "indomada": "indomado",
    "indomadas": "indomado",
    "indomados": "indomado",
    "indomesticabilidades": "indomesticabilidade",
    "indomesticada": "indomesticado",
    "indomesticadas": "indomesticado",
    "indomesticados": "indomesticado",
    "indomesticáveis": "indomesticável",
    "indomináveis": "indominável",
    "indomáveis": "indomável",
    "indoméstica": "indoméstico",
    "indomésticas": "indoméstico",
    "indomésticos": "indoméstico",
    "indonas": "indona",
    "indonésia": "indonésio",
    "indonésias": "indonésio",
    "indonésios": "indonésio",
    "indos": "indo",
    "indostana": "indostano",
    "indostanas": "indostano",
    "indostanos": "indostano",
    "indostânica": "indostânico",
    "indostânicas": "indostânico",
    "indostânicos": "indostânico",
    "indouta": "indouto",
    "indoutas": "indouto",
    "indoutos": "indouto",
    "indoáveis": "indoável",
    "indribláveis": "indriblável",
    "indromina": "indrominar",
    "indrominada": "indrominar",
    "indrominadas": "indrominar",
    "indrominado": "indrominar",
    "indrominados": "indrominar",
    "indrominai": "indrominar",
    "indrominais": "indrominar",
    "indrominam": "indrominar",
    "indrominamo": "indrominar",
    "indrominamos": "indrominar",
    "indrominando": "indrominar",
    "indrominara": "indrominar",
    "indrominaram": "indrominar",
    "indrominaras": "indrominar",
    "indrominarde": "indrominar",
    "indrominardes": "indrominar",
    "indrominare": "indrominar",
    "indrominarei": "indrominar",
    "indrominareis": "indrominar",
    "indrominarem": "indrominar",
    "indrominaremos": "indrominar",
    "indrominares": "indrominar",
    "indrominaria": "indrominar",
    "indrominariam": "indrominar",
    "indrominarias": "indrominar",
    "indrominarmo": "indrominar",
    "indrominarmos": "indrominar",
    "indrominará": "indrominar",
    "indrominarás": "indrominar",
    "indrominarão": "indrominar",
    "indrominaríamos": "indrominar",
    "indrominaríeis": "indrominar",
    "indrominas": "indrominar",
    "indrominasse": "indrominar",
    "indrominassem": "indrominar",
    "indrominasses": "indrominar",
    "indrominaste": "indrominar",
    "indrominastes": "indrominar",
    "indrominava": "indrominar",
    "indrominavam": "indrominar",
    "indrominavas": "indrominar",
    "indromine": "indrominar",
    "indrominei": "indrominar",
    "indromineis": "indrominar",
    "indrominem": "indrominar",
    "indrominemo": "indrominar",
    "indrominemos": "indrominar",
    "indromines": "indrominar",
    "indromino": "indrominar",
    "indrominou": "indrominar",
    "indrominá": "indrominar",
    "indrominámo": "indrominar",
    "indrominámos": "indrominar",
    "indromináramo": "indrominar",
    "indromináramos": "indrominar",
    "indrominárei": "indrominar",
    "indromináreis": "indrominar",
    "indrominásseis": "indrominar",
    "indrominássemos": "indrominar",
    "indrominávamo": "indrominar",
    "indrominávamos": "indrominar",
    "indrominávei": "indrominar",
    "indromináveis": "indrominável",
    "indubitada": "indubitado",
    "indubitadas": "indubitado",
    "indubitados": "indubitado",
    "indubitáveis": "indubitável",
    "inducta": "inducto",
    "inductas": "inducto",
    "inductilidades": "inductilidade",
    "inductos": "inducto",
    "indulgentes": "indulgente",
    "indulgências": "indulgência",
    "indulta": "indultar",
    "indultada": "indultar",
    "indultadas": "indultar",
    "indultado": "indultar",
    "indultados": "indultar",
    "indultai": "indultar",
    "indultais": "indultar",
    "indultam": "indultar",
    "indultamo": "indultar",
    "indultamos": "indultar",
    "indultando": "indultar",
    "indultara": "indultar",
    "indultaram": "indultar",
    "indultaras": "indultar",
    "indultarde": "indultar",
    "indultardes": "indultar",
    "indultare": "indultar",
    "indultarei": "indultar",
    "indultareis": "indultar",
    "indultarem": "indultar",
    "indultaremos": "indultar",
    "indultares": "indultar",
    "indultaria": "indultar",
    "indultariam": "indultar",
    "indultarias": "indultar",
    "indultarmo": "indultar",
    "indultarmos": "indultar",
    "indultará": "indultar",
    "indultarás": "indultar",
    "indultarão": "indultar",
    "indultaríamos": "indultar",
    "indultaríeis": "indultar",
    "indultas": "indultar",
    "indultasse": "indultar",
    "indultassem": "indultar",
    "indultasses": "indultar",
    "indultaste": "indultar",
    "indultastes": "indultar",
    "indultava": "indultar",
    "indultavam": "indultar",
    "indultavas": "indultar",
    "indulte": "indultar",
    "indultei": "indultar",
    "indulteis": "indultar",
    "indultem": "indultar",
    "indultemo": "indultar",
    "indultemos": "indultar",
    "indultes": "indultar",
    "indulto": "indultar",
    "indultos": "indulto",
    "indultou": "indultar",
    "indultá": "indultar",
    "indultámo": "indultar",
    "indultámos": "indultar",
    "indultáramo": "indultar",
    "indultáramos": "indultar",
    "indultárei": "indultar",
    "indultáreis": "indultar",
    "indultária": "indultário",
    "indultárias": "indultário",
    "indultários": "indultário",
    "indultásseis": "indultar",
    "indultássemos": "indultar",
    "indultávamo": "indultar",
    "indultávamos": "indultar",
    "indultávei": "indultar",
    "indultáveis": "indultável",
    "indumenta": "indumentar",
    "indumentada": "indumentar",
    "indumentadas": "indumentar",
    "indumentado": "indumentar",
    "indumentados": "indumentar",
    "indumentai": "indumentar",
    "indumentais": "indumentar",
    "indumentam": "indumentar",
    "indumentamo": "indumentar",
    "indumentamos": "indumentar",
    "indumentando": "indumentar",
    "indumentara": "indumentar",
    "indumentaram": "indumentar",
    "indumentaras": "indumentar",
    "indumentarde": "indumentar",
    "indumentardes": "indumentar",
    "indumentare": "indumentar",
    "indumentarei": "indumentar",
    "indumentareis": "indumentar",
    "indumentarem": "indumentar",
    "indumentaremos": "indumentar",
    "indumentares": "indumentar",
    "indumentaria": "indumentar",
    "indumentariam": "indumentar",
    "indumentarias": "indumentar",
    "indumentarmo": "indumentar",
    "indumentarmos": "indumentar",
    "indumentará": "indumentar",
    "indumentarás": "indumentar",
    "indumentarão": "indumentar",
    "indumentaríamos": "indumentar",
    "indumentaríeis": "indumentar",
    "indumentas": "indumentar",
    "indumentasse": "indumentar",
    "indumentassem": "indumentar",
    "indumentasses": "indumentar",
    "indumentaste": "indumentar",
    "indumentastes": "indumentar",
    "indumentava": "indumentar",
    "indumentavam": "indumentar",
    "indumentavas": "indumentar",
    "indumente": "indumentar",
    "indumentei": "indumentar",
    "indumenteis": "indumentar",
    "indumentem": "indumentar",
    "indumentemo": "indumentar",
    "indumentemos": "indumentar",
    "indumentes": "indumentar",
    "indumento": "indumentar",
    "indumentos": "indumento",
    "indumentou": "indumentar",
    "indumentá": "indumentar",
    "indumentámo": "indumentar",
    "indumentámos": "indumentar",
    "indumentáramo": "indumentar",
    "indumentáramos": "indumentar",
    "indumentárei": "indumentar",
    "indumentáreis": "indumentar",
    "indumentária": "indumentário",
    "indumentárias": "indumentário",
    "indumentários": "indumentário",
    "indumentásseis": "indumentar",
    "indumentássemos": "indumentar",
    "indumentávamo": "indumentar",
    "indumentávamos": "indumentar",
    "indumentávei": "indumentar",
    "indumentáveis": "indumentar",
    "induplicada": "induplicado",
    "induplicadas": "induplicado",
    "induplicados": "induplicado",
    "indurações": "induração",
    "induros": "induro",
    "industria": "industriar",
    "industriada": "industriar",
    "industriadas": "industriar",
    "industriado": "industriar",
    "industriadora": "industriador",
    "industriadoras": "industriador",
    "industriadores": "industriador",
    "industriados": "industriar",
    "industriai": "industriar",
    "industriais": "industriar",
    "industrialismos": "industrialismo",
    "industrialistas": "industrialista",
    "industrializa": "industrializar",
    "industrializada": "industrializar",
    "industrializadas": "industrializar",
    "industrializado": "industrializar",
    "industrializados": "industrializar",
    "industrializai": "industrializar",
    "industrializais": "industrializar",
    "industrializam": "industrializar",
    "industrializamo": "industrializar",
    "industrializamos": "industrializar",
    "industrializando": "industrializar",
    "industrializara": "industrializar",
    "industrializaram": "industrializar",
    "industrializaras": "industrializar",
    "industrializarde": "industrializar",
    "industrializardes": "industrializar",
    "industrializare": "industrializar",
    "industrializarei": "industrializar",
    "industrializareis": "industrializar",
    "industrializarem": "industrializar",
    "industrializaremos": "industrializar",
    "industrializares": "industrializar",
    "industrializaria": "industrializar",
    "industrializariam": "industrializar",
    "industrializarias": "industrializar",
    "industrializarmo": "industrializar",
    "industrializarmos": "industrializar",
    "industrializará": "industrializar",
    "industrializarás": "industrializar",
    "industrializarão": "industrializar",
    "industrializaríamos": "industrializar",
    "industrializaríeis": "industrializar",
    "industrializas": "industrializar",
    "industrializasse": "industrializar",
    "industrializassem": "industrializar",
    "industrializasses": "industrializar",
    "industrializaste": "industrializar",
    "industrializastes": "industrializar",
    "industrializava": "industrializar",
    "industrializavam": "industrializar",
    "industrializavas": "industrializar",
    "industrializações": "industrialização",
    "industrialize": "industrializar",
    "industrializei": "industrializar",
    "industrializeis": "industrializar",
    "industrializem": "industrializar",
    "industrializemo": "industrializar",
    "industrializemos": "industrializar",
    "industrializes": "industrializar",
    "industrializo": "industrializar",
    "industrializou": "industrializar",
    "industrializá": "industrializar",
    "industrializámo": "industrializar",
    "industrializámos": "industrializar",
    "industrializáramo": "industrializar",
    "industrializáramos": "industrializar",
    "industrializárei": "industrializar",
    "industrializáreis": "industrializar",
    "industrializásseis": "industrializar",
    "industrializássemos": "industrializar",
    "industrializávamo": "industrializar",
    "industrializávamos": "industrializar",
    "industrializávei": "industrializar",
    "industrializáveis": "industrializável",
    "industriam": "industriar",
    "industriamo": "industriar",
    "industriamos": "industriar",
    "industriando": "industriar",
    "industriara": "industriar",
    "industriaram": "industriar",
    "industriaras": "industriar",
    "industriarde": "industriar",
    "industriardes": "industriar",
    "industriare": "industriar",
    "industriarei": "industriar",
    "industriareis": "industriar",
    "industriarem": "industriar",
    "industriaremos": "industriar",
    "industriares": "industriar",
    "industriaria": "industriar",
    "industriariam": "industriar",
    "industriarias": "industriar",
    "industriarmo": "industriar",
    "industriarmos": "industriar",
    "industriará": "industriar",
    "industriarás": "industriar",
    "industriarão": "industriar",
    "industriaríamos": "industriar",
    "industriaríeis": "industriar",
    "industrias": "industriar",
    "industriasse": "industriar",
    "industriassem": "industriar",
    "industriasses": "industriar",
    "industriaste": "industriar",
    "industriastes": "industriar",
    "industriava": "industriar",
    "industriavam": "industriar",
    "industriavas": "industriar",
    "industrie": "industriar",
    "industriei": "industriar",
    "industrieis": "industriar",
    "industriem": "industriar",
    "industriemo": "industriar",
    "industriemos": "industriar",
    "industries": "industriar",
    "industrio": "industriar",
    "industriosa": "industrioso",
    "industriosas": "industrioso",
    "industriosos": "industrioso",
    "industriou": "industriar",
    "industriá": "industriar",
    "industriámo": "industriar",
    "industriámos": "industriar",
    "industriáramo": "industriar",
    "industriáramos": "industriar",
    "industriárei": "industriar",
    "industriáreis": "industriar",
    "industriásseis": "industriar",
    "industriássemos": "industriar",
    "industriávamo": "industriar",
    "industriávamos": "industriar",
    "industriávei": "industriar",
    "industriáveis": "industriável",
    "induta": "indutar",
    "indutada": "indutar",
    "indutadas": "indutar",
    "indutado": "indutar",
    "indutados": "indutar",
    "indutai": "indutar",
    "indutais": "indutar",
    "indutam": "indutar",
    "indutamo": "indutar",
    "indutamos": "indutar",
    "indutando": "indutar",
    "indutara": "indutar",
    "indutaram": "indutar",
    "indutaras": "indutar",
    "indutarde": "indutar",
    "indutardes": "indutar",
    "indutare": "indutar",
    "indutarei": "indutar",
    "indutareis": "indutar",
    "indutarem": "indutar",
    "indutaremos": "indutar",
    "indutares": "indutar",
    "indutaria": "indutar",
    "indutariam": "indutar",
    "indutarias": "indutar",
    "indutarmo": "indutar",
    "indutarmos": "indutar",
    "indutará": "indutar",
    "indutarás": "indutar",
    "indutarão": "indutar",
    "indutaríamos": "indutar",
    "indutaríeis": "indutar",
    "indutas": "indutar",
    "indutasse": "indutar",
    "indutassem": "indutar",
    "indutasses": "indutar",
    "indutaste": "indutar",
    "indutastes": "indutar",
    "indutava": "indutar",
    "indutavam": "indutar",
    "indutavas": "indutar",
    "indute": "indutar",
    "indutei": "indutar",
    "induteis": "indutar",
    "indutem": "indutar",
    "indutemo": "indutar",
    "indutemos": "indutar",
    "indutes": "indutar",
    "indutiva": "indutivo",
    "indutivas": "indutivo",
    "indutivos": "indutivo",
    "induto": "indutar",
    "indutora": "indutor",
    "indutoras": "indutor",
    "indutores": "indutor",
    "indutos": "induto",
    "indutou": "indutar",
    "indutá": "indutar",
    "indutámo": "indutar",
    "indutámos": "indutar",
    "indutáramo": "indutar",
    "indutáramos": "indutar",
    "indutárei": "indutar",
    "indutáreis": "indutar",
    "indutásseis": "indutar",
    "indutássemos": "indutar",
    "indutávamo": "indutar",
    "indutávamos": "indutar",
    "indutávei": "indutar",
    "indutáveis": "indutar",
    "indutâncias": "indutância",
    "indutómetros": "indutómetro",
    "induviada": "induviado",
    "induviadas": "induviado",
    "induviados": "induviado",
    "induviais": "induvial",
    "induz": "induzir",
    "induza": "induzir",
    "induzais": "induzir",
    "induzam": "induzir",
    "induzamo": "induzir",
    "induzamos": "induzir",
    "induzas": "induzir",
    "induze": "induzir",
    "induzem": "induzir",
    "induzes": "induzir",
    "induzi": "induzir",
    "induzia": "induzir",
    "induziam": "induzir",
    "induzias": "induzir",
    "induzida": "induzir",
    "induzidas": "induzir",
    "induzido": "induzir",
    "induzidora": "induzidor",
    "induzidoras": "induzidor",
    "induzidores": "induzidor",
    "induzidos": "induzir",
    "induzimentos": "induzimento",
    "induzimo": "induzir",
    "induzimos": "induzir",
    "induzindo": "induzir",
    "induzira": "induzir",
    "induziram": "induzir",
    "induziras": "induzir",
    "induzirde": "induzir",
    "induzirdes": "induzir",
    "induzire": "induzir",
    "induzirei": "induzir",
    "induzireis": "induzir",
    "induzirem": "induzir",
    "induziremos": "induzir",
    "induzires": "induzir",
    "induziria": "induzir",
    "induziriam": "induzir",
    "induzirias": "induzir",
    "induzirmo": "induzir",
    "induzirmos": "induzir",
    "induzirá": "induzir",
    "induzirás": "induzir",
    "induzirão": "induzir",
    "induziríamos": "induzir",
    "induziríeis": "induzir",
    "induzis": "induzir",
    "induzisse": "induzir",
    "induzissem": "induzir",
    "induzisses": "induzir",
    "induziste": "induzir",
    "induzistes": "induzir",
    "induziu": "induzir",
    "induzo": "induzir",
    "induzíamo": "induzir",
    "induzíamos": "induzir",
    "induzíei": "induzir",
    "induzíeis": "induzir",
    "induzíramo": "induzir",
    "induzíramos": "induzir",
    "induzírei": "induzir",
    "induzíreis": "induzir",
    "induzísseis": "induzir",
    "induzíssemos": "induzir",
    "induzíveis": "induzível",
    "induções": "indução",
    "indébita": "indébito",
    "indébitas": "indébito",
    "indébitos": "indébito",
    "indícios": "indício",
    "indículos": "indículo",
    "indígenas": "indígena",
    "indígetes": "indígete",
    "indóceis": "indócil",
    "indóloga": "indólogo",
    "indólogas": "indólogo",
    "indólogos": "indólogo",
    "indómita": "indómito",
    "indómitas": "indómito",
    "indómitos": "indómito",
    "indúcteis": "indúctil",
    "indúsias": "indúsia",
    "indúsios": "indúsio",
    "indústrias": "indústria",
    "indúvia": "indúvio",
    "indúvias": "indúvio",
    "indúvios": "indúvio",
    "inebria": "inebriar",
    "inebriada": "inebriar",
    "inebriadas": "inebriar",
    "inebriado": "inebriar",
    "inebriadora": "inebriador",
    "inebriadoras": "inebriador",
    "inebriadores": "inebriador",
    "inebriados": "inebriar",
    "inebriai": "inebriar",
    "inebriais": "inebriar",
    "inebriam": "inebriar",
    "inebriamentos": "inebriamento",
    "inebriamo": "inebriar",
    "inebriamos": "inebriar",
    "inebriando": "inebriar",
    "inebriantes": "inebriante",
    "inebriara": "inebriar",
    "inebriaram": "inebriar",
    "inebriaras": "inebriar",
    "inebriarde": "inebriar",
    "inebriardes": "inebriar",
    "inebriare": "inebriar",
    "inebriarei": "inebriar",
    "inebriareis": "inebriar",
    "inebriarem": "inebriar",
    "inebriaremos": "inebriar",
    "inebriares": "inebriar",
    "inebriaria": "inebriar",
    "inebriariam": "inebriar",
    "inebriarias": "inebriar",
    "inebriarmo": "inebriar",
    "inebriarmos": "inebriar",
    "inebriará": "inebriar",
    "inebriarás": "inebriar",
    "inebriarão": "inebriar",
    "inebriaríamos": "inebriar",
    "inebriaríeis": "inebriar",
    "inebrias": "inebriar",
    "inebriasse": "inebriar",
    "inebriassem": "inebriar",
    "inebriasses": "inebriar",
    "inebriaste": "inebriar",
    "inebriastes": "inebriar",
    "inebriava": "inebriar",
    "inebriavam": "inebriar",
    "inebriavas": "inebriar",
    "inebriações": "inebriação",
    "inebrie": "inebriar",
    "inebriei": "inebriar",
    "inebrieis": "inebriar",
    "inebriem": "inebriar",
    "inebriemo": "inebriar",
    "inebriemos": "inebriar",
    "inebries": "inebriar",
    "inebrio": "inebriar",
    "inebriou": "inebriar",
    "inebriá": "inebriar",
    "inebriámo": "inebriar",
    "inebriámos": "inebriar",
    "inebriáramo": "inebriar",
    "inebriáramos": "inebriar",
    "inebriárei": "inebriar",
    "inebriáreis": "inebriar",
    "inebriásseis": "inebriar",
    "inebriássemos": "inebriar",
    "inebriávamo": "inebriar",
    "inebriávamos": "inebriar",
    "inebriávei": "inebriar",
    "inebriáveis": "inebriar",
    "ineditismos": "ineditismo",
    "inefabilidades": "inefabilidade",
    "inefectuáveis": "inefectuável",
    "ineficazes": "ineficaz",
    "ineficientes": "ineficiente",
    "ineficiências": "ineficiência",
    "ineficácias": "ineficácia",
    "inefáveis": "inefável",
    "inegociáveis": "inegociável",
    "inegáveis": "inegável",
    "ineixas": "ineixa",
    "inelaboráveis": "inelaborável",
    "inelegantes": "inelegante",
    "inelegibilidades": "inelegibilidade",
    "inelegâncias": "inelegância",
    "inelegíveis": "inelegível",
    "inelidíveis": "inelidível",
    "ineloquentes": "ineloquente",
    "inelutáveis": "inelutável",
    "inelástica": "inelástico",
    "inelásticas": "inelástico",
    "inelásticos": "inelástico",
    "inembutíveis": "inembutível",
    "inemocionáveis": "inemocionável",
    "inenarráveis": "inenarrável",
    "inencaixáveis": "inencaixável",
    "inencobríveis": "inencobrível",
    "inencurtáveis": "inencurtável",
    "inendereçáveis": "inendereçável",
    "inenrugáveis": "inenrugável",
    "inentendíveis": "inentendível",
    "inentortáveis": "inentortável",
    "inepta": "inepto",
    "ineptas": "inepto",
    "ineptidões": "ineptidão",
    "ineptos": "inepto",
    "inequações": "inequação",
    "inequifaciais": "inequifacial",
    "inequilátera": "inequilátero",
    "inequiláteras": "inequilátero",
    "inequiláteros": "inequilátero",
    "inequivalves": "inequivalve",
    "inequívoca": "inequívoco",
    "inequívocas": "inequívoco",
    "inequívocos": "inequívoco",
    "inerentes": "inerente",
    "inermes": "inerme",
    "inerrantes": "inerrante",
    "inerrâncias": "inerrância",
    "inertes": "inerte",
    "inertâncias": "inertância",
    "inerva": "inervar",
    "inervada": "inervar",
    "inervadas": "inervar",
    "inervado": "inervar",
    "inervados": "inervar",
    "inervai": "inervar",
    "inervais": "inervar",
    "inervam": "inervar",
    "inervamo": "inervar",
    "inervamos": "inervar",
    "inervando": "inervar",
    "inervara": "inervar",
    "inervaram": "inervar",
    "inervaras": "inervar",
    "inervarde": "inervar",
    "inervardes": "inervar",
    "inervare": "inervar",
    "inervarei": "inervar",
    "inervareis": "inervar",
    "inervarem": "inervar",
    "inervaremos": "inervar",
    "inervares": "inervar",
    "inervaria": "inervar",
    "inervariam": "inervar",
    "inervarias": "inervar",
    "inervarmo": "inervar",
    "inervarmos": "inervar",
    "inervará": "inervar",
    "inervarás": "inervar",
    "inervarão": "inervar",
    "inervaríamos": "inervar",
    "inervaríeis": "inervar",
    "inervas": "inervar",
    "inervasse": "inervar",
    "inervassem": "inervar",
    "inervasses": "inervar",
    "inervaste": "inervar",
    "inervastes": "inervar",
    "inervava": "inervar",
    "inervavam": "inervar",
    "inervavas": "inervar",
    "inervações": "inervação",
    "inerve": "inervar",
    "inervei": "inervar",
    "inerveis": "inervar",
    "inervem": "inervar",
    "inervemo": "inervar",
    "inervemos": "inervar",
    "inerves": "inervar",
    "inervo": "inervar",
    "inervou": "inervar",
    "inervá": "inervar",
    "inervámo": "inervar",
    "inervámos": "inervar",
    "inerváramo": "inervar",
    "inerváramos": "inervar",
    "inervárei": "inervar",
    "inerváreis": "inervar",
    "inervásseis": "inervar",
    "inervássemos": "inervar",
    "inervávamo": "inervar",
    "inervávamos": "inervar",
    "inervávei": "inervar",
    "inerváveis": "inervar",
    "inerências": "inerência",
    "inescrutabilidades": "inescrutabilidade",
    "inescrutáveis": "inescrutável",
    "inescurecíveis": "inescurecível",
    "inesgotabilidades": "inesgotabilidade",
    "inesgotáveis": "inesgotável",
    "inesiana": "inesiano",
    "inesianas": "inesiano",
    "inesianos": "inesiano",
    "inesmagáveis": "inesmagável",
    "inesmaltáveis": "inesmaltável",
    "inespecificáveis": "inespecificável",
    "inesperada": "inesperado",
    "inesperadas": "inesperado",
    "inesperados": "inesperado",
    "inespoliáveis": "inespoliável",
    "inesquecíveis": "inesquecível",
    "inestancáveis": "inestancável",
    "inestendíveis": "inestendível",
    "inestimada": "inestimado",
    "inestimadas": "inestimado",
    "inestimados": "inestimado",
    "inestimáveis": "inestimável",
    "inestipuláveis": "inestipulável",
    "inestruturáveis": "inestruturável",
    "inestáveis": "inestável",
    "inestética": "inestético",
    "inestéticas": "inestético",
    "inestéticos": "inestético",
    "inevidentes": "inevidente",
    "inevidências": "inevidência",
    "inevitabilidades": "inevitabilidade",
    "inevitáveis": "inevitável",
    "inevocáveis": "inevocável",
    "inexacta": "inexacto",
    "inexactas": "inexacto",
    "inexactidões": "inexactidão",
    "inexactos": "inexacto",
    "inexamináveis": "inexaminável",
    "inexauribilidades": "inexauribilidade",
    "inexauríveis": "inexaurível",
    "inexausta": "inexausto",
    "inexaustas": "inexausto",
    "inexaustos": "inexausto",
    "inexcedíveis": "inexcedível",
    "inexcitabilidades": "inexcitabilidade",
    "inexcitáveis": "inexcitável",
    "inexcluíveis": "inexcluível",
    "inexcretáveis": "inexcretável",
    "inexcusáveis": "inexcusável",
    "inexecutáveis": "inexecutável",
    "inexecuções": "inexecução",
    "inexequibilidades": "inexequibilidade",
    "inexequíveis": "inexequível",
    "inexigíveis": "inexigível",
    "inexistentes": "inexistente",
    "inexistências": "inexistência",
    "inexorabilidades": "inexorabilidade",
    "inexorada": "inexorado",
    "inexoradas": "inexorado",
    "inexorados": "inexorado",
    "inexorcizáveis": "inexorcizável",
    "inexoráveis": "inexorável",
    "inexpectáveis": "inexpectável",
    "inexpedita": "inexpedito",
    "inexpeditas": "inexpedito",
    "inexpeditos": "inexpedito",
    "inexpelíveis": "inexpelível",
    "inexperientes": "inexperiente",
    "inexperiências": "inexperiência",
    "inexperta": "inexperto",
    "inexpertas": "inexperto",
    "inexpertos": "inexperto",
    "inexpiada": "inexpiado",
    "inexpiadas": "inexpiado",
    "inexpiados": "inexpiado",
    "inexpiáveis": "inexpiável",
    "inexplicabilidades": "inexplicabilidade",
    "inexplicada": "inexplicado",
    "inexplicadas": "inexplicado",
    "inexplicados": "inexplicado",
    "inexplicitáveis": "inexplicitável",
    "inexplicáveis": "inexplicável",
    "inexplorada": "inexplorado",
    "inexploradas": "inexplorado",
    "inexplorados": "inexplorado",
    "inexploráveis": "inexplorável",
    "inexplícita": "inexplícito",
    "inexplícitas": "inexplícito",
    "inexplícitos": "inexplícito",
    "inexportáveis": "inexportável",
    "inexpressiva": "inexpressivo",
    "inexpressivas": "inexpressivo",
    "inexpressividades": "inexpressividade",
    "inexpressivos": "inexpressivo",
    "inexpressáveis": "inexpressável",
    "inexpressões": "inexpressão",
    "inexprimíveis": "inexprimível",
    "inexpugnabilidades": "inexpugnabilidade",
    "inexpugnáveis": "inexpugnável",
    "inexpungíveis": "inexpungível",
    "inextensa": "inextenso",
    "inextensas": "inextenso",
    "inextensibilidades": "inextensibilidade",
    "inextensos": "inextenso",
    "inextensíveis": "inextensível",
    "inextensões": "inextensão",
    "inexteriorizáveis": "inexteriorizável",
    "inextermináveis": "inexterminável",
    "inextinguibilidades": "inextinguibilidade",
    "inextinguíveis": "inextinguível",
    "inextinta": "inextinto",
    "inextintas": "inextinto",
    "inextintos": "inextinto",
    "inextirpáveis": "inextirpável",
    "inextraíveis": "inextraível",
    "inextricabilidades": "inextricabilidade",
    "inextricáveis": "inextricável",
    "infactíveis": "infactível",
    "infacunda": "infacundo",
    "infacundas": "infacundo",
    "infacundos": "infacundo",
    "infalibilidades": "infalibilidade",
    "infalibilismos": "infalibilismo",
    "infalibilistas": "infalibilista",
    "infalsificáveis": "infalsificável",
    "infalíveis": "infalível",
    "infama": "infamar",
    "infamada": "infamar",
    "infamadas": "infamar",
    "infamado": "infamar",
    "infamadora": "infamador",
    "infamadoras": "infamador",
    "infamadores": "infamador",
    "infamados": "infamar",
    "infamai": "infamar",
    "infamais": "infamar",
    "infamam": "infamar",
    "infamamo": "infamar",
    "infamamos": "infamar",
    "infamando": "infamar",
    "infamantes": "infamante",
    "infamara": "infamar",
    "infamaram": "infamar",
    "infamaras": "infamar",
    "infamarde": "infamar",
    "infamardes": "infamar",
    "infamare": "infamar",
    "infamarei": "infamar",
    "infamareis": "infamar",
    "infamarem": "infamar",
    "infamaremos": "infamar",
    "infamares": "infamar",
    "infamaria": "infamar",
    "infamariam": "infamar",
    "infamarias": "infamar",
    "infamarmo": "infamar",
    "infamarmos": "infamar",
    "infamará": "infamar",
    "infamarás": "infamar",
    "infamarão": "infamar",
    "infamaríamos": "infamar",
    "infamaríeis": "infamar",
    "infamas": "infamar",
    "infamasse": "infamar",
    "infamassem": "infamar",
    "infamasses": "infamar",
    "infamaste": "infamar",
    "infamastes": "infamar",
    "infamatória": "infamatório",
    "infamatórias": "infamatório",
    "infamatórios": "infamatório",
    "infamava": "infamar",
    "infamavam": "infamar",
    "infamavas": "infamar",
    "infamações": "infamação",
    "infame": "infamar",
    "infamei": "infamar",
    "infameis": "infamar",
    "infamem": "infamar",
    "infamemo": "infamar",
    "infamemos": "infamar",
    "infames": "infame",
    "infamiazinha": "infâmia",
    "infamiazinhas": "infâmia",
    "infamiazita": "infâmia",
    "infamiazitas": "infâmia",
    "infamo": "infamar",
    "infamou": "infamar",
    "infamá": "infamar",
    "infamámo": "infamar",
    "infamámos": "infamar",
    "infamáramo": "infamar",
    "infamáramos": "infamar",
    "infamárei": "infamar",
    "infamáreis": "infamar",
    "infamásseis": "infamar",
    "infamássemos": "infamar",
    "infamávamo": "infamar",
    "infamávamos": "infamar",
    "infamávei": "infamar",
    "infamáveis": "infamar",
    "infanda": "infando",
    "infandas": "infando",
    "infandos": "infando",
    "infanta": "infante",
    "infantados": "infantado",
    "infantarias": "infantaria",
    "infantas": "infante",
    "infanterias": "infanteria",
    "infantes": "infante",
    "infanticidas": "infanticida",
    "infanticídios": "infanticídio",
    "infantilidades": "infantilidade",
    "infantilismos": "infantilismo",
    "infantiliza": "infantilizar",
    "infantilizada": "infantilizar",
    "infantilizadas": "infantilizar",
    "infantilizado": "infantilizar",
    "infantilizados": "infantilizar",
    "infantilizai": "infantilizar",
    "infantilizais": "infantilizar",
    "infantilizam": "infantilizar",
    "infantilizamo": "infantilizar",
    "infantilizamos": "infantilizar",
    "infantilizando": "infantilizar",
    "infantilizara": "infantilizar",
    "infantilizaram": "infantilizar",
    "infantilizaras": "infantilizar",
    "infantilizarde": "infantilizar",
    "infantilizardes": "infantilizar",
    "infantilizare": "infantilizar",
    "infantilizarei": "infantilizar",
    "infantilizareis": "infantilizar",
    "infantilizarem": "infantilizar",
    "infantilizaremos": "infantilizar",
    "infantilizares": "infantilizar",
    "infantilizaria": "infantilizar",
    "infantilizariam": "infantilizar",
    "infantilizarias": "infantilizar",
    "infantilizarmo": "infantilizar",
    "infantilizarmos": "infantilizar",
    "infantilizará": "infantilizar",
    "infantilizarás": "infantilizar",
    "infantilizarão": "infantilizar",
    "infantilizaríamos": "infantilizar",
    "infantilizaríeis": "infantilizar",
    "infantilizas": "infantilizar",
    "infantilizasse": "infantilizar",
    "infantilizassem": "infantilizar",
    "infantilizasses": "infantilizar",
    "infantilizaste": "infantilizar",
    "infantilizastes": "infantilizar",
    "infantilizava": "infantilizar",
    "infantilizavam": "infantilizar",
    "infantilizavas": "infantilizar",
    "infantilizações": "infantilização",
    "infantilize": "infantilizar",
    "infantilizei": "infantilizar",
    "infantilizeis": "infantilizar",
    "infantilizem": "infantilizar",
    "infantilizemo": "infantilizar",
    "infantilizemos": "infantilizar",
    "infantilizes": "infantilizar",
    "infantilizo": "infantilizar",
    "infantilizou": "infantilizar",
    "infantilizá": "infantilizar",
    "infantilizámo": "infantilizar",
    "infantilizámos": "infantilizar",
    "infantilizáramo": "infantilizar",
    "infantilizáramos": "infantilizar",
    "infantilizárei": "infantilizar",
    "infantilizáreis": "infantilizar",
    "infantilizásseis": "infantilizar",
    "infantilizássemos": "infantilizar",
    "infantilizávamo": "infantilizar",
    "infantilizávamos": "infantilizar",
    "infantilizávei": "infantilizar",
    "infantilizáveis": "infantilizar",
    "infantina": "infantino",
    "infantinas": "infantino",
    "infantinos": "infantino",
    "infantis": "infantil",
    "infantistas": "infantista",
    "infantários": "infantário",
    "infanções": "infanção",
    "infartos": "infarto",
    "infatigabilidades": "infatigabilidade",
    "infatigáveis": "infatigável",
    "infausta": "infausto",
    "infaustas": "infausto",
    "infaustos": "infausto",
    "infecciona": "infeccionar",
    "infeccionada": "infeccionar",
    "infeccionadas": "infeccionar",
    "infeccionado": "infeccionar",
    "infeccionados": "infeccionar",
    "infeccionai": "infeccionar",
    "infeccionais": "infeccionar",
    "infeccionam": "infeccionar",
    "infeccionamo": "infeccionar",
    "infeccionamos": "infeccionar",
    "infeccionando": "infeccionar",
    "infeccionara": "infeccionar",
    "infeccionaram": "infeccionar",
    "infeccionaras": "infeccionar",
    "infeccionarde": "infeccionar",
    "infeccionardes": "infeccionar",
    "infeccionare": "infeccionar",
    "infeccionarei": "infeccionar",
    "infeccionareis": "infeccionar",
    "infeccionarem": "infeccionar",
    "infeccionaremos": "infeccionar",
    "infeccionares": "infeccionar",
    "infeccionaria": "infeccionar",
    "infeccionariam": "infeccionar",
    "infeccionarias": "infeccionar",
    "infeccionarmo": "infeccionar",
    "infeccionarmos": "infeccionar",
    "infeccionará": "infeccionar",
    "infeccionarás": "infeccionar",
    "infeccionarão": "infeccionar",
    "infeccionaríamos": "infeccionar",
    "infeccionaríeis": "infeccionar",
    "infeccionas": "infeccionar",
    "infeccionasse": "infeccionar",
    "infeccionassem": "infeccionar",
    "infeccionasses": "infeccionar",
    "infeccionaste": "infeccionar",
    "infeccionastes": "infeccionar",
    "infeccionava": "infeccionar",
    "infeccionavam": "infeccionar",
    "infeccionavas": "infeccionar",
    "infeccione": "infeccionar",
    "infeccionei": "infeccionar",
    "infeccioneis": "infeccionar",
    "infeccionem": "infeccionar",
    "infeccionemo": "infeccionar",
    "infeccionemos": "infeccionar",
    "infecciones": "infeccionar",
    "infecciono": "infeccionar",
    "infeccionou": "infeccionar",
    "infeccioná": "infeccionar",
    "infeccionámo": "infeccionar",
    "infeccionámos": "infeccionar",
    "infeccionáramo": "infeccionar",
    "infeccionáramos": "infeccionar",
    "infeccionárei": "infeccionar",
    "infeccionáreis": "infeccionar",
    "infeccionásseis": "infeccionar",
    "infeccionássemos": "infeccionar",
    "infeccionávamo": "infeccionar",
    "infeccionávamos": "infeccionar",
    "infeccionávei": "infeccionar",
    "infeccionáveis": "infeccionar",
    "infecciosa": "infeccioso",
    "infecciosas": "infeccioso",
    "infecciosidades": "infecciosidade",
    "infecciosos": "infeccioso",
    "infecta": "infecto",
    "infectada": "infectar",
    "infectadas": "infectar",
    "infectado": "infectar",
    "infectados": "infectar",
    "infectadíssima": "infectado",
    "infectadíssimas": "infectado",
    "infectadíssimo": "infectado",
    "infectadíssimos": "infectado",
    "infectai": "infectar",
    "infectais": "infectar",
    "infectam": "infectar",
    "infectamo": "infectar",
    "infectamos": "infectar",
    "infectando": "infectar",
    "infectantes": "infectante",
    "infectara": "infectar",
    "infectaram": "infectar",
    "infectaras": "infectar",
    "infectarde": "infectar",
    "infectardes": "infectar",
    "infectare": "infectar",
    "infectarei": "infectar",
    "infectareis": "infectar",
    "infectarem": "infectar",
    "infectaremos": "infectar",
    "infectares": "infectar",
    "infectaria": "infectar",
    "infectariam": "infectar",
    "infectarias": "infectar",
    "infectarmo": "infectar",
    "infectarmos": "infectar",
    "infectará": "infectar",
    "infectarás": "infectar",
    "infectarão": "infectar",
    "infectaríamos": "infectar",
    "infectaríeis": "infectar",
    "infectas": "infecto",
    "infectasse": "infectar",
    "infectassem": "infectar",
    "infectasses": "infectar",
    "infectaste": "infectar",
    "infectastes": "infectar",
    "infectava": "infectar",
    "infectavam": "infectar",
    "infectavas": "infectar",
    "infecte": "infectar",
    "infectei": "infectar",
    "infecteis": "infectar",
    "infectem": "infectar",
    "infectemo": "infectar",
    "infectemos": "infectar",
    "infectes": "infectar",
    "infecto": "infectar",
    "infectologias": "infectologia",
    "infectos": "infecto",
    "infectou": "infectar",
    "infectuosa": "infectuoso",
    "infectuosas": "infectuoso",
    "infectuosos": "infectuoso",
    "infectá": "infectar",
    "infectámo": "infectar",
    "infectámos": "infectar",
    "infectáramo": "infectar",
    "infectáramos": "infectar",
    "infectárei": "infectar",
    "infectáreis": "infectar",
    "infectásseis": "infectar",
    "infectássemos": "infectar",
    "infectávamo": "infectar",
    "infectávamos": "infectar",
    "infectávei": "infectar",
    "infectáveis": "infectável",
    "infecunda": "infecundo",
    "infecundada": "infecundar",
    "infecundadas": "infecundar",
    "infecundado": "infecundar",
    "infecundados": "infecundar",
    "infecundai": "infecundar",
    "infecundais": "infecundar",
    "infecundam": "infecundar",
    "infecundamo": "infecundar",
    "infecundamos": "infecundar",
    "infecundando": "infecundar",
    "infecundara": "infecundar",
    "infecundaram": "infecundar",
    "infecundaras": "infecundar",
    "infecundarde": "infecundar",
    "infecundardes": "infecundar",
    "infecundare": "infecundar",
    "infecundarei": "infecundar",
    "infecundareis": "infecundar",
    "infecundarem": "infecundar",
    "infecundaremos": "infecundar",
    "infecundares": "infecundar",
    "infecundaria": "infecundar",
    "infecundariam": "infecundar",
    "infecundarias": "infecundar",
    "infecundarmo": "infecundar",
    "infecundarmos": "infecundar",
    "infecundará": "infecundar",
    "infecundarás": "infecundar",
    "infecundarão": "infecundar",
    "infecundaríamos": "infecundar",
    "infecundaríeis": "infecundar",
    "infecundas": "infecundo",
    "infecundasse": "infecundar",
    "infecundassem": "infecundar",
    "infecundasses": "infecundar",
    "infecundaste": "infecundar",
    "infecundastes": "infecundar",
    "infecundava": "infecundar",
    "infecundavam": "infecundar",
    "infecundavas": "infecundar",
    "infecunde": "infecundar",
    "infecundei": "infecundar",
    "infecundeis": "infecundar",
    "infecundem": "infecundar",
    "infecundemo": "infecundar",
    "infecundemos": "infecundar",
    "infecundes": "infecundar",
    "infecundidades": "infecundidade",
    "infecundo": "infecundar",
    "infecundos": "infecundo",
    "infecundou": "infecundar",
    "infecundá": "infecundar",
    "infecundámo": "infecundar",
    "infecundámos": "infecundar",
    "infecundáramo": "infecundar",
    "infecundáramos": "infecundar",
    "infecundárei": "infecundar",
    "infecundáreis": "infecundar",
    "infecundásseis": "infecundar",
    "infecundássemos": "infecundar",
    "infecundávamo": "infecundar",
    "infecundávamos": "infecundar",
    "infecundávei": "infecundar",
    "infecundáveis": "infecundar",
    "infecções": "infecção",
    "infelicidades": "infelicidade",
    "infelicita": "infelicitar",
    "infelicitada": "infelicitar",
    "infelicitadas": "infelicitar",
    "infelicitado": "infelicitar",
    "infelicitados": "infelicitar",
    "infelicitai": "infelicitar",
    "infelicitais": "infelicitar",
    "infelicitam": "infelicitar",
    "infelicitamo": "infelicitar",
    "infelicitamos": "infelicitar",
    "infelicitando": "infelicitar",
    "infelicitara": "infelicitar",
    "infelicitaram": "infelicitar",
    "infelicitaras": "infelicitar",
    "infelicitarde": "infelicitar",
    "infelicitardes": "infelicitar",
    "infelicitare": "infelicitar",
    "infelicitarei": "infelicitar",
    "infelicitareis": "infelicitar",
    "infelicitarem": "infelicitar",
    "infelicitaremos": "infelicitar",
    "infelicitares": "infelicitar",
    "infelicitaria": "infelicitar",
    "infelicitariam": "infelicitar",
    "infelicitarias": "infelicitar",
    "infelicitarmo": "infelicitar",
    "infelicitarmos": "infelicitar",
    "infelicitará": "infelicitar",
    "infelicitarás": "infelicitar",
    "infelicitarão": "infelicitar",
    "infelicitaríamos": "infelicitar",
    "infelicitaríeis": "infelicitar",
    "infelicitas": "infelicitar",
    "infelicitasse": "infelicitar",
    "infelicitassem": "infelicitar",
    "infelicitasses": "infelicitar",
    "infelicitaste": "infelicitar",
    "infelicitastes": "infelicitar",
    "infelicitava": "infelicitar",
    "infelicitavam": "infelicitar",
    "infelicitavas": "infelicitar",
    "infelicite": "infelicitar",
    "infelicitei": "infelicitar",
    "infeliciteis": "infelicitar",
    "infelicitem": "infelicitar",
    "infelicitemo": "infelicitar",
    "infelicitemos": "infelicitar",
    "infelicites": "infelicitar",
    "infelicito": "infelicitar",
    "infelicitou": "infelicitar",
    "infelicitá": "infelicitar",
    "infelicitámo": "infelicitar",
    "infelicitámos": "infelicitar",
    "infelicitáramo": "infelicitar",
    "infelicitáramos": "infelicitar",
    "infelicitárei": "infelicitar",
    "infelicitáreis": "infelicitar",
    "infelicitásseis": "infelicitar",
    "infelicitássemos": "infelicitar",
    "infelicitávamo": "infelicitar",
    "infelicitávamos": "infelicitar",
    "infelicitávei": "infelicitar",
    "infelicitáveis": "infelicitar",
    "infelicíssima": "infeliz",
    "infelicíssimas": "infeliz",
    "infelicíssimo": "infeliz",
    "infelicíssimos": "infeliz",
    "infelizes": "infeliz",
    "infensa": "infenso",
    "infensas": "infenso",
    "infensos": "infenso",
    "inferaxilares": "inferaxilar",
    "infere": "inferir",
    "inferem": "inferir",
    "inferes": "inferir",
    "inferi": "inferir",
    "inferia": "inferir",
    "inferiam": "inferir",
    "inferias": "inferir",
    "inferida": "inferir",
    "inferidas": "inferir",
    "inferido": "inferir",
    "inferidos": "inferir",
    "inferimo": "inferir",
    "inferimos": "inferir",
    "inferindo": "inferir",
    "inferiores": "inferior",
    "inferioridades": "inferioridade",
    "inferiorizada": "inferiorizado",
    "inferiorizadas": "inferiorizado",
    "inferiorizados": "inferiorizado",
    "inferiorizações": "inferiorização",
    "inferira": "inferir",
    "inferiram": "inferir",
    "inferiras": "inferir",
    "inferirde": "inferir",
    "inferirdes": "inferir",
    "inferire": "inferir",
    "inferirei": "inferir",
    "inferireis": "inferir",
    "inferirem": "inferir",
    "inferiremos": "inferir",
    "inferires": "inferir",
    "inferiria": "inferir",
    "infeririam": "inferir",
    "inferirias": "inferir",
    "inferirmo": "inferir",
    "inferirmos": "inferir",
    "inferirá": "inferir",
    "inferirás": "inferir",
    "inferirão": "inferir",
    "inferiríamos": "inferir",
    "inferiríeis": "inferir",
    "inferis": "inferir",
    "inferisse": "inferir",
    "inferissem": "inferir",
    "inferisses": "inferir",
    "inferiste": "inferir",
    "inferistes": "inferir",
    "inferiu": "inferir",
    "infermentescibilidades": "infermentescibilidade",
    "infermentescíveis": "infermentescível",
    "inferna": "inferno",
    "infernada": "infernar",
    "infernadas": "infernar",
    "infernado": "infernar",
    "infernados": "infernar",
    "infernai": "infernar",
    "infernais": "infernar",
    "infernalidades": "infernalidade",
    "infernam": "infernar",
    "infernamo": "infernar",
    "infernamos": "infernar",
    "infernando": "infernar",
    "infernara": "infernar",
    "infernaram": "infernar",
    "infernaras": "infernar",
    "infernarde": "infernar",
    "infernardes": "infernar",
    "infernare": "infernar",
    "infernarei": "infernar",
    "infernareis": "infernar",
    "infernarem": "infernar",
    "infernaremos": "infernar",
    "infernares": "infernar",
    "infernaria": "infernar",
    "infernariam": "infernar",
    "infernarias": "infernar",
    "infernarmo": "infernar",
    "infernarmos": "infernar",
    "infernará": "infernar",
    "infernarás": "infernar",
    "infernarão": "infernar",
    "infernaríamos": "infernar",
    "infernaríeis": "infernar",
    "infernas": "inferno",
    "infernasse": "infernar",
    "infernassem": "infernar",
    "infernasses": "infernar",
    "infernaste": "infernar",
    "infernastes": "infernar",
    "infernava": "infernar",
    "infernavam": "infernar",
    "infernavas": "infernar",
    "inferne": "infernar",
    "infernei": "infernar",
    "inferneiras": "inferneira",
    "inferneis": "infernar",
    "infernem": "infernar",
    "infernemo": "infernar",
    "infernemos": "infernar",
    "infernes": "infernar",
    "inferninhos": "inferninho",
    "inferniza": "infernizar",
    "infernizada": "infernizar",
    "infernizadas": "infernizar",
    "infernizado": "infernizar",
    "infernizados": "infernizar",
    "infernizai": "infernizar",
    "infernizais": "infernizar",
    "infernizam": "infernizar",
    "infernizamo": "infernizar",
    "infernizamos": "infernizar",
    "infernizando": "infernizar",
    "infernizara": "infernizar",
    "infernizaram": "infernizar",
    "infernizaras": "infernizar",
    "infernizarde": "infernizar",
    "infernizardes": "infernizar",
    "infernizare": "infernizar",
    "infernizarei": "infernizar",
    "infernizareis": "infernizar",
    "infernizarem": "infernizar",
    "infernizaremos": "infernizar",
    "infernizares": "infernizar",
    "infernizaria": "infernizar",
    "infernizariam": "infernizar",
    "infernizarias": "infernizar",
    "infernizarmo": "infernizar",
    "infernizarmos": "infernizar",
    "infernizará": "infernizar",
    "infernizarás": "infernizar",
    "infernizarão": "infernizar",
    "infernizaríamos": "infernizar",
    "infernizaríeis": "infernizar",
    "infernizas": "infernizar",
    "infernizasse": "infernizar",
    "infernizassem": "infernizar",
    "infernizasses": "infernizar",
    "infernizaste": "infernizar",
    "infernizastes": "infernizar",
    "infernizava": "infernizar",
    "infernizavam": "infernizar",
    "infernizavas": "infernizar",
    "infernize": "infernizar",
    "infernizei": "infernizar",
    "infernizeis": "infernizar",
    "infernizem": "infernizar",
    "infernizemo": "infernizar",
    "infernizemos": "infernizar",
    "infernizes": "infernizar",
    "infernizo": "infernizar",
    "infernizou": "infernizar",
    "infernizá": "infernizar",
    "infernizámo": "infernizar",
    "infernizámos": "infernizar",
    "infernizáramo": "infernizar",
    "infernizáramos": "infernizar",
    "infernizárei": "infernizar",
    "infernizáreis": "infernizar",
    "infernizásseis": "infernizar",
    "infernizássemos": "infernizar",
    "infernizávamo": "infernizar",
    "infernizávamos": "infernizar",
    "infernizávei": "infernizar",
    "infernizáveis": "infernizar",
    "inferno": "infernar",
    "infernos": "inferno",
    "infernou": "infernar",
    "inferná": "infernar",
    "infernámo": "infernar",
    "infernámos": "infernar",
    "infernáramo": "infernar",
    "infernáramos": "infernar",
    "infernárei": "infernar",
    "infernáreis": "infernar",
    "infernásseis": "infernar",
    "infernássemos": "infernar",
    "infernávamo": "infernar",
    "infernávamos": "infernar",
    "infernávei": "infernar",
    "infernáveis": "infernar",
    "inferovariada": "inferovariado",
    "inferovariadas": "inferovariado",
    "inferovariados": "inferovariado",
    "infertilidades": "infertilidade",
    "infertiliza": "infertilizar",
    "infertilizada": "infertilizar",
    "infertilizadas": "infertilizar",
    "infertilizado": "infertilizar",
    "infertilizados": "infertilizar",
    "infertilizai": "infertilizar",
    "infertilizais": "infertilizar",
    "infertilizam": "infertilizar",
    "infertilizamo": "infertilizar",
    "infertilizamos": "infertilizar",
    "infertilizando": "infertilizar",
    "infertilizara": "infertilizar",
    "infertilizaram": "infertilizar",
    "infertilizaras": "infertilizar",
    "infertilizarde": "infertilizar",
    "infertilizardes": "infertilizar",
    "infertilizare": "infertilizar",
    "infertilizarei": "infertilizar",
    "infertilizareis": "infertilizar",
    "infertilizarem": "infertilizar",
    "infertilizaremos": "infertilizar",
    "infertilizares": "infertilizar",
    "infertilizaria": "infertilizar",
    "infertilizariam": "infertilizar",
    "infertilizarias": "infertilizar",
    "infertilizarmo": "infertilizar",
    "infertilizarmos": "infertilizar",
    "infertilizará": "infertilizar",
    "infertilizarás": "infertilizar",
    "infertilizarão": "infertilizar",
    "infertilizaríamos": "infertilizar",
    "infertilizaríeis": "infertilizar",
    "infertilizas": "infertilizar",
    "infertilizasse": "infertilizar",
    "infertilizassem": "infertilizar",
    "infertilizasses": "infertilizar",
    "infertilizaste": "infertilizar",
    "infertilizastes": "infertilizar",
    "infertilizava": "infertilizar",
    "infertilizavam": "infertilizar",
    "infertilizavas": "infertilizar",
    "infertilize": "infertilizar",
    "infertilizei": "infertilizar",
    "infertilizeis": "infertilizar",
    "infertilizem": "infertilizar",
    "infertilizemo": "infertilizar",
    "infertilizemos": "infertilizar",
    "infertilizes": "infertilizar",
    "infertilizo": "infertilizar",
    "infertilizou": "infertilizar",
    "infertilizá": "infertilizar",
    "infertilizámo": "infertilizar",
    "infertilizámos": "infertilizar",
    "infertilizáramo": "infertilizar",
    "infertilizáramos": "infertilizar",
    "infertilizárei": "infertilizar",
    "infertilizáreis": "infertilizar",
    "infertilizásseis": "infertilizar",
    "infertilizássemos": "infertilizar",
    "infertilizávamo": "infertilizar",
    "infertilizávamos": "infertilizar",
    "infertilizávei": "infertilizar",
    "infertilizáveis": "infertilizável",
    "inferências": "inferência",
    "inferíamo": "inferir",
    "inferíamos": "inferir",
    "inferíei": "inferir",
    "inferíeis": "inferir",
    "inferíramo": "inferir",
    "inferíramos": "inferir",
    "inferírei": "inferir",
    "inferíreis": "inferir",
    "inferísseis": "inferir",
    "inferíssemos": "inferir",
    "inferíveis": "inferível",
    "infesta": "infesto",
    "infestada": "infestar",
    "infestadas": "infestar",
    "infestado": "infestar",
    "infestadora": "infestador",
    "infestadoras": "infestador",
    "infestadores": "infestador",
    "infestados": "infestar",
    "infestai": "infestar",
    "infestais": "infestar",
    "infestam": "infestar",
    "infestamo": "infestar",
    "infestamos": "infestar",
    "infestando": "infestar",
    "infestantes": "infestante",
    "infestara": "infestar",
    "infestaram": "infestar",
    "infestaras": "infestar",
    "infestarde": "infestar",
    "infestardes": "infestar",
    "infestare": "infestar",
    "infestarei": "infestar",
    "infestareis": "infestar",
    "infestarem": "infestar",
    "infestaremos": "infestar",
    "infestares": "infestar",
    "infestaria": "infestar",
    "infestariam": "infestar",
    "infestarias": "infestar",
    "infestarmo": "infestar",
    "infestarmos": "infestar",
    "infestará": "infestar",
    "infestarás": "infestar",
    "infestarão": "infestar",
    "infestaríamos": "infestar",
    "infestaríeis": "infestar",
    "infestas": "infesto",
    "infestasse": "infestar",
    "infestassem": "infestar",
    "infestasses": "infestar",
    "infestaste": "infestar",
    "infestastes": "infestar",
    "infestava": "infestar",
    "infestavam": "infestar",
    "infestavas": "infestar",
    "infestações": "infestação",
    "infeste": "infestar",
    "infestei": "infestar",
    "infesteis": "infestar",
    "infestem": "infestar",
    "infestemo": "infestar",
    "infestemos": "infestar",
    "infestes": "infestar",
    "infesto": "infestar",
    "infestos": "infesto",
    "infestou": "infestar",
    "infestá": "infestar",
    "infestámo": "infestar",
    "infestámos": "infestar",
    "infestáramo": "infestar",
    "infestáramos": "infestar",
    "infestárei": "infestar",
    "infestáreis": "infestar",
    "infestásseis": "infestar",
    "infestássemos": "infestar",
    "infestávamo": "infestar",
    "infestávamos": "infestar",
    "infestávei": "infestar",
    "infestáveis": "infestar",
    "infibuladora": "infibulador",
    "infibuladoras": "infibulador",
    "infibuladores": "infibulador",
    "infibulações": "infibulação",
    "inficionada": "inficionado",
    "inficionadas": "inficionado",
    "inficionadora": "inficionador",
    "inficionadoras": "inficionador",
    "inficionadores": "inficionador",
    "inficionados": "inficionado",
    "inficionações": "inficionação",
    "infida": "infido",
    "infidas": "infido",
    "infidelidades": "infidelidade",
    "infidos": "infido",
    "infieis": "infiel",
    "infiltra": "infiltrar",
    "infiltrada": "infiltrar",
    "infiltradas": "infiltrar",
    "infiltrado": "infiltrar",
    "infiltrados": "infiltrar",
    "infiltrai": "infiltrar",
    "infiltrais": "infiltrar",
    "infiltram": "infiltrar",
    "infiltramo": "infiltrar",
    "infiltramos": "infiltrar",
    "infiltrando": "infiltrar",
    "infiltrara": "infiltrar",
    "infiltraram": "infiltrar",
    "infiltraras": "infiltrar",
    "infiltrarde": "infiltrar",
    "infiltrardes": "infiltrar",
    "infiltrare": "infiltrar",
    "infiltrarei": "infiltrar",
    "infiltrareis": "infiltrar",
    "infiltrarem": "infiltrar",
    "infiltraremos": "infiltrar",
    "infiltrares": "infiltrar",
    "infiltraria": "infiltrar",
    "infiltrariam": "infiltrar",
    "infiltrarias": "infiltrar",
    "infiltrarmo": "infiltrar",
    "infiltrarmos": "infiltrar",
    "infiltrará": "infiltrar",
    "infiltrarás": "infiltrar",
    "infiltrarão": "infiltrar",
    "infiltraríamos": "infiltrar",
    "infiltraríeis": "infiltrar",
    "infiltras": "infiltrar",
    "infiltrasse": "infiltrar",
    "infiltrassem": "infiltrar",
    "infiltrasses": "infiltrar",
    "infiltraste": "infiltrar",
    "infiltrastes": "infiltrar",
    "infiltrava": "infiltrar",
    "infiltravam": "infiltrar",
    "infiltravas": "infiltrar",
    "infiltrações": "infiltração",
    "infiltre": "infiltrar",
    "infiltrei": "infiltrar",
    "infiltreis": "infiltrar",
    "infiltrem": "infiltrar",
    "infiltremo": "infiltrar",
    "infiltremos": "infiltrar",
    "infiltres": "infiltrar",
    "infiltro": "infiltrar",
    "infiltrou": "infiltrar",
    "infiltrá": "infiltrar",
    "infiltrámo": "infiltrar",
    "infiltrámos": "infiltrar",
    "infiltráramo": "infiltrar",
    "infiltráramos": "infiltrar",
    "infiltrárei": "infiltrar",
    "infiltráreis": "infiltrar",
    "infiltrásseis": "infiltrar",
    "infiltrássemos": "infiltrar",
    "infiltrávamo": "infiltrar",
    "infiltrávamos": "infiltrar",
    "infiltrávei": "infiltrar",
    "infiltráveis": "infiltrável",
    "infinda": "infindo",
    "infindas": "infindo",
    "infindos": "infindo",
    "infindáveis": "infindável",
    "infinidades": "infinidade",
    "infinita": "infinito",
    "infinitas": "infinito",
    "infinitesimais": "infinitesimal",
    "infinitiva": "infinitivo",
    "infinitivas": "infinitivo",
    "infinitivos": "infinitivo",
    "infinitos": "infinito",
    "infinitésima": "infinitésimo",
    "infinitésimas": "infinitésimo",
    "infinitésimos": "infinitésimo",
    "infira": "inferir",
    "infirais": "inferir",
    "infiram": "inferir",
    "infiramo": "inferir",
    "infiramos": "inferir",
    "infiras": "inferir",
    "infirma": "infirmar",
    "infirmada": "infirmar",
    "infirmadas": "infirmar",
    "infirmado": "infirmar",
    "infirmados": "infirmar",
    "infirmai": "infirmar",
    "infirmais": "infirmar",
    "infirmam": "infirmar",
    "infirmamo": "infirmar",
    "infirmamos": "infirmar",
    "infirmando": "infirmar",
    "infirmara": "infirmar",
    "infirmaram": "infirmar",
    "infirmaras": "infirmar",
    "infirmarde": "infirmar",
    "infirmardes": "infirmar",
    "infirmare": "infirmar",
    "infirmarei": "infirmar",
    "infirmareis": "infirmar",
    "infirmarem": "infirmar",
    "infirmaremos": "infirmar",
    "infirmares": "infirmar",
    "infirmaria": "infirmar",
    "infirmariam": "infirmar",
    "infirmarias": "infirmar",
    "infirmarmo": "infirmar",
    "infirmarmos": "infirmar",
    "infirmará": "infirmar",
    "infirmarás": "infirmar",
    "infirmarão": "infirmar",
    "infirmaríamos": "infirmar",
    "infirmaríeis": "infirmar",
    "infirmas": "infirmar",
    "infirmasse": "infirmar",
    "infirmassem": "infirmar",
    "infirmasses": "infirmar",
    "infirmaste": "infirmar",
    "infirmastes": "infirmar",
    "infirmativa": "infirmativo",
    "infirmativas": "infirmativo",
    "infirmativos": "infirmativo",
    "infirmava": "infirmar",
    "infirmavam": "infirmar",
    "infirmavas": "infirmar",
    "infirmações": "infirmação",
    "infirme": "infirmar",
    "infirmei": "infirmar",
    "infirmeis": "infirmar",
    "infirmem": "infirmar",
    "infirmemo": "infirmar",
    "infirmemos": "infirmar",
    "infirmes": "infirmar",
    "infirmidades": "infirmidade",
    "infirmo": "infirmar",
    "infirmou": "infirmar",
    "infirmá": "infirmar",
    "infirmámo": "infirmar",
    "infirmámos": "infirmar",
    "infirmáramo": "infirmar",
    "infirmáramos": "infirmar",
    "infirmárei": "infirmar",
    "infirmáreis": "infirmar",
    "infirmásseis": "infirmar",
    "infirmássemos": "infirmar",
    "infirmávamo": "infirmar",
    "infirmávamos": "infirmar",
    "infirmávei": "infirmar",
    "infirmáveis": "infirmar",
    "infiro": "inferir",
    "infixa": "infixar",
    "infixada": "infixar",
    "infixadas": "infixar",
    "infixado": "infixar",
    "infixados": "infixar",
    "infixai": "infixar",
    "infixais": "infixar",
    "infixam": "infixar",
    "infixamo": "infixar",
    "infixamos": "infixar",
    "infixando": "infixar",
    "infixara": "infixar",
    "infixaram": "infixar",
    "infixaras": "infixar",
    "infixarde": "infixar",
    "infixardes": "infixar",
    "infixare": "infixar",
    "infixarei": "infixar",
    "infixareis": "infixar",
    "infixarem": "infixar",
    "infixaremos": "infixar",
    "infixares": "infixar",
    "infixaria": "infixar",
    "infixariam": "infixar",
    "infixarias": "infixar",
    "infixarmo": "infixar",
    "infixarmos": "infixar",
    "infixará": "infixar",
    "infixarás": "infixar",
    "infixarão": "infixar",
    "infixaríamos": "infixar",
    "infixaríeis": "infixar",
    "infixas": "infixar",
    "infixasse": "infixar",
    "infixassem": "infixar",
    "infixasses": "infixar",
    "infixaste": "infixar",
    "infixastes": "infixar",
    "infixava": "infixar",
    "infixavam": "infixar",
    "infixavas": "infixar",
    "infixações": "infixação",
    "infixe": "infixar",
    "infixei": "infixar",
    "infixeis": "infixar",
    "infixem": "infixar",
    "infixemo": "infixar",
    "infixemos": "infixar",
    "infixes": "infixar",
    "infixidezes": "infixidez",
    "infixo": "infixar",
    "infixos": "infixo",
    "infixou": "infixar",
    "infixá": "infixar",
    "infixámo": "infixar",
    "infixámos": "infixar",
    "infixáramo": "infixar",
    "infixáramos": "infixar",
    "infixárei": "infixar",
    "infixáreis": "infixar",
    "infixásseis": "infixar",
    "infixássemos": "infixar",
    "infixávamo": "infixar",
    "infixávamos": "infixar",
    "infixávei": "infixar",
    "infixáveis": "infixar",
    "infiéis": "infiel",
    "infla": "inflar",
    "inflaccionáveis": "inflaccionável",
    "inflaciona": "inflacionar",
    "inflacionada": "inflacionar",
    "inflacionadas": "inflacionar",
    "inflacionado": "inflacionar",
    "inflacionados": "inflacionar",
    "inflacionadíssima": "inflacionado",
    "inflacionadíssimas": "inflacionado",
    "inflacionadíssimo": "inflacionado",
    "inflacionadíssimos": "inflacionado",
    "inflacionai": "inflacionar",
    "inflacionais": "inflacionar",
    "inflacionam": "inflacionar",
    "inflacionamo": "inflacionar",
    "inflacionamos": "inflacionar",
    "inflacionando": "inflacionar",
    "inflacionara": "inflacionar",
    "inflacionaram": "inflacionar",
    "inflacionaras": "inflacionar",
    "inflacionarde": "inflacionar",
    "inflacionardes": "inflacionar",
    "inflacionare": "inflacionar",
    "inflacionarei": "inflacionar",
    "inflacionareis": "inflacionar",
    "inflacionarem": "inflacionar",
    "inflacionaremos": "inflacionar",
    "inflacionares": "inflacionar",
    "inflacionaria": "inflacionar",
    "inflacionariam": "inflacionar",
    "inflacionarias": "inflacionar",
    "inflacionarmo": "inflacionar",
    "inflacionarmos": "inflacionar",
    "inflacionará": "inflacionar",
    "inflacionarás": "inflacionar",
    "inflacionarão": "inflacionar",
    "inflacionaríamos": "inflacionar",
    "inflacionaríeis": "inflacionar",
    "inflacionas": "inflacionar",
    "inflacionasse": "inflacionar",
    "inflacionassem": "inflacionar",
    "inflacionasses": "inflacionar",
    "inflacionaste": "inflacionar",
    "inflacionastes": "inflacionar",
    "inflacionava": "inflacionar",
    "inflacionavam": "inflacionar",
    "inflacionavas": "inflacionar",
    "inflacione": "inflacionar",
    "inflacionei": "inflacionar",
    "inflacioneis": "inflacionar",
    "inflacionem": "inflacionar",
    "inflacionemo": "inflacionar",
    "inflacionemos": "inflacionar",
    "inflaciones": "inflacionar",
    "inflacionismos": "inflacionismo",
    "inflacionistas": "inflacionista",
    "inflaciono": "inflacionar",
    "inflacionou": "inflacionar",
    "inflacioná": "inflacionar",
    "inflacionámo": "inflacionar",
    "inflacionámos": "inflacionar",
    "inflacionáramo": "inflacionar",
    "inflacionáramos": "inflacionar",
    "inflacionárei": "inflacionar",
    "inflacionáreis": "inflacionar",
    "inflacionásseis": "inflacionar",
    "inflacionássemos": "inflacionar",
    "inflacionávamo": "inflacionar",
    "inflacionávamos": "inflacionar",
    "inflacionávei": "inflacionar",
    "inflacionáveis": "inflacionar",
    "inflada": "inflar",
    "infladas": "inflar",
    "inflado": "inflar",
    "inflados": "inflar",
    "inflai": "inflar",
    "inflais": "inflar",
    "inflam": "inflar",
    "inflama": "inflamar",
    "inflamabilidades": "inflamabilidade",
    "inflamada": "inflamar",
    "inflamadas": "inflamar",
    "inflamado": "inflamar",
    "inflamadora": "inflamador",
    "inflamadoras": "inflamador",
    "inflamadores": "inflamador",
    "inflamados": "inflamar",
    "inflamadíssima": "inflamado",
    "inflamadíssimas": "inflamado",
    "inflamadíssimo": "inflamado",
    "inflamadíssimos": "inflamado",
    "inflamai": "inflamar",
    "inflamais": "inflamar",
    "inflamam": "inflamar",
    "inflamamo": "inflamar",
    "inflamamos": "inflamar",
    "inflamando": "inflamar",
    "inflamara": "inflamar",
    "inflamaram": "inflamar",
    "inflamaras": "inflamar",
    "inflamarde": "inflamar",
    "inflamardes": "inflamar",
    "inflamare": "inflamar",
    "inflamarei": "inflamar",
    "inflamareis": "inflamar",
    "inflamarem": "inflamar",
    "inflamaremos": "inflamar",
    "inflamares": "inflamar",
    "inflamaria": "inflamar",
    "inflamariam": "inflamar",
    "inflamarias": "inflamar",
    "inflamarmo": "inflamar",
    "inflamarmos": "inflamar",
    "inflamará": "inflamar",
    "inflamarás": "inflamar",
    "inflamarão": "inflamar",
    "inflamaríamos": "inflamar",
    "inflamaríeis": "inflamar",
    "inflamas": "inflamar",
    "inflamasse": "inflamar",
    "inflamassem": "inflamar",
    "inflamasses": "inflamar",
    "inflamaste": "inflamar",
    "inflamastes": "inflamar",
    "inflamativa": "inflamativo",
    "inflamativas": "inflamativo",
    "inflamativos": "inflamativo",
    "inflamatória": "inflamatório",
    "inflamatórias": "inflamatório",
    "inflamatórios": "inflamatório",
    "inflamava": "inflamar",
    "inflamavam": "inflamar",
    "inflamavas": "inflamar",
    "inflamações": "inflamação",
    "inflame": "inflamar",
    "inflamei": "inflamar",
    "inflameis": "inflamar",
    "inflamem": "inflamar",
    "inflamemo": "inflamar",
    "inflamemos": "inflamar",
    "inflames": "inflamar",
    "inflamo": "inflar",
    "inflamos": "inflar",
    "inflamou": "inflamar",
    "inflamá": "inflamar",
    "inflamámo": "inflamar",
    "inflamámos": "inflamar",
    "inflamáramo": "inflamar",
    "inflamáramos": "inflamar",
    "inflamárei": "inflamar",
    "inflamáreis": "inflamar",
    "inflamásseis": "inflamar",
    "inflamássemos": "inflamar",
    "inflamávamo": "inflamar",
    "inflamávamos": "inflamar",
    "inflamávei": "inflamar",
    "inflamáveis": "inflamável",
    "inflando": "inflar",
    "inflara": "inflar",
    "inflaram": "inflar",
    "inflaras": "inflar",
    "inflarde": "inflar",
    "inflardes": "inflar",
    "inflare": "inflar",
    "inflarei": "inflar",
    "inflareis": "inflar",
    "inflarem": "inflar",
    "inflaremos": "inflar",
    "inflares": "inflar",
    "inflaria": "inflar",
    "inflariam": "inflar",
    "inflarias": "inflar",
    "inflarmo": "inflar",
    "inflarmos": "inflar",
    "inflará": "inflar",
    "inflarás": "inflar",
    "inflarão": "inflar",
    "inflaríamos": "inflar",
    "inflaríeis": "inflar",
    "inflas": "inflar",
    "inflasse": "inflar",
    "inflassem": "inflar",
    "inflasses": "inflar",
    "inflaste": "inflar",
    "inflastes": "inflar",
    "inflatória": "inflatório",
    "inflatórias": "inflatório",
    "inflatórios": "inflatório",
    "inflava": "inflar",
    "inflavam": "inflar",
    "inflavas": "inflar",
    "inflações": "inflação",
    "infle": "inflar",
    "inflecte": "inflectir",
    "inflectem": "inflectir",
    "inflectes": "inflectir",
    "inflecti": "inflectir",
    "inflectia": "inflectir",
    "inflectiam": "inflectir",
    "inflectias": "inflectir",
    "inflectida": "inflectir",
    "inflectidas": "inflectir",
    "inflectido": "inflectir",
    "inflectidos": "inflectir",
    "inflectimo": "inflectir",
    "inflectimos": "inflectir",
    "inflectindo": "inflectir",
    "inflectira": "inflectir",
    "inflectiram": "inflectir",
    "inflectiras": "inflectir",
    "inflectirde": "inflectir",
    "inflectirdes": "inflectir",
    "inflectire": "inflectir",
    "inflectirei": "inflectir",
    "inflectireis": "inflectir",
    "inflectirem": "inflectir",
    "inflectiremos": "inflectir",
    "inflectires": "inflectir",
    "inflectiria": "inflectir",
    "inflectiriam": "inflectir",
    "inflectirias": "inflectir",
    "inflectirmo": "inflectir",
    "inflectirmos": "inflectir",
    "inflectirá": "inflectir",
    "inflectirás": "inflectir",
    "inflectirão": "inflectir",
    "inflectiríamos": "inflectir",
    "inflectiríeis": "inflectir",
    "inflectis": "inflectir",
    "inflectisse": "inflectir",
    "inflectissem": "inflectir",
    "inflectisses": "inflectir",
    "inflectiste": "inflectir",
    "inflectistes": "inflectir",
    "inflectiu": "inflectir",
    "inflectíamo": "inflectir",
    "inflectíamos": "inflectir",
    "inflectíei": "inflectir",
    "inflectíeis": "inflectir",
    "inflectíramo": "inflectir",
    "inflectíramos": "inflectir",
    "inflectírei": "inflectir",
    "inflectíreis": "inflectir",
    "inflectísseis": "inflectir",
    "inflectíssemos": "inflectir",
    "inflei": "inflar",
    "infleis": "inflar",
    "inflem": "inflar",
    "inflemo": "inflar",
    "inflemos": "inflar",
    "infles": "inflar",
    "inflexa": "inflexo",
    "inflexas": "inflexo",
    "inflexibilidades": "inflexibilidade",
    "inflexiva": "inflexivo",
    "inflexivas": "inflexivo",
    "inflexivos": "inflexivo",
    "inflexos": "inflexo",
    "inflexíveis": "inflexível",
    "inflexões": "inflexão",
    "infliacções": "infliacção",
    "inflicta": "inflectir",
    "inflictais": "inflectir",
    "inflictam": "inflectir",
    "inflictamo": "inflectir",
    "inflictamos": "inflectir",
    "inflictas": "inflectir",
    "inflicto": "inflectir",
    "inflige": "infligir",
    "infligem": "infligir",
    "infliges": "infligir",
    "infligi": "infligir",
    "infligia": "infligir",
    "infligiam": "infligir",
    "infligias": "infligir",
    "infligida": "infligir",
    "infligidas": "infligir",
    "infligido": "infligir",
    "infligidos": "infligir",
    "infligimo": "infligir",
    "infligimos": "infligir",
    "infligindo": "infligir",
    "infligira": "infligir",
    "infligiram": "infligir",
    "infligiras": "infligir",
    "infligirde": "infligir",
    "infligirdes": "infligir",
    "infligire": "infligir",
    "infligirei": "infligir",
    "infligireis": "infligir",
    "infligirem": "infligir",
    "infligiremos": "infligir",
    "infligires": "infligir",
    "infligiria": "infligir",
    "infligiriam": "infligir",
    "infligirias": "infligir",
    "infligirmo": "infligir",
    "infligirmos": "infligir",
    "infligirá": "infligir",
    "infligirás": "infligir",
    "infligirão": "infligir",
    "infligiríamos": "infligir",
    "infligiríeis": "infligir",
    "infligis": "infligir",
    "infligisse": "infligir",
    "infligissem": "infligir",
    "infligisses": "infligir",
    "infligiste": "infligir",
    "infligistes": "infligir",
    "infligiu": "infligir",
    "infligíamo": "infligir",
    "infligíamos": "infligir",
    "infligíei": "infligir",
    "infligíeis": "infligir",
    "infligíramo": "infligir",
    "infligíramos": "infligir",
    "infligírei": "infligir",
    "infligíreis": "infligir",
    "infligísseis": "infligir",
    "infligíssemos": "infligir",
    "infligíveis": "infligível",
    "inflija": "infligir",
    "inflijais": "infligir",
    "inflijam": "infligir",
    "inflijamo": "infligir",
    "inflijamos": "infligir",
    "inflijas": "infligir",
    "inflijo": "infligir",
    "inflo": "inflar",
    "inflorescentes": "inflorescente",
    "inflorescências": "inflorescência",
    "inflou": "inflar",
    "influa": "influir",
    "influais": "influir",
    "influam": "influir",
    "influamo": "influir",
    "influamos": "influir",
    "influas": "influir",
    "influem": "influir",
    "influencia": "influenciar",
    "influenciada": "influenciar",
    "influenciadas": "influenciar",
    "influenciado": "influenciar",
    "influenciados": "influenciar",
    "influenciai": "influenciar",
    "influenciais": "influenciar",
    "influenciam": "influenciar",
    "influenciamo": "influenciar",
    "influenciamos": "influenciar",
    "influenciando": "influenciar",
    "influenciara": "influenciar",
    "influenciaram": "influenciar",
    "influenciaras": "influenciar",
    "influenciarde": "influenciar",
    "influenciardes": "influenciar",
    "influenciare": "influenciar",
    "influenciarei": "influenciar",
    "influenciareis": "influenciar",
    "influenciarem": "influenciar",
    "influenciaremos": "influenciar",
    "influenciares": "influenciar",
    "influenciaria": "influenciar",
    "influenciariam": "influenciar",
    "influenciarias": "influenciar",
    "influenciarmo": "influenciar",
    "influenciarmos": "influenciar",
    "influenciará": "influenciar",
    "influenciarás": "influenciar",
    "influenciarão": "influenciar",
    "influenciaríamos": "influenciar",
    "influenciaríeis": "influenciar",
    "influencias": "influenciar",
    "influenciasse": "influenciar",
    "influenciassem": "influenciar",
    "influenciasses": "influenciar",
    "influenciaste": "influenciar",
    "influenciastes": "influenciar",
    "influenciava": "influenciar",
    "influenciavam": "influenciar",
    "influenciavas": "influenciar",
    "influenciações": "influenciação",
    "influencie": "influenciar",
    "influenciei": "influenciar",
    "influencieis": "influenciar",
    "influenciem": "influenciar",
    "influenciemo": "influenciar",
    "influenciemos": "influenciar",
    "influencies": "influenciar",
    "influencio": "influenciar",
    "influenciou": "influenciar",
    "influenciá": "influenciar",
    "influenciámo": "influenciar",
    "influenciámos": "influenciar",
    "influenciáramo": "influenciar",
    "influenciáramos": "influenciar",
    "influenciárei": "influenciar",
    "influenciáreis": "influenciar",
    "influenciásseis": "influenciar",
    "influenciássemos": "influenciar",
    "influenciávamo": "influenciar",
    "influenciávamos": "influenciar",
    "influenciávei": "influenciar",
    "influenciáveis": "influenciável",
    "influentes": "influente",
    "influenzas": "influenza",
    "influenças": "influença",
    "influi": "influir",
    "influidora": "influidor",
    "influidoras": "influidor",
    "influidores": "influidor",
    "influindo": "influir",
    "influirdes": "influir",
    "influirei": "influir",
    "influireis": "influir",
    "influiremos": "influir",
    "influiria": "influir",
    "influiriam": "influir",
    "influirias": "influir",
    "influirmo": "influir",
    "influirmos": "influir",
    "influirá": "influir",
    "influirás": "influir",
    "influirão": "influir",
    "influiríamos": "influir",
    "influiríeis": "influir",
    "influis": "influir",
    "influiu": "influir",
    "influições": "influição",
    "influo": "influir",
    "influxada": "influxado",
    "influxadas": "influxado",
    "influxados": "influxado",
    "influxos": "influxo",
    "influências": "influência",
    "influí": "influir",
    "influía": "influir",
    "influíam": "influir",
    "influíamo": "influir",
    "influíamos": "influir",
    "influías": "influir",
    "influída": "influir",
    "influídas": "influir",
    "influído": "influir",
    "influídos": "influir",
    "influíeis": "influir",
    "influímo": "influir",
    "influímos": "influir",
    "influíra": "influir",
    "influíram": "influir",
    "influíramo": "influir",
    "influíramos": "influir",
    "influíras": "influir",
    "influíreis": "influir",
    "influírem": "influir",
    "influíres": "influir",
    "influís": "influir",
    "influísse": "influir",
    "influísseis": "influir",
    "influíssem": "influir",
    "influíssemos": "influir",
    "influísses": "influir",
    "influíste": "influir",
    "influístes": "influir",
    "inflá": "inflar",
    "inflámo": "inflar",
    "inflámos": "inflar",
    "infláramo": "inflar",
    "infláramos": "inflar",
    "inflárei": "inflar",
    "infláreis": "inflar",
    "inflásseis": "inflar",
    "inflássemos": "inflar",
    "inflávamo": "inflar",
    "inflávamos": "inflar",
    "inflávei": "inflar",
    "infláveis": "inflável",
    "infografias": "infografia",
    "infográfica": "infográfico",
    "infográficas": "infográfico",
    "infográficos": "infográfico",
    "informa": "informar",
    "informada": "informar",
    "informadas": "informar",
    "informado": "informar",
    "informadora": "informador",
    "informadoras": "informador",
    "informadores": "informador",
    "informados": "informar",
    "informadíssima": "informado",
    "informadíssimas": "informado",
    "informadíssimo": "informado",
    "informadíssimos": "informado",
    "informai": "informar",
    "informais": "informar",
    "informalidades": "informalidade",
    "informam": "informar",
    "informamo": "informar",
    "informamos": "informar",
    "informando": "informar",
    "informantes": "informante",
    "informara": "informar",
    "informaram": "informar",
    "informaras": "informar",
    "informarde": "informar",
    "informardes": "informar",
    "informare": "informar",
    "informarei": "informar",
    "informareis": "informar",
    "informarem": "informar",
    "informaremos": "informar",
    "informares": "informar",
    "informaria": "informar",
    "informariam": "informar",
    "informarias": "informar",
    "informarmo": "informar",
    "informarmos": "informar",
    "informará": "informar",
    "informarás": "informar",
    "informarão": "informar",
    "informaríamos": "informar",
    "informaríeis": "informar",
    "informas": "informar",
    "informasse": "informar",
    "informassem": "informar",
    "informasses": "informar",
    "informaste": "informar",
    "informastes": "informar",
    "informativa": "informativo",
    "informativas": "informativo",
    "informativos": "informativo",
    "informatiza": "informatizar",
    "informatizada": "informatizar",
    "informatizadas": "informatizar",
    "informatizado": "informatizar",
    "informatizados": "informatizar",
    "informatizai": "informatizar",
    "informatizais": "informatizar",
    "informatizam": "informatizar",
    "informatizamo": "informatizar",
    "informatizamos": "informatizar",
    "informatizando": "informatizar",
    "informatizara": "informatizar",
    "informatizaram": "informatizar",
    "informatizaras": "informatizar",
    "informatizarde": "informatizar",
    "informatizardes": "informatizar",
    "informatizare": "informatizar",
    "informatizarei": "informatizar",
    "informatizareis": "informatizar",
    "informatizarem": "informatizar",
    "informatizaremos": "informatizar",
    "informatizares": "informatizar",
    "informatizaria": "informatizar",
    "informatizariam": "informatizar",
    "informatizarias": "informatizar",
    "informatizarmo": "informatizar",
    "informatizarmos": "informatizar",
    "informatizará": "informatizar",
    "informatizarás": "informatizar",
    "informatizarão": "informatizar",
    "informatizaríamos": "informatizar",
    "informatizaríeis": "informatizar",
    "informatizas": "informatizar",
    "informatizasse": "informatizar",
    "informatizassem": "informatizar",
    "informatizasses": "informatizar",
    "informatizaste": "informatizar",
    "informatizastes": "informatizar",
    "informatizava": "informatizar",
    "informatizavam": "informatizar",
    "informatizavas": "informatizar",
    "informatizações": "informatização",
    "informatize": "informatizar",
    "informatizei": "informatizar",
    "informatizeis": "informatizar",
    "informatizem": "informatizar",
    "informatizemo": "informatizar",
    "informatizemos": "informatizar",
    "informatizes": "informatizar",
    "informatizo": "informatizar",
    "informatizou": "informatizar",
    "informatizá": "informatizar",
    "informatizámo": "informatizar",
    "informatizámos": "informatizar",
    "informatizáramo": "informatizar",
    "informatizáramos": "informatizar",
    "informatizárei": "informatizar",
    "informatizáreis": "informatizar",
    "informatizásseis": "informatizar",
    "informatizássemos": "informatizar",
    "informatizávamo": "informatizar",
    "informatizávamos": "informatizar",
    "informatizávei": "informatizar",
    "informatizáveis": "informatizável",
    "informava": "informar",
    "informavam": "informar",
    "informavas": "informar",
    "informações": "informação",
    "informe": "informar",
    "informei": "informar",
    "informeis": "informar",
    "informem": "informar",
    "informemo": "informar",
    "informemos": "informar",
    "informes": "informe",
    "informidades": "informidade",
    "informo": "informar",
    "informou": "informar",
    "informá": "informar",
    "informámo": "informar",
    "informámos": "informar",
    "informáramo": "informar",
    "informáramos": "informar",
    "informárei": "informar",
    "informáreis": "informar",
    "informásseis": "informar",
    "informássemos": "informar",
    "informática": "informático",
    "informáticas": "informático",
    "informáticos": "informático",
    "informávamo": "informar",
    "informávamos": "informar",
    "informávei": "informar",
    "informáveis": "informável",
    "infortificáveis": "infortificável",
    "infortuna": "infortunar",
    "infortunada": "infortunar",
    "infortunadas": "infortunar",
    "infortunado": "infortunar",
    "infortunados": "infortunar",
    "infortunai": "infortunar",
    "infortunais": "infortunar",
    "infortunam": "infortunar",
    "infortunamo": "infortunar",
    "infortunamos": "infortunar",
    "infortunando": "infortunar",
    "infortunara": "infortunar",
    "infortunaram": "infortunar",
    "infortunaras": "infortunar",
    "infortunarde": "infortunar",
    "infortunardes": "infortunar",
    "infortunare": "infortunar",
    "infortunarei": "infortunar",
    "infortunareis": "infortunar",
    "infortunarem": "infortunar",
    "infortunaremos": "infortunar",
    "infortunares": "infortunar",
    "infortunaria": "infortunar",
    "infortunariam": "infortunar",
    "infortunarias": "infortunar",
    "infortunarmo": "infortunar",
    "infortunarmos": "infortunar",
    "infortunará": "infortunar",
    "infortunarás": "infortunar",
    "infortunarão": "infortunar",
    "infortunaríamos": "infortunar",
    "infortunaríeis": "infortunar",
    "infortunas": "infortunar",
    "infortunasse": "infortunar",
    "infortunassem": "infortunar",
    "infortunasses": "infortunar",
    "infortunaste": "infortunar",
    "infortunastes": "infortunar",
    "infortunava": "infortunar",
    "infortunavam": "infortunar",
    "infortunavas": "infortunar",
    "infortune": "infortunar",
    "infortunei": "infortunar",
    "infortuneis": "infortunar",
    "infortunem": "infortunar",
    "infortunemo": "infortunar",
    "infortunemos": "infortunar",
    "infortunes": "infortunar",
    "infortuno": "infortunar",
    "infortunosa": "infortunoso",
    "infortunosas": "infortunoso",
    "infortunosos": "infortunoso",
    "infortunou": "infortunar",
    "infortuná": "infortunar",
    "infortunámo": "infortunar",
    "infortunámos": "infortunar",
    "infortunáramo": "infortunar",
    "infortunáramos": "infortunar",
    "infortunárei": "infortunar",
    "infortunáreis": "infortunar",
    "infortunásseis": "infortunar",
    "infortunássemos": "infortunar",
    "infortunávamo": "infortunar",
    "infortunávamos": "infortunar",
    "infortunávei": "infortunar",
    "infortunáveis": "infortunar",
    "infortúnios": "infortúnio",
    "infracitada": "infracitado",
    "infracitadas": "infracitado",
    "infracitados": "infracitado",
    "infracta": "infracto",
    "infractas": "infracto",
    "infractora": "infractor",
    "infractoras": "infractor",
    "infractores": "infractor",
    "infractos": "infracto",
    "infracções": "infracção",
    "infraestruturas": "infraestrutura",
    "infrangibilidades": "infrangibilidade",
    "infrangíveis": "infrangível",
    "infranqueáveis": "infranqueável",
    "infravermelha": "infravermelho",
    "infravermelhas": "infravermelho",
    "infravermelhos": "infravermelho",
    "infrações": "infração",
    "infrenes": "infrene",
    "infrequentada": "infrequentado",
    "infrequentadas": "infrequentado",
    "infrequentados": "infrequentado",
    "infrequentes": "infrequente",
    "infrequências": "infrequência",
    "infringe": "infringir",
    "infringem": "infringir",
    "infringentes": "infringente",
    "infringes": "infringir",
    "infringi": "infringir",
    "infringia": "infringir",
    "infringiam": "infringir",
    "infringias": "infringir",
    "infringida": "infringir",
    "infringidas": "infringir",
    "infringido": "infringir",
    "infringidos": "infringir",
    "infringimo": "infringir",
    "infringimos": "infringir",
    "infringindo": "infringir",
    "infringira": "infringir",
    "infringiram": "infringir",
    "infringiras": "infringir",
    "infringirde": "infringir",
    "infringirdes": "infringir",
    "infringire": "infringir",
    "infringirei": "infringir",
    "infringireis": "infringir",
    "infringirem": "infringir",
    "infringiremos": "infringir",
    "infringires": "infringir",
    "infringiria": "infringir",
    "infringiriam": "infringir",
    "infringirias": "infringir",
    "infringirmo": "infringir",
    "infringirmos": "infringir",
    "infringirá": "infringir",
    "infringirás": "infringir",
    "infringirão": "infringir",
    "infringiríamos": "infringir",
    "infringiríeis": "infringir",
    "infringis": "infringir",
    "infringisse": "infringir",
    "infringissem": "infringir",
    "infringisses": "infringir",
    "infringiste": "infringir",
    "infringistes": "infringir",
    "infringiu": "infringir",
    "infringíamo": "infringir",
    "infringíamos": "infringir",
    "infringíei": "infringir",
    "infringíeis": "infringir",
    "infringíramo": "infringir",
    "infringíramos": "infringir",
    "infringírei": "infringir",
    "infringíreis": "infringir",
    "infringísseis": "infringir",
    "infringíssemos": "infringir",
    "infringíveis": "infringível",
    "infrinja": "infringir",
    "infrinjais": "infringir",
    "infrinjam": "infringir",
    "infrinjamo": "infringir",
    "infrinjamos": "infringir",
    "infrinjas": "infringir",
    "infrinjo": "infringir",
    "infronda": "infrondar",
    "infrondada": "infrondar",
    "infrondadas": "infrondar",
    "infrondado": "infrondar",
    "infrondados": "infrondar",
    "infrondai": "infrondar",
    "infrondais": "infrondar",
    "infrondam": "infrondar",
    "infrondamo": "infrondar",
    "infrondamos": "infrondar",
    "infrondando": "infrondar",
    "infrondara": "infrondar",
    "infrondaram": "infrondar",
    "infrondaras": "infrondar",
    "infrondarde": "infrondar",
    "infrondardes": "infrondar",
    "infrondare": "infrondar",
    "infrondarei": "infrondar",
    "infrondareis": "infrondar",
    "infrondarem": "infrondar",
    "infrondaremos": "infrondar",
    "infrondares": "infrondar",
    "infrondaria": "infrondar",
    "infrondariam": "infrondar",
    "infrondarias": "infrondar",
    "infrondarmo": "infrondar",
    "infrondarmos": "infrondar",
    "infrondará": "infrondar",
    "infrondarás": "infrondar",
    "infrondarão": "infrondar",
    "infrondaríamos": "infrondar",
    "infrondaríeis": "infrondar",
    "infrondas": "infrondar",
    "infrondasse": "infrondar",
    "infrondassem": "infrondar",
    "infrondasses": "infrondar",
    "infrondaste": "infrondar",
    "infrondastes": "infrondar",
    "infrondava": "infrondar",
    "infrondavam": "infrondar",
    "infrondavas": "infrondar",
    "infronde": "infrondar",
    "infrondei": "infrondar",
    "infrondeis": "infrondar",
    "infrondem": "infrondar",
    "infrondemo": "infrondar",
    "infrondemos": "infrondar",
    "infrondes": "infrondar",
    "infrondo": "infrondar",
    "infrondou": "infrondar",
    "infrondá": "infrondar",
    "infrondámo": "infrondar",
    "infrondámos": "infrondar",
    "infrondáramo": "infrondar",
    "infrondáramos": "infrondar",
    "infrondárei": "infrondar",
    "infrondáreis": "infrondar",
    "infrondásseis": "infrondar",
    "infrondássemos": "infrondar",
    "infrondávamo": "infrondar",
    "infrondávamos": "infrondar",
    "infrondávei": "infrondar",
    "infrondáveis": "infrondar",
    "infrutescentes": "infrutescente",
    "infrutescências": "infrutescência",
    "infrutuosa": "infrutuoso",
    "infrutuosas": "infrutuoso",
    "infrutuosidades": "infrutuosidade",
    "infrutuosos": "infrutuoso",
    "infrutífera": "infrutífero",
    "infrutíferas": "infrutífero",
    "infrutíferos": "infrutífero",
    "infumáveis": "infumável",
    "infumígena": "infumígeno",
    "infumígenas": "infumígeno",
    "infumígenos": "infumígeno",
    "infunda": "infundir",
    "infundada": "infundado",
    "infundadas": "infundado",
    "infundados": "infundado",
    "infundais": "infundir",
    "infundam": "infundir",
    "infundamentada": "infundamentado",
    "infundamentadas": "infundamentado",
    "infundamentados": "infundamentado",
    "infundamo": "infundir",
    "infundamos": "infundir",
    "infundas": "infundir",
    "infunde": "infundir",
    "infundem": "infundir",
    "infundes": "infundir",
    "infundi": "infundir",
    "infundia": "infundir",
    "infundiam": "infundir",
    "infundias": "infundir",
    "infundibuliformes": "infundibuliforme",
    "infundices": "infundice",
    "infundida": "infundir",
    "infundidas": "infundir",
    "infundido": "infundir",
    "infundidos": "infundir",
    "infundimo": "infundir",
    "infundimos": "infundir",
    "infundindo": "infundir",
    "infundira": "infundir",
    "infundiram": "infundir",
    "infundiras": "infundir",
    "infundirde": "infundir",
    "infundirdes": "infundir",
    "infundire": "infundir",
    "infundirei": "infundir",
    "infundireis": "infundir",
    "infundirem": "infundir",
    "infundiremos": "infundir",
    "infundires": "infundir",
    "infundiria": "infundir",
    "infundiriam": "infundir",
    "infundirias": "infundir",
    "infundirmo": "infundir",
    "infundirmos": "infundir",
    "infundirá": "infundir",
    "infundirás": "infundir",
    "infundirão": "infundir",
    "infundiríamos": "infundir",
    "infundiríeis": "infundir",
    "infundis": "infundir",
    "infundisse": "infundir",
    "infundissem": "infundir",
    "infundisses": "infundir",
    "infundiste": "infundir",
    "infundistes": "infundir",
    "infundiu": "infundir",
    "infundiças": "infundiça",
    "infundo": "infundir",
    "infundíamo": "infundir",
    "infundíamos": "infundir",
    "infundíbulos": "infundíbulo",
    "infundíei": "infundir",
    "infundíeis": "infundir",
    "infundíramo": "infundir",
    "infundíramos": "infundir",
    "infundírei": "infundir",
    "infundíreis": "infundir",
    "infundísseis": "infundir",
    "infundíssemos": "infundir",
    "infusa": "infuso",
    "infusas": "infuso",
    "infusibilidades": "infusibilidade",
    "infusos": "infuso",
    "infustamentos": "infustamento",
    "infusuras": "infusura",
    "infusíveis": "infusível",
    "infusórios": "infusório",
    "infusões": "infusão",
    "infâmias": "infâmia",
    "infâncias": "infância",
    "infértis": "infértil",
    "inganháveis": "inganhável",
    "ingarilhos": "ingarilho",
    "ingentes": "ingente",
    "ingenuidades": "ingenuidade",
    "ingere": "ingerir",
    "ingerem": "ingerir",
    "ingeres": "ingerir",
    "ingeri": "ingerir",
    "ingeria": "ingerir",
    "ingeriam": "ingerir",
    "ingerias": "ingerir",
    "ingerida": "ingerir",
    "ingeridas": "ingerir",
    "ingerido": "ingerir",
    "ingeridos": "ingerir",
    "ingerimo": "ingerir",
    "ingerimos": "ingerir",
    "ingerindo": "ingerir",
    "ingerira": "ingerir",
    "ingeriram": "ingerir",
    "ingeriras": "ingerir",
    "ingerirde": "ingerir",
    "ingerirdes": "ingerir",
    "ingerire": "ingerir",
    "ingerirei": "ingerir",
    "ingerireis": "ingerir",
    "ingerirem": "ingerir",
    "ingeriremos": "ingerir",
    "ingerires": "ingerir",
    "ingeriria": "ingerir",
    "ingeririam": "ingerir",
    "ingeririas": "ingerir",
    "ingerirmo": "ingerir",
    "ingerirmos": "ingerir",
    "ingerirá": "ingerir",
    "ingerirás": "ingerir",
    "ingerirão": "ingerir",
    "ingeriríamos": "ingerir",
    "ingeriríeis": "ingerir",
    "ingeris": "ingerir",
    "ingerisse": "ingerir",
    "ingerissem": "ingerir",
    "ingerisses": "ingerir",
    "ingeriste": "ingerir",
    "ingeristes": "ingerir",
    "ingeriu": "ingerir",
    "ingerências": "ingerência",
    "ingeríamo": "ingerir",
    "ingeríamos": "ingerir",
    "ingeríei": "ingerir",
    "ingeríeis": "ingerir",
    "ingeríramo": "ingerir",
    "ingeríramos": "ingerir",
    "ingerírei": "ingerir",
    "ingeríreis": "ingerir",
    "ingerísseis": "ingerir",
    "ingeríssemos": "ingerir",
    "ingeríveis": "ingerível",
    "ingestões": "ingestão",
    "ingira": "ingerir",
    "ingirais": "ingerir",
    "ingiram": "ingerir",
    "ingiramo": "ingerir",
    "ingiramos": "ingerir",
    "ingiras": "ingerir",
    "ingiro": "ingerir",
    "inglesa": "inglesar",
    "inglesada": "inglesar",
    "inglesadas": "inglesar",
    "inglesado": "inglesar",
    "inglesados": "inglesar",
    "inglesai": "inglesar",
    "inglesais": "inglesar",
    "inglesam": "inglesar",
    "inglesamo": "inglesar",
    "inglesamos": "inglesar",
    "inglesando": "inglesar",
    "inglesara": "inglesar",
    "inglesaram": "inglesar",
    "inglesaras": "inglesar",
    "inglesarde": "inglesar",
    "inglesardes": "inglesar",
    "inglesare": "inglesar",
    "inglesarei": "inglesar",
    "inglesareis": "inglesar",
    "inglesarem": "inglesar",
    "inglesaremos": "inglesar",
    "inglesares": "inglesar",
    "inglesaria": "inglesar",
    "inglesariam": "inglesar",
    "inglesarias": "inglesar",
    "inglesarmo": "inglesar",
    "inglesarmos": "inglesar",
    "inglesará": "inglesar",
    "inglesarás": "inglesar",
    "inglesarão": "inglesar",
    "inglesaríamos": "inglesar",
    "inglesaríeis": "inglesar",
    "inglesas": "inglesar",
    "inglesasse": "inglesar",
    "inglesassem": "inglesar",
    "inglesasses": "inglesar",
    "inglesaste": "inglesar",
    "inglesastes": "inglesar",
    "inglesava": "inglesar",
    "inglesavam": "inglesar",
    "inglesavas": "inglesar",
    "inglese": "inglesar",
    "inglesei": "inglesar",
    "ingleseis": "inglesar",
    "inglesem": "inglesar",
    "inglesemo": "inglesar",
    "inglesemos": "inglesar",
    "ingleses": "inglesar",
    "inglesias": "inglesia",
    "inglesices": "inglesice",
    "inglesismos": "inglesismo",
    "ingleso": "inglesar",
    "inglesou": "inglesar",
    "inglesá": "inglesar",
    "inglesámo": "inglesar",
    "inglesámos": "inglesar",
    "inglesáramo": "inglesar",
    "inglesáramos": "inglesar",
    "inglesárei": "inglesar",
    "inglesáreis": "inglesar",
    "inglesásseis": "inglesar",
    "inglesássemos": "inglesar",
    "inglesávamo": "inglesar",
    "inglesávamos": "inglesar",
    "inglesávei": "inglesar",
    "inglesáveis": "inglesável",
    "ingloriosa": "inglorioso",
    "ingloriosas": "inglorioso",
    "ingloriosos": "inglorioso",
    "ingluviais": "ingluvial",
    "ingluviosa": "ingluvioso",
    "ingluviosas": "ingluvioso",
    "ingluviosos": "ingluvioso",
    "inglória": "inglório",
    "inglórias": "inglório",
    "inglórios": "inglório",
    "ingovernabilidades": "ingovernabilidade",
    "ingovernáveis": "ingovernável",
    "ingraciosa": "ingracioso",
    "ingraciosas": "ingracioso",
    "ingraciosos": "ingracioso",
    "ingramaticais": "ingramatical",
    "ingramáveis": "ingramável",
    "ingranzéus": "ingranzéu",
    "ingrata": "ingrato",
    "ingratas": "ingrato",
    "ingratatona": "ingratatão",
    "ingratatonas": "ingratatão",
    "ingratatões": "ingratatão",
    "ingratidões": "ingratidão",
    "ingratona": "ingratão",
    "ingratonas": "ingratão",
    "ingratos": "ingrato",
    "ingratões": "ingratão",
    "ingredientes": "ingrediente",
    "ingremes": "ingreme",
    "ingremidades": "ingremidade",
    "ingres": "ingre",
    "ingresias": "ingresia",
    "ingressa": "ingressar",
    "ingressada": "ingressar",
    "ingressadas": "ingressar",
    "ingressado": "ingressar",
    "ingressados": "ingressar",
    "ingressai": "ingressar",
    "ingressais": "ingressar",
    "ingressam": "ingressar",
    "ingressamo": "ingressar",
    "ingressamos": "ingressar",
    "ingressando": "ingressar",
    "ingressara": "ingressar",
    "ingressaram": "ingressar",
    "ingressaras": "ingressar",
    "ingressardes": "ingressar",
    "ingressarei": "ingressar",
    "ingressareis": "ingressar",
    "ingressarem": "ingressar",
    "ingressaremos": "ingressar",
    "ingressares": "ingressar",
    "ingressaria": "ingressar",
    "ingressariam": "ingressar",
    "ingressarias": "ingressar",
    "ingressarmo": "ingressar",
    "ingressarmos": "ingressar",
    "ingressará": "ingressar",
    "ingressarás": "ingressar",
    "ingressarão": "ingressar",
    "ingressaríamos": "ingressar",
    "ingressaríeis": "ingressar",
    "ingressas": "ingressar",
    "ingressasse": "ingressar",
    "ingressassem": "ingressar",
    "ingressasses": "ingressar",
    "ingressaste": "ingressar",
    "ingressastes": "ingressar",
    "ingressava": "ingressar",
    "ingressavam": "ingressar",
    "ingressavas": "ingressar",
    "ingresse": "ingressar",
    "ingressei": "ingressar",
    "ingresseis": "ingressar",
    "ingressem": "ingressar",
    "ingressemo": "ingressar",
    "ingressemos": "ingressar",
    "ingresses": "ingressar",
    "ingresso": "ingressar",
    "ingressos": "ingresso",
    "ingressou": "ingressar",
    "ingressámo": "ingressar",
    "ingressámos": "ingressar",
    "ingressáramo": "ingressar",
    "ingressáramos": "ingressar",
    "ingressáreis": "ingressar",
    "ingressásseis": "ingressar",
    "ingressássemos": "ingressar",
    "ingressávamo": "ingressar",
    "ingressávamos": "ingressar",
    "ingressáveis": "ingressar",
    "ingressões": "ingressão",
    "ingrimes": "ingrime",
    "ingrões": "ingrão",
    "inguinabdominais": "inguinabdominal",
    "inguinais": "inguinal",
    "inguinações": "inguinação",
    "inguinoscrotais": "inguinoscrotal",
    "ingurgita": "ingurgitar",
    "ingurgitada": "ingurgitar",
    "ingurgitadas": "ingurgitar",
    "ingurgitado": "ingurgitar",
    "ingurgitados": "ingurgitar",
    "ingurgitai": "ingurgitar",
    "ingurgitais": "ingurgitar",
    "ingurgitam": "ingurgitar",
    "ingurgitamentos": "ingurgitamento",
    "ingurgitamo": "ingurgitar",
    "ingurgitamos": "ingurgitar",
    "ingurgitando": "ingurgitar",
    "ingurgitara": "ingurgitar",
    "ingurgitaram": "ingurgitar",
    "ingurgitaras": "ingurgitar",
    "ingurgitarde": "ingurgitar",
    "ingurgitardes": "ingurgitar",
    "ingurgitare": "ingurgitar",
    "ingurgitarei": "ingurgitar",
    "ingurgitareis": "ingurgitar",
    "ingurgitarem": "ingurgitar",
    "ingurgitaremos": "ingurgitar",
    "ingurgitares": "ingurgitar",
    "ingurgitaria": "ingurgitar",
    "ingurgitariam": "ingurgitar",
    "ingurgitarias": "ingurgitar",
    "ingurgitarmo": "ingurgitar",
    "ingurgitarmos": "ingurgitar",
    "ingurgitará": "ingurgitar",
    "ingurgitarás": "ingurgitar",
    "ingurgitarão": "ingurgitar",
    "ingurgitaríamos": "ingurgitar",
    "ingurgitaríeis": "ingurgitar",
    "ingurgitas": "ingurgitar",
    "ingurgitasse": "ingurgitar",
    "ingurgitassem": "ingurgitar",
    "ingurgitasses": "ingurgitar",
    "ingurgitaste": "ingurgitar",
    "ingurgitastes": "ingurgitar",
    "ingurgitava": "ingurgitar",
    "ingurgitavam": "ingurgitar",
    "ingurgitavas": "ingurgitar",
    "ingurgitações": "ingurgitação",
    "ingurgite": "ingurgitar",
    "ingurgitei": "ingurgitar",
    "ingurgiteis": "ingurgitar",
    "ingurgitem": "ingurgitar",
    "ingurgitemo": "ingurgitar",
    "ingurgitemos": "ingurgitar",
    "ingurgites": "ingurgitar",
    "ingurgito": "ingurgitar",
    "ingurgitou": "ingurgitar",
    "ingurgitá": "ingurgitar",
    "ingurgitámo": "ingurgitar",
    "ingurgitámos": "ingurgitar",
    "ingurgitáramo": "ingurgitar",
    "ingurgitáramos": "ingurgitar",
    "ingurgitárei": "ingurgitar",
    "ingurgitáreis": "ingurgitar",
    "ingurgitásseis": "ingurgitar",
    "ingurgitássemos": "ingurgitar",
    "ingurgitávamo": "ingurgitar",
    "ingurgitávamos": "ingurgitar",
    "ingurgitávei": "ingurgitar",
    "ingurgitáveis": "ingurgitar",
    "ingénita": "ingénito",
    "ingénitas": "ingénito",
    "ingénitos": "ingénito",
    "ingénua": "ingénuo",
    "ingénuas": "ingénuo",
    "ingénuos": "ingénuo",
    "inhacas": "inhaca",
    "inhacocos": "inhacoco",
    "inhames": "inhame",
    "inhenha": "inhenho",
    "inhenhas": "inhenho",
    "inhenhos": "inhenho",
    "inialas": "iniala",
    "iniba": "inibir",
    "inibais": "inibir",
    "inibam": "inibir",
    "inibamo": "inibir",
    "inibamos": "inibir",
    "inibas": "inibir",
    "inibe": "inibir",
    "inibem": "inibir",
    "inibes": "inibir",
    "inibi": "inibir",
    "inibia": "inibir",
    "inibiam": "inibir",
    "inibias": "inibir",
    "inibida": "inibir",
    "inibidas": "inibir",
    "inibido": "inibir",
    "inibidora": "inibidor",
    "inibidoras": "inibidor",
    "inibidores": "inibidor",
    "inibidos": "inibir",
    "inibidíssima": "inibido",
    "inibidíssimas": "inibido",
    "inibidíssimo": "inibido",
    "inibidíssimos": "inibido",
    "inibimo": "inibir",
    "inibimos": "inibir",
    "inibindo": "inibir",
    "inibira": "inibir",
    "inibiram": "inibir",
    "inibiras": "inibir",
    "inibirde": "inibir",
    "inibirdes": "inibir",
    "inibire": "inibir",
    "inibirei": "inibir",
    "inibireis": "inibir",
    "inibirem": "inibir",
    "inibiremos": "inibir",
    "inibires": "inibir",
    "inibiria": "inibir",
    "inibiriam": "inibir",
    "inibirias": "inibir",
    "inibirmo": "inibir",
    "inibirmos": "inibir",
    "inibirá": "inibir",
    "inibirás": "inibir",
    "inibirão": "inibir",
    "inibiríamos": "inibir",
    "inibiríeis": "inibir",
    "inibis": "inibir",
    "inibisse": "inibir",
    "inibissem": "inibir",
    "inibisses": "inibir",
    "inibiste": "inibir",
    "inibistes": "inibir",
    "inibitiva": "inibitivo",
    "inibitivas": "inibitivo",
    "inibitivos": "inibitivo",
    "inibitória": "inibitório",
    "inibitórias": "inibitório",
    "inibitórios": "inibitório",
    "inibiu": "inibir",
    "inibições": "inibição",
    "inibo": "inibir",
    "inibíamo": "inibir",
    "inibíamos": "inibir",
    "inibíei": "inibir",
    "inibíeis": "inibir",
    "inibíramo": "inibir",
    "inibíramos": "inibir",
    "inibírei": "inibir",
    "inibíreis": "inibir",
    "inibísseis": "inibir",
    "inibíssemos": "inibir",
    "inibíveis": "inibível",
    "inicia": "iniciar",
    "iniciada": "iniciar",
    "iniciadas": "iniciar",
    "iniciado": "iniciar",
    "iniciadora": "iniciador",
    "iniciadoras": "iniciador",
    "iniciadores": "iniciador",
    "iniciados": "iniciar",
    "iniciai": "iniciar",
    "iniciais": "iniciar",
    "iniciam": "iniciar",
    "iniciamo": "iniciar",
    "iniciamos": "iniciar",
    "inicianda": "iniciando",
    "iniciandas": "iniciando",
    "iniciando": "iniciar",
    "iniciandos": "iniciando",
    "iniciara": "iniciar",
    "iniciaram": "iniciar",
    "iniciaras": "iniciar",
    "iniciarde": "iniciar",
    "iniciardes": "iniciar",
    "iniciare": "iniciar",
    "iniciarei": "iniciar",
    "iniciareis": "iniciar",
    "iniciarem": "iniciar",
    "iniciaremos": "iniciar",
    "iniciares": "iniciar",
    "iniciaria": "iniciar",
    "iniciariam": "iniciar",
    "iniciarias": "iniciar",
    "iniciarmo": "iniciar",
    "iniciarmos": "iniciar",
    "iniciará": "iniciar",
    "iniciarás": "iniciar",
    "iniciarão": "iniciar",
    "iniciaríamos": "iniciar",
    "iniciaríeis": "iniciar",
    "inicias": "iniciar",
    "iniciasse": "iniciar",
    "iniciassem": "iniciar",
    "iniciasses": "iniciar",
    "iniciaste": "iniciar",
    "iniciastes": "iniciar",
    "iniciativa": "iniciativo",
    "iniciativas": "iniciativo",
    "iniciativos": "iniciativo",
    "iniciava": "iniciar",
    "iniciavam": "iniciar",
    "iniciavas": "iniciar",
    "iniciações": "iniciação",
    "inicie": "iniciar",
    "iniciei": "iniciar",
    "inicieis": "iniciar",
    "iniciem": "iniciar",
    "iniciemo": "iniciar",
    "iniciemos": "iniciar",
    "inicies": "iniciar",
    "inicio": "iniciar",
    "iniciou": "iniciar",
    "iniciá": "iniciar",
    "iniciámo": "iniciar",
    "iniciámos": "iniciar",
    "iniciáramo": "iniciar",
    "iniciáramos": "iniciar",
    "iniciárei": "iniciar",
    "iniciáreis": "iniciar",
    "iniciásseis": "iniciar",
    "iniciássemos": "iniciar",
    "iniciática": "iniciático",
    "iniciáticas": "iniciático",
    "iniciáticos": "iniciático",
    "iniciávamo": "iniciar",
    "iniciávamos": "iniciar",
    "iniciávei": "iniciar",
    "iniciáveis": "iniciar",
    "inidoneidades": "inidoneidade",
    "inidónea": "inidóneo",
    "inidóneas": "inidóneo",
    "inidóneos": "inidóneo",
    "inigualada": "inigualado",
    "inigualadas": "inigualado",
    "inigualados": "inigualado",
    "inigualáveis": "inigualável",
    "iniludíveis": "iniludível",
    "inimaginada": "inimaginado",
    "inimaginadas": "inimaginado",
    "inimaginados": "inimaginado",
    "inimagináveis": "inimaginável",
    "inimicícias": "inimicícia",
    "inimicíssima": "inimigo",
    "inimicíssimas": "inimigo",
    "inimicíssimo": "inimigo",
    "inimicíssimos": "inimigo",
    "inimiga": "inimigo",
    "inimigas": "inimigo",
    "inimigazinha": "inimigo",
    "inimigazinhas": "inimigo",
    "inimigazita": "inimigo",
    "inimigazitas": "inimigo",
    "inimigos": "inimigo",
    "inimigozinho": "inimigo",
    "inimigozinhos": "inimigo",
    "inimigozito": "inimigo",
    "inimigozitos": "inimigo",
    "inimiguíssima": "inimigo",
    "inimiguíssimas": "inimigo",
    "inimiguíssimo": "inimigo",
    "inimiguíssimos": "inimigo",
    "inimista": "inimistar",
    "inimistada": "inimistar",
    "inimistadas": "inimistar",
    "inimistado": "inimistar",
    "inimistados": "inimistar",
    "inimistai": "inimistar",
    "inimistais": "inimistar",
    "inimistam": "inimistar",
    "inimistamo": "inimistar",
    "inimistamos": "inimistar",
    "inimistando": "inimistar",
    "inimistara": "inimistar",
    "inimistaram": "inimistar",
    "inimistaras": "inimistar",
    "inimistarde": "inimistar",
    "inimistardes": "inimistar",
    "inimistare": "inimistar",
    "inimistarei": "inimistar",
    "inimistareis": "inimistar",
    "inimistarem": "inimistar",
    "inimistaremos": "inimistar",
    "inimistares": "inimistar",
    "inimistaria": "inimistar",
    "inimistariam": "inimistar",
    "inimistarias": "inimistar",
    "inimistarmo": "inimistar",
    "inimistarmos": "inimistar",
    "inimistará": "inimistar",
    "inimistarás": "inimistar",
    "inimistarão": "inimistar",
    "inimistaríamos": "inimistar",
    "inimistaríeis": "inimistar",
    "inimistas": "inimistar",
    "inimistasse": "inimistar",
    "inimistassem": "inimistar",
    "inimistasses": "inimistar",
    "inimistaste": "inimistar",
    "inimistastes": "inimistar",
    "inimistava": "inimistar",
    "inimistavam": "inimistar",
    "inimistavas": "inimistar",
    "inimiste": "inimistar",
    "inimistei": "inimistar",
    "inimisteis": "inimistar",
    "inimistem": "inimistar",
    "inimistemo": "inimistar",
    "inimistemos": "inimistar",
    "inimistes": "inimistar",
    "inimisto": "inimistar",
    "inimistou": "inimistar",
    "inimistá": "inimistar",
    "inimistámo": "inimistar",
    "inimistámos": "inimistar",
    "inimistáramo": "inimistar",
    "inimistáramos": "inimistar",
    "inimistárei": "inimistar",
    "inimistáreis": "inimistar",
    "inimistásseis": "inimistar",
    "inimistássemos": "inimistar",
    "inimistávamo": "inimistar",
    "inimistávamos": "inimistar",
    "inimistávei": "inimistar",
    "inimistáveis": "inimistar",
    "inimitada": "inimitado",
    "inimitadas": "inimitado",
    "inimitados": "inimitado",
    "inimitáveis": "inimitável",
    "inimiza": "inimizar",
    "inimizada": "inimizar",
    "inimizadas": "inimizar",
    "inimizades": "inimizade",
    "inimizado": "inimizar",
    "inimizados": "inimizar",
    "inimizai": "inimizar",
    "inimizais": "inimizar",
    "inimizam": "inimizar",
    "inimizamo": "inimizar",
    "inimizamos": "inimizar",
    "inimizando": "inimizar",
    "inimizara": "inimizar",
    "inimizaram": "inimizar",
    "inimizaras": "inimizar",
    "inimizarde": "inimizar",
    "inimizardes": "inimizar",
    "inimizare": "inimizar",
    "inimizarei": "inimizar",
    "inimizareis": "inimizar",
    "inimizarem": "inimizar",
    "inimizaremos": "inimizar",
    "inimizares": "inimizar",
    "inimizaria": "inimizar",
    "inimizariam": "inimizar",
    "inimizarias": "inimizar",
    "inimizarmo": "inimizar",
    "inimizarmos": "inimizar",
    "inimizará": "inimizar",
    "inimizarás": "inimizar",
    "inimizarão": "inimizar",
    "inimizaríamos": "inimizar",
    "inimizaríeis": "inimizar",
    "inimizas": "inimizar",
    "inimizasse": "inimizar",
    "inimizassem": "inimizar",
    "inimizasses": "inimizar",
    "inimizaste": "inimizar",
    "inimizastes": "inimizar",
    "inimizava": "inimizar",
    "inimizavam": "inimizar",
    "inimizavas": "inimizar",
    "inimize": "inimizar",
    "inimizei": "inimizar",
    "inimizeis": "inimizar",
    "inimizem": "inimizar",
    "inimizemo": "inimizar",
    "inimizemos": "inimizar",
    "inimizes": "inimizar",
    "inimizo": "inimizar",
    "inimizou": "inimizar",
    "inimizá": "inimizar",
    "inimizámo": "inimizar",
    "inimizámos": "inimizar",
    "inimizáramo": "inimizar",
    "inimizáramos": "inimizar",
    "inimizárei": "inimizar",
    "inimizáreis": "inimizar",
    "inimizásseis": "inimizar",
    "inimizássemos": "inimizar",
    "inimizávamo": "inimizar",
    "inimizávamos": "inimizar",
    "inimizávei": "inimizar",
    "inimizáveis": "inimizar",
    "inimputabilidades": "inimputabilidade",
    "inimputáveis": "inimputável",
    "ininteligibilidades": "ininteligibilidade",
    "ininteligências": "ininteligência",
    "ininteligíveis": "ininteligível",
    "ininterrompida": "ininterrompido",
    "ininterrompidas": "ininterrompido",
    "ininterrompidos": "ininterrompido",
    "ininterrupta": "ininterrupto",
    "ininterruptas": "ininterrupto",
    "ininterruptos": "ininterrupto",
    "ininterrupções": "ininterrupção",
    "ininvestigáveis": "ininvestigável",
    "iniodimos": "iniodimo",
    "iniomos": "iniomo",
    "iniquidades": "iniquidade",
    "injecta": "injectar",
    "injectada": "injectar",
    "injectadas": "injectar",
    "injectado": "injectar",
    "injectados": "injectar",
    "injectai": "injectar",
    "injectais": "injectar",
    "injectam": "injectar",
    "injectamo": "injectar",
    "injectamos": "injectar",
    "injectando": "injectar",
    "injectara": "injectar",
    "injectaram": "injectar",
    "injectaras": "injectar",
    "injectarde": "injectar",
    "injectardes": "injectar",
    "injectare": "injectar",
    "injectarei": "injectar",
    "injectareis": "injectar",
    "injectarem": "injectar",
    "injectaremos": "injectar",
    "injectares": "injectar",
    "injectaria": "injectar",
    "injectariam": "injectar",
    "injectarias": "injectar",
    "injectarmo": "injectar",
    "injectarmos": "injectar",
    "injectará": "injectar",
    "injectarás": "injectar",
    "injectarão": "injectar",
    "injectaríamos": "injectar",
    "injectaríeis": "injectar",
    "injectas": "injectar",
    "injectasse": "injectar",
    "injectassem": "injectar",
    "injectasses": "injectar",
    "injectaste": "injectar",
    "injectastes": "injectar",
    "injectava": "injectar",
    "injectavam": "injectar",
    "injectavas": "injectar",
    "injecte": "injectar",
    "injectei": "injectar",
    "injecteis": "injectar",
    "injectem": "injectar",
    "injectemo": "injectar",
    "injectemos": "injectar",
    "injectes": "injectar",
    "injecto": "injectar",
    "injectora": "injector",
    "injectoras": "injector",
    "injectores": "injector",
    "injectou": "injectar",
    "injectá": "injectar",
    "injectámo": "injectar",
    "injectámos": "injectar",
    "injectáramo": "injectar",
    "injectáramos": "injectar",
    "injectárei": "injectar",
    "injectáreis": "injectar",
    "injectásseis": "injectar",
    "injectássemos": "injectar",
    "injectávamo": "injectar",
    "injectávamos": "injectar",
    "injectávei": "injectar",
    "injectáveis": "injectável",
    "injecções": "injecção",
    "injucunda": "injucundo",
    "injucundas": "injucundo",
    "injucundos": "injucundo",
    "injudiciosa": "injudicioso",
    "injudiciosas": "injudicioso",
    "injudiciosos": "injudicioso",
    "injulgada": "injulgado",
    "injulgadas": "injulgado",
    "injulgados": "injulgado",
    "injunge": "injungir",
    "injungem": "injungir",
    "injunges": "injungir",
    "injungi": "injungir",
    "injungia": "injungir",
    "injungiam": "injungir",
    "injungias": "injungir",
    "injungida": "injungir",
    "injungidas": "injungir",
    "injungido": "injungir",
    "injungidos": "injungir",
    "injungimo": "injungir",
    "injungimos": "injungir",
    "injungindo": "injungir",
    "injungira": "injungir",
    "injungiram": "injungir",
    "injungiras": "injungir",
    "injungirde": "injungir",
    "injungirdes": "injungir",
    "injungire": "injungir",
    "injungirei": "injungir",
    "injungireis": "injungir",
    "injungirem": "injungir",
    "injungiremos": "injungir",
    "injungires": "injungir",
    "injungiria": "injungir",
    "injungiriam": "injungir",
    "injungirias": "injungir",
    "injungirmo": "injungir",
    "injungirmos": "injungir",
    "injungirá": "injungir",
    "injungirás": "injungir",
    "injungirão": "injungir",
    "injungiríamos": "injungir",
    "injungiríeis": "injungir",
    "injungis": "injungir",
    "injungisse": "injungir",
    "injungissem": "injungir",
    "injungisses": "injungir",
    "injungiste": "injungir",
    "injungistes": "injungir",
    "injungiu": "injungir",
    "injungíamo": "injungir",
    "injungíamos": "injungir",
    "injungíei": "injungir",
    "injungíeis": "injungir",
    "injungíramo": "injungir",
    "injungíramos": "injungir",
    "injungírei": "injungir",
    "injungíreis": "injungir",
    "injungísseis": "injungir",
    "injungíssemos": "injungir",
    "injunja": "injungir",
    "injunjais": "injungir",
    "injunjam": "injungir",
    "injunjamo": "injungir",
    "injunjamos": "injungir",
    "injunjas": "injungir",
    "injunjo": "injungir",
    "injuntiva": "injuntivo",
    "injuntivas": "injuntivo",
    "injuntivos": "injuntivo",
    "injunções": "injunção",
    "injuria": "injuriar",
    "injuriada": "injuriar",
    "injuriadas": "injuriar",
    "injuriado": "injuriar",
    "injuriadora": "injuriador",
    "injuriadoras": "injuriador",
    "injuriadores": "injuriador",
    "injuriados": "injuriar",
    "injuriadíssima": "injuriado",
    "injuriadíssimas": "injuriado",
    "injuriadíssimo": "injuriado",
    "injuriadíssimos": "injuriado",
    "injuriai": "injuriar",
    "injuriais": "injuriar",
    "injuriam": "injuriar",
    "injuriamo": "injuriar",
    "injuriamos": "injuriar",
    "injuriando": "injuriar",
    "injuriantes": "injuriante",
    "injuriara": "injuriar",
    "injuriaram": "injuriar",
    "injuriaras": "injuriar",
    "injuriarde": "injuriar",
    "injuriardes": "injuriar",
    "injuriare": "injuriar",
    "injuriarei": "injuriar",
    "injuriareis": "injuriar",
    "injuriarem": "injuriar",
    "injuriaremos": "injuriar",
    "injuriares": "injuriar",
    "injuriaria": "injuriar",
    "injuriariam": "injuriar",
    "injuriarias": "injuriar",
    "injuriarmo": "injuriar",
    "injuriarmos": "injuriar",
    "injuriará": "injuriar",
    "injuriarás": "injuriar",
    "injuriarão": "injuriar",
    "injuriaríamos": "injuriar",
    "injuriaríeis": "injuriar",
    "injurias": "injuriar",
    "injuriasse": "injuriar",
    "injuriassem": "injuriar",
    "injuriasses": "injuriar",
    "injuriaste": "injuriar",
    "injuriastes": "injuriar",
    "injuriava": "injuriar",
    "injuriavam": "injuriar",
    "injuriavas": "injuriar",
    "injurie": "injuriar",
    "injuriei": "injuriar",
    "injurieis": "injuriar",
    "injuriem": "injuriar",
    "injuriemo": "injuriar",
    "injuriemos": "injuriar",
    "injuries": "injuriar",
    "injurio": "injuriar",
    "injuriosa": "injurioso",
    "injuriosas": "injurioso",
    "injuriosos": "injurioso",
    "injuriou": "injuriar",
    "injuriá": "injuriar",
    "injuriámo": "injuriar",
    "injuriámos": "injuriar",
    "injuriáramo": "injuriar",
    "injuriáramos": "injuriar",
    "injuriárei": "injuriar",
    "injuriáreis": "injuriar",
    "injuriásseis": "injuriar",
    "injuriássemos": "injuriar",
    "injuriávamo": "injuriar",
    "injuriávamos": "injuriar",
    "injuriávei": "injuriar",
    "injuriáveis": "injuriável",
    "injusta": "injusto",
    "injustas": "injusto",
    "injustifica": "injustificar",
    "injustificada": "injustificar",
    "injustificadas": "injustificar",
    "injustificado": "injustificar",
    "injustificados": "injustificar",
    "injustificai": "injustificar",
    "injustificais": "injustificar",
    "injustificam": "injustificar",
    "injustificamo": "injustificar",
    "injustificamos": "injustificar",
    "injustificando": "injustificar",
    "injustificara": "injustificar",
    "injustificaram": "injustificar",
    "injustificaras": "injustificar",
    "injustificarde": "injustificar",
    "injustificardes": "injustificar",
    "injustificare": "injustificar",
    "injustificarei": "injustificar",
    "injustificareis": "injustificar",
    "injustificarem": "injustificar",
    "injustificaremos": "injustificar",
    "injustificares": "injustificar",
    "injustificaria": "injustificar",
    "injustificariam": "injustificar",
    "injustificarias": "injustificar",
    "injustificarmo": "injustificar",
    "injustificarmos": "injustificar",
    "injustificará": "injustificar",
    "injustificarás": "injustificar",
    "injustificarão": "injustificar",
    "injustificaríamos": "injustificar",
    "injustificaríeis": "injustificar",
    "injustificas": "injustificar",
    "injustificasse": "injustificar",
    "injustificassem": "injustificar",
    "injustificasses": "injustificar",
    "injustificaste": "injustificar",
    "injustificastes": "injustificar",
    "injustificava": "injustificar",
    "injustificavam": "injustificar",
    "injustificavas": "injustificar",
    "injustificações": "injustificação",
    "injustifico": "injustificar",
    "injustificou": "injustificar",
    "injustificá": "injustificar",
    "injustificámo": "injustificar",
    "injustificámos": "injustificar",
    "injustificáramo": "injustificar",
    "injustificáramos": "injustificar",
    "injustificárei": "injustificar",
    "injustificáreis": "injustificar",
    "injustificásseis": "injustificar",
    "injustificássemos": "injustificar",
    "injustificávamo": "injustificar",
    "injustificávamos": "injustificar",
    "injustificávei": "injustificar",
    "injustificáveis": "injustificável",
    "injustifique": "injustificar",
    "injustifiquei": "injustificar",
    "injustifiqueis": "injustificar",
    "injustifiquem": "injustificar",
    "injustifiquemo": "injustificar",
    "injustifiquemos": "injustificar",
    "injustifiques": "injustificar",
    "injustiçada": "injustiçado",
    "injustiçadas": "injustiçado",
    "injustiçados": "injustiçado",
    "injustiças": "injustiça",
    "injustiçosa": "injustiçoso",
    "injustiçosas": "injustiçoso",
    "injustiçosos": "injustiçoso",
    "injustos": "injusto",
    "injustíssima": "injusto",
    "injustíssimas": "injusto",
    "injustíssimo": "injusto",
    "injustíssimos": "injusto",
    "injúrias": "injúria",
    "inlapidada": "inlapidado",
    "inlapidadas": "inlapidado",
    "inlapidados": "inlapidado",
    "inobedientes": "inobediente",
    "inobediências": "inobediência",
    "inobliteráveis": "inobliterável",
    "inobservada": "inobservado",
    "inobservadas": "inobservado",
    "inobservados": "inobservado",
    "inobservantes": "inobservante",
    "inobserváveis": "inobservável",
    "inobservâncias": "inobservância",
    "inocenta": "inocentar",
    "inocentada": "inocentar",
    "inocentadas": "inocentar",
    "inocentado": "inocentar",
    "inocentados": "inocentar",
    "inocentai": "inocentar",
    "inocentais": "inocentar",
    "inocentam": "inocentar",
    "inocentamo": "inocentar",
    "inocentamos": "inocentar",
    "inocentando": "inocentar",
    "inocentara": "inocentar",
    "inocentaram": "inocentar",
    "inocentaras": "inocentar",
    "inocentarde": "inocentar",
    "inocentardes": "inocentar",
    "inocentare": "inocentar",
    "inocentarei": "inocentar",
    "inocentareis": "inocentar",
    "inocentarem": "inocentar",
    "inocentaremos": "inocentar",
    "inocentares": "inocentar",
    "inocentaria": "inocentar",
    "inocentariam": "inocentar",
    "inocentarias": "inocentar",
    "inocentarmo": "inocentar",
    "inocentarmos": "inocentar",
    "inocentará": "inocentar",
    "inocentarás": "inocentar",
    "inocentarão": "inocentar",
    "inocentaríamos": "inocentar",
    "inocentaríeis": "inocentar",
    "inocentas": "inocentar",
    "inocentasse": "inocentar",
    "inocentassem": "inocentar",
    "inocentasses": "inocentar",
    "inocentaste": "inocentar",
    "inocentastes": "inocentar",
    "inocentava": "inocentar",
    "inocentavam": "inocentar",
    "inocentavas": "inocentar",
    "inocente": "inocentar",
    "inocentei": "inocentar",
    "inocenteis": "inocentar",
    "inocentem": "inocentar",
    "inocentemo": "inocentar",
    "inocentemos": "inocentar",
    "inocentes": "inocente",
    "inocento": "inocentar",
    "inocentou": "inocentar",
    "inocentá": "inocentar",
    "inocentámo": "inocentar",
    "inocentámos": "inocentar",
    "inocentáramo": "inocentar",
    "inocentáramos": "inocentar",
    "inocentárei": "inocentar",
    "inocentáreis": "inocentar",
    "inocentásseis": "inocentar",
    "inocentássemos": "inocentar",
    "inocentávamo": "inocentar",
    "inocentávamos": "inocentar",
    "inocentávei": "inocentar",
    "inocentáveis": "inocentável",
    "inocuidades": "inocuidade",
    "inocula": "inocular",
    "inoculabilidades": "inoculabilidade",
    "inoculada": "inocular",
    "inoculadas": "inocular",
    "inoculado": "inocular",
    "inoculadora": "inoculador",
    "inoculadoras": "inoculador",
    "inoculadores": "inoculador",
    "inoculados": "inocular",
    "inoculai": "inocular",
    "inoculais": "inocular",
    "inoculam": "inocular",
    "inoculamo": "inocular",
    "inoculamos": "inocular",
    "inoculando": "inocular",
    "inoculara": "inocular",
    "inocularam": "inocular",
    "inocularas": "inocular",
    "inocularde": "inocular",
    "inoculardes": "inocular",
    "inoculare": "inocular",
    "inocularei": "inocular",
    "inoculareis": "inocular",
    "inocularem": "inocular",
    "inocularemos": "inocular",
    "inoculares": "inocular",
    "inocularia": "inocular",
    "inoculariam": "inocular",
    "inocularias": "inocular",
    "inocularmo": "inocular",
    "inocularmos": "inocular",
    "inoculará": "inocular",
    "inocularás": "inocular",
    "inocularão": "inocular",
    "inocularíamos": "inocular",
    "inocularíeis": "inocular",
    "inoculas": "inocular",
    "inoculasse": "inocular",
    "inoculassem": "inocular",
    "inoculasses": "inocular",
    "inoculaste": "inocular",
    "inoculastes": "inocular",
    "inoculava": "inocular",
    "inoculavam": "inocular",
    "inoculavas": "inocular",
    "inoculações": "inoculação",
    "inocule": "inocular",
    "inoculei": "inocular",
    "inoculeis": "inocular",
    "inoculem": "inocular",
    "inoculemo": "inocular",
    "inoculemos": "inocular",
    "inocules": "inocular",
    "inoculo": "inocular",
    "inoculou": "inocular",
    "inocultáveis": "inocultável",
    "inoculá": "inocular",
    "inoculámo": "inocular",
    "inoculámos": "inocular",
    "inoculáramo": "inocular",
    "inoculáramos": "inocular",
    "inoculárei": "inocular",
    "inoculáreis": "inocular",
    "inoculásseis": "inocular",
    "inoculássemos": "inocular",
    "inoculávamo": "inocular",
    "inoculávamos": "inocular",
    "inoculávei": "inocular",
    "inoculáveis": "inoculável",
    "inocupada": "inocupado",
    "inocupadas": "inocupado",
    "inocupados": "inocupado",
    "inocupações": "inocupação",
    "inocências": "inocência",
    "inodora": "inodoro",
    "inodoras": "inodoro",
    "inodoros": "inodoro",
    "inofensiva": "inofensivo",
    "inofensivas": "inofensivo",
    "inofensivos": "inofensivo",
    "inoficiosa": "inoficioso",
    "inoficiosas": "inoficioso",
    "inoficiosidades": "inoficiosidade",
    "inoficiosos": "inoficioso",
    "inofuscáveis": "inofuscável",
    "inolentes": "inolente",
    "inolvidada": "inolvidado",
    "inolvidadas": "inolvidado",
    "inolvidados": "inolvidado",
    "inolvidáveis": "inolvidável",
    "inominada": "inominado",
    "inominadas": "inominado",
    "inominados": "inominado",
    "inomináveis": "inominável",
    "inomogeneidades": "inomogeneidade",
    "inoperantes": "inoperante",
    "inoperações": "inoperação",
    "inoperáveis": "inoperável",
    "inoperâncias": "inoperância",
    "inopexias": "inopexia",
    "inopina": "inopino",
    "inopinada": "inopinado",
    "inopinadas": "inopinado",
    "inopinados": "inopinado",
    "inopinas": "inopino",
    "inopinos": "inopino",
    "inopináveis": "inopinável",
    "inoportuna": "inoportuno",
    "inoportunas": "inoportuno",
    "inoportunidades": "inoportunidade",
    "inoportunos": "inoportuno",
    "inorganismos": "inorganismo",
    "inorganizada": "inorganizado",
    "inorganizadas": "inorganizado",
    "inorganizados": "inorganizado",
    "inorgânica": "inorgânico",
    "inorgânicas": "inorgânico",
    "inorgânicos": "inorgânico",
    "inosculações": "inosculação",
    "inosites": "inosite",
    "inositóis": "inositol",
    "inositúrias": "inositúria",
    "inospitaleira": "inospitaleiro",
    "inospitaleiras": "inospitaleiro",
    "inospitaleiros": "inospitaleiro",
    "inospitalidades": "inospitalidade",
    "inosúrias": "inosúria",
    "inova": "inovar",
    "inovada": "inovar",
    "inovadas": "inovar",
    "inovado": "inovar",
    "inovadora": "inovador",
    "inovadoras": "inovador",
    "inovadores": "inovador",
    "inovados": "inovar",
    "inovai": "inovar",
    "inovais": "inovar",
    "inovam": "inovar",
    "inovamo": "inovar",
    "inovamos": "inovar",
    "inovando": "inovar",
    "inovara": "inovar",
    "inovaram": "inovar",
    "inovaras": "inovar",
    "inovarde": "inovar",
    "inovardes": "inovar",
    "inovare": "inovar",
    "inovarei": "inovar",
    "inovareis": "inovar",
    "inovarem": "inovar",
    "inovaremos": "inovar",
    "inovares": "inovar",
    "inovaria": "inovar",
    "inovariam": "inovar",
    "inovarias": "inovar",
    "inovarmo": "inovar",
    "inovarmos": "inovar",
    "inovará": "inovar",
    "inovarás": "inovar",
    "inovarão": "inovar",
    "inovaríamos": "inovar",
    "inovaríeis": "inovar",
    "inovas": "inovar",
    "inovasse": "inovar",
    "inovassem": "inovar",
    "inovasses": "inovar",
    "inovaste": "inovar",
    "inovastes": "inovar",
    "inovava": "inovar",
    "inovavam": "inovar",
    "inovavas": "inovar",
    "inovações": "inovação",
    "inove": "inovar",
    "inovei": "inovar",
    "inoveis": "inovar",
    "inovem": "inovar",
    "inovemo": "inovar",
    "inovemos": "inovar",
    "inoves": "inovar",
    "inovo": "inovar",
    "inovou": "inovar",
    "inová": "inovar",
    "inovámo": "inovar",
    "inovámos": "inovar",
    "inováramo": "inovar",
    "inováramos": "inovar",
    "inovárei": "inovar",
    "inováreis": "inovar",
    "inovásseis": "inovar",
    "inovássemos": "inovar",
    "inovávamo": "inovar",
    "inovávamos": "inovar",
    "inovávei": "inovar",
    "inováveis": "inovável",
    "inoxes": "inox",
    "inoxidáveis": "inoxidável",
    "inoxs": "inox",
    "inputes": "input",
    "inqualificada": "inqualificado",
    "inqualificadas": "inqualificado",
    "inqualificados": "inqualificado",
    "inqualificáveis": "inqualificável",
    "inquebrantibilidades": "inquebrantibilidade",
    "inquebrantáveis": "inquebrantável",
    "inquebráveis": "inquebrável",
    "inquera": "inquerir",
    "inquerais": "inquerir",
    "inqueram": "inquerir",
    "inqueramo": "inquerir",
    "inqueramos": "inquerir",
    "inqueras": "inquerir",
    "inquere": "inquerir",
    "inquerem": "inquerir",
    "inqueres": "inquerir",
    "inqueri": "inquerir",
    "inqueria": "inquerir",
    "inqueriam": "inquerir",
    "inquerias": "inquerir",
    "inquerida": "inquerir",
    "inqueridas": "inquerir",
    "inquerideiras": "inquerideira",
    "inquerido": "inquerir",
    "inqueridos": "inquerir",
    "inquerimo": "inquerir",
    "inquerimos": "inquerir",
    "inquerindo": "inquerir",
    "inquerira": "inquerir",
    "inqueriram": "inquerir",
    "inqueriras": "inquerir",
    "inquerirde": "inquerir",
    "inquerirdes": "inquerir",
    "inquerire": "inquerir",
    "inquerirei": "inquerir",
    "inquerireis": "inquerir",
    "inquerirem": "inquerir",
    "inqueriremos": "inquerir",
    "inquerires": "inquerir",
    "inqueriria": "inquerir",
    "inqueririam": "inquerir",
    "inqueririas": "inquerir",
    "inquerirmo": "inquerir",
    "inquerirmos": "inquerir",
    "inquerirá": "inquerir",
    "inquerirás": "inquerir",
    "inquerirão": "inquerir",
    "inqueriríamos": "inquerir",
    "inqueriríeis": "inquerir",
    "inqueris": "inquerir",
    "inquerisse": "inquerir",
    "inquerissem": "inquerir",
    "inquerisses": "inquerir",
    "inqueriste": "inquerir",
    "inqueristes": "inquerir",
    "inqueriu": "inquerir",
    "inquerições": "inquerição",
    "inquero": "inquerir",
    "inqueríamo": "inquerir",
    "inqueríamos": "inquerir",
    "inqueríei": "inquerir",
    "inqueríeis": "inquerir",
    "inqueríramo": "inquerir",
    "inqueríramos": "inquerir",
    "inquerírei": "inquerir",
    "inqueríreis": "inquerir",
    "inquerísseis": "inquerir",
    "inqueríssemos": "inquerir",
    "inquestionáveis": "inquestionável",
    "inquieta": "inquieto",
    "inquietada": "inquietar",
    "inquietadas": "inquietar",
    "inquietado": "inquietar",
    "inquietadora": "inquietador",
    "inquietadoras": "inquietador",
    "inquietadores": "inquietador",
    "inquietados": "inquietar",
    "inquietai": "inquietar",
    "inquietais": "inquietar",
    "inquietam": "inquietar",
    "inquietamentos": "inquietamento",
    "inquietamo": "inquietar",
    "inquietamos": "inquietar",
    "inquietando": "inquietar",
    "inquietantes": "inquietante",
    "inquietara": "inquietar",
    "inquietaram": "inquietar",
    "inquietaras": "inquietar",
    "inquietarde": "inquietar",
    "inquietardes": "inquietar",
    "inquietare": "inquietar",
    "inquietarei": "inquietar",
    "inquietareis": "inquietar",
    "inquietarem": "inquietar",
    "inquietaremos": "inquietar",
    "inquietares": "inquietar",
    "inquietaria": "inquietar",
    "inquietariam": "inquietar",
    "inquietarias": "inquietar",
    "inquietarmo": "inquietar",
    "inquietarmos": "inquietar",
    "inquietará": "inquietar",
    "inquietarás": "inquietar",
    "inquietarão": "inquietar",
    "inquietaríamos": "inquietar",
    "inquietaríeis": "inquietar",
    "inquietas": "inquieto",
    "inquietasse": "inquietar",
    "inquietassem": "inquietar",
    "inquietasses": "inquietar",
    "inquietaste": "inquietar",
    "inquietastes": "inquietar",
    "inquietava": "inquietar",
    "inquietavam": "inquietar",
    "inquietavas": "inquietar",
    "inquietações": "inquietação",
    "inquiete": "inquietar",
    "inquietei": "inquietar",
    "inquieteis": "inquietar",
    "inquietem": "inquietar",
    "inquietemo": "inquietar",
    "inquietemos": "inquietar",
    "inquietes": "inquietar",
    "inquieto": "inquietar",
    "inquietos": "inquieto",
    "inquietou": "inquietar",
    "inquietudes": "inquietude",
    "inquietá": "inquietar",
    "inquietámo": "inquietar",
    "inquietámos": "inquietar",
    "inquietáramo": "inquietar",
    "inquietáramos": "inquietar",
    "inquietárei": "inquietar",
    "inquietáreis": "inquietar",
    "inquietásseis": "inquietar",
    "inquietássemos": "inquietar",
    "inquietávamo": "inquietar",
    "inquietávamos": "inquietar",
    "inquietávei": "inquietar",
    "inquietáveis": "inquietar",
    "inquilina": "inquilino",
    "inquilinas": "inquilino",
    "inquilinatos": "inquilinato",
    "inquilinismos": "inquilinismo",
    "inquilinos": "inquilino",
    "inquina": "inquinar",
    "inquinada": "inquinar",
    "inquinadas": "inquinar",
    "inquinado": "inquinar",
    "inquinados": "inquinar",
    "inquinai": "inquinar",
    "inquinais": "inquinar",
    "inquinam": "inquinar",
    "inquinamentos": "inquinamento",
    "inquinamo": "inquinar",
    "inquinamos": "inquinar",
    "inquinando": "inquinar",
    "inquinara": "inquinar",
    "inquinaram": "inquinar",
    "inquinaras": "inquinar",
    "inquinarde": "inquinar",
    "inquinardes": "inquinar",
    "inquinare": "inquinar",
    "inquinarei": "inquinar",
    "inquinareis": "inquinar",
    "inquinarem": "inquinar",
    "inquinaremos": "inquinar",
    "inquinares": "inquinar",
    "inquinaria": "inquinar",
    "inquinariam": "inquinar",
    "inquinarias": "inquinar",
    "inquinarmo": "inquinar",
    "inquinarmos": "inquinar",
    "inquinará": "inquinar",
    "inquinarás": "inquinar",
    "inquinarão": "inquinar",
    "inquinaríamos": "inquinar",
    "inquinaríeis": "inquinar",
    "inquinas": "inquinar",
    "inquinasse": "inquinar",
    "inquinassem": "inquinar",
    "inquinasses": "inquinar",
    "inquinaste": "inquinar",
    "inquinastes": "inquinar",
    "inquinava": "inquinar",
    "inquinavam": "inquinar",
    "inquinavas": "inquinar",
    "inquinações": "inquinação",
    "inquine": "inquinar",
    "inquinei": "inquinar",
    "inquineis": "inquinar",
    "inquinem": "inquinar",
    "inquinemo": "inquinar",
    "inquinemos": "inquinar",
    "inquines": "inquinar",
    "inquino": "inquinar",
    "inquinou": "inquinar",
    "inquiná": "inquinar",
    "inquinámo": "inquinar",
    "inquinámos": "inquinar",
    "inquináramo": "inquinar",
    "inquináramos": "inquinar",
    "inquinárei": "inquinar",
    "inquináreis": "inquinar",
    "inquinásseis": "inquinar",
    "inquinássemos": "inquinar",
    "inquinávamo": "inquinar",
    "inquinávamos": "inquinar",
    "inquinávei": "inquinar",
    "inquináveis": "inquinar",
    "inquira": "inquirir",
    "inquirais": "inquirir",
    "inquiram": "inquirir",
    "inquiramo": "inquirir",
    "inquiramos": "inquirir",
    "inquiras": "inquirir",
    "inquire": "inquirir",
    "inquirem": "inquirir",
    "inquires": "inquirir",
    "inquiri": "inquirir",
    "inquiria": "inquirir",
    "inquiriam": "inquirir",
    "inquirias": "inquirir",
    "inquirida": "inquirir",
    "inquiridas": "inquirir",
    "inquirido": "inquirir",
    "inquiridora": "inquiridor",
    "inquiridoras": "inquiridor",
    "inquiridores": "inquiridor",
    "inquiridorias": "inquiridoria",
    "inquiridos": "inquirir",
    "inquirimentos": "inquirimento",
    "inquirimo": "inquirir",
    "inquirimos": "inquirir",
    "inquirindo": "inquirir",
    "inquirira": "inquirir",
    "inquiriram": "inquirir",
    "inquiriras": "inquirir",
    "inquirirde": "inquirir",
    "inquirirdes": "inquirir",
    "inquirire": "inquirir",
    "inquirirei": "inquirir",
    "inquirireis": "inquirir",
    "inquirirem": "inquirir",
    "inquiriremos": "inquirir",
    "inquirires": "inquirir",
    "inquiriria": "inquirir",
    "inquiririam": "inquirir",
    "inquiririas": "inquirir",
    "inquirirmo": "inquirir",
    "inquirirmos": "inquirir",
    "inquirirá": "inquirir",
    "inquirirás": "inquirir",
    "inquirirão": "inquirir",
    "inquiriríamos": "inquirir",
    "inquiriríeis": "inquirir",
    "inquiris": "inquirir",
    "inquirisse": "inquirir",
    "inquirissem": "inquirir",
    "inquirisses": "inquirir",
    "inquiriste": "inquirir",
    "inquiristes": "inquirir",
    "inquiritoriais": "inquiritorial",
    "inquiriu": "inquirir",
    "inquirições": "inquirição",
    "inquiro": "inquirir",
    "inquiríamo": "inquirir",
    "inquiríamos": "inquirir",
    "inquiríei": "inquirir",
    "inquiríeis": "inquirir",
    "inquiríramo": "inquirir",
    "inquiríramos": "inquirir",
    "inquirírei": "inquirir",
    "inquiríreis": "inquirir",
    "inquirísseis": "inquirir",
    "inquiríssemos": "inquirir",
    "inquisidora": "inquisidor",
    "inquisidoras": "inquisidor",
    "inquisidores": "inquisidor",
    "inquisitiva": "inquisitivo",
    "inquisitivas": "inquisitivo",
    "inquisitivos": "inquisitivo",
    "inquisitoriais": "inquisitorial",
    "inquisitória": "inquisitório",
    "inquisitórias": "inquisitório",
    "inquisitórios": "inquisitório",
    "inquisições": "inquisição",
    "inquéritos": "inquérito",
    "inrestauráveis": "inrestaurável",
    "insaciabilidades": "insaciabilidade",
    "insaciada": "insaciado",
    "insaciadas": "insaciado",
    "insaciados": "insaciado",
    "insaciedades": "insaciedade",
    "insaciáveis": "insaciável",
    "insaliva": "insalivar",
    "insalivada": "insalivar",
    "insalivadas": "insalivar",
    "insalivado": "insalivar",
    "insalivados": "insalivar",
    "insalivai": "insalivar",
    "insalivais": "insalivar",
    "insalivam": "insalivar",
    "insalivamo": "insalivar",
    "insalivamos": "insalivar",
    "insalivando": "insalivar",
    "insalivara": "insalivar",
    "insalivaram": "insalivar",
    "insalivaras": "insalivar",
    "insalivardes": "insalivar",
    "insalivarei": "insalivar",
    "insalivareis": "insalivar",
    "insalivarem": "insalivar",
    "insalivaremos": "insalivar",
    "insalivares": "insalivar",
    "insalivaria": "insalivar",
    "insalivariam": "insalivar",
    "insalivarias": "insalivar",
    "insalivarmo": "insalivar",
    "insalivarmos": "insalivar",
    "insalivará": "insalivar",
    "insalivarás": "insalivar",
    "insalivarão": "insalivar",
    "insalivaríamos": "insalivar",
    "insalivaríeis": "insalivar",
    "insalivas": "insalivar",
    "insalivasse": "insalivar",
    "insalivassem": "insalivar",
    "insalivasses": "insalivar",
    "insalivaste": "insalivar",
    "insalivastes": "insalivar",
    "insalivava": "insalivar",
    "insalivavam": "insalivar",
    "insalivavas": "insalivar",
    "insalivações": "insalivação",
    "insalive": "insalivar",
    "insalivei": "insalivar",
    "insaliveis": "insalivar",
    "insalivem": "insalivar",
    "insalivemo": "insalivar",
    "insalivemos": "insalivar",
    "insalives": "insalivar",
    "insalivo": "insalivar",
    "insalivou": "insalivar",
    "insalivámo": "insalivar",
    "insalivámos": "insalivar",
    "insaliváramo": "insalivar",
    "insaliváramos": "insalivar",
    "insaliváreis": "insalivar",
    "insalivásseis": "insalivar",
    "insalivássemos": "insalivar",
    "insalivávamo": "insalivar",
    "insalivávamos": "insalivar",
    "insaliváveis": "insalivar",
    "insalubres": "insalubre",
    "insalubrezinha": "insalubre",
    "insalubrezinhas": "insalubre",
    "insalubrezinho": "insalubre",
    "insalubrezinhos": "insalubre",
    "insalubrezita": "insalubre",
    "insalubrezitas": "insalubre",
    "insalubrezito": "insalubre",
    "insalubrezitos": "insalubre",
    "insalubridades": "insalubridade",
    "insalubérrima": "insalubre",
    "insalubérrimas": "insalubre",
    "insalubérrimo": "insalubre",
    "insalubérrimos": "insalubre",
    "insalutífera": "insalutífero",
    "insalutíferas": "insalutífero",
    "insalutíferos": "insalutífero",
    "insalváveis": "insalvável",
    "insana": "insano",
    "insanabilidades": "insanabilidade",
    "insanas": "insano",
    "insaneáveis": "insaneável",
    "insanidades": "insanidade",
    "insanos": "insano",
    "insanáveis": "insanável",
    "insaponificáveis": "insaponificável",
    "insaráveis": "insarável",
    "insatisfatória": "insatisfatório",
    "insatisfatórias": "insatisfatório",
    "insatisfatórios": "insatisfatório",
    "insatisfações": "insatisfação",
    "insatisfeita": "insatisfeito",
    "insatisfeitas": "insatisfeito",
    "insatisfeitos": "insatisfeito",
    "insatisfeitíssima": "insatisfeito",
    "insatisfeitíssimas": "insatisfeito",
    "insatisfeitíssimo": "insatisfeito",
    "insatisfeitíssimos": "insatisfeito",
    "insaturada": "insaturado",
    "insaturadas": "insaturado",
    "insaturados": "insaturado",
    "insaturações": "insaturação",
    "insaturáveis": "insaturável",
    "inscientes": "insciente",
    "insciências": "insciência",
    "inscreva": "inscrever",
    "inscrevais": "inscrever",
    "inscrevam": "inscrever",
    "inscrevamo": "inscrever",
    "inscrevamos": "inscrever",
    "inscrevas": "inscrever",
    "inscreve": "inscrever",
    "inscrevei": "inscrever",
    "inscreveis": "inscrever",
    "inscrevem": "inscrever",
    "inscrevemo": "inscrever",
    "inscrevemos": "inscrever",
    "inscrevendo": "inscrever",
    "inscrevera": "inscrever",
    "inscreveram": "inscrever",
    "inscreveras": "inscrever",
    "inscreverde": "inscrever",
    "inscreverdes": "inscrever",
    "inscrevere": "inscrever",
    "inscreverei": "inscrever",
    "inscrevereis": "inscrever",
    "inscreverem": "inscrever",
    "inscreveremos": "inscrever",
    "inscreveres": "inscrever",
    "inscreveria": "inscrever",
    "inscreveriam": "inscrever",
    "inscreverias": "inscrever",
    "inscrevermo": "inscrever",
    "inscrevermos": "inscrever",
    "inscreverá": "inscrever",
    "inscreverás": "inscrever",
    "inscreverão": "inscrever",
    "inscreveríamos": "inscrever",
    "inscreveríeis": "inscrever",
    "inscreves": "inscrever",
    "inscrevesse": "inscrever",
    "inscrevessem": "inscrever",
    "inscrevesses": "inscrever",
    "inscreveste": "inscrever",
    "inscrevestes": "inscrever",
    "inscreveu": "inscrever",
    "inscrevi": "inscrever",
    "inscrevia": "inscrever",
    "inscreviam": "inscrever",
    "inscrevias": "inscrever",
    "inscrevo": "inscrever",
    "inscrevê": "inscrever",
    "inscrevêramo": "inscrever",
    "inscrevêramos": "inscrever",
    "inscrevêrei": "inscrever",
    "inscrevêreis": "inscrever",
    "inscrevêsseis": "inscrever",
    "inscrevêssemos": "inscrever",
    "inscrevíamo": "inscrever",
    "inscrevíamos": "inscrever",
    "inscrevíei": "inscrever",
    "inscrevíeis": "inscrever",
    "inscrita": "inscrito",
    "inscritas": "inscrito",
    "inscrito": "inscrever",
    "inscritos": "inscrito",
    "inscritíveis": "inscritível",
    "inscrições": "inscrição",
    "insculpa": "insculpir",
    "insculpais": "insculpir",
    "insculpam": "insculpir",
    "insculpamo": "insculpir",
    "insculpamos": "insculpir",
    "insculpas": "insculpir",
    "insculpe": "insculpir",
    "insculpem": "insculpir",
    "insculpes": "insculpir",
    "insculpi": "insculpir",
    "insculpia": "insculpir",
    "insculpiam": "insculpir",
    "insculpias": "insculpir",
    "insculpida": "insculpir",
    "insculpidas": "insculpir",
    "insculpido": "insculpir",
    "insculpidos": "insculpir",
    "insculpimo": "insculpir",
    "insculpimos": "insculpir",
    "insculpindo": "insculpir",
    "insculpira": "insculpir",
    "insculpiram": "insculpir",
    "insculpiras": "insculpir",
    "insculpirde": "insculpir",
    "insculpirdes": "insculpir",
    "insculpire": "insculpir",
    "insculpirei": "insculpir",
    "insculpireis": "insculpir",
    "insculpirem": "insculpir",
    "insculpiremos": "insculpir",
    "insculpires": "insculpir",
    "insculpiria": "insculpir",
    "insculpiriam": "insculpir",
    "insculpirias": "insculpir",
    "insculpirmo": "insculpir",
    "insculpirmos": "insculpir",
    "insculpirá": "insculpir",
    "insculpirás": "insculpir",
    "insculpirão": "insculpir",
    "insculpiríamos": "insculpir",
    "insculpiríeis": "insculpir",
    "insculpis": "insculpir",
    "insculpisse": "insculpir",
    "insculpissem": "insculpir",
    "insculpisses": "insculpir",
    "insculpiste": "insculpir",
    "insculpistes": "insculpir",
    "insculpiu": "insculpir",
    "insculpo": "insculpir",
    "insculpíamo": "insculpir",
    "insculpíamos": "insculpir",
    "insculpíei": "insculpir",
    "insculpíeis": "insculpir",
    "insculpíramo": "insculpir",
    "insculpíramos": "insculpir",
    "insculpírei": "insculpir",
    "insculpíreis": "insculpir",
    "insculpísseis": "insculpir",
    "insculpíssemos": "insculpir",
    "inscultora": "inscultor",
    "inscultoras": "inscultor",
    "inscultores": "inscultor",
    "insculturas": "inscultura",
    "inscícias": "inscícia",
    "insecticidas": "insecticida",
    "insecticídios": "insecticídio",
    "insectiformes": "insectiforme",
    "insectologias": "insectologia",
    "insectologistas": "insectologista",
    "insectológica": "insectológico",
    "insectológicas": "insectológico",
    "insectológicos": "insectológico",
    "insectos": "insecto",
    "insectários": "insectário",
    "insectífera": "insectífero",
    "insectíferas": "insectífero",
    "insectíferos": "insectífero",
    "insectífuga": "insectífugo",
    "insectífugas": "insectífugo",
    "insectífugos": "insectífugo",
    "insectívora": "insectívoro",
    "insectívoras": "insectívoro",
    "insectívoros": "insectívoro",
    "insectófila": "insectófilo",
    "insectófilas": "insectófilo",
    "insectófilos": "insectófilo",
    "insecáveis": "insecável",
    "inseduzíveis": "inseduzível",
    "insegura": "inseguro",
    "inseguranças": "insegurança",
    "inseguras": "inseguro",
    "inseguridades": "inseguridade",
    "inseguros": "inseguro",
    "inseguráveis": "insegurável",
    "insemina": "inseminar",
    "inseminada": "inseminar",
    "inseminadas": "inseminar",
    "inseminado": "inseminar",
    "inseminados": "inseminar",
    "inseminai": "inseminar",
    "inseminais": "inseminar",
    "inseminam": "inseminar",
    "inseminamo": "inseminar",
    "inseminamos": "inseminar",
    "inseminando": "inseminar",
    "inseminara": "inseminar",
    "inseminaram": "inseminar",
    "inseminaras": "inseminar",
    "inseminarde": "inseminar",
    "inseminardes": "inseminar",
    "inseminare": "inseminar",
    "inseminarei": "inseminar",
    "inseminareis": "inseminar",
    "inseminarem": "inseminar",
    "inseminaremos": "inseminar",
    "inseminares": "inseminar",
    "inseminaria": "inseminar",
    "inseminariam": "inseminar",
    "inseminarias": "inseminar",
    "inseminarmo": "inseminar",
    "inseminarmos": "inseminar",
    "inseminará": "inseminar",
    "inseminarás": "inseminar",
    "inseminarão": "inseminar",
    "inseminaríamos": "inseminar",
    "inseminaríeis": "inseminar",
    "inseminas": "inseminar",
    "inseminasse": "inseminar",
    "inseminassem": "inseminar",
    "inseminasses": "inseminar",
    "inseminaste": "inseminar",
    "inseminastes": "inseminar",
    "inseminava": "inseminar",
    "inseminavam": "inseminar",
    "inseminavas": "inseminar",
    "inseminações": "inseminação",
    "insemine": "inseminar",
    "inseminei": "inseminar",
    "insemineis": "inseminar",
    "inseminem": "inseminar",
    "inseminemo": "inseminar",
    "inseminemos": "inseminar",
    "insemines": "inseminar",
    "insemino": "inseminar",
    "inseminou": "inseminar",
    "inseminá": "inseminar",
    "inseminámo": "inseminar",
    "inseminámos": "inseminar",
    "insemináramo": "inseminar",
    "insemináramos": "inseminar",
    "inseminárei": "inseminar",
    "insemináreis": "inseminar",
    "inseminásseis": "inseminar",
    "inseminássemos": "inseminar",
    "inseminávamo": "inseminar",
    "inseminávamos": "inseminar",
    "inseminávei": "inseminar",
    "insemináveis": "inseminável",
    "insensata": "insensato",
    "insensatas": "insensato",
    "insensatezes": "insensatez",
    "insensatos": "insensato",
    "insensibilidades": "insensibilidade",
    "insensibiliza": "insensibilizar",
    "insensibilizada": "insensibilizar",
    "insensibilizadas": "insensibilizar",
    "insensibilizado": "insensibilizar",
    "insensibilizados": "insensibilizar",
    "insensibilizai": "insensibilizar",
    "insensibilizais": "insensibilizar",
    "insensibilizam": "insensibilizar",
    "insensibilizamo": "insensibilizar",
    "insensibilizamos": "insensibilizar",
    "insensibilizando": "insensibilizar",
    "insensibilizara": "insensibilizar",
    "insensibilizaram": "insensibilizar",
    "insensibilizaras": "insensibilizar",
    "insensibilizarde": "insensibilizar",
    "insensibilizardes": "insensibilizar",
    "insensibilizare": "insensibilizar",
    "insensibilizarei": "insensibilizar",
    "insensibilizareis": "insensibilizar",
    "insensibilizarem": "insensibilizar",
    "insensibilizaremos": "insensibilizar",
    "insensibilizares": "insensibilizar",
    "insensibilizaria": "insensibilizar",
    "insensibilizariam": "insensibilizar",
    "insensibilizarias": "insensibilizar",
    "insensibilizarmo": "insensibilizar",
    "insensibilizarmos": "insensibilizar",
    "insensibilizará": "insensibilizar",
    "insensibilizarás": "insensibilizar",
    "insensibilizarão": "insensibilizar",
    "insensibilizaríamos": "insensibilizar",
    "insensibilizaríeis": "insensibilizar",
    "insensibilizas": "insensibilizar",
    "insensibilizasse": "insensibilizar",
    "insensibilizassem": "insensibilizar",
    "insensibilizasses": "insensibilizar",
    "insensibilizaste": "insensibilizar",
    "insensibilizastes": "insensibilizar",
    "insensibilizava": "insensibilizar",
    "insensibilizavam": "insensibilizar",
    "insensibilizavas": "insensibilizar",
    "insensibilizações": "insensibilização",
    "insensibilize": "insensibilizar",
    "insensibilizei": "insensibilizar",
    "insensibilizeis": "insensibilizar",
    "insensibilizem": "insensibilizar",
    "insensibilizemo": "insensibilizar",
    "insensibilizemos": "insensibilizar",
    "insensibilizes": "insensibilizar",
    "insensibilizo": "insensibilizar",
    "insensibilizou": "insensibilizar",
    "insensibilizá": "insensibilizar",
    "insensibilizámo": "insensibilizar",
    "insensibilizámos": "insensibilizar",
    "insensibilizáramo": "insensibilizar",
    "insensibilizáramos": "insensibilizar",
    "insensibilizárei": "insensibilizar",
    "insensibilizáreis": "insensibilizar",
    "insensibilizásseis": "insensibilizar",
    "insensibilizássemos": "insensibilizar",
    "insensibilizávamo": "insensibilizar",
    "insensibilizávamos": "insensibilizar",
    "insensibilizávei": "insensibilizar",
    "insensibilizáveis": "insensibilizar",
    "insensitiva": "insensitivo",
    "insensitivas": "insensitivo",
    "insensitivos": "insensitivo",
    "insensíveis": "insensível",
    "inseparabilidades": "inseparabilidade",
    "inseparada": "inseparado",
    "inseparadas": "inseparado",
    "inseparados": "inseparado",
    "inseparáveis": "inseparável",
    "insepulta": "insepulto",
    "insepultada": "insepultado",
    "insepultadas": "insepultado",
    "insepultados": "insepultado",
    "insepultas": "insepulto",
    "insepultos": "insepulto",
    "insere": "inserir",
    "inserem": "inserir",
    "inseres": "inserir",
    "inseri": "inserir",
    "inseria": "inserir",
    "inseriam": "inserir",
    "inserias": "inserir",
    "inserida": "inserir",
    "inseridas": "inserir",
    "inserido": "inserir",
    "inseridos": "inserir",
    "inserimo": "inserir",
    "inserimos": "inserir",
    "inserindo": "inserir",
    "inserira": "inserir",
    "inseriram": "inserir",
    "inseriras": "inserir",
    "inserirde": "inserir",
    "inserirdes": "inserir",
    "inserire": "inserir",
    "inserirei": "inserir",
    "inserireis": "inserir",
    "inserirem": "inserir",
    "inseriremos": "inserir",
    "inserires": "inserir",
    "inseriria": "inserir",
    "inseririam": "inserir",
    "inseririas": "inserir",
    "inserirmo": "inserir",
    "inserirmos": "inserir",
    "inserirá": "inserir",
    "inserirás": "inserir",
    "inserirão": "inserir",
    "inseriríamos": "inserir",
    "inseriríeis": "inserir",
    "inseris": "inserir",
    "inserisse": "inserir",
    "inserissem": "inserir",
    "inserisses": "inserir",
    "inseriste": "inserir",
    "inseristes": "inserir",
    "inseriu": "inserir",
    "inserta": "inserto",
    "insertas": "inserto",
    "insertos": "inserto",
    "inserções": "inserção",
    "inseríamo": "inserir",
    "inseríamos": "inserir",
    "inseríei": "inserir",
    "inseríeis": "inserir",
    "inseríramo": "inserir",
    "inseríramos": "inserir",
    "inserírei": "inserir",
    "inseríreis": "inserir",
    "inserísseis": "inserir",
    "inseríssemos": "inserir",
    "inseríveis": "inserível",
    "insetivorias": "insetivoria",
    "insexuada": "insexuado",
    "insexuadas": "insexuado",
    "insexuados": "insexuado",
    "insexuais": "insexual",
    "insexualidades": "insexualidade",
    "insidia": "insidiar",
    "insidiada": "insidiar",
    "insidiadas": "insidiar",
    "insidiado": "insidiar",
    "insidiadora": "insidiador",
    "insidiadoras": "insidiador",
    "insidiadores": "insidiador",
    "insidiados": "insidiar",
    "insidiai": "insidiar",
    "insidiais": "insidiar",
    "insidiam": "insidiar",
    "insidiamo": "insidiar",
    "insidiamos": "insidiar",
    "insidiando": "insidiar",
    "insidiara": "insidiar",
    "insidiaram": "insidiar",
    "insidiaras": "insidiar",
    "insidiarde": "insidiar",
    "insidiardes": "insidiar",
    "insidiare": "insidiar",
    "insidiarei": "insidiar",
    "insidiareis": "insidiar",
    "insidiarem": "insidiar",
    "insidiaremos": "insidiar",
    "insidiares": "insidiar",
    "insidiaria": "insidiar",
    "insidiariam": "insidiar",
    "insidiarias": "insidiar",
    "insidiarmo": "insidiar",
    "insidiarmos": "insidiar",
    "insidiará": "insidiar",
    "insidiarás": "insidiar",
    "insidiarão": "insidiar",
    "insidiaríamos": "insidiar",
    "insidiaríeis": "insidiar",
    "insidias": "insidiar",
    "insidiasse": "insidiar",
    "insidiassem": "insidiar",
    "insidiasses": "insidiar",
    "insidiaste": "insidiar",
    "insidiastes": "insidiar",
    "insidiava": "insidiar",
    "insidiavam": "insidiar",
    "insidiavas": "insidiar",
    "insidiações": "insidiação",
    "insidie": "insidiar",
    "insidiei": "insidiar",
    "insidieis": "insidiar",
    "insidiem": "insidiar",
    "insidiemo": "insidiar",
    "insidiemos": "insidiar",
    "insidies": "insidiar",
    "insidio": "insidiar",
    "insidiosa": "insidioso",
    "insidiosas": "insidioso",
    "insidiosos": "insidioso",
    "insidiou": "insidiar",
    "insidiá": "insidiar",
    "insidiámo": "insidiar",
    "insidiámos": "insidiar",
    "insidiáramo": "insidiar",
    "insidiáramos": "insidiar",
    "insidiárei": "insidiar",
    "insidiáreis": "insidiar",
    "insidiásseis": "insidiar",
    "insidiássemos": "insidiar",
    "insidiávamo": "insidiar",
    "insidiávamos": "insidiar",
    "insidiávei": "insidiar",
    "insidiáveis": "insidiar",
    "insights": "insight",
    "insignes": "insigne",
    "insignificantes": "insignificante",
    "insignificativa": "insignificativo",
    "insignificativas": "insignificativo",
    "insignificativos": "insignificativo",
    "insignificâncias": "insignificância",
    "insimula": "insimular",
    "insimulada": "insimular",
    "insimuladas": "insimular",
    "insimulado": "insimular",
    "insimulados": "insimular",
    "insimulai": "insimular",
    "insimulais": "insimular",
    "insimulam": "insimular",
    "insimulamo": "insimular",
    "insimulamos": "insimular",
    "insimulando": "insimular",
    "insimulara": "insimular",
    "insimularam": "insimular",
    "insimularas": "insimular",
    "insimularde": "insimular",
    "insimulardes": "insimular",
    "insimulare": "insimular",
    "insimularei": "insimular",
    "insimulareis": "insimular",
    "insimularem": "insimular",
    "insimularemos": "insimular",
    "insimulares": "insimular",
    "insimularia": "insimular",
    "insimulariam": "insimular",
    "insimularias": "insimular",
    "insimularmo": "insimular",
    "insimularmos": "insimular",
    "insimulará": "insimular",
    "insimularás": "insimular",
    "insimularão": "insimular",
    "insimularíamos": "insimular",
    "insimularíeis": "insimular",
    "insimulas": "insimular",
    "insimulasse": "insimular",
    "insimulassem": "insimular",
    "insimulasses": "insimular",
    "insimulaste": "insimular",
    "insimulastes": "insimular",
    "insimulava": "insimular",
    "insimulavam": "insimular",
    "insimulavas": "insimular",
    "insimulações": "insimulação",
    "insimule": "insimular",
    "insimulei": "insimular",
    "insimuleis": "insimular",
    "insimulem": "insimular",
    "insimulemo": "insimular",
    "insimulemos": "insimular",
    "insimules": "insimular",
    "insimulo": "insimular",
    "insimulou": "insimular",
    "insimulá": "insimular",
    "insimulámo": "insimular",
    "insimulámos": "insimular",
    "insimuláramo": "insimular",
    "insimuláramos": "insimular",
    "insimulárei": "insimular",
    "insimuláreis": "insimular",
    "insimulásseis": "insimular",
    "insimulássemos": "insimular",
    "insimulávamo": "insimular",
    "insimulávamos": "insimular",
    "insimulávei": "insimular",
    "insimuláveis": "insimular",
    "insincera": "insincero",
    "insinceras": "insincero",
    "insinceridades": "insinceridade",
    "insinceros": "insincero",
    "insinua": "insinuar",
    "insinuada": "insinuar",
    "insinuadas": "insinuar",
    "insinuado": "insinuar",
    "insinuadora": "insinuador",
    "insinuadoras": "insinuador",
    "insinuadores": "insinuador",
    "insinuados": "insinuar",
    "insinuai": "insinuar",
    "insinuais": "insinuar",
    "insinuam": "insinuar",
    "insinuamo": "insinuar",
    "insinuamos": "insinuar",
    "insinuando": "insinuar",
    "insinuantes": "insinuante",
    "insinuara": "insinuar",
    "insinuaram": "insinuar",
    "insinuaras": "insinuar",
    "insinuarde": "insinuar",
    "insinuardes": "insinuar",
    "insinuare": "insinuar",
    "insinuarei": "insinuar",
    "insinuareis": "insinuar",
    "insinuarem": "insinuar",
    "insinuaremos": "insinuar",
    "insinuares": "insinuar",
    "insinuaria": "insinuar",
    "insinuariam": "insinuar",
    "insinuarias": "insinuar",
    "insinuarmo": "insinuar",
    "insinuarmos": "insinuar",
    "insinuará": "insinuar",
    "insinuarás": "insinuar",
    "insinuarão": "insinuar",
    "insinuaríamos": "insinuar",
    "insinuaríeis": "insinuar",
    "insinuas": "insinuar",
    "insinuasse": "insinuar",
    "insinuassem": "insinuar",
    "insinuasses": "insinuar",
    "insinuaste": "insinuar",
    "insinuastes": "insinuar",
    "insinuativa": "insinuativo",
    "insinuativas": "insinuativo",
    "insinuativos": "insinuativo",
    "insinuava": "insinuar",
    "insinuavam": "insinuar",
    "insinuavas": "insinuar",
    "insinuações": "insinuação",
    "insinue": "insinuar",
    "insinuei": "insinuar",
    "insinueis": "insinuar",
    "insinuem": "insinuar",
    "insinuemo": "insinuar",
    "insinuemos": "insinuar",
    "insinues": "insinuar",
    "insinuo": "insinuar",
    "insinuou": "insinuar",
    "insinuá": "insinuar",
    "insinuámo": "insinuar",
    "insinuámos": "insinuar",
    "insinuáramo": "insinuar",
    "insinuáramos": "insinuar",
    "insinuárei": "insinuar",
    "insinuáreis": "insinuar",
    "insinuásseis": "insinuar",
    "insinuássemos": "insinuar",
    "insinuávamo": "insinuar",
    "insinuávamos": "insinuar",
    "insinuávei": "insinuar",
    "insinuáveis": "insinuar",
    "insipida": "insipidar",
    "insipidada": "insipidar",
    "insipidadas": "insipidar",
    "insipidado": "insipidar",
    "insipidados": "insipidar",
    "insipidai": "insipidar",
    "insipidais": "insipidar",
    "insipidam": "insipidar",
    "insipidamo": "insipidar",
    "insipidamos": "insipidar",
    "insipidando": "insipidar",
    "insipidara": "insipidar",
    "insipidaram": "insipidar",
    "insipidaras": "insipidar",
    "insipidarde": "insipidar",
    "insipidardes": "insipidar",
    "insipidare": "insipidar",
    "insipidarei": "insipidar",
    "insipidareis": "insipidar",
    "insipidarem": "insipidar",
    "insipidaremos": "insipidar",
    "insipidares": "insipidar",
    "insipidaria": "insipidar",
    "insipidariam": "insipidar",
    "insipidarias": "insipidar",
    "insipidarmo": "insipidar",
    "insipidarmos": "insipidar",
    "insipidará": "insipidar",
    "insipidarás": "insipidar",
    "insipidarão": "insipidar",
    "insipidaríamos": "insipidar",
    "insipidaríeis": "insipidar",
    "insipidas": "insipidar",
    "insipidasse": "insipidar",
    "insipidassem": "insipidar",
    "insipidasses": "insipidar",
    "insipidaste": "insipidar",
    "insipidastes": "insipidar",
    "insipidava": "insipidar",
    "insipidavam": "insipidar",
    "insipidavas": "insipidar",
    "insipide": "insipidar",
    "insipidei": "insipidar",
    "insipideis": "insipidar",
    "insipidem": "insipidar",
    "insipidemo": "insipidar",
    "insipidemos": "insipidar",
    "insipides": "insipidar",
    "insipidezes": "insipidez",
    "insipido": "insipidar",
    "insipidou": "insipidar",
    "insipidá": "insipidar",
    "insipidámo": "insipidar",
    "insipidámos": "insipidar",
    "insipidáramo": "insipidar",
    "insipidáramos": "insipidar",
    "insipidárei": "insipidar",
    "insipidáreis": "insipidar",
    "insipidásseis": "insipidar",
    "insipidássemos": "insipidar",
    "insipidávamo": "insipidar",
    "insipidávamos": "insipidar",
    "insipidávei": "insipidar",
    "insipidáveis": "insipidar",
    "insipientes": "insipiente",
    "insipiências": "insipiência",
    "insira": "inserir",
    "insirais": "inserir",
    "insiram": "inserir",
    "insiramo": "inserir",
    "insiramos": "inserir",
    "insiras": "inserir",
    "insiro": "inserir",
    "insista": "insistir",
    "insistais": "insistir",
    "insistam": "insistir",
    "insistamo": "insistir",
    "insistamos": "insistir",
    "insistas": "insistir",
    "insiste": "insistir",
    "insistem": "insistir",
    "insistentes": "insistente",
    "insistes": "insistir",
    "insisti": "insistir",
    "insistia": "insistir",
    "insistiam": "insistir",
    "insistias": "insistir",
    "insistida": "insistir",
    "insistidas": "insistir",
    "insistido": "insistir",
    "insistidos": "insistir",
    "insistimo": "insistir",
    "insistimos": "insistir",
    "insistindo": "insistir",
    "insistira": "insistir",
    "insistiram": "insistir",
    "insistiras": "insistir",
    "insistirdes": "insistir",
    "insistirei": "insistir",
    "insistireis": "insistir",
    "insistirem": "insistir",
    "insistiremos": "insistir",
    "insistires": "insistir",
    "insistiria": "insistir",
    "insistiriam": "insistir",
    "insistirias": "insistir",
    "insistirmo": "insistir",
    "insistirmos": "insistir",
    "insistirá": "insistir",
    "insistirás": "insistir",
    "insistirão": "insistir",
    "insistiríamos": "insistir",
    "insistiríeis": "insistir",
    "insistis": "insistir",
    "insistisse": "insistir",
    "insistissem": "insistir",
    "insistisses": "insistir",
    "insististe": "insistir",
    "insististes": "insistir",
    "insistiu": "insistir",
    "insisto": "insistir",
    "insistências": "insistência",
    "insistíamo": "insistir",
    "insistíamos": "insistir",
    "insistíeis": "insistir",
    "insistíramo": "insistir",
    "insistíramos": "insistir",
    "insistíreis": "insistir",
    "insistísseis": "insistir",
    "insistíssemos": "insistir",
    "insobriedades": "insobriedade",
    "insociabilidades": "insociabilidade",
    "insociais": "insocial",
    "insociáveis": "insociável",
    "insofismáveis": "insofismável",
    "insofrida": "insofrido",
    "insofridas": "insofrido",
    "insofridos": "insofrido",
    "insofrimentos": "insofrimento",
    "insofríveis": "insofrível",
    "insola": "insolar",
    "insolada": "insolar",
    "insoladas": "insolar",
    "insolado": "insolar",
    "insolados": "insolar",
    "insolai": "insolar",
    "insolais": "insolar",
    "insolam": "insolar",
    "insolamo": "insolar",
    "insolamos": "insolar",
    "insolando": "insolar",
    "insolara": "insolar",
    "insolaram": "insolar",
    "insolaras": "insolar",
    "insolarde": "insolar",
    "insolardes": "insolar",
    "insolare": "insolar",
    "insolarei": "insolar",
    "insolareis": "insolar",
    "insolarem": "insolar",
    "insolaremos": "insolar",
    "insolares": "insolar",
    "insolaria": "insolar",
    "insolariam": "insolar",
    "insolarias": "insolar",
    "insolarmo": "insolar",
    "insolarmos": "insolar",
    "insolará": "insolar",
    "insolarás": "insolar",
    "insolarão": "insolar",
    "insolaríamos": "insolar",
    "insolaríeis": "insolar",
    "insolas": "insolar",
    "insolasse": "insolar",
    "insolassem": "insolar",
    "insolasses": "insolar",
    "insolaste": "insolar",
    "insolastes": "insolar",
    "insolava": "insolar",
    "insolavam": "insolar",
    "insolavas": "insolar",
    "insolações": "insolação",
    "insoldáveis": "insoldável",
    "insole": "insolar",
    "insolei": "insolar",
    "insoleis": "insolar",
    "insolem": "insolar",
    "insolemo": "insolar",
    "insolemos": "insolar",
    "insolentes": "insolente",
    "insoles": "insolar",
    "insolidariedades": "insolidariedade",
    "insolo": "insolar",
    "insolou": "insolar",
    "insolubilidades": "insolubilidade",
    "insolucionáveis": "insolucionável",
    "insoluveis": "insoluvel",
    "insolvabilidades": "insolvabilidade",
    "insolventes": "insolvente",
    "insolvibilidades": "insolvibilidade",
    "insolvências": "insolvência",
    "insolvíveis": "insolvível",
    "insolá": "insolar",
    "insolámo": "insolar",
    "insolámos": "insolar",
    "insoláramo": "insolar",
    "insoláramos": "insolar",
    "insolárei": "insolar",
    "insoláreis": "insolar",
    "insolásseis": "insolar",
    "insolássemos": "insolar",
    "insolávamo": "insolar",
    "insolávamos": "insolar",
    "insolávei": "insolar",
    "insoláveis": "insolar",
    "insolências": "insolência",
    "insolúveis": "insolúvel",
    "insondabilidades": "insondabilidade",
    "insondada": "insondado",
    "insondadas": "insondado",
    "insondados": "insondado",
    "insondáveis": "insondável",
    "insones": "insone",
    "insonhada": "insonhado",
    "insonhadas": "insonhado",
    "insonhados": "insonhado",
    "insonháveis": "insonhável",
    "insonolências": "insonolência",
    "insonora": "insonoro",
    "insonoras": "insonoro",
    "insonoridades": "insonoridade",
    "insonoriza": "insonorizar",
    "insonorizada": "insonorizar",
    "insonorizadas": "insonorizar",
    "insonorizado": "insonorizar",
    "insonorizados": "insonorizar",
    "insonorizai": "insonorizar",
    "insonorizais": "insonorizar",
    "insonorizam": "insonorizar",
    "insonorizamo": "insonorizar",
    "insonorizamos": "insonorizar",
    "insonorizando": "insonorizar",
    "insonorizara": "insonorizar",
    "insonorizaram": "insonorizar",
    "insonorizaras": "insonorizar",
    "insonorizarde": "insonorizar",
    "insonorizardes": "insonorizar",
    "insonorizare": "insonorizar",
    "insonorizarei": "insonorizar",
    "insonorizareis": "insonorizar",
    "insonorizarem": "insonorizar",
    "insonorizaremos": "insonorizar",
    "insonorizares": "insonorizar",
    "insonorizaria": "insonorizar",
    "insonorizariam": "insonorizar",
    "insonorizarias": "insonorizar",
    "insonorizarmo": "insonorizar",
    "insonorizarmos": "insonorizar",
    "insonorizará": "insonorizar",
    "insonorizarás": "insonorizar",
    "insonorizarão": "insonorizar",
    "insonorizaríamos": "insonorizar",
    "insonorizaríeis": "insonorizar",
    "insonorizas": "insonorizar",
    "insonorizasse": "insonorizar",
    "insonorizassem": "insonorizar",
    "insonorizasses": "insonorizar",
    "insonorizaste": "insonorizar",
    "insonorizastes": "insonorizar",
    "insonorizava": "insonorizar",
    "insonorizavam": "insonorizar",
    "insonorizavas": "insonorizar",
    "insonorizações": "insonorização",
    "insonorize": "insonorizar",
    "insonorizei": "insonorizar",
    "insonorizeis": "insonorizar",
    "insonorizem": "insonorizar",
    "insonorizemo": "insonorizar",
    "insonorizemos": "insonorizar",
    "insonorizes": "insonorizar",
    "insonorizo": "insonorizar",
    "insonorizou": "insonorizar",
    "insonorizá": "insonorizar",
    "insonorizámo": "insonorizar",
    "insonorizámos": "insonorizar",
    "insonorizáramo": "insonorizar",
    "insonorizáramos": "insonorizar",
    "insonorizárei": "insonorizar",
    "insonorizáreis": "insonorizar",
    "insonorizásseis": "insonorizar",
    "insonorizássemos": "insonorizar",
    "insonorizávamo": "insonorizar",
    "insonorizávamos": "insonorizar",
    "insonorizávei": "insonorizar",
    "insonorizáveis": "insonorizável",
    "insonoros": "insonoro",
    "insonsa": "insonso",
    "insonsas": "insonso",
    "insonsos": "insonso",
    "insontes": "insonte",
    "insopitáveis": "insopitável",
    "insossa": "insosso",
    "insossada": "insossar",
    "insossadas": "insossar",
    "insossado": "insossar",
    "insossados": "insossar",
    "insossai": "insossar",
    "insossais": "insossar",
    "insossam": "insossar",
    "insossamo": "insossar",
    "insossamos": "insossar",
    "insossando": "insossar",
    "insossara": "insossar",
    "insossaram": "insossar",
    "insossaras": "insossar",
    "insossarde": "insossar",
    "insossardes": "insossar",
    "insossare": "insossar",
    "insossarei": "insossar",
    "insossareis": "insossar",
    "insossarem": "insossar",
    "insossaremos": "insossar",
    "insossares": "insossar",
    "insossaria": "insossar",
    "insossariam": "insossar",
    "insossarias": "insossar",
    "insossarmo": "insossar",
    "insossarmos": "insossar",
    "insossará": "insossar",
    "insossarás": "insossar",
    "insossarão": "insossar",
    "insossaríamos": "insossar",
    "insossaríeis": "insossar",
    "insossas": "insosso",
    "insossasse": "insossar",
    "insossassem": "insossar",
    "insossasses": "insossar",
    "insossaste": "insossar",
    "insossastes": "insossar",
    "insossava": "insossar",
    "insossavam": "insossar",
    "insossavas": "insossar",
    "insosse": "insossar",
    "insossegos": "insossego",
    "insossei": "insossar",
    "insosseis": "insossar",
    "insossem": "insossar",
    "insossemo": "insossar",
    "insossemos": "insossar",
    "insosses": "insossar",
    "insosso": "insossar",
    "insossos": "insosso",
    "insossou": "insossar",
    "insossá": "insossar",
    "insossámo": "insossar",
    "insossámos": "insossar",
    "insossáramo": "insossar",
    "insossáramos": "insossar",
    "insossárei": "insossar",
    "insossáreis": "insossar",
    "insossásseis": "insossar",
    "insossássemos": "insossar",
    "insossávamo": "insossar",
    "insossávamos": "insossar",
    "insossávei": "insossar",
    "insossáveis": "insossar",
    "inspecciona": "inspeccionar",
    "inspeccionada": "inspeccionar",
    "inspeccionadas": "inspeccionar",
    "inspeccionado": "inspeccionar",
    "inspeccionadora": "inspeccionador",
    "inspeccionadoras": "inspeccionador",
    "inspeccionadores": "inspeccionador",
    "inspeccionados": "inspeccionar",
    "inspeccionai": "inspeccionar",
    "inspeccionais": "inspeccionar",
    "inspeccionam": "inspeccionar",
    "inspeccionamentos": "inspeccionamento",
    "inspeccionamo": "inspeccionar",
    "inspeccionamos": "inspeccionar",
    "inspeccionando": "inspeccionar",
    "inspeccionara": "inspeccionar",
    "inspeccionaram": "inspeccionar",
    "inspeccionaras": "inspeccionar",
    "inspeccionarde": "inspeccionar",
    "inspeccionardes": "inspeccionar",
    "inspeccionare": "inspeccionar",
    "inspeccionarei": "inspeccionar",
    "inspeccionareis": "inspeccionar",
    "inspeccionarem": "inspeccionar",
    "inspeccionaremos": "inspeccionar",
    "inspeccionares": "inspeccionar",
    "inspeccionaria": "inspeccionar",
    "inspeccionariam": "inspeccionar",
    "inspeccionarias": "inspeccionar",
    "inspeccionarmo": "inspeccionar",
    "inspeccionarmos": "inspeccionar",
    "inspeccionará": "inspeccionar",
    "inspeccionarás": "inspeccionar",
    "inspeccionarão": "inspeccionar",
    "inspeccionaríamos": "inspeccionar",
    "inspeccionaríeis": "inspeccionar",
    "inspeccionas": "inspeccionar",
    "inspeccionasse": "inspeccionar",
    "inspeccionassem": "inspeccionar",
    "inspeccionasses": "inspeccionar",
    "inspeccionaste": "inspeccionar",
    "inspeccionastes": "inspeccionar",
    "inspeccionava": "inspeccionar",
    "inspeccionavam": "inspeccionar",
    "inspeccionavas": "inspeccionar",
    "inspeccione": "inspeccionar",
    "inspeccionei": "inspeccionar",
    "inspeccioneis": "inspeccionar",
    "inspeccionem": "inspeccionar",
    "inspeccionemo": "inspeccionar",
    "inspeccionemos": "inspeccionar",
    "inspecciones": "inspeccionar",
    "inspecciono": "inspeccionar",
    "inspeccionou": "inspeccionar",
    "inspeccioná": "inspeccionar",
    "inspeccionámo": "inspeccionar",
    "inspeccionámos": "inspeccionar",
    "inspeccionáramo": "inspeccionar",
    "inspeccionáramos": "inspeccionar",
    "inspeccionárei": "inspeccionar",
    "inspeccionáreis": "inspeccionar",
    "inspeccionásseis": "inspeccionar",
    "inspeccionássemos": "inspeccionar",
    "inspeccionávamo": "inspeccionar",
    "inspeccionávamos": "inspeccionar",
    "inspeccionávei": "inspeccionar",
    "inspeccionáveis": "inspeccionável",
    "inspectora": "inspector",
    "inspectorada": "inspectorado",
    "inspectoradas": "inspectorado",
    "inspectorados": "inspectorado",
    "inspectoras": "inspector",
    "inspectores": "inspector",
    "inspectorias": "inspectoria",
    "inspecções": "inspecção",
    "inspira": "inspirar",
    "inspirada": "inspirar",
    "inspiradas": "inspirar",
    "inspirado": "inspirar",
    "inspiradora": "inspirador",
    "inspiradoras": "inspirador",
    "inspiradores": "inspirador",
    "inspirados": "inspirar",
    "inspiradíssima": "inspirado",
    "inspiradíssimas": "inspirado",
    "inspiradíssimo": "inspirado",
    "inspiradíssimos": "inspirado",
    "inspirai": "inspirar",
    "inspirais": "inspirar",
    "inspiram": "inspirar",
    "inspiramo": "inspirar",
    "inspiramos": "inspirar",
    "inspirando": "inspirar",
    "inspirara": "inspirar",
    "inspiraram": "inspirar",
    "inspiraras": "inspirar",
    "inspirarde": "inspirar",
    "inspirardes": "inspirar",
    "inspirare": "inspirar",
    "inspirarei": "inspirar",
    "inspirareis": "inspirar",
    "inspirarem": "inspirar",
    "inspiraremos": "inspirar",
    "inspirares": "inspirar",
    "inspiraria": "inspirar",
    "inspirariam": "inspirar",
    "inspirarias": "inspirar",
    "inspirarmo": "inspirar",
    "inspirarmos": "inspirar",
    "inspirará": "inspirar",
    "inspirarás": "inspirar",
    "inspirarão": "inspirar",
    "inspiraríamos": "inspirar",
    "inspiraríeis": "inspirar",
    "inspiras": "inspirar",
    "inspirasse": "inspirar",
    "inspirassem": "inspirar",
    "inspirasses": "inspirar",
    "inspiraste": "inspirar",
    "inspirastes": "inspirar",
    "inspirativa": "inspirativo",
    "inspirativas": "inspirativo",
    "inspirativos": "inspirativo",
    "inspiratória": "inspiratório",
    "inspiratórias": "inspiratório",
    "inspiratórios": "inspiratório",
    "inspirava": "inspirar",
    "inspiravam": "inspirar",
    "inspiravas": "inspirar",
    "inspirações": "inspiração",
    "inspire": "inspirar",
    "inspirei": "inspirar",
    "inspireis": "inspirar",
    "inspirem": "inspirar",
    "inspiremo": "inspirar",
    "inspiremos": "inspirar",
    "inspires": "inspirar",
    "inspiro": "inspirar",
    "inspirou": "inspirar",
    "inspirá": "inspirar",
    "inspirámo": "inspirar",
    "inspirámos": "inspirar",
    "inspiráramo": "inspirar",
    "inspiráramos": "inspirar",
    "inspirárei": "inspirar",
    "inspiráreis": "inspirar",
    "inspirásseis": "inspirar",
    "inspirássemos": "inspirar",
    "inspirávamo": "inspirar",
    "inspirávamos": "inspirar",
    "inspirávei": "inspirar",
    "inspiráveis": "inspirável",
    "inspissa": "inspissar",
    "inspissada": "inspissar",
    "inspissadas": "inspissar",
    "inspissado": "inspissar",
    "inspissados": "inspissar",
    "inspissai": "inspissar",
    "inspissais": "inspissar",
    "inspissam": "inspissar",
    "inspissamentos": "inspissamento",
    "inspissamo": "inspissar",
    "inspissamos": "inspissar",
    "inspissando": "inspissar",
    "inspissara": "inspissar",
    "inspissaram": "inspissar",
    "inspissaras": "inspissar",
    "inspissarde": "inspissar",
    "inspissardes": "inspissar",
    "inspissare": "inspissar",
    "inspissarei": "inspissar",
    "inspissareis": "inspissar",
    "inspissarem": "inspissar",
    "inspissaremos": "inspissar",
    "inspissares": "inspissar",
    "inspissaria": "inspissar",
    "inspissariam": "inspissar",
    "inspissarias": "inspissar",
    "inspissarmo": "inspissar",
    "inspissarmos": "inspissar",
    "inspissará": "inspissar",
    "inspissarás": "inspissar",
    "inspissarão": "inspissar",
    "inspissaríamos": "inspissar",
    "inspissaríeis": "inspissar",
    "inspissas": "inspissar",
    "inspissasse": "inspissar",
    "inspissassem": "inspissar",
    "inspissasses": "inspissar",
    "inspissaste": "inspissar",
    "inspissastes": "inspissar",
    "inspissava": "inspissar",
    "inspissavam": "inspissar",
    "inspissavas": "inspissar",
    "inspissações": "inspissação",
    "inspisse": "inspissar",
    "inspissei": "inspissar",
    "inspisseis": "inspissar",
    "inspissem": "inspissar",
    "inspissemo": "inspissar",
    "inspissemos": "inspissar",
    "inspisses": "inspissar",
    "inspisso": "inspissar",
    "inspissou": "inspissar",
    "inspissá": "inspissar",
    "inspissámo": "inspissar",
    "inspissámos": "inspissar",
    "inspissáramo": "inspissar",
    "inspissáramos": "inspissar",
    "inspissárei": "inspissar",
    "inspissáreis": "inspissar",
    "inspissásseis": "inspissar",
    "inspissássemos": "inspissar",
    "inspissávamo": "inspissar",
    "inspissávamos": "inspissar",
    "inspissávei": "inspissar",
    "inspissáveis": "inspissar",
    "insta": "instar",
    "instabilidades": "instabilidade",
    "instada": "instar",
    "instadas": "instar",
    "instado": "instar",
    "instados": "instar",
    "instai": "instar",
    "instais": "instar",
    "instala": "instalar",
    "instalada": "instalar",
    "instaladas": "instalar",
    "instalado": "instalar",
    "instaladora": "instalador",
    "instaladoras": "instalador",
    "instaladores": "instalador",
    "instalados": "instalar",
    "instalai": "instalar",
    "instalais": "instalar",
    "instalam": "instalar",
    "instalamo": "instalar",
    "instalamos": "instalar",
    "instalando": "instalar",
    "instalara": "instalar",
    "instalaram": "instalar",
    "instalaras": "instalar",
    "instalarde": "instalar",
    "instalardes": "instalar",
    "instalare": "instalar",
    "instalarei": "instalar",
    "instalareis": "instalar",
    "instalarem": "instalar",
    "instalaremos": "instalar",
    "instalares": "instalar",
    "instalaria": "instalar",
    "instalariam": "instalar",
    "instalarias": "instalar",
    "instalarmo": "instalar",
    "instalarmos": "instalar",
    "instalará": "instalar",
    "instalarás": "instalar",
    "instalarão": "instalar",
    "instalaríamos": "instalar",
    "instalaríeis": "instalar",
    "instalas": "instalar",
    "instalasse": "instalar",
    "instalassem": "instalar",
    "instalasses": "instalar",
    "instalaste": "instalar",
    "instalastes": "instalar",
    "instalava": "instalar",
    "instalavam": "instalar",
    "instalavas": "instalar",
    "instalações": "instalação",
    "instale": "instalar",
    "instalei": "instalar",
    "instaleis": "instalar",
    "instalem": "instalar",
    "instalemo": "instalar",
    "instalemos": "instalar",
    "instales": "instalar",
    "instalo": "instalar",
    "instalou": "instalar",
    "instalá": "instalar",
    "instalámo": "instalar",
    "instalámos": "instalar",
    "instaláramo": "instalar",
    "instaláramos": "instalar",
    "instalárei": "instalar",
    "instaláreis": "instalar",
    "instalásseis": "instalar",
    "instalássemos": "instalar",
    "instalávamo": "instalar",
    "instalávamos": "instalar",
    "instalávei": "instalar",
    "instaláveis": "instalável",
    "instam": "instar",
    "instamo": "instar",
    "instamos": "instar",
    "instando": "instar",
    "instantaneidades": "instantaneidade",
    "instantes": "instante",
    "instantinho": "instante",
    "instantinhos": "instante",
    "instantito": "instante",
    "instantitos": "instante",
    "instantânea": "instantâneo",
    "instantâneas": "instantâneo",
    "instantâneos": "instantâneo",
    "instara": "instar",
    "instaram": "instar",
    "instaras": "instar",
    "instardes": "instar",
    "instarei": "instar",
    "instareis": "instar",
    "instarem": "instar",
    "instaremos": "instar",
    "instares": "instar",
    "instaria": "instar",
    "instariam": "instar",
    "instarias": "instar",
    "instarmo": "instar",
    "instarmos": "instar",
    "instará": "instar",
    "instarás": "instar",
    "instarão": "instar",
    "instaríamos": "instar",
    "instaríeis": "instar",
    "instas": "instar",
    "instasse": "instar",
    "instassem": "instar",
    "instasses": "instar",
    "instaste": "instar",
    "instastes": "instar",
    "instaura": "instaurar",
    "instaurada": "instaurar",
    "instauradas": "instaurar",
    "instaurado": "instaurar",
    "instauradora": "instaurador",
    "instauradoras": "instaurador",
    "instauradores": "instaurador",
    "instaurados": "instaurar",
    "instaurai": "instaurar",
    "instaurais": "instaurar",
    "instauram": "instaurar",
    "instauramo": "instaurar",
    "instauramos": "instaurar",
    "instaurando": "instaurar",
    "instaurara": "instaurar",
    "instauraram": "instaurar",
    "instauraras": "instaurar",
    "instaurarde": "instaurar",
    "instaurardes": "instaurar",
    "instaurare": "instaurar",
    "instaurarei": "instaurar",
    "instaurareis": "instaurar",
    "instaurarem": "instaurar",
    "instauraremos": "instaurar",
    "instaurares": "instaurar",
    "instauraria": "instaurar",
    "instaurariam": "instaurar",
    "instaurarias": "instaurar",
    "instaurarmo": "instaurar",
    "instaurarmos": "instaurar",
    "instaurará": "instaurar",
    "instaurarás": "instaurar",
    "instaurarão": "instaurar",
    "instauraríamos": "instaurar",
    "instauraríeis": "instaurar",
    "instauras": "instaurar",
    "instaurasse": "instaurar",
    "instaurassem": "instaurar",
    "instaurasses": "instaurar",
    "instauraste": "instaurar",
    "instaurastes": "instaurar",
    "instaurava": "instaurar",
    "instauravam": "instaurar",
    "instauravas": "instaurar",
    "instaurações": "instauração",
    "instaure": "instaurar",
    "instaurei": "instaurar",
    "instaureis": "instaurar",
    "instaurem": "instaurar",
    "instauremo": "instaurar",
    "instauremos": "instaurar",
    "instaures": "instaurar",
    "instauro": "instaurar",
    "instaurou": "instaurar",
    "instaurá": "instaurar",
    "instaurámo": "instaurar",
    "instaurámos": "instaurar",
    "instauráramo": "instaurar",
    "instauráramos": "instaurar",
    "instaurárei": "instaurar",
    "instauráreis": "instaurar",
    "instaurásseis": "instaurar",
    "instaurássemos": "instaurar",
    "instaurávamo": "instaurar",
    "instaurávamos": "instaurar",
    "instaurávei": "instaurar",
    "instauráveis": "instaurável",
    "instava": "instar",
    "instavam": "instar",
    "instavas": "instar",
    "inste": "instar",
    "instei": "instar",
    "insteis": "instar",
    "instem": "instar",
    "instemo": "instar",
    "instemos": "instar",
    "instes": "instar",
    "instiga": "instigar",
    "instigada": "instigar",
    "instigadas": "instigar",
    "instigado": "instigar",
    "instigadora": "instigador",
    "instigadoras": "instigador",
    "instigadores": "instigador",
    "instigados": "instigar",
    "instigai": "instigar",
    "instigais": "instigar",
    "instigam": "instigar",
    "instigamo": "instigar",
    "instigamos": "instigar",
    "instigando": "instigar",
    "instigantes": "instigante",
    "instigara": "instigar",
    "instigaram": "instigar",
    "instigaras": "instigar",
    "instigarde": "instigar",
    "instigardes": "instigar",
    "instigare": "instigar",
    "instigarei": "instigar",
    "instigareis": "instigar",
    "instigarem": "instigar",
    "instigaremos": "instigar",
    "instigares": "instigar",
    "instigaria": "instigar",
    "instigariam": "instigar",
    "instigarias": "instigar",
    "instigarmo": "instigar",
    "instigarmos": "instigar",
    "instigará": "instigar",
    "instigarás": "instigar",
    "instigarão": "instigar",
    "instigaríamos": "instigar",
    "instigaríeis": "instigar",
    "instigas": "instigar",
    "instigasse": "instigar",
    "instigassem": "instigar",
    "instigasses": "instigar",
    "instigaste": "instigar",
    "instigastes": "instigar",
    "instigava": "instigar",
    "instigavam": "instigar",
    "instigavas": "instigar",
    "instigações": "instigação",
    "instigo": "instigar",
    "instigou": "instigar",
    "instigue": "instigar",
    "instiguei": "instigar",
    "instigueis": "instigar",
    "instiguem": "instigar",
    "instiguemo": "instigar",
    "instiguemos": "instigar",
    "instigues": "instigar",
    "instigá": "instigar",
    "instigámo": "instigar",
    "instigámos": "instigar",
    "instigáramo": "instigar",
    "instigáramos": "instigar",
    "instigárei": "instigar",
    "instigáreis": "instigar",
    "instigásseis": "instigar",
    "instigássemos": "instigar",
    "instigávamo": "instigar",
    "instigávamos": "instigar",
    "instigávei": "instigar",
    "instigáveis": "instigável",
    "instila": "instilar",
    "instilada": "instilar",
    "instiladas": "instilar",
    "instilado": "instilar",
    "instiladora": "instilador",
    "instiladoras": "instilador",
    "instiladores": "instilador",
    "instilados": "instilar",
    "instilai": "instilar",
    "instilais": "instilar",
    "instilam": "instilar",
    "instilamo": "instilar",
    "instilamos": "instilar",
    "instilando": "instilar",
    "instilara": "instilar",
    "instilaram": "instilar",
    "instilaras": "instilar",
    "instilarde": "instilar",
    "instilardes": "instilar",
    "instilare": "instilar",
    "instilarei": "instilar",
    "instilareis": "instilar",
    "instilarem": "instilar",
    "instilaremos": "instilar",
    "instilares": "instilar",
    "instilaria": "instilar",
    "instilariam": "instilar",
    "instilarias": "instilar",
    "instilarmo": "instilar",
    "instilarmos": "instilar",
    "instilará": "instilar",
    "instilarás": "instilar",
    "instilarão": "instilar",
    "instilaríamos": "instilar",
    "instilaríeis": "instilar",
    "instilas": "instilar",
    "instilasse": "instilar",
    "instilassem": "instilar",
    "instilasses": "instilar",
    "instilaste": "instilar",
    "instilastes": "instilar",
    "instilava": "instilar",
    "instilavam": "instilar",
    "instilavas": "instilar",
    "instilações": "instilação",
    "instile": "instilar",
    "instilei": "instilar",
    "instileis": "instilar",
    "instilem": "instilar",
    "instilemo": "instilar",
    "instilemos": "instilar",
    "instiles": "instilar",
    "instilo": "instilar",
    "instilou": "instilar",
    "instilá": "instilar",
    "instilámo": "instilar",
    "instilámos": "instilar",
    "instiláramo": "instilar",
    "instiláramos": "instilar",
    "instilárei": "instilar",
    "instiláreis": "instilar",
    "instilásseis": "instilar",
    "instilássemos": "instilar",
    "instilávamo": "instilar",
    "instilávamos": "instilar",
    "instilávei": "instilar",
    "instiláveis": "instilar",
    "instintiva": "instintivo",
    "instintivas": "instintivo",
    "instintividades": "instintividade",
    "instintivos": "instintivo",
    "instintos": "instinto",
    "institua": "instituir",
    "instituais": "instituir",
    "instituam": "instituir",
    "instituamo": "instituir",
    "instituamos": "instituir",
    "instituas": "instituir",
    "institucionais": "institucional",
    "institucionaliza": "institucionalizar",
    "institucionalizada": "institucionalizar",
    "institucionalizadas": "institucionalizar",
    "institucionalizado": "institucionalizar",
    "institucionalizados": "institucionalizar",
    "institucionalizai": "institucionalizar",
    "institucionalizais": "institucionalizar",
    "institucionalizam": "institucionalizar",
    "institucionalizamo": "institucionalizar",
    "institucionalizamos": "institucionalizar",
    "institucionalizando": "institucionalizar",
    "institucionalizara": "institucionalizar",
    "institucionalizaram": "institucionalizar",
    "institucionalizaras": "institucionalizar",
    "institucionalizarde": "institucionalizar",
    "institucionalizardes": "institucionalizar",
    "institucionalizare": "institucionalizar",
    "institucionalizarei": "institucionalizar",
    "institucionalizareis": "institucionalizar",
    "institucionalizarem": "institucionalizar",
    "institucionalizaremos": "institucionalizar",
    "institucionalizares": "institucionalizar",
    "institucionalizaria": "institucionalizar",
    "institucionalizariam": "institucionalizar",
    "institucionalizarias": "institucionalizar",
    "institucionalizarmo": "institucionalizar",
    "institucionalizarmos": "institucionalizar",
    "institucionalizará": "institucionalizar",
    "institucionalizarás": "institucionalizar",
    "institucionalizarão": "institucionalizar",
    "institucionalizaríamos": "institucionalizar",
    "institucionalizaríeis": "institucionalizar",
    "institucionalizas": "institucionalizar",
    "institucionalizasse": "institucionalizar",
    "institucionalizassem": "institucionalizar",
    "institucionalizasses": "institucionalizar",
    "institucionalizaste": "institucionalizar",
    "institucionalizastes": "institucionalizar",
    "institucionalizava": "institucionalizar",
    "institucionalizavam": "institucionalizar",
    "institucionalizavas": "institucionalizar",
    "institucionalizações": "institucionalização",
    "institucionalize": "institucionalizar",
    "institucionalizei": "institucionalizar",
    "institucionalizeis": "institucionalizar",
    "institucionalizem": "institucionalizar",
    "institucionalizemo": "institucionalizar",
    "institucionalizemos": "institucionalizar",
    "institucionalizes": "institucionalizar",
    "institucionalizo": "institucionalizar",
    "institucionalizou": "institucionalizar",
    "institucionalizá": "institucionalizar",
    "institucionalizámo": "institucionalizar",
    "institucionalizámos": "institucionalizar",
    "institucionalizáramo": "institucionalizar",
    "institucionalizáramos": "institucionalizar",
    "institucionalizárei": "institucionalizar",
    "institucionalizáreis": "institucionalizar",
    "institucionalizásseis": "institucionalizar",
    "institucionalizássemos": "institucionalizar",
    "institucionalizávamo": "institucionalizar",
    "institucionalizávamos": "institucionalizar",
    "institucionalizávei": "institucionalizar",
    "institucionalizáveis": "institucionalizável",
    "instituem": "instituir",
    "institui": "instituir",
    "instituidora": "instituidor",
    "instituidoras": "instituidor",
    "instituidores": "instituidor",
    "instituindo": "instituir",
    "instituirde": "instituir",
    "instituirdes": "instituir",
    "instituirei": "instituir",
    "instituireis": "instituir",
    "instituiremos": "instituir",
    "instituiria": "instituir",
    "instituiriam": "instituir",
    "instituirias": "instituir",
    "instituirmo": "instituir",
    "instituirmos": "instituir",
    "instituirá": "instituir",
    "instituirás": "instituir",
    "instituirão": "instituir",
    "instituiríamos": "instituir",
    "instituiríeis": "instituir",
    "instituis": "instituir",
    "instituiu": "instituir",
    "instituições": "instituição",
    "instituo": "instituir",
    "institutos": "instituto",
    "instituí": "instituir",
    "instituía": "instituir",
    "instituíam": "instituir",
    "instituíamo": "instituir",
    "instituíamos": "instituir",
    "instituías": "instituir",
    "instituída": "instituir",
    "instituídas": "instituir",
    "instituído": "instituir",
    "instituídos": "instituir",
    "instituíei": "instituir",
    "instituíeis": "instituir",
    "instituímo": "instituir",
    "instituímos": "instituir",
    "instituíra": "instituir",
    "instituíram": "instituir",
    "instituíramo": "instituir",
    "instituíramos": "instituir",
    "instituíras": "instituir",
    "instituíre": "instituir",
    "instituírei": "instituir",
    "instituíreis": "instituir",
    "instituírem": "instituir",
    "instituíres": "instituir",
    "instituís": "instituir",
    "instituísse": "instituir",
    "instituísseis": "instituir",
    "instituíssem": "instituir",
    "instituíssemos": "instituir",
    "instituísses": "instituir",
    "instituíste": "instituir",
    "instituístes": "instituir",
    "instituíveis": "instituível",
    "insto": "instar",
    "instou": "instar",
    "instri": "instruir",
    "instroem": "instruir",
    "instrua": "instruir",
    "instruais": "instruir",
    "instruam": "instruir",
    "instruamo": "instruir",
    "instruamos": "instruir",
    "instruas": "instruir",
    "instruem": "instruir",
    "instruenda": "instruendo",
    "instruendas": "instruendo",
    "instruendos": "instruendo",
    "instrui": "instruir",
    "instruidora": "instruidor",
    "instruidoras": "instruidor",
    "instruidores": "instruidor",
    "instruindo": "instruir",
    "instruirde": "instruir",
    "instruirdes": "instruir",
    "instruirei": "instruir",
    "instruireis": "instruir",
    "instruiremos": "instruir",
    "instruiria": "instruir",
    "instruiriam": "instruir",
    "instruirias": "instruir",
    "instruirmo": "instruir",
    "instruirmos": "instruir",
    "instruirá": "instruir",
    "instruirás": "instruir",
    "instruirão": "instruir",
    "instruiríamos": "instruir",
    "instruiríeis": "instruir",
    "instruis": "instruir",
    "instruiu": "instruir",
    "instrumenta": "instrumentar",
    "instrumentada": "instrumentar",
    "instrumentadas": "instrumentar",
    "instrumentado": "instrumentar",
    "instrumentadora": "instrumentador",
    "instrumentadoras": "instrumentador",
    "instrumentadores": "instrumentador",
    "instrumentados": "instrumentar",
    "instrumentai": "instrumentar",
    "instrumentais": "instrumentar",
    "instrumentalismos": "instrumentalismo",
    "instrumentalistas": "instrumentalista",
    "instrumentaliza": "instrumentalizar",
    "instrumentalizada": "instrumentalizar",
    "instrumentalizadas": "instrumentalizar",
    "instrumentalizado": "instrumentalizar",
    "instrumentalizados": "instrumentalizar",
    "instrumentalizai": "instrumentalizar",
    "instrumentalizais": "instrumentalizar",
    "instrumentalizam": "instrumentalizar",
    "instrumentalizamo": "instrumentalizar",
    "instrumentalizamos": "instrumentalizar",
    "instrumentalizando": "instrumentalizar",
    "instrumentalizara": "instrumentalizar",
    "instrumentalizaram": "instrumentalizar",
    "instrumentalizaras": "instrumentalizar",
    "instrumentalizarde": "instrumentalizar",
    "instrumentalizardes": "instrumentalizar",
    "instrumentalizare": "instrumentalizar",
    "instrumentalizarei": "instrumentalizar",
    "instrumentalizareis": "instrumentalizar",
    "instrumentalizarem": "instrumentalizar",
    "instrumentalizaremos": "instrumentalizar",
    "instrumentalizares": "instrumentalizar",
    "instrumentalizaria": "instrumentalizar",
    "instrumentalizariam": "instrumentalizar",
    "instrumentalizarias": "instrumentalizar",
    "instrumentalizarmo": "instrumentalizar",
    "instrumentalizarmos": "instrumentalizar",
    "instrumentalizará": "instrumentalizar",
    "instrumentalizarás": "instrumentalizar",
    "instrumentalizarão": "instrumentalizar",
    "instrumentalizaríamos": "instrumentalizar",
    "instrumentalizaríeis": "instrumentalizar",
    "instrumentalizas": "instrumentalizar",
    "instrumentalizasse": "instrumentalizar",
    "instrumentalizassem": "instrumentalizar",
    "instrumentalizasses": "instrumentalizar",
    "instrumentalizaste": "instrumentalizar",
    "instrumentalizastes": "instrumentalizar",
    "instrumentalizava": "instrumentalizar",
    "instrumentalizavam": "instrumentalizar",
    "instrumentalizavas": "instrumentalizar",
    "instrumentalizações": "instrumentalização",
    "instrumentalize": "instrumentalizar",
    "instrumentalizei": "instrumentalizar",
    "instrumentalizeis": "instrumentalizar",
    "instrumentalizem": "instrumentalizar",
    "instrumentalizemo": "instrumentalizar",
    "instrumentalizemos": "instrumentalizar",
    "instrumentalizes": "instrumentalizar",
    "instrumentalizo": "instrumentalizar",
    "instrumentalizou": "instrumentalizar",
    "instrumentalizá": "instrumentalizar",
    "instrumentalizámo": "instrumentalizar",
    "instrumentalizámos": "instrumentalizar",
    "instrumentalizáramo": "instrumentalizar",
    "instrumentalizáramos": "instrumentalizar",
    "instrumentalizárei": "instrumentalizar",
    "instrumentalizáreis": "instrumentalizar",
    "instrumentalizásseis": "instrumentalizar",
    "instrumentalizássemos": "instrumentalizar",
    "instrumentalizávamo": "instrumentalizar",
    "instrumentalizávamos": "instrumentalizar",
    "instrumentalizávei": "instrumentalizar",
    "instrumentalizáveis": "instrumentalizar",
    "instrumentam": "instrumentar",
    "instrumentamo": "instrumentar",
    "instrumentamos": "instrumentar",
    "instrumentando": "instrumentar",
    "instrumentara": "instrumentar",
    "instrumentaram": "instrumentar",
    "instrumentaras": "instrumentar",
    "instrumentarde": "instrumentar",
    "instrumentardes": "instrumentar",
    "instrumentare": "instrumentar",
    "instrumentarei": "instrumentar",
    "instrumentareis": "instrumentar",
    "instrumentarem": "instrumentar",
    "instrumentaremos": "instrumentar",
    "instrumentares": "instrumentar",
    "instrumentaria": "instrumentar",
    "instrumentariam": "instrumentar",
    "instrumentarias": "instrumentar",
    "instrumentarmo": "instrumentar",
    "instrumentarmos": "instrumentar",
    "instrumentará": "instrumentar",
    "instrumentarás": "instrumentar",
    "instrumentarão": "instrumentar",
    "instrumentaríamos": "instrumentar",
    "instrumentaríeis": "instrumentar",
    "instrumentas": "instrumentar",
    "instrumentasse": "instrumentar",
    "instrumentassem": "instrumentar",
    "instrumentasses": "instrumentar",
    "instrumentaste": "instrumentar",
    "instrumentastes": "instrumentar",
    "instrumentava": "instrumentar",
    "instrumentavam": "instrumentar",
    "instrumentavas": "instrumentar",
    "instrumentações": "instrumentação",
    "instrumente": "instrumentar",
    "instrumentei": "instrumentar",
    "instrumenteis": "instrumentar",
    "instrumentem": "instrumentar",
    "instrumentemo": "instrumentar",
    "instrumentemos": "instrumentar",
    "instrumentes": "instrumentar",
    "instrumentistas": "instrumentista",
    "instrumento": "instrumentar",
    "instrumentos": "instrumento",
    "instrumentou": "instrumentar",
    "instrumentá": "instrumentar",
    "instrumentámo": "instrumentar",
    "instrumentámos": "instrumentar",
    "instrumentáramo": "instrumentar",
    "instrumentáramos": "instrumentar",
    "instrumentárei": "instrumentar",
    "instrumentáreis": "instrumentar",
    "instrumentárias": "instrumentária",
    "instrumentásseis": "instrumentar",
    "instrumentássemos": "instrumentar",
    "instrumentávamo": "instrumentar",
    "instrumentávamos": "instrumentar",
    "instrumentávei": "instrumentar",
    "instrumentáveis": "instrumentar",
    "instruo": "instruir",
    "instruta": "instruto",
    "instrutas": "instruto",
    "instrutiva": "instrutivo",
    "instrutivas": "instrutivo",
    "instrutivos": "instrutivo",
    "instrutora": "instrutor",
    "instrutoras": "instrutor",
    "instrutores": "instrutor",
    "instrutos": "instruto",
    "instruturas": "instrutura",
    "instrutória": "instrutório",
    "instrutórias": "instrutório",
    "instrutórios": "instrutório",
    "instruçãozinha": "instrução",
    "instruçãozita": "instrução",
    "instruções": "instrução",
    "instruçõezinhas": "instrução",
    "instruçõezitas": "instrução",
    "instruí": "instruir",
    "instruía": "instruir",
    "instruíam": "instruir",
    "instruíamo": "instruir",
    "instruíamos": "instruir",
    "instruías": "instruir",
    "instruída": "instruir",
    "instruídas": "instruir",
    "instruído": "instruir",
    "instruídos": "instruir",
    "instruíei": "instruir",
    "instruíeis": "instruir",
    "instruímo": "instruir",
    "instruímos": "instruir",
    "instruíra": "instruir",
    "instruíram": "instruir",
    "instruíramo": "instruir",
    "instruíramos": "instruir",
    "instruíras": "instruir",
    "instruíre": "instruir",
    "instruírei": "instruir",
    "instruíreis": "instruir",
    "instruírem": "instruir",
    "instruíres": "instruir",
    "instruís": "instruir",
    "instruísse": "instruir",
    "instruísseis": "instruir",
    "instruíssem": "instruir",
    "instruíssemos": "instruir",
    "instruísses": "instruir",
    "instruíste": "instruir",
    "instruístes": "instruir",
    "instruíveis": "instruível",
    "instrói": "instruir",
    "instróis": "instruir",
    "instámo": "instar",
    "instámos": "instar",
    "instáramo": "instar",
    "instáramos": "instar",
    "instáreis": "instar",
    "instásseis": "instar",
    "instássemos": "instar",
    "instávamo": "instar",
    "instávamos": "instar",
    "instáveis": "instável",
    "instâncias": "instância",
    "insuavidades": "insuavidade",
    "insubmergibilidades": "insubmergibilidade",
    "insubmergíveis": "insubmergível",
    "insubmersibilidades": "insubmersibilidade",
    "insubmersíveis": "insubmersível",
    "insubmissa": "insubmisso",
    "insubmissas": "insubmisso",
    "insubmissos": "insubmisso",
    "insubmissões": "insubmissão",
    "insubordina": "insubordinar",
    "insubordinada": "insubordinar",
    "insubordinadas": "insubordinar",
    "insubordinado": "insubordinar",
    "insubordinadora": "insubordinador",
    "insubordinadoras": "insubordinador",
    "insubordinadores": "insubordinador",
    "insubordinados": "insubordinar",
    "insubordinai": "insubordinar",
    "insubordinais": "insubordinar",
    "insubordinam": "insubordinar",
    "insubordinamo": "insubordinar",
    "insubordinamos": "insubordinar",
    "insubordinando": "insubordinar",
    "insubordinara": "insubordinar",
    "insubordinaram": "insubordinar",
    "insubordinaras": "insubordinar",
    "insubordinarde": "insubordinar",
    "insubordinardes": "insubordinar",
    "insubordinare": "insubordinar",
    "insubordinarei": "insubordinar",
    "insubordinareis": "insubordinar",
    "insubordinarem": "insubordinar",
    "insubordinaremos": "insubordinar",
    "insubordinares": "insubordinar",
    "insubordinaria": "insubordinar",
    "insubordinariam": "insubordinar",
    "insubordinarias": "insubordinar",
    "insubordinarmo": "insubordinar",
    "insubordinarmos": "insubordinar",
    "insubordinará": "insubordinar",
    "insubordinarás": "insubordinar",
    "insubordinarão": "insubordinar",
    "insubordinaríamos": "insubordinar",
    "insubordinaríeis": "insubordinar",
    "insubordinas": "insubordinar",
    "insubordinasse": "insubordinar",
    "insubordinassem": "insubordinar",
    "insubordinasses": "insubordinar",
    "insubordinaste": "insubordinar",
    "insubordinastes": "insubordinar",
    "insubordinava": "insubordinar",
    "insubordinavam": "insubordinar",
    "insubordinavas": "insubordinar",
    "insubordinações": "insubordinação",
    "insubordine": "insubordinar",
    "insubordinei": "insubordinar",
    "insubordineis": "insubordinar",
    "insubordinem": "insubordinar",
    "insubordinemo": "insubordinar",
    "insubordinemos": "insubordinar",
    "insubordines": "insubordinar",
    "insubordino": "insubordinar",
    "insubordinou": "insubordinar",
    "insubordiná": "insubordinar",
    "insubordinámo": "insubordinar",
    "insubordinámos": "insubordinar",
    "insubordináramo": "insubordinar",
    "insubordináramos": "insubordinar",
    "insubordinárei": "insubordinar",
    "insubordináreis": "insubordinar",
    "insubordinásseis": "insubordinar",
    "insubordinássemos": "insubordinar",
    "insubordinávamo": "insubordinar",
    "insubordinávamos": "insubordinar",
    "insubordinávei": "insubordinar",
    "insubordináveis": "insubordinável",
    "insubornáveis": "insubornável",
    "insubsistentes": "insubsistente",
    "insubsistências": "insubsistência",
    "insubstanciais": "insubstancial",
    "insubstancialidades": "insubstancialidade",
    "insubstancias": "insubstancia",
    "insubstituíveis": "insubstituível",
    "insubversiva": "insubversivo",
    "insubversivas": "insubversivo",
    "insubversivos": "insubversivo",
    "insucessos": "insucesso",
    "insucessíveis": "insucessível",
    "insueta": "insueto",
    "insuetas": "insueto",
    "insuetos": "insueto",
    "insuetudes": "insuetude",
    "insuficientes": "insuficiente",
    "insuficiências": "insuficiência",
    "insufla": "insuflar",
    "insuflada": "insuflar",
    "insufladas": "insuflar",
    "insuflado": "insuflar",
    "insufladora": "insuflador",
    "insufladoras": "insuflador",
    "insufladores": "insuflador",
    "insuflados": "insuflar",
    "insuflai": "insuflar",
    "insuflais": "insuflar",
    "insuflam": "insuflar",
    "insuflamo": "insuflar",
    "insuflamos": "insuflar",
    "insuflando": "insuflar",
    "insuflara": "insuflar",
    "insuflaram": "insuflar",
    "insuflaras": "insuflar",
    "insuflarde": "insuflar",
    "insuflardes": "insuflar",
    "insuflare": "insuflar",
    "insuflarei": "insuflar",
    "insuflareis": "insuflar",
    "insuflarem": "insuflar",
    "insuflaremos": "insuflar",
    "insuflares": "insuflar",
    "insuflaria": "insuflar",
    "insuflariam": "insuflar",
    "insuflarias": "insuflar",
    "insuflarmo": "insuflar",
    "insuflarmos": "insuflar",
    "insuflará": "insuflar",
    "insuflarás": "insuflar",
    "insuflarão": "insuflar",
    "insuflaríamos": "insuflar",
    "insuflaríeis": "insuflar",
    "insuflas": "insuflar",
    "insuflasse": "insuflar",
    "insuflassem": "insuflar",
    "insuflasses": "insuflar",
    "insuflaste": "insuflar",
    "insuflastes": "insuflar",
    "insuflava": "insuflar",
    "insuflavam": "insuflar",
    "insuflavas": "insuflar",
    "insuflações": "insuflação",
    "insufle": "insuflar",
    "insuflei": "insuflar",
    "insufleis": "insuflar",
    "insuflem": "insuflar",
    "insuflemo": "insuflar",
    "insuflemos": "insuflar",
    "insufles": "insuflar",
    "insuflo": "insuflar",
    "insuflou": "insuflar",
    "insuflá": "insuflar",
    "insuflámo": "insuflar",
    "insuflámos": "insuflar",
    "insufláramo": "insuflar",
    "insufláramos": "insuflar",
    "insuflárei": "insuflar",
    "insufláreis": "insuflar",
    "insuflásseis": "insuflar",
    "insuflássemos": "insuflar",
    "insuflávamo": "insuflar",
    "insuflávamos": "insuflar",
    "insuflávei": "insuflar",
    "insufláveis": "insuflável",
    "insulada": "insulado",
    "insuladas": "insulado",
    "insuladora": "insulador",
    "insuladoras": "insulador",
    "insuladores": "insulador",
    "insulados": "insulado",
    "insulamentos": "insulamento",
    "insulana": "insulano",
    "insulanas": "insulano",
    "insulanos": "insulano",
    "insulares": "insular",
    "insularidades": "insularidade",
    "insulações": "insulação",
    "insulcada": "insulcado",
    "insulcadas": "insulcado",
    "insulcados": "insulcado",
    "insulinas": "insulina",
    "insulindiana": "insulindiano",
    "insulindianas": "insulindiano",
    "insulindianos": "insulindiano",
    "insulinoterapias": "insulinoterapia",
    "insulsa": "insulso",
    "insulsas": "insulso",
    "insulsidades": "insulsidade",
    "insulsos": "insulso",
    "insulta": "insultar",
    "insultada": "insultar",
    "insultadas": "insultar",
    "insultado": "insultar",
    "insultadora": "insultador",
    "insultadoras": "insultador",
    "insultadores": "insultador",
    "insultados": "insultar",
    "insultadíssima": "insultado",
    "insultadíssimas": "insultado",
    "insultadíssimo": "insultado",
    "insultadíssimos": "insultado",
    "insultai": "insultar",
    "insultais": "insultar",
    "insultam": "insultar",
    "insultamo": "insultar",
    "insultamos": "insultar",
    "insultando": "insultar",
    "insultantes": "insultante",
    "insultara": "insultar",
    "insultaram": "insultar",
    "insultaras": "insultar",
    "insultarde": "insultar",
    "insultardes": "insultar",
    "insultare": "insultar",
    "insultarei": "insultar",
    "insultareis": "insultar",
    "insultarem": "insultar",
    "insultaremos": "insultar",
    "insultares": "insultar",
    "insultaria": "insultar",
    "insultariam": "insultar",
    "insultarias": "insultar",
    "insultarmo": "insultar",
    "insultarmos": "insultar",
    "insultará": "insultar",
    "insultarás": "insultar",
    "insultarão": "insultar",
    "insultaríamos": "insultar",
    "insultaríeis": "insultar",
    "insultas": "insultar",
    "insultasse": "insultar",
    "insultassem": "insultar",
    "insultasses": "insultar",
    "insultaste": "insultar",
    "insultastes": "insultar",
    "insultava": "insultar",
    "insultavam": "insultar",
    "insultavas": "insultar",
    "insulte": "insultar",
    "insultei": "insultar",
    "insulteis": "insultar",
    "insultem": "insultar",
    "insultemo": "insultar",
    "insultemos": "insultar",
    "insultes": "insultar",
    "insulto": "insultar",
    "insultos": "insulto",
    "insultou": "insultar",
    "insultuosa": "insultuoso",
    "insultuosas": "insultuoso",
    "insultuosos": "insultuoso",
    "insultá": "insultar",
    "insultámo": "insultar",
    "insultámos": "insultar",
    "insultáramo": "insultar",
    "insultáramos": "insultar",
    "insultárei": "insultar",
    "insultáreis": "insultar",
    "insultásseis": "insultar",
    "insultássemos": "insultar",
    "insultávamo": "insultar",
    "insultávamos": "insultar",
    "insultávei": "insultar",
    "insultáveis": "insultar",
    "insulvezes": "insulvez",
    "insumos": "insumo",
    "insuperabilidades": "insuperabilidade",
    "insuperada": "insuperado",
    "insuperadas": "insuperado",
    "insuperados": "insuperado",
    "insuperáveis": "insuperável",
    "insuportáveis": "insuportável",
    "insupríveis": "insuprível",
    "insurdescências": "insurdescência",
    "insurge": "insurgir",
    "insurgem": "insurgir",
    "insurgentes": "insurgente",
    "insurges": "insurgir",
    "insurgi": "insurgir",
    "insurgia": "insurgir",
    "insurgiam": "insurgir",
    "insurgias": "insurgir",
    "insurgida": "insurgir",
    "insurgidas": "insurgir",
    "insurgido": "insurgir",
    "insurgidos": "insurgir",
    "insurgimo": "insurgir",
    "insurgimos": "insurgir",
    "insurgindo": "insurgir",
    "insurgira": "insurgir",
    "insurgiram": "insurgir",
    "insurgiras": "insurgir",
    "insurgirde": "insurgir",
    "insurgirdes": "insurgir",
    "insurgire": "insurgir",
    "insurgirei": "insurgir",
    "insurgireis": "insurgir",
    "insurgirem": "insurgir",
    "insurgiremos": "insurgir",
    "insurgires": "insurgir",
    "insurgiria": "insurgir",
    "insurgiriam": "insurgir",
    "insurgirias": "insurgir",
    "insurgirmo": "insurgir",
    "insurgirmos": "insurgir",
    "insurgirá": "insurgir",
    "insurgirás": "insurgir",
    "insurgirão": "insurgir",
    "insurgiríamos": "insurgir",
    "insurgiríeis": "insurgir",
    "insurgis": "insurgir",
    "insurgisse": "insurgir",
    "insurgissem": "insurgir",
    "insurgisses": "insurgir",
    "insurgiste": "insurgir",
    "insurgistes": "insurgir",
    "insurgiu": "insurgir",
    "insurgíamo": "insurgir",
    "insurgíamos": "insurgir",
    "insurgíei": "insurgir",
    "insurgíeis": "insurgir",
    "insurgíramo": "insurgir",
    "insurgíramos": "insurgir",
    "insurgírei": "insurgir",
    "insurgíreis": "insurgir",
    "insurgísseis": "insurgir",
    "insurgíssemos": "insurgir",
    "insurja": "insurgir",
    "insurjais": "insurgir",
    "insurjam": "insurgir",
    "insurjamo": "insurgir",
    "insurjamos": "insurgir",
    "insurjas": "insurgir",
    "insurjo": "insurgir",
    "insurrecciona": "insurreccionar",
    "insurreccionada": "insurreccionar",
    "insurreccionadas": "insurreccionar",
    "insurreccionado": "insurreccionar",
    "insurreccionados": "insurreccionar",
    "insurreccionai": "insurreccionar",
    "insurreccionais": "insurreccionar",
    "insurreccionam": "insurreccionar",
    "insurreccionamo": "insurreccionar",
    "insurreccionamos": "insurreccionar",
    "insurreccionando": "insurreccionar",
    "insurreccionara": "insurreccionar",
    "insurreccionaram": "insurreccionar",
    "insurreccionaras": "insurreccionar",
    "insurreccionarde": "insurreccionar",
    "insurreccionardes": "insurreccionar",
    "insurreccionare": "insurreccionar",
    "insurreccionarei": "insurreccionar",
    "insurreccionareis": "insurreccionar",
    "insurreccionarem": "insurreccionar",
    "insurreccionaremos": "insurreccionar",
    "insurreccionares": "insurreccionar",
    "insurreccionaria": "insurreccionar",
    "insurreccionariam": "insurreccionar",
    "insurreccionarias": "insurreccionar",
    "insurreccionarmo": "insurreccionar",
    "insurreccionarmos": "insurreccionar",
    "insurreccionará": "insurreccionar",
    "insurreccionarás": "insurreccionar",
    "insurreccionarão": "insurreccionar",
    "insurreccionaríamos": "insurreccionar",
    "insurreccionaríeis": "insurreccionar",
    "insurreccionas": "insurreccionar",
    "insurreccionasse": "insurreccionar",
    "insurreccionassem": "insurreccionar",
    "insurreccionasses": "insurreccionar",
    "insurreccionaste": "insurreccionar",
    "insurreccionastes": "insurreccionar",
    "insurreccionava": "insurreccionar",
    "insurreccionavam": "insurreccionar",
    "insurreccionavas": "insurreccionar",
    "insurreccione": "insurreccionar",
    "insurreccionei": "insurreccionar",
    "insurreccioneis": "insurreccionar",
    "insurreccionem": "insurreccionar",
    "insurreccionemo": "insurreccionar",
    "insurreccionemos": "insurreccionar",
    "insurrecciones": "insurreccionar",
    "insurrecciono": "insurreccionar",
    "insurreccionou": "insurreccionar",
    "insurreccioná": "insurreccionar",
    "insurreccionámo": "insurreccionar",
    "insurreccionámos": "insurreccionar",
    "insurreccionáramo": "insurreccionar",
    "insurreccionáramos": "insurreccionar",
    "insurreccionárei": "insurreccionar",
    "insurreccionáreis": "insurreccionar",
    "insurreccionásseis": "insurreccionar",
    "insurreccionássemos": "insurreccionar",
    "insurreccionávamo": "insurreccionar",
    "insurreccionávamos": "insurreccionar",
    "insurreccionávei": "insurreccionar",
    "insurreccionáveis": "insurreccionar",
    "insurrecta": "insurrecto",
    "insurrectas": "insurrecto",
    "insurrectos": "insurrecto",
    "insurreições": "insurreição",
    "insusceptíveis": "insusceptível",
    "insuspeita": "insuspeito",
    "insuspeitas": "insuspeito",
    "insuspeitos": "insuspeito",
    "insuspeitáveis": "insuspeitável",
    "insuspeições": "insuspeição",
    "insustentabilidades": "insustentabilidade",
    "insustentada": "insustentado",
    "insustentadas": "insustentado",
    "insustentados": "insustentado",
    "insustentáveis": "insustentável",
    "insânias": "insânia",
    "inséctis": "inséctil",
    "insídias": "insídia",
    "insígnias": "insígnia",
    "insípida": "insípido",
    "insípidas": "insípido",
    "insípidos": "insípido",
    "insóbria": "insóbrio",
    "insóbrias": "insóbrio",
    "insóbrios": "insóbrio",
    "insólita": "insólito",
    "insólitas": "insólito",
    "insólitos": "insólito",
    "insónias": "insónia",
    "intacta": "intacto",
    "intactas": "intacto",
    "intactilidades": "intactilidade",
    "intactos": "intacto",
    "intangibilidades": "intangibilidade",
    "intangíveis": "intangível",
    "integra": "integrar",
    "integrabilidades": "integrabilidade",
    "integracionismos": "integracionismo",
    "integracionistas": "integracionista",
    "integrada": "integrar",
    "integradas": "integrar",
    "integrado": "integrar",
    "integradora": "integrador",
    "integradoras": "integrador",
    "integradores": "integrador",
    "integrados": "integrar",
    "integradíssima": "integrado",
    "integradíssimas": "integrado",
    "integradíssimo": "integrado",
    "integradíssimos": "integrado",
    "integrafos": "integrafo",
    "integrai": "integrar",
    "integrais": "integrar",
    "integralismos": "integralismo",
    "integralistas": "integralista",
    "integralizações": "integralização",
    "integram": "integrar",
    "integramo": "integrar",
    "integramos": "integrar",
    "integrandas": "integranda",
    "integrando": "integrar",
    "integrandos": "integrando",
    "integrantes": "integrante",
    "integrara": "integrar",
    "integraram": "integrar",
    "integraras": "integrar",
    "integrarde": "integrar",
    "integrardes": "integrar",
    "integrare": "integrar",
    "integrarei": "integrar",
    "integrareis": "integrar",
    "integrarem": "integrar",
    "integraremos": "integrar",
    "integrares": "integrar",
    "integraria": "integrar",
    "integrariam": "integrar",
    "integrarias": "integrar",
    "integrarmo": "integrar",
    "integrarmos": "integrar",
    "integrará": "integrar",
    "integrarás": "integrar",
    "integrarão": "integrar",
    "integraríamos": "integrar",
    "integraríeis": "integrar",
    "integras": "integrar",
    "integrasse": "integrar",
    "integrassem": "integrar",
    "integrasses": "integrar",
    "integraste": "integrar",
    "integrastes": "integrar",
    "integrava": "integrar",
    "integravam": "integrar",
    "integravas": "integrar",
    "integrações": "integração",
    "integre": "integrar",
    "integrei": "integrar",
    "integreis": "integrar",
    "integrem": "integrar",
    "integremo": "integrar",
    "integremos": "integrar",
    "integres": "integrar",
    "integricípitos": "integricípito",
    "integridades": "integridade",
    "integrismos": "integrismo",
    "integro": "integrar",
    "integrou": "integrar",
    "integrá": "integrar",
    "integrámo": "integrar",
    "integrámos": "integrar",
    "integráramo": "integrar",
    "integráramos": "integrar",
    "integrárei": "integrar",
    "integráreis": "integrar",
    "integrásseis": "integrar",
    "integrássemos": "integrar",
    "integrávamo": "integrar",
    "integrávamos": "integrar",
    "integrávei": "integrar",
    "integráveis": "integrável",
    "integérrima": "íntegro",
    "integérrimas": "íntegro",
    "integérrimo": "íntegro",
    "integérrimos": "íntegro",
    "inteira": "inteiro",
    "inteirada": "inteirar",
    "inteiradas": "inteirar",
    "inteirado": "inteirar",
    "inteirados": "inteirar",
    "inteirai": "inteirar",
    "inteirais": "inteirar",
    "inteiram": "inteirar",
    "inteiramo": "inteirar",
    "inteiramos": "inteirar",
    "inteirando": "inteirar",
    "inteirara": "inteirar",
    "inteiraram": "inteirar",
    "inteiraras": "inteirar",
    "inteirarde": "inteirar",
    "inteirardes": "inteirar",
    "inteirare": "inteirar",
    "inteirarei": "inteirar",
    "inteirareis": "inteirar",
    "inteirarem": "inteirar",
    "inteiraremos": "inteirar",
    "inteirares": "inteirar",
    "inteiraria": "inteirar",
    "inteirariam": "inteirar",
    "inteirarias": "inteirar",
    "inteirarmo": "inteirar",
    "inteirarmos": "inteirar",
    "inteirará": "inteirar",
    "inteirarás": "inteirar",
    "inteirarão": "inteirar",
    "inteiraríamos": "inteirar",
    "inteiraríeis": "inteirar",
    "inteiras": "inteiro",
    "inteirasse": "inteirar",
    "inteirassem": "inteirar",
    "inteirasses": "inteirar",
    "inteiraste": "inteirar",
    "inteirastes": "inteirar",
    "inteirava": "inteirar",
    "inteiravam": "inteirar",
    "inteiravas": "inteirar",
    "inteirazinha": "inteiro",
    "inteirazinhas": "inteiro",
    "inteirazita": "inteiro",
    "inteirazitas": "inteiro",
    "inteire": "inteirar",
    "inteirei": "inteirar",
    "inteireis": "inteirar",
    "inteirem": "inteirar",
    "inteiremo": "inteirar",
    "inteiremos": "inteirar",
    "inteires": "inteirar",
    "inteirezas": "inteireza",
    "inteirice": "inteiriçar",
    "inteiricei": "inteiriçar",
    "inteiriceis": "inteiriçar",
    "inteiricem": "inteiriçar",
    "inteiricemo": "inteiriçar",
    "inteiricemos": "inteiriçar",
    "inteirices": "inteiriçar",
    "inteirinha": "inteiro",
    "inteirinhas": "inteiro",
    "inteirinho": "inteiro",
    "inteirinhos": "inteiro",
    "inteirita": "inteiro",
    "inteiritas": "inteiro",
    "inteirito": "inteiro",
    "inteiritos": "inteiro",
    "inteiriça": "inteiriço",
    "inteiriçada": "inteiriçar",
    "inteiriçadas": "inteiriçar",
    "inteiriçado": "inteiriçar",
    "inteiriçados": "inteiriçar",
    "inteiriçai": "inteiriçar",
    "inteiriçais": "inteiriçar",
    "inteiriçam": "inteiriçar",
    "inteiriçamentos": "inteiriçamento",
    "inteiriçamo": "inteiriçar",
    "inteiriçamos": "inteiriçar",
    "inteiriçando": "inteiriçar",
    "inteiriçara": "inteiriçar",
    "inteiriçaram": "inteiriçar",
    "inteiriçaras": "inteiriçar",
    "inteiriçarde": "inteiriçar",
    "inteiriçardes": "inteiriçar",
    "inteiriçare": "inteiriçar",
    "inteiriçarei": "inteiriçar",
    "inteiriçareis": "inteiriçar",
    "inteiriçarem": "inteiriçar",
    "inteiriçaremos": "inteiriçar",
    "inteiriçares": "inteiriçar",
    "inteiriçaria": "inteiriçar",
    "inteiriçariam": "inteiriçar",
    "inteiriçarias": "inteiriçar",
    "inteiriçarmo": "inteiriçar",
    "inteiriçarmos": "inteiriçar",
    "inteiriçará": "inteiriçar",
    "inteiriçarás": "inteiriçar",
    "inteiriçarão": "inteiriçar",
    "inteiriçaríamos": "inteiriçar",
    "inteiriçaríeis": "inteiriçar",
    "inteiriças": "inteiriço",
    "inteiriçasse": "inteiriçar",
    "inteiriçassem": "inteiriçar",
    "inteiriçasses": "inteiriçar",
    "inteiriçaste": "inteiriçar",
    "inteiriçastes": "inteiriçar",
    "inteiriçava": "inteiriçar",
    "inteiriçavam": "inteiriçar",
    "inteiriçavas": "inteiriçar",
    "inteiriço": "inteiriçar",
    "inteiriços": "inteiriço",
    "inteiriçou": "inteiriçar",
    "inteiriçá": "inteiriçar",
    "inteiriçámo": "inteiriçar",
    "inteiriçámos": "inteiriçar",
    "inteiriçáramo": "inteiriçar",
    "inteiriçáramos": "inteiriçar",
    "inteiriçárei": "inteiriçar",
    "inteiriçáreis": "inteiriçar",
    "inteiriçásseis": "inteiriçar",
    "inteiriçássemos": "inteiriçar",
    "inteiriçávamo": "inteiriçar",
    "inteiriçávamos": "inteiriçar",
    "inteiriçávei": "inteiriçar",
    "inteiriçáveis": "inteiriçar",
    "inteiro": "inteirar",
    "inteiros": "inteiro",
    "inteirou": "inteirar",
    "inteirozinho": "inteiro",
    "inteirozinhos": "inteiro",
    "inteirozito": "inteiro",
    "inteirozitos": "inteiro",
    "inteirá": "inteirar",
    "inteirámo": "inteirar",
    "inteirámos": "inteirar",
    "inteiráramo": "inteirar",
    "inteiráramos": "inteirar",
    "inteirárei": "inteirar",
    "inteiráreis": "inteirar",
    "inteirásseis": "inteirar",
    "inteirássemos": "inteirar",
    "inteirávamo": "inteirar",
    "inteirávamos": "inteirar",
    "inteirávei": "inteirar",
    "inteiráveis": "inteirar",
    "inteiríssima": "inteiro",
    "inteiríssimas": "inteiro",
    "inteiríssimo": "inteiro",
    "inteiríssimos": "inteiro",
    "intelectiva": "intelectivo",
    "intelectivas": "intelectivo",
    "intelectivos": "intelectivo",
    "intelectos": "intelecto",
    "intelectuais": "intelectual",
    "intelectualidades": "intelectualidade",
    "intelectualismos": "intelectualismo",
    "intelectualistas": "intelectualista",
    "intelectualiza": "intelectualizar",
    "intelectualizada": "intelectualizar",
    "intelectualizadas": "intelectualizar",
    "intelectualizado": "intelectualizar",
    "intelectualizados": "intelectualizar",
    "intelectualizai": "intelectualizar",
    "intelectualizais": "intelectualizar",
    "intelectualizam": "intelectualizar",
    "intelectualizamo": "intelectualizar",
    "intelectualizamos": "intelectualizar",
    "intelectualizando": "intelectualizar",
    "intelectualizara": "intelectualizar",
    "intelectualizaram": "intelectualizar",
    "intelectualizaras": "intelectualizar",
    "intelectualizarde": "intelectualizar",
    "intelectualizardes": "intelectualizar",
    "intelectualizare": "intelectualizar",
    "intelectualizarei": "intelectualizar",
    "intelectualizareis": "intelectualizar",
    "intelectualizarem": "intelectualizar",
    "intelectualizaremos": "intelectualizar",
    "intelectualizares": "intelectualizar",
    "intelectualizaria": "intelectualizar",
    "intelectualizariam": "intelectualizar",
    "intelectualizarias": "intelectualizar",
    "intelectualizarmo": "intelectualizar",
    "intelectualizarmos": "intelectualizar",
    "intelectualizará": "intelectualizar",
    "intelectualizarás": "intelectualizar",
    "intelectualizarão": "intelectualizar",
    "intelectualizaríamos": "intelectualizar",
    "intelectualizaríeis": "intelectualizar",
    "intelectualizas": "intelectualizar",
    "intelectualizasse": "intelectualizar",
    "intelectualizassem": "intelectualizar",
    "intelectualizasses": "intelectualizar",
    "intelectualizaste": "intelectualizar",
    "intelectualizastes": "intelectualizar",
    "intelectualizava": "intelectualizar",
    "intelectualizavam": "intelectualizar",
    "intelectualizavas": "intelectualizar",
    "intelectualizações": "intelectualização",
    "intelectualize": "intelectualizar",
    "intelectualizei": "intelectualizar",
    "intelectualizeis": "intelectualizar",
    "intelectualizem": "intelectualizar",
    "intelectualizemo": "intelectualizar",
    "intelectualizemos": "intelectualizar",
    "intelectualizes": "intelectualizar",
    "intelectualizo": "intelectualizar",
    "intelectualizou": "intelectualizar",
    "intelectualizá": "intelectualizar",
    "intelectualizámo": "intelectualizar",
    "intelectualizámos": "intelectualizar",
    "intelectualizáramo": "intelectualizar",
    "intelectualizáramos": "intelectualizar",
    "intelectualizárei": "intelectualizar",
    "intelectualizáreis": "intelectualizar",
    "intelectualizásseis": "intelectualizar",
    "intelectualizássemos": "intelectualizar",
    "intelectualizávamo": "intelectualizar",
    "intelectualizávamos": "intelectualizar",
    "intelectualizávei": "intelectualizar",
    "intelectualizáveis": "intelectualizar",
    "intelectualóides": "intelectualóide",
    "intelecções": "intelecção",
    "inteligentes": "inteligente",
    "inteligibilidades": "inteligibilidade",
    "inteligências": "inteligência",
    "inteligíveis": "inteligível",
    "intelligentsias": "intelligentsia",
    "intelligentzias": "intelligentzia",
    "intementes": "intemente",
    "intemerata": "intemerato",
    "intemeratas": "intemerato",
    "intemeratos": "intemerato",
    "intempera": "intemperar",
    "intemperada": "intemperar",
    "intemperadas": "intemperar",
    "intemperado": "intemperar",
    "intemperados": "intemperar",
    "intemperai": "intemperar",
    "intemperais": "intemperar",
    "intemperam": "intemperar",
    "intemperamentos": "intemperamento",
    "intemperamo": "intemperar",
    "intemperamos": "intemperar",
    "intemperando": "intemperar",
    "intemperantes": "intemperante",
    "intemperanças": "intemperança",
    "intemperara": "intemperar",
    "intemperaram": "intemperar",
    "intemperaras": "intemperar",
    "intemperarde": "intemperar",
    "intemperardes": "intemperar",
    "intemperare": "intemperar",
    "intemperarei": "intemperar",
    "intemperareis": "intemperar",
    "intemperarem": "intemperar",
    "intemperaremos": "intemperar",
    "intemperares": "intemperar",
    "intemperaria": "intemperar",
    "intemperariam": "intemperar",
    "intemperarias": "intemperar",
    "intemperarmo": "intemperar",
    "intemperarmos": "intemperar",
    "intemperará": "intemperar",
    "intemperarás": "intemperar",
    "intemperarão": "intemperar",
    "intemperaríamos": "intemperar",
    "intemperaríeis": "intemperar",
    "intemperas": "intemperar",
    "intemperasse": "intemperar",
    "intemperassem": "intemperar",
    "intemperasses": "intemperar",
    "intemperaste": "intemperar",
    "intemperastes": "intemperar",
    "intemperava": "intemperar",
    "intemperavam": "intemperar",
    "intemperavas": "intemperar",
    "intempere": "intemperar",
    "intemperei": "intemperar",
    "intempereis": "intemperar",
    "intemperem": "intemperar",
    "intemperemo": "intemperar",
    "intemperemos": "intemperar",
    "intemperes": "intemperar",
    "intemperismos": "intemperismo",
    "intempero": "intemperar",
    "intemperou": "intemperar",
    "intemperá": "intemperar",
    "intemperámo": "intemperar",
    "intemperámos": "intemperar",
    "intemperáramo": "intemperar",
    "intemperáramos": "intemperar",
    "intemperárei": "intemperar",
    "intemperáreis": "intemperar",
    "intemperásseis": "intemperar",
    "intemperássemos": "intemperar",
    "intemperávamo": "intemperar",
    "intemperávamos": "intemperar",
    "intemperávei": "intemperar",
    "intemperáveis": "intemperar",
    "intempestiva": "intempestivo",
    "intempestivas": "intempestivo",
    "intempestividades": "intempestividade",
    "intempestivos": "intempestivo",
    "intemporais": "intemporal",
    "intemporalidades": "intemporalidade",
    "intempéries": "intempérie",
    "intencionada": "intencionado",
    "intencionadas": "intencionado",
    "intencionados": "intencionado",
    "intencionais": "intencional",
    "intencionalidades": "intencionalidade",
    "intencionalistas": "intencionalista",
    "intencionismos": "intencionismo",
    "intencionáveis": "intencionável",
    "intenda": "intender",
    "intendais": "intender",
    "intendam": "intender",
    "intendamo": "intender",
    "intendamos": "intender",
    "intendas": "intender",
    "intende": "intender",
    "intendei": "intender",
    "intendeis": "intender",
    "intendem": "intender",
    "intendemo": "intender",
    "intendemos": "intender",
    "intendendo": "intender",
    "intendentes": "intendente",
    "intendera": "intender",
    "intenderam": "intender",
    "intenderas": "intender",
    "intenderde": "intender",
    "intenderdes": "intender",
    "intendere": "intender",
    "intenderei": "intender",
    "intendereis": "intender",
    "intenderem": "intender",
    "intenderemos": "intender",
    "intenderes": "intender",
    "intenderia": "intender",
    "intenderiam": "intender",
    "intenderias": "intender",
    "intendermo": "intender",
    "intendermos": "intender",
    "intenderá": "intender",
    "intenderás": "intender",
    "intenderão": "intender",
    "intenderíamos": "intender",
    "intenderíeis": "intender",
    "intendes": "intender",
    "intendesse": "intender",
    "intendessem": "intender",
    "intendesses": "intender",
    "intendeste": "intender",
    "intendestes": "intender",
    "intendeu": "intender",
    "intendi": "intender",
    "intendia": "intender",
    "intendiam": "intender",
    "intendias": "intender",
    "intendida": "intender",
    "intendidas": "intender",
    "intendido": "intender",
    "intendidos": "intender",
    "intendo": "intender",
    "intendê": "intender",
    "intendências": "intendência",
    "intendêramo": "intender",
    "intendêramos": "intender",
    "intendêrei": "intender",
    "intendêreis": "intender",
    "intendêsseis": "intender",
    "intendêssemos": "intender",
    "intendíamo": "intender",
    "intendíamos": "intender",
    "intendíei": "intender",
    "intendíeis": "intender",
    "intensa": "intenso",
    "intensas": "intenso",
    "intensidades": "intensidade",
    "intensifica": "intensificar",
    "intensificada": "intensificar",
    "intensificadas": "intensificar",
    "intensificado": "intensificar",
    "intensificados": "intensificar",
    "intensificai": "intensificar",
    "intensificais": "intensificar",
    "intensificam": "intensificar",
    "intensificamo": "intensificar",
    "intensificamos": "intensificar",
    "intensificando": "intensificar",
    "intensificara": "intensificar",
    "intensificaram": "intensificar",
    "intensificaras": "intensificar",
    "intensificarde": "intensificar",
    "intensificardes": "intensificar",
    "intensificare": "intensificar",
    "intensificarei": "intensificar",
    "intensificareis": "intensificar",
    "intensificarem": "intensificar",
    "intensificaremos": "intensificar",
    "intensificares": "intensificar",
    "intensificaria": "intensificar",
    "intensificariam": "intensificar",
    "intensificarias": "intensificar",
    "intensificarmo": "intensificar",
    "intensificarmos": "intensificar",
    "intensificará": "intensificar",
    "intensificarás": "intensificar",
    "intensificarão": "intensificar",
    "intensificaríamos": "intensificar",
    "intensificaríeis": "intensificar",
    "intensificas": "intensificar",
    "intensificasse": "intensificar",
    "intensificassem": "intensificar",
    "intensificasses": "intensificar",
    "intensificaste": "intensificar",
    "intensificastes": "intensificar",
    "intensificava": "intensificar",
    "intensificavam": "intensificar",
    "intensificavas": "intensificar",
    "intensificações": "intensificação",
    "intensifico": "intensificar",
    "intensificou": "intensificar",
    "intensificá": "intensificar",
    "intensificámo": "intensificar",
    "intensificámos": "intensificar",
    "intensificáramo": "intensificar",
    "intensificáramos": "intensificar",
    "intensificárei": "intensificar",
    "intensificáreis": "intensificar",
    "intensificásseis": "intensificar",
    "intensificássemos": "intensificar",
    "intensificávamo": "intensificar",
    "intensificávamos": "intensificar",
    "intensificávei": "intensificar",
    "intensificáveis": "intensificável",
    "intensifique": "intensificar",
    "intensifiquei": "intensificar",
    "intensifiqueis": "intensificar",
    "intensifiquem": "intensificar",
    "intensifiquemo": "intensificar",
    "intensifiquemos": "intensificar",
    "intensifiques": "intensificar",
    "intensiva": "intensivo",
    "intensivas": "intensivo",
    "intensivos": "intensivo",
    "intensos": "intenso",
    "intensões": "intensão",
    "intenta": "intentar",
    "intentada": "intentar",
    "intentadas": "intentar",
    "intentado": "intentar",
    "intentados": "intentar",
    "intentai": "intentar",
    "intentais": "intentar",
    "intentam": "intentar",
    "intentamo": "intentar",
    "intentamos": "intentar",
    "intentando": "intentar",
    "intentara": "intentar",
    "intentaram": "intentar",
    "intentaras": "intentar",
    "intentarde": "intentar",
    "intentardes": "intentar",
    "intentare": "intentar",
    "intentarei": "intentar",
    "intentareis": "intentar",
    "intentarem": "intentar",
    "intentaremos": "intentar",
    "intentares": "intentar",
    "intentaria": "intentar",
    "intentariam": "intentar",
    "intentarias": "intentar",
    "intentarmo": "intentar",
    "intentarmos": "intentar",
    "intentará": "intentar",
    "intentarás": "intentar",
    "intentarão": "intentar",
    "intentaríamos": "intentar",
    "intentaríeis": "intentar",
    "intentas": "intentar",
    "intentasse": "intentar",
    "intentassem": "intentar",
    "intentasses": "intentar",
    "intentaste": "intentar",
    "intentastes": "intentar",
    "intentava": "intentar",
    "intentavam": "intentar",
    "intentavas": "intentar",
    "intente": "intentar",
    "intentei": "intentar",
    "intenteis": "intentar",
    "intentem": "intentar",
    "intentemo": "intentar",
    "intentemos": "intentar",
    "intentes": "intentar",
    "intento": "intentar",
    "intentonas": "intentona",
    "intentos": "intento",
    "intentou": "intentar",
    "intentá": "intentar",
    "intentámo": "intentar",
    "intentámos": "intentar",
    "intentáramo": "intentar",
    "intentáramos": "intentar",
    "intentárei": "intentar",
    "intentáreis": "intentar",
    "intentásseis": "intentar",
    "intentássemos": "intentar",
    "intentávamo": "intentar",
    "intentávamos": "intentar",
    "intentávei": "intentar",
    "intentáveis": "intentar",
    "intenções": "intenção",
    "interactiva": "interactivo",
    "interactivas": "interactivo",
    "interactividades": "interactividade",
    "interactivos": "interactivo",
    "interacções": "interacção",
    "interage": "interagir",
    "interagem": "interagir",
    "interages": "interagir",
    "interagi": "interagir",
    "interagia": "interagir",
    "interagiam": "interagir",
    "interagias": "interagir",
    "interagida": "interagir",
    "interagidas": "interagir",
    "interagido": "interagir",
    "interagidos": "interagir",
    "interagimo": "interagir",
    "interagimos": "interagir",
    "interagindo": "interagir",
    "interagira": "interagir",
    "interagiram": "interagir",
    "interagiras": "interagir",
    "interagirdes": "interagir",
    "interagirei": "interagir",
    "interagireis": "interagir",
    "interagirem": "interagir",
    "interagiremos": "interagir",
    "interagires": "interagir",
    "interagiria": "interagir",
    "interagiriam": "interagir",
    "interagirias": "interagir",
    "interagirmo": "interagir",
    "interagirmos": "interagir",
    "interagirá": "interagir",
    "interagirás": "interagir",
    "interagirão": "interagir",
    "interagiríamos": "interagir",
    "interagiríeis": "interagir",
    "interagis": "interagir",
    "interagisse": "interagir",
    "interagissem": "interagir",
    "interagisses": "interagir",
    "interagiste": "interagir",
    "interagistes": "interagir",
    "interagiu": "interagir",
    "interagíamo": "interagir",
    "interagíamos": "interagir",
    "interagíeis": "interagir",
    "interagíramo": "interagir",
    "interagíramos": "interagir",
    "interagíreis": "interagir",
    "interagísseis": "interagir",
    "interagíssemos": "interagir",
    "interaja": "interagir",
    "interajais": "interagir",
    "interajam": "interagir",
    "interajamo": "interagir",
    "interajamos": "interagir",
    "interajas": "interagir",
    "interajo": "interagir",
    "interaliada": "interaliado",
    "interaliadas": "interaliado",
    "interaliados": "interaliado",
    "interamnenses": "interamnense",
    "interanulares": "interanular",
    "interarticulares": "interarticular",
    "interastrais": "interastral",
    "interatómica": "interatómico",
    "interatómicas": "interatómico",
    "interatómicos": "interatómico",
    "interaçoriana": "interaçoriano",
    "interaçorianas": "interaçoriano",
    "interaçorianos": "interaçoriano",
    "interbancária": "interbancário",
    "interbancárias": "interbancário",
    "interbancários": "interbancário",
    "intercadentes": "intercadente",
    "intercadências": "intercadência",
    "intercala": "intercalar",
    "intercalada": "intercalar",
    "intercaladas": "intercalar",
    "intercalado": "intercalar",
    "intercalados": "intercalar",
    "intercalai": "intercalar",
    "intercalais": "intercalar",
    "intercalam": "intercalar",
    "intercalamentos": "intercalamento",
    "intercalamo": "intercalar",
    "intercalamos": "intercalar",
    "intercalando": "intercalar",
    "intercalara": "intercalar",
    "intercalaram": "intercalar",
    "intercalaras": "intercalar",
    "intercalarde": "intercalar",
    "intercalardes": "intercalar",
    "intercalare": "intercalar",
    "intercalarei": "intercalar",
    "intercalareis": "intercalar",
    "intercalarem": "intercalar",
    "intercalaremos": "intercalar",
    "intercalares": "intercalar",
    "intercalaria": "intercalar",
    "intercalariam": "intercalar",
    "intercalarias": "intercalar",
    "intercalarmo": "intercalar",
    "intercalarmos": "intercalar",
    "intercalará": "intercalar",
    "intercalarás": "intercalar",
    "intercalarão": "intercalar",
    "intercalaríamos": "intercalar",
    "intercalaríeis": "intercalar",
    "intercalas": "intercalar",
    "intercalasse": "intercalar",
    "intercalassem": "intercalar",
    "intercalasses": "intercalar",
    "intercalaste": "intercalar",
    "intercalastes": "intercalar",
    "intercalava": "intercalar",
    "intercalavam": "intercalar",
    "intercalavas": "intercalar",
    "intercalações": "intercalação",
    "intercale": "intercalar",
    "intercalei": "intercalar",
    "intercaleis": "intercalar",
    "intercalem": "intercalar",
    "intercalemo": "intercalar",
    "intercalemos": "intercalar",
    "intercales": "intercalar",
    "intercalo": "intercalar",
    "intercalou": "intercalar",
    "intercalá": "intercalar",
    "intercalámo": "intercalar",
    "intercalámos": "intercalar",
    "intercaláramo": "intercalar",
    "intercaláramos": "intercalar",
    "intercalárei": "intercalar",
    "intercaláreis": "intercalar",
    "intercalásseis": "intercalar",
    "intercalássemos": "intercalar",
    "intercalávamo": "intercalar",
    "intercalávamos": "intercalar",
    "intercalávei": "intercalar",
    "intercaláveis": "intercalável",
    "intercambiantes": "intercambiante",
    "interceda": "interceder",
    "intercedais": "interceder",
    "intercedam": "interceder",
    "intercedamo": "interceder",
    "intercedamos": "interceder",
    "intercedas": "interceder",
    "intercede": "interceder",
    "intercedei": "interceder",
    "intercedeis": "interceder",
    "intercedem": "interceder",
    "intercedemo": "interceder",
    "intercedemos": "interceder",
    "intercedendo": "interceder",
    "intercedentes": "intercedente",
    "intercedera": "interceder",
    "intercederam": "interceder",
    "intercederas": "interceder",
    "intercederdes": "interceder",
    "intercederei": "interceder",
    "intercedereis": "interceder",
    "intercederem": "interceder",
    "intercederemos": "interceder",
    "intercederes": "interceder",
    "intercederia": "interceder",
    "intercederiam": "interceder",
    "intercederias": "interceder",
    "intercedermo": "interceder",
    "intercedermos": "interceder",
    "intercederá": "interceder",
    "intercederás": "interceder",
    "intercederão": "interceder",
    "intercederíamos": "interceder",
    "intercederíeis": "interceder",
    "intercedes": "interceder",
    "intercedesse": "interceder",
    "intercedessem": "interceder",
    "intercedesses": "interceder",
    "intercedeste": "interceder",
    "intercedestes": "interceder",
    "intercedeu": "interceder",
    "intercedi": "interceder",
    "intercedia": "interceder",
    "intercediam": "interceder",
    "intercedias": "interceder",
    "intercedida": "interceder",
    "intercedidas": "interceder",
    "intercedido": "interceder",
    "intercedidos": "interceder",
    "intercedo": "interceder",
    "intercedêramo": "interceder",
    "intercedêramos": "interceder",
    "intercedêreis": "interceder",
    "intercedêsseis": "interceder",
    "intercedêssemos": "interceder",
    "intercedíamo": "interceder",
    "intercedíamos": "interceder",
    "intercedíeis": "interceder",
    "intercelulares": "intercelular",
    "intercentis": "intercentil",
    "intercepta": "intercepto",
    "interceptada": "interceptar",
    "interceptadas": "interceptar",
    "interceptado": "interceptar",
    "interceptadora": "interceptador",
    "interceptadoras": "interceptador",
    "interceptadores": "interceptador",
    "interceptados": "interceptar",
    "interceptai": "interceptar",
    "interceptais": "interceptar",
    "interceptam": "interceptar",
    "interceptamo": "interceptar",
    "interceptamos": "interceptar",
    "interceptando": "interceptar",
    "interceptara": "interceptar",
    "interceptaram": "interceptar",
    "interceptaras": "interceptar",
    "interceptarde": "interceptar",
    "interceptardes": "interceptar",
    "interceptare": "interceptar",
    "interceptarei": "interceptar",
    "interceptareis": "interceptar",
    "interceptarem": "interceptar",
    "interceptaremos": "interceptar",
    "interceptares": "interceptar",
    "interceptaria": "interceptar",
    "interceptariam": "interceptar",
    "interceptarias": "interceptar",
    "interceptarmo": "interceptar",
    "interceptarmos": "interceptar",
    "interceptará": "interceptar",
    "interceptarás": "interceptar",
    "interceptarão": "interceptar",
    "interceptaríamos": "interceptar",
    "interceptaríeis": "interceptar",
    "interceptas": "intercepto",
    "interceptasse": "interceptar",
    "interceptassem": "interceptar",
    "interceptasses": "interceptar",
    "interceptaste": "interceptar",
    "interceptastes": "interceptar",
    "interceptava": "interceptar",
    "interceptavam": "interceptar",
    "interceptavas": "interceptar",
    "interceptações": "interceptação",
    "intercepte": "interceptar",
    "interceptei": "interceptar",
    "intercepteis": "interceptar",
    "interceptem": "interceptar",
    "interceptemo": "interceptar",
    "interceptemos": "interceptar",
    "interceptes": "interceptar",
    "intercepto": "interceptar",
    "interceptora": "interceptor",
    "interceptoras": "interceptor",
    "interceptores": "interceptor",
    "interceptos": "intercepto",
    "interceptou": "interceptar",
    "interceptá": "interceptar",
    "interceptámo": "interceptar",
    "interceptámos": "interceptar",
    "interceptáramo": "interceptar",
    "interceptáramos": "interceptar",
    "interceptárei": "interceptar",
    "interceptáreis": "interceptar",
    "interceptásseis": "interceptar",
    "interceptássemos": "interceptar",
    "interceptávamo": "interceptar",
    "interceptávamos": "interceptar",
    "interceptávei": "interceptar",
    "interceptáveis": "interceptável",
    "intercepções": "intercepção",
    "intercessora": "intercessor",
    "intercessoras": "intercessor",
    "intercessores": "intercessor",
    "intercessões": "intercessão",
    "intercisa": "interciso",
    "intercisas": "interciso",
    "intercisos": "interciso",
    "intercisões": "intercisão",
    "interclaviculares": "interclavicular",
    "interclubistas": "interclubista",
    "intercoloniais": "intercolonial",
    "intercolunares": "intercolunar",
    "intercolúnia": "intercolúnio",
    "intercolúnias": "intercolúnio",
    "intercolúnios": "intercolúnio",
    "intercombinações": "intercombinação",
    "intercomunicações": "intercomunicação",
    "intercomunitária": "intercomunitário",
    "intercomunitárias": "intercomunitário",
    "intercomunitários": "intercomunitário",
    "interconexões": "interconexão",
    "interconsonântica": "interconsonântico",
    "interconsonânticas": "interconsonântico",
    "interconsonânticos": "interconsonântico",
    "intercontinentais": "intercontinental",
    "intercorra": "intercorrer",
    "intercorrais": "intercorrer",
    "intercorram": "intercorrer",
    "intercorramo": "intercorrer",
    "intercorramos": "intercorrer",
    "intercorras": "intercorrer",
    "intercorre": "intercorrer",
    "intercorrei": "intercorrer",
    "intercorreis": "intercorrer",
    "intercorrem": "intercorrer",
    "intercorremo": "intercorrer",
    "intercorremos": "intercorrer",
    "intercorrendo": "intercorrer",
    "intercorrentes": "intercorrente",
    "intercorrera": "intercorrer",
    "intercorreram": "intercorrer",
    "intercorreras": "intercorrer",
    "intercorrerdes": "intercorrer",
    "intercorrerei": "intercorrer",
    "intercorrereis": "intercorrer",
    "intercorrerem": "intercorrer",
    "intercorreremos": "intercorrer",
    "intercorreres": "intercorrer",
    "intercorreria": "intercorrer",
    "intercorreriam": "intercorrer",
    "intercorrerias": "intercorrer",
    "intercorrermo": "intercorrer",
    "intercorrermos": "intercorrer",
    "intercorrerá": "intercorrer",
    "intercorrerás": "intercorrer",
    "intercorrerão": "intercorrer",
    "intercorreríamos": "intercorrer",
    "intercorreríeis": "intercorrer",
    "intercorres": "intercorrer",
    "intercorresse": "intercorrer",
    "intercorressem": "intercorrer",
    "intercorresses": "intercorrer",
    "intercorreste": "intercorrer",
    "intercorrestes": "intercorrer",
    "intercorreu": "intercorrer",
    "intercorri": "intercorrer",
    "intercorria": "intercorrer",
    "intercorriam": "intercorrer",
    "intercorrias": "intercorrer",
    "intercorrida": "intercorrer",
    "intercorridas": "intercorrer",
    "intercorrido": "intercorrer",
    "intercorridos": "intercorrer",
    "intercorro": "intercorrer",
    "intercorrências": "intercorrência",
    "intercorrêramo": "intercorrer",
    "intercorrêramos": "intercorrer",
    "intercorrêreis": "intercorrer",
    "intercorrêsseis": "intercorrer",
    "intercorrêssemos": "intercorrer",
    "intercorríamo": "intercorrer",
    "intercorríamos": "intercorrer",
    "intercorríeis": "intercorrer",
    "intercostais": "intercostal",
    "intercrescimentos": "intercrescimento",
    "interculturas": "intercultura",
    "intercursos": "intercurso",
    "intercutânea": "intercutâneo",
    "intercutâneas": "intercutâneo",
    "intercutâneos": "intercutâneo",
    "intercâmbios": "intercâmbio",
    "intercílios": "intercílio",
    "intercósmica": "intercósmico",
    "intercósmicas": "intercósmico",
    "intercósmicos": "intercósmico",
    "interdecis": "interdecil",
    "interdepartamentais": "interdepartamental",
    "interdependa": "interdepender",
    "interdependais": "interdepender",
    "interdependam": "interdepender",
    "interdependamo": "interdepender",
    "interdependamos": "interdepender",
    "interdependas": "interdepender",
    "interdepende": "interdepender",
    "interdependei": "interdepender",
    "interdependeis": "interdepender",
    "interdependem": "interdepender",
    "interdependemo": "interdepender",
    "interdependemos": "interdepender",
    "interdependendo": "interdepender",
    "interdependentes": "interdependente",
    "interdependera": "interdepender",
    "interdependeram": "interdepender",
    "interdependeras": "interdepender",
    "interdependerdes": "interdepender",
    "interdependerei": "interdepender",
    "interdependereis": "interdepender",
    "interdependerem": "interdepender",
    "interdependeremos": "interdepender",
    "interdependeres": "interdepender",
    "interdependeria": "interdepender",
    "interdependeriam": "interdepender",
    "interdependerias": "interdepender",
    "interdependermo": "interdepender",
    "interdependermos": "interdepender",
    "interdependerá": "interdepender",
    "interdependerás": "interdepender",
    "interdependerão": "interdepender",
    "interdependeríamos": "interdepender",
    "interdependeríeis": "interdepender",
    "interdependes": "interdepender",
    "interdependesse": "interdepender",
    "interdependessem": "interdepender",
    "interdependesses": "interdepender",
    "interdependeste": "interdepender",
    "interdependestes": "interdepender",
    "interdependeu": "interdepender",
    "interdependi": "interdepender",
    "interdependia": "interdepender",
    "interdependiam": "interdepender",
    "interdependias": "interdepender",
    "interdependida": "interdepender",
    "interdependidas": "interdepender",
    "interdependido": "interdepender",
    "interdependidos": "interdepender",
    "interdependo": "interdepender",
    "interdependências": "interdependência",
    "interdependêramo": "interdepender",
    "interdependêramos": "interdepender",
    "interdependêreis": "interdepender",
    "interdependêsseis": "interdepender",
    "interdependêssemos": "interdepender",
    "interdependíamo": "interdepender",
    "interdependíamos": "interdepender",
    "interdependíeis": "interdepender",
    "interdiga": "interdizer",
    "interdigais": "interdizer",
    "interdigam": "interdizer",
    "interdigamo": "interdizer",
    "interdigamos": "interdizer",
    "interdigas": "interdizer",
    "interdigitais": "interdigital",
    "interdigo": "interdizer",
    "interdirei": "interdizer",
    "interdireis": "interdizer",
    "interdiremos": "interdizer",
    "interdiria": "interdizer",
    "interdiriam": "interdizer",
    "interdirias": "interdizer",
    "interdirá": "interdizer",
    "interdirás": "interdizer",
    "interdirão": "interdizer",
    "interdiríamos": "interdizer",
    "interdiríeis": "interdizer",
    "interdisciplinares": "interdisciplinar",
    "interdisciplinaridades": "interdisciplinaridade",
    "interdisse": "interdizer",
    "interdissemo": "interdizer",
    "interdissemos": "interdizer",
    "interdisser": "interdizer",
    "interdissera": "interdizer",
    "interdisseram": "interdizer",
    "interdisseras": "interdizer",
    "interdisserdes": "interdizer",
    "interdisserem": "interdizer",
    "interdisseres": "interdizer",
    "interdissermos": "interdizer",
    "interdissesse": "interdizer",
    "interdissessem": "interdizer",
    "interdissesses": "interdizer",
    "interdisseste": "interdizer",
    "interdissestes": "interdizer",
    "interdisséramo": "interdizer",
    "interdisséramos": "interdizer",
    "interdissérei": "interdizer",
    "interdisséreis": "interdizer",
    "interdissésseis": "interdizer",
    "interdisséssemos": "interdizer",
    "interdita": "interdizer",
    "interditada": "interditar",
    "interditadas": "interditar",
    "interditado": "interditar",
    "interditados": "interditar",
    "interditai": "interditar",
    "interditais": "interditar",
    "interditam": "interditar",
    "interditamo": "interditar",
    "interditamos": "interditar",
    "interditando": "interditar",
    "interditara": "interditar",
    "interditaram": "interditar",
    "interditaras": "interditar",
    "interditarde": "interditar",
    "interditardes": "interditar",
    "interditare": "interditar",
    "interditarei": "interditar",
    "interditareis": "interditar",
    "interditarem": "interditar",
    "interditaremos": "interditar",
    "interditares": "interditar",
    "interditaria": "interditar",
    "interditariam": "interditar",
    "interditarias": "interditar",
    "interditarmo": "interditar",
    "interditarmos": "interditar",
    "interditará": "interditar",
    "interditarás": "interditar",
    "interditarão": "interditar",
    "interditaríamos": "interditar",
    "interditaríeis": "interditar",
    "interditas": "interdizer",
    "interditasse": "interditar",
    "interditassem": "interditar",
    "interditasses": "interditar",
    "interditaste": "interditar",
    "interditastes": "interditar",
    "interditava": "interditar",
    "interditavam": "interditar",
    "interditavas": "interditar",
    "interdite": "interditar",
    "interditei": "interditar",
    "interditeis": "interditar",
    "interditem": "interditar",
    "interditemo": "interditar",
    "interditemos": "interditar",
    "interdites": "interditar",
    "interdito": "interdizer",
    "interditos": "interdizer",
    "interditou": "interditar",
    "interditá": "interditar",
    "interditámo": "interditar",
    "interditámos": "interditar",
    "interditáramo": "interditar",
    "interditáramos": "interditar",
    "interditárei": "interditar",
    "interditáreis": "interditar",
    "interditásseis": "interditar",
    "interditássemos": "interditar",
    "interditávamo": "interditar",
    "interditávamos": "interditar",
    "interditávei": "interditar",
    "interditáveis": "interditável",
    "interdiz": "interdizer",
    "interdize": "interdizer",
    "interdizei": "interdizer",
    "interdizeis": "interdizer",
    "interdizem": "interdizer",
    "interdizemo": "interdizer",
    "interdizemos": "interdizer",
    "interdizendo": "interdizer",
    "interdizerde": "interdizer",
    "interdizerdes": "interdizer",
    "interdizere": "interdizer",
    "interdizerem": "interdizer",
    "interdizeres": "interdizer",
    "interdizermo": "interdizer",
    "interdizermos": "interdizer",
    "interdizes": "interdizer",
    "interdizia": "interdizer",
    "interdiziam": "interdizer",
    "interdizias": "interdizer",
    "interdizê": "interdizer",
    "interdizíamo": "interdizer",
    "interdizíamos": "interdizer",
    "interdizíei": "interdizer",
    "interdizíeis": "interdizer",
    "interdições": "interdição",
    "interescolares": "interescolar",
    "interespacejamentos": "interespacejamento",
    "interessa": "interessar",
    "interessada": "interessar",
    "interessadas": "interessar",
    "interessado": "interessar",
    "interessados": "interessar",
    "interessadíssima": "interessado",
    "interessadíssimas": "interessado",
    "interessadíssimo": "interessado",
    "interessadíssimos": "interessado",
    "interessai": "interessar",
    "interessais": "interessar",
    "interessam": "interessar",
    "interessamo": "interessar",
    "interessamos": "interessar",
    "interessando": "interessar",
    "interessantes": "interessante",
    "interessantíssima": "interessante",
    "interessantíssimas": "interessante",
    "interessantíssimo": "interessante",
    "interessantíssimos": "interessante",
    "interessara": "interessar",
    "interessaram": "interessar",
    "interessaras": "interessar",
    "interessarde": "interessar",
    "interessardes": "interessar",
    "interessare": "interessar",
    "interessarei": "interessar",
    "interessareis": "interessar",
    "interessarem": "interessar",
    "interessaremos": "interessar",
    "interessares": "interessar",
    "interessaria": "interessar",
    "interessariam": "interessar",
    "interessarias": "interessar",
    "interessarmo": "interessar",
    "interessarmos": "interessar",
    "interessará": "interessar",
    "interessarás": "interessar",
    "interessarão": "interessar",
    "interessaríamos": "interessar",
    "interessaríeis": "interessar",
    "interessas": "interessar",
    "interessasse": "interessar",
    "interessassem": "interessar",
    "interessasses": "interessar",
    "interessaste": "interessar",
    "interessastes": "interessar",
    "interessava": "interessar",
    "interessavam": "interessar",
    "interessavas": "interessar",
    "interesse": "interessar",
    "interessei": "interessar",
    "interesseira": "interesseiro",
    "interesseiras": "interesseiro",
    "interesseiros": "interesseiro",
    "interesseis": "interessar",
    "interessem": "interessar",
    "interessemo": "interessar",
    "interessemos": "interessar",
    "interesses": "interesse",
    "interesso": "interessar",
    "interessou": "interessar",
    "interessá": "interessar",
    "interessámo": "interessar",
    "interessámos": "interessar",
    "interessáramo": "interessar",
    "interessáramos": "interessar",
    "interessárei": "interessar",
    "interessáreis": "interessar",
    "interessásseis": "interessar",
    "interessássemos": "interessar",
    "interessávamo": "interessar",
    "interessávamos": "interessar",
    "interessávei": "interessar",
    "interessáveis": "interessar",
    "interestaduais": "interestadual",
    "interestelares": "interestelar",
    "interfaces": "interface",
    "interfases": "interfase",
    "interfemínios": "interfemínio",
    "interfere": "interferir",
    "interferem": "interferir",
    "interferentes": "interferente",
    "interferes": "interferir",
    "interferi": "interferir",
    "interferia": "interferir",
    "interferiam": "interferir",
    "interferias": "interferir",
    "interferida": "interferir",
    "interferidas": "interferir",
    "interferido": "interferir",
    "interferidos": "interferir",
    "interferimo": "interferir",
    "interferimos": "interferir",
    "interferindo": "interferir",
    "interferira": "interferir",
    "interferiram": "interferir",
    "interferiras": "interferir",
    "interferirdes": "interferir",
    "interferirei": "interferir",
    "interferireis": "interferir",
    "interferirem": "interferir",
    "interferiremos": "interferir",
    "interferires": "interferir",
    "interferiria": "interferir",
    "interfeririam": "interferir",
    "interferirias": "interferir",
    "interferirmo": "interferir",
    "interferirmos": "interferir",
    "interferirá": "interferir",
    "interferirás": "interferir",
    "interferirão": "interferir",
    "interferiríamos": "interferir",
    "interferiríeis": "interferir",
    "interferis": "interferir",
    "interferisse": "interferir",
    "interferissem": "interferir",
    "interferisses": "interferir",
    "interferiste": "interferir",
    "interferistes": "interferir",
    "interferiu": "interferir",
    "interferometrias": "interferometria",
    "interferências": "interferência",
    "interferíamo": "interferir",
    "interferíamos": "interferir",
    "interferíeis": "interferir",
    "interferíramo": "interferir",
    "interferíramos": "interferir",
    "interferíreis": "interferir",
    "interferísseis": "interferir",
    "interferíssemos": "interferir",
    "interferómetros": "interferómetro",
    "interfira": "interferir",
    "interfirais": "interferir",
    "interfiram": "interferir",
    "interfiramo": "interferir",
    "interfiramos": "interferir",
    "interfiras": "interferir",
    "interfiro": "interferir",
    "interfixa": "interfixo",
    "interfixas": "interfixo",
    "interfixos": "interfixo",
    "interflorais": "interfloral",
    "interfolia": "interfoliar",
    "interfoliada": "interfoliar",
    "interfoliadas": "interfoliar",
    "interfoliado": "interfoliar",
    "interfoliados": "interfoliar",
    "interfoliai": "interfoliar",
    "interfoliais": "interfoliar",
    "interfoliam": "interfoliar",
    "interfoliamo": "interfoliar",
    "interfoliamos": "interfoliar",
    "interfoliando": "interfoliar",
    "interfoliara": "interfoliar",
    "interfoliaram": "interfoliar",
    "interfoliaras": "interfoliar",
    "interfoliarde": "interfoliar",
    "interfoliardes": "interfoliar",
    "interfoliare": "interfoliar",
    "interfoliarei": "interfoliar",
    "interfoliareis": "interfoliar",
    "interfoliarem": "interfoliar",
    "interfoliaremos": "interfoliar",
    "interfoliares": "interfoliar",
    "interfoliaria": "interfoliar",
    "interfoliariam": "interfoliar",
    "interfoliarias": "interfoliar",
    "interfoliarmo": "interfoliar",
    "interfoliarmos": "interfoliar",
    "interfoliará": "interfoliar",
    "interfoliarás": "interfoliar",
    "interfoliarão": "interfoliar",
    "interfoliaríamos": "interfoliar",
    "interfoliaríeis": "interfoliar",
    "interfolias": "interfoliar",
    "interfoliasse": "interfoliar",
    "interfoliassem": "interfoliar",
    "interfoliasses": "interfoliar",
    "interfoliaste": "interfoliar",
    "interfoliastes": "interfoliar",
    "interfoliava": "interfoliar",
    "interfoliavam": "interfoliar",
    "interfoliavas": "interfoliar",
    "interfoliações": "interfoliação",
    "interfolie": "interfoliar",
    "interfoliei": "interfoliar",
    "interfolieis": "interfoliar",
    "interfoliem": "interfoliar",
    "interfoliemo": "interfoliar",
    "interfoliemos": "interfoliar",
    "interfolies": "interfoliar",
    "interfolio": "interfoliar",
    "interfoliou": "interfoliar",
    "interfoliá": "interfoliar",
    "interfoliácea": "interfoliáceo",
    "interfoliáceas": "interfoliáceo",
    "interfoliáceos": "interfoliáceo",
    "interfoliámo": "interfoliar",
    "interfoliámos": "interfoliar",
    "interfoliáramo": "interfoliar",
    "interfoliáramos": "interfoliar",
    "interfoliárei": "interfoliar",
    "interfoliáreis": "interfoliar",
    "interfoliásseis": "interfoliar",
    "interfoliássemos": "interfoliar",
    "interfoliávamo": "interfoliar",
    "interfoliávamos": "interfoliar",
    "interfoliávei": "interfoliar",
    "interfoliáveis": "interfoliar",
    "interfronteiriça": "interfronteiriço",
    "interfronteiriças": "interfronteiriço",
    "interfronteiriços": "interfronteiriço",
    "interglaciares": "interglaciar",
    "interglaciária": "interglaciário",
    "interglaciárias": "interglaciário",
    "interglaciários": "interglaciário",
    "interglosas": "interglosa",
    "intergovernamentais": "intergovernamental",
    "interina": "interino",
    "interinados": "interinado",
    "interinas": "interino",
    "interinatos": "interinato",
    "interindependências": "interindependência",
    "interinfluências": "interinfluência",
    "interinidades": "interinidade",
    "interinos": "interino",
    "interinstitucionais": "interinstitucional",
    "interinsulares": "interinsular",
    "interiores": "interior",
    "interioridades": "interioridade",
    "interioriza": "interiorizar",
    "interiorizada": "interiorizar",
    "interiorizadas": "interiorizar",
    "interiorizado": "interiorizar",
    "interiorizados": "interiorizar",
    "interiorizai": "interiorizar",
    "interiorizais": "interiorizar",
    "interiorizam": "interiorizar",
    "interiorizamo": "interiorizar",
    "interiorizamos": "interiorizar",
    "interiorizando": "interiorizar",
    "interiorizara": "interiorizar",
    "interiorizaram": "interiorizar",
    "interiorizaras": "interiorizar",
    "interiorizarde": "interiorizar",
    "interiorizardes": "interiorizar",
    "interiorizare": "interiorizar",
    "interiorizarei": "interiorizar",
    "interiorizareis": "interiorizar",
    "interiorizarem": "interiorizar",
    "interiorizaremos": "interiorizar",
    "interiorizares": "interiorizar",
    "interiorizaria": "interiorizar",
    "interiorizariam": "interiorizar",
    "interiorizarias": "interiorizar",
    "interiorizarmo": "interiorizar",
    "interiorizarmos": "interiorizar",
    "interiorizará": "interiorizar",
    "interiorizarás": "interiorizar",
    "interiorizarão": "interiorizar",
    "interiorizaríamos": "interiorizar",
    "interiorizaríeis": "interiorizar",
    "interiorizas": "interiorizar",
    "interiorizasse": "interiorizar",
    "interiorizassem": "interiorizar",
    "interiorizasses": "interiorizar",
    "interiorizaste": "interiorizar",
    "interiorizastes": "interiorizar",
    "interiorizava": "interiorizar",
    "interiorizavam": "interiorizar",
    "interiorizavas": "interiorizar",
    "interiorizações": "interiorização",
    "interiorize": "interiorizar",
    "interiorizei": "interiorizar",
    "interiorizeis": "interiorizar",
    "interiorizem": "interiorizar",
    "interiorizemo": "interiorizar",
    "interiorizemos": "interiorizar",
    "interiorizes": "interiorizar",
    "interiorizo": "interiorizar",
    "interiorizou": "interiorizar",
    "interiorizá": "interiorizar",
    "interiorizámo": "interiorizar",
    "interiorizámos": "interiorizar",
    "interiorizáramo": "interiorizar",
    "interiorizáramos": "interiorizar",
    "interiorizárei": "interiorizar",
    "interiorizáreis": "interiorizar",
    "interiorizásseis": "interiorizar",
    "interiorizássemos": "interiorizar",
    "interiorizávamo": "interiorizar",
    "interiorizávamos": "interiorizar",
    "interiorizávei": "interiorizar",
    "interiorizáveis": "interiorizável",
    "interjacentes": "interjacente",
    "interjeccionais": "interjeccional",
    "interjectiva": "interjectivo",
    "interjectivas": "interjectivo",
    "interjectivos": "interjectivo",
    "interjeições": "interjeição",
    "interliga": "interligar",
    "interligada": "interligar",
    "interligadas": "interligar",
    "interligado": "interligar",
    "interligados": "interligar",
    "interligai": "interligar",
    "interligais": "interligar",
    "interligam": "interligar",
    "interligamo": "interligar",
    "interligamos": "interligar",
    "interligando": "interligar",
    "interligara": "interligar",
    "interligaram": "interligar",
    "interligaras": "interligar",
    "interligarde": "interligar",
    "interligardes": "interligar",
    "interligare": "interligar",
    "interligarei": "interligar",
    "interligareis": "interligar",
    "interligarem": "interligar",
    "interligaremos": "interligar",
    "interligares": "interligar",
    "interligaria": "interligar",
    "interligariam": "interligar",
    "interligarias": "interligar",
    "interligarmo": "interligar",
    "interligarmos": "interligar",
    "interligará": "interligar",
    "interligarás": "interligar",
    "interligarão": "interligar",
    "interligaríamos": "interligar",
    "interligaríeis": "interligar",
    "interligas": "interligar",
    "interligasse": "interligar",
    "interligassem": "interligar",
    "interligasses": "interligar",
    "interligaste": "interligar",
    "interligastes": "interligar",
    "interligava": "interligar",
    "interligavam": "interligar",
    "interligavas": "interligar",
    "interligações": "interligação",
    "interligo": "interligar",
    "interligou": "interligar",
    "interligue": "interligar",
    "interliguei": "interligar",
    "interligueis": "interligar",
    "interliguem": "interligar",
    "interliguemo": "interligar",
    "interliguemos": "interligar",
    "interligues": "interligar",
    "interligá": "interligar",
    "interligámo": "interligar",
    "interligámos": "interligar",
    "interligáramo": "interligar",
    "interligáramos": "interligar",
    "interligárei": "interligar",
    "interligáreis": "interligar",
    "interligásseis": "interligar",
    "interligássemos": "interligar",
    "interligávamo": "interligar",
    "interligávamos": "interligar",
    "interligávei": "interligar",
    "interligáveis": "interligar",
    "interlineares": "interlinear",
    "interlinguistas": "interlinguista",
    "interlinguisticas": "interlinguistica",
    "interlocutora": "interlocutor",
    "interlocutoras": "interlocutor",
    "interlocutores": "interlocutor",
    "interlocutória": "interlocutório",
    "interlocutórias": "interlocutório",
    "interlocutórios": "interlocutório",
    "interlocuções": "interlocução",
    "interlopes": "interlope",
    "interlunares": "interlunar",
    "interlínguas": "interlíngua",
    "interlúcidos": "interlúcido",
    "interlúdios": "interlúdio",
    "interlúnios": "interlúnio",
    "intermações": "intermação",
    "intermedia": "intermediar",
    "intermediada": "intermediar",
    "intermediadas": "intermediar",
    "intermediado": "intermediar",
    "intermediados": "intermediar",
    "intermediai": "intermediar",
    "intermediais": "intermediar",
    "intermediam": "intermediar",
    "intermediamo": "intermediar",
    "intermediamos": "intermediar",
    "intermediando": "intermediar",
    "intermediara": "intermediar",
    "intermediaram": "intermediar",
    "intermediaras": "intermediar",
    "intermediardes": "intermediar",
    "intermediarei": "intermediar",
    "intermediareis": "intermediar",
    "intermediarem": "intermediar",
    "intermediaremos": "intermediar",
    "intermediares": "intermediar",
    "intermediaria": "intermediar",
    "intermediariam": "intermediar",
    "intermediarias": "intermediar",
    "intermediarmo": "intermediar",
    "intermediarmos": "intermediar",
    "intermediará": "intermediar",
    "intermediarás": "intermediar",
    "intermediarão": "intermediar",
    "intermediaríamos": "intermediar",
    "intermediaríeis": "intermediar",
    "intermedias": "intermediar",
    "intermediasse": "intermediar",
    "intermediassem": "intermediar",
    "intermediasses": "intermediar",
    "intermediaste": "intermediar",
    "intermediastes": "intermediar",
    "intermediava": "intermediar",
    "intermediavam": "intermediar",
    "intermediavas": "intermediar",
    "intermediações": "intermediação",
    "intermedie": "intermediar",
    "intermediei": "intermediar",
    "intermedieis": "intermediar",
    "intermediem": "intermediar",
    "intermediemo": "intermediar",
    "intermediemos": "intermediar",
    "intermedies": "intermediar",
    "intermedio": "intermediar",
    "intermediou": "intermediar",
    "intermediámo": "intermediar",
    "intermediámos": "intermediar",
    "intermediáramo": "intermediar",
    "intermediáramos": "intermediar",
    "intermediáreis": "intermediar",
    "intermediária": "intermediário",
    "intermediárias": "intermediário",
    "intermediários": "intermediário",
    "intermediásseis": "intermediar",
    "intermediássemos": "intermediar",
    "intermediávamo": "intermediar",
    "intermediávamos": "intermediar",
    "intermediáveis": "intermediar",
    "intermenstruais": "intermenstrual",
    "intermenstruações": "intermenstruação",
    "intermeta": "intermeter",
    "intermetais": "intermeter",
    "intermetam": "intermeter",
    "intermetamo": "intermeter",
    "intermetamos": "intermeter",
    "intermetas": "intermeter",
    "intermete": "intermeter",
    "intermetei": "intermeter",
    "intermeteis": "intermeter",
    "intermetem": "intermeter",
    "intermetemo": "intermeter",
    "intermetemos": "intermeter",
    "intermetendo": "intermeter",
    "intermetera": "intermeter",
    "intermeteram": "intermeter",
    "intermeteras": "intermeter",
    "intermeterde": "intermeter",
    "intermeterdes": "intermeter",
    "intermetere": "intermeter",
    "intermeterei": "intermeter",
    "intermetereis": "intermeter",
    "intermeterem": "intermeter",
    "intermeteremos": "intermeter",
    "intermeteres": "intermeter",
    "intermeteria": "intermeter",
    "intermeteriam": "intermeter",
    "intermeterias": "intermeter",
    "intermetermo": "intermeter",
    "intermetermos": "intermeter",
    "intermeterá": "intermeter",
    "intermeterás": "intermeter",
    "intermeterão": "intermeter",
    "intermeteríamos": "intermeter",
    "intermeteríeis": "intermeter",
    "intermetes": "intermeter",
    "intermetesse": "intermeter",
    "intermetessem": "intermeter",
    "intermetesses": "intermeter",
    "intermeteste": "intermeter",
    "intermetestes": "intermeter",
    "intermeteu": "intermeter",
    "intermeti": "intermeter",
    "intermetia": "intermeter",
    "intermetiam": "intermeter",
    "intermetias": "intermeter",
    "intermetida": "intermeter",
    "intermetidas": "intermeter",
    "intermetido": "intermeter",
    "intermetidos": "intermeter",
    "intermeto": "intermeter",
    "intermetê": "intermeter",
    "intermetêramo": "intermeter",
    "intermetêramos": "intermeter",
    "intermetêrei": "intermeter",
    "intermetêreis": "intermeter",
    "intermetêsseis": "intermeter",
    "intermetêssemos": "intermeter",
    "intermetíamo": "intermeter",
    "intermetíamos": "intermeter",
    "intermetíei": "intermeter",
    "intermetíeis": "intermeter",
    "interministeriais": "interministerial",
    "intermináveis": "interminável",
    "intermissões": "intermissão",
    "intermistura": "intermisturar",
    "intermisturada": "intermisturar",
    "intermisturadas": "intermisturar",
    "intermisturado": "intermisturar",
    "intermisturados": "intermisturar",
    "intermisturai": "intermisturar",
    "intermisturais": "intermisturar",
    "intermisturam": "intermisturar",
    "intermisturamo": "intermisturar",
    "intermisturamos": "intermisturar",
    "intermisturando": "intermisturar",
    "intermisturara": "intermisturar",
    "intermisturaram": "intermisturar",
    "intermisturaras": "intermisturar",
    "intermisturarde": "intermisturar",
    "intermisturardes": "intermisturar",
    "intermisturare": "intermisturar",
    "intermisturarei": "intermisturar",
    "intermisturareis": "intermisturar",
    "intermisturarem": "intermisturar",
    "intermisturaremos": "intermisturar",
    "intermisturares": "intermisturar",
    "intermisturaria": "intermisturar",
    "intermisturariam": "intermisturar",
    "intermisturarias": "intermisturar",
    "intermisturarmo": "intermisturar",
    "intermisturarmos": "intermisturar",
    "intermisturará": "intermisturar",
    "intermisturarás": "intermisturar",
    "intermisturarão": "intermisturar",
    "intermisturaríamos": "intermisturar",
    "intermisturaríeis": "intermisturar",
    "intermisturas": "intermisturar",
    "intermisturasse": "intermisturar",
    "intermisturassem": "intermisturar",
    "intermisturasses": "intermisturar",
    "intermisturaste": "intermisturar",
    "intermisturastes": "intermisturar",
    "intermisturava": "intermisturar",
    "intermisturavam": "intermisturar",
    "intermisturavas": "intermisturar",
    "intermisture": "intermisturar",
    "intermisturei": "intermisturar",
    "intermistureis": "intermisturar",
    "intermisturem": "intermisturar",
    "intermisturemo": "intermisturar",
    "intermisturemos": "intermisturar",
    "intermistures": "intermisturar",
    "intermisturo": "intermisturar",
    "intermisturou": "intermisturar",
    "intermisturá": "intermisturar",
    "intermisturámo": "intermisturar",
    "intermisturámos": "intermisturar",
    "intermisturáramo": "intermisturar",
    "intermisturáramos": "intermisturar",
    "intermisturárei": "intermisturar",
    "intermisturáreis": "intermisturar",
    "intermisturásseis": "intermisturar",
    "intermisturássemos": "intermisturar",
    "intermisturávamo": "intermisturar",
    "intermisturávamos": "intermisturar",
    "intermisturávei": "intermisturar",
    "intermisturáveis": "intermisturar",
    "intermita": "intermitir",
    "intermitais": "intermitir",
    "intermitam": "intermitir",
    "intermitamo": "intermitir",
    "intermitamos": "intermitir",
    "intermitas": "intermitir",
    "intermite": "intermitir",
    "intermitem": "intermitir",
    "intermitentes": "intermitente",
    "intermites": "intermitir",
    "intermiti": "intermitir",
    "intermitia": "intermitir",
    "intermitiam": "intermitir",
    "intermitias": "intermitir",
    "intermitida": "intermitir",
    "intermitidas": "intermitir",
    "intermitido": "intermitir",
    "intermitidos": "intermitir",
    "intermitimo": "intermitir",
    "intermitimos": "intermitir",
    "intermitindo": "intermitir",
    "intermitira": "intermitir",
    "intermitiram": "intermitir",
    "intermitiras": "intermitir",
    "intermitirdes": "intermitir",
    "intermitirei": "intermitir",
    "intermitireis": "intermitir",
    "intermitirem": "intermitir",
    "intermitiremos": "intermitir",
    "intermitires": "intermitir",
    "intermitiria": "intermitir",
    "intermitiriam": "intermitir",
    "intermitirias": "intermitir",
    "intermitirmo": "intermitir",
    "intermitirmos": "intermitir",
    "intermitirá": "intermitir",
    "intermitirás": "intermitir",
    "intermitirão": "intermitir",
    "intermitiríamos": "intermitir",
    "intermitiríeis": "intermitir",
    "intermitis": "intermitir",
    "intermitisse": "intermitir",
    "intermitissem": "intermitir",
    "intermitisses": "intermitir",
    "intermitiste": "intermitir",
    "intermitistes": "intermitir",
    "intermitiu": "intermitir",
    "intermito": "intermitir",
    "intermitências": "intermitência",
    "intermitíamo": "intermitir",
    "intermitíamos": "intermitir",
    "intermitíeis": "intermitir",
    "intermitíramo": "intermitir",
    "intermitíramos": "intermitir",
    "intermitíreis": "intermitir",
    "intermitísseis": "intermitir",
    "intermitíssemos": "intermitir",
    "intermodulações": "intermodulação",
    "intermoleculares": "intermolecular",
    "intermunicipais": "intermunicipal",
    "intermurais": "intermural",
    "intermusculares": "intermuscular",
    "intermédia": "intermédio",
    "intermédias": "intermédio",
    "intermédios": "intermédio",
    "intermênstruos": "intermênstruo",
    "intermúndios": "intermúndio",
    "interna": "interno",
    "internacionais": "internacional",
    "internacionalidades": "internacionalidade",
    "internacionalismos": "internacionalismo",
    "internacionalistas": "internacionalista",
    "internacionaliza": "internacionalizar",
    "internacionalizada": "internacionalizar",
    "internacionalizadas": "internacionalizar",
    "internacionalizado": "internacionalizar",
    "internacionalizados": "internacionalizar",
    "internacionalizai": "internacionalizar",
    "internacionalizais": "internacionalizar",
    "internacionalizam": "internacionalizar",
    "internacionalizamo": "internacionalizar",
    "internacionalizamos": "internacionalizar",
    "internacionalizando": "internacionalizar",
    "internacionalizara": "internacionalizar",
    "internacionalizaram": "internacionalizar",
    "internacionalizaras": "internacionalizar",
    "internacionalizarde": "internacionalizar",
    "internacionalizardes": "internacionalizar",
    "internacionalizare": "internacionalizar",
    "internacionalizarei": "internacionalizar",
    "internacionalizareis": "internacionalizar",
    "internacionalizarem": "internacionalizar",
    "internacionalizaremos": "internacionalizar",
    "internacionalizares": "internacionalizar",
    "internacionalizaria": "internacionalizar",
    "internacionalizariam": "internacionalizar",
    "internacionalizarias": "internacionalizar",
    "internacionalizarmo": "internacionalizar",
    "internacionalizarmos": "internacionalizar",
    "internacionalizará": "internacionalizar",
    "internacionalizarás": "internacionalizar",
    "internacionalizarão": "internacionalizar",
    "internacionalizaríamos": "internacionalizar",
    "internacionalizaríeis": "internacionalizar",
    "internacionalizas": "internacionalizar",
    "internacionalizasse": "internacionalizar",
    "internacionalizassem": "internacionalizar",
    "internacionalizasses": "internacionalizar",
    "internacionalizaste": "internacionalizar",
    "internacionalizastes": "internacionalizar",
    "internacionalizava": "internacionalizar",
    "internacionalizavam": "internacionalizar",
    "internacionalizavas": "internacionalizar",
    "internacionalizações": "internacionalização",
    "internacionalize": "internacionalizar",
    "internacionalizei": "internacionalizar",
    "internacionalizeis": "internacionalizar",
    "internacionalizem": "internacionalizar",
    "internacionalizemo": "internacionalizar",
    "internacionalizemos": "internacionalizar",
    "internacionalizes": "internacionalizar",
    "internacionalizo": "internacionalizar",
    "internacionalizou": "internacionalizar",
    "internacionalizá": "internacionalizar",
    "internacionalizámo": "internacionalizar",
    "internacionalizámos": "internacionalizar",
    "internacionalizáramo": "internacionalizar",
    "internacionalizáramos": "internacionalizar",
    "internacionalizárei": "internacionalizar",
    "internacionalizáreis": "internacionalizar",
    "internacionalizásseis": "internacionalizar",
    "internacionalizássemos": "internacionalizar",
    "internacionalizávamo": "internacionalizar",
    "internacionalizávamos": "internacionalizar",
    "internacionalizávei": "internacionalizar",
    "internacionalizáveis": "internacionalizável",
    "internada": "internar",
    "internadas": "internar",
    "internado": "internar",
    "internados": "internar",
    "internai": "internar",
    "internais": "internar",
    "internam": "internar",
    "internamentos": "internamento",
    "internamo": "internar",
    "internamos": "internar",
    "internando": "internar",
    "internara": "internar",
    "internaram": "internar",
    "internaras": "internar",
    "internarde": "internar",
    "internardes": "internar",
    "internare": "internar",
    "internarei": "internar",
    "internareis": "internar",
    "internarem": "internar",
    "internaremos": "internar",
    "internares": "internar",
    "internaria": "internar",
    "internariam": "internar",
    "internarias": "internar",
    "internarmo": "internar",
    "internarmos": "internar",
    "internará": "internar",
    "internarás": "internar",
    "internarão": "internar",
    "internaríamos": "internar",
    "internaríeis": "internar",
    "internas": "interno",
    "internasse": "internar",
    "internassem": "internar",
    "internasses": "internar",
    "internaste": "internar",
    "internastes": "internar",
    "internatos": "internato",
    "internava": "internar",
    "internavam": "internar",
    "internavas": "internar",
    "internações": "internação",
    "interne": "internar",
    "internegativos": "internegativo",
    "internei": "internar",
    "interneis": "internar",
    "internem": "internar",
    "internemo": "internar",
    "internemos": "internar",
    "internes": "internar",
    "internistas": "internista",
    "interno": "internar",
    "internodiais": "internodial",
    "internos": "interno",
    "internou": "internar",
    "internucleares": "internuclear",
    "interná": "internar",
    "internámo": "internar",
    "internámos": "internar",
    "internáramo": "internar",
    "internáramos": "internar",
    "internárei": "internar",
    "internáreis": "internar",
    "internásseis": "internar",
    "internássemos": "internar",
    "internávamo": "internar",
    "internávamos": "internar",
    "internávei": "internar",
    "internáveis": "internável",
    "internódios": "internódio",
    "internúncios": "internúncio",
    "interoceptiva": "interoceptivo",
    "interoceptivas": "interoceptivo",
    "interoceptivos": "interoceptivo",
    "interoceptores": "interoceptor",
    "interoceânica": "interoceânico",
    "interoceânicas": "interoceânico",
    "interoceânicos": "interoceânico",
    "interoculares": "interocular",
    "interoperacionalidades": "interoperacionalidade",
    "interoposições": "interoposição",
    "interparietais": "interparietal",
    "interpartidária": "interpartidário",
    "interpartidárias": "interpartidário",
    "interpartidários": "interpartidário",
    "interpela": "interpelar",
    "interpelada": "interpelar",
    "interpeladas": "interpelar",
    "interpelado": "interpelar",
    "interpeladora": "interpelador",
    "interpeladoras": "interpelador",
    "interpeladores": "interpelador",
    "interpelados": "interpelar",
    "interpelai": "interpelar",
    "interpelais": "interpelar",
    "interpelam": "interpelar",
    "interpelamo": "interpelar",
    "interpelamos": "interpelar",
    "interpelando": "interpelar",
    "interpelantes": "interpelante",
    "interpelara": "interpelar",
    "interpelaram": "interpelar",
    "interpelaras": "interpelar",
    "interpelarde": "interpelar",
    "interpelardes": "interpelar",
    "interpelare": "interpelar",
    "interpelarei": "interpelar",
    "interpelareis": "interpelar",
    "interpelarem": "interpelar",
    "interpelaremos": "interpelar",
    "interpelares": "interpelar",
    "interpelaria": "interpelar",
    "interpelariam": "interpelar",
    "interpelarias": "interpelar",
    "interpelarmo": "interpelar",
    "interpelarmos": "interpelar",
    "interpelará": "interpelar",
    "interpelarás": "interpelar",
    "interpelarão": "interpelar",
    "interpelaríamos": "interpelar",
    "interpelaríeis": "interpelar",
    "interpelas": "interpelar",
    "interpelasse": "interpelar",
    "interpelassem": "interpelar",
    "interpelasses": "interpelar",
    "interpelaste": "interpelar",
    "interpelastes": "interpelar",
    "interpelativa": "interpelativo",
    "interpelativas": "interpelativo",
    "interpelativos": "interpelativo",
    "interpelatrizs": "interpelatriz",
    "interpelava": "interpelar",
    "interpelavam": "interpelar",
    "interpelavas": "interpelar",
    "interpelações": "interpelação",
    "interpele": "interpelar",
    "interpelei": "interpelar",
    "interpeleis": "interpelar",
    "interpelem": "interpelar",
    "interpelemo": "interpelar",
    "interpelemos": "interpelar",
    "interpeles": "interpelar",
    "interpelo": "interpelar",
    "interpelou": "interpelar",
    "interpelá": "interpelar",
    "interpelámo": "interpelar",
    "interpelámos": "interpelar",
    "interpeláramo": "interpelar",
    "interpeláramos": "interpelar",
    "interpelárei": "interpelar",
    "interpeláreis": "interpelar",
    "interpelásseis": "interpelar",
    "interpelássemos": "interpelar",
    "interpelávamo": "interpelar",
    "interpelávamos": "interpelar",
    "interpelávei": "interpelar",
    "interpeláveis": "interpelável",
    "interpenetra": "interpenetrar",
    "interpenetrada": "interpenetrar",
    "interpenetradas": "interpenetrar",
    "interpenetrado": "interpenetrar",
    "interpenetrados": "interpenetrar",
    "interpenetrai": "interpenetrar",
    "interpenetrais": "interpenetrar",
    "interpenetram": "interpenetrar",
    "interpenetramo": "interpenetrar",
    "interpenetramos": "interpenetrar",
    "interpenetrando": "interpenetrar",
    "interpenetrara": "interpenetrar",
    "interpenetraram": "interpenetrar",
    "interpenetraras": "interpenetrar",
    "interpenetrardes": "interpenetrar",
    "interpenetrarei": "interpenetrar",
    "interpenetrareis": "interpenetrar",
    "interpenetrarem": "interpenetrar",
    "interpenetraremos": "interpenetrar",
    "interpenetrares": "interpenetrar",
    "interpenetraria": "interpenetrar",
    "interpenetrariam": "interpenetrar",
    "interpenetrarias": "interpenetrar",
    "interpenetrarmo": "interpenetrar",
    "interpenetrarmos": "interpenetrar",
    "interpenetrará": "interpenetrar",
    "interpenetrarás": "interpenetrar",
    "interpenetrarão": "interpenetrar",
    "interpenetraríamos": "interpenetrar",
    "interpenetraríeis": "interpenetrar",
    "interpenetras": "interpenetrar",
    "interpenetrasse": "interpenetrar",
    "interpenetrassem": "interpenetrar",
    "interpenetrasses": "interpenetrar",
    "interpenetraste": "interpenetrar",
    "interpenetrastes": "interpenetrar",
    "interpenetrava": "interpenetrar",
    "interpenetravam": "interpenetrar",
    "interpenetravas": "interpenetrar",
    "interpenetrações": "interpenetração",
    "interpenetre": "interpenetrar",
    "interpenetrei": "interpenetrar",
    "interpenetreis": "interpenetrar",
    "interpenetrem": "interpenetrar",
    "interpenetremo": "interpenetrar",
    "interpenetremos": "interpenetrar",
    "interpenetres": "interpenetrar",
    "interpenetro": "interpenetrar",
    "interpenetrou": "interpenetrar",
    "interpenetrámo": "interpenetrar",
    "interpenetrámos": "interpenetrar",
    "interpenetráramo": "interpenetrar",
    "interpenetráramos": "interpenetrar",
    "interpenetráreis": "interpenetrar",
    "interpenetrásseis": "interpenetrar",
    "interpenetrássemos": "interpenetrar",
    "interpenetrávamo": "interpenetrar",
    "interpenetrávamos": "interpenetrar",
    "interpenetráveis": "interpenetrar",
    "interpeninsulares": "interpeninsular",
    "interpersonalogias": "interpersonalogia",
    "interpessoais": "interpessoal",
    "interpica": "interpicar",
    "interpicada": "interpicar",
    "interpicadas": "interpicar",
    "interpicado": "interpicar",
    "interpicados": "interpicar",
    "interpicai": "interpicar",
    "interpicais": "interpicar",
    "interpicam": "interpicar",
    "interpicamo": "interpicar",
    "interpicamos": "interpicar",
    "interpicando": "interpicar",
    "interpicara": "interpicar",
    "interpicaram": "interpicar",
    "interpicaras": "interpicar",
    "interpicarde": "interpicar",
    "interpicardes": "interpicar",
    "interpicare": "interpicar",
    "interpicarei": "interpicar",
    "interpicareis": "interpicar",
    "interpicarem": "interpicar",
    "interpicaremos": "interpicar",
    "interpicares": "interpicar",
    "interpicaria": "interpicar",
    "interpicariam": "interpicar",
    "interpicarias": "interpicar",
    "interpicarmo": "interpicar",
    "interpicarmos": "interpicar",
    "interpicará": "interpicar",
    "interpicarás": "interpicar",
    "interpicarão": "interpicar",
    "interpicaríamos": "interpicar",
    "interpicaríeis": "interpicar",
    "interpicas": "interpicar",
    "interpicasse": "interpicar",
    "interpicassem": "interpicar",
    "interpicasses": "interpicar",
    "interpicaste": "interpicar",
    "interpicastes": "interpicar",
    "interpicava": "interpicar",
    "interpicavam": "interpicar",
    "interpicavas": "interpicar",
    "interpico": "interpicar",
    "interpicou": "interpicar",
    "interpicá": "interpicar",
    "interpicámo": "interpicar",
    "interpicámos": "interpicar",
    "interpicáramo": "interpicar",
    "interpicáramos": "interpicar",
    "interpicárei": "interpicar",
    "interpicáreis": "interpicar",
    "interpicásseis": "interpicar",
    "interpicássemos": "interpicar",
    "interpicávamo": "interpicar",
    "interpicávamos": "interpicar",
    "interpicávei": "interpicar",
    "interpicáveis": "interpicar",
    "interpique": "interpicar",
    "interpiquei": "interpicar",
    "interpiqueis": "interpicar",
    "interpiquem": "interpicar",
    "interpiquemo": "interpicar",
    "interpiquemos": "interpicar",
    "interpiques": "interpicar",
    "interplanetária": "interplanetário",
    "interplanetárias": "interplanetário",
    "interplanetários": "interplanetário",
    "interpola": "interpolar",
    "interpolada": "interpolar",
    "interpoladas": "interpolar",
    "interpolado": "interpolar",
    "interpoladora": "interpolador",
    "interpoladoras": "interpolador",
    "interpoladores": "interpolador",
    "interpolados": "interpolar",
    "interpolai": "interpolar",
    "interpolais": "interpolar",
    "interpolam": "interpolar",
    "interpolamo": "interpolar",
    "interpolamos": "interpolar",
    "interpolando": "interpolar",
    "interpolara": "interpolar",
    "interpolaram": "interpolar",
    "interpolaras": "interpolar",
    "interpolarde": "interpolar",
    "interpolardes": "interpolar",
    "interpolare": "interpolar",
    "interpolarei": "interpolar",
    "interpolareis": "interpolar",
    "interpolarem": "interpolar",
    "interpolaremos": "interpolar",
    "interpolares": "interpolar",
    "interpolaria": "interpolar",
    "interpolariam": "interpolar",
    "interpolarias": "interpolar",
    "interpolarmo": "interpolar",
    "interpolarmos": "interpolar",
    "interpolará": "interpolar",
    "interpolarás": "interpolar",
    "interpolarão": "interpolar",
    "interpolaríamos": "interpolar",
    "interpolaríeis": "interpolar",
    "interpolas": "interpolar",
    "interpolasse": "interpolar",
    "interpolassem": "interpolar",
    "interpolasses": "interpolar",
    "interpolaste": "interpolar",
    "interpolastes": "interpolar",
    "interpolava": "interpolar",
    "interpolavam": "interpolar",
    "interpolavas": "interpolar",
    "interpolações": "interpolação",
    "interpole": "interpolar",
    "interpolei": "interpolar",
    "interpoleis": "interpolar",
    "interpolem": "interpolar",
    "interpolemo": "interpolar",
    "interpolemos": "interpolar",
    "interpoles": "interpolar",
    "interpoliciais": "interpolicial",
    "interpolo": "interpolar",
    "interpolou": "interpolar",
    "interpolá": "interpolar",
    "interpolámo": "interpolar",
    "interpolámos": "interpolar",
    "interpoláramo": "interpolar",
    "interpoláramos": "interpolar",
    "interpolárei": "interpolar",
    "interpoláreis": "interpolar",
    "interpolásseis": "interpolar",
    "interpolássemos": "interpolar",
    "interpolávamo": "interpolar",
    "interpolávamos": "interpolar",
    "interpolávei": "interpolar",
    "interpoláveis": "interpolável",
    "interpomo": "interpor",
    "interpomos": "interpor",
    "interponde": "interpor",
    "interpondes": "interpor",
    "interpondo": "interpor",
    "interponha": "interpor",
    "interponhais": "interpor",
    "interponham": "interpor",
    "interponhamo": "interpor",
    "interponhamos": "interpor",
    "interponhas": "interpor",
    "interponho": "interpor",
    "interpontuações": "interpontuação",
    "interporde": "interpor",
    "interpordes": "interpor",
    "interpore": "interpor",
    "interporei": "interpor",
    "interporeis": "interpor",
    "interporem": "interpor",
    "interporemos": "interpor",
    "interpores": "interpor",
    "interporia": "interpor",
    "interporiam": "interpor",
    "interporias": "interpor",
    "interpormo": "interpor",
    "interpormos": "interpor",
    "interportos": "interporto",
    "interporá": "interpor",
    "interporás": "interpor",
    "interporão": "interpor",
    "interporíamos": "interpor",
    "interporíeis": "interpor",
    "interpositivas": "interpositiva",
    "interposições": "interposição",
    "interposta": "interposto",
    "interpostas": "interposto",
    "interposto": "interpor",
    "interpostos": "interposto",
    "interpotentes": "interpotente",
    "interprenda": "interprender",
    "interprendais": "interprender",
    "interprendam": "interprender",
    "interprendamo": "interprender",
    "interprendamos": "interprender",
    "interprendas": "interprender",
    "interprende": "interprender",
    "interprendei": "interprender",
    "interprendeis": "interprender",
    "interprendem": "interprender",
    "interprendemo": "interprender",
    "interprendemos": "interprender",
    "interprendendo": "interprender",
    "interprendera": "interprender",
    "interprenderam": "interprender",
    "interprenderas": "interprender",
    "interprenderde": "interprender",
    "interprenderdes": "interprender",
    "interprendere": "interprender",
    "interprenderei": "interprender",
    "interprendereis": "interprender",
    "interprenderem": "interprender",
    "interprenderemos": "interprender",
    "interprenderes": "interprender",
    "interprenderia": "interprender",
    "interprenderiam": "interprender",
    "interprenderias": "interprender",
    "interprendermo": "interprender",
    "interprendermos": "interprender",
    "interprenderá": "interprender",
    "interprenderás": "interprender",
    "interprenderão": "interprender",
    "interprenderíamos": "interprender",
    "interprenderíeis": "interprender",
    "interprendes": "interprender",
    "interprendesse": "interprender",
    "interprendessem": "interprender",
    "interprendesses": "interprender",
    "interprendeste": "interprender",
    "interprendestes": "interprender",
    "interprendeu": "interprender",
    "interprendi": "interprender",
    "interprendia": "interprender",
    "interprendiam": "interprender",
    "interprendias": "interprender",
    "interprendida": "interprender",
    "interprendidas": "interprender",
    "interprendido": "interprender",
    "interprendidos": "interprender",
    "interprendo": "interprender",
    "interprendê": "interprender",
    "interprendêramo": "interprender",
    "interprendêramos": "interprender",
    "interprendêrei": "interprender",
    "interprendêreis": "interprender",
    "interprendêsseis": "interprender",
    "interprendêssemos": "interprender",
    "interprendíamo": "interprender",
    "interprendíamos": "interprender",
    "interprendíei": "interprender",
    "interprendíeis": "interprender",
    "interpresa": "interpresar",
    "interpresada": "interpresar",
    "interpresadas": "interpresar",
    "interpresado": "interpresar",
    "interpresados": "interpresar",
    "interpresai": "interpresar",
    "interpresais": "interpresar",
    "interpresam": "interpresar",
    "interpresamo": "interpresar",
    "interpresamos": "interpresar",
    "interpresando": "interpresar",
    "interpresara": "interpresar",
    "interpresaram": "interpresar",
    "interpresaras": "interpresar",
    "interpresarde": "interpresar",
    "interpresardes": "interpresar",
    "interpresare": "interpresar",
    "interpresarei": "interpresar",
    "interpresareis": "interpresar",
    "interpresarem": "interpresar",
    "interpresaremos": "interpresar",
    "interpresares": "interpresar",
    "interpresaria": "interpresar",
    "interpresariam": "interpresar",
    "interpresarias": "interpresar",
    "interpresarmo": "interpresar",
    "interpresarmos": "interpresar",
    "interpresará": "interpresar",
    "interpresarás": "interpresar",
    "interpresarão": "interpresar",
    "interpresaríamos": "interpresar",
    "interpresaríeis": "interpresar",
    "interpresas": "interpresar",
    "interpresasse": "interpresar",
    "interpresassem": "interpresar",
    "interpresasses": "interpresar",
    "interpresaste": "interpresar",
    "interpresastes": "interpresar",
    "interpresava": "interpresar",
    "interpresavam": "interpresar",
    "interpresavas": "interpresar",
    "interprese": "interpresar",
    "interpresei": "interpresar",
    "interpreseis": "interpresar",
    "interpresem": "interpresar",
    "interpresemo": "interpresar",
    "interpresemos": "interpresar",
    "interpreses": "interpresar",
    "interpreso": "interpresar",
    "interpresou": "interpresar",
    "interpresá": "interpresar",
    "interpresámo": "interpresar",
    "interpresámos": "interpresar",
    "interpresáramo": "interpresar",
    "interpresáramos": "interpresar",
    "interpresárei": "interpresar",
    "interpresáreis": "interpresar",
    "interpresásseis": "interpresar",
    "interpresássemos": "interpresar",
    "interpresávamo": "interpresar",
    "interpresávamos": "interpresar",
    "interpresávei": "interpresar",
    "interpresáveis": "interpresar",
    "interpreta": "interpretar",
    "interpretada": "interpretar",
    "interpretadas": "interpretar",
    "interpretado": "interpretar",
    "interpretadora": "interpretador",
    "interpretadoras": "interpretador",
    "interpretadores": "interpretador",
    "interpretados": "interpretar",
    "interpretai": "interpretar",
    "interpretais": "interpretar",
    "interpretam": "interpretar",
    "interpretamo": "interpretar",
    "interpretamos": "interpretar",
    "interpretando": "interpretar",
    "interpretantes": "interpretante",
    "interpretara": "interpretar",
    "interpretaram": "interpretar",
    "interpretaras": "interpretar",
    "interpretarde": "interpretar",
    "interpretardes": "interpretar",
    "interpretare": "interpretar",
    "interpretarei": "interpretar",
    "interpretareis": "interpretar",
    "interpretarem": "interpretar",
    "interpretaremos": "interpretar",
    "interpretares": "interpretar",
    "interpretaria": "interpretar",
    "interpretariam": "interpretar",
    "interpretarias": "interpretar",
    "interpretarmo": "interpretar",
    "interpretarmos": "interpretar",
    "interpretará": "interpretar",
    "interpretarás": "interpretar",
    "interpretarão": "interpretar",
    "interpretaríamos": "interpretar",
    "interpretaríeis": "interpretar",
    "interpretas": "interpretar",
    "interpretasse": "interpretar",
    "interpretassem": "interpretar",
    "interpretasses": "interpretar",
    "interpretaste": "interpretar",
    "interpretastes": "interpretar",
    "interpretativa": "interpretativo",
    "interpretativas": "interpretativo",
    "interpretativos": "interpretativo",
    "interpretava": "interpretar",
    "interpretavam": "interpretar",
    "interpretavas": "interpretar",
    "interpretações": "interpretação",
    "interprete": "interpretar",
    "interpretei": "interpretar",
    "interpreteis": "interpretar",
    "interpretem": "interpretar",
    "interpretemo": "interpretar",
    "interpretemos": "interpretar",
    "interpretes": "interpretar",
    "interpreto": "interpretar",
    "interpretou": "interpretar",
    "interpretá": "interpretar",
    "interpretámo": "interpretar",
    "interpretámos": "interpretar",
    "interpretáramo": "interpretar",
    "interpretáramos": "interpretar",
    "interpretárei": "interpretar",
    "interpretáreis": "interpretar",
    "interpretásseis": "interpretar",
    "interpretássemos": "interpretar",
    "interpretávamo": "interpretar",
    "interpretávamos": "interpretar",
    "interpretávei": "interpretar",
    "interpretáveis": "interpretável",
    "interprofissionais": "interprofissional",
    "interpunha": "interpor",
    "interpunham": "interpor",
    "interpunhas": "interpor",
    "interpus": "interpor",
    "interpusemo": "interpor",
    "interpusemos": "interpor",
    "interpuser": "interpor",
    "interpusera": "interpor",
    "interpuseram": "interpor",
    "interpuseras": "interpor",
    "interpuserdes": "interpor",
    "interpuserem": "interpor",
    "interpuseres": "interpor",
    "interpusermos": "interpor",
    "interpusesse": "interpor",
    "interpusessem": "interpor",
    "interpusesses": "interpor",
    "interpuseste": "interpor",
    "interpusestes": "interpor",
    "interpuséramo": "interpor",
    "interpuséramos": "interpor",
    "interpusérei": "interpor",
    "interpuséreis": "interpor",
    "interpusésseis": "interpor",
    "interpuséssemos": "interpor",
    "interpô": "interpor",
    "interpôs": "interpor",
    "interpõe": "interpor",
    "interpõem": "interpor",
    "interpões": "interpor",
    "interpúnhamo": "interpor",
    "interpúnhamos": "interpor",
    "interpúnhei": "interpor",
    "interpúnheis": "interpor",
    "interquatis": "interquatil",
    "interregnos": "interregno",
    "interroga": "interrogar",
    "interrogada": "interrogar",
    "interrogadas": "interrogar",
    "interrogado": "interrogar",
    "interrogadora": "interrogador",
    "interrogadoras": "interrogador",
    "interrogadores": "interrogador",
    "interrogados": "interrogar",
    "interrogai": "interrogar",
    "interrogais": "interrogar",
    "interrogam": "interrogar",
    "interrogamo": "interrogar",
    "interrogamos": "interrogar",
    "interroganda": "interrogando",
    "interrogandas": "interrogando",
    "interrogando": "interrogar",
    "interrogandos": "interrogando",
    "interrogantes": "interrogante",
    "interrogara": "interrogar",
    "interrogaram": "interrogar",
    "interrogaras": "interrogar",
    "interrogarde": "interrogar",
    "interrogardes": "interrogar",
    "interrogare": "interrogar",
    "interrogarei": "interrogar",
    "interrogareis": "interrogar",
    "interrogarem": "interrogar",
    "interrogaremos": "interrogar",
    "interrogares": "interrogar",
    "interrogaria": "interrogar",
    "interrogariam": "interrogar",
    "interrogarias": "interrogar",
    "interrogarmo": "interrogar",
    "interrogarmos": "interrogar",
    "interrogará": "interrogar",
    "interrogarás": "interrogar",
    "interrogarão": "interrogar",
    "interrogaríamos": "interrogar",
    "interrogaríeis": "interrogar",
    "interrogas": "interrogar",
    "interrogasse": "interrogar",
    "interrogassem": "interrogar",
    "interrogasses": "interrogar",
    "interrogaste": "interrogar",
    "interrogastes": "interrogar",
    "interrogativa": "interrogativo",
    "interrogativas": "interrogativo",
    "interrogativos": "interrogativo",
    "interrogatória": "interrogatório",
    "interrogatórias": "interrogatório",
    "interrogatórios": "interrogatório",
    "interrogava": "interrogar",
    "interrogavam": "interrogar",
    "interrogavas": "interrogar",
    "interrogações": "interrogação",
    "interrogo": "interrogar",
    "interrogou": "interrogar",
    "interrogue": "interrogar",
    "interroguei": "interrogar",
    "interrogueis": "interrogar",
    "interroguem": "interrogar",
    "interroguemo": "interrogar",
    "interroguemos": "interrogar",
    "interrogues": "interrogar",
    "interrogá": "interrogar",
    "interrogámo": "interrogar",
    "interrogámos": "interrogar",
    "interrogáramo": "interrogar",
    "interrogáramos": "interrogar",
    "interrogárei": "interrogar",
    "interrogáreis": "interrogar",
    "interrogásseis": "interrogar",
    "interrogássemos": "interrogar",
    "interrogávamo": "interrogar",
    "interrogávamos": "interrogar",
    "interrogávei": "interrogar",
    "interrogáveis": "interrogável",
    "interrompa": "interromper",
    "interrompais": "interromper",
    "interrompam": "interromper",
    "interrompamo": "interromper",
    "interrompamos": "interromper",
    "interrompas": "interromper",
    "interrompe": "interromper",
    "interrompei": "interromper",
    "interrompeis": "interromper",
    "interrompem": "interromper",
    "interrompemo": "interromper",
    "interrompemos": "interromper",
    "interrompendo": "interromper",
    "interrompera": "interromper",
    "interromperam": "interromper",
    "interromperas": "interromper",
    "interromperde": "interromper",
    "interromperdes": "interromper",
    "interrompere": "interromper",
    "interromperei": "interromper",
    "interrompereis": "interromper",
    "interromperem": "interromper",
    "interromperemos": "interromper",
    "interromperes": "interromper",
    "interromperia": "interromper",
    "interromperiam": "interromper",
    "interromperias": "interromper",
    "interrompermo": "interromper",
    "interrompermos": "interromper",
    "interromperá": "interromper",
    "interromperás": "interromper",
    "interromperão": "interromper",
    "interromperíamos": "interromper",
    "interromperíeis": "interromper",
    "interrompes": "interromper",
    "interrompesse": "interromper",
    "interrompessem": "interromper",
    "interrompesses": "interromper",
    "interrompeste": "interromper",
    "interrompestes": "interromper",
    "interrompeu": "interromper",
    "interrompi": "interromper",
    "interrompia": "interromper",
    "interrompiam": "interromper",
    "interrompias": "interromper",
    "interrompida": "interrompido",
    "interrompidas": "interrompido",
    "interrompido": "interromper",
    "interrompidos": "interrompido",
    "interrompo": "interromper",
    "interrompê": "interromper",
    "interrompêramo": "interromper",
    "interrompêramos": "interromper",
    "interrompêrei": "interromper",
    "interrompêreis": "interromper",
    "interrompêsseis": "interromper",
    "interrompêssemos": "interromper",
    "interrompíamo": "interromper",
    "interrompíamos": "interromper",
    "interrompíei": "interromper",
    "interrompíeis": "interromper",
    "interrompíveis": "interrompível",
    "interrupta": "interrupto",
    "interruptas": "interrupto",
    "interruptora": "interruptor",
    "interruptoras": "interruptor",
    "interruptores": "interruptor",
    "interruptos": "interrupto",
    "interrupções": "interrupção",
    "interscálmios": "interscálmio",
    "interseccionais": "interseccional",
    "intersecta": "intersectar",
    "intersectada": "intersectar",
    "intersectadas": "intersectar",
    "intersectado": "intersectar",
    "intersectados": "intersectar",
    "intersectai": "intersectar",
    "intersectais": "intersectar",
    "intersectam": "intersectar",
    "intersectamo": "intersectar",
    "intersectamos": "intersectar",
    "intersectando": "intersectar",
    "intersectara": "intersectar",
    "intersectaram": "intersectar",
    "intersectaras": "intersectar",
    "intersectarde": "intersectar",
    "intersectardes": "intersectar",
    "intersectare": "intersectar",
    "intersectarei": "intersectar",
    "intersectareis": "intersectar",
    "intersectarem": "intersectar",
    "intersectaremos": "intersectar",
    "intersectares": "intersectar",
    "intersectaria": "intersectar",
    "intersectariam": "intersectar",
    "intersectarias": "intersectar",
    "intersectarmo": "intersectar",
    "intersectarmos": "intersectar",
    "intersectará": "intersectar",
    "intersectarás": "intersectar",
    "intersectarão": "intersectar",
    "intersectaríamos": "intersectar",
    "intersectaríeis": "intersectar",
    "intersectas": "intersectar",
    "intersectasse": "intersectar",
    "intersectassem": "intersectar",
    "intersectasses": "intersectar",
    "intersectaste": "intersectar",
    "intersectastes": "intersectar",
    "intersectava": "intersectar",
    "intersectavam": "intersectar",
    "intersectavas": "intersectar",
    "intersecte": "intersectar",
    "intersectei": "intersectar",
    "intersecteis": "intersectar",
    "intersectem": "intersectar",
    "intersectemo": "intersectar",
    "intersectemos": "intersectar",
    "intersectes": "intersectar",
    "intersecto": "intersectar",
    "intersectoriais": "intersectorial",
    "intersectou": "intersectar",
    "intersectá": "intersectar",
    "intersectámo": "intersectar",
    "intersectámos": "intersectar",
    "intersectáramo": "intersectar",
    "intersectáramos": "intersectar",
    "intersectárei": "intersectar",
    "intersectáreis": "intersectar",
    "intersectásseis": "intersectar",
    "intersectássemos": "intersectar",
    "intersectávamo": "intersectar",
    "intersectávamos": "intersectar",
    "intersectávei": "intersectar",
    "intersectáveis": "intersectável",
    "intersecções": "intersecção",
    "intersere": "interserir",
    "interserem": "interserir",
    "interseres": "interserir",
    "interseri": "interserir",
    "interseria": "interserir",
    "interseriam": "interserir",
    "interserias": "interserir",
    "interserida": "interserir",
    "interseridas": "interserir",
    "interserido": "interserir",
    "interseridos": "interserir",
    "interserimo": "interserir",
    "interserimos": "interserir",
    "interserindo": "interserir",
    "interserira": "interserir",
    "interseriram": "interserir",
    "interseriras": "interserir",
    "interserirde": "interserir",
    "interserirdes": "interserir",
    "interserire": "interserir",
    "interserirei": "interserir",
    "interserireis": "interserir",
    "interserirem": "interserir",
    "interseriremos": "interserir",
    "interserires": "interserir",
    "interseriria": "interserir",
    "interseririam": "interserir",
    "interseririas": "interserir",
    "interserirmo": "interserir",
    "interserirmos": "interserir",
    "interserirá": "interserir",
    "interserirás": "interserir",
    "interserirão": "interserir",
    "interseriríamos": "interserir",
    "interseriríeis": "interserir",
    "interseris": "interserir",
    "interserisse": "interserir",
    "interserissem": "interserir",
    "interserisses": "interserir",
    "interseriste": "interserir",
    "interseristes": "interserir",
    "interseriu": "interserir",
    "interseríamo": "interserir",
    "interseríamos": "interserir",
    "interseríei": "interserir",
    "interseríeis": "interserir",
    "interseríramo": "interserir",
    "interseríramos": "interserir",
    "interserírei": "interserir",
    "interseríreis": "interserir",
    "interserísseis": "interserir",
    "interseríssemos": "interserir",
    "intersexualidades": "intersexualidade",
    "intersilhada": "intersilhado",
    "intersilhadas": "intersilhado",
    "intersilhados": "intersilhado",
    "intersindicais": "intersindical",
    "intersira": "interserir",
    "intersirais": "interserir",
    "intersiram": "interserir",
    "intersiramo": "interserir",
    "intersiramos": "interserir",
    "intersiras": "interserir",
    "intersiro": "interserir",
    "interstelares": "interstelar",
    "intersticiais": "intersticial",
    "interstícios": "interstício",
    "intersístoles": "intersístole",
    "intertextos": "intertexto",
    "intertextualidades": "intertextualidade",
    "intertipos": "intertipo",
    "intertrigens": "intertrigem",
    "intertrigos": "intertrigo",
    "intertropicais": "intertropical",
    "interuniversitária": "interuniversitário",
    "interuniversitárias": "interuniversitário",
    "interuniversitários": "interuniversitário",
    "interurbana": "interurbano",
    "interurbanas": "interurbano",
    "interurbanos": "interurbano",
    "intervala": "intervalar",
    "intervalada": "intervalar",
    "intervaladas": "intervalar",
    "intervalado": "intervalar",
    "intervalados": "intervalar",
    "intervalai": "intervalar",
    "intervalais": "intervalar",
    "intervalam": "intervalar",
    "intervalamo": "intervalar",
    "intervalamos": "intervalar",
    "intervalando": "intervalar",
    "intervalara": "intervalar",
    "intervalaram": "intervalar",
    "intervalaras": "intervalar",
    "intervalardes": "intervalar",
    "intervalarei": "intervalar",
    "intervalareis": "intervalar",
    "intervalarem": "intervalar",
    "intervalaremos": "intervalar",
    "intervalares": "intervalar",
    "intervalaria": "intervalar",
    "intervalariam": "intervalar",
    "intervalarias": "intervalar",
    "intervalarmo": "intervalar",
    "intervalarmos": "intervalar",
    "intervalará": "intervalar",
    "intervalarás": "intervalar",
    "intervalarão": "intervalar",
    "intervalaríamos": "intervalar",
    "intervalaríeis": "intervalar",
    "intervalas": "intervalar",
    "intervalasse": "intervalar",
    "intervalassem": "intervalar",
    "intervalasses": "intervalar",
    "intervalaste": "intervalar",
    "intervalastes": "intervalar",
    "intervalava": "intervalar",
    "intervalavam": "intervalar",
    "intervalavas": "intervalar",
    "intervale": "intervalar",
    "intervalei": "intervalar",
    "intervaleis": "intervalar",
    "intervalem": "intervalar",
    "intervalemo": "intervalar",
    "intervalemos": "intervalar",
    "intervales": "intervalar",
    "intervalo": "intervalar",
    "intervalos": "intervalo",
    "intervalou": "intervalar",
    "intervalámo": "intervalar",
    "intervalámos": "intervalar",
    "intervaláramo": "intervalar",
    "intervaláramos": "intervalar",
    "intervaláreis": "intervalar",
    "intervalásseis": "intervalar",
    "intervalássemos": "intervalar",
    "intervalávamo": "intervalar",
    "intervalávamos": "intervalar",
    "intervaláveis": "intervalável",
    "interveio": "intervir",
    "intervem": "intervir",
    "intervencionismos": "intervencionismo",
    "intervencionistas": "intervencionista",
    "intervenha": "intervir",
    "intervenhais": "intervir",
    "intervenham": "intervir",
    "intervenhamo": "intervir",
    "intervenhamos": "intervir",
    "intervenhas": "intervir",
    "intervenho": "intervir",
    "intervenientes": "interveniente",
    "interveniências": "interveniência",
    "interventiva": "interventivo",
    "interventivas": "interventivo",
    "interventivos": "interventivo",
    "interventora": "interventor",
    "interventoras": "interventor",
    "interventores": "interventor",
    "interventriculares": "interventricular",
    "intervenções": "intervenção",
    "interversões": "interversão",
    "interverta": "interverter",
    "intervertais": "interverter",
    "intervertam": "interverter",
    "intervertamo": "interverter",
    "intervertamos": "interverter",
    "intervertas": "interverter",
    "interverte": "interverter",
    "intervertebrais": "intervertebral",
    "intervertei": "interverter",
    "interverteis": "interverter",
    "intervertem": "interverter",
    "intervertemo": "interverter",
    "intervertemos": "interverter",
    "intervertendo": "interverter",
    "intervertera": "interverter",
    "interverteram": "interverter",
    "interverteras": "interverter",
    "interverterde": "interverter",
    "interverterdes": "interverter",
    "intervertere": "interverter",
    "interverterei": "interverter",
    "intervertereis": "interverter",
    "interverterem": "interverter",
    "interverteremos": "interverter",
    "interverteres": "interverter",
    "interverteria": "interverter",
    "interverteriam": "interverter",
    "interverterias": "interverter",
    "intervertermo": "interverter",
    "intervertermos": "interverter",
    "interverterá": "interverter",
    "interverterás": "interverter",
    "interverterão": "interverter",
    "interverteríamos": "interverter",
    "interverteríeis": "interverter",
    "intervertes": "interverter",
    "intervertesse": "interverter",
    "intervertessem": "interverter",
    "intervertesses": "interverter",
    "interverteste": "interverter",
    "intervertestes": "interverter",
    "interverteu": "interverter",
    "interverti": "interverter",
    "intervertia": "interverter",
    "intervertiam": "interverter",
    "intervertias": "interverter",
    "intervertida": "interverter",
    "intervertidas": "interverter",
    "intervertido": "interverter",
    "intervertidos": "interverter",
    "interverto": "interverter",
    "intervertê": "interverter",
    "intervertêramo": "interverter",
    "intervertêramos": "interverter",
    "intervertêrei": "interverter",
    "intervertêreis": "interverter",
    "intervertêsseis": "interverter",
    "intervertêssemos": "interverter",
    "intervertíamo": "interverter",
    "intervertíamos": "interverter",
    "intervertíei": "interverter",
    "intervertíeis": "interverter",
    "interviemo": "intervir",
    "interviemos": "intervir",
    "intervier": "intervir",
    "interviera": "intervir",
    "intervieram": "intervir",
    "intervieras": "intervir",
    "intervierdes": "intervir",
    "intervierem": "intervir",
    "intervieres": "intervir",
    "interviermos": "intervir",
    "interviesse": "intervir",
    "interviessem": "intervir",
    "interviesses": "intervir",
    "intervieste": "intervir",
    "interviestes": "intervir",
    "interviews": "interview",
    "intervim": "intervir",
    "intervimo": "intervir",
    "intervimos": "intervir",
    "intervinda": "intervir",
    "intervindas": "intervir",
    "intervinde": "intervir",
    "intervindes": "intervir",
    "intervindo": "intervir",
    "intervindos": "intervir",
    "intervinha": "intervir",
    "intervinham": "intervir",
    "intervinhas": "intervir",
    "intervirdes": "intervir",
    "intervirei": "intervir",
    "intervireis": "intervir",
    "intervirem": "intervir",
    "interviremos": "intervir",
    "intervires": "intervir",
    "interviria": "intervir",
    "interviriam": "intervir",
    "intervirias": "intervir",
    "intervirmo": "intervir",
    "intervirmos": "intervir",
    "intervirá": "intervir",
    "intervirás": "intervir",
    "intervirão": "intervir",
    "interviríamos": "intervir",
    "interviríeis": "intervir",
    "interviéramo": "intervir",
    "interviéramos": "intervir",
    "interviéreis": "intervir",
    "interviésseis": "intervir",
    "interviéssemos": "intervir",
    "intervocais": "intervocal",
    "intervocálica": "intervocálico",
    "intervocálicas": "intervocálico",
    "intervocálicos": "intervocálico",
    "intervém": "intervir",
    "intervéns": "intervir",
    "intervêm": "intervir",
    "intervínhamo": "intervir",
    "intervínhamos": "intervir",
    "intervínheis": "intervir",
    "interétnica": "interétnico",
    "interétnicas": "interétnico",
    "interétnicos": "interétnico",
    "intesrada": "intesrado",
    "intesradas": "intesrado",
    "intesrados": "intesrado",
    "intestina": "intestino",
    "intestinais": "intestinal",
    "intestinas": "intestino",
    "intestinos": "intestino",
    "intestáveis": "intestável",
    "intica": "inticar",
    "inticada": "inticar",
    "inticadas": "inticar",
    "inticado": "inticar",
    "inticados": "inticar",
    "inticais": "inticar",
    "inticam": "inticar",
    "inticamo": "inticar",
    "inticamos": "inticar",
    "inticando": "inticar",
    "inticara": "inticar",
    "inticaram": "inticar",
    "inticaras": "inticar",
    "inticardes": "inticar",
    "inticarei": "inticar",
    "inticareis": "inticar",
    "inticarem": "inticar",
    "inticaremos": "inticar",
    "inticares": "inticar",
    "inticaria": "inticar",
    "inticariam": "inticar",
    "inticarias": "inticar",
    "inticarmo": "inticar",
    "inticarmos": "inticar",
    "inticará": "inticar",
    "inticarás": "inticar",
    "inticarão": "inticar",
    "inticaríamos": "inticar",
    "inticaríeis": "inticar",
    "inticas": "inticar",
    "inticasse": "inticar",
    "inticassem": "inticar",
    "inticasses": "inticar",
    "inticaste": "inticar",
    "inticastes": "inticar",
    "inticava": "inticar",
    "inticavam": "inticar",
    "inticavas": "inticar",
    "intico": "inticar",
    "inticou": "inticar",
    "inticámo": "inticar",
    "inticámos": "inticar",
    "inticáramo": "inticar",
    "inticáramos": "inticar",
    "inticáreis": "inticar",
    "inticásseis": "inticar",
    "inticássemos": "inticar",
    "inticávamo": "inticar",
    "inticávamos": "inticar",
    "inticáveis": "inticar",
    "intima": "intimar",
    "intimada": "intimar",
    "intimadas": "intimar",
    "intimado": "intimar",
    "intimadora": "intimador",
    "intimadoras": "intimador",
    "intimadores": "intimador",
    "intimados": "intimar",
    "intimai": "intimar",
    "intimais": "intimar",
    "intimam": "intimar",
    "intimamo": "intimar",
    "intimamos": "intimar",
    "intimando": "intimar",
    "intimara": "intimar",
    "intimaram": "intimar",
    "intimaras": "intimar",
    "intimarde": "intimar",
    "intimardes": "intimar",
    "intimare": "intimar",
    "intimarei": "intimar",
    "intimareis": "intimar",
    "intimarem": "intimar",
    "intimaremos": "intimar",
    "intimares": "intimar",
    "intimaria": "intimar",
    "intimariam": "intimar",
    "intimarias": "intimar",
    "intimarmo": "intimar",
    "intimarmos": "intimar",
    "intimará": "intimar",
    "intimarás": "intimar",
    "intimarão": "intimar",
    "intimaríamos": "intimar",
    "intimaríeis": "intimar",
    "intimas": "intimar",
    "intimasse": "intimar",
    "intimassem": "intimar",
    "intimasses": "intimar",
    "intimaste": "intimar",
    "intimastes": "intimar",
    "intimativa": "intimativo",
    "intimativas": "intimativo",
    "intimativos": "intimativo",
    "intimava": "intimar",
    "intimavam": "intimar",
    "intimavas": "intimar",
    "intimações": "intimação",
    "intime": "intimar",
    "intimei": "intimar",
    "intimeis": "intimar",
    "intimem": "intimar",
    "intimemo": "intimar",
    "intimemos": "intimar",
    "intimes": "intimar",
    "intimida": "intimidar",
    "intimidada": "intimidar",
    "intimidadas": "intimidar",
    "intimidades": "intimidade",
    "intimidado": "intimidar",
    "intimidadora": "intimidador",
    "intimidadoras": "intimidador",
    "intimidadores": "intimidador",
    "intimidados": "intimidar",
    "intimidadíssima": "intimidado",
    "intimidadíssimas": "intimidado",
    "intimidadíssimo": "intimidado",
    "intimidadíssimos": "intimidado",
    "intimidai": "intimidar",
    "intimidais": "intimidar",
    "intimidam": "intimidar",
    "intimidamo": "intimidar",
    "intimidamos": "intimidar",
    "intimidando": "intimidar",
    "intimidantes": "intimidante",
    "intimidara": "intimidar",
    "intimidaram": "intimidar",
    "intimidaras": "intimidar",
    "intimidarde": "intimidar",
    "intimidardes": "intimidar",
    "intimidare": "intimidar",
    "intimidarei": "intimidar",
    "intimidareis": "intimidar",
    "intimidarem": "intimidar",
    "intimidaremos": "intimidar",
    "intimidares": "intimidar",
    "intimidaria": "intimidar",
    "intimidariam": "intimidar",
    "intimidarias": "intimidar",
    "intimidarmo": "intimidar",
    "intimidarmos": "intimidar",
    "intimidará": "intimidar",
    "intimidarás": "intimidar",
    "intimidarão": "intimidar",
    "intimidaríamos": "intimidar",
    "intimidaríeis": "intimidar",
    "intimidas": "intimidar",
    "intimidasse": "intimidar",
    "intimidassem": "intimidar",
    "intimidasses": "intimidar",
    "intimidaste": "intimidar",
    "intimidastes": "intimidar",
    "intimidativa": "intimidativo",
    "intimidativas": "intimidativo",
    "intimidativos": "intimidativo",
    "intimidatória": "intimidatório",
    "intimidatórias": "intimidatório",
    "intimidatórios": "intimidatório",
    "intimidava": "intimidar",
    "intimidavam": "intimidar",
    "intimidavas": "intimidar",
    "intimidações": "intimidação",
    "intimide": "intimidar",
    "intimidei": "intimidar",
    "intimideis": "intimidar",
    "intimidem": "intimidar",
    "intimidemo": "intimidar",
    "intimidemos": "intimidar",
    "intimides": "intimidar",
    "intimido": "intimidar",
    "intimidou": "intimidar",
    "intimidá": "intimidar",
    "intimidámo": "intimidar",
    "intimidámos": "intimidar",
    "intimidáramo": "intimidar",
    "intimidáramos": "intimidar",
    "intimidárei": "intimidar",
    "intimidáreis": "intimidar",
    "intimidásseis": "intimidar",
    "intimidássemos": "intimidar",
    "intimidávamo": "intimidar",
    "intimidávamos": "intimidar",
    "intimidávei": "intimidar",
    "intimidáveis": "intimidável",
    "intimismos": "intimismo",
    "intimistas": "intimista",
    "intimo": "intimar",
    "intimorata": "intimorato",
    "intimoratas": "intimorato",
    "intimoratos": "intimorato",
    "intimou": "intimar",
    "intimá": "intimar",
    "intimámo": "intimar",
    "intimámos": "intimar",
    "intimáramo": "intimar",
    "intimáramos": "intimar",
    "intimárei": "intimar",
    "intimáreis": "intimar",
    "intimásseis": "intimar",
    "intimássemos": "intimar",
    "intimávamo": "intimar",
    "intimávamos": "intimar",
    "intimávei": "intimar",
    "intimáveis": "intimável",
    "intinas": "intina",
    "intinções": "intinção",
    "intique": "inticar",
    "intiquei": "inticar",
    "intiqueis": "inticar",
    "intiquem": "inticar",
    "intiquemos": "inticar",
    "intiques": "inticar",
    "intis": "inti",
    "intitula": "intitular",
    "intitulada": "intitular",
    "intituladas": "intitular",
    "intitulado": "intitular",
    "intitulados": "intitular",
    "intitulai": "intitular",
    "intitulais": "intitular",
    "intitulam": "intitular",
    "intitulamentos": "intitulamento",
    "intitulamo": "intitular",
    "intitulamos": "intitular",
    "intitulando": "intitular",
    "intitulara": "intitular",
    "intitularam": "intitular",
    "intitularas": "intitular",
    "intitularde": "intitular",
    "intitulardes": "intitular",
    "intitulare": "intitular",
    "intitularei": "intitular",
    "intitulareis": "intitular",
    "intitularem": "intitular",
    "intitularemos": "intitular",
    "intitulares": "intitular",
    "intitularia": "intitular",
    "intitulariam": "intitular",
    "intitularias": "intitular",
    "intitularmo": "intitular",
    "intitularmos": "intitular",
    "intitulará": "intitular",
    "intitularás": "intitular",
    "intitularão": "intitular",
    "intitularíamos": "intitular",
    "intitularíeis": "intitular",
    "intitulas": "intitular",
    "intitulasse": "intitular",
    "intitulassem": "intitular",
    "intitulasses": "intitular",
    "intitulaste": "intitular",
    "intitulastes": "intitular",
    "intitulava": "intitular",
    "intitulavam": "intitular",
    "intitulavas": "intitular",
    "intitulações": "intitulação",
    "intitule": "intitular",
    "intitulei": "intitular",
    "intituleis": "intitular",
    "intitulem": "intitular",
    "intitulemo": "intitular",
    "intitulemos": "intitular",
    "intitules": "intitular",
    "intitulo": "intitular",
    "intitulou": "intitular",
    "intitulá": "intitular",
    "intitulámo": "intitular",
    "intitulámos": "intitular",
    "intituláramo": "intitular",
    "intituláramos": "intitular",
    "intitulárei": "intitular",
    "intituláreis": "intitular",
    "intitulásseis": "intitular",
    "intitulássemos": "intitular",
    "intitulávamo": "intitular",
    "intitulávamos": "intitular",
    "intitulávei": "intitular",
    "intituláveis": "intitular",
    "intocada": "intocado",
    "intocadas": "intocado",
    "intocados": "intocado",
    "intocáveis": "intocável",
    "intolerabilidades": "intolerabilidade",
    "intolerantes": "intolerante",
    "intolerantismos": "intolerantismo",
    "intoleráveis": "intolerável",
    "intolerâncias": "intolerância",
    "intonações": "intonação",
    "intonsa": "intonso",
    "intonsas": "intonso",
    "intonsos": "intonso",
    "intoxica": "intoxicar",
    "intoxicada": "intoxicar",
    "intoxicadas": "intoxicar",
    "intoxicado": "intoxicar",
    "intoxicados": "intoxicar",
    "intoxicai": "intoxicar",
    "intoxicais": "intoxicar",
    "intoxicam": "intoxicar",
    "intoxicamentos": "intoxicamento",
    "intoxicamo": "intoxicar",
    "intoxicamos": "intoxicar",
    "intoxicando": "intoxicar",
    "intoxicara": "intoxicar",
    "intoxicaram": "intoxicar",
    "intoxicaras": "intoxicar",
    "intoxicarde": "intoxicar",
    "intoxicardes": "intoxicar",
    "intoxicare": "intoxicar",
    "intoxicarei": "intoxicar",
    "intoxicareis": "intoxicar",
    "intoxicarem": "intoxicar",
    "intoxicaremos": "intoxicar",
    "intoxicares": "intoxicar",
    "intoxicaria": "intoxicar",
    "intoxicariam": "intoxicar",
    "intoxicarias": "intoxicar",
    "intoxicarmo": "intoxicar",
    "intoxicarmos": "intoxicar",
    "intoxicará": "intoxicar",
    "intoxicarás": "intoxicar",
    "intoxicarão": "intoxicar",
    "intoxicaríamos": "intoxicar",
    "intoxicaríeis": "intoxicar",
    "intoxicas": "intoxicar",
    "intoxicasse": "intoxicar",
    "intoxicassem": "intoxicar",
    "intoxicasses": "intoxicar",
    "intoxicaste": "intoxicar",
    "intoxicastes": "intoxicar",
    "intoxicava": "intoxicar",
    "intoxicavam": "intoxicar",
    "intoxicavas": "intoxicar",
    "intoxicações": "intoxicação",
    "intoxico": "intoxicar",
    "intoxicou": "intoxicar",
    "intoxicá": "intoxicar",
    "intoxicámo": "intoxicar",
    "intoxicámos": "intoxicar",
    "intoxicáramo": "intoxicar",
    "intoxicáramos": "intoxicar",
    "intoxicárei": "intoxicar",
    "intoxicáreis": "intoxicar",
    "intoxicásseis": "intoxicar",
    "intoxicássemos": "intoxicar",
    "intoxicávamo": "intoxicar",
    "intoxicávamos": "intoxicar",
    "intoxicávei": "intoxicar",
    "intoxicáveis": "intoxicável",
    "intoxique": "intoxicar",
    "intoxiquei": "intoxicar",
    "intoxiqueis": "intoxicar",
    "intoxiquem": "intoxicar",
    "intoxiquemo": "intoxicar",
    "intoxiquemos": "intoxicar",
    "intoxiques": "intoxicar",
    "intracelulares": "intracelular",
    "intracomunitária": "intracomunitário",
    "intracomunitárias": "intracomunitário",
    "intracomunitários": "intracomunitário",
    "intradorsa": "intradorso",
    "intradorsas": "intradorso",
    "intradorsos": "intradorso",
    "intraduzíveis": "intraduzível",
    "intradérmica": "intradérmico",
    "intradérmicas": "intradérmico",
    "intradérmicos": "intradérmico",
    "intragáveis": "intragável",
    "intramusculares": "intramuscular",
    "intranquila": "intranquilo",
    "intranquilas": "intranquilo",
    "intranquilidades": "intranquilidade",
    "intranquilos": "intranquilo",
    "intransferências": "intransferência",
    "intransferíveis": "intransferível",
    "intransigentes": "intransigente",
    "intransigências": "intransigência",
    "intransitabilidades": "intransitabilidade",
    "intransitada": "intransitado",
    "intransitadas": "intransitado",
    "intransitados": "intransitado",
    "intransitiva": "intransitivo",
    "intransitivas": "intransitivo",
    "intransitivos": "intransitivo",
    "intransitáveis": "intransitável",
    "intransmissibilidades": "intransmissibilidade",
    "intransmissíveis": "intransmissível",
    "intransparentes": "intransparente",
    "intransponíveis": "intransponível",
    "intransportáveis": "intransportável",
    "intrapulmonares": "intrapulmonar",
    "intratabilidades": "intratabilidade",
    "intratelúrica": "intratelúrico",
    "intratelúricas": "intratelúrico",
    "intratelúricos": "intratelúrico",
    "intratorácica": "intratorácico",
    "intratorácicas": "intratorácico",
    "intratorácicos": "intratorácico",
    "intratáveis": "intratável",
    "intravasculares": "intravascular",
    "intravenosa": "intravenoso",
    "intravenosas": "intravenoso",
    "intravenosos": "intravenoso",
    "intraversões": "intraversão",
    "intravertebrada": "intravertebrado",
    "intravertebradas": "intravertebrado",
    "intravertebrados": "intravertebrado",
    "intravertida": "intravertido",
    "intravertidas": "intravertido",
    "intravertidos": "intravertido",
    "intraváveis": "intravável",
    "intrepida": "intrepido",
    "intrepidas": "intrepido",
    "intrepidos": "intrepido",
    "intrica": "intricar",
    "intricada": "intricar",
    "intricadas": "intricar",
    "intricado": "intricar",
    "intricados": "intricar",
    "intricai": "intricar",
    "intricais": "intricar",
    "intricam": "intricar",
    "intricamo": "intricar",
    "intricamos": "intricar",
    "intricando": "intricar",
    "intricara": "intricar",
    "intricaram": "intricar",
    "intricaras": "intricar",
    "intricarde": "intricar",
    "intricardes": "intricar",
    "intricare": "intricar",
    "intricarei": "intricar",
    "intricareis": "intricar",
    "intricarem": "intricar",
    "intricaremos": "intricar",
    "intricares": "intricar",
    "intricaria": "intricar",
    "intricariam": "intricar",
    "intricarias": "intricar",
    "intricarmo": "intricar",
    "intricarmos": "intricar",
    "intricará": "intricar",
    "intricarás": "intricar",
    "intricarão": "intricar",
    "intricaríamos": "intricar",
    "intricaríeis": "intricar",
    "intricas": "intricar",
    "intricasse": "intricar",
    "intricassem": "intricar",
    "intricasses": "intricar",
    "intricaste": "intricar",
    "intricastes": "intricar",
    "intricava": "intricar",
    "intricavam": "intricar",
    "intricavas": "intricar",
    "intrico": "intricar",
    "intricou": "intricar",
    "intricá": "intricar",
    "intricámo": "intricar",
    "intricámos": "intricar",
    "intricáramo": "intricar",
    "intricáramos": "intricar",
    "intricárei": "intricar",
    "intricáreis": "intricar",
    "intricásseis": "intricar",
    "intricássemos": "intricar",
    "intricávamo": "intricar",
    "intricávamos": "intricar",
    "intricávei": "intricar",
    "intricáveis": "intricar",
    "intriga": "intrigar",
    "intrigada": "intrigar",
    "intrigadas": "intrigar",
    "intrigado": "intrigar",
    "intrigados": "intrigar",
    "intrigadíssima": "intrigado",
    "intrigadíssimas": "intrigado",
    "intrigadíssimo": "intrigado",
    "intrigadíssimos": "intrigado",
    "intrigai": "intrigar",
    "intrigais": "intrigar",
    "intrigalhadas": "intrigalhada",
    "intrigam": "intrigar",
    "intrigamo": "intrigar",
    "intrigamos": "intrigar",
    "intrigando": "intrigar",
    "intrigantes": "intrigante",
    "intrigara": "intrigar",
    "intrigaram": "intrigar",
    "intrigaras": "intrigar",
    "intrigardes": "intrigar",
    "intrigarei": "intrigar",
    "intrigareis": "intrigar",
    "intrigarem": "intrigar",
    "intrigaremos": "intrigar",
    "intrigares": "intrigar",
    "intrigaria": "intrigar",
    "intrigariam": "intrigar",
    "intrigarias": "intrigar",
    "intrigarmo": "intrigar",
    "intrigarmos": "intrigar",
    "intrigará": "intrigar",
    "intrigarás": "intrigar",
    "intrigarão": "intrigar",
    "intrigaríamos": "intrigar",
    "intrigaríeis": "intrigar",
    "intrigas": "intrigar",
    "intrigasse": "intrigar",
    "intrigassem": "intrigar",
    "intrigasses": "intrigar",
    "intrigaste": "intrigar",
    "intrigastes": "intrigar",
    "intrigava": "intrigar",
    "intrigavam": "intrigar",
    "intrigavas": "intrigar",
    "intrigo": "intrigar",
    "intrigou": "intrigar",
    "intrigue": "intrigar",
    "intriguei": "intrigar",
    "intrigueis": "intrigar",
    "intriguem": "intrigar",
    "intriguemo": "intrigar",
    "intriguemos": "intrigar",
    "intrigues": "intrigar",
    "intriguistas": "intriguista",
    "intrigámo": "intrigar",
    "intrigámos": "intrigar",
    "intrigáramo": "intrigar",
    "intrigáramos": "intrigar",
    "intrigáreis": "intrigar",
    "intrigásseis": "intrigar",
    "intrigássemos": "intrigar",
    "intrigávamo": "intrigar",
    "intrigávamos": "intrigar",
    "intrigáveis": "intrigar",
    "intrinca": "intrincar",
    "intrincada": "intrincar",
    "intrincadas": "intrincar",
    "intrincado": "intrincar",
    "intrincados": "intrincar",
    "intrincai": "intrincar",
    "intrincais": "intrincar",
    "intrincam": "intrincar",
    "intrincamo": "intrincar",
    "intrincamos": "intrincar",
    "intrincando": "intrincar",
    "intrincara": "intrincar",
    "intrincaram": "intrincar",
    "intrincaras": "intrincar",
    "intrincarde": "intrincar",
    "intrincardes": "intrincar",
    "intrincare": "intrincar",
    "intrincarei": "intrincar",
    "intrincareis": "intrincar",
    "intrincarem": "intrincar",
    "intrincaremos": "intrincar",
    "intrincares": "intrincar",
    "intrincaria": "intrincar",
    "intrincariam": "intrincar",
    "intrincarias": "intrincar",
    "intrincarmo": "intrincar",
    "intrincarmos": "intrincar",
    "intrincará": "intrincar",
    "intrincarás": "intrincar",
    "intrincarão": "intrincar",
    "intrincaríamos": "intrincar",
    "intrincaríeis": "intrincar",
    "intrincas": "intrincar",
    "intrincasse": "intrincar",
    "intrincassem": "intrincar",
    "intrincasses": "intrincar",
    "intrincaste": "intrincar",
    "intrincastes": "intrincar",
    "intrincava": "intrincar",
    "intrincavam": "intrincar",
    "intrincavas": "intrincar",
    "intrinco": "intrincar",
    "intrincou": "intrincar",
    "intrincá": "intrincar",
    "intrincámo": "intrincar",
    "intrincámos": "intrincar",
    "intrincáramo": "intrincar",
    "intrincáramos": "intrincar",
    "intrincárei": "intrincar",
    "intrincáreis": "intrincar",
    "intrincásseis": "intrincar",
    "intrincássemos": "intrincar",
    "intrincávamo": "intrincar",
    "intrincávamos": "intrincar",
    "intrincávei": "intrincar",
    "intrincáveis": "intrincável",
    "intrinque": "intrincar",
    "intrinquei": "intrincar",
    "intrinqueis": "intrincar",
    "intrinquem": "intrincar",
    "intrinquemo": "intrincar",
    "intrinquemos": "intrincar",
    "intrinques": "intrincar",
    "intrique": "intricar",
    "intriquei": "intricar",
    "intriqueis": "intricar",
    "intriquem": "intricar",
    "intriquemo": "intricar",
    "intriquemos": "intricar",
    "intriques": "intricar",
    "introdutiva": "introdutivo",
    "introdutivas": "introdutivo",
    "introdutivos": "introdutivo",
    "introdutora": "introdutor",
    "introdutoras": "introdutor",
    "introdutores": "introdutor",
    "introdutória": "introdutório",
    "introdutórias": "introdutório",
    "introdutórios": "introdutório",
    "introduz": "introduzir",
    "introduza": "introduzir",
    "introduzais": "introduzir",
    "introduzam": "introduzir",
    "introduzamo": "introduzir",
    "introduzamos": "introduzir",
    "introduzas": "introduzir",
    "introduze": "introduzir",
    "introduzem": "introduzir",
    "introduzes": "introduzir",
    "introduzi": "introduzir",
    "introduzia": "introduzir",
    "introduziam": "introduzir",
    "introduzias": "introduzir",
    "introduzida": "introduzir",
    "introduzidas": "introduzir",
    "introduzido": "introduzir",
    "introduzidos": "introduzir",
    "introduzimo": "introduzir",
    "introduzimos": "introduzir",
    "introduzindo": "introduzir",
    "introduzira": "introduzir",
    "introduziram": "introduzir",
    "introduziras": "introduzir",
    "introduzirde": "introduzir",
    "introduzirdes": "introduzir",
    "introduzire": "introduzir",
    "introduzirei": "introduzir",
    "introduzireis": "introduzir",
    "introduzirem": "introduzir",
    "introduziremos": "introduzir",
    "introduzires": "introduzir",
    "introduziria": "introduzir",
    "introduziriam": "introduzir",
    "introduzirias": "introduzir",
    "introduzirmo": "introduzir",
    "introduzirmos": "introduzir",
    "introduzirá": "introduzir",
    "introduzirás": "introduzir",
    "introduzirão": "introduzir",
    "introduziríamos": "introduzir",
    "introduziríeis": "introduzir",
    "introduzis": "introduzir",
    "introduzisse": "introduzir",
    "introduzissem": "introduzir",
    "introduzisses": "introduzir",
    "introduziste": "introduzir",
    "introduzistes": "introduzir",
    "introduziu": "introduzir",
    "introduzo": "introduzir",
    "introduzíamo": "introduzir",
    "introduzíamos": "introduzir",
    "introduzíei": "introduzir",
    "introduzíeis": "introduzir",
    "introduzíramo": "introduzir",
    "introduzíramos": "introduzir",
    "introduzírei": "introduzir",
    "introduzíreis": "introduzir",
    "introduzísseis": "introduzir",
    "introduzíssemos": "introduzir",
    "introduzíveis": "introduzível",
    "introduções": "introdução",
    "introjecções": "introjecção",
    "intrometa": "intrometer",
    "intrometais": "intrometer",
    "intrometam": "intrometer",
    "intrometamo": "intrometer",
    "intrometamos": "intrometer",
    "intrometas": "intrometer",
    "intromete": "intrometer",
    "intrometediça": "intrometediço",
    "intrometediças": "intrometediço",
    "intrometediços": "intrometediço",
    "intrometei": "intrometer",
    "intrometeis": "intrometer",
    "intrometem": "intrometer",
    "intrometemo": "intrometer",
    "intrometemos": "intrometer",
    "intrometendo": "intrometer",
    "intrometera": "intrometer",
    "intrometeram": "intrometer",
    "intrometeras": "intrometer",
    "intrometerde": "intrometer",
    "intrometerdes": "intrometer",
    "intrometere": "intrometer",
    "intrometerei": "intrometer",
    "intrometereis": "intrometer",
    "intrometerem": "intrometer",
    "intrometeremos": "intrometer",
    "intrometeres": "intrometer",
    "intrometeria": "intrometer",
    "intrometeriam": "intrometer",
    "intrometerias": "intrometer",
    "intrometermo": "intrometer",
    "intrometermos": "intrometer",
    "intrometerá": "intrometer",
    "intrometerás": "intrometer",
    "intrometerão": "intrometer",
    "intrometeríamos": "intrometer",
    "intrometeríeis": "intrometer",
    "intrometes": "intrometer",
    "intrometesse": "intrometer",
    "intrometessem": "intrometer",
    "intrometesses": "intrometer",
    "intrometeste": "intrometer",
    "intrometestes": "intrometer",
    "intrometeu": "intrometer",
    "intrometi": "intrometer",
    "intrometia": "intrometer",
    "intrometiam": "intrometer",
    "intrometias": "intrometer",
    "intrometida": "intrometido",
    "intrometidas": "intrometido",
    "intrometidiça": "intrometidiço",
    "intrometidiças": "intrometidiço",
    "intrometidiços": "intrometidiço",
    "intrometido": "intrometer",
    "intrometidos": "intrometido",
    "intrometimentos": "intrometimento",
    "intrometo": "intrometer",
    "intrometê": "intrometer",
    "intrometêramo": "intrometer",
    "intrometêramos": "intrometer",
    "intrometêrei": "intrometer",
    "intrometêreis": "intrometer",
    "intrometêsseis": "intrometer",
    "intrometêssemos": "intrometer",
    "intrometíamo": "intrometer",
    "intrometíamos": "intrometer",
    "intrometíei": "intrometer",
    "intrometíeis": "intrometer",
    "intromissões": "intromissão",
    "introrsa": "introrso",
    "introrsada": "introrsar",
    "introrsadas": "introrsar",
    "introrsado": "introrsar",
    "introrsados": "introrsar",
    "introrsai": "introrsar",
    "introrsais": "introrsar",
    "introrsam": "introrsar",
    "introrsamo": "introrsar",
    "introrsamos": "introrsar",
    "introrsando": "introrsar",
    "introrsara": "introrsar",
    "introrsaram": "introrsar",
    "introrsaras": "introrsar",
    "introrsarde": "introrsar",
    "introrsardes": "introrsar",
    "introrsare": "introrsar",
    "introrsarei": "introrsar",
    "introrsareis": "introrsar",
    "introrsarem": "introrsar",
    "introrsaremos": "introrsar",
    "introrsares": "introrsar",
    "introrsaria": "introrsar",
    "introrsariam": "introrsar",
    "introrsarias": "introrsar",
    "introrsarmo": "introrsar",
    "introrsarmos": "introrsar",
    "introrsará": "introrsar",
    "introrsarás": "introrsar",
    "introrsarão": "introrsar",
    "introrsaríamos": "introrsar",
    "introrsaríeis": "introrsar",
    "introrsas": "introrso",
    "introrsasse": "introrsar",
    "introrsassem": "introrsar",
    "introrsasses": "introrsar",
    "introrsaste": "introrsar",
    "introrsastes": "introrsar",
    "introrsava": "introrsar",
    "introrsavam": "introrsar",
    "introrsavas": "introrsar",
    "introrse": "introrsar",
    "introrsei": "introrsar",
    "introrseis": "introrsar",
    "introrsem": "introrsar",
    "introrsemo": "introrsar",
    "introrsemos": "introrsar",
    "introrses": "introrsar",
    "introrso": "introrsar",
    "introrsos": "introrso",
    "introrsou": "introrsar",
    "introrsá": "introrsar",
    "introrsámo": "introrsar",
    "introrsámos": "introrsar",
    "introrsáramo": "introrsar",
    "introrsáramos": "introrsar",
    "introrsárei": "introrsar",
    "introrsáreis": "introrsar",
    "introrsásseis": "introrsar",
    "introrsássemos": "introrsar",
    "introrsávamo": "introrsar",
    "introrsávamos": "introrsar",
    "introrsávei": "introrsar",
    "introrsáveis": "introrsar",
    "introscas": "introsca",
    "introspectiva": "introspectivo",
    "introspectivas": "introspectivo",
    "introspectividades": "introspectividade",
    "introspectivos": "introspectivo",
    "introspecções": "introspecção",
    "introversa": "introverso",
    "introversas": "introverso",
    "introversos": "introverso",
    "introversões": "introversão",
    "introverta": "introverter",
    "introvertais": "introverter",
    "introvertam": "introverter",
    "introvertamo": "introverter",
    "introvertamos": "introverter",
    "introvertas": "introverter",
    "introverte": "introverter",
    "introvertei": "introverter",
    "introverteis": "introverter",
    "introvertem": "introverter",
    "introvertemo": "introverter",
    "introvertemos": "introverter",
    "introvertendo": "introverter",
    "introvertera": "introverter",
    "introverteram": "introverter",
    "introverteras": "introverter",
    "introverterdes": "introverter",
    "introverterei": "introverter",
    "introvertereis": "introverter",
    "introverterem": "introverter",
    "introverteremos": "introverter",
    "introverteres": "introverter",
    "introverteria": "introverter",
    "introverteriam": "introverter",
    "introverterias": "introverter",
    "introvertermo": "introverter",
    "introvertermos": "introverter",
    "introverterá": "introverter",
    "introverterás": "introverter",
    "introverterão": "introverter",
    "introverteríamos": "introverter",
    "introverteríeis": "introverter",
    "introvertes": "introverter",
    "introvertesse": "introverter",
    "introvertessem": "introverter",
    "introvertesses": "introverter",
    "introverteste": "introverter",
    "introvertestes": "introverter",
    "introverteu": "introverter",
    "introverti": "introverter",
    "introvertia": "introverter",
    "introvertiam": "introverter",
    "introvertias": "introverter",
    "introvertida": "introvertido",
    "introvertidas": "introvertido",
    "introvertido": "introverter",
    "introvertidos": "introvertido",
    "introverto": "introverter",
    "introvertêramo": "introverter",
    "introvertêramos": "introverter",
    "introvertêreis": "introverter",
    "introvertêsseis": "introverter",
    "introvertêssemos": "introverter",
    "introvertíamo": "introverter",
    "introvertíamos": "introverter",
    "introvertíeis": "introverter",
    "introvertíveis": "introvertível",
    "intruja": "intrujar",
    "intrujada": "intrujar",
    "intrujadas": "intrujar",
    "intrujado": "intrujar",
    "intrujados": "intrujar",
    "intrujadíssima": "intrujado",
    "intrujadíssimas": "intrujado",
    "intrujadíssimo": "intrujado",
    "intrujadíssimos": "intrujado",
    "intrujai": "intrujar",
    "intrujais": "intrujar",
    "intrujam": "intrujar",
    "intrujamo": "intrujar",
    "intrujamos": "intrujar",
    "intrujando": "intrujar",
    "intrujara": "intrujar",
    "intrujaram": "intrujar",
    "intrujaras": "intrujar",
    "intrujarde": "intrujar",
    "intrujardes": "intrujar",
    "intrujare": "intrujar",
    "intrujarei": "intrujar",
    "intrujareis": "intrujar",
    "intrujarem": "intrujar",
    "intrujaremos": "intrujar",
    "intrujares": "intrujar",
    "intrujaria": "intrujar",
    "intrujariam": "intrujar",
    "intrujarias": "intrujar",
    "intrujarmo": "intrujar",
    "intrujarmos": "intrujar",
    "intrujará": "intrujar",
    "intrujarás": "intrujar",
    "intrujarão": "intrujar",
    "intrujaríamos": "intrujar",
    "intrujaríeis": "intrujar",
    "intrujas": "intrujar",
    "intrujasse": "intrujar",
    "intrujassem": "intrujar",
    "intrujasses": "intrujar",
    "intrujaste": "intrujar",
    "intrujastes": "intrujar",
    "intrujava": "intrujar",
    "intrujavam": "intrujar",
    "intrujavas": "intrujar",
    "intruje": "intrujar",
    "intrujei": "intrujar",
    "intrujeis": "intrujar",
    "intrujem": "intrujar",
    "intrujemo": "intrujar",
    "intrujemos": "intrujar",
    "intrujes": "intrujar",
    "intrujices": "intrujice",
    "intrujo": "intrujar",
    "intrujona": "intrujão",
    "intrujonas": "intrujão",
    "intrujou": "intrujar",
    "intrujá": "intrujar",
    "intrujámo": "intrujar",
    "intrujámos": "intrujar",
    "intrujáramo": "intrujar",
    "intrujáramos": "intrujar",
    "intrujárei": "intrujar",
    "intrujáreis": "intrujar",
    "intrujásseis": "intrujar",
    "intrujássemos": "intrujar",
    "intrujávamo": "intrujar",
    "intrujávamos": "intrujar",
    "intrujávei": "intrujar",
    "intrujáveis": "intrujável",
    "intrujões": "intrujão",
    "intrusa": "intruso",
    "intrusas": "intruso",
    "intrusos": "intruso",
    "intrusões": "intrusão",
    "intrépida": "intrépido",
    "intrépidas": "intrépido",
    "intrépidos": "intrépido",
    "intrínseca": "intrínseco",
    "intrínsecas": "intrínseco",
    "intrínsecos": "intrínseco",
    "intróitos": "intróito",
    "intua": "intuir",
    "intuais": "intuir",
    "intuam": "intuir",
    "intuamo": "intuir",
    "intuamos": "intuir",
    "intuas": "intuir",
    "intuem": "intuir",
    "intui": "intuir",
    "intuicionismos": "intuicionismo",
    "intuindo": "intuir",
    "intuirde": "intuir",
    "intuirdes": "intuir",
    "intuirei": "intuir",
    "intuireis": "intuir",
    "intuiremos": "intuir",
    "intuiria": "intuir",
    "intuiriam": "intuir",
    "intuirias": "intuir",
    "intuirmo": "intuir",
    "intuirmos": "intuir",
    "intuirá": "intuir",
    "intuirás": "intuir",
    "intuirão": "intuir",
    "intuiríamos": "intuir",
    "intuiríeis": "intuir",
    "intuis": "intuir",
    "intuitiva": "intuitivo",
    "intuitivas": "intuitivo",
    "intuitivismos": "intuitivismo",
    "intuitivos": "intuitivo",
    "intuitos": "intuito",
    "intuiu": "intuir",
    "intuições": "intuição",
    "intumesce": "intumescer",
    "intumescei": "intumescer",
    "intumesceis": "intumescer",
    "intumescem": "intumescer",
    "intumescemo": "intumescer",
    "intumescemos": "intumescer",
    "intumescendo": "intumescer",
    "intumescentes": "intumescente",
    "intumescera": "intumescer",
    "intumesceram": "intumescer",
    "intumesceras": "intumescer",
    "intumescerdes": "intumescer",
    "intumescerei": "intumescer",
    "intumescereis": "intumescer",
    "intumescerem": "intumescer",
    "intumesceremos": "intumescer",
    "intumesceres": "intumescer",
    "intumesceria": "intumescer",
    "intumesceriam": "intumescer",
    "intumescerias": "intumescer",
    "intumescermo": "intumescer",
    "intumescermos": "intumescer",
    "intumescerá": "intumescer",
    "intumescerás": "intumescer",
    "intumescerão": "intumescer",
    "intumesceríamos": "intumescer",
    "intumesceríeis": "intumescer",
    "intumesces": "intumescer",
    "intumescesse": "intumescer",
    "intumescessem": "intumescer",
    "intumescesses": "intumescer",
    "intumesceste": "intumescer",
    "intumescestes": "intumescer",
    "intumesceu": "intumescer",
    "intumesci": "intumescer",
    "intumescia": "intumescer",
    "intumesciam": "intumescer",
    "intumescias": "intumescer",
    "intumescida": "intumescer",
    "intumescidas": "intumescer",
    "intumescido": "intumescer",
    "intumescidos": "intumescer",
    "intumescimentos": "intumescimento",
    "intumescências": "intumescência",
    "intumescêramo": "intumescer",
    "intumescêramos": "intumescer",
    "intumescêreis": "intumescer",
    "intumescêsseis": "intumescer",
    "intumescêssemos": "intumescer",
    "intumescíamo": "intumescer",
    "intumescíamos": "intumescer",
    "intumescíeis": "intumescer",
    "intumesça": "intumescer",
    "intumesçais": "intumescer",
    "intumesçam": "intumescer",
    "intumesçamo": "intumescer",
    "intumesçamos": "intumescer",
    "intumesças": "intumescer",
    "intumesço": "intumescer",
    "intuo": "intuir",
    "inturgesce": "inturgescer",
    "inturgescei": "inturgescer",
    "inturgesceis": "inturgescer",
    "inturgescem": "inturgescer",
    "inturgescemo": "inturgescer",
    "inturgescemos": "inturgescer",
    "inturgescendo": "inturgescer",
    "inturgescentes": "inturgescente",
    "inturgescera": "inturgescer",
    "inturgesceram": "inturgescer",
    "inturgesceras": "inturgescer",
    "inturgescerdes": "inturgescer",
    "inturgescerei": "inturgescer",
    "inturgescereis": "inturgescer",
    "inturgescerem": "inturgescer",
    "inturgesceremos": "inturgescer",
    "inturgesceres": "inturgescer",
    "inturgesceria": "inturgescer",
    "inturgesceriam": "inturgescer",
    "inturgescerias": "inturgescer",
    "inturgescermo": "inturgescer",
    "inturgescermos": "inturgescer",
    "inturgescerá": "inturgescer",
    "inturgescerás": "inturgescer",
    "inturgescerão": "inturgescer",
    "inturgesceríamos": "inturgescer",
    "inturgesceríeis": "inturgescer",
    "inturgesces": "inturgescer",
    "inturgescesse": "inturgescer",
    "inturgescessem": "inturgescer",
    "inturgescesses": "inturgescer",
    "inturgesceste": "inturgescer",
    "inturgescestes": "inturgescer",
    "inturgesceu": "inturgescer",
    "inturgesci": "inturgescer",
    "inturgescia": "inturgescer",
    "inturgesciam": "inturgescer",
    "inturgescias": "inturgescer",
    "inturgescida": "inturgescer",
    "inturgescidas": "inturgescer",
    "inturgescido": "inturgescer",
    "inturgescidos": "inturgescer",
    "inturgescências": "inturgescência",
    "inturgescêramo": "inturgescer",
    "inturgescêramos": "inturgescer",
    "inturgescêreis": "inturgescer",
    "inturgescêsseis": "inturgescer",
    "inturgescêssemos": "inturgescer",
    "inturgescíamo": "inturgescer",
    "inturgescíamos": "inturgescer",
    "inturgescíeis": "inturgescer",
    "inturgesça": "inturgescer",
    "inturgesçais": "inturgescer",
    "inturgesçam": "inturgescer",
    "inturgesçamo": "inturgescer",
    "inturgesçamos": "inturgescer",
    "inturgesças": "inturgescer",
    "inturgesço": "inturgescer",
    "intuspectiva": "intuspectivo",
    "intuspectivas": "intuspectivo",
    "intuspectivos": "intuspectivo",
    "intuspecções": "intuspecção",
    "intussuscepções": "intussuscepção",
    "intuí": "intuir",
    "intuía": "intuir",
    "intuíam": "intuir",
    "intuíamo": "intuir",
    "intuíamos": "intuir",
    "intuías": "intuir",
    "intuída": "intuir",
    "intuídas": "intuir",
    "intuído": "intuir",
    "intuídos": "intuir",
    "intuíei": "intuir",
    "intuíeis": "intuir",
    "intuímo": "intuir",
    "intuímos": "intuir",
    "intuíra": "intuir",
    "intuíram": "intuir",
    "intuíramo": "intuir",
    "intuíramos": "intuir",
    "intuíras": "intuir",
    "intuíre": "intuir",
    "intuírei": "intuir",
    "intuíreis": "intuir",
    "intuírem": "intuir",
    "intuíres": "intuir",
    "intuís": "intuir",
    "intuísse": "intuir",
    "intuísseis": "intuir",
    "intuíssem": "intuir",
    "intuíssemos": "intuir",
    "intuísses": "intuir",
    "intuíste": "intuir",
    "intuístes": "intuir",
    "intátis": "intátil",
    "intérmina": "intérmino",
    "intérminas": "intérmino",
    "intérminos": "intérmino",
    "intérpretes": "intérprete",
    "inulinas": "inulina",
    "inulta": "inulto",
    "inultas": "inulto",
    "inultos": "inulto",
    "inultrapassáveis": "inultrapassável",
    "inuma": "inumar",
    "inumada": "inumar",
    "inumadas": "inumar",
    "inumado": "inumar",
    "inumados": "inumar",
    "inumai": "inumar",
    "inumais": "inumar",
    "inumam": "inumar",
    "inumamo": "inumar",
    "inumamos": "inumar",
    "inumana": "inumano",
    "inumanas": "inumano",
    "inumando": "inumar",
    "inumanidades": "inumanidade",
    "inumanos": "inumano",
    "inumara": "inumar",
    "inumaram": "inumar",
    "inumaras": "inumar",
    "inumarde": "inumar",
    "inumardes": "inumar",
    "inumare": "inumar",
    "inumarei": "inumar",
    "inumareis": "inumar",
    "inumarem": "inumar",
    "inumaremos": "inumar",
    "inumares": "inumar",
    "inumaria": "inumar",
    "inumariam": "inumar",
    "inumarias": "inumar",
    "inumarmo": "inumar",
    "inumarmos": "inumar",
    "inumará": "inumar",
    "inumarás": "inumar",
    "inumarão": "inumar",
    "inumaríamos": "inumar",
    "inumaríeis": "inumar",
    "inumas": "inumar",
    "inumasse": "inumar",
    "inumassem": "inumar",
    "inumasses": "inumar",
    "inumaste": "inumar",
    "inumastes": "inumar",
    "inumava": "inumar",
    "inumavam": "inumar",
    "inumavas": "inumar",
    "inumações": "inumação",
    "inume": "inumar",
    "inumei": "inumar",
    "inumeis": "inumar",
    "inumem": "inumar",
    "inumemo": "inumar",
    "inumemos": "inumar",
    "inumerabilidades": "inumerabilidade",
    "inumerada": "inumerado",
    "inumeradas": "inumerado",
    "inumerados": "inumerado",
    "inumeráveis": "inumerável",
    "inumes": "inumar",
    "inumo": "inumar",
    "inumou": "inumar",
    "inumá": "inumar",
    "inumámo": "inumar",
    "inumámos": "inumar",
    "inumáramo": "inumar",
    "inumáramos": "inumar",
    "inumárei": "inumar",
    "inumáreis": "inumar",
    "inumásseis": "inumar",
    "inumássemos": "inumar",
    "inumávamo": "inumar",
    "inumávamos": "inumar",
    "inumávei": "inumar",
    "inumáveis": "inumável",
    "inunda": "inundar",
    "inundada": "inundar",
    "inundadas": "inundar",
    "inundado": "inundar",
    "inundados": "inundar",
    "inundai": "inundar",
    "inundais": "inundar",
    "inundam": "inundar",
    "inundamo": "inundar",
    "inundamos": "inundar",
    "inundando": "inundar",
    "inundantes": "inundante",
    "inundara": "inundar",
    "inundaram": "inundar",
    "inundaras": "inundar",
    "inundarde": "inundar",
    "inundardes": "inundar",
    "inundare": "inundar",
    "inundarei": "inundar",
    "inundareis": "inundar",
    "inundarem": "inundar",
    "inundaremos": "inundar",
    "inundares": "inundar",
    "inundaria": "inundar",
    "inundariam": "inundar",
    "inundarias": "inundar",
    "inundarmo": "inundar",
    "inundarmos": "inundar",
    "inundará": "inundar",
    "inundarás": "inundar",
    "inundarão": "inundar",
    "inundaríamos": "inundar",
    "inundaríeis": "inundar",
    "inundas": "inundar",
    "inundasse": "inundar",
    "inundassem": "inundar",
    "inundasses": "inundar",
    "inundaste": "inundar",
    "inundastes": "inundar",
    "inundava": "inundar",
    "inundavam": "inundar",
    "inundavas": "inundar",
    "inundações": "inundação",
    "inunde": "inundar",
    "inundei": "inundar",
    "inundeis": "inundar",
    "inundem": "inundar",
    "inundemo": "inundar",
    "inundemos": "inundar",
    "inundes": "inundar",
    "inundo": "inundar",
    "inundou": "inundar",
    "inundá": "inundar",
    "inundámo": "inundar",
    "inundámos": "inundar",
    "inundáramo": "inundar",
    "inundáramos": "inundar",
    "inundárei": "inundar",
    "inundáreis": "inundar",
    "inundásseis": "inundar",
    "inundássemos": "inundar",
    "inundávamo": "inundar",
    "inundávamos": "inundar",
    "inundávei": "inundar",
    "inundáveis": "inundável",
    "inupta": "inupto",
    "inuptas": "inupto",
    "inuptos": "inupto",
    "inurbana": "inurbano",
    "inurbanas": "inurbano",
    "inurbanidades": "inurbanidade",
    "inurbanos": "inurbano",
    "inusitada": "inusitado",
    "inusitadas": "inusitado",
    "inusitados": "inusitado",
    "inuteis": "inutil",
    "inutilidades": "inutilidade",
    "inutiliza": "inutilizar",
    "inutilizada": "inutilizar",
    "inutilizadas": "inutilizar",
    "inutilizado": "inutilizar",
    "inutilizados": "inutilizar",
    "inutilizai": "inutilizar",
    "inutilizais": "inutilizar",
    "inutilizam": "inutilizar",
    "inutilizamo": "inutilizar",
    "inutilizamos": "inutilizar",
    "inutilizando": "inutilizar",
    "inutilizara": "inutilizar",
    "inutilizaram": "inutilizar",
    "inutilizaras": "inutilizar",
    "inutilizarde": "inutilizar",
    "inutilizardes": "inutilizar",
    "inutilizare": "inutilizar",
    "inutilizarei": "inutilizar",
    "inutilizareis": "inutilizar",
    "inutilizarem": "inutilizar",
    "inutilizaremos": "inutilizar",
    "inutilizares": "inutilizar",
    "inutilizaria": "inutilizar",
    "inutilizariam": "inutilizar",
    "inutilizarias": "inutilizar",
    "inutilizarmo": "inutilizar",
    "inutilizarmos": "inutilizar",
    "inutilizará": "inutilizar",
    "inutilizarás": "inutilizar",
    "inutilizarão": "inutilizar",
    "inutilizaríamos": "inutilizar",
    "inutilizaríeis": "inutilizar",
    "inutilizas": "inutilizar",
    "inutilizasse": "inutilizar",
    "inutilizassem": "inutilizar",
    "inutilizasses": "inutilizar",
    "inutilizaste": "inutilizar",
    "inutilizastes": "inutilizar",
    "inutilizava": "inutilizar",
    "inutilizavam": "inutilizar",
    "inutilizavas": "inutilizar",
    "inutilizações": "inutilização",
    "inutilize": "inutilizar",
    "inutilizei": "inutilizar",
    "inutilizeis": "inutilizar",
    "inutilizem": "inutilizar",
    "inutilizemo": "inutilizar",
    "inutilizemos": "inutilizar",
    "inutilizes": "inutilizar",
    "inutilizo": "inutilizar",
    "inutilizou": "inutilizar",
    "inutilizá": "inutilizar",
    "inutilizámo": "inutilizar",
    "inutilizámos": "inutilizar",
    "inutilizáramo": "inutilizar",
    "inutilizáramos": "inutilizar",
    "inutilizárei": "inutilizar",
    "inutilizáreis": "inutilizar",
    "inutilizásseis": "inutilizar",
    "inutilizássemos": "inutilizar",
    "inutilizávamo": "inutilizar",
    "inutilizávamos": "inutilizar",
    "inutilizávei": "inutilizar",
    "inutilizáveis": "inutilizável",
    "invada": "invadir",
    "invadais": "invadir",
    "invadam": "invadir",
    "invadamo": "invadir",
    "invadamos": "invadir",
    "invadas": "invadir",
    "invade": "invadir",
    "invadem": "invadir",
    "invades": "invadir",
    "invadeáveis": "invadeável",
    "invadi": "invadir",
    "invadia": "invadir",
    "invadiam": "invadir",
    "invadias": "invadir",
    "invadida": "invadir",
    "invadidas": "invadir",
    "invadido": "invadir",
    "invadidos": "invadir",
    "invadimo": "invadir",
    "invadimos": "invadir",
    "invadindo": "invadir",
    "invadira": "invadir",
    "invadiram": "invadir",
    "invadiras": "invadir",
    "invadirde": "invadir",
    "invadirdes": "invadir",
    "invadire": "invadir",
    "invadirei": "invadir",
    "invadireis": "invadir",
    "invadirem": "invadir",
    "invadiremos": "invadir",
    "invadires": "invadir",
    "invadiria": "invadir",
    "invadiriam": "invadir",
    "invadirias": "invadir",
    "invadirmo": "invadir",
    "invadirmos": "invadir",
    "invadirá": "invadir",
    "invadirás": "invadir",
    "invadirão": "invadir",
    "invadiríamos": "invadir",
    "invadiríeis": "invadir",
    "invadis": "invadir",
    "invadisse": "invadir",
    "invadissem": "invadir",
    "invadisses": "invadir",
    "invadiste": "invadir",
    "invadistes": "invadir",
    "invadiu": "invadir",
    "invado": "invadir",
    "invadíamo": "invadir",
    "invadíamos": "invadir",
    "invadíei": "invadir",
    "invadíeis": "invadir",
    "invadíramo": "invadir",
    "invadíramos": "invadir",
    "invadírei": "invadir",
    "invadíreis": "invadir",
    "invadísseis": "invadir",
    "invadíssemos": "invadir",
    "invagina": "invaginar",
    "invaginada": "invaginar",
    "invaginadas": "invaginar",
    "invaginado": "invaginar",
    "invaginados": "invaginar",
    "invaginai": "invaginar",
    "invaginais": "invaginar",
    "invaginam": "invaginar",
    "invaginamo": "invaginar",
    "invaginamos": "invaginar",
    "invaginando": "invaginar",
    "invaginantes": "invaginante",
    "invaginara": "invaginar",
    "invaginaram": "invaginar",
    "invaginaras": "invaginar",
    "invaginarde": "invaginar",
    "invaginardes": "invaginar",
    "invaginare": "invaginar",
    "invaginarei": "invaginar",
    "invaginareis": "invaginar",
    "invaginarem": "invaginar",
    "invaginaremos": "invaginar",
    "invaginares": "invaginar",
    "invaginaria": "invaginar",
    "invaginariam": "invaginar",
    "invaginarias": "invaginar",
    "invaginarmo": "invaginar",
    "invaginarmos": "invaginar",
    "invaginará": "invaginar",
    "invaginarás": "invaginar",
    "invaginarão": "invaginar",
    "invaginaríamos": "invaginar",
    "invaginaríeis": "invaginar",
    "invaginas": "invaginar",
    "invaginasse": "invaginar",
    "invaginassem": "invaginar",
    "invaginasses": "invaginar",
    "invaginaste": "invaginar",
    "invaginastes": "invaginar",
    "invaginava": "invaginar",
    "invaginavam": "invaginar",
    "invaginavas": "invaginar",
    "invaginações": "invaginação",
    "invagine": "invaginar",
    "invaginei": "invaginar",
    "invagineis": "invaginar",
    "invaginem": "invaginar",
    "invaginemo": "invaginar",
    "invaginemos": "invaginar",
    "invagines": "invaginar",
    "invagino": "invaginar",
    "invaginou": "invaginar",
    "invaginá": "invaginar",
    "invaginámo": "invaginar",
    "invaginámos": "invaginar",
    "invagináramo": "invaginar",
    "invagináramos": "invaginar",
    "invaginárei": "invaginar",
    "invagináreis": "invaginar",
    "invaginásseis": "invaginar",
    "invaginássemos": "invaginar",
    "invaginávamo": "invaginar",
    "invaginávamos": "invaginar",
    "invaginávei": "invaginar",
    "invagináveis": "invaginar",
    "invalesce": "invalescer",
    "invalescei": "invalescer",
    "invalesceis": "invalescer",
    "invalescem": "invalescer",
    "invalescemo": "invalescer",
    "invalescemos": "invalescer",
    "invalescendo": "invalescer",
    "invalescera": "invalescer",
    "invalesceram": "invalescer",
    "invalesceras": "invalescer",
    "invalescerdes": "invalescer",
    "invalescerei": "invalescer",
    "invalescereis": "invalescer",
    "invalescerem": "invalescer",
    "invalesceremos": "invalescer",
    "invalesceres": "invalescer",
    "invalesceria": "invalescer",
    "invalesceriam": "invalescer",
    "invalescerias": "invalescer",
    "invalescermo": "invalescer",
    "invalescermos": "invalescer",
    "invalescerá": "invalescer",
    "invalescerás": "invalescer",
    "invalescerão": "invalescer",
    "invalesceríamos": "invalescer",
    "invalesceríeis": "invalescer",
    "invalesces": "invalescer",
    "invalescesse": "invalescer",
    "invalescessem": "invalescer",
    "invalescesses": "invalescer",
    "invalesceste": "invalescer",
    "invalescestes": "invalescer",
    "invalesceu": "invalescer",
    "invalesci": "invalescer",
    "invalescia": "invalescer",
    "invalesciam": "invalescer",
    "invalescias": "invalescer",
    "invalescida": "invalescer",
    "invalescidas": "invalescer",
    "invalescido": "invalescer",
    "invalescidos": "invalescer",
    "invalescêramo": "invalescer",
    "invalescêramos": "invalescer",
    "invalescêreis": "invalescer",
    "invalescêsseis": "invalescer",
    "invalescêssemos": "invalescer",
    "invalescíamo": "invalescer",
    "invalescíamos": "invalescer",
    "invalescíeis": "invalescer",
    "invalesça": "invalescer",
    "invalesçais": "invalescer",
    "invalesçam": "invalescer",
    "invalesçamo": "invalescer",
    "invalesçamos": "invalescer",
    "invalesças": "invalescer",
    "invalesço": "invalescer",
    "invalida": "invalidar",
    "invalidada": "invalidar",
    "invalidadas": "invalidar",
    "invalidades": "invalidade",
    "invalidado": "invalidar",
    "invalidados": "invalidar",
    "invalidai": "invalidar",
    "invalidais": "invalidar",
    "invalidam": "invalidar",
    "invalidamo": "invalidar",
    "invalidamos": "invalidar",
    "invalidando": "invalidar",
    "invalidara": "invalidar",
    "invalidaram": "invalidar",
    "invalidaras": "invalidar",
    "invalidarde": "invalidar",
    "invalidardes": "invalidar",
    "invalidare": "invalidar",
    "invalidarei": "invalidar",
    "invalidareis": "invalidar",
    "invalidarem": "invalidar",
    "invalidaremos": "invalidar",
    "invalidares": "invalidar",
    "invalidaria": "invalidar",
    "invalidariam": "invalidar",
    "invalidarias": "invalidar",
    "invalidarmo": "invalidar",
    "invalidarmos": "invalidar",
    "invalidará": "invalidar",
    "invalidarás": "invalidar",
    "invalidarão": "invalidar",
    "invalidaríamos": "invalidar",
    "invalidaríeis": "invalidar",
    "invalidas": "invalidar",
    "invalidasse": "invalidar",
    "invalidassem": "invalidar",
    "invalidasses": "invalidar",
    "invalidaste": "invalidar",
    "invalidastes": "invalidar",
    "invalidava": "invalidar",
    "invalidavam": "invalidar",
    "invalidavas": "invalidar",
    "invalidações": "invalidação",
    "invalide": "invalidar",
    "invalidei": "invalidar",
    "invalideis": "invalidar",
    "invalidem": "invalidar",
    "invalidemo": "invalidar",
    "invalidemos": "invalidar",
    "invalides": "invalidar",
    "invalido": "invalidar",
    "invalidou": "invalidar",
    "invalidá": "invalidar",
    "invalidámo": "invalidar",
    "invalidámos": "invalidar",
    "invalidáramo": "invalidar",
    "invalidáramos": "invalidar",
    "invalidárei": "invalidar",
    "invalidáreis": "invalidar",
    "invalidásseis": "invalidar",
    "invalidássemos": "invalidar",
    "invalidávamo": "invalidar",
    "invalidávamos": "invalidar",
    "invalidávei": "invalidar",
    "invalidáveis": "invalidável",
    "invares": "invar",
    "invariabilidades": "invariabilidade",
    "invariantes": "invariante",
    "invariáveis": "invariável",
    "invariâncias": "invariância",
    "invasiva": "invasivo",
    "invasivas": "invasivo",
    "invasivos": "invasivo",
    "invasora": "invasor",
    "invasoras": "invasor",
    "invasores": "invasor",
    "invasões": "invasão",
    "invectiva": "invectivo",
    "invectivada": "invectivar",
    "invectivadas": "invectivar",
    "invectivado": "invectivar",
    "invectivadora": "invectivador",
    "invectivadoras": "invectivador",
    "invectivadores": "invectivador",
    "invectivados": "invectivar",
    "invectivai": "invectivar",
    "invectivais": "invectivar",
    "invectivam": "invectivar",
    "invectivamo": "invectivar",
    "invectivamos": "invectivar",
    "invectivando": "invectivar",
    "invectivara": "invectivar",
    "invectivaram": "invectivar",
    "invectivaras": "invectivar",
    "invectivarde": "invectivar",
    "invectivardes": "invectivar",
    "invectivare": "invectivar",
    "invectivarei": "invectivar",
    "invectivareis": "invectivar",
    "invectivarem": "invectivar",
    "invectivaremos": "invectivar",
    "invectivares": "invectivar",
    "invectivaria": "invectivar",
    "invectivariam": "invectivar",
    "invectivarias": "invectivar",
    "invectivarmo": "invectivar",
    "invectivarmos": "invectivar",
    "invectivará": "invectivar",
    "invectivarás": "invectivar",
    "invectivarão": "invectivar",
    "invectivaríamos": "invectivar",
    "invectivaríeis": "invectivar",
    "invectivas": "invectivo",
    "invectivasse": "invectivar",
    "invectivassem": "invectivar",
    "invectivasses": "invectivar",
    "invectivaste": "invectivar",
    "invectivastes": "invectivar",
    "invectivava": "invectivar",
    "invectivavam": "invectivar",
    "invectivavas": "invectivar",
    "invective": "invectivar",
    "invectivei": "invectivar",
    "invectiveis": "invectivar",
    "invectivem": "invectivar",
    "invectivemo": "invectivar",
    "invectivemos": "invectivar",
    "invectives": "invectivar",
    "invectivistas": "invectivista",
    "invectivo": "invectivar",
    "invectivos": "invectivo",
    "invectivou": "invectivar",
    "invectivá": "invectivar",
    "invectivámo": "invectivar",
    "invectivámos": "invectivar",
    "invectiváramo": "invectivar",
    "invectiváramos": "invectivar",
    "invectivárei": "invectivar",
    "invectiváreis": "invectivar",
    "invectivásseis": "invectivar",
    "invectivássemos": "invectivar",
    "invectivávamo": "invectivar",
    "invectivávamos": "invectivar",
    "invectivávei": "invectivar",
    "invectiváveis": "invectivável",
    "invedáveis": "invedável",
    "inveja": "invejar",
    "invejada": "invejar",
    "invejadas": "invejar",
    "invejado": "invejar",
    "invejados": "invejar",
    "invejadíssima": "invejado",
    "invejadíssimas": "invejado",
    "invejadíssimo": "invejado",
    "invejadíssimos": "invejado",
    "invejai": "invejar",
    "invejais": "invejar",
    "invejam": "invejar",
    "invejamo": "invejar",
    "invejamos": "invejar",
    "invejanda": "invejando",
    "invejandas": "invejando",
    "invejando": "invejar",
    "invejandos": "invejando",
    "invejara": "invejar",
    "invejaram": "invejar",
    "invejaras": "invejar",
    "invejarde": "invejar",
    "invejardes": "invejar",
    "invejare": "invejar",
    "invejarei": "invejar",
    "invejareis": "invejar",
    "invejarem": "invejar",
    "invejaremos": "invejar",
    "invejares": "invejar",
    "invejaria": "invejar",
    "invejariam": "invejar",
    "invejarias": "invejar",
    "invejarmo": "invejar",
    "invejarmos": "invejar",
    "invejará": "invejar",
    "invejarás": "invejar",
    "invejarão": "invejar",
    "invejaríamos": "invejar",
    "invejaríeis": "invejar",
    "invejas": "invejar",
    "invejasse": "invejar",
    "invejassem": "invejar",
    "invejasses": "invejar",
    "invejaste": "invejar",
    "invejastes": "invejar",
    "invejava": "invejar",
    "invejavam": "invejar",
    "invejavas": "invejar",
    "invejazinha": "inveja",
    "invejazinhas": "inveja",
    "invejazita": "inveja",
    "invejazitas": "inveja",
    "inveje": "invejar",
    "invejei": "invejar",
    "invejeis": "invejar",
    "invejem": "invejar",
    "invejemo": "invejar",
    "invejemos": "invejar",
    "invejes": "invejar",
    "invejidades": "invejidade",
    "invejinha": "inveja",
    "invejinhas": "inveja",
    "invejita": "inveja",
    "invejitas": "inveja",
    "invejo": "invejar",
    "invejosa": "invejoso",
    "invejosas": "invejoso",
    "invejosazinha": "invejoso",
    "invejosazinhas": "invejoso",
    "invejosazita": "invejoso",
    "invejosazitas": "invejoso",
    "invejosos": "invejoso",
    "invejosozinho": "invejoso",
    "invejosozinhos": "invejoso",
    "invejosozito": "invejoso",
    "invejosozitos": "invejoso",
    "invejou": "invejar",
    "invejá": "invejar",
    "invejámo": "invejar",
    "invejámos": "invejar",
    "invejáramo": "invejar",
    "invejáramos": "invejar",
    "invejárei": "invejar",
    "invejáreis": "invejar",
    "invejásseis": "invejar",
    "invejássemos": "invejar",
    "invejávamo": "invejar",
    "invejávamos": "invejar",
    "invejávei": "invejar",
    "invejáveis": "invejável",
    "invencibilidades": "invencibilidade",
    "invenciona": "invencionar",
    "invencionada": "invencionar",
    "invencionadas": "invencionar",
    "invencionado": "invencionar",
    "invencionados": "invencionar",
    "invencionai": "invencionar",
    "invencionais": "invencionar",
    "invencionam": "invencionar",
    "invencionamo": "invencionar",
    "invencionamos": "invencionar",
    "invencionando": "invencionar",
    "invencionara": "invencionar",
    "invencionaram": "invencionar",
    "invencionaras": "invencionar",
    "invencionarde": "invencionar",
    "invencionardes": "invencionar",
    "invencionare": "invencionar",
    "invencionarei": "invencionar",
    "invencionareis": "invencionar",
    "invencionarem": "invencionar",
    "invencionaremos": "invencionar",
    "invencionares": "invencionar",
    "invencionaria": "invencionar",
    "invencionariam": "invencionar",
    "invencionarias": "invencionar",
    "invencionarmo": "invencionar",
    "invencionarmos": "invencionar",
    "invencionará": "invencionar",
    "invencionarás": "invencionar",
    "invencionarão": "invencionar",
    "invencionaríamos": "invencionar",
    "invencionaríeis": "invencionar",
    "invencionas": "invencionar",
    "invencionasse": "invencionar",
    "invencionassem": "invencionar",
    "invencionasses": "invencionar",
    "invencionaste": "invencionar",
    "invencionastes": "invencionar",
    "invencionava": "invencionar",
    "invencionavam": "invencionar",
    "invencionavas": "invencionar",
    "invencione": "invencionar",
    "invencionei": "invencionar",
    "invencioneira": "invencioneiro",
    "invencioneiras": "invencioneiro",
    "invencioneiros": "invencioneiro",
    "invencioneis": "invencionar",
    "invencionem": "invencionar",
    "invencionemo": "invencionar",
    "invencionemos": "invencionar",
    "invenciones": "invencionar",
    "invencionices": "invencionice",
    "invenciono": "invencionar",
    "invencionou": "invencionar",
    "invencioná": "invencionar",
    "invencionámo": "invencionar",
    "invencionámos": "invencionar",
    "invencionáramo": "invencionar",
    "invencionáramos": "invencionar",
    "invencionárei": "invencionar",
    "invencionáreis": "invencionar",
    "invencionásseis": "invencionar",
    "invencionássemos": "invencionar",
    "invencionávamo": "invencionar",
    "invencionávamos": "invencionar",
    "invencionávei": "invencionar",
    "invencionáveis": "invencionar",
    "invencíveis": "invencível",
    "invendáveis": "invendável",
    "invendíveis": "invendível",
    "inventa": "inventar",
    "inventada": "inventar",
    "inventadas": "inventar",
    "inventado": "inventar",
    "inventados": "inventar",
    "inventai": "inventar",
    "inventais": "inventar",
    "inventam": "inventar",
    "inventamo": "inventar",
    "inventamos": "inventar",
    "inventando": "inventar",
    "inventara": "inventar",
    "inventaram": "inventar",
    "inventaras": "inventar",
    "inventarde": "inventar",
    "inventardes": "inventar",
    "inventare": "inventar",
    "inventarei": "inventar",
    "inventareis": "inventar",
    "inventarem": "inventar",
    "inventaremos": "inventar",
    "inventares": "inventar",
    "inventaria": "inventariar",
    "inventariada": "inventariar",
    "inventariadas": "inventariar",
    "inventariado": "inventariar",
    "inventariados": "inventariar",
    "inventariai": "inventariar",
    "inventariais": "inventariar",
    "inventariam": "inventariar",
    "inventariamo": "inventariar",
    "inventariamos": "inventariar",
    "inventariando": "inventariar",
    "inventariantes": "inventariante",
    "inventariara": "inventariar",
    "inventariaram": "inventariar",
    "inventariaras": "inventariar",
    "inventariarde": "inventariar",
    "inventariardes": "inventariar",
    "inventariare": "inventariar",
    "inventariarei": "inventariar",
    "inventariareis": "inventariar",
    "inventariarem": "inventariar",
    "inventariaremos": "inventariar",
    "inventariares": "inventariar",
    "inventariaria": "inventariar",
    "inventariariam": "inventariar",
    "inventariarias": "inventariar",
    "inventariarmo": "inventariar",
    "inventariarmos": "inventariar",
    "inventariará": "inventariar",
    "inventariarás": "inventariar",
    "inventariarão": "inventariar",
    "inventariaríamos": "inventariar",
    "inventariaríeis": "inventariar",
    "inventarias": "inventariar",
    "inventariasse": "inventariar",
    "inventariassem": "inventariar",
    "inventariasses": "inventariar",
    "inventariaste": "inventariar",
    "inventariastes": "inventariar",
    "inventariava": "inventariar",
    "inventariavam": "inventariar",
    "inventariavas": "inventariar",
    "inventariações": "inventariação",
    "inventarie": "inventariar",
    "inventariei": "inventariar",
    "inventarieis": "inventariar",
    "inventariem": "inventariar",
    "inventariemo": "inventariar",
    "inventariemos": "inventariar",
    "inventaries": "inventariar",
    "inventario": "inventariar",
    "inventariou": "inventariar",
    "inventariá": "inventariar",
    "inventariámo": "inventariar",
    "inventariámos": "inventariar",
    "inventariáramo": "inventariar",
    "inventariáramos": "inventariar",
    "inventariárei": "inventariar",
    "inventariáreis": "inventariar",
    "inventariásseis": "inventariar",
    "inventariássemos": "inventariar",
    "inventariávamo": "inventariar",
    "inventariávamos": "inventariar",
    "inventariávei": "inventariar",
    "inventariáveis": "inventariável",
    "inventarmo": "inventar",
    "inventarmos": "inventar",
    "inventará": "inventar",
    "inventarás": "inventar",
    "inventarão": "inventar",
    "inventaríamos": "inventar",
    "inventaríeis": "inventar",
    "inventas": "inventar",
    "inventasse": "inventar",
    "inventassem": "inventar",
    "inventasses": "inventar",
    "inventaste": "inventar",
    "inventastes": "inventar",
    "inventava": "inventar",
    "inventavam": "inventar",
    "inventavas": "inventar",
    "invente": "inventar",
    "inventei": "inventar",
    "inventeis": "inventar",
    "inventem": "inventar",
    "inventemo": "inventar",
    "inventemos": "inventar",
    "inventes": "inventar",
    "inventiva": "inventivo",
    "inventivas": "inventivo",
    "inventividades": "inventividade",
    "inventivos": "inventivo",
    "invento": "inventar",
    "inventonas": "inventona",
    "inventora": "inventor",
    "inventoras": "inventor",
    "inventores": "inventor",
    "inventos": "invento",
    "inventou": "inventar",
    "inventriz": "inventor",
    "inventrizes": "inventor",
    "inventá": "inventar",
    "inventámo": "inventar",
    "inventámos": "inventar",
    "inventáramo": "inventar",
    "inventáramos": "inventar",
    "inventárei": "inventar",
    "inventáreis": "inventar",
    "inventária": "inventário",
    "inventárias": "inventário",
    "inventários": "inventário",
    "inventásseis": "inventar",
    "inventássemos": "inventar",
    "inventávamo": "inventar",
    "inventávamos": "inventar",
    "inventávei": "inventar",
    "inventáveis": "inventável",
    "invenções": "invenção",
    "inverdadeira": "inverdadeiro",
    "inverdadeiras": "inverdadeiro",
    "inverdadeiros": "inverdadeiro",
    "inverdades": "inverdade",
    "inveridicidades": "inveridicidade",
    "inverificáveis": "inverificável",
    "inverna": "invernar",
    "invernada": "invernar",
    "invernadas": "invernar",
    "invernado": "invernar",
    "invernadoiros": "invernadoiro",
    "invernados": "invernar",
    "invernadouros": "invernadouro",
    "invernagens": "invernagem",
    "invernai": "invernar",
    "invernais": "invernar",
    "invernam": "invernar",
    "invernamo": "invernar",
    "invernamos": "invernar",
    "invernando": "invernar",
    "invernantes": "invernante",
    "invernara": "invernar",
    "invernaram": "invernar",
    "invernaras": "invernar",
    "invernardes": "invernar",
    "invernarei": "invernar",
    "invernareis": "invernar",
    "invernarem": "invernar",
    "invernaremos": "invernar",
    "invernares": "invernar",
    "invernaria": "invernar",
    "invernariam": "invernar",
    "invernarias": "invernar",
    "invernarmo": "invernar",
    "invernarmos": "invernar",
    "invernará": "invernar",
    "invernarás": "invernar",
    "invernarão": "invernar",
    "invernaríamos": "invernar",
    "invernaríeis": "invernar",
    "invernas": "invernar",
    "invernasse": "invernar",
    "invernassem": "invernar",
    "invernasses": "invernar",
    "invernaste": "invernar",
    "invernastes": "invernar",
    "invernava": "invernar",
    "invernavam": "invernar",
    "invernavas": "invernar",
    "inverne": "invernar",
    "invernei": "invernar",
    "inverneiras": "inverneira",
    "inverneis": "invernar",
    "invernem": "invernar",
    "invernemo": "invernar",
    "invernemos": "invernar",
    "invernes": "invernar",
    "invernias": "invernia",
    "inverniça": "inverniço",
    "inverniças": "inverniço",
    "inverniços": "inverniço",
    "inverno": "invernar",
    "invernos": "inverno",
    "invernosa": "invernoso",
    "invernosas": "invernoso",
    "invernosos": "invernoso",
    "invernou": "invernar",
    "invernáculos": "invernáculo",
    "invernámo": "invernar",
    "invernámos": "invernar",
    "invernáramo": "invernar",
    "invernáramos": "invernar",
    "invernáreis": "invernar",
    "invernásseis": "invernar",
    "invernássemos": "invernar",
    "invernávamo": "invernar",
    "invernávamos": "invernar",
    "invernáveis": "invernar",
    "inverosimeis": "inverosimil",
    "inverosimilhantes": "inverosimilhante",
    "inverosimilhanças": "inverosimilhança",
    "inverossimilhanças": "inverossimilhança",
    "inverosímeis": "inverosímil",
    "inversa": "inverso",
    "inversas": "inverso",
    "inversionistas": "inversionista",
    "inversiva": "inversivo",
    "inversivas": "inversivo",
    "inversivos": "inversivo",
    "inversora": "inversor",
    "inversoras": "inversor",
    "inversores": "inversor",
    "inversos": "inverso",
    "inversões": "inversão",
    "inverta": "inverter",
    "invertais": "inverter",
    "invertam": "inverter",
    "invertamo": "inverter",
    "invertamos": "inverter",
    "invertas": "inverter",
    "invertases": "invertase",
    "inverte": "inverter",
    "invertebrada": "invertebrado",
    "invertebradas": "invertebrado",
    "invertebrados": "invertebrado",
    "invertei": "inverter",
    "inverteis": "inverter",
    "invertem": "inverter",
    "invertemo": "inverter",
    "invertemos": "inverter",
    "invertendo": "inverter",
    "invertera": "inverter",
    "inverteram": "inverter",
    "inverteras": "inverter",
    "inverterde": "inverter",
    "inverterdes": "inverter",
    "invertere": "inverter",
    "inverterei": "inverter",
    "invertereis": "inverter",
    "inverterem": "inverter",
    "inverteremos": "inverter",
    "inverteres": "inverter",
    "inverteria": "inverter",
    "inverteriam": "inverter",
    "inverterias": "inverter",
    "invertermo": "inverter",
    "invertermos": "inverter",
    "inverterá": "inverter",
    "inverterás": "inverter",
    "inverterão": "inverter",
    "inverteríamos": "inverter",
    "inverteríeis": "inverter",
    "invertes": "inverter",
    "invertesse": "inverter",
    "invertessem": "inverter",
    "invertesses": "inverter",
    "inverteste": "inverter",
    "invertestes": "inverter",
    "inverteu": "inverter",
    "inverti": "inverter",
    "invertia": "inverter",
    "invertiam": "inverter",
    "invertias": "inverter",
    "invertida": "invertido",
    "invertidas": "invertido",
    "invertido": "inverter",
    "invertidos": "invertido",
    "invertinas": "invertina",
    "inverto": "inverter",
    "invertê": "inverter",
    "invertêramo": "inverter",
    "invertêramos": "inverter",
    "invertêrei": "inverter",
    "invertêreis": "inverter",
    "invertêsseis": "inverter",
    "invertêssemos": "inverter",
    "invertíamo": "inverter",
    "invertíamos": "inverter",
    "invertíei": "inverter",
    "invertíeis": "inverter",
    "invertíveis": "invertível",
    "inverídica": "inverídico",
    "inverídicas": "inverídico",
    "inverídicos": "inverídico",
    "investe": "investir",
    "investem": "investir",
    "investes": "investir",
    "investi": "investir",
    "investia": "investir",
    "investiam": "investir",
    "investias": "investir",
    "investida": "investir",
    "investidas": "investir",
    "investido": "investir",
    "investidora": "investidor",
    "investidoras": "investidor",
    "investidores": "investidor",
    "investidos": "investir",
    "investiduras": "investidura",
    "investiga": "investigar",
    "investigada": "investigar",
    "investigadas": "investigar",
    "investigado": "investigar",
    "investigadora": "investigador",
    "investigadoras": "investigador",
    "investigadores": "investigador",
    "investigados": "investigar",
    "investigai": "investigar",
    "investigais": "investigar",
    "investigam": "investigar",
    "investigamo": "investigar",
    "investigamos": "investigar",
    "investigando": "investigar",
    "investigantes": "investigante",
    "investigara": "investigar",
    "investigaram": "investigar",
    "investigaras": "investigar",
    "investigarde": "investigar",
    "investigardes": "investigar",
    "investigare": "investigar",
    "investigarei": "investigar",
    "investigareis": "investigar",
    "investigarem": "investigar",
    "investigaremos": "investigar",
    "investigares": "investigar",
    "investigaria": "investigar",
    "investigariam": "investigar",
    "investigarias": "investigar",
    "investigarmo": "investigar",
    "investigarmos": "investigar",
    "investigará": "investigar",
    "investigarás": "investigar",
    "investigarão": "investigar",
    "investigaríamos": "investigar",
    "investigaríeis": "investigar",
    "investigas": "investigar",
    "investigasse": "investigar",
    "investigassem": "investigar",
    "investigasses": "investigar",
    "investigaste": "investigar",
    "investigastes": "investigar",
    "investigava": "investigar",
    "investigavam": "investigar",
    "investigavas": "investigar",
    "investigações": "investigação",
    "investigo": "investigar",
    "investigou": "investigar",
    "investigue": "investigar",
    "investiguei": "investigar",
    "investigueis": "investigar",
    "investiguem": "investigar",
    "investiguemo": "investigar",
    "investiguemos": "investigar",
    "investigues": "investigar",
    "investigá": "investigar",
    "investigámo": "investigar",
    "investigámos": "investigar",
    "investigáramo": "investigar",
    "investigáramos": "investigar",
    "investigárei": "investigar",
    "investigáreis": "investigar",
    "investigásseis": "investigar",
    "investigássemos": "investigar",
    "investigávamo": "investigar",
    "investigávamos": "investigar",
    "investigávei": "investigar",
    "investigáveis": "investigável",
    "investimentos": "investimento",
    "investimo": "investir",
    "investimos": "investir",
    "investindo": "investir",
    "investira": "investir",
    "investiram": "investir",
    "investiras": "investir",
    "investirde": "investir",
    "investirdes": "investir",
    "investire": "investir",
    "investirei": "investir",
    "investireis": "investir",
    "investirem": "investir",
    "investiremos": "investir",
    "investires": "investir",
    "investiria": "investir",
    "investiriam": "investir",
    "investirias": "investir",
    "investirmo": "investir",
    "investirmos": "investir",
    "investirá": "investir",
    "investirás": "investir",
    "investirão": "investir",
    "investiríamos": "investir",
    "investiríeis": "investir",
    "investis": "investir",
    "investisse": "investir",
    "investissem": "investir",
    "investisses": "investir",
    "investiste": "investir",
    "investistes": "investir",
    "investiu": "investir",
    "investíamo": "investir",
    "investíamos": "investir",
    "investíei": "investir",
    "investíeis": "investir",
    "investíramo": "investir",
    "investíramos": "investir",
    "investírei": "investir",
    "investíreis": "investir",
    "investísseis": "investir",
    "investíssemos": "investir",
    "invetera": "inveterar",
    "inveterada": "inveterar",
    "inveteradas": "inveterar",
    "inveterado": "inveterar",
    "inveterados": "inveterar",
    "inveterai": "inveterar",
    "inveterais": "inveterar",
    "inveteram": "inveterar",
    "inveteramo": "inveterar",
    "inveteramos": "inveterar",
    "inveterando": "inveterar",
    "inveterara": "inveterar",
    "inveteraram": "inveterar",
    "inveteraras": "inveterar",
    "inveterarde": "inveterar",
    "inveterardes": "inveterar",
    "inveterare": "inveterar",
    "inveterarei": "inveterar",
    "inveterareis": "inveterar",
    "inveterarem": "inveterar",
    "inveteraremos": "inveterar",
    "inveterares": "inveterar",
    "inveteraria": "inveterar",
    "inveterariam": "inveterar",
    "inveterarias": "inveterar",
    "inveterarmo": "inveterar",
    "inveterarmos": "inveterar",
    "inveterará": "inveterar",
    "inveterarás": "inveterar",
    "inveterarão": "inveterar",
    "inveteraríamos": "inveterar",
    "inveteraríeis": "inveterar",
    "inveteras": "inveterar",
    "inveterasse": "inveterar",
    "inveterassem": "inveterar",
    "inveterasses": "inveterar",
    "inveteraste": "inveterar",
    "inveterastes": "inveterar",
    "inveterava": "inveterar",
    "inveteravam": "inveterar",
    "inveteravas": "inveterar",
    "inveterações": "inveteração",
    "invetere": "inveterar",
    "inveterei": "inveterar",
    "invetereis": "inveterar",
    "inveterem": "inveterar",
    "inveteremo": "inveterar",
    "inveteremos": "inveterar",
    "inveteres": "inveterar",
    "invetero": "inveterar",
    "inveterou": "inveterar",
    "inveterá": "inveterar",
    "inveterámo": "inveterar",
    "inveterámos": "inveterar",
    "inveteráramo": "inveterar",
    "inveteráramos": "inveterar",
    "inveterárei": "inveterar",
    "inveteráreis": "inveterar",
    "inveterásseis": "inveterar",
    "inveterássemos": "inveterar",
    "inveterávamo": "inveterar",
    "inveterávamos": "inveterar",
    "inveterávei": "inveterar",
    "inveteráveis": "inveterar",
    "inviabilidades": "inviabilidade",
    "inviabiliza": "inviabilizar",
    "inviabilizada": "inviabilizar",
    "inviabilizadas": "inviabilizar",
    "inviabilizado": "inviabilizar",
    "inviabilizados": "inviabilizar",
    "inviabilizai": "inviabilizar",
    "inviabilizais": "inviabilizar",
    "inviabilizam": "inviabilizar",
    "inviabilizamo": "inviabilizar",
    "inviabilizamos": "inviabilizar",
    "inviabilizando": "inviabilizar",
    "inviabilizara": "inviabilizar",
    "inviabilizaram": "inviabilizar",
    "inviabilizaras": "inviabilizar",
    "inviabilizarde": "inviabilizar",
    "inviabilizardes": "inviabilizar",
    "inviabilizare": "inviabilizar",
    "inviabilizarei": "inviabilizar",
    "inviabilizareis": "inviabilizar",
    "inviabilizarem": "inviabilizar",
    "inviabilizaremos": "inviabilizar",
    "inviabilizares": "inviabilizar",
    "inviabilizaria": "inviabilizar",
    "inviabilizariam": "inviabilizar",
    "inviabilizarias": "inviabilizar",
    "inviabilizarmo": "inviabilizar",
    "inviabilizarmos": "inviabilizar",
    "inviabilizará": "inviabilizar",
    "inviabilizarás": "inviabilizar",
    "inviabilizarão": "inviabilizar",
    "inviabilizaríamos": "inviabilizar",
    "inviabilizaríeis": "inviabilizar",
    "inviabilizas": "inviabilizar",
    "inviabilizasse": "inviabilizar",
    "inviabilizassem": "inviabilizar",
    "inviabilizasses": "inviabilizar",
    "inviabilizaste": "inviabilizar",
    "inviabilizastes": "inviabilizar",
    "inviabilizava": "inviabilizar",
    "inviabilizavam": "inviabilizar",
    "inviabilizavas": "inviabilizar",
    "inviabilizações": "inviabilização",
    "inviabilize": "inviabilizar",
    "inviabilizei": "inviabilizar",
    "inviabilizeis": "inviabilizar",
    "inviabilizem": "inviabilizar",
    "inviabilizemo": "inviabilizar",
    "inviabilizemos": "inviabilizar",
    "inviabilizes": "inviabilizar",
    "inviabilizo": "inviabilizar",
    "inviabilizou": "inviabilizar",
    "inviabilizá": "inviabilizar",
    "inviabilizámo": "inviabilizar",
    "inviabilizámos": "inviabilizar",
    "inviabilizáramo": "inviabilizar",
    "inviabilizáramos": "inviabilizar",
    "inviabilizárei": "inviabilizar",
    "inviabilizáreis": "inviabilizar",
    "inviabilizásseis": "inviabilizar",
    "inviabilizássemos": "inviabilizar",
    "inviabilizávamo": "inviabilizar",
    "inviabilizávamos": "inviabilizar",
    "inviabilizávei": "inviabilizar",
    "inviabilizáveis": "inviabilizar",
    "invicta": "invicto",
    "invictas": "invicto",
    "invictos": "invicto",
    "invigilâncias": "invigilância",
    "inviolabilidades": "inviolabilidade",
    "inviolada": "inviolado",
    "invioladas": "inviolado",
    "inviolados": "inviolado",
    "invioláveis": "inviolável",
    "invipera": "inviperar",
    "inviperada": "inviperar",
    "inviperadas": "inviperar",
    "inviperado": "inviperar",
    "inviperados": "inviperar",
    "inviperai": "inviperar",
    "inviperais": "inviperar",
    "inviperam": "inviperar",
    "inviperamo": "inviperar",
    "inviperamos": "inviperar",
    "inviperando": "inviperar",
    "inviperara": "inviperar",
    "inviperaram": "inviperar",
    "inviperaras": "inviperar",
    "inviperarde": "inviperar",
    "inviperardes": "inviperar",
    "inviperare": "inviperar",
    "inviperarei": "inviperar",
    "inviperareis": "inviperar",
    "inviperarem": "inviperar",
    "inviperaremos": "inviperar",
    "inviperares": "inviperar",
    "inviperaria": "inviperar",
    "inviperariam": "inviperar",
    "inviperarias": "inviperar",
    "inviperarmo": "inviperar",
    "inviperarmos": "inviperar",
    "inviperará": "inviperar",
    "inviperarás": "inviperar",
    "inviperarão": "inviperar",
    "inviperaríamos": "inviperar",
    "inviperaríeis": "inviperar",
    "inviperas": "inviperar",
    "inviperasse": "inviperar",
    "inviperassem": "inviperar",
    "inviperasses": "inviperar",
    "inviperaste": "inviperar",
    "inviperastes": "inviperar",
    "inviperava": "inviperar",
    "inviperavam": "inviperar",
    "inviperavas": "inviperar",
    "invipere": "inviperar",
    "inviperei": "inviperar",
    "invipereis": "inviperar",
    "inviperem": "inviperar",
    "inviperemo": "inviperar",
    "inviperemos": "inviperar",
    "inviperes": "inviperar",
    "invipero": "inviperar",
    "inviperou": "inviperar",
    "inviperá": "inviperar",
    "inviperámo": "inviperar",
    "inviperámos": "inviperar",
    "inviperáramo": "inviperar",
    "inviperáramos": "inviperar",
    "inviperárei": "inviperar",
    "inviperáreis": "inviperar",
    "inviperásseis": "inviperar",
    "inviperássemos": "inviperar",
    "inviperávamo": "inviperar",
    "inviperávamos": "inviperar",
    "inviperávei": "inviperar",
    "inviperáveis": "inviperar",
    "invirilidades": "invirilidade",
    "inviscerações": "invisceração",
    "invisibilidades": "invisibilidade",
    "invista": "investir",
    "invistais": "investir",
    "invistam": "investir",
    "invistamo": "investir",
    "invistamos": "investir",
    "invistas": "investir",
    "invisto": "investir",
    "invisuais": "invisual",
    "invisíveis": "invisível",
    "invita": "invito",
    "invitada": "invitar",
    "invitadas": "invitar",
    "invitado": "invitar",
    "invitados": "invitar",
    "invitai": "invitar",
    "invitais": "invitar",
    "invitam": "invitar",
    "invitamentos": "invitamento",
    "invitamo": "invitar",
    "invitamos": "invitar",
    "invitando": "invitar",
    "invitara": "invitar",
    "invitaram": "invitar",
    "invitaras": "invitar",
    "invitarde": "invitar",
    "invitardes": "invitar",
    "invitare": "invitar",
    "invitarei": "invitar",
    "invitareis": "invitar",
    "invitarem": "invitar",
    "invitaremos": "invitar",
    "invitares": "invitar",
    "invitaria": "invitar",
    "invitariam": "invitar",
    "invitarias": "invitar",
    "invitarmo": "invitar",
    "invitarmos": "invitar",
    "invitará": "invitar",
    "invitarás": "invitar",
    "invitarão": "invitar",
    "invitaríamos": "invitar",
    "invitaríeis": "invitar",
    "invitas": "invito",
    "invitasse": "invitar",
    "invitassem": "invitar",
    "invitasses": "invitar",
    "invitaste": "invitar",
    "invitastes": "invitar",
    "invitatória": "invitatório",
    "invitatórias": "invitatório",
    "invitatórios": "invitatório",
    "invitava": "invitar",
    "invitavam": "invitar",
    "invitavas": "invitar",
    "invitações": "invitação",
    "invite": "invitar",
    "invitei": "invitar",
    "inviteis": "invitar",
    "invitem": "invitar",
    "invitemo": "invitar",
    "invitemos": "invitar",
    "invites": "invite",
    "invito": "invitar",
    "invitos": "invito",
    "invitou": "invitar",
    "invitrescíveis": "invitrescível",
    "invitá": "invitar",
    "invitámo": "invitar",
    "invitámos": "invitar",
    "invitáramo": "invitar",
    "invitáramos": "invitar",
    "invitárei": "invitar",
    "invitáreis": "invitar",
    "invitásseis": "invitar",
    "invitássemos": "invitar",
    "invitávamo": "invitar",
    "invitávamos": "invitar",
    "invitávei": "invitar",
    "invitáveis": "invitar",
    "invivíveis": "invivível",
    "inviáveis": "inviável",
    "invoca": "invocar",
    "invocada": "invocar",
    "invocadas": "invocar",
    "invocado": "invocar",
    "invocadora": "invocador",
    "invocadoras": "invocador",
    "invocadores": "invocador",
    "invocados": "invocar",
    "invocai": "invocar",
    "invocais": "invocar",
    "invocam": "invocar",
    "invocamo": "invocar",
    "invocamos": "invocar",
    "invocando": "invocar",
    "invocara": "invocar",
    "invocaram": "invocar",
    "invocaras": "invocar",
    "invocarde": "invocar",
    "invocardes": "invocar",
    "invocare": "invocar",
    "invocarei": "invocar",
    "invocareis": "invocar",
    "invocarem": "invocar",
    "invocaremos": "invocar",
    "invocares": "invocar",
    "invocaria": "invocar",
    "invocariam": "invocar",
    "invocarias": "invocar",
    "invocarmo": "invocar",
    "invocarmos": "invocar",
    "invocará": "invocar",
    "invocarás": "invocar",
    "invocarão": "invocar",
    "invocaríamos": "invocar",
    "invocaríeis": "invocar",
    "invocas": "invocar",
    "invocasse": "invocar",
    "invocassem": "invocar",
    "invocasses": "invocar",
    "invocaste": "invocar",
    "invocastes": "invocar",
    "invocativa": "invocativo",
    "invocativas": "invocativo",
    "invocativos": "invocativo",
    "invocatória": "invocatório",
    "invocatórias": "invocatório",
    "invocatórios": "invocatório",
    "invocava": "invocar",
    "invocavam": "invocar",
    "invocavas": "invocar",
    "invocações": "invocação",
    "invoco": "invocar",
    "invocou": "invocar",
    "invocá": "invocar",
    "invocámo": "invocar",
    "invocámos": "invocar",
    "invocáramo": "invocar",
    "invocáramos": "invocar",
    "invocárei": "invocar",
    "invocáreis": "invocar",
    "invocásseis": "invocar",
    "invocássemos": "invocar",
    "invocávamo": "invocar",
    "invocávamos": "invocar",
    "invocávei": "invocar",
    "invocáveis": "invocável",
    "involucelos": "involucelo",
    "involucra": "involucrar",
    "involucrada": "involucrar",
    "involucradas": "involucrar",
    "involucrado": "involucrar",
    "involucrados": "involucrar",
    "involucrai": "involucrar",
    "involucrais": "involucrar",
    "involucram": "involucrar",
    "involucramo": "involucrar",
    "involucramos": "involucrar",
    "involucrando": "involucrar",
    "involucrara": "involucrar",
    "involucraram": "involucrar",
    "involucraras": "involucrar",
    "involucrarde": "involucrar",
    "involucrardes": "involucrar",
    "involucrare": "involucrar",
    "involucrarei": "involucrar",
    "involucrareis": "involucrar",
    "involucrarem": "involucrar",
    "involucraremos": "involucrar",
    "involucrares": "involucrar",
    "involucraria": "involucrar",
    "involucrariam": "involucrar",
    "involucrarias": "involucrar",
    "involucrarmo": "involucrar",
    "involucrarmos": "involucrar",
    "involucrará": "involucrar",
    "involucrarás": "involucrar",
    "involucrarão": "involucrar",
    "involucraríamos": "involucrar",
    "involucraríeis": "involucrar",
    "involucras": "involucrar",
    "involucrasse": "involucrar",
    "involucrassem": "involucrar",
    "involucrasses": "involucrar",
    "involucraste": "involucrar",
    "involucrastes": "involucrar",
    "involucrava": "involucrar",
    "involucravam": "involucrar",
    "involucravas": "involucrar",
    "involucre": "involucrar",
    "involucrei": "involucrar",
    "involucreis": "involucrar",
    "involucrem": "involucrar",
    "involucremo": "involucrar",
    "involucremos": "involucrar",
    "involucres": "involucrar",
    "involucriformes": "involucriforme",
    "involucro": "involucrar",
    "involucrou": "involucrar",
    "involucrá": "involucrar",
    "involucrámo": "involucrar",
    "involucrámos": "involucrar",
    "involucráramo": "involucrar",
    "involucráramos": "involucrar",
    "involucrárei": "involucrar",
    "involucráreis": "involucrar",
    "involucrásseis": "involucrar",
    "involucrássemos": "involucrar",
    "involucrávamo": "involucrar",
    "involucrávamos": "involucrar",
    "involucrávei": "involucrar",
    "involucráveis": "involucrar",
    "involuntária": "involuntário",
    "involuntárias": "involuntário",
    "involuntários": "involuntário",
    "involuta": "involuto",
    "involutas": "involuto",
    "involutos": "involuto",
    "involutuosa": "involutuoso",
    "involutuosas": "involutuoso",
    "involutuosos": "involutuoso",
    "involutórios": "involutório",
    "involuções": "involução",
    "invoque": "invocar",
    "invoquei": "invocar",
    "invoqueis": "invocar",
    "invoquem": "invocar",
    "invoquemo": "invocar",
    "invoquemos": "invocar",
    "invoques": "invocar",
    "invulgares": "invulgar",
    "invulgaridades": "invulgaridade",
    "invulnerabilidades": "invulnerabilidade",
    "invulnerada": "invulnerado",
    "invulneradas": "invulnerado",
    "invulnerados": "invulnerado",
    "invulneráveis": "invulnerável",
    "inválida": "inválido",
    "inválidas": "inválido",
    "inválidos": "inválido",
    "invéss": "invés",
    "invídias": "invídia",
    "invólucros": "invólucro",
    "inxida": "inxido",
    "inxidas": "inxido",
    "inxidos": "inxido",
    "inzona": "inzonar",
    "inzonada": "inzonar",
    "inzonadas": "inzonar",
    "inzonado": "inzonar",
    "inzonados": "inzonar",
    "inzonai": "inzonar",
    "inzonais": "inzonar",
    "inzonam": "inzonar",
    "inzonamo": "inzonar",
    "inzonamos": "inzonar",
    "inzonando": "inzonar",
    "inzonara": "inzonar",
    "inzonaram": "inzonar",
    "inzonaras": "inzonar",
    "inzonarde": "inzonar",
    "inzonardes": "inzonar",
    "inzonare": "inzonar",
    "inzonarei": "inzonar",
    "inzonareis": "inzonar",
    "inzonarem": "inzonar",
    "inzonaremos": "inzonar",
    "inzonares": "inzonar",
    "inzonaria": "inzonar",
    "inzonariam": "inzonar",
    "inzonarias": "inzonar",
    "inzonarmo": "inzonar",
    "inzonarmos": "inzonar",
    "inzonará": "inzonar",
    "inzonarás": "inzonar",
    "inzonarão": "inzonar",
    "inzonaríamos": "inzonar",
    "inzonaríeis": "inzonar",
    "inzonas": "inzonar",
    "inzonasse": "inzonar",
    "inzonassem": "inzonar",
    "inzonasses": "inzonar",
    "inzonaste": "inzonar",
    "inzonastes": "inzonar",
    "inzonava": "inzonar",
    "inzonavam": "inzonar",
    "inzonavas": "inzonar",
    "inzone": "inzonar",
    "inzonei": "inzonar",
    "inzoneira": "inzoneiro",
    "inzoneiras": "inzoneiro",
    "inzoneiros": "inzoneiro",
    "inzoneis": "inzonar",
    "inzonem": "inzonar",
    "inzonemo": "inzonar",
    "inzonemos": "inzonar",
    "inzones": "inzonar",
    "inzonices": "inzonice",
    "inzono": "inzonar",
    "inzonou": "inzonar",
    "inzoná": "inzonar",
    "inzonámo": "inzonar",
    "inzonámos": "inzonar",
    "inzonáramo": "inzonar",
    "inzonáramos": "inzonar",
    "inzonárei": "inzonar",
    "inzonáreis": "inzonar",
    "inzonásseis": "inzonar",
    "inzonássemos": "inzonar",
    "inzonávamo": "inzonar",
    "inzonávamos": "inzonar",
    "inzonávei": "inzonar",
    "inzonáveis": "inzonar",
    "inábeis": "inábil",
    "inânias": "inânia",
    "inânimes": "inânime",
    "inça": "inçar",
    "inçada": "inçar",
    "inçadas": "inçar",
    "inçado": "inçar",
    "inçadoiros": "inçadoiro",
    "inçados": "inçar",
    "inçadouros": "inçadouro",
    "inçai": "inçar",
    "inçais": "inçar",
    "inçam": "inçar",
    "inçamo": "inçar",
    "inçamos": "inçar",
    "inçando": "inçar",
    "inçara": "inçar",
    "inçaram": "inçar",
    "inçaras": "inçar",
    "inçarde": "inçar",
    "inçardes": "inçar",
    "inçare": "inçar",
    "inçarei": "inçar",
    "inçareis": "inçar",
    "inçarem": "inçar",
    "inçaremos": "inçar",
    "inçares": "inçar",
    "inçaria": "inçar",
    "inçariam": "inçar",
    "inçarias": "inçar",
    "inçarmo": "inçar",
    "inçarmos": "inçar",
    "inçará": "inçar",
    "inçarás": "inçar",
    "inçarão": "inçar",
    "inçaríamos": "inçar",
    "inçaríeis": "inçar",
    "inças": "inçar",
    "inçasse": "inçar",
    "inçassem": "inçar",
    "inçasses": "inçar",
    "inçaste": "inçar",
    "inçastes": "inçar",
    "inçava": "inçar",
    "inçavam": "inçar",
    "inçavas": "inçar",
    "inço": "inçar",
    "inçou": "inçar",
    "inçá": "inçar",
    "inçámo": "inçar",
    "inçámos": "inçar",
    "inçáramo": "inçar",
    "inçáramos": "inçar",
    "inçárei": "inçar",
    "inçáreis": "inçar",
    "inçásseis": "inçar",
    "inçássemos": "inçar",
    "inçávamo": "inçar",
    "inçávamos": "inçar",
    "inçávei": "inçar",
    "inçáveis": "inçar",
    "inédias": "inédia",
    "inédita": "inédito",
    "inéditas": "inédito",
    "inéditos": "inédito",
    "inépcias": "inépcia",
    "inércias": "inércia",
    "inérvea": "inérveo",
    "inérveas": "inérveo",
    "inérveos": "inérveo",
    "inícios": "início",
    "iníqua": "iníquo",
    "iníquas": "iníquo",
    "iníquos": "iníquo",
    "inócua": "inócuo",
    "inócuas": "inócuo",
    "inócuos": "inócuo",
    "inópias": "inópia",
    "inóspita": "inóspito",
    "inóspitas": "inóspito",
    "inóspitos": "inóspito",
    "inóxia": "inóxio",
    "inóxias": "inóxio",
    "inóxios": "inóxio",
    "inúbias": "inúbia",
    "inúbis": "inúbil",
    "inúmera": "inúmero",
    "inúmeras": "inúmero",
    "inúmeros": "inúmero",
    "inúteis": "inútil",
    "ioda": "iodar",
    "iodada": "iodar",
    "iodadas": "iodar",
    "iodado": "iodar",
    "iodados": "iodar",
    "iodai": "iodar",
    "iodais": "iodar",
    "iodam": "iodar",
    "iodamo": "iodar",
    "iodamos": "iodar",
    "iodando": "iodar",
    "iodara": "iodar",
    "iodaram": "iodar",
    "iodaras": "iodar",
    "iodarde": "iodar",
    "iodardes": "iodar",
    "iodare": "iodar",
    "iodarei": "iodar",
    "iodareis": "iodar",
    "iodarem": "iodar",
    "iodaremos": "iodar",
    "iodares": "iodar",
    "iodargírios": "iodargírio",
    "iodaria": "iodar",
    "iodariam": "iodar",
    "iodarias": "iodar",
    "iodarmo": "iodar",
    "iodarmos": "iodar",
    "iodará": "iodar",
    "iodarás": "iodar",
    "iodarão": "iodar",
    "iodaríamos": "iodar",
    "iodaríeis": "iodar",
    "iodas": "iodar",
    "iodasse": "iodar",
    "iodassem": "iodar",
    "iodasses": "iodar",
    "iodaste": "iodar",
    "iodastes": "iodar",
    "iodatos": "iodato",
    "iodava": "iodar",
    "iodavam": "iodar",
    "iodavas": "iodar",
    "iode": "iodar",
    "iodei": "iodar",
    "iodeis": "iodar",
    "iodem": "iodar",
    "iodemo": "iodar",
    "iodemos": "iodar",
    "iodes": "iode",
    "iodetos": "iodeto",
    "iodimetrias": "iodimetria",
    "iodinas": "iodina",
    "iodismos": "iodismo",
    "iodites": "iodite",
    "iodo": "iodar",
    "iodofórmios": "iodofórmio",
    "iodos": "iodo",
    "iodoterapias": "iodoterapia",
    "iodoterápica": "iodoterápico",
    "iodoterápicas": "iodoterápico",
    "iodoterápicos": "iodoterápico",
    "iodou": "iodar",
    "iodá": "iodar",
    "iodámo": "iodar",
    "iodámos": "iodar",
    "iodáramo": "iodar",
    "iodáramos": "iodar",
    "iodárei": "iodar",
    "iodáreis": "iodar",
    "iodásseis": "iodar",
    "iodássemos": "iodar",
    "iodávamo": "iodar",
    "iodávamos": "iodar",
    "iodávei": "iodar",
    "iodáveis": "iodável",
    "iodídrica": "iodídrico",
    "iodídricas": "iodídrico",
    "iodídricos": "iodídrico",
    "iodífera": "iodífero",
    "iodíferas": "iodífero",
    "iodíferos": "iodífero",
    "iodóis": "iodol",
    "iodómetros": "iodómetro",
    "iofobias": "iofobia",
    "iogacaras": "iogacara",
    "iogas": "ioga",
    "iogues": "iogue",
    "iogurteiras": "iogurteira",
    "iogurtes": "iogurte",
    "ioiôs": "ioiô",
    "ioles": "iole",
    "iologias": "iologia",
    "ioniza": "ionizar",
    "ionizada": "ionizar",
    "ionizadas": "ionizar",
    "ionizado": "ionizar",
    "ionizados": "ionizar",
    "ionizai": "ionizar",
    "ionizais": "ionizar",
    "ionizam": "ionizar",
    "ionizamo": "ionizar",
    "ionizamos": "ionizar",
    "ionizando": "ionizar",
    "ionizantes": "ionizante",
    "ionizara": "ionizar",
    "ionizaram": "ionizar",
    "ionizaras": "ionizar",
    "ionizarde": "ionizar",
    "ionizardes": "ionizar",
    "ionizare": "ionizar",
    "ionizarei": "ionizar",
    "ionizareis": "ionizar",
    "ionizarem": "ionizar",
    "ionizaremos": "ionizar",
    "ionizares": "ionizar",
    "ionizaria": "ionizar",
    "ionizariam": "ionizar",
    "ionizarias": "ionizar",
    "ionizarmo": "ionizar",
    "ionizarmos": "ionizar",
    "ionizará": "ionizar",
    "ionizarás": "ionizar",
    "ionizarão": "ionizar",
    "ionizaríamos": "ionizar",
    "ionizaríeis": "ionizar",
    "ionizas": "ionizar",
    "ionizasse": "ionizar",
    "ionizassem": "ionizar",
    "ionizasses": "ionizar",
    "ionizaste": "ionizar",
    "ionizastes": "ionizar",
    "ionizava": "ionizar",
    "ionizavam": "ionizar",
    "ionizavas": "ionizar",
    "ionizações": "ionização",
    "ionize": "ionizar",
    "ionizei": "ionizar",
    "ionizeis": "ionizar",
    "ionizem": "ionizar",
    "ionizemo": "ionizar",
    "ionizemos": "ionizar",
    "ionizes": "ionizar",
    "ionizo": "ionizar",
    "ionizou": "ionizar",
    "ionizá": "ionizar",
    "ionizámo": "ionizar",
    "ionizámos": "ionizar",
    "ionizáramo": "ionizar",
    "ionizáramos": "ionizar",
    "ionizárei": "ionizar",
    "ionizáreis": "ionizar",
    "ionizásseis": "ionizar",
    "ionizássemos": "ionizar",
    "ionizávamo": "ionizar",
    "ionizávamos": "ionizar",
    "ionizávei": "ionizar",
    "ionizáveis": "ionizar",
    "iononas": "ionona",
    "ionosferas": "ionosfera",
    "iontes": "ionte",
    "iontoforeses": "iontoforese",
    "iorquina": "iorquino",
    "iorquinas": "iorquino",
    "iorquinos": "iorquino",
    "iotacismos": "iotacismo",
    "iotas": "iota",
    "iotiza": "iotizar",
    "iotizada": "iotizar",
    "iotizadas": "iotizar",
    "iotizado": "iotizar",
    "iotizados": "iotizar",
    "iotizai": "iotizar",
    "iotizais": "iotizar",
    "iotizam": "iotizar",
    "iotizamo": "iotizar",
    "iotizamos": "iotizar",
    "iotizando": "iotizar",
    "iotizara": "iotizar",
    "iotizaram": "iotizar",
    "iotizaras": "iotizar",
    "iotizarde": "iotizar",
    "iotizardes": "iotizar",
    "iotizare": "iotizar",
    "iotizarei": "iotizar",
    "iotizareis": "iotizar",
    "iotizarem": "iotizar",
    "iotizaremos": "iotizar",
    "iotizares": "iotizar",
    "iotizaria": "iotizar",
    "iotizariam": "iotizar",
    "iotizarias": "iotizar",
    "iotizarmo": "iotizar",
    "iotizarmos": "iotizar",
    "iotizará": "iotizar",
    "iotizarás": "iotizar",
    "iotizarão": "iotizar",
    "iotizaríamos": "iotizar",
    "iotizaríeis": "iotizar",
    "iotizas": "iotizar",
    "iotizasse": "iotizar",
    "iotizassem": "iotizar",
    "iotizasses": "iotizar",
    "iotizaste": "iotizar",
    "iotizastes": "iotizar",
    "iotizava": "iotizar",
    "iotizavam": "iotizar",
    "iotizavas": "iotizar",
    "iotizações": "iotização",
    "iotize": "iotizar",
    "iotizei": "iotizar",
    "iotizeis": "iotizar",
    "iotizem": "iotizar",
    "iotizemo": "iotizar",
    "iotizemos": "iotizar",
    "iotizes": "iotizar",
    "iotizo": "iotizar",
    "iotizou": "iotizar",
    "iotizá": "iotizar",
    "iotizámo": "iotizar",
    "iotizámos": "iotizar",
    "iotizáramo": "iotizar",
    "iotizáramos": "iotizar",
    "iotizárei": "iotizar",
    "iotizáreis": "iotizar",
    "iotizásseis": "iotizar",
    "iotizássemos": "iotizar",
    "iotizávamo": "iotizar",
    "iotizávamos": "iotizar",
    "iotizávei": "iotizar",
    "iotizáveis": "iotizar",
    "iperites": "iperite",
    "ipombos": "ipombo",
    "ipos": "ipo",
    "ipseidades": "ipseidade",
    "ipsilones": "ipsilone",
    "ipsilons": "ipsilon",
    "ira": "irar",
    "iracemapolenses": "iracemapolense",
    "iracunda": "iracundo",
    "iracundas": "iracundo",
    "iracundos": "iracundo",
    "iracúndias": "iracúndia",
    "irada": "irar",
    "iradas": "irar",
    "irado": "irar",
    "irados": "irar",
    "iradíssima": "irado",
    "iradíssimas": "irado",
    "iradíssimo": "irado",
    "iradíssimos": "irado",
    "irai": "irar",
    "irais": "irar",
    "iram": "irar",
    "iramo": "irar",
    "iramos": "irar",
    "irando": "irar",
    "iraniana": "iraniano",
    "iranianas": "iraniano",
    "iranianos": "iraniano",
    "iraquiana": "iraquiano",
    "iraquianas": "iraquiano",
    "iraquianos": "iraquiano",
    "irara": "irar",
    "iraram": "irar",
    "iraras": "irar",
    "irarde": "irar",
    "irardes": "irar",
    "irare": "irar",
    "irarei": "irar",
    "irareis": "irar",
    "irarem": "irar",
    "iraremos": "irar",
    "irares": "irar",
    "iraria": "irar",
    "irariam": "irar",
    "irarias": "irar",
    "irarmo": "irar",
    "irarmos": "irar",
    "irará": "irar",
    "irarás": "irar",
    "irarão": "irar",
    "iraríamos": "irar",
    "iraríeis": "irar",
    "iras": "irar",
    "irascibilidades": "irascibilidade",
    "irascíveis": "irascível",
    "irasse": "irar",
    "irassem": "irar",
    "irasses": "irar",
    "iraste": "irar",
    "irastes": "irar",
    "irava": "irar",
    "iravam": "irar",
    "iravas": "irar",
    "iraíbas": "iraíba",
    "irde": "ir",
    "irdes": "ir",
    "ire": "irar",
    "irei": "irar",
    "ireis": "irar",
    "irem": "irar",
    "iremo": "irar",
    "iremos": "irar",
    "irenistas": "irenista",
    "irerismos": "irerismo",
    "ires": "irar",
    "iria": "iriar",
    "iriada": "iriar",
    "iriadas": "iriar",
    "iriado": "iriar",
    "iriados": "iriar",
    "iriai": "iriar",
    "iriais": "iriar",
    "iriam": "iriar",
    "iriamo": "iriar",
    "iriamos": "iriar",
    "iriando": "iriar",
    "iriantes": "iriante",
    "iriara": "iriar",
    "iriaram": "iriar",
    "iriaras": "iriar",
    "iriarde": "iriar",
    "iriardes": "iriar",
    "iriare": "iriar",
    "iriarei": "iriar",
    "iriareis": "iriar",
    "iriarem": "iriar",
    "iriaremos": "iriar",
    "iriares": "iriar",
    "iriaria": "iriar",
    "iriariam": "iriar",
    "iriarias": "iriar",
    "iriarmo": "iriar",
    "iriarmos": "iriar",
    "iriará": "iriar",
    "iriarás": "iriar",
    "iriarão": "iriar",
    "iriaríamos": "iriar",
    "iriaríeis": "iriar",
    "irias": "iriar",
    "iriasse": "iriar",
    "iriassem": "iriar",
    "iriasses": "iriar",
    "iriaste": "iriar",
    "iriastes": "iriar",
    "iriava": "iriar",
    "iriavam": "iriar",
    "iriavas": "iriar",
    "iriações": "iriação",
    "iridações": "iridação",
    "iridectomias": "iridectomia",
    "iridectopias": "iridectopia",
    "iridemias": "iridemia",
    "iridescentes": "iridescente",
    "iridocinesias": "iridocinesia",
    "iridotomias": "iridotomia",
    "iridáceas": "iridácea",
    "iridífera": "iridífero",
    "iridíferas": "iridífero",
    "iridíferos": "iridífero",
    "irie": "iriar",
    "iriei": "iriar",
    "irieis": "iriar",
    "iriem": "iriar",
    "iriemo": "iriar",
    "iriemos": "iriar",
    "iries": "iriar",
    "irio": "iriar",
    "iriou": "iriar",
    "irisa": "irisar",
    "irisada": "irisar",
    "irisadas": "irisar",
    "irisado": "irisar",
    "irisados": "irisar",
    "irisai": "irisar",
    "irisais": "irisar",
    "irisam": "irisar",
    "irisamo": "irisar",
    "irisamos": "irisar",
    "irisando": "irisar",
    "irisara": "irisar",
    "irisaram": "irisar",
    "irisaras": "irisar",
    "irisarde": "irisar",
    "irisardes": "irisar",
    "irisare": "irisar",
    "irisarei": "irisar",
    "irisareis": "irisar",
    "irisarem": "irisar",
    "irisaremos": "irisar",
    "irisares": "irisar",
    "irisaria": "irisar",
    "irisariam": "irisar",
    "irisarias": "irisar",
    "irisarmo": "irisar",
    "irisarmos": "irisar",
    "irisará": "irisar",
    "irisarás": "irisar",
    "irisarão": "irisar",
    "irisaríamos": "irisar",
    "irisaríeis": "irisar",
    "irisas": "irisar",
    "irisasse": "irisar",
    "irisassem": "irisar",
    "irisasses": "irisar",
    "irisaste": "irisar",
    "irisastes": "irisar",
    "irisava": "irisar",
    "irisavam": "irisar",
    "irisavas": "irisar",
    "irisações": "irisação",
    "irise": "irisar",
    "irisei": "irisar",
    "iriseis": "irisar",
    "irisem": "irisar",
    "irisemo": "irisar",
    "irisemos": "irisar",
    "irises": "irisar",
    "iriso": "irisar",
    "irisou": "irisar",
    "irisá": "irisar",
    "irisámo": "irisar",
    "irisámos": "irisar",
    "irisáramo": "irisar",
    "irisáramos": "irisar",
    "irisárei": "irisar",
    "irisáreis": "irisar",
    "irisásseis": "irisar",
    "irisássemos": "irisar",
    "irisávamo": "irisar",
    "irisávamos": "irisar",
    "irisávei": "irisar",
    "irisáveis": "irisar",
    "irites": "irite",
    "irizes": "iriz",
    "iriá": "iriar",
    "iriámo": "iriar",
    "iriámos": "iriar",
    "iriáramo": "iriar",
    "iriáramos": "iriar",
    "iriárei": "iriar",
    "iriáreis": "iriar",
    "iriásseis": "iriar",
    "iriássemos": "iriar",
    "iriávamo": "iriar",
    "iriávamos": "iriar",
    "iriávei": "iriar",
    "iriáveis": "iriar",
    "irlandas": "irlanda",
    "irlandesa": "irlandês",
    "irlandesas": "irlandês",
    "irlandeses": "irlandês",
    "irmana": "irmanar",
    "irmanada": "irmanar",
    "irmanadas": "irmanar",
    "irmanado": "irmanar",
    "irmanados": "irmanar",
    "irmanai": "irmanar",
    "irmanais": "irmanar",
    "irmanam": "irmanar",
    "irmanamo": "irmanar",
    "irmanamos": "irmanar",
    "irmanando": "irmanar",
    "irmanara": "irmanar",
    "irmanaram": "irmanar",
    "irmanaras": "irmanar",
    "irmanarde": "irmanar",
    "irmanardes": "irmanar",
    "irmanare": "irmanar",
    "irmanarei": "irmanar",
    "irmanareis": "irmanar",
    "irmanarem": "irmanar",
    "irmanaremos": "irmanar",
    "irmanares": "irmanar",
    "irmanaria": "irmanar",
    "irmanariam": "irmanar",
    "irmanarias": "irmanar",
    "irmanarmo": "irmanar",
    "irmanarmos": "irmanar",
    "irmanará": "irmanar",
    "irmanarás": "irmanar",
    "irmanarão": "irmanar",
    "irmanaríamos": "irmanar",
    "irmanaríeis": "irmanar",
    "irmanas": "irmanar",
    "irmanasse": "irmanar",
    "irmanassem": "irmanar",
    "irmanasses": "irmanar",
    "irmanaste": "irmanar",
    "irmanastes": "irmanar",
    "irmanava": "irmanar",
    "irmanavam": "irmanar",
    "irmanavas": "irmanar",
    "irmanações": "irmanação",
    "irmandades": "irmandade",
    "irmane": "irmanar",
    "irmanei": "irmanar",
    "irmaneis": "irmanar",
    "irmanem": "irmanar",
    "irmanemo": "irmanar",
    "irmanemos": "irmanar",
    "irmanes": "irmanar",
    "irmano": "irmanar",
    "irmanou": "irmanar",
    "irmaná": "irmanar",
    "irmanámo": "irmanar",
    "irmanámos": "irmanar",
    "irmanáramo": "irmanar",
    "irmanáramos": "irmanar",
    "irmanárei": "irmanar",
    "irmanáreis": "irmanar",
    "irmanásseis": "irmanar",
    "irmanássemos": "irmanar",
    "irmanávamo": "irmanar",
    "irmanávamos": "irmanar",
    "irmanávei": "irmanar",
    "irmanáveis": "irmanável",
    "irmo": "ir",
    "irmos": "ir",
    "irmã": "irmão",
    "irmãos": "irmão",
    "irmãozinho": "irmão",
    "irmãozinhos": "irmão",
    "irmãozito": "irmão",
    "irmãozitos": "irmão",
    "irmãs": "irmão",
    "irmãzinha": "irmão",
    "irmãzinhas": "irmão",
    "irmãzita": "irmão",
    "irmãzitas": "irmão",
    "iro": "irar",
    "ironias": "ironia",
    "ironismos": "ironismo",
    "ironistas": "ironista",
    "ironiza": "ironizar",
    "ironizada": "ironizar",
    "ironizadas": "ironizar",
    "ironizado": "ironizar",
    "ironizados": "ironizar",
    "ironizai": "ironizar",
    "ironizais": "ironizar",
    "ironizam": "ironizar",
    "ironizamo": "ironizar",
    "ironizamos": "ironizar",
    "ironizando": "ironizar",
    "ironizara": "ironizar",
    "ironizaram": "ironizar",
    "ironizaras": "ironizar",
    "ironizarde": "ironizar",
    "ironizardes": "ironizar",
    "ironizare": "ironizar",
    "ironizarei": "ironizar",
    "ironizareis": "ironizar",
    "ironizarem": "ironizar",
    "ironizaremos": "ironizar",
    "ironizares": "ironizar",
    "ironizaria": "ironizar",
    "ironizariam": "ironizar",
    "ironizarias": "ironizar",
    "ironizarmo": "ironizar",
    "ironizarmos": "ironizar",
    "ironizará": "ironizar",
    "ironizarás": "ironizar",
    "ironizarão": "ironizar",
    "ironizaríamos": "ironizar",
    "ironizaríeis": "ironizar",
    "ironizas": "ironizar",
    "ironizasse": "ironizar",
    "ironizassem": "ironizar",
    "ironizasses": "ironizar",
    "ironizaste": "ironizar",
    "ironizastes": "ironizar",
    "ironizava": "ironizar",
    "ironizavam": "ironizar",
    "ironizavas": "ironizar",
    "ironize": "ironizar",
    "ironizei": "ironizar",
    "ironizeis": "ironizar",
    "ironizem": "ironizar",
    "ironizemo": "ironizar",
    "ironizemos": "ironizar",
    "ironizes": "ironizar",
    "ironizo": "ironizar",
    "ironizou": "ironizar",
    "ironizá": "ironizar",
    "ironizámo": "ironizar",
    "ironizámos": "ironizar",
    "ironizáramo": "ironizar",
    "ironizáramos": "ironizar",
    "ironizárei": "ironizar",
    "ironizáreis": "ironizar",
    "ironizásseis": "ironizar",
    "ironizássemos": "ironizar",
    "ironizávamo": "ironizar",
    "ironizávamos": "ironizar",
    "ironizávei": "ironizar",
    "ironizáveis": "ironizável",
    "iroquesa": "iroquês",
    "iroquesas": "iroquês",
    "iroqueses": "iroquês",
    "irosa": "iroso",
    "irosas": "iroso",
    "irosos": "iroso",
    "irou": "irar",
    "irracionais": "irracional",
    "irracionalidades": "irracionalidade",
    "irracionalismos": "irracionalismo",
    "irracionáveis": "irracionável",
    "irradia": "irradiar",
    "irradiada": "irradiar",
    "irradiadas": "irradiar",
    "irradiado": "irradiar",
    "irradiadora": "irradiador",
    "irradiadoras": "irradiador",
    "irradiadores": "irradiador",
    "irradiados": "irradiar",
    "irradiai": "irradiar",
    "irradiais": "irradiar",
    "irradiam": "irradiar",
    "irradiamo": "irradiar",
    "irradiamos": "irradiar",
    "irradiando": "irradiar",
    "irradiantes": "irradiante",
    "irradiara": "irradiar",
    "irradiaram": "irradiar",
    "irradiaras": "irradiar",
    "irradiarde": "irradiar",
    "irradiardes": "irradiar",
    "irradiare": "irradiar",
    "irradiarei": "irradiar",
    "irradiareis": "irradiar",
    "irradiarem": "irradiar",
    "irradiaremos": "irradiar",
    "irradiares": "irradiar",
    "irradiaria": "irradiar",
    "irradiariam": "irradiar",
    "irradiarias": "irradiar",
    "irradiarmo": "irradiar",
    "irradiarmos": "irradiar",
    "irradiará": "irradiar",
    "irradiarás": "irradiar",
    "irradiarão": "irradiar",
    "irradiaríamos": "irradiar",
    "irradiaríeis": "irradiar",
    "irradias": "irradiar",
    "irradiasse": "irradiar",
    "irradiassem": "irradiar",
    "irradiasses": "irradiar",
    "irradiaste": "irradiar",
    "irradiastes": "irradiar",
    "irradiava": "irradiar",
    "irradiavam": "irradiar",
    "irradiavas": "irradiar",
    "irradiações": "irradiação",
    "irradicações": "irradicação",
    "irradie": "irradiar",
    "irradiei": "irradiar",
    "irradieis": "irradiar",
    "irradiem": "irradiar",
    "irradiemo": "irradiar",
    "irradiemos": "irradiar",
    "irradies": "irradiar",
    "irradio": "irradiar",
    "irradiosa": "irradioso",
    "irradiosas": "irradioso",
    "irradiosos": "irradioso",
    "irradiou": "irradiar",
    "irradiá": "irradiar",
    "irradiámo": "irradiar",
    "irradiámos": "irradiar",
    "irradiáramo": "irradiar",
    "irradiáramos": "irradiar",
    "irradiárei": "irradiar",
    "irradiáreis": "irradiar",
    "irradiásseis": "irradiar",
    "irradiássemos": "irradiar",
    "irradiávamo": "irradiar",
    "irradiávamos": "irradiar",
    "irradiávei": "irradiar",
    "irradiáveis": "irradiar",
    "irreais": "irreal",
    "irreajustabilidades": "irreajustabilidade",
    "irrealidades": "irrealidade",
    "irrealismos": "irrealismo",
    "irrealistas": "irrealista",
    "irrealizabilidades": "irrealizabilidade",
    "irrealizáveis": "irrealizável",
    "irreclamabilidades": "irreclamabilidade",
    "irreclamáveis": "irreclamável",
    "irrecobrabilidades": "irrecobrabilidade",
    "irreconciliabilidades": "irreconciliabilidade",
    "irreconciliada": "irreconciliado",
    "irreconciliadas": "irreconciliado",
    "irreconciliados": "irreconciliado",
    "irreconciliáveis": "irreconciliável",
    "irreconhecibilidades": "irreconhecibilidade",
    "irreconhecíveis": "irreconhecível",
    "irrecorribilidades": "irrecorribilidade",
    "irrecorríveis": "irrecorrível",
    "irrecuperabilidades": "irrecuperabilidade",
    "irrecuperáveis": "irrecuperável",
    "irrecusabilidades": "irrecusabilidade",
    "irrecusáveis": "irrecusável",
    "irredarguíveis": "irredarguível",
    "irredenta": "irredento",
    "irredentas": "irredento",
    "irredentismos": "irredentismo",
    "irredentistas": "irredentista",
    "irredentos": "irredento",
    "irredimíveis": "irredimível",
    "irredutibilidades": "irredutibilidade",
    "irredutíveis": "irredutível",
    "irreduzíveis": "irreduzível",
    "irreelegibilidades": "irreelegibilidade",
    "irreflectida": "irreflectido",
    "irreflectidas": "irreflectido",
    "irreflectidos": "irreflectido",
    "irreflexa": "irreflexo",
    "irreflexas": "irreflexo",
    "irreflexiva": "irreflexivo",
    "irreflexivas": "irreflexivo",
    "irreflexivos": "irreflexivo",
    "irreflexos": "irreflexo",
    "irreflexões": "irreflexão",
    "irreformalidades": "irreformalidade",
    "irreformáveis": "irreformável",
    "irrefragabilidades": "irrefragabilidade",
    "irrefragáveis": "irrefragável",
    "irrefrangíveis": "irrefrangível",
    "irrefreáveis": "irrefreável",
    "irrefutabilidades": "irrefutabilidade",
    "irrefutada": "irrefutado",
    "irrefutadas": "irrefutado",
    "irrefutados": "irrefutado",
    "irrefutáveis": "irrefutável",
    "irregeneráveis": "irregenerável",
    "irregressíveis": "irregressível",
    "irregulares": "irregular",
    "irregularidades": "irregularidade",
    "irreiterabilidades": "irreiterabilidade",
    "irrelevantes": "irrelevante",
    "irrelevâncias": "irrelevância",
    "irreligiosa": "irreligioso",
    "irreligiosas": "irreligioso",
    "irreligiosidades": "irreligiosidade",
    "irreligiosos": "irreligioso",
    "irreligiões": "irreligião",
    "irremediabilidades": "irremediabilidade",
    "irremediáveis": "irremediável",
    "irremeáveis": "irremeável",
    "irremissibilidades": "irremissibilidade",
    "irremissíveis": "irremissível",
    "irremitentes": "irremitente",
    "irremovibilidades": "irremovibilidade",
    "irremovíveis": "irremovível",
    "irremunerada": "irremunerado",
    "irremuneradas": "irremunerado",
    "irremunerados": "irremunerado",
    "irremuneráveis": "irremunerável",
    "irremíveis": "irremível",
    "irrenumerabilidades": "irrenumerabilidade",
    "irrenunciabilidades": "irrenunciabilidade",
    "irrenunciáveis": "irrenunciável",
    "irreparabilidades": "irreparabilidade",
    "irrepartíveis": "irrepartível",
    "irreparáveis": "irreparável",
    "irrepetíveis": "irrepetível",
    "irrepleta": "irrepleto",
    "irrepletas": "irrepleto",
    "irrepletos": "irrepleto",
    "irreplicáveis": "irreplicável",
    "irrepreensibilidades": "irrepreensibilidade",
    "irrepreensíveis": "irrepreensível",
    "irrepresentabilidades": "irrepresentabilidade",
    "irrepresentáveis": "irrepresentável",
    "irrepressíveis": "irrepressível",
    "irreprimibilidades": "irreprimibilidade",
    "irreprimíveis": "irreprimível",
    "irrequieta": "irrequieto",
    "irrequietas": "irrequieto",
    "irrequietismos": "irrequietismo",
    "irrequietos": "irrequieto",
    "irrescindibilidades": "irrescindibilidade",
    "irresgatabilidades": "irresgatabilidade",
    "irresgatáveis": "irresgatável",
    "irresignabilidades": "irresignabilidade",
    "irresignáveis": "irresignável",
    "irresistentes": "irresistente",
    "irresistibilidades": "irresistibilidade",
    "irresistências": "irresistência",
    "irresistíveis": "irresistível",
    "irresoluta": "irresoluto",
    "irresolutas": "irresoluto",
    "irresolutos": "irresoluto",
    "irresoluções": "irresolução",
    "irresolvíveis": "irresolvível",
    "irresolúveis": "irresolúvel",
    "irrespeitabilidades": "irrespeitabilidade",
    "irrespeitos": "irrespeito",
    "irrespeitosa": "irrespeitoso",
    "irrespeitosas": "irrespeitoso",
    "irrespeitosos": "irrespeitoso",
    "irrespeitáveis": "irrespeitável",
    "irrespirabilidades": "irrespirabilidade",
    "irrespiráveis": "irrespirável",
    "irrespondíveis": "irrespondível",
    "irresponsabilidades": "irresponsabilidade",
    "irresponsáveis": "irresponsável",
    "irrestauráveis": "irrestaurável",
    "irrestituíveis": "irrestituível",
    "irrestribilidades": "irrestribilidade",
    "irrestringíveis": "irrestringível",
    "irrestrita": "irrestrito",
    "irrestritas": "irrestrito",
    "irrestritos": "irrestrito",
    "irretorquíveis": "irretorquível",
    "irretratabilidades": "irretratabilidade",
    "irretratáveis": "irretratável",
    "irretroactividades": "irretroactividade",
    "irreverencia": "irreverenciar",
    "irreverenciada": "irreverenciar",
    "irreverenciadas": "irreverenciar",
    "irreverenciado": "irreverenciar",
    "irreverenciados": "irreverenciar",
    "irreverenciai": "irreverenciar",
    "irreverenciais": "irreverenciar",
    "irreverenciam": "irreverenciar",
    "irreverenciamo": "irreverenciar",
    "irreverenciamos": "irreverenciar",
    "irreverenciando": "irreverenciar",
    "irreverenciara": "irreverenciar",
    "irreverenciaram": "irreverenciar",
    "irreverenciaras": "irreverenciar",
    "irreverenciardes": "irreverenciar",
    "irreverenciarei": "irreverenciar",
    "irreverenciareis": "irreverenciar",
    "irreverenciarem": "irreverenciar",
    "irreverenciaremos": "irreverenciar",
    "irreverenciares": "irreverenciar",
    "irreverenciaria": "irreverenciar",
    "irreverenciariam": "irreverenciar",
    "irreverenciarias": "irreverenciar",
    "irreverenciarmo": "irreverenciar",
    "irreverenciarmos": "irreverenciar",
    "irreverenciará": "irreverenciar",
    "irreverenciarás": "irreverenciar",
    "irreverenciarão": "irreverenciar",
    "irreverenciaríamos": "irreverenciar",
    "irreverenciaríeis": "irreverenciar",
    "irreverencias": "irreverenciar",
    "irreverenciasse": "irreverenciar",
    "irreverenciassem": "irreverenciar",
    "irreverenciasses": "irreverenciar",
    "irreverenciaste": "irreverenciar",
    "irreverenciastes": "irreverenciar",
    "irreverenciava": "irreverenciar",
    "irreverenciavam": "irreverenciar",
    "irreverenciavas": "irreverenciar",
    "irreverencie": "irreverenciar",
    "irreverenciei": "irreverenciar",
    "irreverencieis": "irreverenciar",
    "irreverenciem": "irreverenciar",
    "irreverenciemo": "irreverenciar",
    "irreverenciemos": "irreverenciar",
    "irreverencies": "irreverenciar",
    "irreverencio": "irreverenciar",
    "irreverenciosa": "irreverencioso",
    "irreverenciosas": "irreverencioso",
    "irreverenciosos": "irreverencioso",
    "irreverenciou": "irreverenciar",
    "irreverenciámo": "irreverenciar",
    "irreverenciámos": "irreverenciar",
    "irreverenciáramo": "irreverenciar",
    "irreverenciáramos": "irreverenciar",
    "irreverenciáreis": "irreverenciar",
    "irreverenciásseis": "irreverenciar",
    "irreverenciássemos": "irreverenciar",
    "irreverenciávamo": "irreverenciar",
    "irreverenciávamos": "irreverenciar",
    "irreverenciáveis": "irreverenciar",
    "irreverentes": "irreverente",
    "irreversilibidades": "irreversilibidade",
    "irreversíveis": "irreversível",
    "irreverências": "irreverência",
    "irrevocabilidades": "irrevocabilidade",
    "irrevocáveis": "irrevocável",
    "irrevogabilidades": "irrevogabilidade",
    "irrevogada": "irrevogado",
    "irrevogadas": "irrevogado",
    "irrevogados": "irrevogado",
    "irrevogáveis": "irrevogável",
    "irridentes": "irridente",
    "irriga": "irrigar",
    "irrigada": "irrigar",
    "irrigadas": "irrigar",
    "irrigado": "irrigar",
    "irrigadores": "irrigador",
    "irrigados": "irrigar",
    "irrigai": "irrigar",
    "irrigais": "irrigar",
    "irrigam": "irrigar",
    "irrigamo": "irrigar",
    "irrigamos": "irrigar",
    "irrigando": "irrigar",
    "irrigara": "irrigar",
    "irrigaram": "irrigar",
    "irrigaras": "irrigar",
    "irrigarde": "irrigar",
    "irrigardes": "irrigar",
    "irrigare": "irrigar",
    "irrigarei": "irrigar",
    "irrigareis": "irrigar",
    "irrigarem": "irrigar",
    "irrigaremos": "irrigar",
    "irrigares": "irrigar",
    "irrigaria": "irrigar",
    "irrigariam": "irrigar",
    "irrigarias": "irrigar",
    "irrigarmo": "irrigar",
    "irrigarmos": "irrigar",
    "irrigará": "irrigar",
    "irrigarás": "irrigar",
    "irrigarão": "irrigar",
    "irrigaríamos": "irrigar",
    "irrigaríeis": "irrigar",
    "irrigas": "irrigar",
    "irrigasse": "irrigar",
    "irrigassem": "irrigar",
    "irrigasses": "irrigar",
    "irrigaste": "irrigar",
    "irrigastes": "irrigar",
    "irrigatória": "irrigatório",
    "irrigatórias": "irrigatório",
    "irrigatórios": "irrigatório",
    "irrigava": "irrigar",
    "irrigavam": "irrigar",
    "irrigavas": "irrigar",
    "irrigações": "irrigação",
    "irrigo": "irrigar",
    "irrigou": "irrigar",
    "irrigue": "irrigar",
    "irriguei": "irrigar",
    "irrigueis": "irrigar",
    "irriguem": "irrigar",
    "irriguemo": "irrigar",
    "irriguemos": "irrigar",
    "irrigues": "irrigar",
    "irrigá": "irrigar",
    "irrigámo": "irrigar",
    "irrigámos": "irrigar",
    "irrigáramo": "irrigar",
    "irrigáramos": "irrigar",
    "irrigárei": "irrigar",
    "irrigáreis": "irrigar",
    "irrigásseis": "irrigar",
    "irrigássemos": "irrigar",
    "irrigávamo": "irrigar",
    "irrigávamos": "irrigar",
    "irrigávei": "irrigar",
    "irrigáveis": "irrigável",
    "irrisora": "irrisor",
    "irrisoras": "irrisor",
    "irrisores": "irrisor",
    "irrisória": "irrisório",
    "irrisórias": "irrisório",
    "irrisórios": "irrisório",
    "irrisões": "irrisão",
    "irrita": "irritar",
    "irritabilidades": "irritabilidade",
    "irritada": "irritar",
    "irritadas": "irritar",
    "irritadiça": "irritadiço",
    "irritadiças": "irritadiço",
    "irritadiços": "irritadiço",
    "irritado": "irritar",
    "irritadora": "irritador",
    "irritadoras": "irritador",
    "irritadores": "irritador",
    "irritados": "irritar",
    "irritadíssima": "irritado",
    "irritadíssimas": "irritado",
    "irritadíssimo": "irritado",
    "irritadíssimos": "irritado",
    "irritai": "irritar",
    "irritais": "irritar",
    "irritam": "irritar",
    "irritamentos": "irritamento",
    "irritamo": "irritar",
    "irritamos": "irritar",
    "irritando": "irritar",
    "irritantes": "irritante",
    "irritara": "irritar",
    "irritaram": "irritar",
    "irritaras": "irritar",
    "irritarde": "irritar",
    "irritardes": "irritar",
    "irritare": "irritar",
    "irritarei": "irritar",
    "irritareis": "irritar",
    "irritarem": "irritar",
    "irritaremos": "irritar",
    "irritares": "irritar",
    "irritaria": "irritar",
    "irritariam": "irritar",
    "irritarias": "irritar",
    "irritarmo": "irritar",
    "irritarmos": "irritar",
    "irritará": "irritar",
    "irritarás": "irritar",
    "irritarão": "irritar",
    "irritaríamos": "irritar",
    "irritaríeis": "irritar",
    "irritas": "irritar",
    "irritasse": "irritar",
    "irritassem": "irritar",
    "irritasses": "irritar",
    "irritaste": "irritar",
    "irritastes": "irritar",
    "irritativa": "irritativo",
    "irritativas": "irritativo",
    "irritativos": "irritativo",
    "irritava": "irritar",
    "irritavam": "irritar",
    "irritavas": "irritar",
    "irritações": "irritação",
    "irrite": "irritar",
    "irritei": "irritar",
    "irriteis": "irritar",
    "irritem": "irritar",
    "irritemo": "irritar",
    "irritemos": "irritar",
    "irrites": "irritar",
    "irrito": "irritar",
    "irritou": "irritar",
    "irritá": "irritar",
    "irritámo": "irritar",
    "irritámos": "irritar",
    "irritáramo": "irritar",
    "irritáramos": "irritar",
    "irritárei": "irritar",
    "irritáreis": "irritar",
    "irritásseis": "irritar",
    "irritássemos": "irritar",
    "irritávamo": "irritar",
    "irritávamos": "irritar",
    "irritávei": "irritar",
    "irritáveis": "irritável",
    "irroga": "irrogar",
    "irrogada": "irrogar",
    "irrogadas": "irrogar",
    "irrogado": "irrogar",
    "irrogados": "irrogar",
    "irrogai": "irrogar",
    "irrogais": "irrogar",
    "irrogam": "irrogar",
    "irrogamo": "irrogar",
    "irrogamos": "irrogar",
    "irrogando": "irrogar",
    "irrogara": "irrogar",
    "irrogaram": "irrogar",
    "irrogaras": "irrogar",
    "irrogarde": "irrogar",
    "irrogardes": "irrogar",
    "irrogare": "irrogar",
    "irrogarei": "irrogar",
    "irrogareis": "irrogar",
    "irrogarem": "irrogar",
    "irrogaremos": "irrogar",
    "irrogares": "irrogar",
    "irrogaria": "irrogar",
    "irrogariam": "irrogar",
    "irrogarias": "irrogar",
    "irrogarmo": "irrogar",
    "irrogarmos": "irrogar",
    "irrogará": "irrogar",
    "irrogarás": "irrogar",
    "irrogarão": "irrogar",
    "irrogaríamos": "irrogar",
    "irrogaríeis": "irrogar",
    "irrogas": "irrogar",
    "irrogasse": "irrogar",
    "irrogassem": "irrogar",
    "irrogasses": "irrogar",
    "irrogaste": "irrogar",
    "irrogastes": "irrogar",
    "irrogava": "irrogar",
    "irrogavam": "irrogar",
    "irrogavas": "irrogar",
    "irrogações": "irrogação",
    "irrogo": "irrogar",
    "irrogou": "irrogar",
    "irrogue": "irrogar",
    "irroguei": "irrogar",
    "irrogueis": "irrogar",
    "irroguem": "irrogar",
    "irroguemo": "irrogar",
    "irroguemos": "irrogar",
    "irrogues": "irrogar",
    "irrogá": "irrogar",
    "irrogámo": "irrogar",
    "irrogámos": "irrogar",
    "irrogáramo": "irrogar",
    "irrogáramos": "irrogar",
    "irrogárei": "irrogar",
    "irrogáreis": "irrogar",
    "irrogásseis": "irrogar",
    "irrogássemos": "irrogar",
    "irrogávamo": "irrogar",
    "irrogávamos": "irrogar",
    "irrogávei": "irrogar",
    "irrogáveis": "irrogar",
    "irrompa": "irromper",
    "irrompais": "irromper",
    "irrompam": "irromper",
    "irrompamo": "irromper",
    "irrompamos": "irromper",
    "irrompas": "irromper",
    "irrompe": "irromper",
    "irrompei": "irromper",
    "irrompeis": "irromper",
    "irrompem": "irromper",
    "irrompemo": "irromper",
    "irrompemos": "irromper",
    "irrompendo": "irromper",
    "irrompera": "irromper",
    "irromperam": "irromper",
    "irromperas": "irromper",
    "irromperdes": "irromper",
    "irromperei": "irromper",
    "irrompereis": "irromper",
    "irromperem": "irromper",
    "irromperemos": "irromper",
    "irromperes": "irromper",
    "irromperia": "irromper",
    "irromperiam": "irromper",
    "irromperias": "irromper",
    "irrompermo": "irromper",
    "irrompermos": "irromper",
    "irromperá": "irromper",
    "irromperás": "irromper",
    "irromperão": "irromper",
    "irromperíamos": "irromper",
    "irromperíeis": "irromper",
    "irrompes": "irromper",
    "irrompesse": "irromper",
    "irrompessem": "irromper",
    "irrompesses": "irromper",
    "irrompeste": "irromper",
    "irrompestes": "irromper",
    "irrompeu": "irromper",
    "irrompi": "irromper",
    "irrompia": "irromper",
    "irrompiam": "irromper",
    "irrompias": "irromper",
    "irrompida": "irromper",
    "irrompidas": "irromper",
    "irrompido": "irromper",
    "irrompidos": "irromper",
    "irrompimentos": "irrompimento",
    "irrompo": "irromper",
    "irrompêramo": "irromper",
    "irrompêramos": "irromper",
    "irrompêreis": "irromper",
    "irrompêsseis": "irromper",
    "irrompêssemos": "irromper",
    "irrompíamo": "irromper",
    "irrompíamos": "irromper",
    "irrompíeis": "irromper",
    "irrora": "irrorar",
    "irrorada": "irrorar",
    "irroradas": "irrorar",
    "irrorado": "irrorar",
    "irrorados": "irrorar",
    "irrorai": "irrorar",
    "irrorais": "irrorar",
    "irroram": "irrorar",
    "irroramo": "irrorar",
    "irroramos": "irrorar",
    "irrorando": "irrorar",
    "irrorara": "irrorar",
    "irroraram": "irrorar",
    "irroraras": "irrorar",
    "irrorarde": "irrorar",
    "irrorardes": "irrorar",
    "irrorare": "irrorar",
    "irrorarei": "irrorar",
    "irrorareis": "irrorar",
    "irrorarem": "irrorar",
    "irroraremos": "irrorar",
    "irrorares": "irrorar",
    "irroraria": "irrorar",
    "irrorariam": "irrorar",
    "irrorarias": "irrorar",
    "irrorarmo": "irrorar",
    "irrorarmos": "irrorar",
    "irrorará": "irrorar",
    "irrorarás": "irrorar",
    "irrorarão": "irrorar",
    "irroraríamos": "irrorar",
    "irroraríeis": "irrorar",
    "irroras": "irrorar",
    "irrorasse": "irrorar",
    "irrorassem": "irrorar",
    "irrorasses": "irrorar",
    "irroraste": "irrorar",
    "irrorastes": "irrorar",
    "irrorava": "irrorar",
    "irroravam": "irrorar",
    "irroravas": "irrorar",
    "irrorações": "irroração",
    "irrore": "irrorar",
    "irrorei": "irrorar",
    "irroreis": "irrorar",
    "irrorem": "irrorar",
    "irroremo": "irrorar",
    "irroremos": "irrorar",
    "irrores": "irrorar",
    "irroro": "irrorar",
    "irrorou": "irrorar",
    "irrorá": "irrorar",
    "irrorámo": "irrorar",
    "irrorámos": "irrorar",
    "irroráramo": "irrorar",
    "irroráramos": "irrorar",
    "irrorárei": "irrorar",
    "irroráreis": "irrorar",
    "irrorásseis": "irrorar",
    "irrorássemos": "irrorar",
    "irrorávamo": "irrorar",
    "irrorávamos": "irrorar",
    "irrorávei": "irrorar",
    "irroráveis": "irrorar",
    "irruptiva": "irruptivo",
    "irruptivas": "irruptivo",
    "irruptivos": "irruptivo",
    "irrupções": "irrupção",
    "irrígua": "irríguo",
    "irríguas": "irríguo",
    "irríguos": "irríguo",
    "irá": "irar",
    "irámo": "irar",
    "irámos": "irar",
    "iráramo": "irar",
    "iráramos": "irar",
    "irárei": "irar",
    "iráreis": "irar",
    "irás": "ir",
    "irásseis": "irar",
    "irássemos": "irar",
    "irávamo": "irar",
    "irávamos": "irar",
    "irávei": "irar",
    "iráveis": "irar",
    "irânica": "irânico",
    "irânicas": "irânico",
    "irânicos": "irânico",
    "irão": "ir",
    "iríamos": "ir",
    "irídica": "irídico",
    "irídicas": "irídico",
    "irídicos": "irídico",
    "irídios": "irídio",
    "iríeis": "ir",
    "irónica": "irónico",
    "irónicas": "irónico",
    "irónicos": "irónico",
    "isabea": "isabeo",
    "isabeas": "isabeo",
    "isabelas": "isabela",
    "isabeos": "isabeo",
    "isabéis": "isabel",
    "isadelfa": "isadelfo",
    "isadelfas": "isadelfo",
    "isadelfos": "isadelfo",
    "isagoges": "isagoge",
    "isagógica": "isagógico",
    "isagógicas": "isagógico",
    "isagógicos": "isagógico",
    "isalotérmica": "isalotérmico",
    "isalotérmicas": "isalotérmico",
    "isalotérmicos": "isalotérmico",
    "isalóbara": "isalóbaro",
    "isalóbaras": "isalóbaro",
    "isalóbaros": "isalóbaro",
    "isantinas": "isantina",
    "isanómala": "isanómalo",
    "isanómalas": "isanómalo",
    "isanómalos": "isanómalo",
    "isbas": "isba",
    "isca": "iscar",
    "iscada": "iscar",
    "iscadas": "iscar",
    "iscado": "iscar",
    "iscados": "iscar",
    "iscai": "iscar",
    "iscais": "iscar",
    "iscam": "iscar",
    "iscamo": "iscar",
    "iscamos": "iscar",
    "iscando": "iscar",
    "iscara": "iscar",
    "iscaram": "iscar",
    "iscaras": "iscar",
    "iscarde": "iscar",
    "iscardes": "iscar",
    "iscare": "iscar",
    "iscarei": "iscar",
    "iscareis": "iscar",
    "iscarem": "iscar",
    "iscaremos": "iscar",
    "iscares": "iscar",
    "iscaria": "iscar",
    "iscariam": "iscar",
    "iscarias": "iscar",
    "iscariotes": "iscariote",
    "iscariotistas": "iscariotista",
    "iscarmo": "iscar",
    "iscarmos": "iscar",
    "iscará": "iscar",
    "iscarás": "iscar",
    "iscarão": "iscar",
    "iscaríamos": "iscar",
    "iscaríeis": "iscar",
    "iscas": "iscar",
    "iscasse": "iscar",
    "iscassem": "iscar",
    "iscasses": "iscar",
    "iscaste": "iscar",
    "iscastes": "iscar",
    "iscava": "iscar",
    "iscavam": "iscar",
    "iscavas": "iscar",
    "iscnofonias": "iscnofonia",
    "isco": "iscar",
    "iscos": "isco",
    "iscou": "iscar",
    "iscá": "iscar",
    "iscámo": "iscar",
    "iscámos": "iscar",
    "iscáramo": "iscar",
    "iscáramos": "iscar",
    "iscárei": "iscar",
    "iscáreis": "iscar",
    "iscásseis": "iscar",
    "iscássemos": "iscar",
    "iscávamo": "iscar",
    "iscávamos": "iscar",
    "iscávei": "iscar",
    "iscáveis": "iscar",
    "iscúrias": "iscúria",
    "isenergéticas": "isenergética",
    "isenta": "isento",
    "isentada": "isentar",
    "isentadas": "isentar",
    "isentado": "isentar",
    "isentados": "isentar",
    "isentai": "isentar",
    "isentais": "isentar",
    "isentam": "isentar",
    "isentamo": "isentar",
    "isentamos": "isentar",
    "isentando": "isentar",
    "isentara": "isentar",
    "isentaram": "isentar",
    "isentaras": "isentar",
    "isentarde": "isentar",
    "isentardes": "isentar",
    "isentare": "isentar",
    "isentarei": "isentar",
    "isentareis": "isentar",
    "isentarem": "isentar",
    "isentaremos": "isentar",
    "isentares": "isentar",
    "isentaria": "isentar",
    "isentariam": "isentar",
    "isentarias": "isentar",
    "isentarmo": "isentar",
    "isentarmos": "isentar",
    "isentará": "isentar",
    "isentarás": "isentar",
    "isentarão": "isentar",
    "isentaríamos": "isentar",
    "isentaríeis": "isentar",
    "isentas": "isento",
    "isentasse": "isentar",
    "isentassem": "isentar",
    "isentasses": "isentar",
    "isentaste": "isentar",
    "isentastes": "isentar",
    "isentava": "isentar",
    "isentavam": "isentar",
    "isentavas": "isentar",
    "isente": "isentar",
    "isentei": "isentar",
    "isenteis": "isentar",
    "isentem": "isentar",
    "isentemo": "isentar",
    "isentemos": "isentar",
    "isentes": "isentar",
    "isento": "isentar",
    "isentos": "isento",
    "isentou": "isentar",
    "isentrópica": "isentrópico",
    "isentrópicas": "isentrópico",
    "isentrópicos": "isentrópico",
    "isentá": "isentar",
    "isentálpica": "isentálpico",
    "isentálpicas": "isentálpico",
    "isentálpicos": "isentálpico",
    "isentámo": "isentar",
    "isentámos": "isentar",
    "isentáramo": "isentar",
    "isentáramos": "isentar",
    "isentárei": "isentar",
    "isentáreis": "isentar",
    "isentásseis": "isentar",
    "isentássemos": "isentar",
    "isentávamo": "isentar",
    "isentávamos": "isentar",
    "isentávei": "isentar",
    "isentáveis": "isentável",
    "isenções": "isenção",
    "isenérgicas": "isenérgica",
    "islames": "islame",
    "islamismos": "islamismo",
    "islamistas": "islamista",
    "islamitas": "islamita",
    "islamizada": "islamizado",
    "islamizadas": "islamizado",
    "islamizados": "islamizado",
    "islamizações": "islamização",
    "islamítica": "islamítico",
    "islamíticas": "islamítico",
    "islamíticos": "islamítico",
    "islandesa": "islandês",
    "islandesas": "islandês",
    "islandeses": "islandês",
    "islenha": "islenho",
    "islenhas": "islenho",
    "islenhos": "islenho",
    "islâmica": "islâmico",
    "islâmicas": "islâmico",
    "islâmicos": "islâmico",
    "islãos": "islão",
    "islãs": "islã",
    "ismaeliana": "ismaeliano",
    "ismaelianas": "ismaeliano",
    "ismaelianos": "ismaeliano",
    "ismaelismos": "ismaelismo",
    "ismaelitas": "ismaelita",
    "ismos": "ismo",
    "isoalinas": "isoalina",
    "isobafias": "isobafia",
    "isobarométrica": "isobarométrico",
    "isobarométricas": "isobarométrico",
    "isobarométricos": "isobarométrico",
    "isobárica": "isobárico",
    "isobáricas": "isobárico",
    "isobáricos": "isobárico",
    "isoclinais": "isoclinal",
    "isoclínica": "isoclínico",
    "isoclínicas": "isoclínico",
    "isoclínicos": "isoclínico",
    "isocola": "isocolo",
    "isocolas": "isocolo",
    "isocolos": "isocolo",
    "isocolóides": "isocolóide",
    "isocotilias": "isocotilia",
    "isocromias": "isocromia",
    "isocromática": "isocromático",
    "isocromáticas": "isocromático",
    "isocromáticos": "isocromático",
    "isocronismos": "isocronismo",
    "isocrómica": "isocrómico",
    "isocrómicas": "isocrómico",
    "isocrómicos": "isocrómico",
    "isocórica": "isocórico",
    "isocóricas": "isocórico",
    "isocóricos": "isocórico",
    "isodactilias": "isodactilia",
    "isodinamias": "isodinamia",
    "isodinâmica": "isodinâmico",
    "isodinâmicas": "isodinâmico",
    "isodinâmicos": "isodinâmico",
    "isodiáfora": "isodiáforo",
    "isodiáforas": "isodiáforo",
    "isodiáforos": "isodiáforo",
    "isodáctila": "isodáctilo",
    "isodáctilas": "isodáctilo",
    "isodáctilos": "isodáctilo",
    "isoetáceas": "isoetácea",
    "isofila": "isofilo",
    "isofilas": "isofilo",
    "isofilos": "isofilo",
    "isogamias": "isogamia",
    "isogeotermas": "isogeoterma",
    "isoglossa": "isoglosso",
    "isoglossas": "isoglosso",
    "isoglossos": "isoglosso",
    "isogonais": "isogonal",
    "isografias": "isografia",
    "isográfica": "isográfico",
    "isográficas": "isográfico",
    "isográficos": "isográfico",
    "isogâmica": "isogâmico",
    "isogâmicas": "isogâmico",
    "isogâmicos": "isogâmico",
    "isogónica": "isogónico",
    "isogónicas": "isogónico",
    "isogónicos": "isogónico",
    "isoipsa": "isoipso",
    "isoipsas": "isoipso",
    "isoipsos": "isoipso",
    "isoiética": "isoiético",
    "isoiéticas": "isoiético",
    "isoiéticos": "isoiético",
    "isola": "isolar",
    "isolacionismos": "isolacionismo",
    "isolacionistas": "isolacionista",
    "isolada": "isolar",
    "isoladas": "isolar",
    "isolado": "isolar",
    "isoladora": "isolador",
    "isoladoras": "isolador",
    "isoladores": "isolador",
    "isolados": "isolar",
    "isoladíssima": "isolado",
    "isoladíssimas": "isolado",
    "isoladíssimo": "isolado",
    "isoladíssimos": "isolado",
    "isolai": "isolar",
    "isolais": "isolar",
    "isolam": "isolar",
    "isolamentos": "isolamento",
    "isolamo": "isolar",
    "isolamos": "isolar",
    "isolando": "isolar",
    "isolantes": "isolante",
    "isolara": "isolar",
    "isolaram": "isolar",
    "isolaras": "isolar",
    "isolarde": "isolar",
    "isolardes": "isolar",
    "isolare": "isolar",
    "isolarei": "isolar",
    "isolareis": "isolar",
    "isolarem": "isolar",
    "isolaremos": "isolar",
    "isolares": "isolar",
    "isolaria": "isolar",
    "isolariam": "isolar",
    "isolarias": "isolar",
    "isolarmo": "isolar",
    "isolarmos": "isolar",
    "isolará": "isolar",
    "isolarás": "isolar",
    "isolarão": "isolar",
    "isolaríamos": "isolar",
    "isolaríeis": "isolar",
    "isolas": "isolar",
    "isolasse": "isolar",
    "isolassem": "isolar",
    "isolasses": "isolar",
    "isolaste": "isolar",
    "isolastes": "isolar",
    "isolava": "isolar",
    "isolavam": "isolar",
    "isolavas": "isolar",
    "isolações": "isolação",
    "isole": "isolar",
    "isolecítica": "isolecítico",
    "isolecíticas": "isolecítico",
    "isolecíticos": "isolecítico",
    "isolei": "isolar",
    "isoleis": "isolar",
    "isolem": "isolar",
    "isolemo": "isolar",
    "isolemos": "isolar",
    "isoles": "isolar",
    "isolinhas": "isolinha",
    "isolo": "isolar",
    "isolou": "isolar",
    "isolá": "isolar",
    "isolámo": "isolar",
    "isolámos": "isolar",
    "isoláramo": "isolar",
    "isoláramos": "isolar",
    "isolárei": "isolar",
    "isoláreis": "isolar",
    "isolásseis": "isolar",
    "isolássemos": "isolar",
    "isolávamo": "isolar",
    "isolávamos": "isolar",
    "isolávei": "isolar",
    "isoláveis": "isolável",
    "isolécita": "isolécito",
    "isolécitas": "isolécito",
    "isolécitos": "isolécito",
    "isomagnética": "isomagnético",
    "isomagnéticas": "isomagnético",
    "isomagnéticos": "isomagnético",
    "isomerias": "isomeria",
    "isomerismos": "isomerismo",
    "isometrias": "isometria",
    "isomorfa": "isomorfo",
    "isomorfas": "isomorfo",
    "isomorfias": "isomorfia",
    "isomorfismos": "isomorfismo",
    "isomorfos": "isomorfo",
    "isométrica": "isométrico",
    "isométricas": "isométrico",
    "isométricos": "isométrico",
    "isonomias": "isonomia",
    "isopatas": "isopata",
    "isopatias": "isopatia",
    "isopias": "isopia",
    "isopicnas": "isopicna",
    "isopiéstica": "isopiéstico",
    "isopiésticas": "isopiéstico",
    "isopiésticos": "isopiéstico",
    "isopletas": "isopleta",
    "isopora": "isoporo",
    "isoporas": "isoporo",
    "isoporos": "isoporo",
    "isoprenos": "isopreno",
    "isopétala": "isopétalo",
    "isopétalas": "isopétalo",
    "isopétalos": "isopétalo",
    "isopícnica": "isopícnico",
    "isopícnicas": "isopícnico",
    "isopícnicos": "isopícnico",
    "isopórica": "isopórico",
    "isopóricas": "isopórico",
    "isopóricos": "isopórico",
    "isoquiménica": "isoquiménico",
    "isoquiménicas": "isoquiménico",
    "isoquiménicos": "isoquiménico",
    "isoquímena": "isoquímeno",
    "isoquímenas": "isoquímeno",
    "isoquímenos": "isoquímeno",
    "isoscelias": "isoscelia",
    "isosmias": "isosmia",
    "isospórica": "isospórico",
    "isospóricas": "isospórico",
    "isospóricos": "isospórico",
    "isossilábica": "isossilábico",
    "isossilábicas": "isossilábico",
    "isossilábicos": "isossilábico",
    "isossista": "isossisto",
    "isossistas": "isossisto",
    "isossistos": "isossisto",
    "isostasias": "isostasia",
    "isostática": "isostático",
    "isostáticas": "isostático",
    "isostáticos": "isostático",
    "isostémones": "isostémone",
    "isotonias": "isotonia",
    "isotropias": "isotropia",
    "isotrópica": "isotrópico",
    "isotrópicas": "isotrópico",
    "isotrópicos": "isotrópico",
    "isotérica": "isotérico",
    "isotéricas": "isotérico",
    "isotéricos": "isotérico",
    "isotérmica": "isotérmico",
    "isotérmicas": "isotérmico",
    "isotérmicos": "isotérmico",
    "isotónica": "isotónico",
    "isotónicas": "isotónico",
    "isotónicos": "isotónico",
    "isotópica": "isotópico",
    "isotópicas": "isotópico",
    "isotópicos": "isotópico",
    "isoédrica": "isoédrico",
    "isoédricas": "isoédrico",
    "isoédricos": "isoédrico",
    "isque": "iscar",
    "isquei": "iscar",
    "isqueiros": "isqueiro",
    "isqueis": "iscar",
    "isquem": "iscar",
    "isquemias": "isquemia",
    "isquemo": "iscar",
    "isquemos": "iscar",
    "isques": "iscar",
    "isquiadelfa": "isquiadelfo",
    "isquiadelfas": "isquiadelfo",
    "isquiadelfos": "isquiadelfo",
    "isquémica": "isquémico",
    "isquémicas": "isquémico",
    "isquémicos": "isquémico",
    "israeliana": "israeliano",
    "israelianas": "israeliano",
    "israelianos": "israeliano",
    "israelistas": "israelista",
    "israelitas": "israelita",
    "israelítica": "israelítico",
    "israelíticas": "israelítico",
    "israelíticos": "israelítico",
    "israéis": "israel",
    "isseis": "issei",
    "istmos": "istmo",
    "isurias": "isuria",
    "iságama": "iságamo",
    "iságamas": "iságamo",
    "iságamos": "iságamo",
    "isáxones": "isáxone",
    "isíaca": "isíaco",
    "isíacas": "isíaco",
    "isíacos": "isíaco",
    "isídios": "isídio",
    "isóbara": "isóbaro",
    "isóbaras": "isóbaro",
    "isóbares": "isóbare",
    "isóbaros": "isóbaro",
    "isóbata": "isóbato",
    "isóbatas": "isóbato",
    "isóbatos": "isóbato",
    "isóclina": "isóclino",
    "isóclinas": "isóclino",
    "isóclinos": "isóclino",
    "isócoras": "isócora",
    "isócroma": "isócromo",
    "isócromas": "isócromo",
    "isócromos": "isócromo",
    "isócrona": "isócrono",
    "isócronas": "isócrono",
    "isócronos": "isócrono",
    "isófona": "isófono",
    "isófonas": "isófono",
    "isófonos": "isófono",
    "isógena": "isógeno",
    "isógenas": "isógeno",
    "isógenos": "isógeno",
    "isógona": "isógono",
    "isógonas": "isógono",
    "isógonos": "isógono",
    "isóloga": "isólogo",
    "isólogas": "isólogo",
    "isólogos": "isólogo",
    "isómera": "isómero",
    "isómeras": "isómero",
    "isómeros": "isómero",
    "isónefas": "isónefa",
    "isónoma": "isónomo",
    "isónomas": "isónomo",
    "isónomos": "isónomo",
    "isópica": "isópico",
    "isópicas": "isópico",
    "isópicos": "isópico",
    "isópodes": "isópode",
    "isóptera": "isóptero",
    "isópteras": "isóptero",
    "isópteros": "isóptero",
    "isóscele": "isósceles",
    "isósporos": "isósporo",
    "isóstases": "isóstase",
    "isótera": "isótero",
    "isóteras": "isótero",
    "isóteros": "isótero",
    "isótipos": "isótipo",
    "isótona": "isótono",
    "isótonas": "isótono",
    "isótonos": "isótono",
    "isótopa": "isótopo",
    "isótopas": "isótopo",
    "isótopos": "isótopo",
    "isótropa": "isótropo",
    "isótropas": "isótropo",
    "isótropos": "isótropo",
    "isúrias": "isúria",
    "itabirites": "itabirite",
    "itacenses": "itacense",
    "itacolumites": "itacolumite",
    "italiana": "italiano",
    "italianada": "italianado",
    "italianadas": "italianado",
    "italianados": "italianado",
    "italianas": "italiano",
    "italianismos": "italianismo",
    "italianiza": "italianizar",
    "italianizada": "italianizar",
    "italianizadas": "italianizar",
    "italianizado": "italianizar",
    "italianizados": "italianizar",
    "italianizai": "italianizar",
    "italianizais": "italianizar",
    "italianizam": "italianizar",
    "italianizamo": "italianizar",
    "italianizamos": "italianizar",
    "italianizando": "italianizar",
    "italianizara": "italianizar",
    "italianizaram": "italianizar",
    "italianizaras": "italianizar",
    "italianizarde": "italianizar",
    "italianizardes": "italianizar",
    "italianizare": "italianizar",
    "italianizarei": "italianizar",
    "italianizareis": "italianizar",
    "italianizarem": "italianizar",
    "italianizaremos": "italianizar",
    "italianizares": "italianizar",
    "italianizaria": "italianizar",
    "italianizariam": "italianizar",
    "italianizarias": "italianizar",
    "italianizarmo": "italianizar",
    "italianizarmos": "italianizar",
    "italianizará": "italianizar",
    "italianizarás": "italianizar",
    "italianizarão": "italianizar",
    "italianizaríamos": "italianizar",
    "italianizaríeis": "italianizar",
    "italianizas": "italianizar",
    "italianizasse": "italianizar",
    "italianizassem": "italianizar",
    "italianizasses": "italianizar",
    "italianizaste": "italianizar",
    "italianizastes": "italianizar",
    "italianizava": "italianizar",
    "italianizavam": "italianizar",
    "italianizavas": "italianizar",
    "italianizações": "italianização",
    "italianize": "italianizar",
    "italianizei": "italianizar",
    "italianizeis": "italianizar",
    "italianizem": "italianizar",
    "italianizemo": "italianizar",
    "italianizemos": "italianizar",
    "italianizes": "italianizar",
    "italianizo": "italianizar",
    "italianizou": "italianizar",
    "italianizá": "italianizar",
    "italianizámo": "italianizar",
    "italianizámos": "italianizar",
    "italianizáramo": "italianizar",
    "italianizáramos": "italianizar",
    "italianizárei": "italianizar",
    "italianizáreis": "italianizar",
    "italianizásseis": "italianizar",
    "italianizássemos": "italianizar",
    "italianizávamo": "italianizar",
    "italianizávamos": "italianizar",
    "italianizávei": "italianizar",
    "italianizáveis": "italianizável",
    "italianos": "italiano",
    "italiotas": "italiota",
    "itens": "item",
    "itera": "iterar",
    "iterada": "iterar",
    "iteradas": "iterar",
    "iterado": "iterar",
    "iterados": "iterar",
    "iterai": "iterar",
    "iterais": "iterar",
    "iteram": "iterar",
    "iteramo": "iterar",
    "iteramos": "iterar",
    "iterando": "iterar",
    "iterara": "iterar",
    "iteraram": "iterar",
    "iteraras": "iterar",
    "iterarde": "iterar",
    "iterardes": "iterar",
    "iterare": "iterar",
    "iterarei": "iterar",
    "iterareis": "iterar",
    "iterarem": "iterar",
    "iteraremos": "iterar",
    "iterares": "iterar",
    "iteraria": "iterar",
    "iterariam": "iterar",
    "iterarias": "iterar",
    "iterarmo": "iterar",
    "iterarmos": "iterar",
    "iterará": "iterar",
    "iterarás": "iterar",
    "iterarão": "iterar",
    "iteraríamos": "iterar",
    "iteraríeis": "iterar",
    "iteras": "iterar",
    "iterasse": "iterar",
    "iterassem": "iterar",
    "iterasses": "iterar",
    "iteraste": "iterar",
    "iterastes": "iterar",
    "iterativa": "iterativo",
    "iterativas": "iterativo",
    "iterativos": "iterativo",
    "iterava": "iterar",
    "iteravam": "iterar",
    "iteravas": "iterar",
    "iterações": "iteração",
    "itere": "iterar",
    "iterei": "iterar",
    "itereis": "iterar",
    "iterem": "iterar",
    "iteremo": "iterar",
    "iteremos": "iterar",
    "iteres": "iterar",
    "itero": "iterar",
    "iterou": "iterar",
    "iterá": "iterar",
    "iterámo": "iterar",
    "iterámos": "iterar",
    "iteráramo": "iterar",
    "iteráramos": "iterar",
    "iterárei": "iterar",
    "iteráreis": "iterar",
    "iterásseis": "iterar",
    "iterássemos": "iterar",
    "iterávamo": "iterar",
    "iterávamos": "iterar",
    "iterávei": "iterar",
    "iteráveis": "iterável",
    "itinerantes": "itinerante",
    "itinerária": "itinerário",
    "itinerárias": "itinerário",
    "itinerários": "itinerário",
    "itinerâncias": "itinerância",
    "itupavas": "itupava",
    "itálica": "itálico",
    "itálicas": "itálico",
    "itálicos": "itálico",
    "itérbios": "itérbio",
    "ivas": "iva",
    "ixiáceas": "ixiácea",
    "ixocifoses": "ixocifose",
    "ixoras": "ixora",
    "izais": "izal",
    "izaquentes": "izaquente",
    "izares": "izar",
    "izas": "iza",
    "izuqueira": "izuqueiro",
    "izuqueiras": "izuqueiro",
    "izuqueiros": "izuqueiro",
    "iátrica": "iátrico",
    "iátricas": "iátrico",
    "iátricos": "iátrico",
    "iâmbica": "iâmbico",
    "iâmbicas": "iâmbico",
    "iâmbicos": "iâmbico",
    "iântina": "iântino",
    "iântinas": "iântino",
    "iântinos": "iântino",
    "iça": "içar",
    "içada": "içar",
    "içadas": "içar",
    "içado": "içar",
    "içados": "içar",
    "içai": "içar",
    "içais": "içar",
    "içam": "içar",
    "içamentos": "içamento",
    "içamo": "içar",
    "içamos": "içar",
    "içando": "içar",
    "içara": "içar",
    "içaram": "içar",
    "içaras": "içara",
    "içarde": "içar",
    "içardes": "içar",
    "içare": "içar",
    "içarei": "içar",
    "içareis": "içar",
    "içarem": "içar",
    "içaremos": "içar",
    "içares": "içar",
    "içaria": "içar",
    "içariam": "içar",
    "içarias": "içar",
    "içarmo": "içar",
    "içarmos": "içar",
    "içará": "içar",
    "içarás": "içar",
    "içarão": "içar",
    "içaríamos": "içar",
    "içaríeis": "içar",
    "iças": "içar",
    "içasse": "içar",
    "içassem": "içar",
    "içasses": "içar",
    "içaste": "içar",
    "içastes": "içar",
    "içava": "içar",
    "içavam": "içar",
    "içavas": "içar",
    "iço": "içar",
    "içou": "içar",
    "içá": "içar",
    "içámo": "içar",
    "içámos": "içar",
    "içáramo": "içar",
    "içáramos": "içar",
    "içárei": "içar",
    "içáreis": "içar",
    "içásseis": "içar",
    "içássemos": "içar",
    "içávamo": "içar",
    "içávamos": "içar",
    "içávei": "içar",
    "içáveis": "içável",
    "iídiches": "iídiche",
    "iódica": "iódico",
    "iódicas": "iódico",
    "iódicos": "iódico",
    "iónia": "iónio",
    "iónias": "iónio",
    "iónica": "iónico",
    "iónicas": "iónico",
    "iónicos": "iónico",
    "iónios": "iónio",
    "iões": "ião",
    "iúcas": "iúca",
    "jaaraboás": "jaaraboá",
    "jabirus": "jabiru",
    "jabitas": "jabita",
    "jabuticabas": "jabuticaba",
    "jabutins": "jabutim",
    "jacamins": "jacamim",
    "jacamis": "jacami",
    "jacapucaias": "jacapucaia",
    "jacarandanas": "jacarandana",
    "jacarandás": "jacarandá",
    "jacaratingas": "jacaratinga",
    "jacaretingas": "jacaretinga",
    "jacarinas": "jacarina",
    "jacarinis": "jacarini",
    "jacarácias": "jacarácia",
    "jacarés": "jacaré",
    "jacas": "jaca",
    "jacatirões": "jacatirão",
    "jacatupés": "jacatupé",
    "jacentes": "jacente",
    "jacintina": "jacintino",
    "jacintinas": "jacintino",
    "jacintinos": "jacintino",
    "jacintos": "jacinto",
    "jackpots": "jackpot",
    "jacksoniana": "jacksoniano",
    "jacksonianas": "jacksoniano",
    "jacksonianos": "jacksoniano",
    "jacobeia": "jacobeu",
    "jacobeias": "jacobeu",
    "jacobeus": "jacobeu",
    "jacobices": "jacobice",
    "jacobina": "jacobino",
    "jacobinas": "jacobino",
    "jacobinices": "jacobinice",
    "jacobinismos": "jacobinismo",
    "jacobinos": "jacobino",
    "jacobitas": "jacobita",
    "jacorais": "jacoral",
    "jacorária": "jacorário",
    "jacorárias": "jacorário",
    "jacorários": "jacorário",
    "jacres": "jacre",
    "jacta": "jactar",
    "jactada": "jactar",
    "jactadas": "jactar",
    "jactado": "jactar",
    "jactados": "jactar",
    "jactai": "jactar",
    "jactais": "jactar",
    "jactam": "jactar",
    "jactamo": "jactar",
    "jactamos": "jactar",
    "jactancia": "jactanciar",
    "jactanciada": "jactanciar",
    "jactanciadas": "jactanciar",
    "jactanciado": "jactanciar",
    "jactanciados": "jactanciar",
    "jactanciai": "jactanciar",
    "jactanciais": "jactanciar",
    "jactanciam": "jactanciar",
    "jactanciamo": "jactanciar",
    "jactanciamos": "jactanciar",
    "jactanciando": "jactanciar",
    "jactanciara": "jactanciar",
    "jactanciaram": "jactanciar",
    "jactanciaras": "jactanciar",
    "jactanciarde": "jactanciar",
    "jactanciardes": "jactanciar",
    "jactanciare": "jactanciar",
    "jactanciarei": "jactanciar",
    "jactanciareis": "jactanciar",
    "jactanciarem": "jactanciar",
    "jactanciaremos": "jactanciar",
    "jactanciares": "jactanciar",
    "jactanciaria": "jactanciar",
    "jactanciariam": "jactanciar",
    "jactanciarias": "jactanciar",
    "jactanciarmo": "jactanciar",
    "jactanciarmos": "jactanciar",
    "jactanciará": "jactanciar",
    "jactanciarás": "jactanciar",
    "jactanciarão": "jactanciar",
    "jactanciaríamos": "jactanciar",
    "jactanciaríeis": "jactanciar",
    "jactancias": "jactanciar",
    "jactanciasse": "jactanciar",
    "jactanciassem": "jactanciar",
    "jactanciasses": "jactanciar",
    "jactanciaste": "jactanciar",
    "jactanciastes": "jactanciar",
    "jactanciava": "jactanciar",
    "jactanciavam": "jactanciar",
    "jactanciavas": "jactanciar",
    "jactancie": "jactanciar",
    "jactanciei": "jactanciar",
    "jactancieis": "jactanciar",
    "jactanciem": "jactanciar",
    "jactanciemo": "jactanciar",
    "jactanciemos": "jactanciar",
    "jactancies": "jactanciar",
    "jactancio": "jactanciar",
    "jactanciosa": "jactancioso",
    "jactanciosas": "jactancioso",
    "jactanciosidades": "jactanciosidade",
    "jactanciosos": "jactancioso",
    "jactanciou": "jactanciar",
    "jactanciá": "jactanciar",
    "jactanciámo": "jactanciar",
    "jactanciámos": "jactanciar",
    "jactanciáramo": "jactanciar",
    "jactanciáramos": "jactanciar",
    "jactanciárei": "jactanciar",
    "jactanciáreis": "jactanciar",
    "jactanciásseis": "jactanciar",
    "jactanciássemos": "jactanciar",
    "jactanciávamo": "jactanciar",
    "jactanciávamos": "jactanciar",
    "jactanciávei": "jactanciar",
    "jactanciáveis": "jactanciar",
    "jactando": "jactar",
    "jactantes": "jactante",
    "jactara": "jactar",
    "jactaram": "jactar",
    "jactaras": "jactar",
    "jactarde": "jactar",
    "jactardes": "jactar",
    "jactare": "jactar",
    "jactarei": "jactar",
    "jactareis": "jactar",
    "jactarem": "jactar",
    "jactaremos": "jactar",
    "jactares": "jactar",
    "jactaria": "jactar",
    "jactariam": "jactar",
    "jactarias": "jactar",
    "jactarmo": "jactar",
    "jactarmos": "jactar",
    "jactará": "jactar",
    "jactarás": "jactar",
    "jactarão": "jactar",
    "jactaríamos": "jactar",
    "jactaríeis": "jactar",
    "jactas": "jactar",
    "jactasse": "jactar",
    "jactassem": "jactar",
    "jactasses": "jactar",
    "jactaste": "jactar",
    "jactastes": "jactar",
    "jactava": "jactar",
    "jactavam": "jactar",
    "jactavas": "jactar",
    "jacte": "jactar",
    "jactei": "jactar",
    "jacteis": "jactar",
    "jactem": "jactar",
    "jactemo": "jactar",
    "jactemos": "jactar",
    "jactes": "jactar",
    "jacto": "jactar",
    "jactos": "jacto",
    "jactou": "jactar",
    "jactá": "jactar",
    "jactámo": "jactar",
    "jactámos": "jactar",
    "jactáramo": "jactar",
    "jactáramos": "jactar",
    "jactárei": "jactar",
    "jactáreis": "jactar",
    "jactásseis": "jactar",
    "jactássemos": "jactar",
    "jactávamo": "jactar",
    "jactávamos": "jactar",
    "jactávei": "jactar",
    "jactáveis": "jactar",
    "jactâncias": "jactância",
    "jacuacangas": "jacuacanga",
    "jacubas": "jacuba",
    "jacula": "jacular",
    "jaculada": "jacular",
    "jaculadas": "jacular",
    "jaculado": "jacular",
    "jaculadora": "jaculador",
    "jaculadoras": "jaculador",
    "jaculadores": "jaculador",
    "jaculados": "jacular",
    "jaculai": "jacular",
    "jaculais": "jacular",
    "jaculam": "jacular",
    "jaculamo": "jacular",
    "jaculamos": "jacular",
    "jaculando": "jacular",
    "jaculara": "jacular",
    "jacularam": "jacular",
    "jacularas": "jacular",
    "jacularde": "jacular",
    "jaculardes": "jacular",
    "jaculare": "jacular",
    "jacularei": "jacular",
    "jaculareis": "jacular",
    "jacularem": "jacular",
    "jacularemos": "jacular",
    "jaculares": "jacular",
    "jacularia": "jacular",
    "jaculariam": "jacular",
    "jacularias": "jacular",
    "jacularmo": "jacular",
    "jacularmos": "jacular",
    "jaculará": "jacular",
    "jacularás": "jacular",
    "jacularão": "jacular",
    "jacularíamos": "jacular",
    "jacularíeis": "jacular",
    "jaculas": "jacular",
    "jaculasse": "jacular",
    "jaculassem": "jacular",
    "jaculasses": "jacular",
    "jaculaste": "jacular",
    "jaculastes": "jacular",
    "jaculatória": "jaculatório",
    "jaculatórias": "jaculatório",
    "jaculatórios": "jaculatório",
    "jaculava": "jacular",
    "jaculavam": "jacular",
    "jaculavas": "jacular",
    "jaculações": "jaculação",
    "jacule": "jacular",
    "jaculei": "jacular",
    "jaculeis": "jacular",
    "jaculem": "jacular",
    "jaculemo": "jacular",
    "jaculemos": "jacular",
    "jacules": "jacular",
    "jaculo": "jacular",
    "jaculou": "jacular",
    "jaculá": "jacular",
    "jaculámo": "jacular",
    "jaculámos": "jacular",
    "jaculáramo": "jacular",
    "jaculáramos": "jacular",
    "jaculárei": "jacular",
    "jaculáreis": "jacular",
    "jaculásseis": "jacular",
    "jaculássemos": "jacular",
    "jaculávamo": "jacular",
    "jaculávamos": "jacular",
    "jaculávei": "jacular",
    "jaculáveis": "jacular",
    "jacumãs": "jacumã",
    "jacupembas": "jacupemba",
    "jacupiranguites": "jacupiranguite",
    "jacutingas": "jacutinga",
    "jacuíbas": "jacuíba",
    "jacás": "jacá",
    "jades": "jade",
    "jadeítes": "jadeíte",
    "jaeza": "jaezar",
    "jaezada": "jaezar",
    "jaezadas": "jaezar",
    "jaezado": "jaezar",
    "jaezados": "jaezar",
    "jaezai": "jaezar",
    "jaezais": "jaezar",
    "jaezam": "jaezar",
    "jaezamo": "jaezar",
    "jaezamos": "jaezar",
    "jaezando": "jaezar",
    "jaezara": "jaezar",
    "jaezaram": "jaezar",
    "jaezaras": "jaezar",
    "jaezarde": "jaezar",
    "jaezardes": "jaezar",
    "jaezare": "jaezar",
    "jaezarei": "jaezar",
    "jaezareis": "jaezar",
    "jaezarem": "jaezar",
    "jaezaremos": "jaezar",
    "jaezares": "jaezar",
    "jaezaria": "jaezar",
    "jaezariam": "jaezar",
    "jaezarias": "jaezar",
    "jaezarmo": "jaezar",
    "jaezarmos": "jaezar",
    "jaezará": "jaezar",
    "jaezarás": "jaezar",
    "jaezarão": "jaezar",
    "jaezaríamos": "jaezar",
    "jaezaríeis": "jaezar",
    "jaezas": "jaezar",
    "jaezasse": "jaezar",
    "jaezassem": "jaezar",
    "jaezasses": "jaezar",
    "jaezaste": "jaezar",
    "jaezastes": "jaezar",
    "jaezava": "jaezar",
    "jaezavam": "jaezar",
    "jaezavas": "jaezar",
    "jaeze": "jaezar",
    "jaezei": "jaezar",
    "jaezeis": "jaezar",
    "jaezem": "jaezar",
    "jaezemo": "jaezar",
    "jaezemos": "jaezar",
    "jaezes": "jaezar",
    "jaezo": "jaezar",
    "jaezou": "jaezar",
    "jaezá": "jaezar",
    "jaezámo": "jaezar",
    "jaezámos": "jaezar",
    "jaezáramo": "jaezar",
    "jaezáramos": "jaezar",
    "jaezárei": "jaezar",
    "jaezáreis": "jaezar",
    "jaezásseis": "jaezar",
    "jaezássemos": "jaezar",
    "jaezávamo": "jaezar",
    "jaezávamos": "jaezar",
    "jaezávei": "jaezar",
    "jaezáveis": "jaezar",
    "jafética": "jafético",
    "jaféticas": "jafético",
    "jaféticos": "jafético",
    "jagas": "jaga",
    "jagodess": "jagodes",
    "jagras": "jagra",
    "jagres": "jagre",
    "jaguacatiguaçus": "jaguacatiguaçu",
    "jaguanés": "jaguané",
    "jaguapés": "jaguapé",
    "jaguares": "jaguar",
    "jaguaretês": "jaguaretê",
    "jaguarés": "jaguaré",
    "jaguatiricas": "jaguatirica",
    "jagunça": "jagunço",
    "jagunças": "jagunço",
    "jagunços": "jagunço",
    "jaguris": "jaguri",
    "jalapinas": "jalapina",
    "jaldes": "jalde",
    "jaldinina": "jaldinino",
    "jaldininas": "jaldinino",
    "jaldininos": "jaldinino",
    "jalecas": "jaleca",
    "jalecos": "jaleco",
    "jaleias": "jaleia",
    "jaleques": "jaleque",
    "jalnes": "jalne",
    "jalofa": "jalofo",
    "jalofas": "jalofo",
    "jalofos": "jalofo",
    "jalutos": "jaluto",
    "jamaicana": "jamaicano",
    "jamaicanas": "jamaicano",
    "jamaicanos": "jamaicano",
    "jamantas": "jamanta",
    "jambas": "jamba",
    "jambeiros": "jambeiro",
    "jambelegíaca": "jambelegíaco",
    "jambelegíacas": "jambelegíaco",
    "jambelegíacos": "jambelegíaco",
    "jamboeiros": "jamboeiro",
    "jambolanos": "jambolano",
    "jamboleiros": "jamboleiro",
    "jambolões": "jambolão",
    "jambos": "jambo",
    "jambuaçus": "jambuaçu",
    "jambuis": "jambul",
    "jambus": "jambu",
    "jambóis": "jambol",
    "janambás": "janambá",
    "janaúbas": "janaúba",
    "jandaias": "jandaia",
    "jandas": "janda",
    "jandaíras": "jandaíra",
    "jandiás": "jandiá",
    "janeiradas": "janeirada",
    "janeireira": "janeireiro",
    "janeireiras": "janeireiro",
    "janeireiros": "janeireiro",
    "janeirenta": "janeirento",
    "janeirentas": "janeirento",
    "janeirentos": "janeirento",
    "janeirinha": "janeirinho",
    "janeirinhas": "janeirinho",
    "janeirinhos": "janeirinho",
    "janelas": "janela",
    "janeleira": "janeleiro",
    "janeleiras": "janeleiro",
    "janeleiros": "janeleiro",
    "janelinha": "janela",
    "janelinhas": "janela",
    "janelita": "janela",
    "janelitas": "janela",
    "janelos": "janelo",
    "janelões": "janelão",
    "jangadas": "jangada",
    "jangadeira": "jangadeiro",
    "jangadeiras": "jangadeiro",
    "jangadeiros": "jangadeiro",
    "jangas": "janga",
    "jangazes": "jangaz",
    "jangás": "jangá",
    "janicefalias": "janicefalia",
    "janicéfalos": "janicéfalo",
    "janicípites": "janicípite",
    "janiras": "janira",
    "janistroqueses": "janistroques",
    "janota": "janotar",
    "janotada": "janotar",
    "janotadas": "janotar",
    "janotado": "janotar",
    "janotados": "janotar",
    "janotai": "janotar",
    "janotais": "janotar",
    "janotam": "janotar",
    "janotamo": "janotar",
    "janotamos": "janotar",
    "janotando": "janotar",
    "janotara": "janotar",
    "janotaram": "janotar",
    "janotaras": "janotar",
    "janotarde": "janotar",
    "janotardes": "janotar",
    "janotare": "janotar",
    "janotarei": "janotar",
    "janotareis": "janotar",
    "janotarem": "janotar",
    "janotaremos": "janotar",
    "janotares": "janotar",
    "janotaria": "janotar",
    "janotariam": "janotar",
    "janotarias": "janotaria",
    "janotarmo": "janotar",
    "janotarmos": "janotar",
    "janotará": "janotar",
    "janotarás": "janotar",
    "janotarão": "janotar",
    "janotaríamos": "janotar",
    "janotaríeis": "janotar",
    "janotas": "janotar",
    "janotasse": "janotar",
    "janotassem": "janotar",
    "janotasses": "janotar",
    "janotaste": "janotar",
    "janotastes": "janotar",
    "janotava": "janotar",
    "janotavam": "janotar",
    "janotavas": "janotar",
    "janote": "janotar",
    "janotei": "janotar",
    "janoteis": "janotar",
    "janotem": "janotar",
    "janotemo": "janotar",
    "janotemos": "janotar",
    "janotes": "janotar",
    "janotices": "janotice",
    "janotismos": "janotismo",
    "janoto": "janotar",
    "janotou": "janotar",
    "janotá": "janotar",
    "janotámo": "janotar",
    "janotámos": "janotar",
    "janotáramo": "janotar",
    "janotáramos": "janotar",
    "janotárei": "janotar",
    "janotáreis": "janotar",
    "janotásseis": "janotar",
    "janotássemos": "janotar",
    "janotávamo": "janotar",
    "janotávamos": "janotar",
    "janotávei": "janotar",
    "janotáveis": "janotar",
    "jansenismos": "jansenismo",
    "jansenistas": "jansenista",
    "janta": "jantar",
    "jantada": "jantar",
    "jantadas": "jantar",
    "jantado": "jantar",
    "jantados": "jantar",
    "jantai": "jantar",
    "jantais": "jantar",
    "jantam": "jantar",
    "jantamo": "jantar",
    "jantamos": "jantar",
    "jantando": "jantar",
    "jantara": "jantar",
    "jantaradas": "jantarada",
    "jantaram": "jantar",
    "jantaras": "jantar",
    "jantardes": "jantar",
    "jantarei": "jantar",
    "jantareis": "jantar",
    "jantarem": "jantar",
    "jantaremos": "jantar",
    "jantares": "jantar",
    "jantaretas": "jantareta",
    "jantaria": "jantar",
    "jantariam": "jantar",
    "jantarias": "jantar",
    "jantarinho": "jantar",
    "jantarinhos": "jantar",
    "jantarito": "jantar",
    "jantaritos": "jantar",
    "jantarmo": "jantar",
    "jantarmos": "jantar",
    "jantarolas": "jantarola",
    "jantará": "jantar",
    "jantarás": "jantar",
    "jantarão": "jantar",
    "jantaríamos": "jantar",
    "jantaríeis": "jantar",
    "jantarões": "jantarão",
    "jantas": "jantar",
    "jantasse": "jantar",
    "jantassem": "jantar",
    "jantasses": "jantar",
    "jantaste": "jantar",
    "jantastes": "jantar",
    "jantava": "jantar",
    "jantavam": "jantar",
    "jantavas": "jantar",
    "jante": "jantar",
    "jantei": "jantar",
    "janteis": "jantar",
    "jantem": "jantar",
    "jantemo": "jantar",
    "jantemos": "jantar",
    "jantes": "jante",
    "janto": "jantar",
    "jantou": "jantar",
    "jantámo": "jantar",
    "jantámos": "jantar",
    "jantáramo": "jantar",
    "jantáramos": "jantar",
    "jantáreis": "jantar",
    "jantásseis": "jantar",
    "jantássemos": "jantar",
    "jantávamo": "jantar",
    "jantávamos": "jantar",
    "jantáveis": "jantar",
    "januaíras": "januaíra",
    "januários": "januário",
    "janícipes": "janícipe",
    "janízaros": "janízaro",
    "janíçaros": "janíçaro",
    "japacanins": "japacanim",
    "japacanis": "japacani",
    "japanas": "japana",
    "japarandubas": "japaranduba",
    "japinabeiros": "japinabeiro",
    "japins": "japim",
    "japis": "japi",
    "japonas": "japona",
    "japoneiras": "japoneira",
    "japonenses": "japonense",
    "japonesa": "japonesar",
    "japonesada": "japonesar",
    "japonesadas": "japonesar",
    "japonesado": "japonesar",
    "japonesados": "japonesar",
    "japonesai": "japonesar",
    "japonesais": "japonesar",
    "japonesam": "japonesar",
    "japonesamo": "japonesar",
    "japonesamos": "japonesar",
    "japonesando": "japonesar",
    "japonesara": "japonesar",
    "japonesaram": "japonesar",
    "japonesaras": "japonesar",
    "japonesarde": "japonesar",
    "japonesardes": "japonesar",
    "japonesare": "japonesar",
    "japonesarei": "japonesar",
    "japonesareis": "japonesar",
    "japonesarem": "japonesar",
    "japonesaremos": "japonesar",
    "japonesares": "japonesar",
    "japonesaria": "japonesar",
    "japonesariam": "japonesar",
    "japonesarias": "japonesar",
    "japonesarmo": "japonesar",
    "japonesarmos": "japonesar",
    "japonesará": "japonesar",
    "japonesarás": "japonesar",
    "japonesarão": "japonesar",
    "japonesaríamos": "japonesar",
    "japonesaríeis": "japonesar",
    "japonesas": "japonesar",
    "japonesasse": "japonesar",
    "japonesassem": "japonesar",
    "japonesasses": "japonesar",
    "japonesaste": "japonesar",
    "japonesastes": "japonesar",
    "japonesava": "japonesar",
    "japonesavam": "japonesar",
    "japonesavas": "japonesar",
    "japonese": "japonesar",
    "japonesei": "japonesar",
    "japoneseis": "japonesar",
    "japonesem": "japonesar",
    "japonesemo": "japonesar",
    "japonesemos": "japonesar",
    "japoneses": "japonesar",
    "japonesismos": "japonesismo",
    "japonesistas": "japonesista",
    "japoneso": "japonesar",
    "japonesou": "japonesar",
    "japonesá": "japonesar",
    "japonesámo": "japonesar",
    "japonesámos": "japonesar",
    "japonesáramo": "japonesar",
    "japonesáramos": "japonesar",
    "japonesárei": "japonesar",
    "japonesáreis": "japonesar",
    "japonesásseis": "japonesar",
    "japonesássemos": "japonesar",
    "japonesávamo": "japonesar",
    "japonesávamos": "japonesar",
    "japonesávei": "japonesar",
    "japonesáveis": "japonesável",
    "japonismos": "japonismo",
    "japoniza": "japonizar",
    "japonizada": "japonizar",
    "japonizadas": "japonizar",
    "japonizado": "japonizar",
    "japonizados": "japonizar",
    "japonizai": "japonizar",
    "japonizais": "japonizar",
    "japonizam": "japonizar",
    "japonizamo": "japonizar",
    "japonizamos": "japonizar",
    "japonizando": "japonizar",
    "japonizara": "japonizar",
    "japonizaram": "japonizar",
    "japonizaras": "japonizar",
    "japonizarde": "japonizar",
    "japonizardes": "japonizar",
    "japonizare": "japonizar",
    "japonizarei": "japonizar",
    "japonizareis": "japonizar",
    "japonizarem": "japonizar",
    "japonizaremos": "japonizar",
    "japonizares": "japonizar",
    "japonizaria": "japonizar",
    "japonizariam": "japonizar",
    "japonizarias": "japonizar",
    "japonizarmo": "japonizar",
    "japonizarmos": "japonizar",
    "japonizará": "japonizar",
    "japonizarás": "japonizar",
    "japonizarão": "japonizar",
    "japonizaríamos": "japonizar",
    "japonizaríeis": "japonizar",
    "japonizas": "japonizar",
    "japonizasse": "japonizar",
    "japonizassem": "japonizar",
    "japonizasses": "japonizar",
    "japonizaste": "japonizar",
    "japonizastes": "japonizar",
    "japonizava": "japonizar",
    "japonizavam": "japonizar",
    "japonizavas": "japonizar",
    "japonize": "japonizar",
    "japonizei": "japonizar",
    "japonizeis": "japonizar",
    "japonizem": "japonizar",
    "japonizemo": "japonizar",
    "japonizemos": "japonizar",
    "japonizes": "japonizar",
    "japonizo": "japonizar",
    "japonizou": "japonizar",
    "japonizá": "japonizar",
    "japonizámo": "japonizar",
    "japonizámos": "japonizar",
    "japonizáramo": "japonizar",
    "japonizáramos": "japonizar",
    "japonizárei": "japonizar",
    "japonizáreis": "japonizar",
    "japonizásseis": "japonizar",
    "japonizássemos": "japonizar",
    "japonizávamo": "japonizar",
    "japonizávamos": "japonizar",
    "japonizávei": "japonizar",
    "japonizáveis": "japonizável",
    "japuangas": "japuanga",
    "japus": "japu",
    "japués": "japué",
    "japuíras": "japuíra",
    "japuís": "japuí",
    "japónica": "japónico",
    "japónicas": "japónico",
    "japónicos": "japónico",
    "japões": "japão",
    "jaquejaques": "jaquejaque",
    "jaques": "jaque",
    "jaquetas": "jaqueta",
    "jaquetões": "jaquetão",
    "jaquinzinhos": "jaquinzinho",
    "jaquiranabóias": "jaquiranabóia",
    "jaqués": "jaqué",
    "jaramataias": "jaramataia",
    "jarapés": "jarapé",
    "jararacas": "jararaca",
    "jararacuçus": "jararacuçu",
    "jardas": "jarda",
    "jardina": "jardinar",
    "jardinada": "jardinar",
    "jardinadas": "jardinar",
    "jardinado": "jardinar",
    "jardinados": "jardinar",
    "jardinagens": "jardinagem",
    "jardinai": "jardinar",
    "jardinais": "jardinar",
    "jardinam": "jardinar",
    "jardinamo": "jardinar",
    "jardinamos": "jardinar",
    "jardinando": "jardinar",
    "jardinara": "jardinar",
    "jardinaram": "jardinar",
    "jardinaras": "jardinar",
    "jardinarde": "jardinar",
    "jardinardes": "jardinar",
    "jardinare": "jardinar",
    "jardinarei": "jardinar",
    "jardinareis": "jardinar",
    "jardinarem": "jardinar",
    "jardinaremos": "jardinar",
    "jardinares": "jardinar",
    "jardinaria": "jardinar",
    "jardinariam": "jardinar",
    "jardinarias": "jardinar",
    "jardinarmo": "jardinar",
    "jardinarmos": "jardinar",
    "jardinará": "jardinar",
    "jardinarás": "jardinar",
    "jardinarão": "jardinar",
    "jardinaríamos": "jardinar",
    "jardinaríeis": "jardinar",
    "jardinas": "jardinar",
    "jardinasse": "jardinar",
    "jardinassem": "jardinar",
    "jardinasses": "jardinar",
    "jardinaste": "jardinar",
    "jardinastes": "jardinar",
    "jardinava": "jardinar",
    "jardinavam": "jardinar",
    "jardinavas": "jardinar",
    "jardine": "jardinar",
    "jardinei": "jardinar",
    "jardineira": "jardineiro",
    "jardineiras": "jardineiro",
    "jardineiros": "jardineiro",
    "jardineis": "jardinar",
    "jardinem": "jardinar",
    "jardinemo": "jardinar",
    "jardinemos": "jardinar",
    "jardines": "jardinar",
    "jardinetes": "jardinete",
    "jardinistas": "jardinista",
    "jardino": "jardinar",
    "jardinou": "jardinar",
    "jardins": "jardim",
    "jardinzinho": "jardim",
    "jardinzinhos": "jardim",
    "jardinzito": "jardim",
    "jardinzitos": "jardim",
    "jardiná": "jardinar",
    "jardinámo": "jardinar",
    "jardinámos": "jardinar",
    "jardináramo": "jardinar",
    "jardináramos": "jardinar",
    "jardinárei": "jardinar",
    "jardináreis": "jardinar",
    "jardinásseis": "jardinar",
    "jardinássemos": "jardinar",
    "jardinávamo": "jardinar",
    "jardinávamos": "jardinar",
    "jardinávei": "jardinar",
    "jardináveis": "jardinável",
    "jarerés": "jareré",
    "jargões": "jargão",
    "jarivás": "jarivá",
    "jaros": "jaro",
    "jarrafas": "jarrafa",
    "jarras": "jarra",
    "jarreta": "jarretar",
    "jarretada": "jarretar",
    "jarretadas": "jarretar",
    "jarretado": "jarretar",
    "jarretados": "jarretar",
    "jarretai": "jarretar",
    "jarretais": "jarretar",
    "jarretam": "jarretar",
    "jarretamo": "jarretar",
    "jarretamos": "jarretar",
    "jarretando": "jarretar",
    "jarretara": "jarretar",
    "jarretaram": "jarretar",
    "jarretaras": "jarretar",
    "jarretarde": "jarretar",
    "jarretardes": "jarretar",
    "jarretare": "jarretar",
    "jarretarei": "jarretar",
    "jarretareis": "jarretar",
    "jarretarem": "jarretar",
    "jarretaremos": "jarretar",
    "jarretares": "jarretar",
    "jarretaria": "jarretar",
    "jarretariam": "jarretar",
    "jarretarias": "jarretar",
    "jarretarmo": "jarretar",
    "jarretarmos": "jarretar",
    "jarretará": "jarretar",
    "jarretarás": "jarretar",
    "jarretarão": "jarretar",
    "jarretaríamos": "jarretar",
    "jarretaríeis": "jarretar",
    "jarretas": "jarretar",
    "jarretasse": "jarretar",
    "jarretassem": "jarretar",
    "jarretasses": "jarretar",
    "jarretaste": "jarretar",
    "jarretastes": "jarretar",
    "jarretava": "jarretar",
    "jarretavam": "jarretar",
    "jarretavas": "jarretar",
    "jarrete": "jarretar",
    "jarretei": "jarretar",
    "jarreteiras": "jarreteira",
    "jarreteis": "jarretar",
    "jarretem": "jarretar",
    "jarretemo": "jarretar",
    "jarretemos": "jarretar",
    "jarretes": "jarrete",
    "jarretices": "jarretice",
    "jarreto": "jarretar",
    "jarretou": "jarretar",
    "jarretá": "jarretar",
    "jarretámo": "jarretar",
    "jarretámos": "jarretar",
    "jarretáramo": "jarretar",
    "jarretáramos": "jarretar",
    "jarretárei": "jarretar",
    "jarretáreis": "jarretar",
    "jarretásseis": "jarretar",
    "jarretássemos": "jarretar",
    "jarretávamo": "jarretar",
    "jarretávamos": "jarretar",
    "jarretávei": "jarretar",
    "jarretáveis": "jarretar",
    "jarrilhos": "jarrilho",
    "jarrinha": "jarra",
    "jarrinhas": "jarrinha",
    "jarrinho": "jarro",
    "jarrinhos": "jarro",
    "jarrita": "jarra",
    "jarritas": "jarra",
    "jarrito": "jarro",
    "jarritos": "jarro",
    "jarros": "jarro",
    "jarrões": "jarrão",
    "jarás": "jará",
    "jarês": "jarê",
    "jasmineiros": "jasmineiro",
    "jasmins": "jasmim",
    "jasminácea": "jasmináceo",
    "jasmináceas": "jasmináceo",
    "jasmináceos": "jasmináceo",
    "jasmínea": "jasmíneo",
    "jasmíneas": "jasmíneo",
    "jasmíneos": "jasmíneo",
    "jaspeada": "jaspear",
    "jaspeadas": "jaspear",
    "jaspeado": "jaspear",
    "jaspeadora": "jaspeador",
    "jaspeadoras": "jaspeador",
    "jaspeadores": "jaspeador",
    "jaspeados": "jaspear",
    "jaspeai": "jaspear",
    "jaspeais": "jaspear",
    "jaspeamo": "jaspear",
    "jaspeamos": "jaspear",
    "jaspeando": "jaspear",
    "jaspeara": "jaspear",
    "jaspearam": "jaspear",
    "jaspearas": "jaspear",
    "jaspearde": "jaspear",
    "jaspeardes": "jaspear",
    "jaspeare": "jaspear",
    "jaspearei": "jaspear",
    "jaspeareis": "jaspear",
    "jaspearem": "jaspear",
    "jaspearemos": "jaspear",
    "jaspeares": "jaspear",
    "jaspearia": "jaspear",
    "jaspeariam": "jaspear",
    "jaspearias": "jaspear",
    "jaspearmo": "jaspear",
    "jaspearmos": "jaspear",
    "jaspeará": "jaspear",
    "jaspearás": "jaspear",
    "jaspearão": "jaspear",
    "jaspearíamos": "jaspear",
    "jaspearíeis": "jaspear",
    "jaspeasse": "jaspear",
    "jaspeassem": "jaspear",
    "jaspeasses": "jaspear",
    "jaspeaste": "jaspear",
    "jaspeastes": "jaspear",
    "jaspeava": "jaspear",
    "jaspeavam": "jaspear",
    "jaspeavas": "jaspear",
    "jaspeei": "jaspear",
    "jaspeeis": "jaspear",
    "jaspeemo": "jaspear",
    "jaspeemos": "jaspear",
    "jaspeia": "jaspear",
    "jaspeiam": "jaspear",
    "jaspeias": "jaspear",
    "jaspeie": "jaspear",
    "jaspeiem": "jaspear",
    "jaspeies": "jaspear",
    "jaspeio": "jaspear",
    "jaspeou": "jaspear",
    "jaspes": "jaspe",
    "jaspeá": "jaspear",
    "jaspeámo": "jaspear",
    "jaspeámos": "jaspear",
    "jaspeáramo": "jaspear",
    "jaspeáramos": "jaspear",
    "jaspeárei": "jaspear",
    "jaspeáreis": "jaspear",
    "jaspeásseis": "jaspear",
    "jaspeássemos": "jaspear",
    "jaspeávamo": "jaspear",
    "jaspeávamos": "jaspear",
    "jaspeávei": "jaspear",
    "jaspeáveis": "jaspear",
    "jaspóides": "jaspóide",
    "jassaís": "jassaí",
    "jataíbas": "jataíba",
    "jataís": "jataí",
    "jataúbas": "jataúba",
    "jaulapitis": "jaulapiti",
    "jaulas": "jaula",
    "jaus": "jau",
    "javalina": "javalino",
    "javalinas": "javalino",
    "javalinos": "javalino",
    "javalis": "javali",
    "javanca": "javanco",
    "javancas": "javanco",
    "javancos": "javanco",
    "javanesa": "javanês",
    "javanesas": "javanês",
    "javaneses": "javanês",
    "javarda": "javardo",
    "javardas": "javardo",
    "javardices": "javardice",
    "javardos": "javardo",
    "javaés": "javaé",
    "javra": "javrar",
    "javrada": "javrar",
    "javradas": "javrar",
    "javradeiras": "javradeira",
    "javrado": "javrar",
    "javrados": "javrar",
    "javrai": "javrar",
    "javrais": "javrar",
    "javram": "javrar",
    "javramo": "javrar",
    "javramos": "javrar",
    "javrando": "javrar",
    "javrara": "javrar",
    "javraram": "javrar",
    "javraras": "javrar",
    "javrarde": "javrar",
    "javrardes": "javrar",
    "javrare": "javrar",
    "javrarei": "javrar",
    "javrareis": "javrar",
    "javrarem": "javrar",
    "javraremos": "javrar",
    "javrares": "javrar",
    "javraria": "javrar",
    "javrariam": "javrar",
    "javrarias": "javrar",
    "javrarmo": "javrar",
    "javrarmos": "javrar",
    "javrará": "javrar",
    "javrarás": "javrar",
    "javrarão": "javrar",
    "javraríamos": "javrar",
    "javraríeis": "javrar",
    "javras": "javrar",
    "javrasse": "javrar",
    "javrassem": "javrar",
    "javrasses": "javrar",
    "javraste": "javrar",
    "javrastes": "javrar",
    "javrava": "javrar",
    "javravam": "javrar",
    "javravas": "javrar",
    "javre": "javrar",
    "javrei": "javrar",
    "javreis": "javrar",
    "javrem": "javrar",
    "javremo": "javrar",
    "javremos": "javrar",
    "javres": "javre",
    "javro": "javrar",
    "javrou": "javrar",
    "javrá": "javrar",
    "javrámo": "javrar",
    "javrámos": "javrar",
    "javráramo": "javrar",
    "javráramos": "javrar",
    "javrárei": "javrar",
    "javráreis": "javrar",
    "javrásseis": "javrar",
    "javrássemos": "javrar",
    "javrávamo": "javrar",
    "javrávamos": "javrar",
    "javrávei": "javrar",
    "javráveis": "javrar",
    "javés": "javé",
    "jaz": "jazer",
    "jaza": "jazer",
    "jazais": "jazer",
    "jazam": "jazer",
    "jazamo": "jazer",
    "jazamos": "jazer",
    "jazas": "jazer",
    "jaze": "jazer",
    "jazei": "jazer",
    "jazeis": "jazer",
    "jazem": "jazer",
    "jazemo": "jazer",
    "jazemos": "jazer",
    "jazendo": "jazer",
    "jazera": "jazer",
    "jazeram": "jazer",
    "jazeras": "jazer",
    "jazerdes": "jazer",
    "jazerei": "jazer",
    "jazereis": "jazer",
    "jazerem": "jazer",
    "jazeremos": "jazer",
    "jazeres": "jazer",
    "jazeria": "jazer",
    "jazeriam": "jazer",
    "jazerias": "jazer",
    "jazerina": "jazerino",
    "jazerinas": "jazerino",
    "jazerinos": "jazerino",
    "jazermo": "jazer",
    "jazermos": "jazer",
    "jazerá": "jazer",
    "jazerás": "jazer",
    "jazerão": "jazer",
    "jazeríamos": "jazer",
    "jazeríeis": "jazer",
    "jazerões": "jazerão",
    "jazes": "jazer",
    "jazesse": "jazer",
    "jazessem": "jazer",
    "jazesses": "jazer",
    "jazeste": "jazer",
    "jazestes": "jazer",
    "jazeu": "jazer",
    "jazi": "jazer",
    "jazia": "jazer",
    "jaziam": "jazer",
    "jazias": "jazer",
    "jazida": "jazer",
    "jazidas": "jazida",
    "jazido": "jazer",
    "jazidos": "jazer",
    "jazigos": "jazigo",
    "jazimentos": "jazimento",
    "jazituras": "jazitura",
    "jazo": "jazer",
    "jazzes": "jazz",
    "jazzistas": "jazzista",
    "jazzística": "jazzístico",
    "jazzísticas": "jazzístico",
    "jazzísticos": "jazzístico",
    "jazêramo": "jazer",
    "jazêramos": "jazer",
    "jazêreis": "jazer",
    "jazêsseis": "jazer",
    "jazêssemos": "jazer",
    "jazíamo": "jazer",
    "jazíamos": "jazer",
    "jazíeis": "jazer",
    "jaças": "jaça",
    "jaús": "jaú",
    "jeeps": "jeep",
    "jeiras": "jeira",
    "jeirões": "jeirão",
    "jeitaços": "jeitaço",
    "jeiteiras": "jeiteira",
    "jeitinho": "jeito",
    "jeitinhos": "jeito",
    "jeitito": "jeito",
    "jeititos": "jeito",
    "jeitos": "jeito",
    "jeitosa": "jeitoso",
    "jeitosas": "jeitoso",
    "jeitosos": "jeitoso",
    "jeitões": "jeitão",
    "jejua": "jejuar",
    "jejuada": "jejuar",
    "jejuadas": "jejuar",
    "jejuado": "jejuar",
    "jejuadora": "jejuador",
    "jejuadoras": "jejuador",
    "jejuadores": "jejuador",
    "jejuados": "jejuar",
    "jejuai": "jejuar",
    "jejuais": "jejuar",
    "jejuam": "jejuar",
    "jejuamo": "jejuar",
    "jejuamos": "jejuar",
    "jejuando": "jejuar",
    "jejuara": "jejuar",
    "jejuaram": "jejuar",
    "jejuaras": "jejuar",
    "jejuardes": "jejuar",
    "jejuarei": "jejuar",
    "jejuareis": "jejuar",
    "jejuarem": "jejuar",
    "jejuaremos": "jejuar",
    "jejuares": "jejuar",
    "jejuaria": "jejuar",
    "jejuariam": "jejuar",
    "jejuarias": "jejuar",
    "jejuarmo": "jejuar",
    "jejuarmos": "jejuar",
    "jejuará": "jejuar",
    "jejuarás": "jejuar",
    "jejuarão": "jejuar",
    "jejuaríamos": "jejuar",
    "jejuaríeis": "jejuar",
    "jejuas": "jejuar",
    "jejuasse": "jejuar",
    "jejuassem": "jejuar",
    "jejuasses": "jejuar",
    "jejuaste": "jejuar",
    "jejuastes": "jejuar",
    "jejuava": "jejuar",
    "jejuavam": "jejuar",
    "jejuavas": "jejuar",
    "jejue": "jejuar",
    "jejuei": "jejuar",
    "jejueis": "jejuar",
    "jejuem": "jejuar",
    "jejuemo": "jejuar",
    "jejuemos": "jejuar",
    "jejues": "jejuar",
    "jejunos": "jejuno",
    "jejuns": "jejum",
    "jejuo": "jejuar",
    "jejuou": "jejuar",
    "jejuámo": "jejuar",
    "jejuámos": "jejuar",
    "jejuáramo": "jejuar",
    "jejuáramos": "jejuar",
    "jejuáreis": "jejuar",
    "jejuásseis": "jejuar",
    "jejuássemos": "jejuar",
    "jejuávamo": "jejuar",
    "jejuávamos": "jejuar",
    "jejuáveis": "jejuar",
    "jenipapadas": "jenipapada",
    "jenipaparanas": "jenipaparana",
    "jenipapeiros": "jenipapeiro",
    "jenipapos": "jenipapo",
    "jenolins": "jenolim",
    "jeovismos": "jeovismo",
    "jeovistas": "jeovista",
    "jeovás": "jeová",
    "jequiriobas": "jequirioba",
    "jequitiranabóias": "jequitiranabóia",
    "jerarcas": "jerarca",
    "jerarquias": "jerarquia",
    "jerebas": "jereba",
    "jeremia": "jeremiar",
    "jeremiada": "jeremiar",
    "jeremiadas": "jeremiar",
    "jeremiado": "jeremiar",
    "jeremiados": "jeremiar",
    "jeremiai": "jeremiar",
    "jeremiais": "jeremiar",
    "jeremiam": "jeremiar",
    "jeremiamo": "jeremiar",
    "jeremiamos": "jeremiar",
    "jeremiando": "jeremiar",
    "jeremiara": "jeremiar",
    "jeremiaram": "jeremiar",
    "jeremiaras": "jeremiar",
    "jeremiardes": "jeremiar",
    "jeremiarei": "jeremiar",
    "jeremiareis": "jeremiar",
    "jeremiarem": "jeremiar",
    "jeremiaremos": "jeremiar",
    "jeremiares": "jeremiar",
    "jeremiaria": "jeremiar",
    "jeremiariam": "jeremiar",
    "jeremiarias": "jeremiar",
    "jeremiarmo": "jeremiar",
    "jeremiarmos": "jeremiar",
    "jeremiará": "jeremiar",
    "jeremiarás": "jeremiar",
    "jeremiarão": "jeremiar",
    "jeremiaríamos": "jeremiar",
    "jeremiaríeis": "jeremiar",
    "jeremias": "jeremiar",
    "jeremiasse": "jeremiar",
    "jeremiassem": "jeremiar",
    "jeremiasses": "jeremiar",
    "jeremiaste": "jeremiar",
    "jeremiastes": "jeremiar",
    "jeremiava": "jeremiar",
    "jeremiavam": "jeremiar",
    "jeremiavas": "jeremiar",
    "jeremie": "jeremiar",
    "jeremiei": "jeremiar",
    "jeremieis": "jeremiar",
    "jeremiem": "jeremiar",
    "jeremiemo": "jeremiar",
    "jeremiemos": "jeremiar",
    "jeremies": "jeremiar",
    "jeremio": "jeremiar",
    "jeremiou": "jeremiar",
    "jeremiámo": "jeremiar",
    "jeremiámos": "jeremiar",
    "jeremiáramo": "jeremiar",
    "jeremiáramos": "jeremiar",
    "jeremiáreis": "jeremiar",
    "jeremiásseis": "jeremiar",
    "jeremiássemos": "jeremiar",
    "jeremiávamo": "jeremiar",
    "jeremiávamos": "jeremiar",
    "jeremiáveis": "jeremiar",
    "jererés": "jereré",
    "jeribazeiros": "jeribazeiro",
    "jeribitas": "jeribita",
    "jeribás": "jeribá",
    "jerica": "jerico",
    "jericadas": "jericada",
    "jericais": "jerical",
    "jericas": "jerico",
    "jericos": "jerico",
    "jerimuns": "jerimum",
    "jerimus": "jerimu",
    "jeripitis": "jeripiti",
    "jerivás": "jerivá",
    "jeroglífica": "jeroglífico",
    "jeroglíficas": "jeroglífico",
    "jeroglíficos": "jeroglífico",
    "jeronimitas": "jeronimita",
    "jeropigas": "jeropiga",
    "jerosolimitana": "jerosolimitano",
    "jerosolimitanas": "jerosolimitano",
    "jerosolimitanos": "jerosolimitano",
    "jerárquica": "jerárquico",
    "jerárquicas": "jerárquico",
    "jerárquicos": "jerárquico",
    "jeróglifos": "jeróglifo",
    "jerónima": "jerónimo",
    "jerónimas": "jerónimo",
    "jerónimos": "jerónimo",
    "jessaís": "jessaí",
    "jesuitadas": "jesuitada",
    "jesuitices": "jesuitice",
    "jesuitismos": "jesuitismo",
    "jesuitofobias": "jesuitofobia",
    "jesuss": "jesus",
    "jesuítas": "jesuíta",
    "jesuítica": "jesuítico",
    "jesuíticas": "jesuítico",
    "jesuíticos": "jesuítico",
    "jetaíbas": "jetaíba",
    "jetaís": "jetaí",
    "jeticas": "jetica",
    "jibas": "jiba",
    "jibóias": "jibóia",
    "jicaras": "jicara",
    "jifingos": "jifingo",
    "jigajogas": "jigajoga",
    "jigas": "jiga",
    "jilabas": "jilaba",
    "jiloeiros": "jiloeiro",
    "jilós": "jiló",
    "jimbolamentos": "jimbolamento",
    "jimbolos": "jimbolo",
    "jimbos": "jimbo",
    "jinga": "jingo",
    "jingas": "jingo",
    "jingles": "jingle",
    "jingos": "jingo",
    "jingoísmos": "jingoísmo",
    "jingoístas": "jingoísta",
    "jingubas": "jinguba",
    "jipes": "jipe",
    "jipoúbas": "jipoúba",
    "jipão": "jipe",
    "jipões": "jipe",
    "jirimuns": "jirimum",
    "jirimus": "jirimu",
    "jiripitis": "jiripiti",
    "jis": "ji",
    "jiticas": "jitica",
    "jitos": "jito",
    "jj": "j",
    "joalharias": "joalharia",
    "joalheira": "joalheiro",
    "joalheiras": "joalheiro",
    "joalheirazinha": "joalheiro",
    "joalheirazinhas": "joalheiro",
    "joalheirazita": "joalheiro",
    "joalheirazitas": "joalheiro",
    "joalheiros": "joalheiro",
    "joalheirozinho": "joalheiro",
    "joalheirozinhos": "joalheiro",
    "joalheirozito": "joalheiro",
    "joalheirozitos": "joalheiro",
    "joanetes": "joanete",
    "joanica": "joanico",
    "joanicas": "joanico",
    "joanicos": "joanico",
    "joanina": "joanino",
    "joaninas": "joanino",
    "joaninhas": "joaninha",
    "joaninos": "joanino",
    "jobes": "job",
    "jocosa": "jocoso",
    "jocosas": "jocoso",
    "jocosidades": "jocosidade",
    "jocosos": "jocoso",
    "jocós": "jocó",
    "joeira": "joeirar",
    "joeirada": "joeirar",
    "joeiradas": "joeirar",
    "joeirado": "joeirar",
    "joeirados": "joeirar",
    "joeirai": "joeirar",
    "joeirais": "joeirar",
    "joeiram": "joeirar",
    "joeiramentos": "joeiramento",
    "joeiramo": "joeirar",
    "joeiramos": "joeirar",
    "joeirando": "joeirar",
    "joeirara": "joeirar",
    "joeiraram": "joeirar",
    "joeiraras": "joeirar",
    "joeirarde": "joeirar",
    "joeirardes": "joeirar",
    "joeirare": "joeirar",
    "joeirarei": "joeirar",
    "joeirareis": "joeirar",
    "joeirarem": "joeirar",
    "joeiraremos": "joeirar",
    "joeirares": "joeirar",
    "joeiraria": "joeirar",
    "joeirariam": "joeirar",
    "joeirarias": "joeirar",
    "joeirarmo": "joeirar",
    "joeirarmos": "joeirar",
    "joeirará": "joeirar",
    "joeirarás": "joeirar",
    "joeirarão": "joeirar",
    "joeiraríamos": "joeirar",
    "joeiraríeis": "joeirar",
    "joeiras": "joeirar",
    "joeirasse": "joeirar",
    "joeirassem": "joeirar",
    "joeirasses": "joeirar",
    "joeiraste": "joeirar",
    "joeirastes": "joeirar",
    "joeirava": "joeirar",
    "joeiravam": "joeirar",
    "joeiravas": "joeirar",
    "joeire": "joeirar",
    "joeirei": "joeirar",
    "joeireira": "joeireiro",
    "joeireiras": "joeireiro",
    "joeireiros": "joeireiro",
    "joeireis": "joeirar",
    "joeirem": "joeirar",
    "joeiremo": "joeirar",
    "joeiremos": "joeirar",
    "joeires": "joeirar",
    "joeiro": "joeirar",
    "joeiros": "joeiro",
    "joeirou": "joeirar",
    "joeirá": "joeirar",
    "joeirámo": "joeirar",
    "joeirámos": "joeirar",
    "joeiráramo": "joeirar",
    "joeiráramos": "joeirar",
    "joeirárei": "joeirar",
    "joeiráreis": "joeirar",
    "joeirásseis": "joeirar",
    "joeirássemos": "joeirar",
    "joeirávamo": "joeirar",
    "joeirávamos": "joeirar",
    "joeirávei": "joeirar",
    "joeiráveis": "joeirar",
    "joelha": "joelhar",
    "joelhada": "joelhar",
    "joelhadas": "joelhar",
    "joelhado": "joelhar",
    "joelhados": "joelhar",
    "joelhai": "joelhar",
    "joelhais": "joelhar",
    "joelham": "joelhar",
    "joelhamo": "joelhar",
    "joelhamos": "joelhar",
    "joelhando": "joelhar",
    "joelhara": "joelhar",
    "joelharam": "joelhar",
    "joelharas": "joelhar",
    "joelhardes": "joelhar",
    "joelharei": "joelhar",
    "joelhareis": "joelhar",
    "joelharem": "joelhar",
    "joelharemos": "joelhar",
    "joelhares": "joelhar",
    "joelharia": "joelhar",
    "joelhariam": "joelhar",
    "joelharias": "joelhar",
    "joelharmo": "joelhar",
    "joelharmos": "joelhar",
    "joelhará": "joelhar",
    "joelharás": "joelhar",
    "joelharão": "joelhar",
    "joelharíamos": "joelhar",
    "joelharíeis": "joelhar",
    "joelhas": "joelhar",
    "joelhasse": "joelhar",
    "joelhassem": "joelhar",
    "joelhasses": "joelhar",
    "joelhaste": "joelhar",
    "joelhastes": "joelhar",
    "joelhava": "joelhar",
    "joelhavam": "joelhar",
    "joelhavas": "joelhar",
    "joelhaços": "joelhaço",
    "joelhe": "joelhar",
    "joelhei": "joelhar",
    "joelheira": "joelheiro",
    "joelheiras": "joelheiro",
    "joelheiros": "joelheiro",
    "joelheis": "joelhar",
    "joelhem": "joelhar",
    "joelhemo": "joelhar",
    "joelhemos": "joelhar",
    "joelhes": "joelhar",
    "joelho": "joelhar",
    "joelhos": "joelho",
    "joelhou": "joelhar",
    "joelhámo": "joelhar",
    "joelhámos": "joelhar",
    "joelháramo": "joelhar",
    "joelháramos": "joelhar",
    "joelháreis": "joelhar",
    "joelhásseis": "joelhar",
    "joelhássemos": "joelhar",
    "joelhávamo": "joelhar",
    "joelhávamos": "joelhar",
    "joelháveis": "joelhar",
    "joga": "jogar",
    "jogada": "jogar",
    "jogadas": "jogar",
    "jogadinha": "jogada",
    "jogadinhas": "jogada",
    "jogadita": "jogada",
    "jogaditas": "jogada",
    "jogado": "jogar",
    "jogadora": "jogador",
    "jogadoras": "jogador",
    "jogadores": "jogador",
    "jogados": "jogar",
    "jogadouros": "jogadouro",
    "jogai": "jogar",
    "jogais": "jogar",
    "jogam": "jogar",
    "jogamo": "jogar",
    "jogamos": "jogar",
    "jogando": "jogar",
    "jogara": "jogar",
    "jogaram": "jogar",
    "jogaras": "jogar",
    "jogarde": "jogar",
    "jogardes": "jogar",
    "jogare": "jogar",
    "jogarei": "jogar",
    "jogareis": "jogar",
    "jogarem": "jogar",
    "jogaremos": "jogar",
    "jogares": "jogar",
    "jogaria": "jogar",
    "jogariam": "jogar",
    "jogarias": "jogar",
    "jogarmo": "jogar",
    "jogarmos": "jogar",
    "jogará": "jogar",
    "jogarás": "jogar",
    "jogarão": "jogar",
    "jogaríamos": "jogar",
    "jogaríeis": "jogar",
    "jogas": "jogar",
    "jogasse": "jogar",
    "jogassem": "jogar",
    "jogasses": "jogar",
    "jogaste": "jogar",
    "jogastes": "jogar",
    "jogatanas": "jogatana",
    "jogatas": "jogata",
    "jogatinas": "jogatina",
    "jogava": "jogar",
    "jogavam": "jogar",
    "jogavas": "jogar",
    "joggings": "jogging",
    "jogo": "jogar",
    "jogos": "jogo",
    "jogou": "jogar",
    "jograis": "jogral",
    "jogralesas": "jogralesa",
    "jogralescas": "jogralesca",
    "jogralices": "jogralice",
    "jogralidades": "jogralidade",
    "jogue": "jogar",
    "joguei": "jogar",
    "jogueis": "jogar",
    "joguem": "jogar",
    "joguemo": "jogar",
    "joguemos": "jogar",
    "jogues": "jogue",
    "jogueta": "joguetar",
    "joguetada": "joguetar",
    "joguetadas": "joguetar",
    "joguetado": "joguetar",
    "joguetados": "joguetar",
    "joguetai": "joguetar",
    "joguetais": "joguetar",
    "joguetam": "joguetar",
    "joguetamo": "joguetar",
    "joguetamos": "joguetar",
    "joguetando": "joguetar",
    "joguetara": "joguetar",
    "joguetaram": "joguetar",
    "joguetaras": "joguetar",
    "joguetardes": "joguetar",
    "joguetarei": "joguetar",
    "joguetareis": "joguetar",
    "joguetarem": "joguetar",
    "joguetaremos": "joguetar",
    "joguetares": "joguetar",
    "joguetaria": "joguetar",
    "joguetariam": "joguetar",
    "joguetarias": "joguetar",
    "joguetarmo": "joguetar",
    "joguetarmos": "joguetar",
    "joguetará": "joguetar",
    "joguetarás": "joguetar",
    "joguetarão": "joguetar",
    "joguetaríamos": "joguetar",
    "joguetaríeis": "joguetar",
    "joguetas": "joguetar",
    "joguetasse": "joguetar",
    "joguetassem": "joguetar",
    "joguetasses": "joguetar",
    "joguetaste": "joguetar",
    "joguetastes": "joguetar",
    "joguetava": "joguetar",
    "joguetavam": "joguetar",
    "joguetavas": "joguetar",
    "joguete": "joguetar",
    "jogueteada": "joguetear",
    "jogueteadas": "joguetear",
    "jogueteado": "joguetear",
    "jogueteados": "joguetear",
    "jogueteai": "joguetear",
    "jogueteais": "joguetear",
    "jogueteamo": "joguetear",
    "jogueteamos": "joguetear",
    "jogueteando": "joguetear",
    "jogueteara": "joguetear",
    "joguetearam": "joguetear",
    "joguetearas": "joguetear",
    "jogueteardes": "joguetear",
    "joguetearei": "joguetear",
    "jogueteareis": "joguetear",
    "joguetearem": "joguetear",
    "joguetearemos": "joguetear",
    "jogueteares": "joguetear",
    "joguetearia": "joguetear",
    "jogueteariam": "joguetear",
    "joguetearias": "joguetear",
    "joguetearmo": "joguetear",
    "joguetearmos": "joguetear",
    "jogueteará": "joguetear",
    "joguetearás": "joguetear",
    "joguetearão": "joguetear",
    "joguetearíamos": "joguetear",
    "joguetearíeis": "joguetear",
    "jogueteasse": "joguetear",
    "jogueteassem": "joguetear",
    "jogueteasses": "joguetear",
    "jogueteaste": "joguetear",
    "jogueteastes": "joguetear",
    "jogueteava": "joguetear",
    "jogueteavam": "joguetear",
    "jogueteavas": "joguetear",
    "jogueteei": "joguetear",
    "jogueteeis": "joguetear",
    "jogueteemo": "joguetear",
    "jogueteemos": "joguetear",
    "joguetei": "joguetar",
    "jogueteia": "joguetear",
    "jogueteiam": "joguetear",
    "jogueteias": "joguetear",
    "jogueteie": "joguetear",
    "jogueteiem": "joguetear",
    "jogueteies": "joguetear",
    "jogueteio": "joguetear",
    "jogueteis": "joguetar",
    "joguetem": "joguetar",
    "joguetemo": "joguetar",
    "joguetemos": "joguetar",
    "jogueteou": "joguetear",
    "joguetes": "joguete",
    "jogueteámo": "joguetear",
    "jogueteámos": "joguetear",
    "jogueteáramo": "joguetear",
    "jogueteáramos": "joguetear",
    "jogueteáreis": "joguetear",
    "jogueteásseis": "joguetear",
    "jogueteássemos": "joguetear",
    "jogueteávamo": "joguetear",
    "jogueteávamos": "joguetear",
    "jogueteáveis": "joguetear",
    "jogueto": "joguetar",
    "joguetou": "joguetar",
    "joguetámo": "joguetar",
    "joguetámos": "joguetar",
    "joguetáramo": "joguetar",
    "joguetáramos": "joguetar",
    "joguetáreis": "joguetar",
    "joguetásseis": "joguetar",
    "joguetássemos": "joguetar",
    "joguetávamo": "joguetar",
    "joguetávamos": "joguetar",
    "joguetáveis": "joguetar",
    "joguinho": "jogo",
    "joguinhos": "jogo",
    "joguito": "jogo",
    "joguitos": "jogo",
    "jogá": "jogar",
    "jogámo": "jogar",
    "jogámos": "jogar",
    "jogáramo": "jogar",
    "jogáramos": "jogar",
    "jogárei": "jogar",
    "jogáreis": "jogar",
    "jogásseis": "jogar",
    "jogássemos": "jogar",
    "jogávamo": "jogar",
    "jogávamos": "jogar",
    "jogávei": "jogar",
    "jogáveis": "jogável",
    "jogões": "jogão",
    "joios": "joio",
    "jokers": "joker",
    "joldas": "jolda",
    "joldeira": "joldeiro",
    "joldeiras": "joldeiro",
    "joldeiros": "joldeiro",
    "joldras": "joldra",
    "jordana": "jordano",
    "jordanas": "jordano",
    "jordanos": "jordano",
    "jornadas": "jornada",
    "jornadeada": "jornadear",
    "jornadeadas": "jornadear",
    "jornadeado": "jornadear",
    "jornadeados": "jornadear",
    "jornadeai": "jornadear",
    "jornadeais": "jornadear",
    "jornadeamo": "jornadear",
    "jornadeamos": "jornadear",
    "jornadeando": "jornadear",
    "jornadeara": "jornadear",
    "jornadearam": "jornadear",
    "jornadearas": "jornadear",
    "jornadeardes": "jornadear",
    "jornadearei": "jornadear",
    "jornadeareis": "jornadear",
    "jornadearem": "jornadear",
    "jornadearemos": "jornadear",
    "jornadeares": "jornadear",
    "jornadearia": "jornadear",
    "jornadeariam": "jornadear",
    "jornadearias": "jornadear",
    "jornadearmo": "jornadear",
    "jornadearmos": "jornadear",
    "jornadeará": "jornadear",
    "jornadearás": "jornadear",
    "jornadearão": "jornadear",
    "jornadearíamos": "jornadear",
    "jornadearíeis": "jornadear",
    "jornadeasse": "jornadear",
    "jornadeassem": "jornadear",
    "jornadeasses": "jornadear",
    "jornadeaste": "jornadear",
    "jornadeastes": "jornadear",
    "jornadeava": "jornadear",
    "jornadeavam": "jornadear",
    "jornadeavas": "jornadear",
    "jornadeei": "jornadear",
    "jornadeeis": "jornadear",
    "jornadeemo": "jornadear",
    "jornadeemos": "jornadear",
    "jornadeia": "jornadear",
    "jornadeiam": "jornadear",
    "jornadeias": "jornadear",
    "jornadeie": "jornadear",
    "jornadeiem": "jornadear",
    "jornadeies": "jornadear",
    "jornadeio": "jornadear",
    "jornadeou": "jornadear",
    "jornadeámo": "jornadear",
    "jornadeámos": "jornadear",
    "jornadeáramo": "jornadear",
    "jornadeáramos": "jornadear",
    "jornadeáreis": "jornadear",
    "jornadeásseis": "jornadear",
    "jornadeássemos": "jornadear",
    "jornadeávamo": "jornadear",
    "jornadeávamos": "jornadear",
    "jornadeáveis": "jornadear",
    "jornais": "jornal",
    "jornaizinhos": "jornal",
    "jornaizitos": "jornal",
    "jornaladas": "jornalada",
    "jornalecos": "jornaleco",
    "jornaleira": "jornaleiro",
    "jornaleiras": "jornaleiro",
    "jornaleiros": "jornaleiro",
    "jornalinho": "jornal",
    "jornalinhos": "jornal",
    "jornalismos": "jornalismo",
    "jornalistas": "jornalista",
    "jornalito": "jornal",
    "jornalitos": "jornal",
    "jornalzinho": "jornal",
    "jornalzito": "jornal",
    "jornalística": "jornalístico",
    "jornalísticas": "jornalístico",
    "jornalísticos": "jornalístico",
    "jornas": "jorna",
    "jorneias": "jorneia",
    "jorra": "jorrar",
    "jorrada": "jorrar",
    "jorradas": "jorrar",
    "jorrado": "jorrar",
    "jorrados": "jorrar",
    "jorrai": "jorrar",
    "jorrais": "jorrar",
    "jorram": "jorrar",
    "jorramentos": "jorramento",
    "jorramo": "jorrar",
    "jorramos": "jorrar",
    "jorrando": "jorrar",
    "jorrara": "jorrar",
    "jorraram": "jorrar",
    "jorraras": "jorrar",
    "jorrarde": "jorrar",
    "jorrardes": "jorrar",
    "jorrare": "jorrar",
    "jorrarei": "jorrar",
    "jorrareis": "jorrar",
    "jorrarem": "jorrar",
    "jorraremos": "jorrar",
    "jorrares": "jorrar",
    "jorraria": "jorrar",
    "jorrariam": "jorrar",
    "jorrarias": "jorrar",
    "jorrarmo": "jorrar",
    "jorrarmos": "jorrar",
    "jorrará": "jorrar",
    "jorrarás": "jorrar",
    "jorrarão": "jorrar",
    "jorraríamos": "jorrar",
    "jorraríeis": "jorrar",
    "jorras": "jorrar",
    "jorrasse": "jorrar",
    "jorrassem": "jorrar",
    "jorrasses": "jorrar",
    "jorraste": "jorrar",
    "jorrastes": "jorrar",
    "jorrava": "jorrar",
    "jorravam": "jorrar",
    "jorravas": "jorrar",
    "jorre": "jorrar",
    "jorrei": "jorrar",
    "jorreis": "jorrar",
    "jorrem": "jorrar",
    "jorremo": "jorrar",
    "jorremos": "jorrar",
    "jorres": "jorrar",
    "jorro": "jorrar",
    "jorros": "jorro",
    "jorrou": "jorrar",
    "jorrá": "jorrar",
    "jorrámo": "jorrar",
    "jorrámos": "jorrar",
    "jorráramo": "jorrar",
    "jorráramos": "jorrar",
    "jorrárei": "jorrar",
    "jorráreis": "jorrar",
    "jorrásseis": "jorrar",
    "jorrássemos": "jorrar",
    "jorrávamo": "jorrar",
    "jorrávamos": "jorrar",
    "jorrávei": "jorrar",
    "jorráveis": "jorrar",
    "jorrões": "jorrão",
    "josefina": "josefino",
    "josefinas": "josefino",
    "josefinos": "josefino",
    "josezinhos": "josezinho",
    "jotas": "jota",
    "jotnianos": "jotniano",
    "joules": "joule",
    "jovens": "jovem",
    "jovenzinha": "jovem",
    "jovenzinhas": "jovem",
    "jovenzinho": "jovem",
    "jovenzinhos": "jovem",
    "jovenzita": "jovem",
    "jovenzitas": "jovem",
    "jovenzito": "jovem",
    "jovenzitos": "jovem",
    "joviais": "jovial",
    "jovialidades": "jovialidade",
    "jovializa": "jovializar",
    "jovializada": "jovializar",
    "jovializadas": "jovializar",
    "jovializado": "jovializar",
    "jovializados": "jovializar",
    "jovializai": "jovializar",
    "jovializais": "jovializar",
    "jovializam": "jovializar",
    "jovializamo": "jovializar",
    "jovializamos": "jovializar",
    "jovializando": "jovializar",
    "jovializara": "jovializar",
    "jovializaram": "jovializar",
    "jovializaras": "jovializar",
    "jovializarde": "jovializar",
    "jovializardes": "jovializar",
    "jovializare": "jovializar",
    "jovializarei": "jovializar",
    "jovializareis": "jovializar",
    "jovializarem": "jovializar",
    "jovializaremos": "jovializar",
    "jovializares": "jovializar",
    "jovializaria": "jovializar",
    "jovializariam": "jovializar",
    "jovializarias": "jovializar",
    "jovializarmo": "jovializar",
    "jovializarmos": "jovializar",
    "jovializará": "jovializar",
    "jovializarás": "jovializar",
    "jovializarão": "jovializar",
    "jovializaríamos": "jovializar",
    "jovializaríeis": "jovializar",
    "jovializas": "jovializar",
    "jovializasse": "jovializar",
    "jovializassem": "jovializar",
    "jovializasses": "jovializar",
    "jovializaste": "jovializar",
    "jovializastes": "jovializar",
    "jovializava": "jovializar",
    "jovializavam": "jovializar",
    "jovializavas": "jovializar",
    "jovialize": "jovializar",
    "jovializei": "jovializar",
    "jovializeis": "jovializar",
    "jovializem": "jovializar",
    "jovializemo": "jovializar",
    "jovializemos": "jovializar",
    "jovializes": "jovializar",
    "jovializo": "jovializar",
    "jovializou": "jovializar",
    "jovializá": "jovializar",
    "jovializámo": "jovializar",
    "jovializámos": "jovializar",
    "jovializáramo": "jovializar",
    "jovializáramos": "jovializar",
    "jovializárei": "jovializar",
    "jovializáreis": "jovializar",
    "jovializásseis": "jovializar",
    "jovializássemos": "jovializar",
    "jovializávamo": "jovializar",
    "jovializávamos": "jovializar",
    "jovializávei": "jovializar",
    "jovializáveis": "jovializar",
    "juazeiros": "juazeiro",
    "jubada": "jubado",
    "jubadas": "jubado",
    "jubados": "jubado",
    "jubanetes": "jubanete",
    "jubas": "juba",
    "jubetas": "jubeta",
    "jubila": "jubilar",
    "jubilada": "jubilar",
    "jubiladas": "jubilar",
    "jubilado": "jubilar",
    "jubilados": "jubilar",
    "jubilai": "jubilar",
    "jubilais": "jubilar",
    "jubilam": "jubilar",
    "jubilamo": "jubilar",
    "jubilamos": "jubilar",
    "jubilando": "jubilar",
    "jubilara": "jubilar",
    "jubilaram": "jubilar",
    "jubilaras": "jubilar",
    "jubilarde": "jubilar",
    "jubilardes": "jubilar",
    "jubilare": "jubilar",
    "jubilarei": "jubilar",
    "jubilareis": "jubilar",
    "jubilarem": "jubilar",
    "jubilaremos": "jubilar",
    "jubilares": "jubilar",
    "jubilaria": "jubilar",
    "jubilariam": "jubilar",
    "jubilarias": "jubilar",
    "jubilarmo": "jubilar",
    "jubilarmos": "jubilar",
    "jubilará": "jubilar",
    "jubilarás": "jubilar",
    "jubilarão": "jubilar",
    "jubilaríamos": "jubilar",
    "jubilaríeis": "jubilar",
    "jubilas": "jubilar",
    "jubilasse": "jubilar",
    "jubilassem": "jubilar",
    "jubilasses": "jubilar",
    "jubilaste": "jubilar",
    "jubilastes": "jubilar",
    "jubilatória": "jubilatório",
    "jubilatórias": "jubilatório",
    "jubilatórios": "jubilatório",
    "jubilava": "jubilar",
    "jubilavam": "jubilar",
    "jubilavas": "jubilar",
    "jubilações": "jubilação",
    "jubile": "jubilar",
    "jubilei": "jubilar",
    "jubileis": "jubilar",
    "jubilem": "jubilar",
    "jubilemo": "jubilar",
    "jubilemos": "jubilar",
    "jubiles": "jubilar",
    "jubileus": "jubileu",
    "jubilo": "jubilar",
    "jubilosa": "jubiloso",
    "jubilosas": "jubiloso",
    "jubilosos": "jubiloso",
    "jubilou": "jubilar",
    "jubilá": "jubilar",
    "jubilámo": "jubilar",
    "jubilámos": "jubilar",
    "jubiláramo": "jubilar",
    "jubiláramos": "jubilar",
    "jubilárei": "jubilar",
    "jubiláreis": "jubilar",
    "jubilásseis": "jubilar",
    "jubilássemos": "jubilar",
    "jubilávamo": "jubilar",
    "jubilávamos": "jubilar",
    "jubilávei": "jubilar",
    "jubiláveis": "jubilável",
    "juciris": "juciri",
    "jucubaúbas": "jucubaúba",
    "jucunda": "jucundo",
    "jucundas": "jucundo",
    "jucundidades": "jucundidade",
    "jucundos": "jucundo",
    "jucurus": "jucuru",
    "jucurutus": "jucurutu",
    "jucás": "jucá",
    "judaica": "judaico",
    "judaicas": "judaico",
    "judaicos": "judaico",
    "judaiza": "judaizar",
    "judaizada": "judaizar",
    "judaizadas": "judaizar",
    "judaizado": "judaizar",
    "judaizados": "judaizar",
    "judaizai": "judaizar",
    "judaizais": "judaizar",
    "judaizam": "judaizar",
    "judaizamo": "judaizar",
    "judaizamos": "judaizar",
    "judaizando": "judaizar",
    "judaizantes": "judaizante",
    "judaizara": "judaizar",
    "judaizaram": "judaizar",
    "judaizaras": "judaizar",
    "judaizarde": "judaizar",
    "judaizardes": "judaizar",
    "judaizare": "judaizar",
    "judaizarei": "judaizar",
    "judaizareis": "judaizar",
    "judaizarem": "judaizar",
    "judaizaremos": "judaizar",
    "judaizares": "judaizar",
    "judaizaria": "judaizar",
    "judaizariam": "judaizar",
    "judaizarias": "judaizar",
    "judaizarmo": "judaizar",
    "judaizarmos": "judaizar",
    "judaizará": "judaizar",
    "judaizarás": "judaizar",
    "judaizarão": "judaizar",
    "judaizaríamos": "judaizar",
    "judaizaríeis": "judaizar",
    "judaizas": "judaizar",
    "judaizasse": "judaizar",
    "judaizassem": "judaizar",
    "judaizasses": "judaizar",
    "judaizaste": "judaizar",
    "judaizastes": "judaizar",
    "judaizava": "judaizar",
    "judaizavam": "judaizar",
    "judaizavas": "judaizar",
    "judaize": "judaizar",
    "judaizei": "judaizar",
    "judaizeis": "judaizar",
    "judaizem": "judaizar",
    "judaizemo": "judaizar",
    "judaizemos": "judaizar",
    "judaizes": "judaizar",
    "judaizo": "judaizar",
    "judaizou": "judaizar",
    "judaizá": "judaizar",
    "judaizámo": "judaizar",
    "judaizámos": "judaizar",
    "judaizáramo": "judaizar",
    "judaizáramos": "judaizar",
    "judaizárei": "judaizar",
    "judaizáreis": "judaizar",
    "judaizásseis": "judaizar",
    "judaizássemos": "judaizar",
    "judaizávamo": "judaizar",
    "judaizávamos": "judaizar",
    "judaizávei": "judaizar",
    "judaizáveis": "judaizável",
    "judaísmos": "judaísmo",
    "judaístas": "judaísta",
    "judengas": "judenga",
    "judeus": "judeu",
    "judia": "judio",
    "judiada": "judiar",
    "judiadas": "judiar",
    "judiado": "judiar",
    "judiados": "judiar",
    "judiai": "judiar",
    "judiais": "judiar",
    "judiam": "judiar",
    "judiamo": "judiar",
    "judiamos": "judiar",
    "judiando": "judiar",
    "judiara": "judiar",
    "judiaram": "judiar",
    "judiaras": "judiar",
    "judiardes": "judiar",
    "judiarei": "judiar",
    "judiareis": "judiar",
    "judiarem": "judiar",
    "judiaremos": "judiar",
    "judiares": "judiar",
    "judiaria": "judiar",
    "judiariam": "judiar",
    "judiarias": "judiaria",
    "judiarmo": "judiar",
    "judiarmos": "judiar",
    "judiará": "judiar",
    "judiarás": "judiar",
    "judiarão": "judiar",
    "judiaríamos": "judiar",
    "judiaríeis": "judiar",
    "judias": "judio",
    "judiasse": "judiar",
    "judiassem": "judiar",
    "judiasses": "judiar",
    "judiaste": "judiar",
    "judiastes": "judiar",
    "judiava": "judiar",
    "judiavam": "judiar",
    "judiavas": "judiar",
    "judicativa": "judicativo",
    "judicativas": "judicativo",
    "judicativos": "judicativo",
    "judicaturas": "judicatura",
    "judicatória": "judicatório",
    "judicatórias": "judicatório",
    "judicatórios": "judicatório",
    "judicia": "judiciar",
    "judiciada": "judiciar",
    "judiciadas": "judiciar",
    "judiciado": "judiciar",
    "judiciados": "judiciar",
    "judiciai": "judiciar",
    "judiciais": "judiciar",
    "judiciam": "judiciar",
    "judiciamo": "judiciar",
    "judiciamos": "judiciar",
    "judiciando": "judiciar",
    "judiciara": "judiciar",
    "judiciaram": "judiciar",
    "judiciaras": "judiciar",
    "judiciardes": "judiciar",
    "judiciarei": "judiciar",
    "judiciareis": "judiciar",
    "judiciarem": "judiciar",
    "judiciaremos": "judiciar",
    "judiciares": "judiciar",
    "judiciaria": "judiciar",
    "judiciariam": "judiciar",
    "judiciarias": "judiciar",
    "judiciarmo": "judiciar",
    "judiciarmos": "judiciar",
    "judiciará": "judiciar",
    "judiciarás": "judiciar",
    "judiciarão": "judiciar",
    "judiciaríamos": "judiciar",
    "judiciaríeis": "judiciar",
    "judicias": "judiciar",
    "judiciasse": "judiciar",
    "judiciassem": "judiciar",
    "judiciasses": "judiciar",
    "judiciaste": "judiciar",
    "judiciastes": "judiciar",
    "judiciava": "judiciar",
    "judiciavam": "judiciar",
    "judiciavas": "judiciar",
    "judicie": "judiciar",
    "judiciei": "judiciar",
    "judicieis": "judiciar",
    "judiciem": "judiciar",
    "judiciemo": "judiciar",
    "judiciemos": "judiciar",
    "judicies": "judiciar",
    "judicio": "judiciar",
    "judiciosa": "judicioso",
    "judiciosas": "judicioso",
    "judiciosos": "judicioso",
    "judiciou": "judiciar",
    "judiciámo": "judiciar",
    "judiciámos": "judiciar",
    "judiciáramo": "judiciar",
    "judiciáramos": "judiciar",
    "judiciáreis": "judiciar",
    "judiciária": "judiciário",
    "judiciárias": "judiciário",
    "judiciários": "judiciário",
    "judiciásseis": "judiciar",
    "judiciássemos": "judiciar",
    "judiciávamo": "judiciar",
    "judiciávamos": "judiciar",
    "judiciáveis": "judiciar",
    "judie": "judiar",
    "judiei": "judiar",
    "judieis": "judiar",
    "judiem": "judiar",
    "judiemo": "judiar",
    "judiemos": "judiar",
    "judies": "judiar",
    "judio": "judiar",
    "judios": "judio",
    "judiou": "judiar",
    "judiámo": "judiar",
    "judiámos": "judiar",
    "judiáramo": "judiar",
    "judiáramos": "judiar",
    "judiáreis": "judiar",
    "judiásseis": "judiar",
    "judiássemos": "judiar",
    "judiávamo": "judiar",
    "judiávamos": "judiar",
    "judiáveis": "judiar",
    "judocas": "judoca",
    "judos": "judo",
    "juga": "jugar",
    "jugada": "jugar",
    "jugadas": "jugar",
    "jugadeira": "jugadeiro",
    "jugadeiras": "jugadeiro",
    "jugadeiros": "jugadeiro",
    "jugado": "jugar",
    "jugadores": "jugador",
    "jugados": "jugar",
    "jugai": "jugar",
    "jugais": "jugar",
    "jugam": "jugar",
    "jugamo": "jugar",
    "jugamos": "jugar",
    "jugando": "jugar",
    "jugara": "jugar",
    "jugaram": "jugar",
    "jugaras": "jugar",
    "jugarde": "jugar",
    "jugardes": "jugar",
    "jugare": "jugar",
    "jugarei": "jugar",
    "jugareis": "jugar",
    "jugarem": "jugar",
    "jugaremos": "jugar",
    "jugares": "jugar",
    "jugaria": "jugar",
    "jugariam": "jugar",
    "jugarias": "jugaria",
    "jugarmo": "jugar",
    "jugarmos": "jugar",
    "jugará": "jugar",
    "jugarás": "jugar",
    "jugarão": "jugar",
    "jugaríamos": "jugar",
    "jugaríeis": "jugar",
    "jugas": "jugar",
    "jugasse": "jugar",
    "jugassem": "jugar",
    "jugasses": "jugar",
    "jugaste": "jugar",
    "jugastes": "jugar",
    "jugava": "jugar",
    "jugavam": "jugar",
    "jugavas": "jugar",
    "juglandinas": "juglandina",
    "juglandáceas": "juglandácea",
    "jugo": "jugar",
    "jugos": "jugo",
    "jugoslava": "jugoslavo",
    "jugoslavas": "jugoslavo",
    "jugoslavos": "jugoslavo",
    "jugou": "jugar",
    "jugue": "jugar",
    "juguei": "jugar",
    "jugueira": "jugueiro",
    "jugueiras": "jugueiro",
    "jugueiros": "jugueiro",
    "jugueis": "jugar",
    "juguem": "jugar",
    "juguemo": "jugar",
    "juguemos": "jugar",
    "jugues": "jugar",
    "jugulantes": "jugulante",
    "jugulares": "jugular",
    "jugulações": "jugulação",
    "juguleiras": "juguleira",
    "jugá": "jugar",
    "jugámo": "jugar",
    "jugámos": "jugar",
    "jugáramo": "jugar",
    "jugáramos": "jugar",
    "jugárei": "jugar",
    "jugáreis": "jugar",
    "jugásseis": "jugar",
    "jugássemos": "jugar",
    "jugávamo": "jugar",
    "jugávamos": "jugar",
    "jugávei": "jugar",
    "jugáveis": "jugar",
    "juizinho": "juízo",
    "juizinhos": "juízo",
    "juizito": "juízo",
    "juizitos": "juízo",
    "jujubas": "jujuba",
    "jujubeiras": "jujubeira",
    "julaventos": "julavento",
    "julga": "julgar",
    "julgada": "julgar",
    "julgadas": "julgar",
    "julgado": "julgar",
    "julgadora": "julgador",
    "julgadoras": "julgador",
    "julgadores": "julgador",
    "julgados": "julgar",
    "julgai": "julgar",
    "julgais": "julgar",
    "julgam": "julgar",
    "julgamentos": "julgamento",
    "julgamo": "julgar",
    "julgamos": "julgar",
    "julgando": "julgar",
    "julgara": "julgar",
    "julgaram": "julgar",
    "julgaras": "julgar",
    "julgarde": "julgar",
    "julgardes": "julgar",
    "julgare": "julgar",
    "julgarei": "julgar",
    "julgareis": "julgar",
    "julgarem": "julgar",
    "julgaremos": "julgar",
    "julgares": "julgar",
    "julgaria": "julgar",
    "julgariam": "julgar",
    "julgarias": "julgar",
    "julgarmo": "julgar",
    "julgarmos": "julgar",
    "julgará": "julgar",
    "julgarás": "julgar",
    "julgarão": "julgar",
    "julgaríamos": "julgar",
    "julgaríeis": "julgar",
    "julgas": "julgar",
    "julgasse": "julgar",
    "julgassem": "julgar",
    "julgasses": "julgar",
    "julgaste": "julgar",
    "julgastes": "julgar",
    "julgava": "julgar",
    "julgavam": "julgar",
    "julgavas": "julgar",
    "julgo": "julgar",
    "julgou": "julgar",
    "julgue": "julgar",
    "julguei": "julgar",
    "julgueis": "julgar",
    "julguem": "julgar",
    "julguemo": "julgar",
    "julguemos": "julgar",
    "julgues": "julgar",
    "julgá": "julgar",
    "julgámo": "julgar",
    "julgámos": "julgar",
    "julgáramo": "julgar",
    "julgáramos": "julgar",
    "julgárei": "julgar",
    "julgáreis": "julgar",
    "julgásseis": "julgar",
    "julgássemos": "julgar",
    "julgávamo": "julgar",
    "julgávamos": "julgar",
    "julgávei": "julgar",
    "julgáveis": "julgável",
    "juliana": "juliano",
    "julianas": "juliano",
    "julianos": "juliano",
    "jumbebas": "jumbeba",
    "jumenta": "jumento",
    "jumentadas": "jumentada",
    "jumentais": "jumental",
    "jumentas": "jumento",
    "jumentica": "jumentico",
    "jumenticas": "jumentico",
    "jumenticos": "jumentico",
    "jumentis": "jumentil",
    "jumentos": "jumento",
    "junca": "juncar",
    "juncada": "juncar",
    "juncadas": "juncar",
    "juncado": "juncar",
    "juncados": "juncar",
    "juncagináceas": "juncaginácea",
    "juncai": "juncar",
    "juncais": "juncar",
    "juncam": "juncar",
    "juncamo": "juncar",
    "juncamos": "juncar",
    "juncando": "juncar",
    "juncara": "juncar",
    "juncaram": "juncar",
    "juncaras": "juncar",
    "juncarde": "juncar",
    "juncardes": "juncar",
    "juncare": "juncar",
    "juncarei": "juncar",
    "juncareis": "juncar",
    "juncarem": "juncar",
    "juncaremos": "juncar",
    "juncares": "juncar",
    "juncaria": "juncar",
    "juncariam": "juncar",
    "juncarias": "juncar",
    "juncarmo": "juncar",
    "juncarmos": "juncar",
    "juncará": "juncar",
    "juncarás": "juncar",
    "juncarão": "juncar",
    "juncaríamos": "juncar",
    "juncaríeis": "juncar",
    "juncas": "juncar",
    "juncasse": "juncar",
    "juncassem": "juncar",
    "juncasses": "juncar",
    "juncaste": "juncar",
    "juncastes": "juncar",
    "juncava": "juncar",
    "juncavam": "juncar",
    "juncavas": "juncar",
    "junceiras": "junceira",
    "juncinhas": "juncinha",
    "junco": "juncar",
    "juncos": "junco",
    "juncosa": "juncoso",
    "juncosas": "juncoso",
    "juncosos": "juncoso",
    "juncou": "juncar",
    "juncá": "juncar",
    "juncáceas": "juncácea",
    "juncámo": "juncar",
    "juncámos": "juncar",
    "juncáramo": "juncar",
    "juncáramos": "juncar",
    "juncárei": "juncar",
    "juncáreis": "juncar",
    "juncásseis": "juncar",
    "juncássemos": "juncar",
    "juncávamo": "juncar",
    "juncávamos": "juncar",
    "juncávei": "juncar",
    "juncáveis": "juncar",
    "jundiás": "jundiá",
    "junge": "jungir",
    "jungem": "jungir",
    "junges": "jungir",
    "jungi": "jungir",
    "jungia": "jungir",
    "jungiam": "jungir",
    "jungias": "jungir",
    "jungida": "jungir",
    "jungidas": "jungir",
    "jungido": "jungir",
    "jungidos": "jungir",
    "jungimo": "jungir",
    "jungimos": "jungir",
    "jungindo": "jungir",
    "jungira": "jungir",
    "jungiram": "jungir",
    "jungiras": "jungir",
    "jungirde": "jungir",
    "jungirdes": "jungir",
    "jungire": "jungir",
    "jungirei": "jungir",
    "jungireis": "jungir",
    "jungirem": "jungir",
    "jungiremos": "jungir",
    "jungires": "jungir",
    "jungiria": "jungir",
    "jungiriam": "jungir",
    "jungirias": "jungir",
    "jungirmo": "jungir",
    "jungirmos": "jungir",
    "jungirá": "jungir",
    "jungirás": "jungir",
    "jungirão": "jungir",
    "jungiríamos": "jungir",
    "jungiríeis": "jungir",
    "jungis": "jungir",
    "jungisse": "jungir",
    "jungissem": "jungir",
    "jungisses": "jungir",
    "jungiste": "jungir",
    "jungistes": "jungir",
    "jungiu": "jungir",
    "jungos": "jungo",
    "jungíamo": "jungir",
    "jungíamos": "jungir",
    "jungíei": "jungir",
    "jungíeis": "jungir",
    "jungíramo": "jungir",
    "jungíramos": "jungir",
    "jungírei": "jungir",
    "jungíreis": "jungir",
    "jungísseis": "jungir",
    "jungíssemos": "jungir",
    "juniores": "junior",
    "juniperácea": "juniperáceo",
    "juniperáceas": "juniperáceo",
    "juniperáceos": "juniperáceo",
    "junja": "jungir",
    "junjais": "jungir",
    "junjam": "jungir",
    "junjamo": "jungir",
    "junjamos": "jungir",
    "junjas": "jungir",
    "junjo": "jungir",
    "junque": "juncar",
    "junquei": "juncar",
    "junqueiras": "junqueira",
    "junqueis": "juncar",
    "junquem": "juncar",
    "junquemo": "juncar",
    "junquemos": "juncar",
    "junques": "juncar",
    "junquilhos": "junquilho",
    "junta": "junto",
    "juntada": "juntar",
    "juntadas": "juntar",
    "juntado": "juntar",
    "juntados": "juntar",
    "juntai": "juntar",
    "juntais": "juntar",
    "juntam": "juntar",
    "juntamo": "juntar",
    "juntamos": "juntar",
    "juntando": "juntar",
    "juntara": "juntar",
    "juntaram": "juntar",
    "juntaras": "juntar",
    "juntarde": "juntar",
    "juntardes": "juntar",
    "juntare": "juntar",
    "juntarei": "juntar",
    "juntareis": "juntar",
    "juntarem": "juntar",
    "juntaremos": "juntar",
    "juntares": "juntar",
    "juntaria": "juntar",
    "juntariam": "juntar",
    "juntarias": "juntar",
    "juntarmo": "juntar",
    "juntarmos": "juntar",
    "juntará": "juntar",
    "juntarás": "juntar",
    "juntarão": "juntar",
    "juntaríamos": "juntar",
    "juntaríeis": "juntar",
    "juntas": "junto",
    "juntasse": "juntar",
    "juntassem": "juntar",
    "juntasses": "juntar",
    "juntaste": "juntar",
    "juntastes": "juntar",
    "juntava": "juntar",
    "juntavam": "juntar",
    "juntavas": "juntar",
    "junte": "juntar",
    "juntei": "juntar",
    "junteiras": "junteira",
    "junteis": "juntar",
    "juntem": "juntar",
    "juntemo": "juntar",
    "juntemos": "juntar",
    "juntes": "juntar",
    "juntinha": "junto",
    "juntinhas": "junto",
    "juntinho": "junto",
    "juntinhos": "junto",
    "juntita": "junto",
    "juntitas": "junto",
    "juntito": "junto",
    "juntitos": "junto",
    "junto": "juntar",
    "juntoiras": "juntoira",
    "juntos": "junto",
    "juntou": "juntar",
    "juntouras": "juntoura",
    "junturas": "juntura",
    "juntá": "juntar",
    "juntámo": "juntar",
    "juntámos": "juntar",
    "juntáramo": "juntar",
    "juntáramos": "juntar",
    "juntárei": "juntar",
    "juntáreis": "juntar",
    "juntásseis": "juntar",
    "juntássemos": "juntar",
    "juntávamo": "juntar",
    "juntávamos": "juntar",
    "juntávei": "juntar",
    "juntáveis": "juntável",
    "juntíssima": "junto",
    "juntíssimas": "junto",
    "juntíssimo": "junto",
    "juntíssimos": "junto",
    "junças": "junça",
    "junçosa": "junçoso",
    "junçosas": "junçoso",
    "junçosos": "junçoso",
    "junções": "junção",
    "junípera": "junípero",
    "juníperas": "junípero",
    "juníperos": "junípero",
    "jupiedes": "jupiede",
    "jupiteriana": "jupiteriano",
    "jupiterianas": "jupiteriano",
    "jupiterianos": "jupiteriano",
    "juquirionanos": "juquirionano",
    "jura": "jurar",
    "jurada": "jurar",
    "juradas": "jurar",
    "jurado": "jurar",
    "juradora": "jurador",
    "juradoras": "jurador",
    "juradores": "jurador",
    "jurados": "jurar",
    "jurai": "jurar",
    "juraica": "juraico",
    "juraicas": "juraico",
    "juraicos": "juraico",
    "jurais": "jurar",
    "juram": "jurar",
    "juramentos": "juramento",
    "juramo": "jurar",
    "juramos": "jurar",
    "jurando": "jurar",
    "jurara": "jurar",
    "juraram": "jurar",
    "juraras": "jurar",
    "jurarde": "jurar",
    "jurardes": "jurar",
    "jurare": "jurar",
    "jurarei": "jurar",
    "jurareis": "jurar",
    "jurarem": "jurar",
    "juraremos": "jurar",
    "jurares": "jurar",
    "juraria": "jurar",
    "jurariam": "jurar",
    "jurarias": "jurar",
    "jurarmo": "jurar",
    "jurarmos": "jurar",
    "jurará": "jurar",
    "jurarás": "jurar",
    "jurarão": "jurar",
    "juraríamos": "jurar",
    "juraríeis": "jurar",
    "juras": "jurar",
    "jurasse": "jurar",
    "jurassem": "jurar",
    "jurasses": "jurar",
    "juraste": "jurar",
    "jurastes": "jurar",
    "juratória": "juratório",
    "juratórias": "juratório",
    "juratórios": "juratório",
    "jurava": "jurar",
    "juravam": "jurar",
    "juravas": "jurar",
    "jure": "jurar",
    "jurei": "jurar",
    "jureis": "jurar",
    "jurem": "jurar",
    "juremas": "jurema",
    "juremo": "jurar",
    "juremos": "jurar",
    "jures": "jurar",
    "jurisconsulentes": "jurisconsulente",
    "jurisconsulta": "jurisconsulto",
    "jurisconsultas": "jurisconsulto",
    "jurisconsultos": "jurisconsulto",
    "jurisdicionais": "jurisdicional",
    "jurisdições": "jurisdição",
    "jurisperita": "jurisperito",
    "jurisperitas": "jurisperito",
    "jurisperitos": "jurisperito",
    "jurisperícias": "jurisperícia",
    "jurisprudentes": "jurisprudente",
    "jurisprudências": "jurisprudência",
    "juristas": "jurista",
    "juritis": "juriti",
    "juro": "jurar",
    "juros": "juro",
    "jurou": "jurar",
    "jurra": "jurrar",
    "jurrada": "jurrar",
    "jurradas": "jurrar",
    "jurrado": "jurrar",
    "jurrados": "jurrar",
    "jurrai": "jurrar",
    "jurrais": "jurrar",
    "jurram": "jurrar",
    "jurramo": "jurrar",
    "jurramos": "jurrar",
    "jurrando": "jurrar",
    "jurrara": "jurrar",
    "jurraram": "jurrar",
    "jurraras": "jurrar",
    "jurrarde": "jurrar",
    "jurrardes": "jurrar",
    "jurrare": "jurrar",
    "jurrarei": "jurrar",
    "jurrareis": "jurrar",
    "jurrarem": "jurrar",
    "jurraremos": "jurrar",
    "jurrares": "jurrar",
    "jurraria": "jurrar",
    "jurrariam": "jurrar",
    "jurrarias": "jurrar",
    "jurrarmo": "jurrar",
    "jurrarmos": "jurrar",
    "jurrará": "jurrar",
    "jurrarás": "jurrar",
    "jurrarão": "jurrar",
    "jurraríamos": "jurrar",
    "jurraríeis": "jurrar",
    "jurras": "jurrar",
    "jurrasse": "jurrar",
    "jurrassem": "jurrar",
    "jurrasses": "jurrar",
    "jurraste": "jurrar",
    "jurrastes": "jurrar",
    "jurrava": "jurrar",
    "jurravam": "jurrar",
    "jurravas": "jurrar",
    "jurre": "jurrar",
    "jurrei": "jurrar",
    "jurreis": "jurrar",
    "jurrem": "jurrar",
    "jurremo": "jurrar",
    "jurremos": "jurrar",
    "jurres": "jurrar",
    "jurro": "jurrar",
    "jurrou": "jurrar",
    "jurrá": "jurrar",
    "jurrámo": "jurrar",
    "jurrámos": "jurrar",
    "jurráramo": "jurrar",
    "jurráramos": "jurrar",
    "jurrárei": "jurrar",
    "jurráreis": "jurrar",
    "jurrásseis": "jurrar",
    "jurrássemos": "jurrar",
    "jurrávamo": "jurrar",
    "jurrávamos": "jurrar",
    "jurrávei": "jurrar",
    "jurráveis": "jurrar",
    "jurubebas": "jurubeba",
    "jurujubas": "jurujuba",
    "jururus": "jururu",
    "jurá": "jurar",
    "jurámo": "jurar",
    "jurámos": "jurar",
    "juráramo": "jurar",
    "juráramos": "jurar",
    "jurárei": "jurar",
    "juráreis": "jurar",
    "jurásseis": "jurar",
    "jurássemos": "jurar",
    "jurássicos": "jurássico",
    "jurávamo": "jurar",
    "jurávamos": "jurar",
    "jurávei": "jurar",
    "juráveis": "jurar",
    "jurídica": "jurídico",
    "jurídicas": "jurídico",
    "jurídicos": "jurídico",
    "jusantes": "jusante",
    "juses": "jus",
    "jussiva": "jussivo",
    "jussivas": "jussivo",
    "jussivos": "jussivo",
    "justa": "justo",
    "justada": "justar",
    "justadas": "justar",
    "justado": "justar",
    "justadora": "justador",
    "justadoras": "justador",
    "justadores": "justador",
    "justados": "justar",
    "justafluviais": "justafluvial",
    "justai": "justar",
    "justais": "justar",
    "justalienares": "justalienar",
    "justam": "justar",
    "justamo": "justar",
    "justamos": "justar",
    "justando": "justar",
    "justapomo": "justapor",
    "justapomos": "justapor",
    "justaponde": "justapor",
    "justapondes": "justapor",
    "justapondo": "justapor",
    "justaponha": "justapor",
    "justaponhais": "justapor",
    "justaponham": "justapor",
    "justaponhamo": "justapor",
    "justaponhamos": "justapor",
    "justaponhas": "justapor",
    "justaponho": "justapor",
    "justaponíveis": "justaponível",
    "justaporde": "justapor",
    "justapordes": "justapor",
    "justapore": "justapor",
    "justaporei": "justapor",
    "justaporeis": "justapor",
    "justaporem": "justapor",
    "justaporemos": "justapor",
    "justapores": "justapor",
    "justaporia": "justapor",
    "justaporiam": "justapor",
    "justaporias": "justapor",
    "justapormo": "justapor",
    "justapormos": "justapor",
    "justaporá": "justapor",
    "justaporás": "justapor",
    "justaporão": "justapor",
    "justaporíamos": "justapor",
    "justaporíeis": "justapor",
    "justaposições": "justaposição",
    "justaposta": "justaposto",
    "justapostas": "justaposto",
    "justaposto": "justapor",
    "justapostos": "justaposto",
    "justapunha": "justapor",
    "justapunham": "justapor",
    "justapunhas": "justapor",
    "justapus": "justapor",
    "justapusemo": "justapor",
    "justapusemos": "justapor",
    "justapuser": "justapor",
    "justapusera": "justapor",
    "justapuseram": "justapor",
    "justapuseras": "justapor",
    "justapuserdes": "justapor",
    "justapuserem": "justapor",
    "justapuseres": "justapor",
    "justapusermos": "justapor",
    "justapusesse": "justapor",
    "justapusessem": "justapor",
    "justapusesses": "justapor",
    "justapuseste": "justapor",
    "justapusestes": "justapor",
    "justapuséramo": "justapor",
    "justapuséramos": "justapor",
    "justapusérei": "justapor",
    "justapuséreis": "justapor",
    "justapusésseis": "justapor",
    "justapuséssemos": "justapor",
    "justapô": "justapor",
    "justapôs": "justapor",
    "justapõe": "justapor",
    "justapõem": "justapor",
    "justapões": "justapor",
    "justapúnhamo": "justapor",
    "justapúnhamos": "justapor",
    "justapúnhei": "justapor",
    "justapúnheis": "justapor",
    "justara": "justar",
    "justaram": "justar",
    "justaras": "justar",
    "justardes": "justar",
    "justarei": "justar",
    "justareis": "justar",
    "justarem": "justar",
    "justaremos": "justar",
    "justares": "justar",
    "justaria": "justar",
    "justariam": "justar",
    "justarias": "justar",
    "justarmo": "justar",
    "justarmos": "justar",
    "justará": "justar",
    "justarás": "justar",
    "justarão": "justar",
    "justaríamos": "justar",
    "justaríeis": "justar",
    "justas": "justo",
    "justasse": "justar",
    "justassem": "justar",
    "justasses": "justar",
    "justaste": "justar",
    "justastes": "justar",
    "justava": "justar",
    "justavam": "justar",
    "justavas": "justar",
    "justavertebrais": "justavertebral",
    "justazinha": "justo",
    "justazinhas": "justo",
    "justazita": "justo",
    "justazitas": "justo",
    "juste": "justar",
    "justei": "justar",
    "justeis": "justar",
    "justem": "justar",
    "justemo": "justar",
    "justemos": "justar",
    "justes": "justar",
    "justezas": "justeza",
    "justice": "justiçar",
    "justicei": "justiçar",
    "justiceira": "justiceiro",
    "justiceiras": "justiceiro",
    "justiceiros": "justiceiro",
    "justiceis": "justiçar",
    "justicem": "justiçar",
    "justicemo": "justiçar",
    "justicemos": "justiçar",
    "justices": "justiçar",
    "justifica": "justificar",
    "justificada": "justificar",
    "justificadas": "justificar",
    "justificado": "justificar",
    "justificadora": "justificador",
    "justificadoras": "justificador",
    "justificadores": "justificador",
    "justificados": "justificar",
    "justificadíssima": "justificado",
    "justificadíssimas": "justificado",
    "justificadíssimo": "justificado",
    "justificadíssimos": "justificado",
    "justificai": "justificar",
    "justificais": "justificar",
    "justificam": "justificar",
    "justificamo": "justificar",
    "justificamos": "justificar",
    "justificando": "justificar",
    "justificantes": "justificante",
    "justificara": "justificar",
    "justificaram": "justificar",
    "justificaras": "justificar",
    "justificarde": "justificar",
    "justificardes": "justificar",
    "justificare": "justificar",
    "justificarei": "justificar",
    "justificareis": "justificar",
    "justificarem": "justificar",
    "justificaremos": "justificar",
    "justificares": "justificar",
    "justificaria": "justificar",
    "justificariam": "justificar",
    "justificarias": "justificar",
    "justificarmo": "justificar",
    "justificarmos": "justificar",
    "justificará": "justificar",
    "justificarás": "justificar",
    "justificarão": "justificar",
    "justificaríamos": "justificar",
    "justificaríeis": "justificar",
    "justificas": "justificar",
    "justificasse": "justificar",
    "justificassem": "justificar",
    "justificasses": "justificar",
    "justificaste": "justificar",
    "justificastes": "justificar",
    "justificativa": "justificativo",
    "justificativas": "justificativo",
    "justificativos": "justificativo",
    "justificatória": "justificatório",
    "justificatórias": "justificatório",
    "justificatórios": "justificatório",
    "justificava": "justificar",
    "justificavam": "justificar",
    "justificavas": "justificar",
    "justificações": "justificação",
    "justifico": "justificar",
    "justificou": "justificar",
    "justificá": "justificar",
    "justificámo": "justificar",
    "justificámos": "justificar",
    "justificáramo": "justificar",
    "justificáramos": "justificar",
    "justificárei": "justificar",
    "justificáreis": "justificar",
    "justificásseis": "justificar",
    "justificássemos": "justificar",
    "justificávamo": "justificar",
    "justificávamos": "justificar",
    "justificávei": "justificar",
    "justificáveis": "justificável",
    "justifique": "justificar",
    "justifiquei": "justificar",
    "justifiqueis": "justificar",
    "justifiquem": "justificar",
    "justifiquemo": "justificar",
    "justifiquemos": "justificar",
    "justifiques": "justificar",
    "justilhos": "justilho",
    "justinha": "justo",
    "justinhas": "justo",
    "justinho": "justo",
    "justinhos": "justo",
    "justinianeia": "justinianeu",
    "justinianeias": "justinianeu",
    "justinianeus": "justinianeu",
    "justita": "justo",
    "justitas": "justo",
    "justito": "justo",
    "justitos": "justo",
    "justiça": "justiçar",
    "justiçada": "justiçar",
    "justiçadas": "justiçar",
    "justiçado": "justiçar",
    "justiçados": "justiçar",
    "justiçai": "justiçar",
    "justiçais": "justiçar",
    "justiçam": "justiçar",
    "justiçamo": "justiçar",
    "justiçamos": "justiçar",
    "justiçando": "justiçar",
    "justiçara": "justiçar",
    "justiçaram": "justiçar",
    "justiçaras": "justiçar",
    "justiçarde": "justiçar",
    "justiçardes": "justiçar",
    "justiçare": "justiçar",
    "justiçarei": "justiçar",
    "justiçareis": "justiçar",
    "justiçarem": "justiçar",
    "justiçaremos": "justiçar",
    "justiçares": "justiçar",
    "justiçaria": "justiçar",
    "justiçariam": "justiçar",
    "justiçarias": "justiçar",
    "justiçarmo": "justiçar",
    "justiçarmos": "justiçar",
    "justiçará": "justiçar",
    "justiçarás": "justiçar",
    "justiçarão": "justiçar",
    "justiçaríamos": "justiçar",
    "justiçaríeis": "justiçar",
    "justiças": "justiçar",
    "justiçasse": "justiçar",
    "justiçassem": "justiçar",
    "justiçasses": "justiçar",
    "justiçaste": "justiçar",
    "justiçastes": "justiçar",
    "justiçava": "justiçar",
    "justiçavam": "justiçar",
    "justiçavas": "justiçar",
    "justiço": "justiçar",
    "justiçosa": "justiçoso",
    "justiçosas": "justiçoso",
    "justiçosos": "justiçoso",
    "justiçou": "justiçar",
    "justiçá": "justiçar",
    "justiçámo": "justiçar",
    "justiçámos": "justiçar",
    "justiçáramo": "justiçar",
    "justiçáramos": "justiçar",
    "justiçárei": "justiçar",
    "justiçáreis": "justiçar",
    "justiçásseis": "justiçar",
    "justiçássemos": "justiçar",
    "justiçávamo": "justiçar",
    "justiçávamos": "justiçar",
    "justiçávei": "justiçar",
    "justiçáveis": "justiçável",
    "justo": "justar",
    "justos": "justo",
    "justou": "justar",
    "justozinho": "justo",
    "justozinhos": "justo",
    "justozito": "justo",
    "justozitos": "justo",
    "justuras": "justura",
    "justámo": "justar",
    "justámos": "justar",
    "justáramo": "justar",
    "justáramos": "justar",
    "justáreis": "justar",
    "justásseis": "justar",
    "justássemos": "justar",
    "justávamo": "justar",
    "justávamos": "justar",
    "justáveis": "justável",
    "justíssima": "justo",
    "justíssimas": "justo",
    "justíssimo": "justo",
    "justíssimos": "justo",
    "juta": "juto",
    "jutaipebas": "jutaipeba",
    "jutas": "juto",
    "jutaís": "jutaí",
    "jutaúbas": "jutaúba",
    "jutlandesa": "jutlandês",
    "jutlandesas": "jutlandês",
    "jutlandeses": "jutlandês",
    "jutos": "juto",
    "juvenalesca": "juvenalesco",
    "juvenalescas": "juvenalesco",
    "juvenalescos": "juvenalesco",
    "juvenca": "juvenco",
    "juvencas": "juvenco",
    "juvencos": "juvenco",
    "juvenescimentos": "juvenescimento",
    "juvenilidades": "juvenilidade",
    "juvenis": "juvenil",
    "juventas": "juventa",
    "juventudes": "juventude",
    "juvenílias": "juvenília",
    "juás": "juá",
    "juçapés": "juçapé",
    "juçaras": "juçara",
    "juçareiras": "juçareira",
    "juíza": "juiz",
    "juízas": "juiz",
    "juízes": "juiz",
    "juízos": "juízo",
    "juós": "juó",
    "jáceas": "jácea",
    "jáculos": "jáculo",
    "jágaras": "jágara",
    "járdias": "járdia",
    "jáspea": "jáspeo",
    "jáspeas": "jáspeo",
    "jáspeos": "jáspeo",
    "jâmbica": "jâmbico",
    "jâmbicas": "jâmbico",
    "jâmbicos": "jâmbico",
    "jérseis": "jérsei",
    "jóias": "jóia",
    "jóinas": "jóina",
    "jónia": "jónio",
    "jónias": "jónio",
    "jónica": "jónico",
    "jónicas": "jónico",
    "jónicos": "jónico",
    "jónios": "jónio",
    "jóqueis": "jóquei",
    "jórneas": "jórnea",
    "júbilos": "júbilo",
    "júniores": "júnior",
    "júpiteres": "júpiter",
    "júris": "júri",
    "júvias": "júvia",
    "kabuquis": "kabuqui",
    "kafkiana": "kafkiano",
    "kafkianas": "kafkiano",
    "kafkianos": "kafkiano",
    "kaiseres": "kaiser",
    "kamikazes": "kamikaze",
    "kangas": "kanga",
    "kantiana": "kantiano",
    "kantianas": "kantiano",
    "kantianos": "kantiano",
    "kantismos": "kantismo",
    "kantistas": "kantista",
    "karatés": "karaté",
    "karros": "karro",
    "kartings": "karting",
    "kartismos": "kartismo",
    "kartistas": "kartista",
    "karts": "kart",
    "kartódromos": "kartódromo",
    "kazanianos": "kazaniano",
    "keewatinianos": "keewatiniano",
    "keplérias": "kepléria",
    "ketchups": "ketchup",
    "keuperes": "keuper",
    "keweenavianos": "keweenaviano",
    "keynesiana": "keynesiano",
    "keynesianas": "keynesiano",
    "keynesianos": "keynesiano",
    "kilojoules": "kilojoule",
    "kilotões": "kilotão",
    "kilts": "kilt",
    "kimberlites": "kimberlite",
    "kimeridgianos": "kimeridgiano",
    "kings": "king",
    "kitchenettes": "kitchenette",
    "kits": "kit",
    "kiwis": "kiwi",
    "kk": "k",
    "kleriana": "kleriano",
    "klerianas": "kleriano",
    "klerianos": "kleriano",
    "kneippismos": "kneippismo",
    "kneippistas": "kneippista",
    "kremlins": "kremlim",
    "kungurianos": "kunguriano",
    "kíries": "kírie",
    "la": "o",
    "labaredas": "labareda",
    "labaçais": "labaçal",
    "labaças": "labaça",
    "labelada": "labelado",
    "labeladas": "labelado",
    "labelados": "labelado",
    "labelos": "labelo",
    "labiada": "labiado",
    "labiadas": "labiado",
    "labiados": "labiado",
    "labiais": "labial",
    "labialismos": "labialismo",
    "labializa": "labializar",
    "labializada": "labializar",
    "labializadas": "labializar",
    "labializado": "labializar",
    "labializados": "labializar",
    "labializai": "labializar",
    "labializais": "labializar",
    "labializam": "labializar",
    "labializamo": "labializar",
    "labializamos": "labializar",
    "labializando": "labializar",
    "labializara": "labializar",
    "labializaram": "labializar",
    "labializaras": "labializar",
    "labializarde": "labializar",
    "labializardes": "labializar",
    "labializare": "labializar",
    "labializarei": "labializar",
    "labializareis": "labializar",
    "labializarem": "labializar",
    "labializaremos": "labializar",
    "labializares": "labializar",
    "labializaria": "labializar",
    "labializariam": "labializar",
    "labializarias": "labializar",
    "labializarmo": "labializar",
    "labializarmos": "labializar",
    "labializará": "labializar",
    "labializarás": "labializar",
    "labializarão": "labializar",
    "labializaríamos": "labializar",
    "labializaríeis": "labializar",
    "labializas": "labializar",
    "labializasse": "labializar",
    "labializassem": "labializar",
    "labializasses": "labializar",
    "labializaste": "labializar",
    "labializastes": "labializar",
    "labializava": "labializar",
    "labializavam": "labializar",
    "labializavas": "labializar",
    "labializações": "labialização",
    "labialize": "labializar",
    "labializei": "labializar",
    "labializeis": "labializar",
    "labializem": "labializar",
    "labializemo": "labializar",
    "labializemos": "labializar",
    "labializes": "labializar",
    "labializo": "labializar",
    "labializou": "labializar",
    "labializá": "labializar",
    "labializámo": "labializar",
    "labializámos": "labializar",
    "labializáramo": "labializar",
    "labializáramos": "labializar",
    "labializárei": "labializar",
    "labializáreis": "labializar",
    "labializásseis": "labializar",
    "labializássemos": "labializar",
    "labializávamo": "labializar",
    "labializávamos": "labializar",
    "labializávei": "labializar",
    "labializáveis": "labializável",
    "labidura": "labiduro",
    "labiduras": "labiduro",
    "labiduros": "labiduro",
    "labidómetros": "labidómetro",
    "labilidades": "labilidade",
    "labiodentais": "labiodental",
    "labionasais": "labionasal",
    "labiosa": "labioso",
    "labiosas": "labioso",
    "labiosidades": "labiosidade",
    "labiosos": "labioso",
    "labiovelares": "labiovelar",
    "labiozinho": "lábio",
    "labiozinhos": "lábio",
    "labiozito": "lábio",
    "labiozitos": "lábio",
    "labirintodontes": "labirintodonte",
    "labirintos": "labirinto",
    "labiríntica": "labiríntico",
    "labirínticas": "labiríntico",
    "labirínticos": "labiríntico",
    "labitas": "labita",
    "lablades": "lablade",
    "labora": "laborar",
    "laborada": "laborar",
    "laboradas": "laborar",
    "laborado": "laborar",
    "laborados": "laborar",
    "laborai": "laborar",
    "laborais": "laborar",
    "laboram": "laborar",
    "laboramo": "laborar",
    "laboramos": "laborar",
    "laborando": "laborar",
    "laborara": "laborar",
    "laboraram": "laborar",
    "laboraras": "laborar",
    "laborardes": "laborar",
    "laborarei": "laborar",
    "laborareis": "laborar",
    "laborarem": "laborar",
    "laboraremos": "laborar",
    "laborares": "laborar",
    "laboraria": "laborar",
    "laborariam": "laborar",
    "laborarias": "laborar",
    "laborarmo": "laborar",
    "laborarmos": "laborar",
    "laborará": "laborar",
    "laborarás": "laborar",
    "laborarão": "laborar",
    "laboraríamos": "laborar",
    "laboraríeis": "laborar",
    "laboras": "laborar",
    "laborasse": "laborar",
    "laborassem": "laborar",
    "laborasses": "laborar",
    "laboraste": "laborar",
    "laborastes": "laborar",
    "laboratoriais": "laboratorial",
    "laboratoristas": "laboratorista",
    "laboratórios": "laboratório",
    "laborava": "laborar",
    "laboravam": "laborar",
    "laboravas": "laborar",
    "laborações": "laboração",
    "labore": "laborar",
    "laborei": "laborar",
    "laboreis": "laborar",
    "laborem": "laborar",
    "laboremo": "laborar",
    "laboremos": "laborar",
    "labores": "laborar",
    "laboriosa": "laborioso",
    "laboriosas": "laborioso",
    "laboriosidades": "laboriosidade",
    "laboriosos": "laborioso",
    "laboristas": "laborista",
    "laboro": "laborar",
    "laborou": "laborar",
    "laborámo": "laborar",
    "laborámos": "laborar",
    "laboráramo": "laborar",
    "laboráramos": "laborar",
    "laboráreis": "laborar",
    "laborásseis": "laborar",
    "laborássemos": "laborar",
    "laborávamo": "laborar",
    "laborávamos": "laborar",
    "laboráveis": "laborável",
    "labradores": "labrador",
    "labradorites": "labradorite",
    "labrega": "labrego",
    "labregada": "labregar",
    "labregadas": "labregar",
    "labregado": "labregar",
    "labregados": "labregar",
    "labregai": "labregar",
    "labregais": "labregar",
    "labregam": "labregar",
    "labregamo": "labregar",
    "labregamos": "labregar",
    "labregando": "labregar",
    "labregara": "labregar",
    "labregaram": "labregar",
    "labregaras": "labregar",
    "labregardes": "labregar",
    "labregarei": "labregar",
    "labregareis": "labregar",
    "labregarem": "labregar",
    "labregaremos": "labregar",
    "labregares": "labregar",
    "labregaria": "labregar",
    "labregariam": "labregar",
    "labregarias": "labregar",
    "labregarmo": "labregar",
    "labregarmos": "labregar",
    "labregará": "labregar",
    "labregarás": "labregar",
    "labregarão": "labregar",
    "labregaríamos": "labregar",
    "labregaríeis": "labregar",
    "labregas": "labrego",
    "labregasse": "labregar",
    "labregassem": "labregar",
    "labregasses": "labregar",
    "labregaste": "labregar",
    "labregastes": "labregar",
    "labregava": "labregar",
    "labregavam": "labregar",
    "labregavas": "labregar",
    "labrego": "labregar",
    "labregos": "labrego",
    "labregou": "labregar",
    "labregue": "labregar",
    "labreguei": "labregar",
    "labregueis": "labregar",
    "labreguem": "labregar",
    "labreguemo": "labregar",
    "labreguemos": "labregar",
    "labregues": "labregar",
    "labreguices": "labreguice",
    "labregámo": "labregar",
    "labregámos": "labregar",
    "labregáramo": "labregar",
    "labregáramos": "labregar",
    "labregáreis": "labregar",
    "labregásseis": "labregar",
    "labregássemos": "labregar",
    "labregávamo": "labregar",
    "labregávamos": "labregar",
    "labregáveis": "labregar",
    "labresta": "labrestar",
    "labrestada": "labrestar",
    "labrestadas": "labrestar",
    "labrestado": "labrestar",
    "labrestados": "labrestar",
    "labrestai": "labrestar",
    "labrestais": "labrestar",
    "labrestam": "labrestar",
    "labrestamo": "labrestar",
    "labrestamos": "labrestar",
    "labrestando": "labrestar",
    "labrestara": "labrestar",
    "labrestaram": "labrestar",
    "labrestaras": "labrestar",
    "labrestarde": "labrestar",
    "labrestardes": "labrestar",
    "labrestare": "labrestar",
    "labrestarei": "labrestar",
    "labrestareis": "labrestar",
    "labrestarem": "labrestar",
    "labrestaremos": "labrestar",
    "labrestares": "labrestar",
    "labrestaria": "labrestar",
    "labrestariam": "labrestar",
    "labrestarias": "labrestar",
    "labrestarmo": "labrestar",
    "labrestarmos": "labrestar",
    "labrestará": "labrestar",
    "labrestarás": "labrestar",
    "labrestarão": "labrestar",
    "labrestaríamos": "labrestar",
    "labrestaríeis": "labrestar",
    "labrestas": "labrestar",
    "labrestasse": "labrestar",
    "labrestassem": "labrestar",
    "labrestasses": "labrestar",
    "labrestaste": "labrestar",
    "labrestastes": "labrestar",
    "labrestava": "labrestar",
    "labrestavam": "labrestar",
    "labrestavas": "labrestar",
    "labreste": "labrestar",
    "labrestei": "labrestar",
    "labresteis": "labrestar",
    "labrestem": "labrestar",
    "labrestemo": "labrestar",
    "labrestemos": "labrestar",
    "labrestes": "labrestar",
    "labresto": "labrestar",
    "labrestos": "labresto",
    "labrestou": "labrestar",
    "labrestá": "labrestar",
    "labrestámo": "labrestar",
    "labrestámos": "labrestar",
    "labrestáramo": "labrestar",
    "labrestáramos": "labrestar",
    "labrestárei": "labrestar",
    "labrestáreis": "labrestar",
    "labrestásseis": "labrestar",
    "labrestássemos": "labrestar",
    "labrestávamo": "labrestar",
    "labrestávamos": "labrestar",
    "labrestávei": "labrestar",
    "labrestáveis": "labrestar",
    "labros": "labro",
    "labrosa": "labroso",
    "labrosas": "labroso",
    "labroscas": "labrosca",
    "labrosos": "labroso",
    "labrostas": "labrosta",
    "labrostes": "labroste",
    "labrusca": "labrusco",
    "labruscas": "labrusco",
    "labruscos": "labrusco",
    "labrídeos": "labrídeo",
    "labugantes": "labugante",
    "laburnos": "laburno",
    "labuta": "labutar",
    "labutada": "labutar",
    "labutadas": "labutar",
    "labutado": "labutar",
    "labutadora": "labutador",
    "labutadoras": "labutador",
    "labutadores": "labutador",
    "labutados": "labutar",
    "labutai": "labutar",
    "labutais": "labutar",
    "labutam": "labutar",
    "labutamo": "labutar",
    "labutamos": "labutar",
    "labutando": "labutar",
    "labutara": "labutar",
    "labutaram": "labutar",
    "labutaras": "labutar",
    "labutardes": "labutar",
    "labutarei": "labutar",
    "labutareis": "labutar",
    "labutarem": "labutar",
    "labutaremos": "labutar",
    "labutares": "labutar",
    "labutaria": "labutar",
    "labutariam": "labutar",
    "labutarias": "labutar",
    "labutarmo": "labutar",
    "labutarmos": "labutar",
    "labutará": "labutar",
    "labutarás": "labutar",
    "labutarão": "labutar",
    "labutaríamos": "labutar",
    "labutaríeis": "labutar",
    "labutas": "labutar",
    "labutasse": "labutar",
    "labutassem": "labutar",
    "labutasses": "labutar",
    "labutaste": "labutar",
    "labutastes": "labutar",
    "labutava": "labutar",
    "labutavam": "labutar",
    "labutavas": "labutar",
    "labutações": "labutação",
    "labute": "labutar",
    "labutei": "labutar",
    "labuteis": "labutar",
    "labutem": "labutar",
    "labutemo": "labutar",
    "labutemos": "labutar",
    "labutes": "labutar",
    "labuto": "labutar",
    "labutou": "labutar",
    "labutámo": "labutar",
    "labutámos": "labutar",
    "labutáramo": "labutar",
    "labutáramos": "labutar",
    "labutáreis": "labutar",
    "labutásseis": "labutar",
    "labutássemos": "labutar",
    "labutávamo": "labutar",
    "labutávamos": "labutar",
    "labutáveis": "labutar",
    "labuza": "labuzar",
    "labuzada": "labuzar",
    "labuzadas": "labuzar",
    "labuzado": "labuzar",
    "labuzados": "labuzar",
    "labuzai": "labuzar",
    "labuzais": "labuzar",
    "labuzam": "labuzar",
    "labuzamo": "labuzar",
    "labuzamos": "labuzar",
    "labuzando": "labuzar",
    "labuzara": "labuzar",
    "labuzaram": "labuzar",
    "labuzaras": "labuzar",
    "labuzarde": "labuzar",
    "labuzardes": "labuzar",
    "labuzare": "labuzar",
    "labuzarei": "labuzar",
    "labuzareis": "labuzar",
    "labuzarem": "labuzar",
    "labuzaremos": "labuzar",
    "labuzares": "labuzar",
    "labuzaria": "labuzar",
    "labuzariam": "labuzar",
    "labuzarias": "labuzar",
    "labuzarmo": "labuzar",
    "labuzarmos": "labuzar",
    "labuzará": "labuzar",
    "labuzarás": "labuzar",
    "labuzarão": "labuzar",
    "labuzaríamos": "labuzar",
    "labuzaríeis": "labuzar",
    "labuzas": "labuzar",
    "labuzasse": "labuzar",
    "labuzassem": "labuzar",
    "labuzasses": "labuzar",
    "labuzaste": "labuzar",
    "labuzastes": "labuzar",
    "labuzava": "labuzar",
    "labuzavam": "labuzar",
    "labuzavas": "labuzar",
    "labuze": "labuzar",
    "labuzei": "labuzar",
    "labuzeis": "labuzar",
    "labuzem": "labuzar",
    "labuzemo": "labuzar",
    "labuzemos": "labuzar",
    "labuzes": "labuzar",
    "labuzo": "labuzar",
    "labuzou": "labuzar",
    "labuzá": "labuzar",
    "labuzámo": "labuzar",
    "labuzámos": "labuzar",
    "labuzáramo": "labuzar",
    "labuzáramos": "labuzar",
    "labuzárei": "labuzar",
    "labuzáreis": "labuzar",
    "labuzásseis": "labuzar",
    "labuzássemos": "labuzar",
    "labuzávamo": "labuzar",
    "labuzávamos": "labuzar",
    "labuzávei": "labuzar",
    "labuzáveis": "labuzar",
    "labéus": "labéu",
    "labíolos": "labíolo",
    "labões": "labão",
    "laca": "lacar",
    "lacada": "lacar",
    "lacadas": "lacar",
    "lacado": "lacar",
    "lacados": "lacar",
    "lacaia": "lacaio",
    "lacaiadas": "lacaiada",
    "lacaias": "lacaio",
    "lacaiesca": "lacaiesco",
    "lacaiescas": "lacaiesco",
    "lacaiescos": "lacaiesco",
    "lacaios": "lacaio",
    "lacais": "lacar",
    "lacam": "lacar",
    "lacamo": "lacar",
    "lacamos": "lacar",
    "lacando": "lacar",
    "lacaniana": "lacaniano",
    "lacanianas": "lacaniano",
    "lacanianos": "lacaniano",
    "lacara": "lacar",
    "lacaram": "lacar",
    "lacaras": "lacar",
    "lacardes": "lacar",
    "lacarei": "lacar",
    "lacareis": "lacar",
    "lacarem": "lacar",
    "lacaremos": "lacar",
    "lacares": "lacar",
    "lacaria": "lacar",
    "lacariam": "lacar",
    "lacarias": "lacar",
    "lacarmo": "lacar",
    "lacarmos": "lacar",
    "lacará": "lacar",
    "lacarás": "lacar",
    "lacarão": "lacar",
    "lacaríamos": "lacar",
    "lacaríeis": "lacar",
    "lacas": "lacar",
    "lacasse": "lacar",
    "lacassem": "lacar",
    "lacasses": "lacar",
    "lacaste": "lacar",
    "lacastes": "lacar",
    "lacava": "lacar",
    "lacavam": "lacar",
    "lacavas": "lacar",
    "lace": "laçar",
    "laceada": "lacear",
    "laceadas": "lacear",
    "laceado": "lacear",
    "laceados": "lacear",
    "laceai": "lacear",
    "laceais": "lacear",
    "laceamo": "lacear",
    "laceamos": "lacear",
    "laceando": "lacear",
    "laceara": "lacear",
    "lacearam": "lacear",
    "lacearas": "lacear",
    "lacearde": "lacear",
    "laceardes": "lacear",
    "laceare": "lacear",
    "lacearei": "lacear",
    "laceareis": "lacear",
    "lacearem": "lacear",
    "lacearemos": "lacear",
    "laceares": "lacear",
    "lacearia": "lacear",
    "laceariam": "lacear",
    "lacearias": "lacear",
    "lacearmo": "lacear",
    "lacearmos": "lacear",
    "laceará": "lacear",
    "lacearás": "lacear",
    "lacearão": "lacear",
    "lacearíamos": "lacear",
    "lacearíeis": "lacear",
    "laceasse": "lacear",
    "laceassem": "lacear",
    "laceasses": "lacear",
    "laceaste": "lacear",
    "laceastes": "lacear",
    "laceava": "lacear",
    "laceavam": "lacear",
    "laceavas": "lacear",
    "lacedemónia": "lacedemónio",
    "lacedemónias": "lacedemónio",
    "lacedemónios": "lacedemónio",
    "laceei": "lacear",
    "laceeis": "lacear",
    "laceemo": "lacear",
    "laceemos": "lacear",
    "lacei": "laçar",
    "laceia": "lacear",
    "laceiam": "lacear",
    "laceias": "lacear",
    "laceie": "lacear",
    "laceiem": "lacear",
    "laceies": "lacear",
    "laceio": "lacear",
    "laceiras": "laceira",
    "laceis": "laçar",
    "lacem": "laçar",
    "lacemo": "laçar",
    "lacemos": "laçar",
    "laceou": "lacear",
    "lacera": "lacerar",
    "lacerada": "lacerar",
    "laceradas": "lacerar",
    "lacerado": "lacerar",
    "lacerados": "lacerar",
    "lacerai": "lacerar",
    "lacerais": "lacerar",
    "laceram": "lacerar",
    "laceramo": "lacerar",
    "laceramos": "lacerar",
    "lacerando": "lacerar",
    "lacerantes": "lacerante",
    "lacerara": "lacerar",
    "laceraram": "lacerar",
    "laceraras": "lacerar",
    "lacerarde": "lacerar",
    "lacerardes": "lacerar",
    "lacerare": "lacerar",
    "lacerarei": "lacerar",
    "lacerareis": "lacerar",
    "lacerarem": "lacerar",
    "laceraremos": "lacerar",
    "lacerares": "lacerar",
    "laceraria": "lacerar",
    "lacerariam": "lacerar",
    "lacerarias": "lacerar",
    "lacerarmo": "lacerar",
    "lacerarmos": "lacerar",
    "lacerará": "lacerar",
    "lacerarás": "lacerar",
    "lacerarão": "lacerar",
    "laceraríamos": "lacerar",
    "laceraríeis": "lacerar",
    "laceras": "lacerar",
    "lacerasse": "lacerar",
    "lacerassem": "lacerar",
    "lacerasses": "lacerar",
    "laceraste": "lacerar",
    "lacerastes": "lacerar",
    "lacerava": "lacerar",
    "laceravam": "lacerar",
    "laceravas": "lacerar",
    "lacerações": "laceração",
    "lacere": "lacerar",
    "lacerei": "lacerar",
    "lacereis": "lacerar",
    "lacerem": "lacerar",
    "laceremo": "lacerar",
    "laceremos": "lacerar",
    "laceres": "lacerar",
    "lacernas": "lacerna",
    "lacero": "lacerar",
    "lacerou": "lacerar",
    "lacertiformes": "lacertiforme",
    "lacertídeos": "lacertídeo",
    "lacerá": "lacerar",
    "lacerámo": "lacerar",
    "lacerámos": "lacerar",
    "laceráramo": "lacerar",
    "laceráramos": "lacerar",
    "lacerárei": "lacerar",
    "laceráreis": "lacerar",
    "lacerásseis": "lacerar",
    "lacerássemos": "lacerar",
    "lacerávamo": "lacerar",
    "lacerávamos": "lacerar",
    "lacerávei": "lacerar",
    "laceráveis": "lacerável",
    "laces": "laçar",
    "lacetes": "lacete",
    "laceá": "lacear",
    "laceámo": "lacear",
    "laceámos": "lacear",
    "laceáramo": "lacear",
    "laceáramos": "lacear",
    "laceárei": "lacear",
    "laceáreis": "lacear",
    "laceásseis": "lacear",
    "laceássemos": "lacear",
    "laceávamo": "lacear",
    "laceávamos": "lacear",
    "laceávei": "lacear",
    "laceáveis": "lacear",
    "lacibrigenses": "lacibrigense",
    "lacinho": "laço",
    "lacinhos": "laço",
    "laciniada": "laciniado",
    "laciniadas": "laciniado",
    "laciniados": "laciniado",
    "lacito": "laço",
    "lacitos": "laço",
    "laco": "lacar",
    "lacobricenses": "lacobricense",
    "lacomancias": "lacomancia",
    "lacomantes": "lacomante",
    "laconismos": "laconismo",
    "laconiza": "laconizar",
    "laconizada": "laconizar",
    "laconizadas": "laconizar",
    "laconizado": "laconizar",
    "laconizados": "laconizar",
    "laconizai": "laconizar",
    "laconizais": "laconizar",
    "laconizam": "laconizar",
    "laconizamo": "laconizar",
    "laconizamos": "laconizar",
    "laconizando": "laconizar",
    "laconizara": "laconizar",
    "laconizaram": "laconizar",
    "laconizaras": "laconizar",
    "laconizarde": "laconizar",
    "laconizardes": "laconizar",
    "laconizare": "laconizar",
    "laconizarei": "laconizar",
    "laconizareis": "laconizar",
    "laconizarem": "laconizar",
    "laconizaremos": "laconizar",
    "laconizares": "laconizar",
    "laconizaria": "laconizar",
    "laconizariam": "laconizar",
    "laconizarias": "laconizar",
    "laconizarmo": "laconizar",
    "laconizarmos": "laconizar",
    "laconizará": "laconizar",
    "laconizarás": "laconizar",
    "laconizarão": "laconizar",
    "laconizaríamos": "laconizar",
    "laconizaríeis": "laconizar",
    "laconizas": "laconizar",
    "laconizasse": "laconizar",
    "laconizassem": "laconizar",
    "laconizasses": "laconizar",
    "laconizaste": "laconizar",
    "laconizastes": "laconizar",
    "laconizava": "laconizar",
    "laconizavam": "laconizar",
    "laconizavas": "laconizar",
    "laconize": "laconizar",
    "laconizei": "laconizar",
    "laconizeis": "laconizar",
    "laconizem": "laconizar",
    "laconizemo": "laconizar",
    "laconizemos": "laconizar",
    "laconizes": "laconizar",
    "laconizo": "laconizar",
    "laconizou": "laconizar",
    "laconizá": "laconizar",
    "laconizámo": "laconizar",
    "laconizámos": "laconizar",
    "laconizáramo": "laconizar",
    "laconizáramos": "laconizar",
    "laconizárei": "laconizar",
    "laconizáreis": "laconizar",
    "laconizásseis": "laconizar",
    "laconizássemos": "laconizar",
    "laconizávamo": "laconizar",
    "laconizávamos": "laconizar",
    "laconizávei": "laconizar",
    "laconizáveis": "laconizar",
    "lacou": "lacar",
    "lacra": "lacrar",
    "lacrada": "lacrar",
    "lacradas": "lacrar",
    "lacrado": "lacrar",
    "lacradora": "lacrador",
    "lacradoras": "lacrador",
    "lacradores": "lacrador",
    "lacrados": "lacrar",
    "lacrai": "lacrar",
    "lacraias": "lacraia",
    "lacrais": "lacrar",
    "lacram": "lacrar",
    "lacramo": "lacrar",
    "lacramos": "lacrar",
    "lacrando": "lacrar",
    "lacrara": "lacrar",
    "lacraram": "lacrar",
    "lacraras": "lacrar",
    "lacrarde": "lacrar",
    "lacrardes": "lacrar",
    "lacrare": "lacrar",
    "lacrarei": "lacrar",
    "lacrareis": "lacrar",
    "lacrarem": "lacrar",
    "lacraremos": "lacrar",
    "lacrares": "lacrar",
    "lacraria": "lacrar",
    "lacrariam": "lacrar",
    "lacrarias": "lacrar",
    "lacrarmo": "lacrar",
    "lacrarmos": "lacrar",
    "lacrará": "lacrar",
    "lacrarás": "lacrar",
    "lacrarão": "lacrar",
    "lacraríamos": "lacrar",
    "lacraríeis": "lacrar",
    "lacras": "lacrar",
    "lacrasse": "lacrar",
    "lacrassem": "lacrar",
    "lacrasses": "lacrar",
    "lacraste": "lacrar",
    "lacrastes": "lacrar",
    "lacraus": "lacrau",
    "lacrava": "lacrar",
    "lacravam": "lacrar",
    "lacravas": "lacrar",
    "lacre": "lacrar",
    "lacreada": "lacrear",
    "lacreadas": "lacrear",
    "lacreado": "lacrear",
    "lacreados": "lacrear",
    "lacreai": "lacrear",
    "lacreais": "lacrear",
    "lacreamo": "lacrear",
    "lacreamos": "lacrear",
    "lacreando": "lacrear",
    "lacreara": "lacrear",
    "lacrearam": "lacrear",
    "lacrearas": "lacrear",
    "lacrearde": "lacrear",
    "lacreardes": "lacrear",
    "lacreare": "lacrear",
    "lacrearei": "lacrear",
    "lacreareis": "lacrear",
    "lacrearem": "lacrear",
    "lacrearemos": "lacrear",
    "lacreares": "lacrear",
    "lacrearia": "lacrear",
    "lacreariam": "lacrear",
    "lacrearias": "lacrear",
    "lacrearmo": "lacrear",
    "lacrearmos": "lacrear",
    "lacreará": "lacrear",
    "lacrearás": "lacrear",
    "lacrearão": "lacrear",
    "lacrearíamos": "lacrear",
    "lacrearíeis": "lacrear",
    "lacreasse": "lacrear",
    "lacreassem": "lacrear",
    "lacreasses": "lacrear",
    "lacreaste": "lacrear",
    "lacreastes": "lacrear",
    "lacreava": "lacrear",
    "lacreavam": "lacrear",
    "lacreavas": "lacrear",
    "lacreei": "lacrear",
    "lacreeis": "lacrear",
    "lacreemo": "lacrear",
    "lacreemos": "lacrear",
    "lacrei": "lacrar",
    "lacreia": "lacrear",
    "lacreiam": "lacrear",
    "lacreias": "lacrear",
    "lacreie": "lacrear",
    "lacreiem": "lacrear",
    "lacreies": "lacrear",
    "lacreio": "lacrear",
    "lacreis": "lacrar",
    "lacrem": "lacrar",
    "lacremo": "lacrar",
    "lacremos": "lacrar",
    "lacreou": "lacrear",
    "lacres": "lacre",
    "lacreá": "lacrear",
    "lacreámo": "lacrear",
    "lacreámos": "lacrear",
    "lacreáramo": "lacrear",
    "lacreáramos": "lacrear",
    "lacreárei": "lacrear",
    "lacreáreis": "lacrear",
    "lacreásseis": "lacrear",
    "lacreássemos": "lacrear",
    "lacreávamo": "lacrear",
    "lacreávamos": "lacrear",
    "lacreávei": "lacrear",
    "lacreáveis": "lacrear",
    "lacrimais": "lacrimal",
    "lacrimantes": "lacrimante",
    "lacrimatória": "lacrimatório",
    "lacrimatórias": "lacrimatório",
    "lacrimatórios": "lacrimatório",
    "lacrimações": "lacrimação",
    "lacrimeja": "lacrimejar",
    "lacrimejada": "lacrimejar",
    "lacrimejadas": "lacrimejar",
    "lacrimejado": "lacrimejar",
    "lacrimejados": "lacrimejar",
    "lacrimejai": "lacrimejar",
    "lacrimejais": "lacrimejar",
    "lacrimejam": "lacrimejar",
    "lacrimejamo": "lacrimejar",
    "lacrimejamos": "lacrimejar",
    "lacrimejando": "lacrimejar",
    "lacrimejantes": "lacrimejante",
    "lacrimejara": "lacrimejar",
    "lacrimejaram": "lacrimejar",
    "lacrimejaras": "lacrimejar",
    "lacrimejardes": "lacrimejar",
    "lacrimejarei": "lacrimejar",
    "lacrimejareis": "lacrimejar",
    "lacrimejarem": "lacrimejar",
    "lacrimejaremos": "lacrimejar",
    "lacrimejares": "lacrimejar",
    "lacrimejaria": "lacrimejar",
    "lacrimejariam": "lacrimejar",
    "lacrimejarias": "lacrimejar",
    "lacrimejarmo": "lacrimejar",
    "lacrimejarmos": "lacrimejar",
    "lacrimejará": "lacrimejar",
    "lacrimejarás": "lacrimejar",
    "lacrimejarão": "lacrimejar",
    "lacrimejaríamos": "lacrimejar",
    "lacrimejaríeis": "lacrimejar",
    "lacrimejas": "lacrimejar",
    "lacrimejasse": "lacrimejar",
    "lacrimejassem": "lacrimejar",
    "lacrimejasses": "lacrimejar",
    "lacrimejaste": "lacrimejar",
    "lacrimejastes": "lacrimejar",
    "lacrimejava": "lacrimejar",
    "lacrimejavam": "lacrimejar",
    "lacrimejavas": "lacrimejar",
    "lacrimeje": "lacrimejar",
    "lacrimejei": "lacrimejar",
    "lacrimejeis": "lacrimejar",
    "lacrimejem": "lacrimejar",
    "lacrimejemo": "lacrimejar",
    "lacrimejemos": "lacrimejar",
    "lacrimejes": "lacrimejar",
    "lacrimejo": "lacrimejar",
    "lacrimejos": "lacrimejo",
    "lacrimejou": "lacrimejar",
    "lacrimejámo": "lacrimejar",
    "lacrimejámos": "lacrimejar",
    "lacrimejáramo": "lacrimejar",
    "lacrimejáramos": "lacrimejar",
    "lacrimejáreis": "lacrimejar",
    "lacrimejásseis": "lacrimejar",
    "lacrimejássemos": "lacrimejar",
    "lacrimejávamo": "lacrimejar",
    "lacrimejávamos": "lacrimejar",
    "lacrimejáveis": "lacrimejar",
    "lacrimogénea": "lacrimogéneo",
    "lacrimogéneas": "lacrimogéneo",
    "lacrimogéneos": "lacrimogéneo",
    "lacrimosa": "lacrimoso",
    "lacrimosas": "lacrimoso",
    "lacrimosos": "lacrimoso",
    "lacrimotomias": "lacrimotomia",
    "lacrimáveis": "lacrimável",
    "lacrimótomos": "lacrimótomo",
    "lacro": "lacrar",
    "lacrou": "lacrar",
    "lacrá": "lacrar",
    "lacrámo": "lacrar",
    "lacrámos": "lacrar",
    "lacráramo": "lacrar",
    "lacráramos": "lacrar",
    "lacrárei": "lacrar",
    "lacráreis": "lacrar",
    "lacrásseis": "lacrar",
    "lacrássemos": "lacrar",
    "lacrávamo": "lacrar",
    "lacrávamos": "lacrar",
    "lacrávei": "lacrar",
    "lacráveis": "lacrável",
    "lacta": "lactar",
    "lactada": "lactar",
    "lactadas": "lactar",
    "lactado": "lactar",
    "lactados": "lactar",
    "lactai": "lactar",
    "lactais": "lactar",
    "lactam": "lactar",
    "lactamo": "lactar",
    "lactamos": "lactar",
    "lactando": "lactar",
    "lactantes": "lactante",
    "lactara": "lactar",
    "lactaram": "lactar",
    "lactaras": "lactar",
    "lactarde": "lactar",
    "lactardes": "lactar",
    "lactare": "lactar",
    "lactarei": "lactar",
    "lactareis": "lactar",
    "lactarem": "lactar",
    "lactaremos": "lactar",
    "lactares": "lactar",
    "lactaria": "lactar",
    "lactariam": "lactar",
    "lactarias": "lactar",
    "lactariáceas": "lactariácea",
    "lactarmo": "lactar",
    "lactarmos": "lactar",
    "lactará": "lactar",
    "lactarás": "lactar",
    "lactarão": "lactar",
    "lactaríamos": "lactar",
    "lactaríeis": "lactar",
    "lactas": "lactar",
    "lactases": "lactase",
    "lactasse": "lactar",
    "lactassem": "lactar",
    "lactasses": "lactar",
    "lactaste": "lactar",
    "lactastes": "lactar",
    "lactatos": "lactato",
    "lactava": "lactar",
    "lactavam": "lactar",
    "lactavas": "lactar",
    "lactações": "lactação",
    "lacte": "lactar",
    "lactei": "lactar",
    "lacteis": "lactar",
    "lactem": "lactar",
    "lactemo": "lactar",
    "lactemos": "lactar",
    "lactentes": "lactente",
    "lactes": "lactar",
    "lactescentes": "lactescente",
    "lactescências": "lactescência",
    "lacticemias": "lacticemia",
    "lacticinosa": "lacticinoso",
    "lacticinosas": "lacticinoso",
    "lacticinosos": "lacticinoso",
    "lacticolores": "lacticolor",
    "lacticultora": "lacticultor",
    "lacticultoras": "lacticultor",
    "lacticultores": "lacticultor",
    "lacticulturas": "lacticultura",
    "lacticínios": "lacticínio",
    "lactifobias": "lactifobia",
    "lactiformes": "lactiforme",
    "lacto": "lactar",
    "lactobacilos": "lactobacilo",
    "lactobutirómetros": "lactobutirómetro",
    "lactodensimetrias": "lactodensimetria",
    "lactodensímetros": "lactodensímetro",
    "lactosa": "lactoso",
    "lactosas": "lactoso",
    "lactoses": "lactose",
    "lactosos": "lactoso",
    "lactosúrias": "lactosúria",
    "lactou": "lactar",
    "lactucinas": "lactucina",
    "lactucáceas": "lactucácea",
    "lactucários": "lactucário",
    "lactucíneas": "lactucínea",
    "lactumenes": "lactúmen",
    "lactumes": "lactume",
    "lactá": "lactar",
    "lactámo": "lactar",
    "lactámos": "lactar",
    "lactáramo": "lactar",
    "lactáramos": "lactar",
    "lactárei": "lactar",
    "lactáreis": "lactar",
    "lactária": "lactário",
    "lactárias": "lactário",
    "lactários": "lactário",
    "lactásseis": "lactar",
    "lactássemos": "lactar",
    "lactávamo": "lactar",
    "lactávamos": "lactar",
    "lactávei": "lactar",
    "lactáveis": "lactar",
    "lactâncias": "lactância",
    "lactífaga": "lactífago",
    "lactífagas": "lactífago",
    "lactífagos": "lactífago",
    "lactífera": "lactífero",
    "lactíferas": "lactífero",
    "lactíferos": "lactífero",
    "lactífuga": "lactífugo",
    "lactífugas": "lactífugo",
    "lactífugos": "lactífugo",
    "lactígena": "lactígeno",
    "lactígenas": "lactígeno",
    "lactígenos": "lactígeno",
    "lactígera": "lactígero",
    "lactígeras": "lactígero",
    "lactígeros": "lactígero",
    "lactómetros": "lactómetro",
    "lactúcea": "lactúceo",
    "lactúceas": "lactúceo",
    "lactúceos": "lactúceo",
    "lacunares": "lacunar",
    "lacunas": "lacuna",
    "lacunosa": "lacunoso",
    "lacunosas": "lacunoso",
    "lacunosidades": "lacunosidade",
    "lacunosos": "lacunoso",
    "lacunários": "lacunário",
    "lacustrais": "lacustral",
    "lacustres": "lacustre",
    "lacámo": "lacar",
    "lacámos": "lacar",
    "lacáramo": "lacar",
    "lacáramos": "lacar",
    "lacáreis": "lacar",
    "lacásseis": "lacar",
    "lacássemos": "lacar",
    "lacávamo": "lacar",
    "lacávamos": "lacar",
    "lacáveis": "lacável",
    "lacértidas": "lacértida",
    "lacínias": "lacínia",
    "lacólitos": "lacólito",
    "lacónia": "lacónio",
    "lacónias": "lacónio",
    "lacónica": "lacónico",
    "lacónicas": "lacónico",
    "lacónicos": "lacónico",
    "lacónios": "lacónio",
    "ladainhas": "ladainha",
    "ladairos": "ladairo",
    "ladanífera": "ladanífero",
    "ladaníferas": "ladanífero",
    "ladaníferos": "ladanífero",
    "ladas": "lada",
    "ladeada": "ladear",
    "ladeadas": "ladear",
    "ladeado": "ladear",
    "ladeados": "ladear",
    "ladeai": "ladear",
    "ladeais": "ladear",
    "ladeamentos": "ladeamento",
    "ladeamo": "ladear",
    "ladeamos": "ladear",
    "ladeando": "ladear",
    "ladeara": "ladear",
    "ladearam": "ladear",
    "ladearas": "ladear",
    "ladearde": "ladear",
    "ladeardes": "ladear",
    "ladeare": "ladear",
    "ladearei": "ladear",
    "ladeareis": "ladear",
    "ladearem": "ladear",
    "ladearemos": "ladear",
    "ladeares": "ladear",
    "ladearia": "ladear",
    "ladeariam": "ladear",
    "ladearias": "ladear",
    "ladearmo": "ladear",
    "ladearmos": "ladear",
    "ladeará": "ladear",
    "ladearás": "ladear",
    "ladearão": "ladear",
    "ladearíamos": "ladear",
    "ladearíeis": "ladear",
    "ladeasse": "ladear",
    "ladeassem": "ladear",
    "ladeasses": "ladear",
    "ladeaste": "ladear",
    "ladeastes": "ladear",
    "ladeava": "ladear",
    "ladeavam": "ladear",
    "ladeavas": "ladear",
    "ladeei": "ladear",
    "ladeeis": "ladear",
    "ladeemo": "ladear",
    "ladeemos": "ladear",
    "ladeia": "ladear",
    "ladeiam": "ladear",
    "ladeias": "ladear",
    "ladeie": "ladear",
    "ladeiem": "ladear",
    "ladeies": "ladear",
    "ladeio": "ladear",
    "ladeira": "ladeiro",
    "ladeirada": "ladeirar",
    "ladeiradas": "ladeirar",
    "ladeirado": "ladeirar",
    "ladeirados": "ladeirar",
    "ladeirai": "ladeirar",
    "ladeirais": "ladeirar",
    "ladeiram": "ladeirar",
    "ladeiramo": "ladeirar",
    "ladeiramos": "ladeirar",
    "ladeirando": "ladeirar",
    "ladeirara": "ladeirar",
    "ladeiraram": "ladeirar",
    "ladeiraras": "ladeirar",
    "ladeirardes": "ladeirar",
    "ladeirarei": "ladeirar",
    "ladeirareis": "ladeirar",
    "ladeirarem": "ladeirar",
    "ladeiraremos": "ladeirar",
    "ladeirares": "ladeirar",
    "ladeiraria": "ladeirar",
    "ladeirariam": "ladeirar",
    "ladeirarias": "ladeirar",
    "ladeirarmo": "ladeirar",
    "ladeirarmos": "ladeirar",
    "ladeirará": "ladeirar",
    "ladeirarás": "ladeirar",
    "ladeirarão": "ladeirar",
    "ladeiraríamos": "ladeirar",
    "ladeiraríeis": "ladeirar",
    "ladeiras": "ladeiro",
    "ladeirasse": "ladeirar",
    "ladeirassem": "ladeirar",
    "ladeirasses": "ladeirar",
    "ladeiraste": "ladeirar",
    "ladeirastes": "ladeirar",
    "ladeirava": "ladeirar",
    "ladeiravam": "ladeirar",
    "ladeiravas": "ladeirar",
    "ladeire": "ladeirar",
    "ladeirei": "ladeirar",
    "ladeireis": "ladeirar",
    "ladeirem": "ladeirar",
    "ladeiremo": "ladeirar",
    "ladeiremos": "ladeirar",
    "ladeirenta": "ladeirento",
    "ladeirentas": "ladeirento",
    "ladeirentos": "ladeirento",
    "ladeires": "ladeirar",
    "ladeiro": "ladeirar",
    "ladeiros": "ladeiro",
    "ladeirou": "ladeirar",
    "ladeirámo": "ladeirar",
    "ladeirámos": "ladeirar",
    "ladeiráramo": "ladeirar",
    "ladeiráramos": "ladeirar",
    "ladeiráreis": "ladeirar",
    "ladeirásseis": "ladeirar",
    "ladeirássemos": "ladeirar",
    "ladeirávamo": "ladeirar",
    "ladeirávamos": "ladeirar",
    "ladeiráveis": "ladeirar",
    "ladeou": "ladear",
    "ladezas": "ladeza",
    "ladeá": "ladear",
    "ladeámo": "ladear",
    "ladeámos": "ladear",
    "ladeáramo": "ladear",
    "ladeáramos": "ladear",
    "ladeárei": "ladear",
    "ladeáreis": "ladear",
    "ladeásseis": "ladear",
    "ladeássemos": "ladear",
    "ladeávamo": "ladear",
    "ladeávamos": "ladear",
    "ladeávei": "ladear",
    "ladeáveis": "ladeável",
    "ladina": "ladino",
    "ladinas": "ladino",
    "ladinezas": "ladineza",
    "ladinianos": "ladiniano",
    "ladinos": "ladino",
    "lados": "lado",
    "ladra": "ladro",
    "ladrada": "ladrar",
    "ladradas": "ladrar",
    "ladrado": "ladrar",
    "ladradora": "ladrador",
    "ladradoras": "ladrador",
    "ladradores": "ladrador",
    "ladrados": "ladrar",
    "ladraduras": "ladradura",
    "ladrai": "ladrar",
    "ladrais": "ladrar",
    "ladram": "ladrar",
    "ladramo": "ladrar",
    "ladramos": "ladrar",
    "ladrando": "ladrar",
    "ladranzanas": "ladranzana",
    "ladrara": "ladrar",
    "ladraram": "ladrar",
    "ladraras": "ladrar",
    "ladrardes": "ladrar",
    "ladrarei": "ladrar",
    "ladrareis": "ladrar",
    "ladrarem": "ladrar",
    "ladraremos": "ladrar",
    "ladrares": "ladrar",
    "ladraria": "ladrar",
    "ladrariam": "ladrar",
    "ladrarias": "ladraria",
    "ladrarmo": "ladrar",
    "ladrarmos": "ladrar",
    "ladrará": "ladrar",
    "ladrarás": "ladrar",
    "ladrarão": "ladrar",
    "ladraríamos": "ladrar",
    "ladraríeis": "ladrar",
    "ladras": "ladro",
    "ladrasse": "ladrar",
    "ladrassem": "ladrar",
    "ladrasses": "ladrar",
    "ladraste": "ladrar",
    "ladrastes": "ladrar",
    "ladrava": "ladrar",
    "ladravam": "ladrar",
    "ladravas": "ladrar",
    "ladravazes": "ladravaz",
    "ladravões": "ladravão",
    "ladre": "ladrar",
    "ladrei": "ladrar",
    "ladreis": "ladrar",
    "ladrem": "ladrar",
    "ladremo": "ladrar",
    "ladremos": "ladrar",
    "ladres": "ladrar",
    "ladridos": "ladrido",
    "ladrilha": "ladrilhar",
    "ladrilhada": "ladrilhar",
    "ladrilhadas": "ladrilhar",
    "ladrilhado": "ladrilhar",
    "ladrilhadora": "ladrilhador",
    "ladrilhadoras": "ladrilhador",
    "ladrilhadores": "ladrilhador",
    "ladrilhados": "ladrilhar",
    "ladrilhagens": "ladrilhagem",
    "ladrilhai": "ladrilhar",
    "ladrilhais": "ladrilhar",
    "ladrilham": "ladrilhar",
    "ladrilhamo": "ladrilhar",
    "ladrilhamos": "ladrilhar",
    "ladrilhando": "ladrilhar",
    "ladrilhara": "ladrilhar",
    "ladrilharam": "ladrilhar",
    "ladrilharas": "ladrilhar",
    "ladrilharde": "ladrilhar",
    "ladrilhardes": "ladrilhar",
    "ladrilhare": "ladrilhar",
    "ladrilharei": "ladrilhar",
    "ladrilhareis": "ladrilhar",
    "ladrilharem": "ladrilhar",
    "ladrilharemos": "ladrilhar",
    "ladrilhares": "ladrilhar",
    "ladrilharia": "ladrilhar",
    "ladrilhariam": "ladrilhar",
    "ladrilharias": "ladrilhar",
    "ladrilharmo": "ladrilhar",
    "ladrilharmos": "ladrilhar",
    "ladrilhará": "ladrilhar",
    "ladrilharás": "ladrilhar",
    "ladrilharão": "ladrilhar",
    "ladrilharíamos": "ladrilhar",
    "ladrilharíeis": "ladrilhar",
    "ladrilhas": "ladrilhar",
    "ladrilhasse": "ladrilhar",
    "ladrilhassem": "ladrilhar",
    "ladrilhasses": "ladrilhar",
    "ladrilhaste": "ladrilhar",
    "ladrilhastes": "ladrilhar",
    "ladrilhava": "ladrilhar",
    "ladrilhavam": "ladrilhar",
    "ladrilhavas": "ladrilhar",
    "ladrilhe": "ladrilhar",
    "ladrilhei": "ladrilhar",
    "ladrilheira": "ladrilheiro",
    "ladrilheiras": "ladrilheiro",
    "ladrilheiros": "ladrilheiro",
    "ladrilheis": "ladrilhar",
    "ladrilhem": "ladrilhar",
    "ladrilhemo": "ladrilhar",
    "ladrilhemos": "ladrilhar",
    "ladrilhes": "ladrilhar",
    "ladrilho": "ladrilhar",
    "ladrilhos": "ladrilho",
    "ladrilhou": "ladrilhar",
    "ladrilhá": "ladrilhar",
    "ladrilhámo": "ladrilhar",
    "ladrilhámos": "ladrilhar",
    "ladrilháramo": "ladrilhar",
    "ladrilháramos": "ladrilhar",
    "ladrilhárei": "ladrilhar",
    "ladrilháreis": "ladrilhar",
    "ladrilhásseis": "ladrilhar",
    "ladrilhássemos": "ladrilhar",
    "ladrilhávamo": "ladrilhar",
    "ladrilhávamos": "ladrilhar",
    "ladrilhávei": "ladrilhar",
    "ladrilháveis": "ladrilhar",
    "ladrinha": "ladrão",
    "ladrinhas": "ladrão",
    "ladripa": "ladripar",
    "ladripada": "ladripar",
    "ladripadas": "ladripar",
    "ladripado": "ladripar",
    "ladripados": "ladripar",
    "ladripai": "ladripar",
    "ladripais": "ladripar",
    "ladripam": "ladripar",
    "ladripamo": "ladripar",
    "ladripamos": "ladripar",
    "ladripando": "ladripar",
    "ladripara": "ladripar",
    "ladriparam": "ladripar",
    "ladriparas": "ladripar",
    "ladriparde": "ladripar",
    "ladripardes": "ladripar",
    "ladripare": "ladripar",
    "ladriparei": "ladripar",
    "ladripareis": "ladripar",
    "ladriparem": "ladripar",
    "ladriparemos": "ladripar",
    "ladripares": "ladripar",
    "ladriparia": "ladripar",
    "ladripariam": "ladripar",
    "ladriparias": "ladripar",
    "ladriparmo": "ladripar",
    "ladriparmos": "ladripar",
    "ladripará": "ladripar",
    "ladriparás": "ladripar",
    "ladriparão": "ladripar",
    "ladriparíamos": "ladripar",
    "ladriparíeis": "ladripar",
    "ladripas": "ladripar",
    "ladripasse": "ladripar",
    "ladripassem": "ladripar",
    "ladripasses": "ladripar",
    "ladripaste": "ladripar",
    "ladripastes": "ladripar",
    "ladripava": "ladripar",
    "ladripavam": "ladripar",
    "ladripavas": "ladripar",
    "ladripe": "ladripar",
    "ladripei": "ladripar",
    "ladripeis": "ladripar",
    "ladripem": "ladripar",
    "ladripemo": "ladripar",
    "ladripemos": "ladripar",
    "ladripes": "ladripar",
    "ladripo": "ladripar",
    "ladripou": "ladripar",
    "ladripá": "ladripar",
    "ladripámo": "ladripar",
    "ladripámos": "ladripar",
    "ladripáramo": "ladripar",
    "ladripáramos": "ladripar",
    "ladripárei": "ladripar",
    "ladripáreis": "ladripar",
    "ladripásseis": "ladripar",
    "ladripássemos": "ladripar",
    "ladripávamo": "ladripar",
    "ladripávamos": "ladripar",
    "ladripávei": "ladripar",
    "ladripáveis": "ladripar",
    "ladrisca": "ladrisco",
    "ladriscas": "ladrisco",
    "ladriscos": "ladrisco",
    "ladrita": "ladrão",
    "ladritas": "ladrão",
    "ladriços": "ladriço",
    "ladro": "ladrar",
    "ladroa": "ladroar",
    "ladroada": "ladroar",
    "ladroadas": "ladroar",
    "ladroado": "ladroar",
    "ladroados": "ladroar",
    "ladroagens": "ladroagem",
    "ladroai": "ladroar",
    "ladroais": "ladroar",
    "ladroam": "ladroar",
    "ladroamo": "ladroar",
    "ladroamos": "ladroar",
    "ladroando": "ladroar",
    "ladroara": "ladroar",
    "ladroaram": "ladroar",
    "ladroaras": "ladroar",
    "ladroarde": "ladroar",
    "ladroardes": "ladroar",
    "ladroare": "ladroar",
    "ladroarei": "ladroar",
    "ladroareis": "ladroar",
    "ladroarem": "ladroar",
    "ladroaremos": "ladroar",
    "ladroares": "ladroar",
    "ladroaria": "ladroar",
    "ladroariam": "ladroar",
    "ladroarias": "ladroar",
    "ladroarmo": "ladroar",
    "ladroarmos": "ladroar",
    "ladroará": "ladroar",
    "ladroarás": "ladroar",
    "ladroarão": "ladroar",
    "ladroaríamos": "ladroar",
    "ladroaríeis": "ladroar",
    "ladroas": "ladroar",
    "ladroasse": "ladroar",
    "ladroassem": "ladroar",
    "ladroasses": "ladroar",
    "ladroaste": "ladroar",
    "ladroastes": "ladroar",
    "ladroava": "ladroar",
    "ladroavam": "ladroar",
    "ladroavas": "ladroar",
    "ladroaça": "ladroaço",
    "ladroaças": "ladroaço",
    "ladroaços": "ladroaço",
    "ladroe": "ladroar",
    "ladroei": "ladroar",
    "ladroeira": "ladroeiro",
    "ladroeirada": "ladroeirar",
    "ladroeiradas": "ladroeirar",
    "ladroeirado": "ladroeirar",
    "ladroeirados": "ladroeirar",
    "ladroeirai": "ladroeirar",
    "ladroeirais": "ladroeirar",
    "ladroeiram": "ladroeirar",
    "ladroeiramo": "ladroeirar",
    "ladroeiramos": "ladroeirar",
    "ladroeirando": "ladroeirar",
    "ladroeirara": "ladroeirar",
    "ladroeiraram": "ladroeirar",
    "ladroeiraras": "ladroeirar",
    "ladroeirardes": "ladroeirar",
    "ladroeirarei": "ladroeirar",
    "ladroeirareis": "ladroeirar",
    "ladroeirarem": "ladroeirar",
    "ladroeiraremos": "ladroeirar",
    "ladroeirares": "ladroeirar",
    "ladroeiraria": "ladroeirar",
    "ladroeirariam": "ladroeirar",
    "ladroeirarias": "ladroeirar",
    "ladroeirarmo": "ladroeirar",
    "ladroeirarmos": "ladroeirar",
    "ladroeirará": "ladroeirar",
    "ladroeirarás": "ladroeirar",
    "ladroeirarão": "ladroeirar",
    "ladroeiraríamos": "ladroeirar",
    "ladroeiraríeis": "ladroeirar",
    "ladroeiras": "ladroeiro",
    "ladroeirasse": "ladroeirar",
    "ladroeirassem": "ladroeirar",
    "ladroeirasses": "ladroeirar",
    "ladroeiraste": "ladroeirar",
    "ladroeirastes": "ladroeirar",
    "ladroeirava": "ladroeirar",
    "ladroeiravam": "ladroeirar",
    "ladroeiravas": "ladroeirar",
    "ladroeire": "ladroeirar",
    "ladroeirei": "ladroeirar",
    "ladroeireis": "ladroeirar",
    "ladroeirem": "ladroeirar",
    "ladroeiremo": "ladroeirar",
    "ladroeiremos": "ladroeirar",
    "ladroeires": "ladroeirar",
    "ladroeiro": "ladroeirar",
    "ladroeiros": "ladroeiro",
    "ladroeirou": "ladroeirar",
    "ladroeirámo": "ladroeirar",
    "ladroeirámos": "ladroeirar",
    "ladroeiráramo": "ladroeirar",
    "ladroeiráramos": "ladroeirar",
    "ladroeiráreis": "ladroeirar",
    "ladroeirásseis": "ladroeirar",
    "ladroeirássemos": "ladroeirar",
    "ladroeirávamo": "ladroeirar",
    "ladroeirávamos": "ladroeirar",
    "ladroeiráveis": "ladroeirar",
    "ladroeis": "ladroar",
    "ladroem": "ladroar",
    "ladroemo": "ladroar",
    "ladroemos": "ladroar",
    "ladroes": "ladroar",
    "ladroinha": "ladrão",
    "ladroinhas": "ladrão",
    "ladroita": "ladrão",
    "ladroitas": "ladrão",
    "ladrona": "ladrão",
    "ladronas": "ladrão",
    "ladronaça": "ladronaço",
    "ladronaças": "ladronaço",
    "ladronaços": "ladronaço",
    "ladroninha": "ladrão",
    "ladroninhas": "ladrão",
    "ladronita": "ladrão",
    "ladronitas": "ladrão",
    "ladroo": "ladroar",
    "ladroou": "ladroar",
    "ladros": "ladro",
    "ladrou": "ladrar",
    "ladroá": "ladroar",
    "ladroámo": "ladroar",
    "ladroámos": "ladroar",
    "ladroáramo": "ladroar",
    "ladroáramos": "ladroar",
    "ladroárei": "ladroar",
    "ladroáreis": "ladroar",
    "ladroásseis": "ladroar",
    "ladroássemos": "ladroar",
    "ladroávamo": "ladroar",
    "ladroávamos": "ladroar",
    "ladroávei": "ladroar",
    "ladroáveis": "ladroar",
    "ladroíces": "ladroíce",
    "ladroísmos": "ladroísmo",
    "ladrámo": "ladrar",
    "ladrámos": "ladrar",
    "ladráramo": "ladrar",
    "ladráramos": "ladrar",
    "ladráreis": "ladrar",
    "ladrásseis": "ladrar",
    "ladrássemos": "ladrar",
    "ladrávamo": "ladrar",
    "ladrávamos": "ladrar",
    "ladráveis": "ladrar",
    "ladrãozinho": "ladrão",
    "ladrãozito": "ladrão",
    "ladrões": "ladrão",
    "ladrõezinhos": "ladrão",
    "ladrõezitos": "ladrão",
    "ladys": "lady",
    "lagalhés": "lagalhé",
    "lagamares": "lagamar",
    "laganhas": "laganha",
    "laganhenta": "laganhento",
    "laganhentas": "laganhento",
    "laganhentos": "laganhento",
    "laganhosa": "laganhoso",
    "laganhosas": "laganhoso",
    "laganhosos": "laganhoso",
    "lagaradas": "lagarada",
    "lagaragens": "lagaragem",
    "lagareira": "lagareiro",
    "lagareiras": "lagareiro",
    "lagareiros": "lagareiro",
    "lagares": "lagar",
    "lagaretas": "lagareta",
    "lagarinhos": "lagarinho",
    "lagariça": "lagariço",
    "lagariças": "lagariço",
    "lagariços": "lagariço",
    "lagaros": "lagaro",
    "lagartas": "lagarta",
    "lagarteada": "lagartear",
    "lagarteadas": "lagartear",
    "lagarteado": "lagartear",
    "lagarteados": "lagartear",
    "lagarteai": "lagartear",
    "lagarteais": "lagartear",
    "lagarteamo": "lagartear",
    "lagarteamos": "lagartear",
    "lagarteando": "lagartear",
    "lagarteara": "lagartear",
    "lagartearam": "lagartear",
    "lagartearas": "lagartear",
    "lagarteardes": "lagartear",
    "lagartearei": "lagartear",
    "lagarteareis": "lagartear",
    "lagartearem": "lagartear",
    "lagartearemos": "lagartear",
    "lagarteares": "lagartear",
    "lagartearia": "lagartear",
    "lagarteariam": "lagartear",
    "lagartearias": "lagartear",
    "lagartearmo": "lagartear",
    "lagartearmos": "lagartear",
    "lagarteará": "lagartear",
    "lagartearás": "lagartear",
    "lagartearão": "lagartear",
    "lagartearíamos": "lagartear",
    "lagartearíeis": "lagartear",
    "lagarteasse": "lagartear",
    "lagarteassem": "lagartear",
    "lagarteasses": "lagartear",
    "lagarteaste": "lagartear",
    "lagarteastes": "lagartear",
    "lagarteava": "lagartear",
    "lagarteavam": "lagartear",
    "lagarteavas": "lagartear",
    "lagarteei": "lagartear",
    "lagarteeis": "lagartear",
    "lagarteemo": "lagartear",
    "lagarteemos": "lagartear",
    "lagarteia": "lagartear",
    "lagarteiam": "lagartear",
    "lagarteias": "lagartear",
    "lagarteie": "lagartear",
    "lagarteiem": "lagartear",
    "lagarteies": "lagartear",
    "lagarteio": "lagartear",
    "lagarteiras": "lagarteira",
    "lagarteiros": "lagarteiro",
    "lagarteou": "lagartear",
    "lagarteámo": "lagartear",
    "lagarteámos": "lagartear",
    "lagarteáramo": "lagartear",
    "lagarteáramos": "lagartear",
    "lagarteáreis": "lagartear",
    "lagarteásseis": "lagartear",
    "lagarteássemos": "lagartear",
    "lagarteávamo": "lagartear",
    "lagarteávamos": "lagartear",
    "lagarteáveis": "lagartear",
    "lagartixas": "lagartixa",
    "lagartos": "lagarto",
    "lagas": "laga",
    "lageas": "lagea",
    "lagenas": "lagena",
    "lagoas": "lagoa",
    "lagocéfala": "lagocéfalo",
    "lagocéfalas": "lagocéfalo",
    "lagocéfalos": "lagocéfalo",
    "lagoeiros": "lagoeiro",
    "lagoftalmias": "lagoftalmia",
    "lagomorfos": "lagomorfo",
    "lagoquilias": "lagoquilia",
    "lagos": "lago",
    "lagostas": "lagosta",
    "lagosteira": "lagosteiro",
    "lagosteiras": "lagosteiro",
    "lagosteiros": "lagosteiro",
    "lagostins": "lagostim",
    "lagrangianas": "lagrangiana",
    "lagrimais": "lagrimal",
    "lagrimantes": "lagrimante",
    "lagrimatória": "lagrimatório",
    "lagrimatórias": "lagrimatório",
    "lagrimatórios": "lagrimatório",
    "lagrimazinha": "lágrima",
    "lagrimazinhas": "lágrima",
    "lagrimazita": "lágrima",
    "lagrimazitas": "lágrima",
    "lagrimações": "lagrimação",
    "lagrimeja": "lagrimejar",
    "lagrimejada": "lagrimejar",
    "lagrimejadas": "lagrimejar",
    "lagrimejado": "lagrimejar",
    "lagrimejados": "lagrimejar",
    "lagrimejai": "lagrimejar",
    "lagrimejais": "lagrimejar",
    "lagrimejam": "lagrimejar",
    "lagrimejamo": "lagrimejar",
    "lagrimejamos": "lagrimejar",
    "lagrimejando": "lagrimejar",
    "lagrimejara": "lagrimejar",
    "lagrimejaram": "lagrimejar",
    "lagrimejaras": "lagrimejar",
    "lagrimejardes": "lagrimejar",
    "lagrimejarei": "lagrimejar",
    "lagrimejareis": "lagrimejar",
    "lagrimejarem": "lagrimejar",
    "lagrimejaremos": "lagrimejar",
    "lagrimejares": "lagrimejar",
    "lagrimejaria": "lagrimejar",
    "lagrimejariam": "lagrimejar",
    "lagrimejarias": "lagrimejar",
    "lagrimejarmo": "lagrimejar",
    "lagrimejarmos": "lagrimejar",
    "lagrimejará": "lagrimejar",
    "lagrimejarás": "lagrimejar",
    "lagrimejarão": "lagrimejar",
    "lagrimejaríamos": "lagrimejar",
    "lagrimejaríeis": "lagrimejar",
    "lagrimejas": "lagrimejar",
    "lagrimejasse": "lagrimejar",
    "lagrimejassem": "lagrimejar",
    "lagrimejasses": "lagrimejar",
    "lagrimejaste": "lagrimejar",
    "lagrimejastes": "lagrimejar",
    "lagrimejava": "lagrimejar",
    "lagrimejavam": "lagrimejar",
    "lagrimejavas": "lagrimejar",
    "lagrimeje": "lagrimejar",
    "lagrimejei": "lagrimejar",
    "lagrimejeis": "lagrimejar",
    "lagrimejem": "lagrimejar",
    "lagrimejemo": "lagrimejar",
    "lagrimejemos": "lagrimejar",
    "lagrimejes": "lagrimejar",
    "lagrimejo": "lagrimejar",
    "lagrimejou": "lagrimejar",
    "lagrimejámo": "lagrimejar",
    "lagrimejámos": "lagrimejar",
    "lagrimejáramo": "lagrimejar",
    "lagrimejáramos": "lagrimejar",
    "lagrimejáreis": "lagrimejar",
    "lagrimejásseis": "lagrimejar",
    "lagrimejássemos": "lagrimejar",
    "lagrimejávamo": "lagrimejar",
    "lagrimejávamos": "lagrimejar",
    "lagrimejáveis": "lagrimejar",
    "lagrimosa": "lagrimoso",
    "lagrimosas": "lagrimoso",
    "lagrimosos": "lagrimoso",
    "laguinho": "lago",
    "laguinhos": "lago",
    "laguito": "lago",
    "laguitos": "lago",
    "lagunares": "lagunar",
    "lagunas": "laguna",
    "lagópodes": "lagópode",
    "lagões": "lagão",
    "laias": "laia",
    "laica": "laico",
    "laicados": "laicado",
    "laicais": "laical",
    "laicas": "laico",
    "laicidades": "laicidade",
    "laicifica": "laicificar",
    "laicificada": "laicificar",
    "laicificadas": "laicificar",
    "laicificado": "laicificar",
    "laicificados": "laicificar",
    "laicificai": "laicificar",
    "laicificais": "laicificar",
    "laicificam": "laicificar",
    "laicificamo": "laicificar",
    "laicificamos": "laicificar",
    "laicificando": "laicificar",
    "laicificara": "laicificar",
    "laicificaram": "laicificar",
    "laicificaras": "laicificar",
    "laicificarde": "laicificar",
    "laicificardes": "laicificar",
    "laicificare": "laicificar",
    "laicificarei": "laicificar",
    "laicificareis": "laicificar",
    "laicificarem": "laicificar",
    "laicificaremos": "laicificar",
    "laicificares": "laicificar",
    "laicificaria": "laicificar",
    "laicificariam": "laicificar",
    "laicificarias": "laicificar",
    "laicificarmo": "laicificar",
    "laicificarmos": "laicificar",
    "laicificará": "laicificar",
    "laicificarás": "laicificar",
    "laicificarão": "laicificar",
    "laicificaríamos": "laicificar",
    "laicificaríeis": "laicificar",
    "laicificas": "laicificar",
    "laicificasse": "laicificar",
    "laicificassem": "laicificar",
    "laicificasses": "laicificar",
    "laicificaste": "laicificar",
    "laicificastes": "laicificar",
    "laicificava": "laicificar",
    "laicificavam": "laicificar",
    "laicificavas": "laicificar",
    "laicifico": "laicificar",
    "laicificou": "laicificar",
    "laicificá": "laicificar",
    "laicificámo": "laicificar",
    "laicificámos": "laicificar",
    "laicificáramo": "laicificar",
    "laicificáramos": "laicificar",
    "laicificárei": "laicificar",
    "laicificáreis": "laicificar",
    "laicificásseis": "laicificar",
    "laicificássemos": "laicificar",
    "laicificávamo": "laicificar",
    "laicificávamos": "laicificar",
    "laicificávei": "laicificar",
    "laicificáveis": "laicificável",
    "laicifique": "laicificar",
    "laicifiquei": "laicificar",
    "laicifiqueis": "laicificar",
    "laicifiquem": "laicificar",
    "laicifiquemo": "laicificar",
    "laicifiquemos": "laicificar",
    "laicifiques": "laicificar",
    "laicismos": "laicismo",
    "laiciza": "laicizar",
    "laicizada": "laicizar",
    "laicizadas": "laicizar",
    "laicizado": "laicizar",
    "laicizados": "laicizar",
    "laicizai": "laicizar",
    "laicizais": "laicizar",
    "laicizam": "laicizar",
    "laicizamo": "laicizar",
    "laicizamos": "laicizar",
    "laicizando": "laicizar",
    "laicizara": "laicizar",
    "laicizaram": "laicizar",
    "laicizaras": "laicizar",
    "laicizarde": "laicizar",
    "laicizardes": "laicizar",
    "laicizare": "laicizar",
    "laicizarei": "laicizar",
    "laicizareis": "laicizar",
    "laicizarem": "laicizar",
    "laicizaremos": "laicizar",
    "laicizares": "laicizar",
    "laicizaria": "laicizar",
    "laicizariam": "laicizar",
    "laicizarias": "laicizar",
    "laicizarmo": "laicizar",
    "laicizarmos": "laicizar",
    "laicizará": "laicizar",
    "laicizarás": "laicizar",
    "laicizarão": "laicizar",
    "laicizaríamos": "laicizar",
    "laicizaríeis": "laicizar",
    "laicizas": "laicizar",
    "laicizasse": "laicizar",
    "laicizassem": "laicizar",
    "laicizasses": "laicizar",
    "laicizaste": "laicizar",
    "laicizastes": "laicizar",
    "laicizava": "laicizar",
    "laicizavam": "laicizar",
    "laicizavas": "laicizar",
    "laicizações": "laicização",
    "laicize": "laicizar",
    "laicizei": "laicizar",
    "laicizeis": "laicizar",
    "laicizem": "laicizar",
    "laicizemo": "laicizar",
    "laicizemos": "laicizar",
    "laicizes": "laicizar",
    "laicizo": "laicizar",
    "laicizou": "laicizar",
    "laicizá": "laicizar",
    "laicizámo": "laicizar",
    "laicizámos": "laicizar",
    "laicizáramo": "laicizar",
    "laicizáramos": "laicizar",
    "laicizárei": "laicizar",
    "laicizáreis": "laicizar",
    "laicizásseis": "laicizar",
    "laicizássemos": "laicizar",
    "laicizávamo": "laicizar",
    "laicizávamos": "laicizar",
    "laicizávei": "laicizar",
    "laicizáveis": "laicizável",
    "laicos": "laico",
    "lais": "lai",
    "laises": "lais",
    "laiva": "laivar",
    "laivada": "laivar",
    "laivadas": "laivar",
    "laivado": "laivar",
    "laivados": "laivar",
    "laivai": "laivar",
    "laivais": "laivar",
    "laivam": "laivar",
    "laivamo": "laivar",
    "laivamos": "laivar",
    "laivando": "laivar",
    "laivara": "laivar",
    "laivaram": "laivar",
    "laivaras": "laivar",
    "laivarde": "laivar",
    "laivardes": "laivar",
    "laivare": "laivar",
    "laivarei": "laivar",
    "laivareis": "laivar",
    "laivarem": "laivar",
    "laivaremos": "laivar",
    "laivares": "laivar",
    "laivaria": "laivar",
    "laivariam": "laivar",
    "laivarias": "laivar",
    "laivarmo": "laivar",
    "laivarmos": "laivar",
    "laivará": "laivar",
    "laivarás": "laivar",
    "laivarão": "laivar",
    "laivaríamos": "laivar",
    "laivaríeis": "laivar",
    "laivas": "laivar",
    "laivasse": "laivar",
    "laivassem": "laivar",
    "laivasses": "laivar",
    "laivaste": "laivar",
    "laivastes": "laivar",
    "laivava": "laivar",
    "laivavam": "laivar",
    "laivavas": "laivar",
    "laive": "laivar",
    "laivei": "laivar",
    "laiveis": "laivar",
    "laivem": "laivar",
    "laivemo": "laivar",
    "laivemos": "laivar",
    "laives": "laivar",
    "laivo": "laivar",
    "laivos": "laivo",
    "laivou": "laivar",
    "laivá": "laivar",
    "laivámo": "laivar",
    "laivámos": "laivar",
    "laiváramo": "laivar",
    "laiváramos": "laivar",
    "laivárei": "laivar",
    "laiváreis": "laivar",
    "laivásseis": "laivar",
    "laivássemos": "laivar",
    "laivávamo": "laivar",
    "laivávamos": "laivar",
    "laivávei": "laivar",
    "laiváveis": "laivar",
    "lajas": "laja",
    "lajeada": "lajear",
    "lajeadas": "lajear",
    "lajeado": "lajear",
    "lajeadora": "lajeador",
    "lajeadoras": "lajeador",
    "lajeadores": "lajeador",
    "lajeados": "lajear",
    "lajeai": "lajear",
    "lajeais": "lajear",
    "lajeamentos": "lajeamento",
    "lajeamo": "lajear",
    "lajeamos": "lajear",
    "lajeando": "lajear",
    "lajeara": "lajear",
    "lajearam": "lajear",
    "lajearas": "lajear",
    "lajearde": "lajear",
    "lajeardes": "lajear",
    "lajeare": "lajear",
    "lajearei": "lajear",
    "lajeareis": "lajear",
    "lajearem": "lajear",
    "lajearemos": "lajear",
    "lajeares": "lajear",
    "lajearia": "lajear",
    "lajeariam": "lajear",
    "lajearias": "lajear",
    "lajearmo": "lajear",
    "lajearmos": "lajear",
    "lajeará": "lajear",
    "lajearás": "lajear",
    "lajearão": "lajear",
    "lajearíamos": "lajear",
    "lajearíeis": "lajear",
    "lajeasse": "lajear",
    "lajeassem": "lajear",
    "lajeasses": "lajear",
    "lajeaste": "lajear",
    "lajeastes": "lajear",
    "lajeava": "lajear",
    "lajeavam": "lajear",
    "lajeavas": "lajear",
    "lajedos": "lajedo",
    "lajeei": "lajear",
    "lajeeis": "lajear",
    "lajeemo": "lajear",
    "lajeemos": "lajear",
    "lajeia": "lajear",
    "lajeiam": "lajear",
    "lajeias": "lajear",
    "lajeie": "lajear",
    "lajeiem": "lajear",
    "lajeies": "lajear",
    "lajeio": "lajear",
    "lajens": "lajem",
    "lajenses": "lajense",
    "lajeosa": "lajeoso",
    "lajeosas": "lajeoso",
    "lajeosos": "lajeoso",
    "lajeou": "lajear",
    "lajes": "laje",
    "lajeá": "lajear",
    "lajeámo": "lajear",
    "lajeámos": "lajear",
    "lajeáramo": "lajear",
    "lajeáramos": "lajear",
    "lajeárei": "lajear",
    "lajeáreis": "lajear",
    "lajeásseis": "lajear",
    "lajeássemos": "lajear",
    "lajeávamo": "lajear",
    "lajeávamos": "lajear",
    "lajeávei": "lajear",
    "lajeáveis": "lajear",
    "lajotas": "lajota",
    "lala": "lalar",
    "lalada": "lalar",
    "laladas": "lalar",
    "lalado": "lalar",
    "lalados": "lalar",
    "lalai": "lalar",
    "lalais": "lalar",
    "lalam": "lalar",
    "lalamo": "lalar",
    "lalamos": "lalar",
    "lalando": "lalar",
    "lalara": "lalar",
    "lalaram": "lalar",
    "lalaras": "lalar",
    "lalardes": "lalar",
    "lalarei": "lalar",
    "lalareis": "lalar",
    "lalarem": "lalar",
    "lalaremos": "lalar",
    "lalares": "lalar",
    "lalaria": "lalar",
    "lalariam": "lalar",
    "lalarias": "lalar",
    "lalarmo": "lalar",
    "lalarmos": "lalar",
    "lalará": "lalar",
    "lalarás": "lalar",
    "lalarão": "lalar",
    "lalaríamos": "lalar",
    "lalaríeis": "lalar",
    "lalas": "lalar",
    "lalasse": "lalar",
    "lalassem": "lalar",
    "lalasses": "lalar",
    "lalaste": "lalar",
    "lalastes": "lalar",
    "lalava": "lalar",
    "lalavam": "lalar",
    "lalavas": "lalar",
    "lalações": "lalação",
    "lale": "lalar",
    "lalei": "lalar",
    "laleis": "lalar",
    "lalem": "lalar",
    "lalemo": "lalar",
    "lalemos": "lalar",
    "lales": "lalar",
    "lalo": "lalar",
    "lalomanias": "lalomania",
    "lalopatias": "lalopatia",
    "laloplegias": "laloplegia",
    "lalou": "lalar",
    "lalámo": "lalar",
    "lalámos": "lalar",
    "laláramo": "lalar",
    "laláramos": "lalar",
    "laláreis": "lalar",
    "lalásseis": "lalar",
    "lalássemos": "lalar",
    "lalávamo": "lalar",
    "lalávamos": "lalar",
    "laláveis": "lalar",
    "lamaceiras": "lamaceira",
    "lamaceiros": "lamaceiro",
    "lamacenta": "lamacento",
    "lamacentas": "lamacento",
    "lamacentos": "lamacento",
    "lamantins": "lamantim",
    "lamarckiana": "lamarckiano",
    "lamarckianas": "lamarckiano",
    "lamarckianismos": "lamarckianismo",
    "lamarckianos": "lamarckiano",
    "lamarckismos": "lamarckismo",
    "lamarckistas": "lamarckista",
    "lamarosa": "lamaroso",
    "lamarosas": "lamaroso",
    "lamarosos": "lamaroso",
    "lamartiniana": "lamartiniano",
    "lamartinianas": "lamartiniano",
    "lamartinianos": "lamartiniano",
    "lamartinistas": "lamartinista",
    "lamarões": "lamarão",
    "lamas": "lama",
    "lamaserias": "lamaseria",
    "lamaçais": "lamaçal",
    "lamaísmos": "lamaísmo",
    "lamaístas": "lamaísta",
    "lamba": "lamber",
    "lambadas": "lambada",
    "lambais": "lamber",
    "lambam": "lamber",
    "lambamo": "lamber",
    "lambamos": "lamber",
    "lambanças": "lambança",
    "lambara": "lambarar",
    "lambarada": "lambarar",
    "lambaradas": "lambarar",
    "lambarado": "lambarar",
    "lambarados": "lambarar",
    "lambarai": "lambarar",
    "lambarais": "lambarar",
    "lambaram": "lambarar",
    "lambaramo": "lambarar",
    "lambaramos": "lambarar",
    "lambarando": "lambarar",
    "lambarara": "lambarar",
    "lambararam": "lambarar",
    "lambararas": "lambarar",
    "lambarardes": "lambarar",
    "lambararei": "lambarar",
    "lambarareis": "lambarar",
    "lambararem": "lambarar",
    "lambararemos": "lambarar",
    "lambarares": "lambarar",
    "lambararia": "lambarar",
    "lambarariam": "lambarar",
    "lambararias": "lambarar",
    "lambararmo": "lambarar",
    "lambararmos": "lambarar",
    "lambarará": "lambarar",
    "lambararás": "lambarar",
    "lambararão": "lambarar",
    "lambararíamos": "lambarar",
    "lambararíeis": "lambarar",
    "lambaras": "lambarar",
    "lambarasse": "lambarar",
    "lambarassem": "lambarar",
    "lambarasses": "lambarar",
    "lambaraste": "lambarar",
    "lambarastes": "lambarar",
    "lambarava": "lambarar",
    "lambaravam": "lambarar",
    "lambaravas": "lambarar",
    "lambarazes": "lambaraz",
    "lambare": "lambarar",
    "lambarei": "lambarar",
    "lambareira": "lambareiro",
    "lambareiras": "lambareiro",
    "lambareirazinha": "lambareiro",
    "lambareirazinhas": "lambareiro",
    "lambareirazita": "lambareiro",
    "lambareirazitas": "lambareiro",
    "lambareiros": "lambareiro",
    "lambareirozinho": "lambareiro",
    "lambareirozinhos": "lambareiro",
    "lambareirozito": "lambareiro",
    "lambareirozitos": "lambareiro",
    "lambareis": "lambarar",
    "lambareja": "lambarejar",
    "lambarejada": "lambarejar",
    "lambarejadas": "lambarejar",
    "lambarejado": "lambarejar",
    "lambarejados": "lambarejar",
    "lambarejai": "lambarejar",
    "lambarejais": "lambarejar",
    "lambarejam": "lambarejar",
    "lambarejamo": "lambarejar",
    "lambarejamos": "lambarejar",
    "lambarejando": "lambarejar",
    "lambarejara": "lambarejar",
    "lambarejaram": "lambarejar",
    "lambarejaras": "lambarejar",
    "lambarejardes": "lambarejar",
    "lambarejarei": "lambarejar",
    "lambarejareis": "lambarejar",
    "lambarejarem": "lambarejar",
    "lambarejaremos": "lambarejar",
    "lambarejares": "lambarejar",
    "lambarejaria": "lambarejar",
    "lambarejariam": "lambarejar",
    "lambarejarias": "lambarejar",
    "lambarejarmo": "lambarejar",
    "lambarejarmos": "lambarejar",
    "lambarejará": "lambarejar",
    "lambarejarás": "lambarejar",
    "lambarejarão": "lambarejar",
    "lambarejaríamos": "lambarejar",
    "lambarejaríeis": "lambarejar",
    "lambarejas": "lambarejar",
    "lambarejasse": "lambarejar",
    "lambarejassem": "lambarejar",
    "lambarejasses": "lambarejar",
    "lambarejaste": "lambarejar",
    "lambarejastes": "lambarejar",
    "lambarejava": "lambarejar",
    "lambarejavam": "lambarejar",
    "lambarejavas": "lambarejar",
    "lambareje": "lambarejar",
    "lambarejei": "lambarejar",
    "lambarejeis": "lambarejar",
    "lambarejem": "lambarejar",
    "lambarejemo": "lambarejar",
    "lambarejemos": "lambarejar",
    "lambarejes": "lambarejar",
    "lambarejo": "lambarejar",
    "lambarejou": "lambarejar",
    "lambarejámo": "lambarejar",
    "lambarejámos": "lambarejar",
    "lambarejáramo": "lambarejar",
    "lambarejáramos": "lambarejar",
    "lambarejáreis": "lambarejar",
    "lambarejásseis": "lambarejar",
    "lambarejássemos": "lambarejar",
    "lambarejávamo": "lambarejar",
    "lambarejávamos": "lambarejar",
    "lambarejáveis": "lambarejar",
    "lambarem": "lambarar",
    "lambaremo": "lambarar",
    "lambaremos": "lambarar",
    "lambares": "lambarar",
    "lambarices": "lambarice",
    "lambarisca": "lambariscar",
    "lambariscada": "lambariscar",
    "lambariscadas": "lambariscar",
    "lambariscado": "lambariscar",
    "lambariscados": "lambariscar",
    "lambariscais": "lambariscar",
    "lambariscam": "lambariscar",
    "lambariscamo": "lambariscar",
    "lambariscamos": "lambariscar",
    "lambariscando": "lambariscar",
    "lambariscara": "lambariscar",
    "lambariscaram": "lambariscar",
    "lambariscaras": "lambariscar",
    "lambariscardes": "lambariscar",
    "lambariscarei": "lambariscar",
    "lambariscareis": "lambariscar",
    "lambariscarem": "lambariscar",
    "lambariscaremos": "lambariscar",
    "lambariscares": "lambariscar",
    "lambariscaria": "lambariscar",
    "lambariscariam": "lambariscar",
    "lambariscarias": "lambariscar",
    "lambariscarmo": "lambariscar",
    "lambariscarmos": "lambariscar",
    "lambariscará": "lambariscar",
    "lambariscarás": "lambariscar",
    "lambariscarão": "lambariscar",
    "lambariscaríamos": "lambariscar",
    "lambariscaríeis": "lambariscar",
    "lambariscas": "lambariscar",
    "lambariscasse": "lambariscar",
    "lambariscassem": "lambariscar",
    "lambariscasses": "lambariscar",
    "lambariscaste": "lambariscar",
    "lambariscastes": "lambariscar",
    "lambariscava": "lambariscar",
    "lambariscavam": "lambariscar",
    "lambariscavas": "lambariscar",
    "lambarisco": "lambariscar",
    "lambariscou": "lambariscar",
    "lambariscámo": "lambariscar",
    "lambariscámos": "lambariscar",
    "lambariscáramo": "lambariscar",
    "lambariscáramos": "lambariscar",
    "lambariscáreis": "lambariscar",
    "lambariscásseis": "lambariscar",
    "lambariscássemos": "lambariscar",
    "lambariscávamo": "lambariscar",
    "lambariscávamos": "lambariscar",
    "lambariscáveis": "lambariscar",
    "lambarisque": "lambariscar",
    "lambarisquei": "lambariscar",
    "lambarisqueis": "lambariscar",
    "lambarisquem": "lambariscar",
    "lambarisquemos": "lambariscar",
    "lambarisques": "lambariscar",
    "lambarizinhos": "lambarizinho",
    "lambaro": "lambarar",
    "lambarona": "lambarão",
    "lambaronas": "lambarão",
    "lambarou": "lambarar",
    "lambarámo": "lambarar",
    "lambarámos": "lambarar",
    "lambaráramo": "lambarar",
    "lambaráramos": "lambarar",
    "lambaráreis": "lambarar",
    "lambarásseis": "lambarar",
    "lambarássemos": "lambarar",
    "lambarávamo": "lambarar",
    "lambarávamos": "lambarar",
    "lambaráveis": "lambarar",
    "lambarões": "lambarão",
    "lambas": "lamber",
    "lambaza": "lambazar",
    "lambazada": "lambazar",
    "lambazadas": "lambazar",
    "lambazado": "lambazar",
    "lambazados": "lambazar",
    "lambazai": "lambazar",
    "lambazais": "lambazar",
    "lambazam": "lambazar",
    "lambazamo": "lambazar",
    "lambazamos": "lambazar",
    "lambazando": "lambazar",
    "lambazara": "lambazar",
    "lambazaram": "lambazar",
    "lambazaras": "lambazar",
    "lambazarde": "lambazar",
    "lambazardes": "lambazar",
    "lambazare": "lambazar",
    "lambazarei": "lambazar",
    "lambazareis": "lambazar",
    "lambazarem": "lambazar",
    "lambazaremos": "lambazar",
    "lambazares": "lambazar",
    "lambazaria": "lambazar",
    "lambazariam": "lambazar",
    "lambazarias": "lambazar",
    "lambazarmo": "lambazar",
    "lambazarmos": "lambazar",
    "lambazará": "lambazar",
    "lambazarás": "lambazar",
    "lambazarão": "lambazar",
    "lambazaríamos": "lambazar",
    "lambazaríeis": "lambazar",
    "lambazas": "lambazar",
    "lambazasse": "lambazar",
    "lambazassem": "lambazar",
    "lambazasses": "lambazar",
    "lambazaste": "lambazar",
    "lambazastes": "lambazar",
    "lambazava": "lambazar",
    "lambazavam": "lambazar",
    "lambazavas": "lambazar",
    "lambaze": "lambazar",
    "lambazei": "lambazar",
    "lambazeis": "lambazar",
    "lambazem": "lambazar",
    "lambazemo": "lambazar",
    "lambazemos": "lambazar",
    "lambazes": "lambazar",
    "lambazo": "lambazar",
    "lambazou": "lambazar",
    "lambazá": "lambazar",
    "lambazámo": "lambazar",
    "lambazámos": "lambazar",
    "lambazáramo": "lambazar",
    "lambazáramos": "lambazar",
    "lambazárei": "lambazar",
    "lambazáreis": "lambazar",
    "lambazásseis": "lambazar",
    "lambazássemos": "lambazar",
    "lambazávamo": "lambazar",
    "lambazávamos": "lambazar",
    "lambazávei": "lambazar",
    "lambazáveis": "lambazar",
    "lambdacismos": "lambdacismo",
    "lambdas": "lambda",
    "lambdóides": "lambdóide",
    "lambe": "lamber",
    "lambeada": "lambear",
    "lambeadas": "lambear",
    "lambeado": "lambear",
    "lambeados": "lambear",
    "lambeai": "lambear",
    "lambeais": "lambear",
    "lambeamo": "lambear",
    "lambeamos": "lambear",
    "lambeando": "lambear",
    "lambeara": "lambear",
    "lambearam": "lambear",
    "lambearas": "lambear",
    "lambearde": "lambear",
    "lambeardes": "lambear",
    "lambeare": "lambear",
    "lambearei": "lambear",
    "lambeareis": "lambear",
    "lambearem": "lambear",
    "lambearemos": "lambear",
    "lambeares": "lambear",
    "lambearia": "lambear",
    "lambeariam": "lambear",
    "lambearias": "lambear",
    "lambearmo": "lambear",
    "lambearmos": "lambear",
    "lambeará": "lambear",
    "lambearás": "lambear",
    "lambearão": "lambear",
    "lambearíamos": "lambear",
    "lambearíeis": "lambear",
    "lambeasse": "lambear",
    "lambeassem": "lambear",
    "lambeasses": "lambear",
    "lambeaste": "lambear",
    "lambeastes": "lambear",
    "lambeava": "lambear",
    "lambeavam": "lambear",
    "lambeavas": "lambear",
    "lambedelas": "lambedela",
    "lambedora": "lambedor",
    "lambedoras": "lambedor",
    "lambedores": "lambedor",
    "lambeduras": "lambedura",
    "lambeei": "lambear",
    "lambeeis": "lambear",
    "lambeemo": "lambear",
    "lambeemos": "lambear",
    "lambefes": "lambefe",
    "lambei": "lamber",
    "lambeia": "lambear",
    "lambeiam": "lambear",
    "lambeias": "lambear",
    "lambeie": "lambear",
    "lambeiem": "lambear",
    "lambeies": "lambear",
    "lambeio": "lambear",
    "lambeira": "lambeiro",
    "lambeiras": "lambeiro",
    "lambeiros": "lambeiro",
    "lambeis": "lamber",
    "lambeles": "lambel",
    "lambem": "lamber",
    "lambemo": "lamber",
    "lambemos": "lamber",
    "lambendo": "lamber",
    "lambeou": "lambear",
    "lambera": "lamber",
    "lamberam": "lamber",
    "lamberas": "lamber",
    "lamberde": "lamber",
    "lamberdes": "lamber",
    "lambere": "lamber",
    "lamberei": "lamber",
    "lambereis": "lamber",
    "lamberem": "lamber",
    "lamberemos": "lamber",
    "lamberes": "lamber",
    "lamberia": "lamber",
    "lamberiam": "lamber",
    "lamberias": "lamber",
    "lambermo": "lamber",
    "lambermos": "lamber",
    "lamberts": "lambert",
    "lamberá": "lamber",
    "lamberás": "lamber",
    "lamberão": "lamber",
    "lamberíamos": "lamber",
    "lamberíeis": "lamber",
    "lambes": "lamber",
    "lambesse": "lamber",
    "lambessem": "lamber",
    "lambesses": "lamber",
    "lambeste": "lamber",
    "lambestes": "lamber",
    "lambetas": "lambeta",
    "lambeu": "lamber",
    "lambeá": "lambear",
    "lambeámo": "lambear",
    "lambeámos": "lambear",
    "lambeáramo": "lambear",
    "lambeáramos": "lambear",
    "lambeárei": "lambear",
    "lambeáreis": "lambear",
    "lambeásseis": "lambear",
    "lambeássemos": "lambear",
    "lambeávamo": "lambear",
    "lambeávamos": "lambear",
    "lambeávei": "lambear",
    "lambeáveis": "lambear",
    "lambi": "lamber",
    "lambia": "lamber",
    "lambiam": "lamber",
    "lambias": "lamber",
    "lambida": "lambido",
    "lambidas": "lambido",
    "lambidelas": "lambidela",
    "lambido": "lamber",
    "lambidos": "lambido",
    "lambisca": "lambiscar",
    "lambiscada": "lambiscar",
    "lambiscadas": "lambiscar",
    "lambiscado": "lambiscar",
    "lambiscados": "lambiscar",
    "lambiscai": "lambiscar",
    "lambiscais": "lambiscar",
    "lambiscam": "lambiscar",
    "lambiscamo": "lambiscar",
    "lambiscamos": "lambiscar",
    "lambiscando": "lambiscar",
    "lambiscara": "lambiscar",
    "lambiscaram": "lambiscar",
    "lambiscaras": "lambiscar",
    "lambiscarde": "lambiscar",
    "lambiscardes": "lambiscar",
    "lambiscare": "lambiscar",
    "lambiscarei": "lambiscar",
    "lambiscareis": "lambiscar",
    "lambiscarem": "lambiscar",
    "lambiscaremos": "lambiscar",
    "lambiscares": "lambiscar",
    "lambiscaria": "lambiscar",
    "lambiscariam": "lambiscar",
    "lambiscarias": "lambiscar",
    "lambiscarmo": "lambiscar",
    "lambiscarmos": "lambiscar",
    "lambiscará": "lambiscar",
    "lambiscarás": "lambiscar",
    "lambiscarão": "lambiscar",
    "lambiscaríamos": "lambiscar",
    "lambiscaríeis": "lambiscar",
    "lambiscas": "lambiscar",
    "lambiscasse": "lambiscar",
    "lambiscassem": "lambiscar",
    "lambiscasses": "lambiscar",
    "lambiscaste": "lambiscar",
    "lambiscastes": "lambiscar",
    "lambiscava": "lambiscar",
    "lambiscavam": "lambiscar",
    "lambiscavas": "lambiscar",
    "lambisco": "lambiscar",
    "lambiscos": "lambisco",
    "lambiscou": "lambiscar",
    "lambiscá": "lambiscar",
    "lambiscámo": "lambiscar",
    "lambiscámos": "lambiscar",
    "lambiscáramo": "lambiscar",
    "lambiscáramos": "lambiscar",
    "lambiscárei": "lambiscar",
    "lambiscáreis": "lambiscar",
    "lambiscásseis": "lambiscar",
    "lambiscássemos": "lambiscar",
    "lambiscávamo": "lambiscar",
    "lambiscávamos": "lambiscar",
    "lambiscávei": "lambiscar",
    "lambiscáveis": "lambiscar",
    "lambisgonhices": "lambisgonhice",
    "lambisgóias": "lambisgóia",
    "lambisque": "lambiscar",
    "lambisquei": "lambiscar",
    "lambisqueira": "lambisqueiro",
    "lambisqueiras": "lambisqueiro",
    "lambisqueiros": "lambisqueiro",
    "lambisqueis": "lambiscar",
    "lambisquem": "lambiscar",
    "lambisquemo": "lambiscar",
    "lambisquemos": "lambiscar",
    "lambisques": "lambiscar",
    "lambo": "lamber",
    "lambona": "lambão",
    "lambonas": "lambão",
    "lambonazinha": "lambão",
    "lambonazinhas": "lambão",
    "lambonazita": "lambão",
    "lambonazitas": "lambão",
    "lambrequins": "lambrequim",
    "lambretas": "lambreta",
    "lambrins": "lambrim",
    "lambris": "lambril",
    "lambriza": "lambrizar",
    "lambrizada": "lambrizar",
    "lambrizadas": "lambrizar",
    "lambrizado": "lambrizar",
    "lambrizados": "lambrizar",
    "lambrizai": "lambrizar",
    "lambrizais": "lambrizar",
    "lambrizam": "lambrizar",
    "lambrizamo": "lambrizar",
    "lambrizamos": "lambrizar",
    "lambrizando": "lambrizar",
    "lambrizara": "lambrizar",
    "lambrizaram": "lambrizar",
    "lambrizaras": "lambrizar",
    "lambrizarde": "lambrizar",
    "lambrizardes": "lambrizar",
    "lambrizare": "lambrizar",
    "lambrizarei": "lambrizar",
    "lambrizareis": "lambrizar",
    "lambrizarem": "lambrizar",
    "lambrizaremos": "lambrizar",
    "lambrizares": "lambrizar",
    "lambrizaria": "lambrizar",
    "lambrizariam": "lambrizar",
    "lambrizarias": "lambrizar",
    "lambrizarmo": "lambrizar",
    "lambrizarmos": "lambrizar",
    "lambrizará": "lambrizar",
    "lambrizarás": "lambrizar",
    "lambrizarão": "lambrizar",
    "lambrizaríamos": "lambrizar",
    "lambrizaríeis": "lambrizar",
    "lambrizas": "lambrizar",
    "lambrizasse": "lambrizar",
    "lambrizassem": "lambrizar",
    "lambrizasses": "lambrizar",
    "lambrizaste": "lambrizar",
    "lambrizastes": "lambrizar",
    "lambrizava": "lambrizar",
    "lambrizavam": "lambrizar",
    "lambrizavas": "lambrizar",
    "lambrize": "lambrizar",
    "lambrizei": "lambrizar",
    "lambrizeis": "lambrizar",
    "lambrizem": "lambrizar",
    "lambrizemo": "lambrizar",
    "lambrizemos": "lambrizar",
    "lambrizes": "lambrizar",
    "lambrizo": "lambrizar",
    "lambrizou": "lambrizar",
    "lambrizá": "lambrizar",
    "lambrizámo": "lambrizar",
    "lambrizámos": "lambrizar",
    "lambrizáramo": "lambrizar",
    "lambrizáramos": "lambrizar",
    "lambrizárei": "lambrizar",
    "lambrizáreis": "lambrizar",
    "lambrizásseis": "lambrizar",
    "lambrizássemos": "lambrizar",
    "lambrizávamo": "lambrizar",
    "lambrizávamos": "lambrizar",
    "lambrizávei": "lambrizar",
    "lambrizáveis": "lambrizar",
    "lambuce": "lambuçar",
    "lambucei": "lambuçar",
    "lambuceis": "lambuçar",
    "lambucem": "lambuçar",
    "lambucemo": "lambuçar",
    "lambucemos": "lambuçar",
    "lambuces": "lambuçar",
    "lambugens": "lambugem",
    "lambuja": "lambujar",
    "lambujada": "lambujar",
    "lambujadas": "lambujar",
    "lambujado": "lambujar",
    "lambujados": "lambujar",
    "lambujai": "lambujar",
    "lambujais": "lambujar",
    "lambujam": "lambujar",
    "lambujamo": "lambujar",
    "lambujamos": "lambujar",
    "lambujando": "lambujar",
    "lambujara": "lambujar",
    "lambujaram": "lambujar",
    "lambujaras": "lambujar",
    "lambujardes": "lambujar",
    "lambujarei": "lambujar",
    "lambujareis": "lambujar",
    "lambujarem": "lambujar",
    "lambujaremos": "lambujar",
    "lambujares": "lambujar",
    "lambujaria": "lambujar",
    "lambujariam": "lambujar",
    "lambujarias": "lambujar",
    "lambujarmo": "lambujar",
    "lambujarmos": "lambujar",
    "lambujará": "lambujar",
    "lambujarás": "lambujar",
    "lambujarão": "lambujar",
    "lambujaríamos": "lambujar",
    "lambujaríeis": "lambujar",
    "lambujas": "lambujar",
    "lambujasse": "lambujar",
    "lambujassem": "lambujar",
    "lambujasses": "lambujar",
    "lambujaste": "lambujar",
    "lambujastes": "lambujar",
    "lambujava": "lambujar",
    "lambujavam": "lambujar",
    "lambujavas": "lambujar",
    "lambuje": "lambujar",
    "lambujei": "lambujar",
    "lambujeira": "lambujeiro",
    "lambujeiras": "lambujeiro",
    "lambujeiros": "lambujeiro",
    "lambujeis": "lambujar",
    "lambujem": "lambujar",
    "lambujemo": "lambujar",
    "lambujemos": "lambujar",
    "lambujes": "lambujar",
    "lambujinhas": "lambujinha",
    "lambujo": "lambujar",
    "lambujou": "lambujar",
    "lambujámo": "lambujar",
    "lambujámos": "lambujar",
    "lambujáramo": "lambujar",
    "lambujáramos": "lambujar",
    "lambujáreis": "lambujar",
    "lambujásseis": "lambujar",
    "lambujássemos": "lambujar",
    "lambujávamo": "lambujar",
    "lambujávamos": "lambujar",
    "lambujáveis": "lambujar",
    "lambuza": "lambuzar",
    "lambuzada": "lambuzar",
    "lambuzadas": "lambuzar",
    "lambuzadelas": "lambuzadela",
    "lambuzado": "lambuzar",
    "lambuzados": "lambuzar",
    "lambuzai": "lambuzar",
    "lambuzais": "lambuzar",
    "lambuzam": "lambuzar",
    "lambuzamo": "lambuzar",
    "lambuzamos": "lambuzar",
    "lambuzando": "lambuzar",
    "lambuzara": "lambuzar",
    "lambuzaram": "lambuzar",
    "lambuzaras": "lambuzar",
    "lambuzarde": "lambuzar",
    "lambuzardes": "lambuzar",
    "lambuzare": "lambuzar",
    "lambuzarei": "lambuzar",
    "lambuzareis": "lambuzar",
    "lambuzarem": "lambuzar",
    "lambuzaremos": "lambuzar",
    "lambuzares": "lambuzar",
    "lambuzaria": "lambuzar",
    "lambuzariam": "lambuzar",
    "lambuzarias": "lambuzar",
    "lambuzarmo": "lambuzar",
    "lambuzarmos": "lambuzar",
    "lambuzará": "lambuzar",
    "lambuzarás": "lambuzar",
    "lambuzarão": "lambuzar",
    "lambuzaríamos": "lambuzar",
    "lambuzaríeis": "lambuzar",
    "lambuzas": "lambuzar",
    "lambuzasse": "lambuzar",
    "lambuzassem": "lambuzar",
    "lambuzasses": "lambuzar",
    "lambuzaste": "lambuzar",
    "lambuzastes": "lambuzar",
    "lambuzava": "lambuzar",
    "lambuzavam": "lambuzar",
    "lambuzavas": "lambuzar",
    "lambuze": "lambuzar",
    "lambuzei": "lambuzar",
    "lambuzeis": "lambuzar",
    "lambuzem": "lambuzar",
    "lambuzemo": "lambuzar",
    "lambuzemos": "lambuzar",
    "lambuzes": "lambuzar",
    "lambuzo": "lambuzar",
    "lambuzou": "lambuzar",
    "lambuzá": "lambuzar",
    "lambuzámo": "lambuzar",
    "lambuzámos": "lambuzar",
    "lambuzáramo": "lambuzar",
    "lambuzáramos": "lambuzar",
    "lambuzárei": "lambuzar",
    "lambuzáreis": "lambuzar",
    "lambuzásseis": "lambuzar",
    "lambuzássemos": "lambuzar",
    "lambuzávamo": "lambuzar",
    "lambuzávamos": "lambuzar",
    "lambuzávei": "lambuzar",
    "lambuzáveis": "lambuzar",
    "lambuça": "lambuçar",
    "lambuçada": "lambuçar",
    "lambuçadas": "lambuçar",
    "lambuçadelas": "lambuçadela",
    "lambuçado": "lambuçar",
    "lambuçados": "lambuçar",
    "lambuçai": "lambuçar",
    "lambuçais": "lambuçar",
    "lambuçam": "lambuçar",
    "lambuçamo": "lambuçar",
    "lambuçamos": "lambuçar",
    "lambuçando": "lambuçar",
    "lambuçara": "lambuçar",
    "lambuçaram": "lambuçar",
    "lambuçaras": "lambuçar",
    "lambuçardes": "lambuçar",
    "lambuçarei": "lambuçar",
    "lambuçareis": "lambuçar",
    "lambuçarem": "lambuçar",
    "lambuçaremos": "lambuçar",
    "lambuçares": "lambuçar",
    "lambuçaria": "lambuçar",
    "lambuçariam": "lambuçar",
    "lambuçarias": "lambuçar",
    "lambuçarmo": "lambuçar",
    "lambuçarmos": "lambuçar",
    "lambuçará": "lambuçar",
    "lambuçarás": "lambuçar",
    "lambuçarão": "lambuçar",
    "lambuçaríamos": "lambuçar",
    "lambuçaríeis": "lambuçar",
    "lambuças": "lambuçar",
    "lambuçasse": "lambuçar",
    "lambuçassem": "lambuçar",
    "lambuçasses": "lambuçar",
    "lambuçaste": "lambuçar",
    "lambuçastes": "lambuçar",
    "lambuçava": "lambuçar",
    "lambuçavam": "lambuçar",
    "lambuçavas": "lambuçar",
    "lambuço": "lambuçar",
    "lambuçou": "lambuçar",
    "lambuçámo": "lambuçar",
    "lambuçámos": "lambuçar",
    "lambuçáramo": "lambuçar",
    "lambuçáramos": "lambuçar",
    "lambuçáreis": "lambuçar",
    "lambuçásseis": "lambuçar",
    "lambuçássemos": "lambuçar",
    "lambuçávamo": "lambuçar",
    "lambuçávamos": "lambuçar",
    "lambuçáveis": "lambuçar",
    "lambãozinho": "lambão",
    "lambãozito": "lambão",
    "lambéis": "lambel",
    "lambê": "lamber",
    "lambêramo": "lamber",
    "lambêramos": "lamber",
    "lambêrei": "lamber",
    "lambêreis": "lamber",
    "lambêsseis": "lamber",
    "lambêssemos": "lamber",
    "lambíamo": "lamber",
    "lambíamos": "lamber",
    "lambíei": "lamber",
    "lambíeis": "lamber",
    "lambíveis": "lambível",
    "lambões": "lambão",
    "lambõezinhos": "lambão",
    "lambõezitos": "lambão",
    "lamecenses": "lamecense",
    "lamecha": "lamechar",
    "lamechada": "lamechar",
    "lamechadas": "lamechar",
    "lamechado": "lamechar",
    "lamechados": "lamechar",
    "lamechai": "lamechar",
    "lamechais": "lamechar",
    "lamecham": "lamechar",
    "lamechamo": "lamechar",
    "lamechamos": "lamechar",
    "lamechando": "lamechar",
    "lamechara": "lamechar",
    "lamecharam": "lamechar",
    "lamecharas": "lamechar",
    "lamechardes": "lamechar",
    "lamecharei": "lamechar",
    "lamechareis": "lamechar",
    "lamecharem": "lamechar",
    "lamecharemos": "lamechar",
    "lamechares": "lamechar",
    "lamecharia": "lamechar",
    "lamechariam": "lamechar",
    "lamecharias": "lamecharia",
    "lamecharmo": "lamechar",
    "lamecharmos": "lamechar",
    "lamechará": "lamechar",
    "lamecharás": "lamechar",
    "lamecharão": "lamechar",
    "lamecharíamos": "lamechar",
    "lamecharíeis": "lamechar",
    "lamechas": "lamechar",
    "lamechasse": "lamechar",
    "lamechassem": "lamechar",
    "lamechasses": "lamechar",
    "lamechaste": "lamechar",
    "lamechastes": "lamechar",
    "lamechava": "lamechar",
    "lamechavam": "lamechar",
    "lamechavas": "lamechar",
    "lamechazinha": "lamecha",
    "lamechazinhas": "lamecha",
    "lamechazinho": "lamecha",
    "lamechazinhos": "lamecha",
    "lamechazita": "lamecha",
    "lamechazitas": "lamecha",
    "lamechazito": "lamecha",
    "lamechazitos": "lamecha",
    "lameche": "lamechar",
    "lamechei": "lamechar",
    "lamecheis": "lamechar",
    "lamechem": "lamechar",
    "lamechemo": "lamechar",
    "lamechemos": "lamechar",
    "lameches": "lamechar",
    "lamechices": "lamechice",
    "lamechismos": "lamechismo",
    "lamecho": "lamechar",
    "lamechou": "lamechar",
    "lamechámo": "lamechar",
    "lamechámos": "lamechar",
    "lamecháramo": "lamechar",
    "lamecháramos": "lamechar",
    "lamecháreis": "lamechar",
    "lamechásseis": "lamechar",
    "lamechássemos": "lamechar",
    "lamechávamo": "lamechar",
    "lamechávamos": "lamechar",
    "lamecháveis": "lamechar",
    "lamegos": "lamego",
    "lamegueiros": "lamegueiro",
    "lameirais": "lameiral",
    "lameiras": "lameira",
    "lameirenta": "lameirento",
    "lameirentas": "lameirento",
    "lameirentos": "lameirento",
    "lameirinhas": "lameirinha",
    "lameiros": "lameiro",
    "lamela": "lamelar",
    "lamelada": "lamelar",
    "lameladas": "lamelar",
    "lamelado": "lamelar",
    "lamelados": "lamelar",
    "lamelai": "lamelar",
    "lamelais": "lamelar",
    "lamelam": "lamelar",
    "lamelamo": "lamelar",
    "lamelamos": "lamelar",
    "lamelando": "lamelar",
    "lamelara": "lamelar",
    "lamelaram": "lamelar",
    "lamelaras": "lamelar",
    "lamelarde": "lamelar",
    "lamelardes": "lamelar",
    "lamelare": "lamelar",
    "lamelarei": "lamelar",
    "lamelareis": "lamelar",
    "lamelarem": "lamelar",
    "lamelaremos": "lamelar",
    "lamelares": "lamelar",
    "lamelaria": "lamelar",
    "lamelariam": "lamelar",
    "lamelarias": "lamelar",
    "lamelarmo": "lamelar",
    "lamelarmos": "lamelar",
    "lamelará": "lamelar",
    "lamelarás": "lamelar",
    "lamelarão": "lamelar",
    "lamelaríamos": "lamelar",
    "lamelaríeis": "lamelar",
    "lamelas": "lamelar",
    "lamelasse": "lamelar",
    "lamelassem": "lamelar",
    "lamelasses": "lamelar",
    "lamelaste": "lamelar",
    "lamelastes": "lamelar",
    "lamelava": "lamelar",
    "lamelavam": "lamelar",
    "lamelavas": "lamelar",
    "lamelações": "lamelação",
    "lamele": "lamelar",
    "lamelei": "lamelar",
    "lameleis": "lamelar",
    "lamelem": "lamelar",
    "lamelemo": "lamelar",
    "lamelemos": "lamelar",
    "lameles": "lamelar",
    "lamelibrânquia": "lamelibrânquio",
    "lamelibrânquias": "lamelibrânquio",
    "lamelibrânquios": "lamelibrânquio",
    "lamelicórnea": "lamelicórneo",
    "lamelicórneas": "lamelicórneo",
    "lamelicórneos": "lamelicórneo",
    "lameliformes": "lameliforme",
    "lamelirrostra": "lamelirrostro",
    "lamelirrostras": "lamelirrostro",
    "lamelirrostros": "lamelirrostro",
    "lamelo": "lamelar",
    "lamelosa": "lameloso",
    "lamelosas": "lameloso",
    "lamelosos": "lameloso",
    "lamelou": "lamelar",
    "lamelá": "lamelar",
    "lamelámo": "lamelar",
    "lamelámos": "lamelar",
    "lameláramo": "lamelar",
    "lameláramos": "lamelar",
    "lamelárei": "lamelar",
    "lameláreis": "lamelar",
    "lamelásseis": "lamelar",
    "lamelássemos": "lamelar",
    "lamelávamo": "lamelar",
    "lamelávamos": "lamelar",
    "lamelávei": "lamelar",
    "lameláveis": "lamelável",
    "lamelífera": "lamelífero",
    "lamelíferas": "lamelífero",
    "lamelíferos": "lamelífero",
    "lamelípedes": "lamelípede",
    "lamenta": "lamentar",
    "lamentada": "lamentar",
    "lamentadas": "lamentar",
    "lamentado": "lamentar",
    "lamentadora": "lamentador",
    "lamentadoras": "lamentador",
    "lamentadores": "lamentador",
    "lamentados": "lamentar",
    "lamentai": "lamentar",
    "lamentais": "lamentar",
    "lamentam": "lamentar",
    "lamentamo": "lamentar",
    "lamentamos": "lamentar",
    "lamentando": "lamentar",
    "lamentara": "lamentar",
    "lamentaram": "lamentar",
    "lamentaras": "lamentar",
    "lamentarde": "lamentar",
    "lamentardes": "lamentar",
    "lamentare": "lamentar",
    "lamentarei": "lamentar",
    "lamentareis": "lamentar",
    "lamentarem": "lamentar",
    "lamentaremos": "lamentar",
    "lamentares": "lamentar",
    "lamentaria": "lamentar",
    "lamentariam": "lamentar",
    "lamentarias": "lamentar",
    "lamentarmo": "lamentar",
    "lamentarmos": "lamentar",
    "lamentará": "lamentar",
    "lamentarás": "lamentar",
    "lamentarão": "lamentar",
    "lamentaríamos": "lamentar",
    "lamentaríeis": "lamentar",
    "lamentas": "lamentar",
    "lamentasse": "lamentar",
    "lamentassem": "lamentar",
    "lamentasses": "lamentar",
    "lamentaste": "lamentar",
    "lamentastes": "lamentar",
    "lamentava": "lamentar",
    "lamentavam": "lamentar",
    "lamentavas": "lamentar",
    "lamentações": "lamentação",
    "lamente": "lamentar",
    "lamentei": "lamentar",
    "lamenteis": "lamentar",
    "lamentem": "lamentar",
    "lamentemo": "lamentar",
    "lamentemos": "lamentar",
    "lamentes": "lamentar",
    "lamento": "lamentar",
    "lamentos": "lamento",
    "lamentosa": "lamentoso",
    "lamentosas": "lamentoso",
    "lamentosos": "lamentoso",
    "lamentou": "lamentar",
    "lamentá": "lamentar",
    "lamentámo": "lamentar",
    "lamentámos": "lamentar",
    "lamentáramo": "lamentar",
    "lamentáramos": "lamentar",
    "lamentárei": "lamentar",
    "lamentáreis": "lamentar",
    "lamentásseis": "lamentar",
    "lamentássemos": "lamentar",
    "lamentávamo": "lamentar",
    "lamentávamos": "lamentar",
    "lamentávei": "lamentar",
    "lamentáveis": "lamentável",
    "lamieiras": "lamieira",
    "lamieiros": "lamieiro",
    "lamina": "laminar",
    "laminada": "laminar",
    "laminadas": "laminar",
    "laminado": "laminar",
    "laminadora": "laminador",
    "laminadoras": "laminador",
    "laminadores": "laminador",
    "laminados": "laminar",
    "laminagens": "laminagem",
    "laminai": "laminar",
    "laminais": "laminar",
    "laminam": "laminar",
    "laminamo": "laminar",
    "laminamos": "laminar",
    "laminando": "laminar",
    "laminara": "laminar",
    "laminaram": "laminar",
    "laminaras": "laminar",
    "laminarde": "laminar",
    "laminardes": "laminar",
    "laminare": "laminar",
    "laminarei": "laminar",
    "laminareis": "laminar",
    "laminarem": "laminar",
    "laminaremos": "laminar",
    "laminares": "laminar",
    "laminaria": "laminar",
    "laminariam": "laminar",
    "laminarias": "laminar",
    "laminariáceas": "laminariácea",
    "laminarmo": "laminar",
    "laminarmos": "laminar",
    "laminará": "laminar",
    "laminarás": "laminar",
    "laminarão": "laminar",
    "laminaríamos": "laminar",
    "laminaríeis": "laminar",
    "laminas": "laminar",
    "laminasse": "laminar",
    "laminassem": "laminar",
    "laminasses": "laminar",
    "laminaste": "laminar",
    "laminastes": "laminar",
    "laminava": "laminar",
    "laminavam": "laminar",
    "laminavas": "laminar",
    "laminações": "laminação",
    "lamine": "laminar",
    "laminei": "laminar",
    "lamineis": "laminar",
    "laminem": "laminar",
    "laminemo": "laminar",
    "laminemos": "laminar",
    "lamines": "laminar",
    "lamino": "laminar",
    "laminosa": "laminoso",
    "laminosas": "laminoso",
    "laminosos": "laminoso",
    "laminou": "laminar",
    "laminá": "laminar",
    "laminámo": "laminar",
    "laminámos": "laminar",
    "lamináramo": "laminar",
    "lamináramos": "laminar",
    "laminárei": "laminar",
    "lamináreis": "laminar",
    "laminárias": "laminária",
    "laminásseis": "laminar",
    "laminássemos": "laminar",
    "laminávamo": "laminar",
    "laminávamos": "laminar",
    "laminávei": "laminar",
    "lamináveis": "laminável",
    "lamirezinho": "lamiré",
    "lamirezinhos": "lamiré",
    "lamirezito": "lamiré",
    "lamirezitos": "lamiré",
    "lamirés": "lamiré",
    "lamiáceas": "lamiácea",
    "lamnídeos": "lamnídeo",
    "lamojas": "lamoja",
    "lamosa": "lamoso",
    "lamosas": "lamoso",
    "lamosos": "lamoso",
    "lampa": "lampo",
    "lampadeira": "lampadeiro",
    "lampadeiras": "lampadeiro",
    "lampadeiros": "lampadeiro",
    "lampadeja": "lampadejar",
    "lampadejada": "lampadejar",
    "lampadejadas": "lampadejar",
    "lampadejado": "lampadejar",
    "lampadejados": "lampadejar",
    "lampadejai": "lampadejar",
    "lampadejais": "lampadejar",
    "lampadejam": "lampadejar",
    "lampadejamo": "lampadejar",
    "lampadejamos": "lampadejar",
    "lampadejando": "lampadejar",
    "lampadejara": "lampadejar",
    "lampadejaram": "lampadejar",
    "lampadejaras": "lampadejar",
    "lampadejardes": "lampadejar",
    "lampadejarei": "lampadejar",
    "lampadejareis": "lampadejar",
    "lampadejarem": "lampadejar",
    "lampadejaremos": "lampadejar",
    "lampadejares": "lampadejar",
    "lampadejaria": "lampadejar",
    "lampadejariam": "lampadejar",
    "lampadejarias": "lampadejar",
    "lampadejarmo": "lampadejar",
    "lampadejarmos": "lampadejar",
    "lampadejará": "lampadejar",
    "lampadejarás": "lampadejar",
    "lampadejarão": "lampadejar",
    "lampadejaríamos": "lampadejar",
    "lampadejaríeis": "lampadejar",
    "lampadejas": "lampadejar",
    "lampadejasse": "lampadejar",
    "lampadejassem": "lampadejar",
    "lampadejasses": "lampadejar",
    "lampadejaste": "lampadejar",
    "lampadejastes": "lampadejar",
    "lampadejava": "lampadejar",
    "lampadejavam": "lampadejar",
    "lampadejavas": "lampadejar",
    "lampadeje": "lampadejar",
    "lampadejei": "lampadejar",
    "lampadejeis": "lampadejar",
    "lampadejem": "lampadejar",
    "lampadejemo": "lampadejar",
    "lampadejemos": "lampadejar",
    "lampadejes": "lampadejar",
    "lampadejo": "lampadejar",
    "lampadejou": "lampadejar",
    "lampadejámo": "lampadejar",
    "lampadejámos": "lampadejar",
    "lampadejáramo": "lampadejar",
    "lampadejáramos": "lampadejar",
    "lampadejáreis": "lampadejar",
    "lampadejásseis": "lampadejar",
    "lampadejássemos": "lampadejar",
    "lampadejávamo": "lampadejar",
    "lampadejávamos": "lampadejar",
    "lampadejáveis": "lampadejar",
    "lampadodromias": "lampadodromia",
    "lampadomancias": "lampadomancia",
    "lampadomantes": "lampadomante",
    "lampados": "lampado",
    "lampadários": "lampadário",
    "lampanas": "lampana",
    "lampareja": "lamparejar",
    "lamparejada": "lamparejar",
    "lamparejadas": "lamparejar",
    "lamparejado": "lamparejar",
    "lamparejados": "lamparejar",
    "lamparejai": "lamparejar",
    "lamparejais": "lamparejar",
    "lamparejam": "lamparejar",
    "lamparejamo": "lamparejar",
    "lamparejamos": "lamparejar",
    "lamparejando": "lamparejar",
    "lamparejara": "lamparejar",
    "lamparejaram": "lamparejar",
    "lamparejaras": "lamparejar",
    "lamparejardes": "lamparejar",
    "lamparejarei": "lamparejar",
    "lamparejareis": "lamparejar",
    "lamparejarem": "lamparejar",
    "lamparejaremos": "lamparejar",
    "lamparejares": "lamparejar",
    "lamparejaria": "lamparejar",
    "lamparejariam": "lamparejar",
    "lamparejarias": "lamparejar",
    "lamparejarmo": "lamparejar",
    "lamparejarmos": "lamparejar",
    "lamparejará": "lamparejar",
    "lamparejarás": "lamparejar",
    "lamparejarão": "lamparejar",
    "lamparejaríamos": "lamparejar",
    "lamparejaríeis": "lamparejar",
    "lamparejas": "lamparejar",
    "lamparejasse": "lamparejar",
    "lamparejassem": "lamparejar",
    "lamparejasses": "lamparejar",
    "lamparejaste": "lamparejar",
    "lamparejastes": "lamparejar",
    "lamparejava": "lamparejar",
    "lamparejavam": "lamparejar",
    "lamparejavas": "lamparejar",
    "lampareje": "lamparejar",
    "lamparejei": "lamparejar",
    "lamparejeis": "lamparejar",
    "lamparejem": "lamparejar",
    "lamparejemo": "lamparejar",
    "lamparejemos": "lamparejar",
    "lamparejes": "lamparejar",
    "lamparejo": "lamparejar",
    "lamparejou": "lamparejar",
    "lamparejámo": "lamparejar",
    "lamparejámos": "lamparejar",
    "lamparejáramo": "lamparejar",
    "lamparejáramos": "lamparejar",
    "lamparejáreis": "lamparejar",
    "lamparejásseis": "lamparejar",
    "lamparejássemos": "lamparejar",
    "lamparejávamo": "lamparejar",
    "lamparejávamos": "lamparejar",
    "lamparejáveis": "lamparejar",
    "lamparinas": "lamparina",
    "lamparões": "lamparão",
    "lampas": "lampo",
    "lampascópios": "lampascópio",
    "lampassada": "lampassado",
    "lampassadas": "lampassado",
    "lampassados": "lampassado",
    "lampeira": "lampeiro",
    "lampeiras": "lampeiro",
    "lampeirazinha": "lampeiro",
    "lampeirazinhas": "lampeiro",
    "lampeirazita": "lampeiro",
    "lampeirazitas": "lampeiro",
    "lampeiros": "lampeiro",
    "lampeirozinho": "lampeiro",
    "lampeirozinhos": "lampeiro",
    "lampeirozito": "lampeiro",
    "lampeirozitos": "lampeiro",
    "lampeja": "lampejar",
    "lampejada": "lampejar",
    "lampejadas": "lampejar",
    "lampejado": "lampejar",
    "lampejados": "lampejar",
    "lampejai": "lampejar",
    "lampejais": "lampejar",
    "lampejam": "lampejar",
    "lampejamo": "lampejar",
    "lampejamos": "lampejar",
    "lampejando": "lampejar",
    "lampejantes": "lampejante",
    "lampejara": "lampejar",
    "lampejaram": "lampejar",
    "lampejaras": "lampejar",
    "lampejardes": "lampejar",
    "lampejarei": "lampejar",
    "lampejareis": "lampejar",
    "lampejarem": "lampejar",
    "lampejaremos": "lampejar",
    "lampejares": "lampejar",
    "lampejaria": "lampejar",
    "lampejariam": "lampejar",
    "lampejarias": "lampejar",
    "lampejarmo": "lampejar",
    "lampejarmos": "lampejar",
    "lampejará": "lampejar",
    "lampejarás": "lampejar",
    "lampejarão": "lampejar",
    "lampejaríamos": "lampejar",
    "lampejaríeis": "lampejar",
    "lampejas": "lampejar",
    "lampejasse": "lampejar",
    "lampejassem": "lampejar",
    "lampejasses": "lampejar",
    "lampejaste": "lampejar",
    "lampejastes": "lampejar",
    "lampejava": "lampejar",
    "lampejavam": "lampejar",
    "lampejavas": "lampejar",
    "lampeje": "lampejar",
    "lampejei": "lampejar",
    "lampejeis": "lampejar",
    "lampejem": "lampejar",
    "lampejemo": "lampejar",
    "lampejemos": "lampejar",
    "lampejes": "lampejar",
    "lampejo": "lampejar",
    "lampejos": "lampejo",
    "lampejou": "lampejar",
    "lampejámo": "lampejar",
    "lampejámos": "lampejar",
    "lampejáramo": "lampejar",
    "lampejáramos": "lampejar",
    "lampejáreis": "lampejar",
    "lampejásseis": "lampejar",
    "lampejássemos": "lampejar",
    "lampejávamo": "lampejar",
    "lampejávamos": "lampejar",
    "lampejáveis": "lampejar",
    "lampianistas": "lampianista",
    "lampinhos": "lampinho",
    "lampirídeos": "lampirídeo",
    "lampistas": "lampista",
    "lampiões": "lampião",
    "lampos": "lampo",
    "lampreada": "lamprear",
    "lampreadas": "lamprear",
    "lampreado": "lamprear",
    "lampreados": "lamprear",
    "lampreai": "lamprear",
    "lampreais": "lamprear",
    "lampreamo": "lamprear",
    "lampreamos": "lamprear",
    "lampreando": "lamprear",
    "lampreara": "lamprear",
    "lamprearam": "lamprear",
    "lamprearas": "lamprear",
    "lampreardes": "lamprear",
    "lamprearei": "lamprear",
    "lampreareis": "lamprear",
    "lamprearem": "lamprear",
    "lamprearemos": "lamprear",
    "lampreares": "lamprear",
    "lamprearia": "lamprear",
    "lampreariam": "lamprear",
    "lamprearias": "lamprear",
    "lamprearmo": "lamprear",
    "lamprearmos": "lamprear",
    "lampreará": "lamprear",
    "lamprearás": "lamprear",
    "lamprearão": "lamprear",
    "lamprearíamos": "lamprear",
    "lamprearíeis": "lamprear",
    "lampreasse": "lamprear",
    "lampreassem": "lamprear",
    "lampreasses": "lamprear",
    "lampreaste": "lamprear",
    "lampreastes": "lamprear",
    "lampreava": "lamprear",
    "lampreavam": "lamprear",
    "lampreavas": "lamprear",
    "lampreei": "lamprear",
    "lampreeiras": "lampreeira",
    "lampreeis": "lamprear",
    "lampreemo": "lamprear",
    "lampreemos": "lamprear",
    "lampreia": "lamprear",
    "lampreiam": "lamprear",
    "lampreias": "lampreia",
    "lampreie": "lamprear",
    "lampreiem": "lamprear",
    "lampreies": "lamprear",
    "lampreio": "lamprear",
    "lampreou": "lamprear",
    "lampreámo": "lamprear",
    "lampreámos": "lamprear",
    "lampreáramo": "lamprear",
    "lampreáramos": "lamprear",
    "lampreáreis": "lamprear",
    "lampreásseis": "lamprear",
    "lampreássemos": "lamprear",
    "lampreávamo": "lamprear",
    "lampreávamos": "lamprear",
    "lampreáveis": "lamprear",
    "lampridídeos": "lampridídeo",
    "lamprídidas": "lamprídida",
    "lamprófiros": "lamprófiro",
    "lamprómetros": "lamprómetro",
    "lampíridas": "lampírida",
    "lamuria": "lamuriar",
    "lamuriada": "lamuriar",
    "lamuriadas": "lamuriar",
    "lamuriado": "lamuriar",
    "lamuriadora": "lamuriador",
    "lamuriadoras": "lamuriador",
    "lamuriadores": "lamuriador",
    "lamuriados": "lamuriar",
    "lamuriai": "lamuriar",
    "lamuriais": "lamuriar",
    "lamuriam": "lamuriar",
    "lamuriamo": "lamuriar",
    "lamuriamos": "lamuriar",
    "lamuriando": "lamuriar",
    "lamuriantes": "lamuriante",
    "lamuriara": "lamuriar",
    "lamuriaram": "lamuriar",
    "lamuriaras": "lamuriar",
    "lamuriardes": "lamuriar",
    "lamuriarei": "lamuriar",
    "lamuriareis": "lamuriar",
    "lamuriarem": "lamuriar",
    "lamuriaremos": "lamuriar",
    "lamuriares": "lamuriar",
    "lamuriaria": "lamuriar",
    "lamuriariam": "lamuriar",
    "lamuriarias": "lamuriar",
    "lamuriarmo": "lamuriar",
    "lamuriarmos": "lamuriar",
    "lamuriará": "lamuriar",
    "lamuriarás": "lamuriar",
    "lamuriarão": "lamuriar",
    "lamuriaríamos": "lamuriar",
    "lamuriaríeis": "lamuriar",
    "lamurias": "lamuriar",
    "lamuriasse": "lamuriar",
    "lamuriassem": "lamuriar",
    "lamuriasses": "lamuriar",
    "lamuriaste": "lamuriar",
    "lamuriastes": "lamuriar",
    "lamuriava": "lamuriar",
    "lamuriavam": "lamuriar",
    "lamuriavas": "lamuriar",
    "lamurie": "lamuriar",
    "lamuriei": "lamuriar",
    "lamurieis": "lamuriar",
    "lamuriem": "lamuriar",
    "lamuriemo": "lamuriar",
    "lamuriemos": "lamuriar",
    "lamurienta": "lamuriento",
    "lamurientas": "lamuriento",
    "lamurientos": "lamuriento",
    "lamuries": "lamuriar",
    "lamurio": "lamuriar",
    "lamuriosa": "lamurioso",
    "lamuriosas": "lamurioso",
    "lamuriosos": "lamurioso",
    "lamuriou": "lamuriar",
    "lamuriámo": "lamuriar",
    "lamuriámos": "lamuriar",
    "lamuriáramo": "lamuriar",
    "lamuriáramos": "lamuriar",
    "lamuriáreis": "lamuriar",
    "lamuriásseis": "lamuriar",
    "lamuriássemos": "lamuriar",
    "lamuriávamo": "lamuriar",
    "lamuriávamos": "lamuriar",
    "lamuriáveis": "lamuriar",
    "lamínulas": "lamínula",
    "lamúrias": "lamúria",
    "lanadas": "lanada",
    "lanares": "lanar",
    "lance": "lançar",
    "lanceada": "lancear",
    "lanceadas": "lancear",
    "lanceado": "lancear",
    "lanceadora": "lanceador",
    "lanceadoras": "lanceador",
    "lanceadores": "lanceador",
    "lanceados": "lancear",
    "lanceai": "lancear",
    "lanceais": "lancear",
    "lanceamo": "lancear",
    "lanceamos": "lancear",
    "lanceando": "lancear",
    "lanceara": "lancear",
    "lancearam": "lancear",
    "lancearas": "lancear",
    "lancearde": "lancear",
    "lanceardes": "lancear",
    "lanceare": "lancear",
    "lancearei": "lancear",
    "lanceareis": "lancear",
    "lancearem": "lancear",
    "lancearemos": "lancear",
    "lanceares": "lancear",
    "lancearia": "lancear",
    "lanceariam": "lancear",
    "lancearias": "lancear",
    "lancearmo": "lancear",
    "lancearmos": "lancear",
    "lanceará": "lancear",
    "lancearás": "lancear",
    "lancearão": "lancear",
    "lancearíamos": "lancear",
    "lancearíeis": "lancear",
    "lanceasse": "lancear",
    "lanceassem": "lancear",
    "lanceasses": "lancear",
    "lanceaste": "lancear",
    "lanceastes": "lancear",
    "lanceava": "lancear",
    "lanceavam": "lancear",
    "lanceavas": "lancear",
    "lanceei": "lancear",
    "lanceeis": "lancear",
    "lanceemo": "lancear",
    "lanceemos": "lancear",
    "lancei": "lançar",
    "lanceia": "lancear",
    "lanceiam": "lancear",
    "lanceias": "lancear",
    "lanceie": "lancear",
    "lanceiem": "lancear",
    "lanceies": "lancear",
    "lanceio": "lancear",
    "lanceira": "lanceiro",
    "lanceiras": "lanceiro",
    "lanceiros": "lanceiro",
    "lanceis": "lançar",
    "lancem": "lançar",
    "lancemo": "lançar",
    "lancemos": "lançar",
    "lanceolada": "lanceolado",
    "lanceoladas": "lanceolado",
    "lanceolados": "lanceolado",
    "lanceolares": "lanceolar",
    "lanceou": "lancear",
    "lances": "lance",
    "lanceta": "lancetar",
    "lancetada": "lancetar",
    "lancetadas": "lancetar",
    "lancetado": "lancetar",
    "lancetados": "lancetar",
    "lancetai": "lancetar",
    "lancetais": "lancetar",
    "lancetam": "lancetar",
    "lancetamo": "lancetar",
    "lancetamos": "lancetar",
    "lancetando": "lancetar",
    "lancetara": "lancetar",
    "lancetaram": "lancetar",
    "lancetaras": "lancetar",
    "lancetarde": "lancetar",
    "lancetardes": "lancetar",
    "lancetare": "lancetar",
    "lancetarei": "lancetar",
    "lancetareis": "lancetar",
    "lancetarem": "lancetar",
    "lancetaremos": "lancetar",
    "lancetares": "lancetar",
    "lancetaria": "lancetar",
    "lancetariam": "lancetar",
    "lancetarias": "lancetar",
    "lancetarmo": "lancetar",
    "lancetarmos": "lancetar",
    "lancetará": "lancetar",
    "lancetarás": "lancetar",
    "lancetarão": "lancetar",
    "lancetaríamos": "lancetar",
    "lancetaríeis": "lancetar",
    "lancetas": "lancetar",
    "lancetasse": "lancetar",
    "lancetassem": "lancetar",
    "lancetasses": "lancetar",
    "lancetaste": "lancetar",
    "lancetastes": "lancetar",
    "lancetava": "lancetar",
    "lancetavam": "lancetar",
    "lancetavas": "lancetar",
    "lancete": "lancetar",
    "lancetei": "lancetar",
    "lanceteiras": "lanceteira",
    "lanceteis": "lancetar",
    "lancetem": "lancetar",
    "lancetemo": "lancetar",
    "lancetemos": "lancetar",
    "lancetes": "lancetar",
    "lanceto": "lancetar",
    "lancetou": "lancetar",
    "lancetá": "lancetar",
    "lancetámo": "lancetar",
    "lancetámos": "lancetar",
    "lancetáramo": "lancetar",
    "lancetáramos": "lancetar",
    "lancetárei": "lancetar",
    "lancetáreis": "lancetar",
    "lancetásseis": "lancetar",
    "lancetássemos": "lancetar",
    "lancetávamo": "lancetar",
    "lancetávamos": "lancetar",
    "lancetávei": "lancetar",
    "lancetáveis": "lancetável",
    "lanceá": "lancear",
    "lanceámo": "lancear",
    "lanceámos": "lancear",
    "lanceáramo": "lancear",
    "lanceáramos": "lancear",
    "lanceárei": "lancear",
    "lanceáreis": "lancear",
    "lanceásseis": "lancear",
    "lanceássemos": "lancear",
    "lanceávamo": "lancear",
    "lanceávamos": "lancear",
    "lanceávei": "lancear",
    "lanceáveis": "lancear",
    "lancha": "lanchar",
    "lanchada": "lanchar",
    "lanchadas": "lanchar",
    "lanchado": "lanchar",
    "lanchados": "lanchar",
    "lanchai": "lanchar",
    "lanchais": "lanchar",
    "lancham": "lanchar",
    "lanchamo": "lanchar",
    "lanchamos": "lanchar",
    "lanchando": "lanchar",
    "lanchara": "lanchar",
    "lancharam": "lanchar",
    "lancharas": "lanchar",
    "lancharde": "lanchar",
    "lanchardes": "lanchar",
    "lanchare": "lanchar",
    "lancharei": "lanchar",
    "lanchareis": "lanchar",
    "lancharem": "lanchar",
    "lancharemos": "lanchar",
    "lanchares": "lanchar",
    "lancharia": "lanchar",
    "lanchariam": "lanchar",
    "lancharias": "lanchar",
    "lancharmo": "lanchar",
    "lancharmos": "lanchar",
    "lanchará": "lanchar",
    "lancharás": "lanchar",
    "lancharão": "lanchar",
    "lancharíamos": "lanchar",
    "lancharíeis": "lanchar",
    "lanchas": "lanchar",
    "lanchasse": "lanchar",
    "lanchassem": "lanchar",
    "lanchasses": "lanchar",
    "lanchaste": "lanchar",
    "lanchastes": "lanchar",
    "lanchava": "lanchar",
    "lanchavam": "lanchar",
    "lanchavas": "lanchar",
    "lanche": "lanchar",
    "lanchei": "lanchar",
    "lancheira": "lancheiro",
    "lancheiras": "lancheiro",
    "lancheiros": "lancheiro",
    "lancheis": "lanchar",
    "lanchem": "lanchar",
    "lanchemo": "lanchar",
    "lanchemos": "lanchar",
    "lanches": "lanche",
    "lanchetas": "lancheta",
    "lancho": "lanchar",
    "lanchou": "lanchar",
    "lanchá": "lanchar",
    "lanchámo": "lanchar",
    "lanchámos": "lanchar",
    "lancháramo": "lanchar",
    "lancháramos": "lanchar",
    "lanchárei": "lanchar",
    "lancháreis": "lanchar",
    "lanchásseis": "lanchar",
    "lanchássemos": "lanchar",
    "lanchávamo": "lanchar",
    "lanchávamos": "lanchar",
    "lanchávei": "lanchar",
    "lancháveis": "lanchar",
    "lanchões": "lanchão",
    "lancina": "lancinar",
    "lancinada": "lancinar",
    "lancinadas": "lancinar",
    "lancinado": "lancinar",
    "lancinados": "lancinar",
    "lancinai": "lancinar",
    "lancinais": "lancinar",
    "lancinam": "lancinar",
    "lancinamo": "lancinar",
    "lancinamos": "lancinar",
    "lancinando": "lancinar",
    "lancinantes": "lancinante",
    "lancinara": "lancinar",
    "lancinaram": "lancinar",
    "lancinaras": "lancinar",
    "lancinarde": "lancinar",
    "lancinardes": "lancinar",
    "lancinare": "lancinar",
    "lancinarei": "lancinar",
    "lancinareis": "lancinar",
    "lancinarem": "lancinar",
    "lancinaremos": "lancinar",
    "lancinares": "lancinar",
    "lancinaria": "lancinar",
    "lancinariam": "lancinar",
    "lancinarias": "lancinar",
    "lancinarmo": "lancinar",
    "lancinarmos": "lancinar",
    "lancinará": "lancinar",
    "lancinarás": "lancinar",
    "lancinarão": "lancinar",
    "lancinaríamos": "lancinar",
    "lancinaríeis": "lancinar",
    "lancinas": "lancinar",
    "lancinasse": "lancinar",
    "lancinassem": "lancinar",
    "lancinasses": "lancinar",
    "lancinaste": "lancinar",
    "lancinastes": "lancinar",
    "lancinava": "lancinar",
    "lancinavam": "lancinar",
    "lancinavas": "lancinar",
    "lancine": "lancinar",
    "lancinei": "lancinar",
    "lancineis": "lancinar",
    "lancinem": "lancinar",
    "lancinemo": "lancinar",
    "lancinemos": "lancinar",
    "lancines": "lancinar",
    "lancino": "lancinar",
    "lancinou": "lancinar",
    "lanciná": "lancinar",
    "lancinámo": "lancinar",
    "lancinámos": "lancinar",
    "lancináramo": "lancinar",
    "lancináramos": "lancinar",
    "lancinárei": "lancinar",
    "lancináreis": "lancinar",
    "lancinásseis": "lancinar",
    "lancinássemos": "lancinar",
    "lancinávamo": "lancinar",
    "lancinávamos": "lancinar",
    "lancinávei": "lancinar",
    "lancináveis": "lancinar",
    "lancis": "lancil",
    "landainas": "landaina",
    "landas": "landa",
    "landaus": "landau",
    "landeilianos": "landeiliano",
    "landeira": "landeiro",
    "landeirais": "landeiral",
    "landeiras": "landeiro",
    "landeiros": "landeiro",
    "landenianos": "landeniano",
    "landes": "lande",
    "landesa": "landês",
    "landesas": "landês",
    "landeses": "landês",
    "landgraves": "landgrave",
    "landgrávios": "landgrávio",
    "landina": "landino",
    "landinas": "landino",
    "landinos": "landino",
    "landins": "landim",
    "landiscos": "landisco",
    "landoverianos": "landoveriano",
    "landra": "landre",
    "landras": "landre",
    "landreiros": "landreiro",
    "landres": "landre",
    "landros": "landro",
    "landós": "landó",
    "lanfranhudos": "lanfranhudo",
    "langa": "languir",
    "langais": "languir",
    "langam": "languir",
    "langamo": "languir",
    "langamos": "languir",
    "langanhos": "langanho",
    "langareada": "langarear",
    "langareadas": "langarear",
    "langareado": "langarear",
    "langareados": "langarear",
    "langareai": "langarear",
    "langareais": "langarear",
    "langareamo": "langarear",
    "langareamos": "langarear",
    "langareando": "langarear",
    "langareara": "langarear",
    "langarearam": "langarear",
    "langarearas": "langarear",
    "langareardes": "langarear",
    "langarearei": "langarear",
    "langareareis": "langarear",
    "langarearem": "langarear",
    "langarearemos": "langarear",
    "langareares": "langarear",
    "langarearia": "langarear",
    "langareariam": "langarear",
    "langarearias": "langarear",
    "langarearmo": "langarear",
    "langarearmos": "langarear",
    "langareará": "langarear",
    "langarearás": "langarear",
    "langarearão": "langarear",
    "langarearíamos": "langarear",
    "langarearíeis": "langarear",
    "langareasse": "langarear",
    "langareassem": "langarear",
    "langareasses": "langarear",
    "langareaste": "langarear",
    "langareastes": "langarear",
    "langareava": "langarear",
    "langareavam": "langarear",
    "langareavas": "langarear",
    "langareei": "langarear",
    "langareeis": "langarear",
    "langareemo": "langarear",
    "langareemos": "langarear",
    "langareia": "langarear",
    "langareiam": "langarear",
    "langareias": "langarear",
    "langareie": "langarear",
    "langareiem": "langarear",
    "langareies": "langarear",
    "langareio": "langarear",
    "langareou": "langarear",
    "langareámo": "langarear",
    "langareámos": "langarear",
    "langareáramo": "langarear",
    "langareáramos": "langarear",
    "langareáreis": "langarear",
    "langareásseis": "langarear",
    "langareássemos": "langarear",
    "langareávamo": "langarear",
    "langareávamos": "langarear",
    "langareáveis": "langarear",
    "langarás": "langará",
    "langarés": "langaré",
    "langas": "languir",
    "lango": "languir",
    "langonhas": "langonha",
    "langores": "langor",
    "langorosa": "langoroso",
    "langorosas": "langoroso",
    "langorosos": "langoroso",
    "languas": "langua",
    "langue": "languir",
    "languedora": "languedor",
    "languedoras": "languedor",
    "languedores": "languedor",
    "langueirões": "langueirão",
    "languem": "languir",
    "languenta": "languento",
    "languentas": "languento",
    "languentos": "languento",
    "langues": "languir",
    "languesce": "languescer",
    "languescei": "languescer",
    "languesceis": "languescer",
    "languescem": "languescer",
    "languescemo": "languescer",
    "languescemos": "languescer",
    "languescendo": "languescer",
    "languescentes": "languescente",
    "languescera": "languescer",
    "languesceram": "languescer",
    "languesceras": "languescer",
    "languescerdes": "languescer",
    "languescerei": "languescer",
    "languescereis": "languescer",
    "languescerem": "languescer",
    "languesceremos": "languescer",
    "languesceres": "languescer",
    "languesceria": "languescer",
    "languesceriam": "languescer",
    "languescerias": "languescer",
    "languescermo": "languescer",
    "languescermos": "languescer",
    "languescerá": "languescer",
    "languescerás": "languescer",
    "languescerão": "languescer",
    "languesceríamos": "languescer",
    "languesceríeis": "languescer",
    "languesces": "languescer",
    "languescesse": "languescer",
    "languescessem": "languescer",
    "languescesses": "languescer",
    "languesceste": "languescer",
    "languescestes": "languescer",
    "languesceu": "languescer",
    "languesci": "languescer",
    "languescia": "languescer",
    "languesciam": "languescer",
    "languescias": "languescer",
    "languescida": "languescer",
    "languescidas": "languescer",
    "languescido": "languescer",
    "languescidos": "languescer",
    "languescêramo": "languescer",
    "languescêramos": "languescer",
    "languescêreis": "languescer",
    "languescêsseis": "languescer",
    "languescêssemos": "languescer",
    "languescíamo": "languescer",
    "languescíamos": "languescer",
    "languescíeis": "languescer",
    "languesça": "languescer",
    "languesçais": "languescer",
    "languesçam": "languescer",
    "languesçamo": "languescer",
    "languesçamos": "languescer",
    "languesças": "languescer",
    "languesço": "languescer",
    "langui": "languir",
    "languia": "languir",
    "languiam": "languir",
    "languias": "languir",
    "languida": "languir",
    "languidas": "languir",
    "languidesce": "languidescer",
    "languidescei": "languidescer",
    "languidesceis": "languidescer",
    "languidescem": "languidescer",
    "languidescemo": "languidescer",
    "languidescemos": "languidescer",
    "languidescendo": "languidescer",
    "languidescera": "languidescer",
    "languidesceram": "languidescer",
    "languidesceras": "languidescer",
    "languidescerdes": "languidescer",
    "languidescerei": "languidescer",
    "languidescereis": "languidescer",
    "languidescerem": "languidescer",
    "languidesceremos": "languidescer",
    "languidesceres": "languidescer",
    "languidesceria": "languidescer",
    "languidesceriam": "languidescer",
    "languidescerias": "languidescer",
    "languidescermo": "languidescer",
    "languidescermos": "languidescer",
    "languidescerá": "languidescer",
    "languidescerás": "languidescer",
    "languidescerão": "languidescer",
    "languidesceríamos": "languidescer",
    "languidesceríeis": "languidescer",
    "languidesces": "languidescer",
    "languidescesse": "languidescer",
    "languidescessem": "languidescer",
    "languidescesses": "languidescer",
    "languidesceste": "languidescer",
    "languidescestes": "languidescer",
    "languidesceu": "languidescer",
    "languidesci": "languidescer",
    "languidescia": "languidescer",
    "languidesciam": "languidescer",
    "languidescias": "languidescer",
    "languidescida": "languidescer",
    "languidescidas": "languidescer",
    "languidescido": "languidescer",
    "languidescidos": "languidescer",
    "languidescêramo": "languidescer",
    "languidescêramos": "languidescer",
    "languidescêreis": "languidescer",
    "languidescêsseis": "languidescer",
    "languidescêssemos": "languidescer",
    "languidescíamo": "languidescer",
    "languidescíamos": "languidescer",
    "languidescíeis": "languidescer",
    "languidesça": "languidescer",
    "languidesçais": "languidescer",
    "languidesçam": "languidescer",
    "languidesçamo": "languidescer",
    "languidesçamos": "languidescer",
    "languidesças": "languidescer",
    "languidesço": "languidescer",
    "languidezes": "languidez",
    "languido": "languir",
    "languidos": "languir",
    "languimo": "languir",
    "languimos": "languir",
    "languindo": "languir",
    "languinhenta": "languinhento",
    "languinhentas": "languinhento",
    "languinhentos": "languinhento",
    "languira": "languir",
    "languiram": "languir",
    "languiras": "languir",
    "languirde": "languir",
    "languirdes": "languir",
    "languire": "languir",
    "languirei": "languir",
    "languireis": "languir",
    "languirem": "languir",
    "languiremos": "languir",
    "languires": "languir",
    "languiria": "languir",
    "languiriam": "languir",
    "languirias": "languir",
    "languirmo": "languir",
    "languirmos": "languir",
    "languirá": "languir",
    "languirás": "languir",
    "languirão": "languir",
    "languiríamos": "languir",
    "languiríeis": "languir",
    "languis": "languir",
    "languisse": "languir",
    "languissem": "languir",
    "languisses": "languir",
    "languiste": "languir",
    "languistes": "languir",
    "languiu": "languir",
    "languíamo": "languir",
    "languíamos": "languir",
    "languíei": "languir",
    "languíeis": "languir",
    "languíramo": "languir",
    "languíramos": "languir",
    "languírei": "languir",
    "languíreis": "languir",
    "languísseis": "languir",
    "languíssemos": "languir",
    "lanha": "lanhar",
    "lanhada": "lanhar",
    "lanhadas": "lanhar",
    "lanhado": "lanhar",
    "lanhados": "lanhar",
    "lanhai": "lanhar",
    "lanhais": "lanhar",
    "lanham": "lanhar",
    "lanhamo": "lanhar",
    "lanhamos": "lanhar",
    "lanhando": "lanhar",
    "lanhara": "lanhar",
    "lanharam": "lanhar",
    "lanharas": "lanhar",
    "lanharde": "lanhar",
    "lanhardes": "lanhar",
    "lanhare": "lanhar",
    "lanharei": "lanhar",
    "lanhareis": "lanhar",
    "lanharem": "lanhar",
    "lanharemos": "lanhar",
    "lanhares": "lanhar",
    "lanharia": "lanhar",
    "lanhariam": "lanhar",
    "lanharias": "lanhar",
    "lanharmo": "lanhar",
    "lanharmos": "lanhar",
    "lanhará": "lanhar",
    "lanharás": "lanhar",
    "lanharão": "lanhar",
    "lanharíamos": "lanhar",
    "lanharíeis": "lanhar",
    "lanhas": "lanhar",
    "lanhasse": "lanhar",
    "lanhassem": "lanhar",
    "lanhasses": "lanhar",
    "lanhaste": "lanhar",
    "lanhastes": "lanhar",
    "lanhava": "lanhar",
    "lanhavam": "lanhar",
    "lanhavas": "lanhar",
    "lanhaços": "lanhaço",
    "lanhe": "lanhar",
    "lanhei": "lanhar",
    "lanheis": "lanhar",
    "lanhem": "lanhar",
    "lanhemo": "lanhar",
    "lanhemos": "lanhar",
    "lanhes": "lanhar",
    "lanho": "lanhar",
    "lanhos": "lanho",
    "lanhou": "lanhar",
    "lanhá": "lanhar",
    "lanhámo": "lanhar",
    "lanhámos": "lanhar",
    "lanháramo": "lanhar",
    "lanháramos": "lanhar",
    "lanhárei": "lanhar",
    "lanháreis": "lanhar",
    "lanhásseis": "lanhar",
    "lanhássemos": "lanhar",
    "lanhávamo": "lanhar",
    "lanhávamos": "lanhar",
    "lanhávei": "lanhar",
    "lanháveis": "lanhar",
    "lanifícios": "lanifício",
    "laniídeos": "laniídeo",
    "lanolinas": "lanolina",
    "lanosa": "lanoso",
    "lanosas": "lanoso",
    "lanosidades": "lanosidade",
    "lanosos": "lanoso",
    "lansquenetes": "lansquenete",
    "lansquenés": "lansquené",
    "lantanídeos": "lantanídeo",
    "lantejoilas": "lantejoila",
    "lantejoula": "lantejoular",
    "lantejoulada": "lantejoular",
    "lantejouladas": "lantejoular",
    "lantejoulado": "lantejoular",
    "lantejoulados": "lantejoular",
    "lantejoulai": "lantejoular",
    "lantejoulais": "lantejoular",
    "lantejoulam": "lantejoular",
    "lantejoulamo": "lantejoular",
    "lantejoulamos": "lantejoular",
    "lantejoulando": "lantejoular",
    "lantejoulara": "lantejoular",
    "lantejoularam": "lantejoular",
    "lantejoularas": "lantejoular",
    "lantejoularde": "lantejoular",
    "lantejoulardes": "lantejoular",
    "lantejoulare": "lantejoular",
    "lantejoularei": "lantejoular",
    "lantejoulareis": "lantejoular",
    "lantejoularem": "lantejoular",
    "lantejoularemos": "lantejoular",
    "lantejoulares": "lantejoular",
    "lantejoularia": "lantejoular",
    "lantejoulariam": "lantejoular",
    "lantejoularias": "lantejoular",
    "lantejoularmo": "lantejoular",
    "lantejoularmos": "lantejoular",
    "lantejoulará": "lantejoular",
    "lantejoularás": "lantejoular",
    "lantejoularão": "lantejoular",
    "lantejoularíamos": "lantejoular",
    "lantejoularíeis": "lantejoular",
    "lantejoulas": "lantejoular",
    "lantejoulasse": "lantejoular",
    "lantejoulassem": "lantejoular",
    "lantejoulasses": "lantejoular",
    "lantejoulaste": "lantejoular",
    "lantejoulastes": "lantejoular",
    "lantejoulava": "lantejoular",
    "lantejoulavam": "lantejoular",
    "lantejoulavas": "lantejoular",
    "lantejoule": "lantejoular",
    "lantejoulei": "lantejoular",
    "lantejouleis": "lantejoular",
    "lantejoulem": "lantejoular",
    "lantejoulemo": "lantejoular",
    "lantejoulemos": "lantejoular",
    "lantejoules": "lantejoular",
    "lantejoulo": "lantejoular",
    "lantejoulou": "lantejoular",
    "lantejoulá": "lantejoular",
    "lantejoulámo": "lantejoular",
    "lantejoulámos": "lantejoular",
    "lantejouláramo": "lantejoular",
    "lantejouláramos": "lantejoular",
    "lantejoulárei": "lantejoular",
    "lantejouláreis": "lantejoular",
    "lantejoulásseis": "lantejoular",
    "lantejoulássemos": "lantejoular",
    "lantejoulávamo": "lantejoular",
    "lantejoulávamos": "lantejoular",
    "lantejoulávei": "lantejoular",
    "lantejouláveis": "lantejoular",
    "lanternas": "lanterna",
    "lanterneira": "lanterneiro",
    "lanterneiras": "lanterneiro",
    "lanterneiros": "lanterneiro",
    "lanternetas": "lanterneta",
    "lanterninos": "lanternino",
    "lanternins": "lanternim",
    "lantânios": "lantânio",
    "lanuda": "lanudo",
    "lanudas": "lanudo",
    "lanudos": "lanudo",
    "lanugens": "lanugem",
    "lanuginosa": "lanuginoso",
    "lanuginosas": "lanuginoso",
    "lanuginosos": "lanuginoso",
    "lanvirnianos": "lanvirniano",
    "lanzoa": "lanzoar",
    "lanzoada": "lanzoar",
    "lanzoadas": "lanzoar",
    "lanzoado": "lanzoar",
    "lanzoados": "lanzoar",
    "lanzoai": "lanzoar",
    "lanzoais": "lanzoar",
    "lanzoam": "lanzoar",
    "lanzoamo": "lanzoar",
    "lanzoamos": "lanzoar",
    "lanzoando": "lanzoar",
    "lanzoara": "lanzoar",
    "lanzoaram": "lanzoar",
    "lanzoaras": "lanzoar",
    "lanzoardes": "lanzoar",
    "lanzoarei": "lanzoar",
    "lanzoareis": "lanzoar",
    "lanzoarem": "lanzoar",
    "lanzoaremos": "lanzoar",
    "lanzoares": "lanzoar",
    "lanzoaria": "lanzoar",
    "lanzoariam": "lanzoar",
    "lanzoarias": "lanzoar",
    "lanzoarmo": "lanzoar",
    "lanzoarmos": "lanzoar",
    "lanzoará": "lanzoar",
    "lanzoarás": "lanzoar",
    "lanzoarão": "lanzoar",
    "lanzoaríamos": "lanzoar",
    "lanzoaríeis": "lanzoar",
    "lanzoas": "lanzoar",
    "lanzoasse": "lanzoar",
    "lanzoassem": "lanzoar",
    "lanzoasses": "lanzoar",
    "lanzoaste": "lanzoar",
    "lanzoastes": "lanzoar",
    "lanzoava": "lanzoar",
    "lanzoavam": "lanzoar",
    "lanzoavas": "lanzoar",
    "lanzoe": "lanzoar",
    "lanzoei": "lanzoar",
    "lanzoeis": "lanzoar",
    "lanzoem": "lanzoar",
    "lanzoemo": "lanzoar",
    "lanzoemos": "lanzoar",
    "lanzoes": "lanzoar",
    "lanzoo": "lanzoar",
    "lanzoou": "lanzoar",
    "lanzoámo": "lanzoar",
    "lanzoámos": "lanzoar",
    "lanzoáramo": "lanzoar",
    "lanzoáramos": "lanzoar",
    "lanzoáreis": "lanzoar",
    "lanzoásseis": "lanzoar",
    "lanzoássemos": "lanzoar",
    "lanzoávamo": "lanzoar",
    "lanzoávamos": "lanzoar",
    "lanzoáveis": "lanzoar",
    "lanzuda": "lanzudo",
    "lanzudas": "lanzudo",
    "lanzudos": "lanzudo",
    "lança": "lançar",
    "lançada": "lançar",
    "lançadas": "lançar",
    "lançadeiras": "lançadeira",
    "lançadiça": "lançadiço",
    "lançadiças": "lançadiço",
    "lançadiços": "lançadiço",
    "lançado": "lançar",
    "lançadora": "lançador",
    "lançadoras": "lançador",
    "lançadorazinha": "lançador",
    "lançadorazinhas": "lançador",
    "lançadorazita": "lançador",
    "lançadorazitas": "lançador",
    "lançadores": "lançador",
    "lançadorzinho": "lançador",
    "lançadorzinhos": "lançador",
    "lançadorzito": "lançador",
    "lançadorzitos": "lançador",
    "lançados": "lançar",
    "lançaduras": "lançadura",
    "lançai": "lançar",
    "lançais": "lançar",
    "lançam": "lançar",
    "lançamentos": "lançamento",
    "lançamo": "lançar",
    "lançamos": "lançar",
    "lançando": "lançar",
    "lançantes": "lançante",
    "lançara": "lançar",
    "lançaram": "lançar",
    "lançaras": "lançar",
    "lançarde": "lançar",
    "lançardes": "lançar",
    "lançare": "lançar",
    "lançarei": "lançar",
    "lançareis": "lançar",
    "lançarem": "lançar",
    "lançaremos": "lançar",
    "lançares": "lançar",
    "lançaria": "lançar",
    "lançariam": "lançar",
    "lançarias": "lançar",
    "lançarmo": "lançar",
    "lançarmos": "lançar",
    "lançarotes": "lançarote",
    "lançará": "lançar",
    "lançarás": "lançar",
    "lançarão": "lançar",
    "lançaríamos": "lançar",
    "lançaríeis": "lançar",
    "lanças": "lançar",
    "lançasse": "lançar",
    "lançassem": "lançar",
    "lançasses": "lançar",
    "lançaste": "lançar",
    "lançastes": "lançar",
    "lançava": "lançar",
    "lançavam": "lançar",
    "lançavas": "lançar",
    "lançaços": "lançaço",
    "lanço": "lançar",
    "lanços": "lanço",
    "lançou": "lançar",
    "lançá": "lançar",
    "lançámo": "lançar",
    "lançámos": "lançar",
    "lançáramo": "lançar",
    "lançáramos": "lançar",
    "lançárei": "lançar",
    "lançáreis": "lançar",
    "lançásseis": "lançar",
    "lançássemos": "lançar",
    "lançávamo": "lançar",
    "lançávamos": "lançar",
    "lançávei": "lançar",
    "lançáveis": "lançável",
    "lanífera": "lanífero",
    "laníferas": "lanífero",
    "laníferos": "lanífero",
    "lanígera": "lanígero",
    "lanígeras": "lanígero",
    "lanígeros": "lanígero",
    "laníidas": "laníida",
    "laosiana": "laosiano",
    "laosianas": "laosiano",
    "laosianos": "laosiano",
    "lapadas": "lapada",
    "lapardeira": "lapardeiro",
    "lapardeiras": "lapardeiro",
    "lapardeiros": "lapardeiro",
    "laparoscopias": "laparoscopia",
    "laparoscópios": "laparoscópio",
    "laparota": "laparoto",
    "laparotas": "laparoto",
    "laparotomias": "laparotomia",
    "laparotomiza": "laparotomizar",
    "laparotomizada": "laparotomizar",
    "laparotomizadas": "laparotomizar",
    "laparotomizado": "laparotomizar",
    "laparotomizados": "laparotomizar",
    "laparotomizai": "laparotomizar",
    "laparotomizais": "laparotomizar",
    "laparotomizam": "laparotomizar",
    "laparotomizamo": "laparotomizar",
    "laparotomizamos": "laparotomizar",
    "laparotomizando": "laparotomizar",
    "laparotomizara": "laparotomizar",
    "laparotomizaram": "laparotomizar",
    "laparotomizaras": "laparotomizar",
    "laparotomizardes": "laparotomizar",
    "laparotomizarei": "laparotomizar",
    "laparotomizareis": "laparotomizar",
    "laparotomizarem": "laparotomizar",
    "laparotomizaremos": "laparotomizar",
    "laparotomizares": "laparotomizar",
    "laparotomizaria": "laparotomizar",
    "laparotomizariam": "laparotomizar",
    "laparotomizarias": "laparotomizar",
    "laparotomizarmo": "laparotomizar",
    "laparotomizarmos": "laparotomizar",
    "laparotomizará": "laparotomizar",
    "laparotomizarás": "laparotomizar",
    "laparotomizarão": "laparotomizar",
    "laparotomizaríamos": "laparotomizar",
    "laparotomizaríeis": "laparotomizar",
    "laparotomizas": "laparotomizar",
    "laparotomizasse": "laparotomizar",
    "laparotomizassem": "laparotomizar",
    "laparotomizasses": "laparotomizar",
    "laparotomizaste": "laparotomizar",
    "laparotomizastes": "laparotomizar",
    "laparotomizava": "laparotomizar",
    "laparotomizavam": "laparotomizar",
    "laparotomizavas": "laparotomizar",
    "laparotomize": "laparotomizar",
    "laparotomizei": "laparotomizar",
    "laparotomizeis": "laparotomizar",
    "laparotomizem": "laparotomizar",
    "laparotomizemo": "laparotomizar",
    "laparotomizemos": "laparotomizar",
    "laparotomizes": "laparotomizar",
    "laparotomizo": "laparotomizar",
    "laparotomizou": "laparotomizar",
    "laparotomizámo": "laparotomizar",
    "laparotomizámos": "laparotomizar",
    "laparotomizáramo": "laparotomizar",
    "laparotomizáramos": "laparotomizar",
    "laparotomizáreis": "laparotomizar",
    "laparotomizásseis": "laparotomizar",
    "laparotomizássemos": "laparotomizar",
    "laparotomizávamo": "laparotomizar",
    "laparotomizávamos": "laparotomizar",
    "laparotomizáveis": "laparotomizável",
    "laparotos": "laparoto",
    "laparões": "laparão",
    "lapas": "lapa",
    "lapeiras": "lapeira",
    "lapelas": "lapela",
    "lapiana": "lapiano",
    "lapianas": "lapiano",
    "lapianos": "lapiano",
    "lapida": "lapidar",
    "lapidada": "lapidar",
    "lapidadas": "lapidar",
    "lapidado": "lapidar",
    "lapidadora": "lapidador",
    "lapidadoras": "lapidador",
    "lapidadores": "lapidador",
    "lapidados": "lapidar",
    "lapidagens": "lapidagem",
    "lapidai": "lapidar",
    "lapidais": "lapidar",
    "lapidam": "lapidar",
    "lapidamo": "lapidar",
    "lapidamos": "lapidar",
    "lapidando": "lapidar",
    "lapidara": "lapidar",
    "lapidaram": "lapidar",
    "lapidaras": "lapidar",
    "lapidarde": "lapidar",
    "lapidardes": "lapidar",
    "lapidare": "lapidar",
    "lapidarei": "lapidar",
    "lapidareis": "lapidar",
    "lapidarem": "lapidar",
    "lapidaremos": "lapidar",
    "lapidares": "lapidar",
    "lapidaria": "lapidar",
    "lapidariam": "lapidar",
    "lapidarias": "lapidaria",
    "lapidarmo": "lapidar",
    "lapidarmos": "lapidar",
    "lapidará": "lapidar",
    "lapidarás": "lapidar",
    "lapidarão": "lapidar",
    "lapidaríamos": "lapidar",
    "lapidaríeis": "lapidar",
    "lapidas": "lapidar",
    "lapidasse": "lapidar",
    "lapidassem": "lapidar",
    "lapidasses": "lapidar",
    "lapidaste": "lapidar",
    "lapidastes": "lapidar",
    "lapidava": "lapidar",
    "lapidavam": "lapidar",
    "lapidavas": "lapidar",
    "lapidações": "lapidação",
    "lapide": "lapidar",
    "lapidei": "lapidar",
    "lapideis": "lapidar",
    "lapidem": "lapidar",
    "lapidemo": "lapidar",
    "lapidemos": "lapidar",
    "lapides": "lapidar",
    "lapidescentes": "lapidescente",
    "lapidifica": "lapidificar",
    "lapidificada": "lapidificar",
    "lapidificadas": "lapidificar",
    "lapidificado": "lapidificar",
    "lapidificados": "lapidificar",
    "lapidificai": "lapidificar",
    "lapidificais": "lapidificar",
    "lapidificam": "lapidificar",
    "lapidificamo": "lapidificar",
    "lapidificamos": "lapidificar",
    "lapidificando": "lapidificar",
    "lapidificara": "lapidificar",
    "lapidificaram": "lapidificar",
    "lapidificaras": "lapidificar",
    "lapidificarde": "lapidificar",
    "lapidificardes": "lapidificar",
    "lapidificare": "lapidificar",
    "lapidificarei": "lapidificar",
    "lapidificareis": "lapidificar",
    "lapidificarem": "lapidificar",
    "lapidificaremos": "lapidificar",
    "lapidificares": "lapidificar",
    "lapidificaria": "lapidificar",
    "lapidificariam": "lapidificar",
    "lapidificarias": "lapidificar",
    "lapidificarmo": "lapidificar",
    "lapidificarmos": "lapidificar",
    "lapidificará": "lapidificar",
    "lapidificarás": "lapidificar",
    "lapidificarão": "lapidificar",
    "lapidificaríamos": "lapidificar",
    "lapidificaríeis": "lapidificar",
    "lapidificas": "lapidificar",
    "lapidificasse": "lapidificar",
    "lapidificassem": "lapidificar",
    "lapidificasses": "lapidificar",
    "lapidificaste": "lapidificar",
    "lapidificastes": "lapidificar",
    "lapidificava": "lapidificar",
    "lapidificavam": "lapidificar",
    "lapidificavas": "lapidificar",
    "lapidificações": "lapidificação",
    "lapidifico": "lapidificar",
    "lapidificou": "lapidificar",
    "lapidificá": "lapidificar",
    "lapidificámo": "lapidificar",
    "lapidificámos": "lapidificar",
    "lapidificáramo": "lapidificar",
    "lapidificáramos": "lapidificar",
    "lapidificárei": "lapidificar",
    "lapidificáreis": "lapidificar",
    "lapidificásseis": "lapidificar",
    "lapidificássemos": "lapidificar",
    "lapidificávamo": "lapidificar",
    "lapidificávamos": "lapidificar",
    "lapidificávei": "lapidificar",
    "lapidificáveis": "lapidificável",
    "lapidifique": "lapidificar",
    "lapidifiquei": "lapidificar",
    "lapidifiqueis": "lapidificar",
    "lapidifiquem": "lapidificar",
    "lapidifiquemo": "lapidificar",
    "lapidifiquemos": "lapidificar",
    "lapidifiques": "lapidificar",
    "lapido": "lapidar",
    "lapidosa": "lapidoso",
    "lapidosas": "lapidoso",
    "lapidosos": "lapidoso",
    "lapidou": "lapidar",
    "lapidá": "lapidar",
    "lapidámo": "lapidar",
    "lapidámos": "lapidar",
    "lapidáramo": "lapidar",
    "lapidáramos": "lapidar",
    "lapidárei": "lapidar",
    "lapidáreis": "lapidar",
    "lapidária": "lapidário",
    "lapidárias": "lapidário",
    "lapidários": "lapidário",
    "lapidásseis": "lapidar",
    "lapidássemos": "lapidar",
    "lapidávamo": "lapidar",
    "lapidávamos": "lapidar",
    "lapidávei": "lapidar",
    "lapidáveis": "lapidável",
    "lapidícolas": "lapidícola",
    "lapidífica": "lapidífico",
    "lapidíficas": "lapidífico",
    "lapidíficos": "lapidífico",
    "lapiezes": "lapiez",
    "lapinhas": "lapinha",
    "lapisa": "lapisar",
    "lapisada": "lapisar",
    "lapisadas": "lapisar",
    "lapisado": "lapisar",
    "lapisados": "lapisar",
    "lapisai": "lapisar",
    "lapisais": "lapisar",
    "lapisam": "lapisar",
    "lapisamo": "lapisar",
    "lapisamos": "lapisar",
    "lapisando": "lapisar",
    "lapisara": "lapisar",
    "lapisaram": "lapisar",
    "lapisaras": "lapisar",
    "lapisarde": "lapisar",
    "lapisardes": "lapisar",
    "lapisare": "lapisar",
    "lapisarei": "lapisar",
    "lapisareis": "lapisar",
    "lapisarem": "lapisar",
    "lapisaremos": "lapisar",
    "lapisares": "lapisar",
    "lapisaria": "lapisar",
    "lapisariam": "lapisar",
    "lapisarias": "lapisar",
    "lapisarmo": "lapisar",
    "lapisarmos": "lapisar",
    "lapisará": "lapisar",
    "lapisarás": "lapisar",
    "lapisarão": "lapisar",
    "lapisaríamos": "lapisar",
    "lapisaríeis": "lapisar",
    "lapisas": "lapisar",
    "lapisasse": "lapisar",
    "lapisassem": "lapisar",
    "lapisasses": "lapisar",
    "lapisaste": "lapisar",
    "lapisastes": "lapisar",
    "lapisava": "lapisar",
    "lapisavam": "lapisar",
    "lapisavas": "lapisar",
    "lapise": "lapisar",
    "lapisei": "lapisar",
    "lapiseiras": "lapiseira",
    "lapiseis": "lapisar",
    "lapisem": "lapisar",
    "lapisemo": "lapisar",
    "lapisemos": "lapisar",
    "lapises": "lapisar",
    "lapiso": "lapisar",
    "lapisou": "lapisar",
    "lapisá": "lapisar",
    "lapisámo": "lapisar",
    "lapisámos": "lapisar",
    "lapisáramo": "lapisar",
    "lapisáramos": "lapisar",
    "lapisárei": "lapisar",
    "lapisáreis": "lapisar",
    "lapisásseis": "lapisar",
    "lapisássemos": "lapisar",
    "lapisávamo": "lapisar",
    "lapisávamos": "lapisar",
    "lapisávei": "lapisar",
    "lapisáveis": "lapisar",
    "lapiáses": "lapiás",
    "laplacianos": "laplaciano",
    "lapona": "lapão",
    "laponas": "lapão",
    "lapouça": "lapouço",
    "lapouças": "lapouço",
    "lapouços": "lapouço",
    "lapsanas": "lapsana",
    "lapsos": "lapso",
    "lapuza": "lapuz",
    "lapuzas": "lapuz",
    "lapuzes": "lapuz",
    "lapídea": "lapídeo",
    "lapídeas": "lapídeo",
    "lapídeos": "lapídeo",
    "lapílis": "lapíli",
    "lapónia": "lapónio",
    "lapónias": "lapónio",
    "lapónios": "lapónio",
    "lapões": "lapão",
    "lapúrdia": "lapúrdio",
    "lapúrdias": "lapúrdio",
    "lapúrdios": "lapúrdio",
    "laque": "lacar",
    "laqueada": "laquear",
    "laqueadas": "laquear",
    "laqueado": "laquear",
    "laqueadora": "laqueador",
    "laqueadoras": "laqueador",
    "laqueadores": "laqueador",
    "laqueados": "laquear",
    "laqueai": "laquear",
    "laqueais": "laquear",
    "laqueamo": "laquear",
    "laqueamos": "laquear",
    "laqueando": "laquear",
    "laqueara": "laquear",
    "laquearam": "laquear",
    "laquearas": "laquear",
    "laquearde": "laquear",
    "laqueardes": "laquear",
    "laqueare": "laquear",
    "laquearei": "laquear",
    "laqueareis": "laquear",
    "laquearem": "laquear",
    "laquearemos": "laquear",
    "laqueares": "laquear",
    "laquearia": "laquear",
    "laqueariam": "laquear",
    "laquearias": "laquear",
    "laquearmo": "laquear",
    "laquearmos": "laquear",
    "laqueará": "laquear",
    "laquearás": "laquear",
    "laquearão": "laquear",
    "laquearíamos": "laquear",
    "laquearíeis": "laquear",
    "laqueasse": "laquear",
    "laqueassem": "laquear",
    "laqueasses": "laquear",
    "laqueaste": "laquear",
    "laqueastes": "laquear",
    "laqueava": "laquear",
    "laqueavam": "laquear",
    "laqueavas": "laquear",
    "laqueações": "laqueação",
    "laquecas": "laqueca",
    "laqueei": "laquear",
    "laqueeis": "laquear",
    "laqueemo": "laquear",
    "laqueemos": "laquear",
    "laquei": "lacar",
    "laqueia": "laquear",
    "laqueiam": "laquear",
    "laqueias": "laquear",
    "laqueie": "laquear",
    "laqueiem": "laquear",
    "laqueies": "laquear",
    "laqueio": "laquear",
    "laqueis": "lacar",
    "laquem": "lacar",
    "laquemos": "lacar",
    "laqueou": "laquear",
    "laques": "lacar",
    "laqueá": "laquear",
    "laqueámo": "laquear",
    "laqueámos": "laquear",
    "laqueáramo": "laquear",
    "laqueáramos": "laquear",
    "laqueárei": "laquear",
    "laqueáreis": "laquear",
    "laqueários": "laqueário",
    "laqueásseis": "laquear",
    "laqueássemos": "laquear",
    "laqueávamo": "laquear",
    "laqueávamos": "laquear",
    "laqueávei": "laquear",
    "laqueáveis": "laqueável",
    "laracha": "larachar",
    "larachada": "larachar",
    "larachadas": "larachar",
    "larachado": "larachar",
    "larachados": "larachar",
    "larachai": "larachar",
    "larachais": "larachar",
    "laracham": "larachar",
    "larachamo": "larachar",
    "larachamos": "larachar",
    "larachando": "larachar",
    "larachara": "larachar",
    "laracharam": "larachar",
    "laracharas": "larachar",
    "larachardes": "larachar",
    "laracharei": "larachar",
    "larachareis": "larachar",
    "laracharem": "larachar",
    "laracharemos": "larachar",
    "larachares": "larachar",
    "laracharia": "larachar",
    "larachariam": "larachar",
    "laracharias": "larachar",
    "laracharmo": "larachar",
    "laracharmos": "larachar",
    "larachará": "larachar",
    "laracharás": "larachar",
    "laracharão": "larachar",
    "laracharíamos": "larachar",
    "laracharíeis": "larachar",
    "larachas": "larachar",
    "larachasse": "larachar",
    "larachassem": "larachar",
    "larachasses": "larachar",
    "larachaste": "larachar",
    "larachastes": "larachar",
    "larachava": "larachar",
    "larachavam": "larachar",
    "larachavas": "larachar",
    "larache": "larachar",
    "laracheada": "larachear",
    "laracheadas": "larachear",
    "laracheado": "larachear",
    "laracheados": "larachear",
    "laracheai": "larachear",
    "laracheais": "larachear",
    "laracheamo": "larachear",
    "laracheamos": "larachear",
    "laracheando": "larachear",
    "laracheara": "larachear",
    "larachearam": "larachear",
    "larachearas": "larachear",
    "larachearde": "larachear",
    "laracheardes": "larachear",
    "laracheare": "larachear",
    "larachearei": "larachear",
    "laracheareis": "larachear",
    "larachearem": "larachear",
    "larachearemos": "larachear",
    "laracheares": "larachear",
    "larachearia": "larachear",
    "laracheariam": "larachear",
    "larachearias": "larachear",
    "larachearmo": "larachear",
    "larachearmos": "larachear",
    "laracheará": "larachear",
    "larachearás": "larachear",
    "larachearão": "larachear",
    "larachearíamos": "larachear",
    "larachearíeis": "larachear",
    "laracheasse": "larachear",
    "laracheassem": "larachear",
    "laracheasses": "larachear",
    "laracheaste": "larachear",
    "laracheastes": "larachear",
    "laracheava": "larachear",
    "laracheavam": "larachear",
    "laracheavas": "larachear",
    "laracheei": "larachear",
    "laracheeis": "larachear",
    "laracheemo": "larachear",
    "laracheemos": "larachear",
    "larachei": "larachar",
    "laracheia": "larachear",
    "laracheiam": "larachear",
    "laracheias": "larachear",
    "laracheie": "larachear",
    "laracheiem": "larachear",
    "laracheies": "larachear",
    "laracheio": "larachear",
    "laracheis": "larachar",
    "larachem": "larachar",
    "larachemo": "larachar",
    "larachemos": "larachar",
    "laracheou": "larachear",
    "laraches": "larachar",
    "laracheá": "larachear",
    "laracheámo": "larachear",
    "laracheámos": "larachear",
    "laracheáramo": "larachear",
    "laracheáramos": "larachear",
    "laracheárei": "larachear",
    "laracheáreis": "larachear",
    "laracheásseis": "larachear",
    "laracheássemos": "larachear",
    "laracheávamo": "larachear",
    "laracheávamos": "larachear",
    "laracheávei": "larachear",
    "laracheáveis": "larachear",
    "larachistas": "larachista",
    "laracho": "larachar",
    "larachou": "larachar",
    "larachámo": "larachar",
    "larachámos": "larachar",
    "laracháramo": "larachar",
    "laracháramos": "larachar",
    "laracháreis": "larachar",
    "larachásseis": "larachar",
    "larachássemos": "larachar",
    "larachávamo": "larachar",
    "larachávamos": "larachar",
    "laracháveis": "larachar",
    "laradas": "larada",
    "laranja": "laranjo",
    "laranjadas": "laranjada",
    "laranjais": "laranjal",
    "laranjas": "laranjo",
    "laranjeiras": "laranjeira",
    "laranjinha": "laranja",
    "laranjinhas": "laranjinha",
    "laranjita": "laranja",
    "laranjitas": "laranja",
    "laranjos": "laranjo",
    "larcões": "larcão",
    "larda": "lardo",
    "lardas": "lardo",
    "lardeada": "lardear",
    "lardeadas": "lardear",
    "lardeadeiras": "lardeadeira",
    "lardeado": "lardear",
    "lardeados": "lardear",
    "lardeai": "lardear",
    "lardeais": "lardear",
    "lardeamo": "lardear",
    "lardeamos": "lardear",
    "lardeando": "lardear",
    "lardeara": "lardear",
    "lardearam": "lardear",
    "lardearas": "lardear",
    "lardearde": "lardear",
    "lardeardes": "lardear",
    "lardeare": "lardear",
    "lardearei": "lardear",
    "lardeareis": "lardear",
    "lardearem": "lardear",
    "lardearemos": "lardear",
    "lardeares": "lardear",
    "lardearia": "lardear",
    "lardeariam": "lardear",
    "lardearias": "lardear",
    "lardearmo": "lardear",
    "lardearmos": "lardear",
    "lardeará": "lardear",
    "lardearás": "lardear",
    "lardearão": "lardear",
    "lardearíamos": "lardear",
    "lardearíeis": "lardear",
    "lardeasse": "lardear",
    "lardeassem": "lardear",
    "lardeasses": "lardear",
    "lardeaste": "lardear",
    "lardeastes": "lardear",
    "lardeava": "lardear",
    "lardeavam": "lardear",
    "lardeavas": "lardear",
    "lardeei": "lardear",
    "lardeeis": "lardear",
    "lardeemo": "lardear",
    "lardeemos": "lardear",
    "lardeia": "lardear",
    "lardeiam": "lardear",
    "lardeias": "lardear",
    "lardeie": "lardear",
    "lardeiem": "lardear",
    "lardeies": "lardear",
    "lardeio": "lardear",
    "lardeou": "lardear",
    "lardeá": "lardear",
    "lardeámo": "lardear",
    "lardeámos": "lardear",
    "lardeáramo": "lardear",
    "lardeáramos": "lardear",
    "lardeárei": "lardear",
    "lardeáreis": "lardear",
    "lardeásseis": "lardear",
    "lardeássemos": "lardear",
    "lardeávamo": "lardear",
    "lardeávamos": "lardear",
    "lardeávei": "lardear",
    "lardeáveis": "lardeável",
    "lardiformes": "lardiforme",
    "lardoeiros": "lardoeiro",
    "lardos": "lardo",
    "lardívora": "lardívoro",
    "lardívoras": "lardívoro",
    "lardívoros": "lardívoro",
    "lareada": "larear",
    "lareadas": "larear",
    "lareado": "larear",
    "lareados": "larear",
    "lareai": "larear",
    "lareais": "larear",
    "lareamo": "larear",
    "lareamos": "larear",
    "lareando": "larear",
    "lareara": "larear",
    "larearam": "larear",
    "larearas": "larear",
    "lareardes": "larear",
    "larearei": "larear",
    "lareareis": "larear",
    "larearem": "larear",
    "larearemos": "larear",
    "lareares": "larear",
    "larearia": "larear",
    "lareariam": "larear",
    "larearias": "larear",
    "larearmo": "larear",
    "larearmos": "larear",
    "lareará": "larear",
    "larearás": "larear",
    "larearão": "larear",
    "larearíamos": "larear",
    "larearíeis": "larear",
    "lareasse": "larear",
    "lareassem": "larear",
    "lareasses": "larear",
    "lareaste": "larear",
    "lareastes": "larear",
    "lareava": "larear",
    "lareavam": "larear",
    "lareavas": "larear",
    "lareei": "larear",
    "lareeis": "larear",
    "lareemo": "larear",
    "lareemos": "larear",
    "laregos": "larego",
    "lareia": "larear",
    "lareiam": "larear",
    "lareias": "larear",
    "lareie": "larear",
    "lareiem": "larear",
    "lareies": "larear",
    "lareio": "larear",
    "lareira": "lareiro",
    "lareiras": "lareiro",
    "lareiros": "lareiro",
    "lareou": "larear",
    "lares": "lar",
    "lareámo": "larear",
    "lareámos": "larear",
    "lareáramo": "larear",
    "lareáramos": "larear",
    "lareáreis": "larear",
    "lareásseis": "larear",
    "lareássemos": "larear",
    "lareávamo": "larear",
    "lareávamos": "larear",
    "lareáveis": "larear",
    "larga": "largo",
    "largada": "largar",
    "largadas": "largar",
    "largado": "largar",
    "largados": "largar",
    "largai": "largar",
    "largais": "largar",
    "largam": "largar",
    "largamo": "largar",
    "largamos": "largar",
    "largando": "largar",
    "largara": "largar",
    "largaram": "largar",
    "largaras": "largar",
    "largarde": "largar",
    "largardes": "largar",
    "largare": "largar",
    "largarei": "largar",
    "largareis": "largar",
    "largarem": "largar",
    "largaremos": "largar",
    "largares": "largar",
    "largaria": "largar",
    "largariam": "largar",
    "largarias": "largar",
    "largarmo": "largar",
    "largarmos": "largar",
    "largará": "largar",
    "largarás": "largar",
    "largarão": "largar",
    "largaríamos": "largar",
    "largaríeis": "largar",
    "largas": "largo",
    "largasse": "largar",
    "largassem": "largar",
    "largasses": "largar",
    "largaste": "largar",
    "largastes": "largar",
    "largava": "largar",
    "largavam": "largar",
    "largavas": "largar",
    "largazinha": "largo",
    "largazinhas": "largo",
    "largazita": "largo",
    "largazitas": "largo",
    "largações": "largação",
    "largo": "largar",
    "largos": "largo",
    "largou": "largar",
    "largozinho": "largo",
    "largozinhos": "largo",
    "largozito": "largo",
    "largozitos": "largo",
    "largue": "largar",
    "largueada": "larguear",
    "largueadas": "larguear",
    "largueado": "larguear",
    "largueadora": "largueador",
    "largueadoras": "largueador",
    "largueadores": "largueador",
    "largueados": "larguear",
    "largueai": "larguear",
    "largueais": "larguear",
    "largueamo": "larguear",
    "largueamos": "larguear",
    "largueando": "larguear",
    "largueara": "larguear",
    "larguearam": "larguear",
    "larguearas": "larguear",
    "larguearde": "larguear",
    "largueardes": "larguear",
    "largueare": "larguear",
    "larguearei": "larguear",
    "largueareis": "larguear",
    "larguearem": "larguear",
    "larguearemos": "larguear",
    "largueares": "larguear",
    "larguearia": "larguear",
    "largueariam": "larguear",
    "larguearias": "larguear",
    "larguearmo": "larguear",
    "larguearmos": "larguear",
    "largueará": "larguear",
    "larguearás": "larguear",
    "larguearão": "larguear",
    "larguearíamos": "larguear",
    "larguearíeis": "larguear",
    "largueasse": "larguear",
    "largueassem": "larguear",
    "largueasses": "larguear",
    "largueaste": "larguear",
    "largueastes": "larguear",
    "largueava": "larguear",
    "largueavam": "larguear",
    "largueavas": "larguear",
    "largueei": "larguear",
    "largueeis": "larguear",
    "largueemo": "larguear",
    "largueemos": "larguear",
    "larguei": "largar",
    "largueia": "larguear",
    "largueiam": "larguear",
    "largueias": "larguear",
    "largueie": "larguear",
    "largueiem": "larguear",
    "largueies": "larguear",
    "largueio": "larguear",
    "largueis": "largar",
    "larguem": "largar",
    "larguemo": "largar",
    "larguemos": "largar",
    "largueou": "larguear",
    "largues": "largar",
    "larguetos": "largueto",
    "larguezas": "largueza",
    "largueá": "larguear",
    "largueámo": "larguear",
    "largueámos": "larguear",
    "largueáramo": "larguear",
    "largueáramos": "larguear",
    "largueárei": "larguear",
    "largueáreis": "larguear",
    "largueásseis": "larguear",
    "largueássemos": "larguear",
    "largueávamo": "larguear",
    "largueávamos": "larguear",
    "largueávei": "larguear",
    "largueáveis": "larguear",
    "larguinha": "largo",
    "larguinhas": "largo",
    "larguinho": "largo",
    "larguinhos": "largo",
    "larguita": "largo",
    "larguitas": "largo",
    "larguito": "largo",
    "larguitos": "largo",
    "larguras": "largura",
    "largá": "largar",
    "largámo": "largar",
    "largámos": "largar",
    "largáramo": "largar",
    "largáramos": "largar",
    "largárei": "largar",
    "largáreis": "largar",
    "largásseis": "largar",
    "largássemos": "largar",
    "largávamo": "largar",
    "largávamos": "largar",
    "largávei": "largar",
    "largáveis": "largável",
    "largíflua": "largífluo",
    "largífluas": "largífluo",
    "largífluos": "largífluo",
    "laricas": "larica",
    "laringalgias": "laringalgia",
    "laringectomias": "laringectomia",
    "laringes": "laringe",
    "laringiana": "laringiano",
    "laringianas": "laringiano",
    "laringianos": "laringiano",
    "laringites": "laringite",
    "laringofissuras": "laringofissura",
    "laringografias": "laringografia",
    "laringologias": "laringologia",
    "laringologistas": "laringologista",
    "laringoscopias": "laringoscopia",
    "laringoscópios": "laringoscópio",
    "laringotomias": "laringotomia",
    "laringotraqueotomias": "laringotraqueotomia",
    "larins": "larim",
    "larocas": "laroca",
    "larotas": "larota",
    "larotes": "larote",
    "larozes": "laroz",
    "larros": "larro",
    "larvada": "larvado",
    "larvadas": "larvado",
    "larvados": "larvado",
    "larvais": "larval",
    "larvares": "larvar",
    "larvas": "larva",
    "larvicidas": "larvicida",
    "larviformes": "larviforme",
    "larváceos": "larváceo",
    "larvária": "larvário",
    "larvárias": "larvário",
    "larvários": "larvário",
    "larvícolas": "larvícola",
    "larvípara": "larvíparo",
    "larvíparas": "larvíparo",
    "larvíparos": "larvíparo",
    "larvívora": "larvívoro",
    "larvívoras": "larvívoro",
    "larvívoros": "larvívoro",
    "larvófagos": "larvófago",
    "larápia": "larápio",
    "larápias": "larápio",
    "larápios": "larápio",
    "larários": "larário",
    "larés": "laré",
    "laréus": "laréu",
    "larídeos": "larídeo",
    "laríneas": "larínea",
    "laríngea": "laríngeo",
    "laríngeas": "laríngeo",
    "laríngeos": "laríngeo",
    "larós": "laró",
    "las": "o",
    "lasanhas": "lasanha",
    "lasca": "lascar",
    "lascada": "lascar",
    "lascadas": "lascar",
    "lascado": "lascar",
    "lascados": "lascar",
    "lascai": "lascar",
    "lascais": "lascar",
    "lascam": "lascar",
    "lascamo": "lascar",
    "lascamos": "lascar",
    "lascando": "lascar",
    "lascara": "lascar",
    "lascaram": "lascar",
    "lascaras": "lascar",
    "lascarde": "lascar",
    "lascardes": "lascar",
    "lascare": "lascar",
    "lascarei": "lascar",
    "lascareis": "lascar",
    "lascarem": "lascar",
    "lascaremos": "lascar",
    "lascares": "lascar",
    "lascaria": "lascar",
    "lascariam": "lascar",
    "lascarias": "lascar",
    "lascarinha": "lascarinho",
    "lascarinhas": "lascarinho",
    "lascarinhos": "lascarinho",
    "lascarins": "lascarim",
    "lascaris": "lascari",
    "lascarmo": "lascar",
    "lascarmos": "lascar",
    "lascará": "lascar",
    "lascarás": "lascar",
    "lascarão": "lascar",
    "lascaríamos": "lascar",
    "lascaríeis": "lascar",
    "lascas": "lascar",
    "lascasse": "lascar",
    "lascassem": "lascar",
    "lascasses": "lascar",
    "lascaste": "lascar",
    "lascastes": "lascar",
    "lascava": "lascar",
    "lascavam": "lascar",
    "lascavas": "lascar",
    "lasciva": "lascivo",
    "lascivas": "lascivo",
    "lascivos": "lascivo",
    "lasco": "lascar",
    "lascou": "lascar",
    "lascá": "lascar",
    "lascámo": "lascar",
    "lascámos": "lascar",
    "lascáramo": "lascar",
    "lascáramos": "lascar",
    "lascárei": "lascar",
    "lascáreis": "lascar",
    "lascásseis": "lascar",
    "lascássemos": "lascar",
    "lascávamo": "lascar",
    "lascávamos": "lascar",
    "lascávei": "lascar",
    "lascáveis": "lascável",
    "lascívias": "lascívia",
    "laseres": "laser",
    "lasionites": "lasionite",
    "lasque": "lascar",
    "lasquei": "lascar",
    "lasqueis": "lascar",
    "lasquem": "lascar",
    "lasquemo": "lascar",
    "lasquemos": "lascar",
    "lasques": "lascar",
    "lasquinha": "lasca",
    "lasquinhas": "lasca",
    "lasquita": "lasca",
    "lasquitas": "lasca",
    "lassa": "lasso",
    "lassada": "lassar",
    "lassadas": "lassar",
    "lassado": "lassar",
    "lassados": "lassar",
    "lassai": "lassar",
    "lassais": "lassar",
    "lassam": "lassar",
    "lassamo": "lassar",
    "lassamos": "lassar",
    "lassando": "lassar",
    "lassara": "lassar",
    "lassaram": "lassar",
    "lassaras": "lassar",
    "lassarde": "lassar",
    "lassardes": "lassar",
    "lassare": "lassar",
    "lassarei": "lassar",
    "lassareis": "lassar",
    "lassarem": "lassar",
    "lassaremos": "lassar",
    "lassares": "lassar",
    "lassaria": "lassar",
    "lassariam": "lassar",
    "lassarias": "lassar",
    "lassarmo": "lassar",
    "lassarmos": "lassar",
    "lassará": "lassar",
    "lassarás": "lassar",
    "lassarão": "lassar",
    "lassaríamos": "lassar",
    "lassaríeis": "lassar",
    "lassas": "lasso",
    "lassasse": "lassar",
    "lassassem": "lassar",
    "lassasses": "lassar",
    "lassaste": "lassar",
    "lassastes": "lassar",
    "lassava": "lassar",
    "lassavam": "lassar",
    "lassavas": "lassar",
    "lasse": "lassar",
    "lassei": "lassar",
    "lasseira": "lasseiro",
    "lasseiras": "lasseiro",
    "lasseiros": "lasseiro",
    "lasseis": "lassar",
    "lassem": "lassar",
    "lassemo": "lassar",
    "lassemos": "lassar",
    "lasses": "lassar",
    "lassidões": "lassidão",
    "lassitudes": "lassitude",
    "lasso": "lassar",
    "lassos": "lasso",
    "lassou": "lassar",
    "lassá": "lassar",
    "lassámo": "lassar",
    "lassámos": "lassar",
    "lassáramo": "lassar",
    "lassáramos": "lassar",
    "lassárei": "lassar",
    "lassáreis": "lassar",
    "lassásseis": "lassar",
    "lassássemos": "lassar",
    "lassávamo": "lassar",
    "lassávamos": "lassar",
    "lassávei": "lassar",
    "lassáveis": "lassável",
    "lastima": "lastimar",
    "lastimada": "lastimar",
    "lastimadas": "lastimar",
    "lastimado": "lastimar",
    "lastimadora": "lastimador",
    "lastimadoras": "lastimador",
    "lastimadores": "lastimador",
    "lastimados": "lastimar",
    "lastimai": "lastimar",
    "lastimais": "lastimar",
    "lastimam": "lastimar",
    "lastimamo": "lastimar",
    "lastimamos": "lastimar",
    "lastimando": "lastimar",
    "lastimara": "lastimar",
    "lastimaram": "lastimar",
    "lastimaras": "lastimar",
    "lastimarde": "lastimar",
    "lastimardes": "lastimar",
    "lastimare": "lastimar",
    "lastimarei": "lastimar",
    "lastimareis": "lastimar",
    "lastimarem": "lastimar",
    "lastimaremos": "lastimar",
    "lastimares": "lastimar",
    "lastimaria": "lastimar",
    "lastimariam": "lastimar",
    "lastimarias": "lastimar",
    "lastimarmo": "lastimar",
    "lastimarmos": "lastimar",
    "lastimará": "lastimar",
    "lastimarás": "lastimar",
    "lastimarão": "lastimar",
    "lastimaríamos": "lastimar",
    "lastimaríeis": "lastimar",
    "lastimas": "lastimar",
    "lastimasse": "lastimar",
    "lastimassem": "lastimar",
    "lastimasses": "lastimar",
    "lastimaste": "lastimar",
    "lastimastes": "lastimar",
    "lastimava": "lastimar",
    "lastimavam": "lastimar",
    "lastimavas": "lastimar",
    "lastime": "lastimar",
    "lastimei": "lastimar",
    "lastimeis": "lastimar",
    "lastimem": "lastimar",
    "lastimemo": "lastimar",
    "lastimemos": "lastimar",
    "lastimes": "lastimar",
    "lastimo": "lastimar",
    "lastimosa": "lastimoso",
    "lastimosas": "lastimoso",
    "lastimosos": "lastimoso",
    "lastimou": "lastimar",
    "lastimá": "lastimar",
    "lastimámo": "lastimar",
    "lastimámos": "lastimar",
    "lastimáramo": "lastimar",
    "lastimáramos": "lastimar",
    "lastimárei": "lastimar",
    "lastimáreis": "lastimar",
    "lastimásseis": "lastimar",
    "lastimássemos": "lastimar",
    "lastimávamo": "lastimar",
    "lastimávamos": "lastimar",
    "lastimávei": "lastimar",
    "lastimáveis": "lastimável",
    "lastra": "lastrar",
    "lastrada": "lastrar",
    "lastradas": "lastrar",
    "lastrado": "lastrar",
    "lastradora": "lastrador",
    "lastradoras": "lastrador",
    "lastradores": "lastrador",
    "lastrados": "lastrar",
    "lastrai": "lastrar",
    "lastrais": "lastrar",
    "lastram": "lastrar",
    "lastramo": "lastrar",
    "lastramos": "lastrar",
    "lastrando": "lastrar",
    "lastrara": "lastrar",
    "lastraram": "lastrar",
    "lastraras": "lastrar",
    "lastrarde": "lastrar",
    "lastrardes": "lastrar",
    "lastrare": "lastrar",
    "lastrarei": "lastrar",
    "lastrareis": "lastrar",
    "lastrarem": "lastrar",
    "lastraremos": "lastrar",
    "lastrares": "lastrar",
    "lastraria": "lastrar",
    "lastrariam": "lastrar",
    "lastrarias": "lastrar",
    "lastrarmo": "lastrar",
    "lastrarmos": "lastrar",
    "lastrará": "lastrar",
    "lastrarás": "lastrar",
    "lastrarão": "lastrar",
    "lastraríamos": "lastrar",
    "lastraríeis": "lastrar",
    "lastras": "lastrar",
    "lastrasse": "lastrar",
    "lastrassem": "lastrar",
    "lastrasses": "lastrar",
    "lastraste": "lastrar",
    "lastrastes": "lastrar",
    "lastrava": "lastrar",
    "lastravam": "lastrar",
    "lastravas": "lastrar",
    "lastrações": "lastração",
    "lastre": "lastrar",
    "lastrei": "lastrar",
    "lastreis": "lastrar",
    "lastrem": "lastrar",
    "lastremo": "lastrar",
    "lastremos": "lastrar",
    "lastres": "lastrar",
    "lastro": "lastrar",
    "lastros": "lastro",
    "lastrou": "lastrar",
    "lastrá": "lastrar",
    "lastrámo": "lastrar",
    "lastrámos": "lastrar",
    "lastráramo": "lastrar",
    "lastráramos": "lastrar",
    "lastrárei": "lastrar",
    "lastráreis": "lastrar",
    "lastrásseis": "lastrar",
    "lastrássemos": "lastrar",
    "lastrávamo": "lastrar",
    "lastrávamos": "lastrar",
    "lastrávei": "lastrar",
    "lastráveis": "lastrar",
    "lata": "lato",
    "latadas": "latada",
    "latagona": "latagão",
    "latagonas": "latagão",
    "latagões": "latagão",
    "latais": "latir",
    "latam": "latir",
    "latamo": "latir",
    "latamos": "latir",
    "latarias": "lataria",
    "latas": "lato",
    "late": "latir",
    "lateada": "latear",
    "lateadas": "latear",
    "lateado": "latear",
    "lateados": "latear",
    "lateai": "latear",
    "lateais": "latear",
    "lateamo": "latear",
    "lateamos": "latear",
    "lateando": "latear",
    "lateara": "latear",
    "latearam": "latear",
    "latearas": "latear",
    "latearde": "latear",
    "lateardes": "latear",
    "lateare": "latear",
    "latearei": "latear",
    "lateareis": "latear",
    "latearem": "latear",
    "latearemos": "latear",
    "lateares": "latear",
    "latearia": "latear",
    "lateariam": "latear",
    "latearias": "latear",
    "latearmo": "latear",
    "latearmos": "latear",
    "lateará": "latear",
    "latearás": "latear",
    "latearão": "latear",
    "latearíamos": "latear",
    "latearíeis": "latear",
    "lateasse": "latear",
    "lateassem": "latear",
    "lateasses": "latear",
    "lateaste": "latear",
    "lateastes": "latear",
    "lateava": "latear",
    "lateavam": "latear",
    "lateavas": "latear",
    "latebrosa": "latebroso",
    "latebrosas": "latebroso",
    "latebrosos": "latebroso",
    "lateei": "latear",
    "lateeis": "latear",
    "lateemo": "latear",
    "lateemos": "latear",
    "lategadas": "lategada",
    "latei": "later",
    "lateia": "latear",
    "lateiam": "latear",
    "lateias": "latear",
    "lateie": "latear",
    "lateiem": "latear",
    "lateies": "latear",
    "lateio": "latear",
    "lateiros": "lateiro",
    "lateis": "later",
    "lateja": "latejar",
    "latejada": "latejar",
    "latejadas": "latejar",
    "latejado": "latejar",
    "latejados": "latejar",
    "latejai": "latejar",
    "latejais": "latejar",
    "latejam": "latejar",
    "latejamo": "latejar",
    "latejamos": "latejar",
    "latejando": "latejar",
    "latejantes": "latejante",
    "latejara": "latejar",
    "latejaram": "latejar",
    "latejaras": "latejar",
    "latejardes": "latejar",
    "latejarei": "latejar",
    "latejareis": "latejar",
    "latejarem": "latejar",
    "latejaremos": "latejar",
    "latejares": "latejar",
    "latejaria": "latejar",
    "latejariam": "latejar",
    "latejarias": "latejar",
    "latejarmo": "latejar",
    "latejarmos": "latejar",
    "latejará": "latejar",
    "latejarás": "latejar",
    "latejarão": "latejar",
    "latejaríamos": "latejar",
    "latejaríeis": "latejar",
    "latejas": "latejar",
    "latejasse": "latejar",
    "latejassem": "latejar",
    "latejasses": "latejar",
    "latejaste": "latejar",
    "latejastes": "latejar",
    "latejava": "latejar",
    "latejavam": "latejar",
    "latejavas": "latejar",
    "lateje": "latejar",
    "latejei": "latejar",
    "latejeis": "latejar",
    "latejem": "latejar",
    "latejemo": "latejar",
    "latejemos": "latejar",
    "latejes": "latejar",
    "latejo": "latejar",
    "latejos": "latejo",
    "latejou": "latejar",
    "latejámo": "latejar",
    "latejámos": "latejar",
    "latejáramo": "latejar",
    "latejáramos": "latejar",
    "latejáreis": "latejar",
    "latejásseis": "latejar",
    "latejássemos": "latejar",
    "latejávamo": "latejar",
    "latejávamos": "latejar",
    "latejáveis": "latejar",
    "latem": "latir",
    "latemo": "later",
    "latemos": "later",
    "latendo": "later",
    "latentes": "latente",
    "lateou": "latear",
    "latera": "later",
    "laterais": "lateral",
    "lateralidades": "lateralidade",
    "lateralinérvea": "lateralinérveo",
    "lateralinérveas": "lateralinérveo",
    "lateralinérveos": "lateralinérveo",
    "lateraliza": "lateralizar",
    "lateralizada": "lateralizar",
    "lateralizadas": "lateralizar",
    "lateralizado": "lateralizar",
    "lateralizados": "lateralizar",
    "lateralizai": "lateralizar",
    "lateralizais": "lateralizar",
    "lateralizam": "lateralizar",
    "lateralizamo": "lateralizar",
    "lateralizamos": "lateralizar",
    "lateralizando": "lateralizar",
    "lateralizara": "lateralizar",
    "lateralizaram": "lateralizar",
    "lateralizaras": "lateralizar",
    "lateralizarde": "lateralizar",
    "lateralizardes": "lateralizar",
    "lateralizare": "lateralizar",
    "lateralizarei": "lateralizar",
    "lateralizareis": "lateralizar",
    "lateralizarem": "lateralizar",
    "lateralizaremos": "lateralizar",
    "lateralizares": "lateralizar",
    "lateralizaria": "lateralizar",
    "lateralizariam": "lateralizar",
    "lateralizarias": "lateralizar",
    "lateralizarmo": "lateralizar",
    "lateralizarmos": "lateralizar",
    "lateralizará": "lateralizar",
    "lateralizarás": "lateralizar",
    "lateralizarão": "lateralizar",
    "lateralizaríamos": "lateralizar",
    "lateralizaríeis": "lateralizar",
    "lateralizas": "lateralizar",
    "lateralizasse": "lateralizar",
    "lateralizassem": "lateralizar",
    "lateralizasses": "lateralizar",
    "lateralizaste": "lateralizar",
    "lateralizastes": "lateralizar",
    "lateralizava": "lateralizar",
    "lateralizavam": "lateralizar",
    "lateralizavas": "lateralizar",
    "lateralize": "lateralizar",
    "lateralizei": "lateralizar",
    "lateralizeis": "lateralizar",
    "lateralizem": "lateralizar",
    "lateralizemo": "lateralizar",
    "lateralizemos": "lateralizar",
    "lateralizes": "lateralizar",
    "lateralizo": "lateralizar",
    "lateralizou": "lateralizar",
    "lateralizá": "lateralizar",
    "lateralizámo": "lateralizar",
    "lateralizámos": "lateralizar",
    "lateralizáramo": "lateralizar",
    "lateralizáramos": "lateralizar",
    "lateralizárei": "lateralizar",
    "lateralizáreis": "lateralizar",
    "lateralizásseis": "lateralizar",
    "lateralizássemos": "lateralizar",
    "lateralizávamo": "lateralizar",
    "lateralizávamos": "lateralizar",
    "lateralizávei": "lateralizar",
    "lateralizáveis": "lateralizar",
    "lateram": "later",
    "lateranenses": "lateranense",
    "lateras": "later",
    "laterdes": "later",
    "laterei": "later",
    "latereis": "later",
    "laterem": "later",
    "lateremos": "later",
    "lateres": "later",
    "lateria": "later",
    "lateriam": "later",
    "laterias": "later",
    "lateriflora": "laterifloro",
    "laterifloras": "laterifloro",
    "laterifloros": "laterifloro",
    "laterifólia": "laterifólio",
    "laterifólias": "laterifólio",
    "laterifólios": "laterifólio",
    "laterites": "laterite",
    "lateritizações": "lateritização",
    "lateriversões": "lateriversão",
    "latermo": "later",
    "latermos": "later",
    "lateroversões": "lateroversão",
    "laterá": "later",
    "laterás": "later",
    "laterão": "later",
    "lateríamos": "later",
    "laterícia": "laterício",
    "laterícias": "laterício",
    "laterícios": "laterício",
    "lateríeis": "later",
    "lates": "latir",
    "latescências": "latescência",
    "latesse": "later",
    "latessem": "later",
    "latesses": "later",
    "lateste": "later",
    "latestes": "later",
    "lateu": "later",
    "lateá": "latear",
    "lateámo": "latear",
    "lateámos": "latear",
    "lateáramo": "latear",
    "lateáramos": "latear",
    "lateárei": "latear",
    "lateáreis": "latear",
    "lateásseis": "latear",
    "lateássemos": "latear",
    "lateávamo": "latear",
    "lateávamos": "latear",
    "lateávei": "latear",
    "lateáveis": "latear",
    "lati": "latir",
    "latia": "latir",
    "latiam": "latir",
    "latias": "latir",
    "laticlavos": "laticlavo",
    "laticlávios": "laticlávio",
    "laticífera": "laticífero",
    "laticíferas": "laticífero",
    "laticíferos": "laticífero",
    "laticórnea": "laticórneo",
    "laticórneas": "laticórneo",
    "laticórneos": "laticórneo",
    "latida": "latir",
    "latidas": "latir",
    "latido": "latir",
    "latidos": "latir",
    "latiflora": "latifloro",
    "latifloras": "latifloro",
    "latifloros": "latifloro",
    "latifoliada": "latifoliado",
    "latifoliadas": "latifoliado",
    "latifoliados": "latifoliado",
    "latifundiária": "latifundiário",
    "latifundiárias": "latifundiário",
    "latifundiários": "latifundiário",
    "latifólia": "latifólio",
    "latifólias": "latifólio",
    "latifólios": "latifólio",
    "latifúndios": "latifúndio",
    "latilabra": "latilabro",
    "latilabras": "latilabro",
    "latilabros": "latilabro",
    "latimo": "latir",
    "latimos": "latir",
    "latina": "latino",
    "latinada": "latinar",
    "latinadas": "latinar",
    "latinado": "latinar",
    "latinados": "latinar",
    "latinai": "latinar",
    "latinais": "latinar",
    "latinam": "latinar",
    "latinamo": "latinar",
    "latinamos": "latinar",
    "latinando": "latinar",
    "latinara": "latinar",
    "latinaram": "latinar",
    "latinaras": "latinar",
    "latinardes": "latinar",
    "latinarei": "latinar",
    "latinareis": "latinar",
    "latinarem": "latinar",
    "latinaremos": "latinar",
    "latinares": "latinar",
    "latinaria": "latinar",
    "latinariam": "latinar",
    "latinarias": "latinar",
    "latinarmo": "latinar",
    "latinarmos": "latinar",
    "latinará": "latinar",
    "latinarás": "latinar",
    "latinarão": "latinar",
    "latinaríamos": "latinar",
    "latinaríeis": "latinar",
    "latinas": "latino",
    "latinasse": "latinar",
    "latinassem": "latinar",
    "latinasses": "latinar",
    "latinaste": "latinar",
    "latinastes": "latinar",
    "latinava": "latinar",
    "latinavam": "latinar",
    "latinavas": "latinar",
    "latindo": "latir",
    "latine": "latinar",
    "latinei": "latinar",
    "latineis": "latinar",
    "latinem": "latinar",
    "latinemo": "latinar",
    "latinemos": "latinar",
    "latines": "latinar",
    "latinha": "lata",
    "latinhas": "lata",
    "latinices": "latinice",
    "latinidades": "latinidade",
    "latiniparlas": "latiniparla",
    "latinismos": "latinismo",
    "latinistas": "latinista",
    "latiniza": "latinizar",
    "latinizada": "latinizar",
    "latinizadas": "latinizar",
    "latinizado": "latinizar",
    "latinizados": "latinizar",
    "latinizai": "latinizar",
    "latinizais": "latinizar",
    "latinizam": "latinizar",
    "latinizamo": "latinizar",
    "latinizamos": "latinizar",
    "latinizando": "latinizar",
    "latinizantes": "latinizante",
    "latinizara": "latinizar",
    "latinizaram": "latinizar",
    "latinizaras": "latinizar",
    "latinizarde": "latinizar",
    "latinizardes": "latinizar",
    "latinizare": "latinizar",
    "latinizarei": "latinizar",
    "latinizareis": "latinizar",
    "latinizarem": "latinizar",
    "latinizaremos": "latinizar",
    "latinizares": "latinizar",
    "latinizaria": "latinizar",
    "latinizariam": "latinizar",
    "latinizarias": "latinizar",
    "latinizarmo": "latinizar",
    "latinizarmos": "latinizar",
    "latinizará": "latinizar",
    "latinizarás": "latinizar",
    "latinizarão": "latinizar",
    "latinizaríamos": "latinizar",
    "latinizaríeis": "latinizar",
    "latinizas": "latinizar",
    "latinizasse": "latinizar",
    "latinizassem": "latinizar",
    "latinizasses": "latinizar",
    "latinizaste": "latinizar",
    "latinizastes": "latinizar",
    "latinizava": "latinizar",
    "latinizavam": "latinizar",
    "latinizavas": "latinizar",
    "latinizações": "latinização",
    "latinize": "latinizar",
    "latinizei": "latinizar",
    "latinizeis": "latinizar",
    "latinizem": "latinizar",
    "latinizemo": "latinizar",
    "latinizemos": "latinizar",
    "latinizes": "latinizar",
    "latinizo": "latinizar",
    "latinizou": "latinizar",
    "latinizá": "latinizar",
    "latinizámo": "latinizar",
    "latinizámos": "latinizar",
    "latinizáramo": "latinizar",
    "latinizáramos": "latinizar",
    "latinizárei": "latinizar",
    "latinizáreis": "latinizar",
    "latinizásseis": "latinizar",
    "latinizássemos": "latinizar",
    "latinizávamo": "latinizar",
    "latinizávamos": "latinizar",
    "latinizávei": "latinizar",
    "latinizáveis": "latinizável",
    "latino": "latinar",
    "latinos": "latino",
    "latinou": "latinar",
    "latins": "latim",
    "latinzinho": "latim",
    "latinzinhos": "latim",
    "latinzito": "latim",
    "latinzitos": "latim",
    "latinámo": "latinar",
    "latinámos": "latinar",
    "latináramo": "latinar",
    "latináramos": "latinar",
    "latináreis": "latinar",
    "latinásseis": "latinar",
    "latinássemos": "latinar",
    "latinávamo": "latinar",
    "latinávamos": "latinar",
    "latináveis": "latinar",
    "latinórios": "latinório",
    "latipenes": "latipene",
    "latira": "latir",
    "latiram": "latir",
    "latiras": "latir",
    "latirdes": "latir",
    "latirei": "latir",
    "latireis": "latir",
    "latirem": "latir",
    "latiremos": "latir",
    "latires": "latir",
    "latiria": "latir",
    "latiriam": "latir",
    "latirias": "latir",
    "latirinas": "latirina",
    "latirismos": "latirismo",
    "latirmo": "latir",
    "latirmos": "latir",
    "latirrostra": "latirrostro",
    "latirrostras": "latirrostro",
    "latirrostros": "latirrostro",
    "latirá": "latir",
    "latirás": "latir",
    "latirão": "latir",
    "latiríamos": "latir",
    "latiríeis": "latir",
    "latis": "latir",
    "latisse": "latir",
    "latissem": "latir",
    "latisses": "latir",
    "latiste": "latir",
    "latistes": "latir",
    "latita": "lata",
    "latitas": "lata",
    "latitudes": "latitude",
    "latitudinária": "latitudinário",
    "latitudinárias": "latitudinário",
    "latitudinários": "latitudinário",
    "latiu": "latir",
    "lato": "latir",
    "latoadas": "latoada",
    "latoarias": "latoaria",
    "latoeira": "latoeiro",
    "latoeiras": "latoeiro",
    "latoeiros": "latoeiro",
    "latos": "lato",
    "latosas": "latosa",
    "latrantes": "latrante",
    "latrias": "latria",
    "latrinas": "latrina",
    "latrineira": "latrineiro",
    "latrineiras": "latrineiro",
    "latrineiros": "latrineiro",
    "latrinária": "latrinário",
    "latrinárias": "latrinário",
    "latrinários": "latrinário",
    "latrocina": "latrocinar",
    "latrocinada": "latrocinar",
    "latrocinadas": "latrocinar",
    "latrocinado": "latrocinar",
    "latrocinados": "latrocinar",
    "latrocinai": "latrocinar",
    "latrocinais": "latrocinar",
    "latrocinam": "latrocinar",
    "latrocinamo": "latrocinar",
    "latrocinamos": "latrocinar",
    "latrocinando": "latrocinar",
    "latrocinara": "latrocinar",
    "latrocinaram": "latrocinar",
    "latrocinaras": "latrocinar",
    "latrocinarde": "latrocinar",
    "latrocinardes": "latrocinar",
    "latrocinare": "latrocinar",
    "latrocinarei": "latrocinar",
    "latrocinareis": "latrocinar",
    "latrocinarem": "latrocinar",
    "latrocinaremos": "latrocinar",
    "latrocinares": "latrocinar",
    "latrocinaria": "latrocinar",
    "latrocinariam": "latrocinar",
    "latrocinarias": "latrocinar",
    "latrocinarmo": "latrocinar",
    "latrocinarmos": "latrocinar",
    "latrocinará": "latrocinar",
    "latrocinarás": "latrocinar",
    "latrocinarão": "latrocinar",
    "latrocinaríamos": "latrocinar",
    "latrocinaríeis": "latrocinar",
    "latrocinas": "latrocinar",
    "latrocinasse": "latrocinar",
    "latrocinassem": "latrocinar",
    "latrocinasses": "latrocinar",
    "latrocinaste": "latrocinar",
    "latrocinastes": "latrocinar",
    "latrocinava": "latrocinar",
    "latrocinavam": "latrocinar",
    "latrocinavas": "latrocinar",
    "latrocine": "latrocinar",
    "latrocinei": "latrocinar",
    "latrocineis": "latrocinar",
    "latrocinem": "latrocinar",
    "latrocinemo": "latrocinar",
    "latrocinemos": "latrocinar",
    "latrocines": "latrocinar",
    "latrocino": "latrocinar",
    "latrocinou": "latrocinar",
    "latrociná": "latrocinar",
    "latrocinámo": "latrocinar",
    "latrocinámos": "latrocinar",
    "latrocináramo": "latrocinar",
    "latrocináramos": "latrocinar",
    "latrocinárei": "latrocinar",
    "latrocináreis": "latrocinar",
    "latrocinásseis": "latrocinar",
    "latrocinássemos": "latrocinar",
    "latrocinávamo": "latrocinar",
    "latrocinávamos": "latrocinar",
    "latrocinávei": "latrocinar",
    "latrocináveis": "latrocinar",
    "latrocínios": "latrocínio",
    "latências": "latência",
    "latêramo": "later",
    "latêramos": "later",
    "latêreis": "later",
    "latêsseis": "later",
    "latêssemos": "later",
    "latíamo": "latir",
    "latíamos": "latir",
    "latíbulos": "latíbulo",
    "latíeis": "latir",
    "latímana": "latímano",
    "latímanas": "latímano",
    "latímanos": "latímano",
    "latípedes": "latípede",
    "latíramo": "latir",
    "latíramos": "latir",
    "latíreis": "latir",
    "latísseis": "latir",
    "latíssemos": "latir",
    "latões": "latão",
    "laudabilidades": "laudabilidade",
    "laudaninas": "laudanina",
    "laudaniza": "laudanizar",
    "laudanizada": "laudanizar",
    "laudanizadas": "laudanizar",
    "laudanizado": "laudanizar",
    "laudanizados": "laudanizar",
    "laudanizai": "laudanizar",
    "laudanizais": "laudanizar",
    "laudanizam": "laudanizar",
    "laudanizamo": "laudanizar",
    "laudanizamos": "laudanizar",
    "laudanizando": "laudanizar",
    "laudanizara": "laudanizar",
    "laudanizaram": "laudanizar",
    "laudanizaras": "laudanizar",
    "laudanizarde": "laudanizar",
    "laudanizardes": "laudanizar",
    "laudanizare": "laudanizar",
    "laudanizarei": "laudanizar",
    "laudanizareis": "laudanizar",
    "laudanizarem": "laudanizar",
    "laudanizaremos": "laudanizar",
    "laudanizares": "laudanizar",
    "laudanizaria": "laudanizar",
    "laudanizariam": "laudanizar",
    "laudanizarias": "laudanizar",
    "laudanizarmo": "laudanizar",
    "laudanizarmos": "laudanizar",
    "laudanizará": "laudanizar",
    "laudanizarás": "laudanizar",
    "laudanizarão": "laudanizar",
    "laudanizaríamos": "laudanizar",
    "laudanizaríeis": "laudanizar",
    "laudanizas": "laudanizar",
    "laudanizasse": "laudanizar",
    "laudanizassem": "laudanizar",
    "laudanizasses": "laudanizar",
    "laudanizaste": "laudanizar",
    "laudanizastes": "laudanizar",
    "laudanizava": "laudanizar",
    "laudanizavam": "laudanizar",
    "laudanizavas": "laudanizar",
    "laudanize": "laudanizar",
    "laudanizei": "laudanizar",
    "laudanizeis": "laudanizar",
    "laudanizem": "laudanizar",
    "laudanizemo": "laudanizar",
    "laudanizemos": "laudanizar",
    "laudanizes": "laudanizar",
    "laudanizo": "laudanizar",
    "laudanizou": "laudanizar",
    "laudanizá": "laudanizar",
    "laudanizámo": "laudanizar",
    "laudanizámos": "laudanizar",
    "laudanizáramo": "laudanizar",
    "laudanizáramos": "laudanizar",
    "laudanizárei": "laudanizar",
    "laudanizáreis": "laudanizar",
    "laudanizásseis": "laudanizar",
    "laudanizássemos": "laudanizar",
    "laudanizávamo": "laudanizar",
    "laudanizávamos": "laudanizar",
    "laudanizávei": "laudanizar",
    "laudanizáveis": "laudanizar",
    "laudas": "lauda",
    "laudativa": "laudativo",
    "laudativas": "laudativo",
    "laudativos": "laudativo",
    "laudatícia": "laudatício",
    "laudatícias": "laudatício",
    "laudatícios": "laudatício",
    "laudatória": "laudatório",
    "laudatórias": "laudatório",
    "laudatórios": "laudatório",
    "laudos": "laudo",
    "laudáveis": "laudável",
    "laudânica": "laudânico",
    "laudânicas": "laudânico",
    "laudânicos": "laudânico",
    "laudéis": "laudel",
    "laudémios": "laudémio",
    "lauras": "laura",
    "laurbanenses": "laurbanense",
    "laureada": "laurear",
    "laureadas": "laurear",
    "laureado": "laurear",
    "laureados": "laurear",
    "laureai": "laurear",
    "laureais": "laurear",
    "laureamo": "laurear",
    "laureamos": "laurear",
    "laureando": "laurear",
    "laureara": "laurear",
    "laurearam": "laurear",
    "laurearas": "laurear",
    "laurearde": "laurear",
    "laureardes": "laurear",
    "laureare": "laurear",
    "laurearei": "laurear",
    "laureareis": "laurear",
    "laurearem": "laurear",
    "laurearemos": "laurear",
    "laureares": "laurear",
    "laurearia": "laurear",
    "laureariam": "laurear",
    "laurearias": "laurear",
    "laurearmo": "laurear",
    "laurearmos": "laurear",
    "laureará": "laurear",
    "laurearás": "laurear",
    "laurearão": "laurear",
    "laurearíamos": "laurear",
    "laurearíeis": "laurear",
    "laureasse": "laurear",
    "laureassem": "laurear",
    "laureasses": "laurear",
    "laureaste": "laurear",
    "laureastes": "laurear",
    "laureava": "laurear",
    "laureavam": "laurear",
    "laureavas": "laurear",
    "laureei": "laurear",
    "laureeis": "laurear",
    "laureemo": "laurear",
    "laureemos": "laurear",
    "laureia": "laurear",
    "laureiam": "laurear",
    "laureias": "laurear",
    "laureie": "laurear",
    "laureiem": "laurear",
    "laureies": "laurear",
    "laureio": "laurear",
    "laureios": "laureio",
    "laurenciana": "laurenciano",
    "laurencianas": "laurenciano",
    "laurencianos": "laurenciano",
    "laurentina": "laurentino",
    "laurentinas": "laurentino",
    "laurentinos": "laurentino",
    "laureou": "laurear",
    "laureá": "laurear",
    "laureámo": "laurear",
    "laureámos": "laurear",
    "laureáramo": "laurear",
    "laureáramos": "laurear",
    "laureárei": "laurear",
    "laureáreis": "laurear",
    "laureásseis": "laurear",
    "laureássemos": "laurear",
    "laureávamo": "laurear",
    "laureávamos": "laurear",
    "laureávei": "laurear",
    "laureáveis": "laureável",
    "laurifólia": "laurifólio",
    "laurifólias": "laurifólio",
    "laurifólios": "laurifólio",
    "laurina": "laurino",
    "laurinas": "laurino",
    "laurinos": "laurino",
    "lauráceas": "laurácea",
    "laurásias": "laurásia",
    "lauréis": "laurel",
    "lauréolas": "lauréola",
    "laurêncios": "laurêncio",
    "laurícoma": "laurícomo",
    "laurícomas": "laurícomo",
    "laurícomos": "laurícomo",
    "laurífera": "laurífero",
    "lauríferas": "laurífero",
    "lauríferos": "laurífero",
    "laurígera": "laurígero",
    "laurígeras": "laurígero",
    "laurígeros": "laurígero",
    "laurínea": "lauríneo",
    "lauríneas": "lauríneo",
    "lauríneos": "lauríneo",
    "lausperenes": "lausperene",
    "lauta": "lauto",
    "lautas": "lauto",
    "lautos": "lauto",
    "lava": "lavar",
    "lavabos": "lavabo",
    "lavacros": "lavacro",
    "lavada": "lavar",
    "lavadarias": "lavadaria",
    "lavadas": "lavar",
    "lavadeira": "lavador",
    "lavadeiras": "lavador",
    "lavadeiros": "lavadeiro",
    "lavadelas": "lavadela",
    "lavadiça": "lavadiço",
    "lavadiças": "lavadiço",
    "lavadiços": "lavadiço",
    "lavado": "lavar",
    "lavadoiros": "lavadoiro",
    "lavadora": "lavador",
    "lavadoras": "lavador",
    "lavadores": "lavador",
    "lavados": "lavar",
    "lavadouras": "lavadoura",
    "lavadouros": "lavadouro",
    "lavaduras": "lavadura",
    "lavadíssima": "lavado",
    "lavadíssimas": "lavado",
    "lavadíssimo": "lavado",
    "lavadíssimos": "lavado",
    "lavagantes": "lavagante",
    "lavagens": "lavagem",
    "lavai": "lavar",
    "lavais": "lavar",
    "lavaja": "lavajar",
    "lavajada": "lavajar",
    "lavajadas": "lavajar",
    "lavajado": "lavajar",
    "lavajados": "lavajar",
    "lavajai": "lavajar",
    "lavajais": "lavajar",
    "lavajam": "lavajar",
    "lavajamo": "lavajar",
    "lavajamos": "lavajar",
    "lavajando": "lavajar",
    "lavajara": "lavajar",
    "lavajaram": "lavajar",
    "lavajaras": "lavajar",
    "lavajarde": "lavajar",
    "lavajardes": "lavajar",
    "lavajare": "lavajar",
    "lavajarei": "lavajar",
    "lavajareis": "lavajar",
    "lavajarem": "lavajar",
    "lavajaremos": "lavajar",
    "lavajares": "lavajar",
    "lavajaria": "lavajar",
    "lavajariam": "lavajar",
    "lavajarias": "lavajar",
    "lavajarmo": "lavajar",
    "lavajarmos": "lavajar",
    "lavajará": "lavajar",
    "lavajarás": "lavajar",
    "lavajarão": "lavajar",
    "lavajaríamos": "lavajar",
    "lavajaríeis": "lavajar",
    "lavajas": "lavajar",
    "lavajasse": "lavajar",
    "lavajassem": "lavajar",
    "lavajasses": "lavajar",
    "lavajaste": "lavajar",
    "lavajastes": "lavajar",
    "lavajava": "lavajar",
    "lavajavam": "lavajar",
    "lavajavas": "lavajar",
    "lavaje": "lavajar",
    "lavajei": "lavajar",
    "lavajeis": "lavajar",
    "lavajem": "lavajar",
    "lavajemo": "lavajar",
    "lavajemos": "lavajar",
    "lavajes": "lavajar",
    "lavajo": "lavajar",
    "lavajolas": "lavajola",
    "lavajonas": "lavajona",
    "lavajos": "lavajo",
    "lavajou": "lavajar",
    "lavajá": "lavajar",
    "lavajámo": "lavajar",
    "lavajámos": "lavajar",
    "lavajáramo": "lavajar",
    "lavajáramos": "lavajar",
    "lavajárei": "lavajar",
    "lavajáreis": "lavajar",
    "lavajásseis": "lavajar",
    "lavajássemos": "lavajar",
    "lavajávamo": "lavajar",
    "lavajávamos": "lavajar",
    "lavajávei": "lavajar",
    "lavajáveis": "lavajar",
    "lavam": "lavar",
    "lavamentos": "lavamento",
    "lavamo": "lavar",
    "lavamos": "lavar",
    "lavancos": "lavanco",
    "lavandarias": "lavandaria",
    "lavandas": "lavanda",
    "lavandeira": "lavandeiro",
    "lavandeiras": "lavandeiro",
    "lavandeiros": "lavandeiro",
    "lavanderias": "lavanderia",
    "lavandiscas": "lavandisca",
    "lavando": "lavar",
    "lavara": "lavar",
    "lavaram": "lavar",
    "lavaras": "lavar",
    "lavarde": "lavar",
    "lavardes": "lavar",
    "lavare": "lavar",
    "lavaredas": "lavareda",
    "lavarei": "lavar",
    "lavareis": "lavar",
    "lavarem": "lavar",
    "lavaremos": "lavar",
    "lavares": "lavar",
    "lavaria": "lavar",
    "lavariam": "lavar",
    "lavarias": "lavar",
    "lavarintos": "lavarinto",
    "lavarmo": "lavar",
    "lavarmos": "lavar",
    "lavará": "lavar",
    "lavarás": "lavar",
    "lavarão": "lavar",
    "lavaríamos": "lavar",
    "lavaríeis": "lavar",
    "lavas": "lavar",
    "lavasse": "lavar",
    "lavassem": "lavar",
    "lavasses": "lavar",
    "lavaste": "lavar",
    "lavastes": "lavar",
    "lavativa": "lavativo",
    "lavativas": "lavativo",
    "lavativos": "lavativo",
    "lavatórios": "lavatório",
    "lavava": "lavar",
    "lavavam": "lavar",
    "lavavas": "lavar",
    "lavações": "lavação",
    "lave": "lavar",
    "lavei": "lavar",
    "laveis": "lavar",
    "lavem": "lavar",
    "lavemo": "lavar",
    "lavemos": "lavar",
    "lavercas": "laverca",
    "lavercos": "laverco",
    "laves": "lavar",
    "lavo": "lavar",
    "lavoiras": "lavoira",
    "lavora": "lavorar",
    "lavorada": "lavorar",
    "lavoradas": "lavorar",
    "lavorado": "lavorar",
    "lavorados": "lavorar",
    "lavorai": "lavorar",
    "lavorais": "lavorar",
    "lavoram": "lavorar",
    "lavoramo": "lavorar",
    "lavoramos": "lavorar",
    "lavorando": "lavorar",
    "lavorara": "lavorar",
    "lavoraram": "lavorar",
    "lavoraras": "lavorar",
    "lavorarde": "lavorar",
    "lavorardes": "lavorar",
    "lavorare": "lavorar",
    "lavorarei": "lavorar",
    "lavorareis": "lavorar",
    "lavorarem": "lavorar",
    "lavoraremos": "lavorar",
    "lavorares": "lavorar",
    "lavoraria": "lavorar",
    "lavorariam": "lavorar",
    "lavorarias": "lavorar",
    "lavorarmo": "lavorar",
    "lavorarmos": "lavorar",
    "lavorará": "lavorar",
    "lavorarás": "lavorar",
    "lavorarão": "lavorar",
    "lavoraríamos": "lavorar",
    "lavoraríeis": "lavorar",
    "lavoras": "lavorar",
    "lavorasse": "lavorar",
    "lavorassem": "lavorar",
    "lavorasses": "lavorar",
    "lavoraste": "lavorar",
    "lavorastes": "lavorar",
    "lavorava": "lavorar",
    "lavoravam": "lavorar",
    "lavoravas": "lavorar",
    "lavore": "lavorar",
    "lavorei": "lavorar",
    "lavoreis": "lavorar",
    "lavorem": "lavorar",
    "lavoremo": "lavorar",
    "lavoremos": "lavorar",
    "lavores": "lavorar",
    "lavoro": "lavorar",
    "lavorou": "lavorar",
    "lavorá": "lavorar",
    "lavorámo": "lavorar",
    "lavorámos": "lavorar",
    "lavoráramo": "lavorar",
    "lavoráramos": "lavorar",
    "lavorárei": "lavorar",
    "lavoráreis": "lavorar",
    "lavorásseis": "lavorar",
    "lavorássemos": "lavorar",
    "lavorávamo": "lavorar",
    "lavorávamos": "lavorar",
    "lavorávei": "lavorar",
    "lavoráveis": "lavorar",
    "lavosa": "lavoso",
    "lavosas": "lavoso",
    "lavosos": "lavoso",
    "lavou": "lavar",
    "lavoura": "lavourar",
    "lavourada": "lavourar",
    "lavouradas": "lavourar",
    "lavourado": "lavourar",
    "lavourados": "lavourar",
    "lavourai": "lavourar",
    "lavourais": "lavourar",
    "lavouram": "lavourar",
    "lavouramo": "lavourar",
    "lavouramos": "lavourar",
    "lavourando": "lavourar",
    "lavourara": "lavourar",
    "lavouraram": "lavourar",
    "lavouraras": "lavourar",
    "lavourarde": "lavourar",
    "lavourardes": "lavourar",
    "lavourare": "lavourar",
    "lavourarei": "lavourar",
    "lavourareis": "lavourar",
    "lavourarem": "lavourar",
    "lavouraremos": "lavourar",
    "lavourares": "lavourar",
    "lavouraria": "lavourar",
    "lavourariam": "lavourar",
    "lavourarias": "lavourar",
    "lavourarmo": "lavourar",
    "lavourarmos": "lavourar",
    "lavourará": "lavourar",
    "lavourarás": "lavourar",
    "lavourarão": "lavourar",
    "lavouraríamos": "lavourar",
    "lavouraríeis": "lavourar",
    "lavouras": "lavourar",
    "lavourasse": "lavourar",
    "lavourassem": "lavourar",
    "lavourasses": "lavourar",
    "lavouraste": "lavourar",
    "lavourastes": "lavourar",
    "lavourava": "lavourar",
    "lavouravam": "lavourar",
    "lavouravas": "lavourar",
    "lavoure": "lavourar",
    "lavourei": "lavourar",
    "lavoureis": "lavourar",
    "lavourem": "lavourar",
    "lavouremo": "lavourar",
    "lavouremos": "lavourar",
    "lavoures": "lavourar",
    "lavouro": "lavourar",
    "lavourou": "lavourar",
    "lavourá": "lavourar",
    "lavourámo": "lavourar",
    "lavourámos": "lavourar",
    "lavouráramo": "lavourar",
    "lavouráramos": "lavourar",
    "lavourárei": "lavourar",
    "lavouráreis": "lavourar",
    "lavourásseis": "lavourar",
    "lavourássemos": "lavourar",
    "lavourávamo": "lavourar",
    "lavourávamos": "lavourar",
    "lavourávei": "lavourar",
    "lavouráveis": "lavourar",
    "lavra": "lavrar",
    "lavrada": "lavrar",
    "lavradas": "lavrar",
    "lavradeira": "lavrador",
    "lavradeiras": "lavrador",
    "lavradeiros": "lavradeiro",
    "lavradia": "lavradio",
    "lavradias": "lavradio",
    "lavradios": "lavradio",
    "lavrado": "lavrar",
    "lavradora": "lavrador",
    "lavradoras": "lavrador",
    "lavradores": "lavrador",
    "lavrados": "lavrar",
    "lavragens": "lavragem",
    "lavrai": "lavrar",
    "lavrais": "lavrar",
    "lavram": "lavrar",
    "lavramentos": "lavramento",
    "lavramo": "lavrar",
    "lavramos": "lavrar",
    "lavrando": "lavrar",
    "lavrantes": "lavrante",
    "lavrara": "lavrar",
    "lavraram": "lavrar",
    "lavraras": "lavrar",
    "lavrarde": "lavrar",
    "lavrardes": "lavrar",
    "lavrare": "lavrar",
    "lavrarei": "lavrar",
    "lavrareis": "lavrar",
    "lavrarem": "lavrar",
    "lavraremos": "lavrar",
    "lavrares": "lavrar",
    "lavraria": "lavrar",
    "lavrariam": "lavrar",
    "lavrarias": "lavrar",
    "lavrarmo": "lavrar",
    "lavrarmos": "lavrar",
    "lavrará": "lavrar",
    "lavrarás": "lavrar",
    "lavrarão": "lavrar",
    "lavraríamos": "lavrar",
    "lavraríeis": "lavrar",
    "lavras": "lavrar",
    "lavrasse": "lavrar",
    "lavrassem": "lavrar",
    "lavrasses": "lavrar",
    "lavraste": "lavrar",
    "lavrastes": "lavrar",
    "lavrava": "lavrar",
    "lavravam": "lavrar",
    "lavravas": "lavrar",
    "lavre": "lavrar",
    "lavrei": "lavrar",
    "lavreis": "lavrar",
    "lavrem": "lavrar",
    "lavremo": "lavrar",
    "lavremos": "lavrar",
    "lavres": "lavrar",
    "lavro": "lavrar",
    "lavrou": "lavrar",
    "lavrá": "lavrar",
    "lavrámo": "lavrar",
    "lavrámos": "lavrar",
    "lavráramo": "lavrar",
    "lavráramos": "lavrar",
    "lavrárei": "lavrar",
    "lavráreis": "lavrar",
    "lavrásseis": "lavrar",
    "lavrássemos": "lavrar",
    "lavrávamo": "lavrar",
    "lavrávamos": "lavrar",
    "lavrávei": "lavrar",
    "lavráveis": "lavrável",
    "lavá": "lavar",
    "lavámo": "lavar",
    "lavámos": "lavar",
    "laváramo": "lavar",
    "laváramos": "lavar",
    "lavárei": "lavar",
    "laváreis": "lavar",
    "lavásseis": "lavar",
    "lavássemos": "lavar",
    "lavática": "lavático",
    "laváticas": "lavático",
    "laváticos": "lavático",
    "lavávamo": "lavar",
    "lavávamos": "lavar",
    "lavávei": "lavar",
    "laváveis": "lavável",
    "laxa": "laxo",
    "laxada": "laxar",
    "laxadas": "laxar",
    "laxado": "laxar",
    "laxados": "laxar",
    "laxai": "laxar",
    "laxais": "laxar",
    "laxam": "laxar",
    "laxamo": "laxar",
    "laxamos": "laxar",
    "laxando": "laxar",
    "laxantes": "laxante",
    "laxara": "laxar",
    "laxaram": "laxar",
    "laxaras": "laxar",
    "laxarde": "laxar",
    "laxardes": "laxar",
    "laxare": "laxar",
    "laxarei": "laxar",
    "laxareis": "laxar",
    "laxarem": "laxar",
    "laxaremos": "laxar",
    "laxares": "laxar",
    "laxaria": "laxar",
    "laxariam": "laxar",
    "laxarias": "laxar",
    "laxarmo": "laxar",
    "laxarmos": "laxar",
    "laxará": "laxar",
    "laxarás": "laxar",
    "laxarão": "laxar",
    "laxaríamos": "laxar",
    "laxaríeis": "laxar",
    "laxas": "laxo",
    "laxasse": "laxar",
    "laxassem": "laxar",
    "laxasses": "laxar",
    "laxaste": "laxar",
    "laxastes": "laxar",
    "laxativa": "laxativo",
    "laxativas": "laxativo",
    "laxativos": "laxativo",
    "laxava": "laxar",
    "laxavam": "laxar",
    "laxavas": "laxar",
    "laxações": "laxação",
    "laxe": "laxar",
    "laxei": "laxar",
    "laxeis": "laxar",
    "laxem": "laxar",
    "laxemo": "laxar",
    "laxemos": "laxar",
    "laxes": "laxar",
    "laxidões": "laxidão",
    "laxiflora": "laxifloro",
    "laxifloras": "laxifloro",
    "laxifloros": "laxifloro",
    "laxismos": "laxismo",
    "laxistas": "laxista",
    "laxo": "laxar",
    "laxos": "laxo",
    "laxou": "laxar",
    "laxá": "laxar",
    "laxámo": "laxar",
    "laxámos": "laxar",
    "laxáramo": "laxar",
    "laxáramos": "laxar",
    "laxárei": "laxar",
    "laxáreis": "laxar",
    "laxásseis": "laxar",
    "laxássemos": "laxar",
    "laxávamo": "laxar",
    "laxávamos": "laxar",
    "laxávei": "laxar",
    "laxáveis": "laxar",
    "lazara": "lazarar",
    "lazarada": "lazarar",
    "lazaradas": "lazarar",
    "lazarado": "lazarar",
    "lazarados": "lazarar",
    "lazarai": "lazarar",
    "lazarais": "lazarar",
    "lazaram": "lazarar",
    "lazaramo": "lazarar",
    "lazaramos": "lazarar",
    "lazarando": "lazarar",
    "lazarara": "lazarar",
    "lazararam": "lazarar",
    "lazararas": "lazarar",
    "lazararde": "lazarar",
    "lazarardes": "lazarar",
    "lazarare": "lazarar",
    "lazararei": "lazarar",
    "lazarareis": "lazarar",
    "lazararem": "lazarar",
    "lazararemos": "lazarar",
    "lazarares": "lazarar",
    "lazararia": "lazarar",
    "lazarariam": "lazarar",
    "lazararias": "lazarar",
    "lazararmo": "lazarar",
    "lazararmos": "lazarar",
    "lazarará": "lazarar",
    "lazararás": "lazarar",
    "lazararão": "lazarar",
    "lazararíamos": "lazarar",
    "lazararíeis": "lazarar",
    "lazaras": "lazarar",
    "lazarasse": "lazarar",
    "lazarassem": "lazarar",
    "lazarasses": "lazarar",
    "lazaraste": "lazarar",
    "lazarastes": "lazarar",
    "lazarava": "lazarar",
    "lazaravam": "lazarar",
    "lazaravas": "lazarar",
    "lazare": "lazarar",
    "lazaredos": "lazaredo",
    "lazarei": "lazarar",
    "lazareis": "lazarar",
    "lazarem": "lazarar",
    "lazaremo": "lazarar",
    "lazaremos": "lazarar",
    "lazarenta": "lazarento",
    "lazarentas": "lazarento",
    "lazarentos": "lazarento",
    "lazares": "lazarar",
    "lazarinas": "lazarina",
    "lazarismos": "lazarismo",
    "lazaristas": "lazarista",
    "lazaro": "lazarar",
    "lazarones": "lazarone",
    "lazarou": "lazarar",
    "lazará": "lazarar",
    "lazarámo": "lazarar",
    "lazarámos": "lazarar",
    "lazaráramo": "lazarar",
    "lazaráramos": "lazarar",
    "lazarárei": "lazarar",
    "lazaráreis": "lazarar",
    "lazarásseis": "lazarar",
    "lazarássemos": "lazarar",
    "lazarávamo": "lazarar",
    "lazarávamos": "lazarar",
    "lazarávei": "lazarar",
    "lazaráveis": "lazarar",
    "lazeira": "lazeirar",
    "lazeirada": "lazeirar",
    "lazeiradas": "lazeirar",
    "lazeirado": "lazeirar",
    "lazeirados": "lazeirar",
    "lazeirai": "lazeirar",
    "lazeirais": "lazeirar",
    "lazeiram": "lazeirar",
    "lazeiramo": "lazeirar",
    "lazeiramos": "lazeirar",
    "lazeirando": "lazeirar",
    "lazeirara": "lazeirar",
    "lazeiraram": "lazeirar",
    "lazeiraras": "lazeirar",
    "lazeirardes": "lazeirar",
    "lazeirarei": "lazeirar",
    "lazeirareis": "lazeirar",
    "lazeirarem": "lazeirar",
    "lazeiraremos": "lazeirar",
    "lazeirares": "lazeirar",
    "lazeiraria": "lazeirar",
    "lazeirariam": "lazeirar",
    "lazeirarias": "lazeirar",
    "lazeirarmo": "lazeirar",
    "lazeirarmos": "lazeirar",
    "lazeirará": "lazeirar",
    "lazeirarás": "lazeirar",
    "lazeirarão": "lazeirar",
    "lazeiraríamos": "lazeirar",
    "lazeiraríeis": "lazeirar",
    "lazeiras": "lazeirar",
    "lazeirasse": "lazeirar",
    "lazeirassem": "lazeirar",
    "lazeirasses": "lazeirar",
    "lazeiraste": "lazeirar",
    "lazeirastes": "lazeirar",
    "lazeirava": "lazeirar",
    "lazeiravam": "lazeirar",
    "lazeiravas": "lazeirar",
    "lazeire": "lazeirar",
    "lazeirei": "lazeirar",
    "lazeireis": "lazeirar",
    "lazeirem": "lazeirar",
    "lazeiremo": "lazeirar",
    "lazeiremos": "lazeirar",
    "lazeirenta": "lazeirento",
    "lazeirentas": "lazeirento",
    "lazeirentos": "lazeirento",
    "lazeires": "lazeirar",
    "lazeiro": "lazeirar",
    "lazeirou": "lazeirar",
    "lazeirámo": "lazeirar",
    "lazeirámos": "lazeirar",
    "lazeiráramo": "lazeirar",
    "lazeiráramos": "lazeirar",
    "lazeiráreis": "lazeirar",
    "lazeirásseis": "lazeirar",
    "lazeirássemos": "lazeirar",
    "lazeirávamo": "lazeirar",
    "lazeirávamos": "lazeirar",
    "lazeiráveis": "lazeirar",
    "lazera": "lazerar",
    "lazerada": "lazerar",
    "lazeradas": "lazerar",
    "lazerado": "lazerar",
    "lazerados": "lazerar",
    "lazerai": "lazerar",
    "lazerais": "lazerar",
    "lazeram": "lazerar",
    "lazeramo": "lazerar",
    "lazeramos": "lazerar",
    "lazerando": "lazerar",
    "lazerara": "lazerar",
    "lazeraram": "lazerar",
    "lazeraras": "lazerar",
    "lazerarde": "lazerar",
    "lazerardes": "lazerar",
    "lazerare": "lazerar",
    "lazerarei": "lazerar",
    "lazerareis": "lazerar",
    "lazerarem": "lazerar",
    "lazeraremos": "lazerar",
    "lazerares": "lazerar",
    "lazeraria": "lazerar",
    "lazerariam": "lazerar",
    "lazerarias": "lazerar",
    "lazerarmo": "lazerar",
    "lazerarmos": "lazerar",
    "lazerará": "lazerar",
    "lazerarás": "lazerar",
    "lazerarão": "lazerar",
    "lazeraríamos": "lazerar",
    "lazeraríeis": "lazerar",
    "lazeras": "lazerar",
    "lazerasse": "lazerar",
    "lazerassem": "lazerar",
    "lazerasses": "lazerar",
    "lazeraste": "lazerar",
    "lazerastes": "lazerar",
    "lazerava": "lazerar",
    "lazeravam": "lazerar",
    "lazeravas": "lazerar",
    "lazere": "lazerar",
    "lazerei": "lazerar",
    "lazereis": "lazerar",
    "lazerem": "lazerar",
    "lazeremo": "lazerar",
    "lazeremos": "lazerar",
    "lazeres": "lazerar",
    "lazero": "lazerar",
    "lazerou": "lazerar",
    "lazerá": "lazerar",
    "lazerámo": "lazerar",
    "lazerámos": "lazerar",
    "lazeráramo": "lazerar",
    "lazeráramos": "lazerar",
    "lazerárei": "lazerar",
    "lazeráreis": "lazerar",
    "lazerásseis": "lazerar",
    "lazerássemos": "lazerar",
    "lazerávamo": "lazerar",
    "lazerávamos": "lazerar",
    "lazerávei": "lazerar",
    "lazeráveis": "lazerar",
    "lazulites": "lazulite",
    "lazzos": "lazzo",
    "lazões": "lazão",
    "lazúlis": "lazúli",
    "laça": "laçar",
    "laçada": "laçar",
    "laçadas": "laçar",
    "laçado": "laçar",
    "laçadora": "laçador",
    "laçadoras": "laçador",
    "laçadores": "laçador",
    "laçados": "laçar",
    "laçai": "laçar",
    "laçais": "laçar",
    "laçam": "laçar",
    "laçamo": "laçar",
    "laçamos": "laçar",
    "laçando": "laçar",
    "laçara": "laçar",
    "laçaram": "laçar",
    "laçaras": "laçar",
    "laçarde": "laçar",
    "laçardes": "laçar",
    "laçare": "laçar",
    "laçarei": "laçar",
    "laçareis": "laçar",
    "laçarem": "laçar",
    "laçaremos": "laçar",
    "laçares": "laçar",
    "laçaria": "laçar",
    "laçariam": "laçar",
    "laçarias": "laçaria",
    "laçarmo": "laçar",
    "laçarmos": "laçar",
    "laçarotes": "laçarote",
    "laçará": "laçar",
    "laçarás": "laçar",
    "laçarão": "laçar",
    "laçaríamos": "laçar",
    "laçaríeis": "laçar",
    "laças": "laçar",
    "laçasse": "laçar",
    "laçassem": "laçar",
    "laçasses": "laçar",
    "laçaste": "laçar",
    "laçastes": "laçar",
    "laçava": "laçar",
    "laçavam": "laçar",
    "laçavas": "laçar",
    "laçaços": "laçaço",
    "laço": "laçar",
    "laços": "laço",
    "laçou": "laçar",
    "laçá": "laçar",
    "laçámo": "laçar",
    "laçámos": "laçar",
    "laçáramo": "laçar",
    "laçáramos": "laçar",
    "laçárei": "laçar",
    "laçáreis": "laçar",
    "laçásseis": "laçar",
    "laçássemos": "laçar",
    "laçávamo": "laçar",
    "laçávamos": "laçar",
    "laçávei": "laçar",
    "laçáveis": "laçável",
    "lações": "lação",
    "laúdes": "laúde",
    "leais": "leal",
    "lealda": "lealdar",
    "lealdada": "lealdar",
    "lealdadas": "lealdar",
    "lealdades": "lealdade",
    "lealdado": "lealdar",
    "lealdadora": "lealdador",
    "lealdadoras": "lealdador",
    "lealdadores": "lealdador",
    "lealdados": "lealdar",
    "lealdai": "lealdar",
    "lealdais": "lealdar",
    "lealdam": "lealdar",
    "lealdamentos": "lealdamento",
    "lealdamo": "lealdar",
    "lealdamos": "lealdar",
    "lealdando": "lealdar",
    "lealdara": "lealdar",
    "lealdaram": "lealdar",
    "lealdaras": "lealdar",
    "lealdarde": "lealdar",
    "lealdardes": "lealdar",
    "lealdare": "lealdar",
    "lealdarei": "lealdar",
    "lealdareis": "lealdar",
    "lealdarem": "lealdar",
    "lealdaremos": "lealdar",
    "lealdares": "lealdar",
    "lealdaria": "lealdar",
    "lealdariam": "lealdar",
    "lealdarias": "lealdar",
    "lealdarmo": "lealdar",
    "lealdarmos": "lealdar",
    "lealdará": "lealdar",
    "lealdarás": "lealdar",
    "lealdarão": "lealdar",
    "lealdaríamos": "lealdar",
    "lealdaríeis": "lealdar",
    "lealdas": "lealdar",
    "lealdasse": "lealdar",
    "lealdassem": "lealdar",
    "lealdasses": "lealdar",
    "lealdaste": "lealdar",
    "lealdastes": "lealdar",
    "lealdava": "lealdar",
    "lealdavam": "lealdar",
    "lealdavas": "lealdar",
    "lealdações": "lealdação",
    "lealde": "lealdar",
    "lealdei": "lealdar",
    "lealdeis": "lealdar",
    "lealdem": "lealdar",
    "lealdemo": "lealdar",
    "lealdemos": "lealdar",
    "lealdes": "lealdar",
    "lealdo": "lealdar",
    "lealdosa": "lealdoso",
    "lealdosas": "lealdoso",
    "lealdosos": "lealdoso",
    "lealdou": "lealdar",
    "lealdá": "lealdar",
    "lealdámo": "lealdar",
    "lealdámos": "lealdar",
    "lealdáramo": "lealdar",
    "lealdáramos": "lealdar",
    "lealdárei": "lealdar",
    "lealdáreis": "lealdar",
    "lealdásseis": "lealdar",
    "lealdássemos": "lealdar",
    "lealdávamo": "lealdar",
    "lealdávamos": "lealdar",
    "lealdávei": "lealdar",
    "lealdáveis": "lealdar",
    "lealismos": "lealismo",
    "lebezinha": "lebre",
    "lebezinhas": "lebre",
    "lebezita": "lebre",
    "lebezitas": "lebre",
    "leborinhos": "leborinho",
    "lebrachos": "lebracho",
    "lebradas": "lebrada",
    "lebreira": "lebreiro",
    "lebreiras": "lebreiro",
    "lebreiros": "lebreiro",
    "lebres": "lebre",
    "lebrão": "lebre",
    "lebréis": "lebrel",
    "lebrés": "lebré",
    "lebréus": "lebréu",
    "lebrões": "lebre",
    "lebãozinho": "lebre",
    "lebãozito": "lebre",
    "lebõezinhos": "lebre",
    "lebõezitos": "lebre",
    "lecanomancias": "lecanomancia",
    "lecciona": "leccionar",
    "leccionada": "leccionar",
    "leccionadas": "leccionar",
    "leccionado": "leccionar",
    "leccionadora": "leccionador",
    "leccionadoras": "leccionador",
    "leccionadores": "leccionador",
    "leccionados": "leccionar",
    "leccionai": "leccionar",
    "leccionais": "leccionar",
    "leccionam": "leccionar",
    "leccionamo": "leccionar",
    "leccionamos": "leccionar",
    "leccionanda": "leccionando",
    "leccionandas": "leccionando",
    "leccionando": "leccionar",
    "leccionandos": "leccionando",
    "leccionara": "leccionar",
    "leccionaram": "leccionar",
    "leccionaras": "leccionar",
    "leccionarde": "leccionar",
    "leccionardes": "leccionar",
    "leccionare": "leccionar",
    "leccionarei": "leccionar",
    "leccionareis": "leccionar",
    "leccionarem": "leccionar",
    "leccionaremos": "leccionar",
    "leccionares": "leccionar",
    "leccionaria": "leccionar",
    "leccionariam": "leccionar",
    "leccionarias": "leccionar",
    "leccionarmo": "leccionar",
    "leccionarmos": "leccionar",
    "leccionará": "leccionar",
    "leccionarás": "leccionar",
    "leccionarão": "leccionar",
    "leccionaríamos": "leccionar",
    "leccionaríeis": "leccionar",
    "leccionas": "leccionar",
    "leccionasse": "leccionar",
    "leccionassem": "leccionar",
    "leccionasses": "leccionar",
    "leccionaste": "leccionar",
    "leccionastes": "leccionar",
    "leccionava": "leccionar",
    "leccionavam": "leccionar",
    "leccionavas": "leccionar",
    "leccionações": "leccionação",
    "leccione": "leccionar",
    "leccionei": "leccionar",
    "leccioneis": "leccionar",
    "leccionem": "leccionar",
    "leccionemo": "leccionar",
    "leccionemos": "leccionar",
    "lecciones": "leccionar",
    "leccionistas": "leccionista",
    "lecciono": "leccionar",
    "leccionou": "leccionar",
    "leccioná": "leccionar",
    "leccionámo": "leccionar",
    "leccionámos": "leccionar",
    "leccionáramo": "leccionar",
    "leccionáramos": "leccionar",
    "leccionárei": "leccionar",
    "leccionáreis": "leccionar",
    "leccionários": "leccionário",
    "leccionásseis": "leccionar",
    "leccionássemos": "leccionar",
    "leccionávamo": "leccionar",
    "leccionávamos": "leccionar",
    "leccionávei": "leccionar",
    "leccionáveis": "leccionável",
    "lecheguanas": "lecheguana",
    "lechetrezes": "lechetrez",
    "lecitidáceas": "lecitidácea",
    "lecitinas": "lecitina",
    "lecos": "leco",
    "lecticária": "lecticário",
    "lecticárias": "lecticário",
    "lecticários": "lecticário",
    "lectistérnios": "lectistérnio",
    "lectiva": "lectivo",
    "lectivas": "lectivo",
    "lectivos": "lectivo",
    "lectocéfala": "lectocéfalo",
    "lectocéfalas": "lectocéfalo",
    "lectocéfalos": "lectocéfalo",
    "lectícolas": "lectícola",
    "leda": "ledo",
    "ledas": "ledo",
    "lede": "ler",
    "ledes": "ler",
    "ledianos": "lediano",
    "ledices": "ledice",
    "ledora": "ledor",
    "ledoras": "ledor",
    "ledores": "ledor",
    "ledos": "ledo",
    "lega": "legar",
    "legacias": "legacia",
    "legacões": "legacão",
    "legada": "legar",
    "legadas": "legar",
    "legado": "legar",
    "legados": "legar",
    "legai": "legar",
    "legais": "legar",
    "legalidades": "legalidade",
    "legalismos": "legalismo",
    "legalistas": "legalista",
    "legaliza": "legalizar",
    "legalizada": "legalizar",
    "legalizadas": "legalizar",
    "legalizado": "legalizar",
    "legalizados": "legalizar",
    "legalizai": "legalizar",
    "legalizais": "legalizar",
    "legalizam": "legalizar",
    "legalizamo": "legalizar",
    "legalizamos": "legalizar",
    "legalizando": "legalizar",
    "legalizara": "legalizar",
    "legalizaram": "legalizar",
    "legalizaras": "legalizar",
    "legalizarde": "legalizar",
    "legalizardes": "legalizar",
    "legalizare": "legalizar",
    "legalizarei": "legalizar",
    "legalizareis": "legalizar",
    "legalizarem": "legalizar",
    "legalizaremos": "legalizar",
    "legalizares": "legalizar",
    "legalizaria": "legalizar",
    "legalizariam": "legalizar",
    "legalizarias": "legalizar",
    "legalizarmo": "legalizar",
    "legalizarmos": "legalizar",
    "legalizará": "legalizar",
    "legalizarás": "legalizar",
    "legalizarão": "legalizar",
    "legalizaríamos": "legalizar",
    "legalizaríeis": "legalizar",
    "legalizas": "legalizar",
    "legalizasse": "legalizar",
    "legalizassem": "legalizar",
    "legalizasses": "legalizar",
    "legalizaste": "legalizar",
    "legalizastes": "legalizar",
    "legalizava": "legalizar",
    "legalizavam": "legalizar",
    "legalizavas": "legalizar",
    "legalizações": "legalização",
    "legalize": "legalizar",
    "legalizei": "legalizar",
    "legalizeis": "legalizar",
    "legalizem": "legalizar",
    "legalizemo": "legalizar",
    "legalizemos": "legalizar",
    "legalizes": "legalizar",
    "legalizo": "legalizar",
    "legalizou": "legalizar",
    "legalizá": "legalizar",
    "legalizámo": "legalizar",
    "legalizámos": "legalizar",
    "legalizáramo": "legalizar",
    "legalizáramos": "legalizar",
    "legalizárei": "legalizar",
    "legalizáreis": "legalizar",
    "legalizásseis": "legalizar",
    "legalizássemos": "legalizar",
    "legalizávamo": "legalizar",
    "legalizávamos": "legalizar",
    "legalizávei": "legalizar",
    "legalizáveis": "legalizável",
    "legam": "legar",
    "legamo": "legar",
    "legamos": "legar",
    "legando": "legar",
    "legara": "legar",
    "legaram": "legar",
    "legaras": "legar",
    "legarde": "legar",
    "legardes": "legar",
    "legare": "legar",
    "legarei": "legar",
    "legareis": "legar",
    "legarem": "legar",
    "legaremos": "legar",
    "legares": "legar",
    "legaria": "legar",
    "legariam": "legar",
    "legarias": "legar",
    "legarmo": "legar",
    "legarmos": "legar",
    "legará": "legar",
    "legarás": "legar",
    "legarão": "legar",
    "legaríamos": "legar",
    "legaríeis": "legar",
    "legas": "legar",
    "legasse": "legar",
    "legassem": "legar",
    "legasses": "legar",
    "legaste": "legar",
    "legastes": "legar",
    "legatária": "legatário",
    "legatárias": "legatário",
    "legatários": "legatário",
    "legatória": "legatório",
    "legatórias": "legatório",
    "legatórios": "legatório",
    "legava": "legar",
    "legavam": "legar",
    "legavas": "legar",
    "legações": "legação",
    "legenda": "legendar",
    "legendada": "legendar",
    "legendadas": "legendar",
    "legendado": "legendar",
    "legendadora": "legendador",
    "legendadoras": "legendador",
    "legendadores": "legendador",
    "legendados": "legendar",
    "legendagens": "legendagem",
    "legendai": "legendar",
    "legendais": "legendar",
    "legendam": "legendar",
    "legendamo": "legendar",
    "legendamos": "legendar",
    "legendando": "legendar",
    "legendara": "legendar",
    "legendaram": "legendar",
    "legendaras": "legendar",
    "legendarde": "legendar",
    "legendardes": "legendar",
    "legendare": "legendar",
    "legendarei": "legendar",
    "legendareis": "legendar",
    "legendarem": "legendar",
    "legendaremos": "legendar",
    "legendares": "legendar",
    "legendaria": "legendar",
    "legendariam": "legendar",
    "legendarias": "legendar",
    "legendarmo": "legendar",
    "legendarmos": "legendar",
    "legendará": "legendar",
    "legendarás": "legendar",
    "legendarão": "legendar",
    "legendaríamos": "legendar",
    "legendaríeis": "legendar",
    "legendas": "legendar",
    "legendasse": "legendar",
    "legendassem": "legendar",
    "legendasses": "legendar",
    "legendaste": "legendar",
    "legendastes": "legendar",
    "legendava": "legendar",
    "legendavam": "legendar",
    "legendavas": "legendar",
    "legende": "legendar",
    "legendei": "legendar",
    "legendeis": "legendar",
    "legendem": "legendar",
    "legendemo": "legendar",
    "legendemos": "legendar",
    "legendes": "legendar",
    "legendo": "legendar",
    "legendou": "legendar",
    "legendá": "legendar",
    "legendámo": "legendar",
    "legendámos": "legendar",
    "legendáramo": "legendar",
    "legendáramos": "legendar",
    "legendárei": "legendar",
    "legendáreis": "legendar",
    "legendária": "legendário",
    "legendárias": "legendário",
    "legendários": "legendário",
    "legendásseis": "legendar",
    "legendássemos": "legendar",
    "legendávamo": "legendar",
    "legendávamos": "legendar",
    "legendávei": "legendar",
    "legendáveis": "legendar",
    "legibilidades": "legibilidade",
    "legionária": "legionário",
    "legionárias": "legionário",
    "legionários": "legionário",
    "legisla": "legislar",
    "legislada": "legislar",
    "legisladas": "legislar",
    "legislado": "legislar",
    "legisladora": "legislador",
    "legisladoras": "legislador",
    "legisladores": "legislador",
    "legislados": "legislar",
    "legislai": "legislar",
    "legislais": "legislar",
    "legislam": "legislar",
    "legislamo": "legislar",
    "legislamos": "legislar",
    "legislando": "legislar",
    "legislara": "legislar",
    "legislaram": "legislar",
    "legislaras": "legislar",
    "legislarde": "legislar",
    "legislardes": "legislar",
    "legislare": "legislar",
    "legislarei": "legislar",
    "legislareis": "legislar",
    "legislarem": "legislar",
    "legislaremos": "legislar",
    "legislares": "legislar",
    "legislaria": "legislar",
    "legislariam": "legislar",
    "legislarias": "legislar",
    "legislarmo": "legislar",
    "legislarmos": "legislar",
    "legislará": "legislar",
    "legislarás": "legislar",
    "legislarão": "legislar",
    "legislaríamos": "legislar",
    "legislaríeis": "legislar",
    "legislas": "legislar",
    "legislasse": "legislar",
    "legislassem": "legislar",
    "legislasses": "legislar",
    "legislaste": "legislar",
    "legislastes": "legislar",
    "legislativa": "legislativo",
    "legislativas": "legislativo",
    "legislativos": "legislativo",
    "legislaturas": "legislatura",
    "legislatória": "legislatório",
    "legislatórias": "legislatório",
    "legislatórios": "legislatório",
    "legislava": "legislar",
    "legislavam": "legislar",
    "legislavas": "legislar",
    "legislações": "legislação",
    "legisle": "legislar",
    "legislei": "legislar",
    "legisleis": "legislar",
    "legislem": "legislar",
    "legislemo": "legislar",
    "legislemos": "legislar",
    "legisles": "legislar",
    "legislo": "legislar",
    "legislou": "legislar",
    "legislá": "legislar",
    "legislámo": "legislar",
    "legislámos": "legislar",
    "legisláramo": "legislar",
    "legisláramos": "legislar",
    "legislárei": "legislar",
    "legisláreis": "legislar",
    "legislásseis": "legislar",
    "legislássemos": "legislar",
    "legislávamo": "legislar",
    "legislávamos": "legislar",
    "legislávei": "legislar",
    "legisláveis": "legislável",
    "legisperita": "legisperito",
    "legisperitas": "legisperito",
    "legisperitos": "legisperito",
    "legistas": "legista",
    "legitima": "legitimar",
    "legitimada": "legitimar",
    "legitimadas": "legitimar",
    "legitimado": "legitimar",
    "legitimadora": "legitimador",
    "legitimadoras": "legitimador",
    "legitimadores": "legitimador",
    "legitimados": "legitimar",
    "legitimai": "legitimar",
    "legitimais": "legitimar",
    "legitimam": "legitimar",
    "legitimamo": "legitimar",
    "legitimamos": "legitimar",
    "legitimando": "legitimar",
    "legitimara": "legitimar",
    "legitimaram": "legitimar",
    "legitimaras": "legitimar",
    "legitimarde": "legitimar",
    "legitimardes": "legitimar",
    "legitimare": "legitimar",
    "legitimarei": "legitimar",
    "legitimareis": "legitimar",
    "legitimarem": "legitimar",
    "legitimaremos": "legitimar",
    "legitimares": "legitimar",
    "legitimaria": "legitimar",
    "legitimariam": "legitimar",
    "legitimarias": "legitimar",
    "legitimarmo": "legitimar",
    "legitimarmos": "legitimar",
    "legitimará": "legitimar",
    "legitimarás": "legitimar",
    "legitimarão": "legitimar",
    "legitimaríamos": "legitimar",
    "legitimaríeis": "legitimar",
    "legitimas": "legitimar",
    "legitimasse": "legitimar",
    "legitimassem": "legitimar",
    "legitimasses": "legitimar",
    "legitimaste": "legitimar",
    "legitimastes": "legitimar",
    "legitimava": "legitimar",
    "legitimavam": "legitimar",
    "legitimavas": "legitimar",
    "legitimações": "legitimação",
    "legitime": "legitimar",
    "legitimei": "legitimar",
    "legitimeis": "legitimar",
    "legitimem": "legitimar",
    "legitimemo": "legitimar",
    "legitimemos": "legitimar",
    "legitimes": "legitimar",
    "legitimidades": "legitimidade",
    "legitimismos": "legitimismo",
    "legitimistas": "legitimista",
    "legitimizações": "legitimização",
    "legitimo": "legitimar",
    "legitimou": "legitimar",
    "legitimá": "legitimar",
    "legitimámo": "legitimar",
    "legitimámos": "legitimar",
    "legitimáramo": "legitimar",
    "legitimáramos": "legitimar",
    "legitimárei": "legitimar",
    "legitimáreis": "legitimar",
    "legitimásseis": "legitimar",
    "legitimássemos": "legitimar",
    "legitimávamo": "legitimar",
    "legitimávamos": "legitimar",
    "legitimávei": "legitimar",
    "legitimáveis": "legitimável",
    "legiões": "legião",
    "lego": "legar",
    "legou": "legar",
    "legra": "legrar",
    "legrada": "legrar",
    "legradas": "legrar",
    "legrado": "legrar",
    "legrados": "legrar",
    "legraduras": "legradura",
    "legrai": "legrar",
    "legrais": "legrar",
    "legram": "legrar",
    "legramo": "legrar",
    "legramos": "legrar",
    "legrando": "legrar",
    "legrara": "legrar",
    "legraram": "legrar",
    "legraras": "legrar",
    "legrarde": "legrar",
    "legrardes": "legrar",
    "legrare": "legrar",
    "legrarei": "legrar",
    "legrareis": "legrar",
    "legrarem": "legrar",
    "legraremos": "legrar",
    "legrares": "legrar",
    "legraria": "legrar",
    "legrariam": "legrar",
    "legrarias": "legrar",
    "legrarmo": "legrar",
    "legrarmos": "legrar",
    "legrará": "legrar",
    "legrarás": "legrar",
    "legrarão": "legrar",
    "legraríamos": "legrar",
    "legraríeis": "legrar",
    "legras": "legrar",
    "legrasse": "legrar",
    "legrassem": "legrar",
    "legrasses": "legrar",
    "legraste": "legrar",
    "legrastes": "legrar",
    "legrava": "legrar",
    "legravam": "legrar",
    "legravas": "legrar",
    "legrações": "legração",
    "legre": "legrar",
    "legrei": "legrar",
    "legreis": "legrar",
    "legrem": "legrar",
    "legremo": "legrar",
    "legremos": "legrar",
    "legres": "legre",
    "legro": "legrar",
    "legrou": "legrar",
    "legrá": "legrar",
    "legrámo": "legrar",
    "legrámos": "legrar",
    "legráramo": "legrar",
    "legráramos": "legrar",
    "legrárei": "legrar",
    "legráreis": "legrar",
    "legrásseis": "legrar",
    "legrássemos": "legrar",
    "legrávamo": "legrar",
    "legrávamos": "legrar",
    "legrávei": "legrar",
    "legráveis": "legrar",
    "legue": "legar",
    "leguei": "legar",
    "legueis": "legar",
    "leguelhés": "leguelhé",
    "leguem": "legar",
    "leguemo": "legar",
    "leguemos": "legar",
    "legues": "legar",
    "leguleia": "leguleio",
    "leguleias": "leguleio",
    "leguleios": "leguleio",
    "leguleja": "legulejo",
    "legulejas": "legulejo",
    "legulejos": "legulejo",
    "legumeira": "legumeiro",
    "legumeiras": "legumeiro",
    "legumeiros": "legumeiro",
    "legumes": "legume",
    "leguminas": "legumina",
    "leguminiformes": "leguminiforme",
    "leguministas": "leguminista",
    "leguminosa": "leguminoso",
    "leguminosas": "leguminoso",
    "leguminosos": "leguminoso",
    "leguminária": "leguminário",
    "leguminárias": "leguminário",
    "leguminários": "leguminário",
    "leguminívora": "leguminívoro",
    "leguminívoras": "leguminívoro",
    "leguminívoros": "leguminívoro",
    "legumistas": "legumista",
    "leguórias": "leguória",
    "legá": "legar",
    "legámo": "legar",
    "legámos": "legar",
    "legáramo": "legar",
    "legáramos": "legar",
    "legárei": "legar",
    "legáreis": "legar",
    "legásseis": "legar",
    "legássemos": "legar",
    "legávamo": "legar",
    "legávamos": "legar",
    "legávei": "legar",
    "legáveis": "legável",
    "legífera": "legífero",
    "legíferas": "legífero",
    "legíferos": "legífero",
    "legítima": "legítimo",
    "legítimas": "legítimo",
    "legítimos": "legítimo",
    "legíveis": "legível",
    "leia": "ler",
    "leiais": "ler",
    "leiam": "ler",
    "leiamo": "ler",
    "leiamos": "ler",
    "leias": "ler",
    "leibniziana": "leibniziano",
    "leibnizianas": "leibniziano",
    "leibnizianos": "leibniziano",
    "leicenços": "leicenço",
    "leiga": "leigo",
    "leigada": "leigar",
    "leigadas": "leigar",
    "leigado": "leigar",
    "leigados": "leigar",
    "leigai": "leigar",
    "leigais": "leigar",
    "leigam": "leigar",
    "leigamo": "leigar",
    "leigamos": "leigar",
    "leigando": "leigar",
    "leigara": "leigar",
    "leigaram": "leigar",
    "leigaras": "leigar",
    "leigarde": "leigar",
    "leigardes": "leigar",
    "leigare": "leigar",
    "leigarei": "leigar",
    "leigareis": "leigar",
    "leigarem": "leigar",
    "leigaremos": "leigar",
    "leigares": "leigar",
    "leigaria": "leigar",
    "leigariam": "leigar",
    "leigarias": "leigar",
    "leigarmo": "leigar",
    "leigarmos": "leigar",
    "leigarrazes": "leigarraz",
    "leigarraça": "leigarraço",
    "leigarraças": "leigarraço",
    "leigarraços": "leigarraço",
    "leigarrona": "leigarrão",
    "leigarronas": "leigarrão",
    "leigarrões": "leigarrão",
    "leigará": "leigar",
    "leigarás": "leigar",
    "leigarão": "leigar",
    "leigaríamos": "leigar",
    "leigaríeis": "leigar",
    "leigas": "leigo",
    "leigasse": "leigar",
    "leigassem": "leigar",
    "leigasses": "leigar",
    "leigaste": "leigar",
    "leigastes": "leigar",
    "leigava": "leigar",
    "leigavam": "leigar",
    "leigavas": "leigar",
    "leigaça": "leigaço",
    "leigaças": "leigaço",
    "leigaços": "leigaço",
    "leigo": "leigar",
    "leigos": "leigo",
    "leigou": "leigar",
    "leigue": "leigar",
    "leiguei": "leigar",
    "leigueis": "leigar",
    "leiguem": "leigar",
    "leiguemo": "leigar",
    "leiguemos": "leigar",
    "leigues": "leigar",
    "leiguices": "leiguice",
    "leigá": "leigar",
    "leigámo": "leigar",
    "leigámos": "leigar",
    "leigáramo": "leigar",
    "leigáramos": "leigar",
    "leigárei": "leigar",
    "leigáreis": "leigar",
    "leigásseis": "leigar",
    "leigássemos": "leigar",
    "leigávamo": "leigar",
    "leigávamos": "leigar",
    "leigávei": "leigar",
    "leigáveis": "leigar",
    "leiloa": "leiloar",
    "leiloada": "leiloar",
    "leiloadas": "leiloar",
    "leiloado": "leiloar",
    "leiloados": "leiloar",
    "leiloai": "leiloar",
    "leiloais": "leiloar",
    "leiloam": "leiloar",
    "leiloamentos": "leiloamento",
    "leiloamo": "leiloar",
    "leiloamos": "leiloar",
    "leiloando": "leiloar",
    "leiloara": "leiloar",
    "leiloaram": "leiloar",
    "leiloaras": "leiloar",
    "leiloarde": "leiloar",
    "leiloardes": "leiloar",
    "leiloare": "leiloar",
    "leiloarei": "leiloar",
    "leiloareis": "leiloar",
    "leiloarem": "leiloar",
    "leiloaremos": "leiloar",
    "leiloares": "leiloar",
    "leiloaria": "leiloar",
    "leiloariam": "leiloar",
    "leiloarias": "leiloar",
    "leiloarmo": "leiloar",
    "leiloarmos": "leiloar",
    "leiloará": "leiloar",
    "leiloarás": "leiloar",
    "leiloarão": "leiloar",
    "leiloaríamos": "leiloar",
    "leiloaríeis": "leiloar",
    "leiloas": "leiloar",
    "leiloasse": "leiloar",
    "leiloassem": "leiloar",
    "leiloasses": "leiloar",
    "leiloaste": "leiloar",
    "leiloastes": "leiloar",
    "leiloava": "leiloar",
    "leiloavam": "leiloar",
    "leiloavas": "leiloar",
    "leiloe": "leiloar",
    "leiloei": "leiloar",
    "leiloeira": "leiloeiro",
    "leiloeiras": "leiloeiro",
    "leiloeiros": "leiloeiro",
    "leiloeis": "leiloar",
    "leiloem": "leiloar",
    "leiloemo": "leiloar",
    "leiloemos": "leiloar",
    "leiloes": "leiloar",
    "leiloo": "leiloar",
    "leiloou": "leiloar",
    "leiloá": "leiloar",
    "leiloámo": "leiloar",
    "leiloámos": "leiloar",
    "leiloáramo": "leiloar",
    "leiloáramos": "leiloar",
    "leiloárei": "leiloar",
    "leiloáreis": "leiloar",
    "leiloásseis": "leiloar",
    "leiloássemos": "leiloar",
    "leiloávamo": "leiloar",
    "leiloávamos": "leiloar",
    "leiloávei": "leiloar",
    "leiloáveis": "leiloável",
    "leilãozinho": "leilão",
    "leilãozito": "leilão",
    "leilões": "leilão",
    "leilõezinhos": "leilão",
    "leilõezitos": "leilão",
    "leio": "ler",
    "leiras": "leira",
    "leirienses": "leiriense",
    "leirioas": "leirioa",
    "leirotos": "leiroto",
    "leis": "lei",
    "leishmanioses": "leishmaniose",
    "leishmânias": "leishmânia",
    "leitada": "leitado",
    "leitadas": "leitado",
    "leitados": "leitado",
    "leitares": "leitar",
    "leitarias": "leitaria",
    "leitarigas": "leitariga",
    "leitas": "leita",
    "leitegadas": "leitegada",
    "leiteira": "leiteiro",
    "leiteiras": "leiteiro",
    "leiteirazinha": "leiteiro",
    "leiteirazinhas": "leiteiro",
    "leiteirazita": "leiteiro",
    "leiteirazitas": "leiteiro",
    "leiteiros": "leiteiro",
    "leiteirozinho": "leiteiro",
    "leiteirozinhos": "leiteiro",
    "leiteirozito": "leiteiro",
    "leiteirozitos": "leiteiro",
    "leitenta": "leitento",
    "leitentas": "leitento",
    "leitentos": "leitento",
    "leites": "leite",
    "leitigas": "leitiga",
    "leitinho": "leite",
    "leitinhos": "leite",
    "leitito": "leite",
    "leititos": "leite",
    "leitmotivs": "leitmotiv",
    "leitoa": "leitão",
    "leitoada": "leitoado",
    "leitoadas": "leitoado",
    "leitoados": "leitoado",
    "leitoas": "leitão",
    "leitoazinha": "leitão",
    "leitoazinhas": "leitão",
    "leitoazita": "leitão",
    "leitoazitas": "leitão",
    "leitora": "leitor",
    "leitorados": "leitorado",
    "leitoras": "leitor",
    "leitores": "leitor",
    "leitoris": "leitoril",
    "leitos": "leito",
    "leitosa": "leitoso",
    "leitosas": "leitoso",
    "leitosos": "leitoso",
    "leitozinho": "leito",
    "leitozinhos": "leito",
    "leitozito": "leito",
    "leitozitos": "leito",
    "leituada": "leituado",
    "leituadas": "leituado",
    "leituados": "leituado",
    "leitugas": "leituga",
    "leituras": "leitura",
    "leitãozinho": "leitão",
    "leitãozito": "leitão",
    "leitões": "leitão",
    "leitõezinhos": "leitão",
    "leitõezitos": "leitão",
    "leivancos": "leivanco",
    "leivas": "leiva",
    "leivões": "leivão",
    "leixonenses": "leixonense",
    "leixões": "leixão",
    "lela": "lelo",
    "lelas": "lelo",
    "lelos": "lelo",
    "lelés": "lelé",
    "lemas": "lema",
    "lematiza": "lematizar",
    "lematizada": "lematizar",
    "lematizadas": "lematizar",
    "lematizado": "lematizar",
    "lematizados": "lematizar",
    "lematizai": "lematizar",
    "lematizais": "lematizar",
    "lematizam": "lematizar",
    "lematizamo": "lematizar",
    "lematizamos": "lematizar",
    "lematizando": "lematizar",
    "lematizara": "lematizar",
    "lematizaram": "lematizar",
    "lematizaras": "lematizar",
    "lematizarde": "lematizar",
    "lematizardes": "lematizar",
    "lematizare": "lematizar",
    "lematizarei": "lematizar",
    "lematizareis": "lematizar",
    "lematizarem": "lematizar",
    "lematizaremos": "lematizar",
    "lematizares": "lematizar",
    "lematizaria": "lematizar",
    "lematizariam": "lematizar",
    "lematizarias": "lematizar",
    "lematizarmo": "lematizar",
    "lematizarmos": "lematizar",
    "lematizará": "lematizar",
    "lematizarás": "lematizar",
    "lematizarão": "lematizar",
    "lematizaríamos": "lematizar",
    "lematizaríeis": "lematizar",
    "lematizas": "lematizar",
    "lematizasse": "lematizar",
    "lematizassem": "lematizar",
    "lematizasses": "lematizar",
    "lematizaste": "lematizar",
    "lematizastes": "lematizar",
    "lematizava": "lematizar",
    "lematizavam": "lematizar",
    "lematizavas": "lematizar",
    "lematize": "lematizar",
    "lematizei": "lematizar",
    "lematizeis": "lematizar",
    "lematizem": "lematizar",
    "lematizemo": "lematizar",
    "lematizemos": "lematizar",
    "lematizes": "lematizar",
    "lematizo": "lematizar",
    "lematizou": "lematizar",
    "lematizá": "lematizar",
    "lematizámo": "lematizar",
    "lematizámos": "lematizar",
    "lematizáramo": "lematizar",
    "lematizáramos": "lematizar",
    "lematizárei": "lematizar",
    "lematizáreis": "lematizar",
    "lematizásseis": "lematizar",
    "lematizássemos": "lematizar",
    "lematizávamo": "lematizar",
    "lematizávamos": "lematizar",
    "lematizávei": "lematizar",
    "lematizáveis": "lematizável",
    "lembra": "lembrar",
    "lembrada": "lembrar",
    "lembradas": "lembrar",
    "lembradiça": "lembradiço",
    "lembradiças": "lembradiço",
    "lembradiços": "lembradiço",
    "lembrado": "lembrar",
    "lembradora": "lembrador",
    "lembradoras": "lembrador",
    "lembradores": "lembrador",
    "lembrados": "lembrar",
    "lembrai": "lembrar",
    "lembrais": "lembrar",
    "lembram": "lembrar",
    "lembramo": "lembrar",
    "lembramos": "lembrar",
    "lembrando": "lembrar",
    "lembranças": "lembrança",
    "lembrara": "lembrar",
    "lembraram": "lembrar",
    "lembraras": "lembrar",
    "lembrarde": "lembrar",
    "lembrardes": "lembrar",
    "lembrare": "lembrar",
    "lembrarei": "lembrar",
    "lembrareis": "lembrar",
    "lembrarem": "lembrar",
    "lembraremos": "lembrar",
    "lembrares": "lembrar",
    "lembraria": "lembrar",
    "lembrariam": "lembrar",
    "lembrarias": "lembrar",
    "lembrarmo": "lembrar",
    "lembrarmos": "lembrar",
    "lembrará": "lembrar",
    "lembrarás": "lembrar",
    "lembrarão": "lembrar",
    "lembraríamos": "lembrar",
    "lembraríeis": "lembrar",
    "lembras": "lembrar",
    "lembrasse": "lembrar",
    "lembrassem": "lembrar",
    "lembrasses": "lembrar",
    "lembraste": "lembrar",
    "lembrastes": "lembrar",
    "lembrava": "lembrar",
    "lembravam": "lembrar",
    "lembravas": "lembrar",
    "lembre": "lembrar",
    "lembrei": "lembrar",
    "lembreis": "lembrar",
    "lembrem": "lembrar",
    "lembremo": "lembrar",
    "lembremos": "lembrar",
    "lembres": "lembrar",
    "lembretes": "lembrete",
    "lembro": "lembrar",
    "lembrou": "lembrar",
    "lembrá": "lembrar",
    "lembrámo": "lembrar",
    "lembrámos": "lembrar",
    "lembráramo": "lembrar",
    "lembráramos": "lembrar",
    "lembrárei": "lembrar",
    "lembráreis": "lembrar",
    "lembrásseis": "lembrar",
    "lembrássemos": "lembrar",
    "lembrávamo": "lembrar",
    "lembrávamos": "lembrar",
    "lembrávei": "lembrar",
    "lembráveis": "lembrável",
    "lemes": "leme",
    "lemistes": "lemiste",
    "lemnas": "lemna",
    "lemniscatas": "lemniscata",
    "lemniscatos": "lemniscato",
    "lemniscos": "lemnisco",
    "lemnácea": "lemnáceo",
    "lemnáceas": "lemnáceo",
    "lemnáceos": "lemnáceo",
    "lemo": "ler",
    "lemografias": "lemografia",
    "lemos": "ler",
    "lempas": "lempa",
    "lempiras": "lempira",
    "lemurais": "lemural",
    "lemurianos": "lemuriano",
    "lemurídeos": "lemurídeo",
    "lemática": "lemático",
    "lemáticas": "lemático",
    "lemáticos": "lemático",
    "lemúrias": "lemúria",
    "lemúridas": "lemúrida",
    "lemúrios": "lemúrio",
    "lenas": "lena",
    "lencinho": "lenço",
    "lencinhos": "lenço",
    "lencito": "lenço",
    "lencitos": "lenço",
    "lendas": "lenda",
    "lendeaços": "lendeaço",
    "lendeosa": "lendeoso",
    "lendeosas": "lendeoso",
    "lendeosos": "lendeoso",
    "lendo": "ler",
    "lendroeiras": "lendroeira",
    "lendroeiros": "lendroeiro",
    "lendária": "lendário",
    "lendárias": "lendário",
    "lendários": "lendário",
    "lenes": "lene",
    "lengalenga": "lengalengar",
    "lengalengada": "lengalengar",
    "lengalengadas": "lengalengar",
    "lengalengado": "lengalengar",
    "lengalengados": "lengalengar",
    "lengalengai": "lengalengar",
    "lengalengais": "lengalengar",
    "lengalengam": "lengalengar",
    "lengalengamo": "lengalengar",
    "lengalengamos": "lengalengar",
    "lengalengando": "lengalengar",
    "lengalengara": "lengalengar",
    "lengalengaram": "lengalengar",
    "lengalengaras": "lengalengar",
    "lengalengardes": "lengalengar",
    "lengalengarei": "lengalengar",
    "lengalengareis": "lengalengar",
    "lengalengarem": "lengalengar",
    "lengalengaremos": "lengalengar",
    "lengalengares": "lengalengar",
    "lengalengaria": "lengalengar",
    "lengalengariam": "lengalengar",
    "lengalengarias": "lengalengar",
    "lengalengarmo": "lengalengar",
    "lengalengarmos": "lengalengar",
    "lengalengará": "lengalengar",
    "lengalengarás": "lengalengar",
    "lengalengarão": "lengalengar",
    "lengalengaríamos": "lengalengar",
    "lengalengaríeis": "lengalengar",
    "lengalengas": "lengalengar",
    "lengalengasse": "lengalengar",
    "lengalengassem": "lengalengar",
    "lengalengasses": "lengalengar",
    "lengalengaste": "lengalengar",
    "lengalengastes": "lengalengar",
    "lengalengava": "lengalengar",
    "lengalengavam": "lengalengar",
    "lengalengavas": "lengalengar",
    "lengalengo": "lengalengar",
    "lengalengou": "lengalengar",
    "lengalengue": "lengalengar",
    "lengalenguei": "lengalengar",
    "lengalengueis": "lengalengar",
    "lengalenguem": "lengalengar",
    "lengalenguemo": "lengalengar",
    "lengalenguemos": "lengalengar",
    "lengalengues": "lengalengar",
    "lengalengámo": "lengalengar",
    "lengalengámos": "lengalengar",
    "lengalengáramo": "lengalengar",
    "lengalengáramos": "lengalengar",
    "lengalengáreis": "lengalengar",
    "lengalengásseis": "lengalengar",
    "lengalengássemos": "lengalengar",
    "lengalengávamo": "lengalengar",
    "lengalengávamos": "lengalengar",
    "lengalengáveis": "lengalengar",
    "lengas": "lenga",
    "lengues": "lengue",
    "lenha": "lenhar",
    "lenhada": "lenhar",
    "lenhadas": "lenhar",
    "lenhado": "lenhar",
    "lenhadora": "lenhador",
    "lenhadoras": "lenhador",
    "lenhadores": "lenhador",
    "lenhados": "lenhar",
    "lenhai": "lenhar",
    "lenhais": "lenhar",
    "lenham": "lenhar",
    "lenhamo": "lenhar",
    "lenhamos": "lenhar",
    "lenhando": "lenhar",
    "lenhara": "lenhar",
    "lenharam": "lenhar",
    "lenharas": "lenhar",
    "lenhardes": "lenhar",
    "lenharei": "lenhar",
    "lenhareis": "lenhar",
    "lenharem": "lenhar",
    "lenharemos": "lenhar",
    "lenhares": "lenhar",
    "lenharia": "lenhar",
    "lenhariam": "lenhar",
    "lenharias": "lenhar",
    "lenharmo": "lenhar",
    "lenharmos": "lenhar",
    "lenhará": "lenhar",
    "lenharás": "lenhar",
    "lenharão": "lenhar",
    "lenharíamos": "lenhar",
    "lenharíeis": "lenhar",
    "lenhas": "lenhar",
    "lenhasse": "lenhar",
    "lenhassem": "lenhar",
    "lenhasses": "lenhar",
    "lenhaste": "lenhar",
    "lenhastes": "lenhar",
    "lenhava": "lenhar",
    "lenhavam": "lenhar",
    "lenhavas": "lenhar",
    "lenhe": "lenhar",
    "lenhei": "lenhar",
    "lenheira": "lenheiro",
    "lenheiras": "lenheiro",
    "lenheiros": "lenheiro",
    "lenheis": "lenhar",
    "lenhem": "lenhar",
    "lenhemo": "lenhar",
    "lenhemos": "lenhar",
    "lenhes": "lenhar",
    "lenhifica": "lenhificar",
    "lenhificada": "lenhificar",
    "lenhificadas": "lenhificar",
    "lenhificado": "lenhificar",
    "lenhificados": "lenhificar",
    "lenhificai": "lenhificar",
    "lenhificais": "lenhificar",
    "lenhificam": "lenhificar",
    "lenhificamo": "lenhificar",
    "lenhificamos": "lenhificar",
    "lenhificando": "lenhificar",
    "lenhificara": "lenhificar",
    "lenhificaram": "lenhificar",
    "lenhificaras": "lenhificar",
    "lenhificarde": "lenhificar",
    "lenhificardes": "lenhificar",
    "lenhificare": "lenhificar",
    "lenhificarei": "lenhificar",
    "lenhificareis": "lenhificar",
    "lenhificarem": "lenhificar",
    "lenhificaremos": "lenhificar",
    "lenhificares": "lenhificar",
    "lenhificaria": "lenhificar",
    "lenhificariam": "lenhificar",
    "lenhificarias": "lenhificar",
    "lenhificarmo": "lenhificar",
    "lenhificarmos": "lenhificar",
    "lenhificará": "lenhificar",
    "lenhificarás": "lenhificar",
    "lenhificarão": "lenhificar",
    "lenhificaríamos": "lenhificar",
    "lenhificaríeis": "lenhificar",
    "lenhificas": "lenhificar",
    "lenhificasse": "lenhificar",
    "lenhificassem": "lenhificar",
    "lenhificasses": "lenhificar",
    "lenhificaste": "lenhificar",
    "lenhificastes": "lenhificar",
    "lenhificava": "lenhificar",
    "lenhificavam": "lenhificar",
    "lenhificavas": "lenhificar",
    "lenhificações": "lenhificação",
    "lenhifico": "lenhificar",
    "lenhificou": "lenhificar",
    "lenhificá": "lenhificar",
    "lenhificámo": "lenhificar",
    "lenhificámos": "lenhificar",
    "lenhificáramo": "lenhificar",
    "lenhificáramos": "lenhificar",
    "lenhificárei": "lenhificar",
    "lenhificáreis": "lenhificar",
    "lenhificásseis": "lenhificar",
    "lenhificássemos": "lenhificar",
    "lenhificávamo": "lenhificar",
    "lenhificávamos": "lenhificar",
    "lenhificávei": "lenhificar",
    "lenhificáveis": "lenhificável",
    "lenhifique": "lenhificar",
    "lenhifiquei": "lenhificar",
    "lenhifiqueis": "lenhificar",
    "lenhifiquem": "lenhificar",
    "lenhifiquemo": "lenhificar",
    "lenhifiquemos": "lenhificar",
    "lenhifiques": "lenhificar",
    "lenhinas": "lenhina",
    "lenhites": "lenhite",
    "lenho": "lenhar",
    "lenhos": "lenho",
    "lenhosa": "lenhoso",
    "lenhosas": "lenhoso",
    "lenhoses": "lenhose",
    "lenhosos": "lenhoso",
    "lenhou": "lenhar",
    "lenhozinho": "lenho",
    "lenhozinhos": "lenho",
    "lenhozito": "lenho",
    "lenhozitos": "lenho",
    "lenhámo": "lenhar",
    "lenhámos": "lenhar",
    "lenháramo": "lenhar",
    "lenháramos": "lenhar",
    "lenháreis": "lenhar",
    "lenhásseis": "lenhar",
    "lenhássemos": "lenhar",
    "lenhávamo": "lenhar",
    "lenhávamos": "lenhar",
    "lenháveis": "lenhar",
    "lenhívora": "lenhívoro",
    "lenhívoras": "lenhívoro",
    "lenhívoros": "lenhívoro",
    "leni": "lenir",
    "lenia": "lenir",
    "leniam": "lenir",
    "lenias": "lenir",
    "lenida": "lenir",
    "lenidades": "lenidade",
    "lenidas": "lenir",
    "lenido": "lenir",
    "lenidos": "lenir",
    "lenientes": "leniente",
    "lenifica": "lenificar",
    "lenificada": "lenificar",
    "lenificadas": "lenificar",
    "lenificado": "lenificar",
    "lenificados": "lenificar",
    "lenificai": "lenificar",
    "lenificais": "lenificar",
    "lenificam": "lenificar",
    "lenificamo": "lenificar",
    "lenificamos": "lenificar",
    "lenificando": "lenificar",
    "lenificara": "lenificar",
    "lenificaram": "lenificar",
    "lenificaras": "lenificar",
    "lenificarde": "lenificar",
    "lenificardes": "lenificar",
    "lenificare": "lenificar",
    "lenificarei": "lenificar",
    "lenificareis": "lenificar",
    "lenificarem": "lenificar",
    "lenificaremos": "lenificar",
    "lenificares": "lenificar",
    "lenificaria": "lenificar",
    "lenificariam": "lenificar",
    "lenificarias": "lenificar",
    "lenificarmo": "lenificar",
    "lenificarmos": "lenificar",
    "lenificará": "lenificar",
    "lenificarás": "lenificar",
    "lenificarão": "lenificar",
    "lenificaríamos": "lenificar",
    "lenificaríeis": "lenificar",
    "lenificas": "lenificar",
    "lenificasse": "lenificar",
    "lenificassem": "lenificar",
    "lenificasses": "lenificar",
    "lenificaste": "lenificar",
    "lenificastes": "lenificar",
    "lenificava": "lenificar",
    "lenificavam": "lenificar",
    "lenificavas": "lenificar",
    "lenifico": "lenificar",
    "lenificou": "lenificar",
    "lenificá": "lenificar",
    "lenificámo": "lenificar",
    "lenificámos": "lenificar",
    "lenificáramo": "lenificar",
    "lenificáramos": "lenificar",
    "lenificárei": "lenificar",
    "lenificáreis": "lenificar",
    "lenificásseis": "lenificar",
    "lenificássemos": "lenificar",
    "lenificávamo": "lenificar",
    "lenificávamos": "lenificar",
    "lenificávei": "lenificar",
    "lenificáveis": "lenificável",
    "lenifique": "lenificar",
    "lenifiquei": "lenificar",
    "lenifiqueis": "lenificar",
    "lenifiquem": "lenificar",
    "lenifiquemo": "lenificar",
    "lenifiquemos": "lenificar",
    "lenifiques": "lenificar",
    "lenimentos": "lenimento",
    "lenimentosa": "lenimentoso",
    "lenimentosas": "lenimentoso",
    "lenimentosos": "lenimentoso",
    "lenimo": "lenir",
    "lenimos": "lenir",
    "lenindo": "lenir",
    "leninismos": "leninismo",
    "leninistas": "leninista",
    "lenira": "lenir",
    "leniram": "lenir",
    "leniras": "lenir",
    "lenirde": "lenir",
    "lenirdes": "lenir",
    "lenire": "lenir",
    "lenirei": "lenir",
    "lenireis": "lenir",
    "lenirem": "lenir",
    "leniremos": "lenir",
    "lenires": "lenir",
    "leniria": "lenir",
    "leniriam": "lenir",
    "lenirias": "lenir",
    "lenirmo": "lenir",
    "lenirmos": "lenir",
    "lenirá": "lenir",
    "lenirás": "lenir",
    "lenirão": "lenir",
    "leniríamos": "lenir",
    "leniríeis": "lenir",
    "lenis": "lenir",
    "lenisse": "lenir",
    "lenissem": "lenir",
    "lenisses": "lenir",
    "leniste": "lenir",
    "lenistes": "lenir",
    "lenitiva": "lenitivo",
    "lenitivas": "lenitivo",
    "lenitivos": "lenitivo",
    "leniu": "lenir",
    "lenocínios": "lenocínio",
    "lenta": "lento",
    "lentada": "lentar",
    "lentadas": "lentar",
    "lentado": "lentar",
    "lentados": "lentar",
    "lentai": "lentar",
    "lentais": "lentar",
    "lentam": "lentar",
    "lentamo": "lentar",
    "lentamos": "lentar",
    "lentando": "lentar",
    "lentara": "lentar",
    "lentaram": "lentar",
    "lentaras": "lentar",
    "lentarde": "lentar",
    "lentardes": "lentar",
    "lentare": "lentar",
    "lentarei": "lentar",
    "lentareis": "lentar",
    "lentarem": "lentar",
    "lentaremos": "lentar",
    "lentares": "lentar",
    "lentaria": "lentar",
    "lentariam": "lentar",
    "lentarias": "lentar",
    "lentarmo": "lentar",
    "lentarmos": "lentar",
    "lentará": "lentar",
    "lentarás": "lentar",
    "lentarão": "lentar",
    "lentaríamos": "lentar",
    "lentaríeis": "lentar",
    "lentas": "lento",
    "lentasse": "lentar",
    "lentassem": "lentar",
    "lentasses": "lentar",
    "lentaste": "lentar",
    "lentastes": "lentar",
    "lentava": "lentar",
    "lentavam": "lentar",
    "lentavas": "lentar",
    "lentazinha": "lento",
    "lentazinhas": "lento",
    "lentazita": "lento",
    "lentazitas": "lento",
    "lente": "lentar",
    "lenteada": "lentear",
    "lenteadas": "lentear",
    "lenteado": "lentear",
    "lenteados": "lentear",
    "lenteai": "lentear",
    "lenteais": "lentear",
    "lenteamo": "lentear",
    "lenteamos": "lentear",
    "lenteando": "lentear",
    "lenteara": "lentear",
    "lentearam": "lentear",
    "lentearas": "lentear",
    "lentearde": "lentear",
    "lenteardes": "lentear",
    "lenteare": "lentear",
    "lentearei": "lentear",
    "lenteareis": "lentear",
    "lentearem": "lentear",
    "lentearemos": "lentear",
    "lenteares": "lentear",
    "lentearia": "lentear",
    "lenteariam": "lentear",
    "lentearias": "lentear",
    "lentearmo": "lentear",
    "lentearmos": "lentear",
    "lenteará": "lentear",
    "lentearás": "lentear",
    "lentearão": "lentear",
    "lentearíamos": "lentear",
    "lentearíeis": "lentear",
    "lenteasse": "lentear",
    "lenteassem": "lentear",
    "lenteasses": "lentear",
    "lenteaste": "lentear",
    "lenteastes": "lentear",
    "lenteava": "lentear",
    "lenteavam": "lentear",
    "lenteavas": "lentear",
    "lenteei": "lentear",
    "lenteeis": "lentear",
    "lenteemo": "lentear",
    "lenteemos": "lentear",
    "lentei": "lentar",
    "lenteia": "lentear",
    "lenteiam": "lentear",
    "lenteias": "lentear",
    "lenteie": "lentear",
    "lenteiem": "lentear",
    "lenteies": "lentear",
    "lenteio": "lentear",
    "lenteiros": "lenteiro",
    "lenteis": "lentar",
    "lenteja": "lentejar",
    "lentejada": "lentejar",
    "lentejadas": "lentejar",
    "lentejado": "lentejar",
    "lentejados": "lentejar",
    "lentejai": "lentejar",
    "lentejais": "lentejar",
    "lentejam": "lentejar",
    "lentejamo": "lentejar",
    "lentejamos": "lentejar",
    "lentejando": "lentejar",
    "lentejara": "lentejar",
    "lentejaram": "lentejar",
    "lentejaras": "lentejar",
    "lentejarde": "lentejar",
    "lentejardes": "lentejar",
    "lentejare": "lentejar",
    "lentejarei": "lentejar",
    "lentejareis": "lentejar",
    "lentejarem": "lentejar",
    "lentejaremos": "lentejar",
    "lentejares": "lentejar",
    "lentejaria": "lentejar",
    "lentejariam": "lentejar",
    "lentejarias": "lentejar",
    "lentejarmo": "lentejar",
    "lentejarmos": "lentejar",
    "lentejará": "lentejar",
    "lentejarás": "lentejar",
    "lentejarão": "lentejar",
    "lentejaríamos": "lentejar",
    "lentejaríeis": "lentejar",
    "lentejas": "lentejar",
    "lentejasse": "lentejar",
    "lentejassem": "lentejar",
    "lentejasses": "lentejar",
    "lentejaste": "lentejar",
    "lentejastes": "lentejar",
    "lentejava": "lentejar",
    "lentejavam": "lentejar",
    "lentejavas": "lentejar",
    "lenteje": "lentejar",
    "lentejei": "lentejar",
    "lentejeis": "lentejar",
    "lentejem": "lentejar",
    "lentejemo": "lentejar",
    "lentejemos": "lentejar",
    "lentejes": "lentejar",
    "lentejo": "lentejar",
    "lentejoila": "lentejoilar",
    "lentejoilada": "lentejoilar",
    "lentejoiladas": "lentejoilar",
    "lentejoilado": "lentejoilar",
    "lentejoilados": "lentejoilar",
    "lentejoilai": "lentejoilar",
    "lentejoilais": "lentejoilar",
    "lentejoilam": "lentejoilar",
    "lentejoilamo": "lentejoilar",
    "lentejoilamos": "lentejoilar",
    "lentejoilando": "lentejoilar",
    "lentejoilara": "lentejoilar",
    "lentejoilaram": "lentejoilar",
    "lentejoilaras": "lentejoilar",
    "lentejoilarde": "lentejoilar",
    "lentejoilardes": "lentejoilar",
    "lentejoilare": "lentejoilar",
    "lentejoilarei": "lentejoilar",
    "lentejoilareis": "lentejoilar",
    "lentejoilarem": "lentejoilar",
    "lentejoilaremos": "lentejoilar",
    "lentejoilares": "lentejoilar",
    "lentejoilaria": "lentejoilar",
    "lentejoilariam": "lentejoilar",
    "lentejoilarias": "lentejoilar",
    "lentejoilarmo": "lentejoilar",
    "lentejoilarmos": "lentejoilar",
    "lentejoilará": "lentejoilar",
    "lentejoilarás": "lentejoilar",
    "lentejoilarão": "lentejoilar",
    "lentejoilaríamos": "lentejoilar",
    "lentejoilaríeis": "lentejoilar",
    "lentejoilas": "lentejoilar",
    "lentejoilasse": "lentejoilar",
    "lentejoilassem": "lentejoilar",
    "lentejoilasses": "lentejoilar",
    "lentejoilaste": "lentejoilar",
    "lentejoilastes": "lentejoilar",
    "lentejoilava": "lentejoilar",
    "lentejoilavam": "lentejoilar",
    "lentejoilavas": "lentejoilar",
    "lentejoile": "lentejoilar",
    "lentejoilei": "lentejoilar",
    "lentejoileis": "lentejoilar",
    "lentejoilem": "lentejoilar",
    "lentejoilemo": "lentejoilar",
    "lentejoilemos": "lentejoilar",
    "lentejoiles": "lentejoilar",
    "lentejoilo": "lentejoilar",
    "lentejoilou": "lentejoilar",
    "lentejoilá": "lentejoilar",
    "lentejoilámo": "lentejoilar",
    "lentejoilámos": "lentejoilar",
    "lentejoiláramo": "lentejoilar",
    "lentejoiláramos": "lentejoilar",
    "lentejoilárei": "lentejoilar",
    "lentejoiláreis": "lentejoilar",
    "lentejoilásseis": "lentejoilar",
    "lentejoilássemos": "lentejoilar",
    "lentejoilávamo": "lentejoilar",
    "lentejoilávamos": "lentejoilar",
    "lentejoilávei": "lentejoilar",
    "lentejoiláveis": "lentejoilar",
    "lentejou": "lentejar",
    "lentejoula": "lentejoular",
    "lentejoulada": "lentejoular",
    "lentejouladas": "lentejoular",
    "lentejoulado": "lentejoular",
    "lentejoulados": "lentejoular",
    "lentejoulai": "lentejoular",
    "lentejoulais": "lentejoular",
    "lentejoulam": "lentejoular",
    "lentejoulamo": "lentejoular",
    "lentejoulamos": "lentejoular",
    "lentejoulando": "lentejoular",
    "lentejoulara": "lentejoular",
    "lentejoularam": "lentejoular",
    "lentejoularas": "lentejoular",
    "lentejoularde": "lentejoular",
    "lentejoulardes": "lentejoular",
    "lentejoulare": "lentejoular",
    "lentejoularei": "lentejoular",
    "lentejoulareis": "lentejoular",
    "lentejoularem": "lentejoular",
    "lentejoularemos": "lentejoular",
    "lentejoulares": "lentejoular",
    "lentejoularia": "lentejoular",
    "lentejoulariam": "lentejoular",
    "lentejoularias": "lentejoular",
    "lentejoularmo": "lentejoular",
    "lentejoularmos": "lentejoular",
    "lentejoulará": "lentejoular",
    "lentejoularás": "lentejoular",
    "lentejoularão": "lentejoular",
    "lentejoularíamos": "lentejoular",
    "lentejoularíeis": "lentejoular",
    "lentejoulas": "lentejoular",
    "lentejoulasse": "lentejoular",
    "lentejoulassem": "lentejoular",
    "lentejoulasses": "lentejoular",
    "lentejoulaste": "lentejoular",
    "lentejoulastes": "lentejoular",
    "lentejoulava": "lentejoular",
    "lentejoulavam": "lentejoular",
    "lentejoulavas": "lentejoular",
    "lentejoule": "lentejoular",
    "lentejoulei": "lentejoular",
    "lentejouleis": "lentejoular",
    "lentejoulem": "lentejoular",
    "lentejoulemo": "lentejoular",
    "lentejoulemos": "lentejoular",
    "lentejoules": "lentejoular",
    "lentejoulo": "lentejoular",
    "lentejoulou": "lentejoular",
    "lentejoulá": "lentejoular",
    "lentejoulámo": "lentejoular",
    "lentejoulámos": "lentejoular",
    "lentejouláramo": "lentejoular",
    "lentejouláramos": "lentejoular",
    "lentejoulárei": "lentejoular",
    "lentejouláreis": "lentejoular",
    "lentejoulásseis": "lentejoular",
    "lentejoulássemos": "lentejoular",
    "lentejoulávamo": "lentejoular",
    "lentejoulávamos": "lentejoular",
    "lentejoulávei": "lentejoular",
    "lentejouláveis": "lentejoular",
    "lentejá": "lentejar",
    "lentejámo": "lentejar",
    "lentejámos": "lentejar",
    "lentejáramo": "lentejar",
    "lentejáramos": "lentejar",
    "lentejárei": "lentejar",
    "lentejáreis": "lentejar",
    "lentejásseis": "lentejar",
    "lentejássemos": "lentejar",
    "lentejávamo": "lentejar",
    "lentejávamos": "lentejar",
    "lentejávei": "lentejar",
    "lentejáveis": "lentejar",
    "lentem": "lentar",
    "lentemo": "lentar",
    "lentemos": "lentar",
    "lenteou": "lentear",
    "lentes": "lente",
    "lentesce": "lentescer",
    "lentescei": "lentescer",
    "lentesceis": "lentescer",
    "lentescem": "lentescer",
    "lentescemo": "lentescer",
    "lentescemos": "lentescer",
    "lentescendo": "lentescer",
    "lentescentes": "lentescente",
    "lentescera": "lentescer",
    "lentesceram": "lentescer",
    "lentesceras": "lentescer",
    "lentescerde": "lentescer",
    "lentescerdes": "lentescer",
    "lentescere": "lentescer",
    "lentescerei": "lentescer",
    "lentescereis": "lentescer",
    "lentescerem": "lentescer",
    "lentesceremos": "lentescer",
    "lentesceres": "lentescer",
    "lentesceria": "lentescer",
    "lentesceriam": "lentescer",
    "lentescerias": "lentescer",
    "lentescermo": "lentescer",
    "lentescermos": "lentescer",
    "lentescerá": "lentescer",
    "lentescerás": "lentescer",
    "lentescerão": "lentescer",
    "lentesceríamos": "lentescer",
    "lentesceríeis": "lentescer",
    "lentesces": "lentescer",
    "lentescesse": "lentescer",
    "lentescessem": "lentescer",
    "lentescesses": "lentescer",
    "lentesceste": "lentescer",
    "lentescestes": "lentescer",
    "lentesceu": "lentescer",
    "lentesci": "lentescer",
    "lentescia": "lentescer",
    "lentesciam": "lentescer",
    "lentescias": "lentescer",
    "lentescida": "lentescer",
    "lentescidas": "lentescer",
    "lentescido": "lentescer",
    "lentescidos": "lentescer",
    "lentescê": "lentescer",
    "lentescêramo": "lentescer",
    "lentescêramos": "lentescer",
    "lentescêrei": "lentescer",
    "lentescêreis": "lentescer",
    "lentescêsseis": "lentescer",
    "lentescêssemos": "lentescer",
    "lentescíamo": "lentescer",
    "lentescíamos": "lentescer",
    "lentescíei": "lentescer",
    "lentescíeis": "lentescer",
    "lentesça": "lentescer",
    "lentesçais": "lentescer",
    "lentesçam": "lentescer",
    "lentesçamo": "lentescer",
    "lentesçamos": "lentescer",
    "lentesças": "lentescer",
    "lentesço": "lentescer",
    "lentezas": "lenteza",
    "lenteá": "lentear",
    "lenteámo": "lentear",
    "lenteámos": "lentear",
    "lenteáramo": "lentear",
    "lenteáramos": "lentear",
    "lenteárei": "lentear",
    "lenteáreis": "lentear",
    "lenteásseis": "lentear",
    "lenteássemos": "lentear",
    "lenteávamo": "lentear",
    "lenteávamos": "lentear",
    "lenteávei": "lentear",
    "lenteáveis": "lentear",
    "lentibulariáceas": "lentibulariácea",
    "lenticelas": "lenticela",
    "lenticulares": "lenticular",
    "lenticões": "lenticão",
    "lentidões": "lentidão",
    "lentiformes": "lentiforme",
    "lentigens": "lentigem",
    "lentiginosa": "lentiginoso",
    "lentiginosas": "lentiginoso",
    "lentiginosos": "lentiginoso",
    "lentilhas": "lentilha",
    "lentilheiras": "lentilheira",
    "lentilhosa": "lentilhoso",
    "lentilhosas": "lentilhoso",
    "lentilhosos": "lentilhoso",
    "lentilhões": "lentilhão",
    "lentinha": "lento",
    "lentinhas": "lento",
    "lentinho": "lento",
    "lentinhos": "lento",
    "lentiscais": "lentiscal",
    "lentiscas": "lentisca",
    "lentiscos": "lentisco",
    "lentisqueiras": "lentisqueira",
    "lentita": "lento",
    "lentitas": "lento",
    "lentito": "lento",
    "lentitos": "lento",
    "lento": "lentar",
    "lentores": "lentor",
    "lentos": "lento",
    "lentou": "lentar",
    "lentozinho": "lento",
    "lentozinhos": "lento",
    "lentozito": "lento",
    "lentozitos": "lento",
    "lenturas": "lentura",
    "lentá": "lentar",
    "lentámo": "lentar",
    "lentámos": "lentar",
    "lentáramo": "lentar",
    "lentáramos": "lentar",
    "lentárei": "lentar",
    "lentáreis": "lentar",
    "lentásseis": "lentar",
    "lentássemos": "lentar",
    "lentávamo": "lentar",
    "lentávamos": "lentar",
    "lentávei": "lentar",
    "lentáveis": "lentar",
    "lentículas": "lentícula",
    "lentígrada": "lentígrado",
    "lentígradas": "lentígrado",
    "lentígrados": "lentígrado",
    "lentíssima": "lento",
    "lentíssimas": "lento",
    "lentíssimo": "lento",
    "lentíssimos": "lento",
    "lençalhos": "lençalho",
    "lençarias": "lençaria",
    "lenços": "lenço",
    "lençóis": "lençol",
    "leníamo": "lenir",
    "leníamos": "lenir",
    "leníei": "lenir",
    "leníeis": "lenir",
    "leníramo": "lenir",
    "leníramos": "lenir",
    "lenírei": "lenir",
    "leníreis": "lenir",
    "lenísseis": "lenir",
    "leníssemos": "lenir",
    "leoa": "leão",
    "leoas": "leão",
    "leoazinha": "leão",
    "leoazinhas": "leão",
    "leoazita": "leão",
    "leoazitas": "leão",
    "leonada": "leonado",
    "leonadas": "leonado",
    "leonados": "leonado",
    "leoneiras": "leoneira",
    "leones": "leone",
    "leonesa": "leonês",
    "leonesas": "leonês",
    "leoneses": "leonês",
    "leonina": "leonino",
    "leoninas": "leonino",
    "leoninos": "leonino",
    "leontíases": "leontíase",
    "leonuros": "leonuro",
    "leopardada": "leopardado",
    "leopardadas": "leopardado",
    "leopardados": "leopardado",
    "leopardos": "leopardo",
    "lepadídeos": "lepadídeo",
    "lepidoblástica": "lepidoblástico",
    "lepidoblásticas": "lepidoblástico",
    "lepidoblásticos": "lepidoblástico",
    "lepidocarpa": "lepidocarpo",
    "lepidocarpas": "lepidocarpo",
    "lepidocarpos": "lepidocarpo",
    "lepidomelanos": "lepidomelano",
    "lepidopídeos": "lepidopídeo",
    "lepidossirenes": "lepidossirene",
    "lepidossirenídeos": "lepidossirenídeo",
    "lepidossirénidas": "lepidossirénida",
    "lepidócera": "lepidócero",
    "lepidóceras": "lepidócero",
    "lepidóceros": "lepidócero",
    "lepidólitos": "lepidólito",
    "lepidópidas": "lepidópida",
    "lepidópteros": "lepidóptero",
    "lepismas": "lepisma",
    "leporina": "leporino",
    "leporinas": "leporino",
    "leporinos": "leporino",
    "leporídeos": "leporídeo",
    "lepras": "lepra",
    "leprologias": "leprologia",
    "leprologistas": "leprologista",
    "lepromas": "leproma",
    "leprosa": "leproso",
    "leprosarias": "leprosaria",
    "leprosas": "leproso",
    "leproses": "leprose",
    "leprosos": "leproso",
    "leprosários": "leprosário",
    "leprosórios": "leprosório",
    "lepróloga": "leprólogo",
    "leprólogas": "leprólogo",
    "leprólogos": "leprólogo",
    "leptinites": "leptinite",
    "leptocardios": "leptocardio",
    "leptocéfala": "leptocéfalo",
    "leptocéfalas": "leptocéfalo",
    "leptocéfalos": "leptocéfalo",
    "leptodactilídeos": "leptodactilídeo",
    "leptologias": "leptologia",
    "leptomedusas": "leptomedusa",
    "leptomeninges": "leptomeninge",
    "leptomeningites": "leptomeningite",
    "leptossómica": "leptossómico",
    "leptossómicas": "leptossómico",
    "leptossómicos": "leptossómico",
    "lepturíneos": "lepturíneo",
    "leptões": "leptão",
    "lepádidas": "lepádida",
    "lepíperos": "lepípero",
    "lepóridas": "lepórida",
    "leques": "leque",
    "lera": "ler",
    "leram": "ler",
    "leras": "ler",
    "lercas": "lerca",
    "lerda": "lerdo",
    "lerdas": "lerdo",
    "lerdaça": "lerdaço",
    "lerdaças": "lerdaço",
    "lerdaços": "lerdaço",
    "lerde": "ler",
    "lerdes": "ler",
    "lerdices": "lerdice",
    "lerdos": "lerdo",
    "lere": "ler",
    "lerei": "ler",
    "lereis": "ler",
    "lerem": "ler",
    "leremos": "ler",
    "leres": "ler",
    "leria": "leriar",
    "leriada": "leriar",
    "leriadas": "leriar",
    "leriado": "leriar",
    "leriados": "leriar",
    "leriai": "leriar",
    "leriais": "leriar",
    "leriam": "leriar",
    "leriamo": "leriar",
    "leriamos": "leriar",
    "leriando": "leriar",
    "leriara": "leriar",
    "leriaram": "leriar",
    "leriaras": "leriar",
    "leriardes": "leriar",
    "leriarei": "leriar",
    "leriareis": "leriar",
    "leriarem": "leriar",
    "leriaremos": "leriar",
    "leriares": "leriar",
    "leriaria": "leriar",
    "leriariam": "leriar",
    "leriarias": "leriar",
    "leriarmo": "leriar",
    "leriarmos": "leriar",
    "leriará": "leriar",
    "leriarás": "leriar",
    "leriarão": "leriar",
    "leriaríamos": "leriar",
    "leriaríeis": "leriar",
    "lerias": "leriar",
    "leriasse": "leriar",
    "leriassem": "leriar",
    "leriasses": "leriar",
    "leriaste": "leriar",
    "leriastes": "leriar",
    "leriava": "leriar",
    "leriavam": "leriar",
    "leriavas": "leriar",
    "lericas": "lerica",
    "lerie": "leriar",
    "leriei": "leriar",
    "lerieis": "leriar",
    "leriem": "leriar",
    "leriemo": "leriar",
    "leriemos": "leriar",
    "leries": "leriar",
    "lerio": "leriar",
    "leriou": "leriar",
    "leriámo": "leriar",
    "leriámos": "leriar",
    "leriáramo": "leriar",
    "leriáramos": "leriar",
    "leriáreis": "leriar",
    "leriásseis": "leriar",
    "leriássemos": "leriar",
    "leriávamo": "leriar",
    "leriávamos": "leriar",
    "leriáveis": "leriar",
    "lermo": "ler",
    "lermos": "ler",
    "lerá": "ler",
    "lerás": "ler",
    "lerão": "ler",
    "leríamos": "ler",
    "leríeis": "ler",
    "lesa": "leso",
    "lesada": "lesar",
    "lesadas": "lesar",
    "lesado": "lesar",
    "lesadora": "lesador",
    "lesadoras": "lesador",
    "lesadores": "lesador",
    "lesados": "lesar",
    "lesadíssima": "lesado",
    "lesadíssimas": "lesado",
    "lesadíssimo": "lesado",
    "lesadíssimos": "lesado",
    "lesai": "lesar",
    "lesais": "lesar",
    "lesam": "lesar",
    "lesamo": "lesar",
    "lesamos": "lesar",
    "lesando": "lesar",
    "lesantes": "lesante",
    "lesara": "lesar",
    "lesaram": "lesar",
    "lesaras": "lesar",
    "lesarde": "lesar",
    "lesardes": "lesar",
    "lesare": "lesar",
    "lesarei": "lesar",
    "lesareis": "lesar",
    "lesarem": "lesar",
    "lesaremos": "lesar",
    "lesares": "lesar",
    "lesaria": "lesar",
    "lesariam": "lesar",
    "lesarias": "lesar",
    "lesarmo": "lesar",
    "lesarmos": "lesar",
    "lesará": "lesar",
    "lesarás": "lesar",
    "lesarão": "lesar",
    "lesaríamos": "lesar",
    "lesaríeis": "lesar",
    "lesas": "leso",
    "lesasse": "lesar",
    "lesassem": "lesar",
    "lesasses": "lesar",
    "lesaste": "lesar",
    "lesastes": "lesar",
    "lesava": "lesar",
    "lesavam": "lesar",
    "lesavas": "lesar",
    "lesbiana": "lesbiano",
    "lesbianas": "lesbiano",
    "lesbianismos": "lesbianismo",
    "lesbianos": "lesbiano",
    "lesbíaca": "lesbíaco",
    "lesbíacas": "lesbíaco",
    "lesbíacos": "lesbíaco",
    "lese": "lesar",
    "lesei": "lesar",
    "leseis": "lesar",
    "lesem": "lesar",
    "lesemo": "lesar",
    "lesemos": "lesar",
    "leses": "lesar",
    "lesins": "lesim",
    "lesiona": "lesionar",
    "lesionada": "lesionar",
    "lesionadas": "lesionar",
    "lesionado": "lesionar",
    "lesionados": "lesionar",
    "lesionai": "lesionar",
    "lesionais": "lesionar",
    "lesionam": "lesionar",
    "lesionamo": "lesionar",
    "lesionamos": "lesionar",
    "lesionando": "lesionar",
    "lesionara": "lesionar",
    "lesionaram": "lesionar",
    "lesionaras": "lesionar",
    "lesionarde": "lesionar",
    "lesionardes": "lesionar",
    "lesionare": "lesionar",
    "lesionarei": "lesionar",
    "lesionareis": "lesionar",
    "lesionarem": "lesionar",
    "lesionaremos": "lesionar",
    "lesionares": "lesionar",
    "lesionaria": "lesionar",
    "lesionariam": "lesionar",
    "lesionarias": "lesionar",
    "lesionarmo": "lesionar",
    "lesionarmos": "lesionar",
    "lesionará": "lesionar",
    "lesionarás": "lesionar",
    "lesionarão": "lesionar",
    "lesionaríamos": "lesionar",
    "lesionaríeis": "lesionar",
    "lesionas": "lesionar",
    "lesionasse": "lesionar",
    "lesionassem": "lesionar",
    "lesionasses": "lesionar",
    "lesionaste": "lesionar",
    "lesionastes": "lesionar",
    "lesionava": "lesionar",
    "lesionavam": "lesionar",
    "lesionavas": "lesionar",
    "lesione": "lesionar",
    "lesionei": "lesionar",
    "lesioneis": "lesionar",
    "lesionem": "lesionar",
    "lesionemo": "lesionar",
    "lesionemos": "lesionar",
    "lesiones": "lesionar",
    "lesiono": "lesionar",
    "lesionou": "lesionar",
    "lesioná": "lesionar",
    "lesionámo": "lesionar",
    "lesionámos": "lesionar",
    "lesionáramo": "lesionar",
    "lesionáramos": "lesionar",
    "lesionárei": "lesionar",
    "lesionáreis": "lesionar",
    "lesionásseis": "lesionar",
    "lesionássemos": "lesionar",
    "lesionávamo": "lesionar",
    "lesionávamos": "lesionar",
    "lesionávei": "lesionar",
    "lesionáveis": "lesionar",
    "lesiva": "lesivo",
    "lesivas": "lesivo",
    "lesivos": "lesivo",
    "lesma": "lesmar",
    "lesmada": "lesmar",
    "lesmadas": "lesmar",
    "lesmado": "lesmar",
    "lesmados": "lesmar",
    "lesmai": "lesmar",
    "lesmais": "lesmar",
    "lesmam": "lesmar",
    "lesmamo": "lesmar",
    "lesmamos": "lesmar",
    "lesmando": "lesmar",
    "lesmara": "lesmar",
    "lesmaram": "lesmar",
    "lesmaras": "lesmar",
    "lesmardes": "lesmar",
    "lesmarei": "lesmar",
    "lesmareis": "lesmar",
    "lesmarem": "lesmar",
    "lesmaremos": "lesmar",
    "lesmares": "lesmar",
    "lesmaria": "lesmar",
    "lesmariam": "lesmar",
    "lesmarias": "lesmar",
    "lesmarmo": "lesmar",
    "lesmarmos": "lesmar",
    "lesmará": "lesmar",
    "lesmarás": "lesmar",
    "lesmarão": "lesmar",
    "lesmaríamos": "lesmar",
    "lesmaríeis": "lesmar",
    "lesmas": "lesmar",
    "lesmasse": "lesmar",
    "lesmassem": "lesmar",
    "lesmasses": "lesmar",
    "lesmaste": "lesmar",
    "lesmastes": "lesmar",
    "lesmava": "lesmar",
    "lesmavam": "lesmar",
    "lesmavas": "lesmar",
    "lesme": "lesmar",
    "lesmei": "lesmar",
    "lesmeis": "lesmar",
    "lesmem": "lesmar",
    "lesmemo": "lesmar",
    "lesmemos": "lesmar",
    "lesmenta": "lesmento",
    "lesmentas": "lesmento",
    "lesmentos": "lesmento",
    "lesmes": "lesme",
    "lesmo": "lesmar",
    "lesmou": "lesmar",
    "lesmámo": "lesmar",
    "lesmámos": "lesmar",
    "lesmáramo": "lesmar",
    "lesmáramos": "lesmar",
    "lesmáreis": "lesmar",
    "lesmásseis": "lesmar",
    "lesmássemos": "lesmar",
    "lesmávamo": "lesmar",
    "lesmávamos": "lesmar",
    "lesmáveis": "lesmar",
    "leso": "lesar",
    "lesos": "leso",
    "lesota": "lesoto",
    "lesotas": "lesoto",
    "lesotos": "lesoto",
    "lesou": "lesar",
    "lesse": "ler",
    "lessem": "ler",
    "lesses": "ler",
    "lesta": "lesto",
    "lestadas": "lestada",
    "lestas": "lesto",
    "leste": "ler",
    "lestes": "leste",
    "lestias": "lestia",
    "lestos": "lesto",
    "lestras": "lestra",
    "lesá": "lesar",
    "lesámo": "lesar",
    "lesámos": "lesar",
    "lesáramo": "lesar",
    "lesáramos": "lesar",
    "lesárei": "lesar",
    "lesáreis": "lesar",
    "lesásseis": "lesar",
    "lesássemos": "lesar",
    "lesávamo": "lesar",
    "lesávamos": "lesar",
    "lesávei": "lesar",
    "lesáveis": "lesar",
    "lesões": "lesão",
    "letais": "letal",
    "letalidades": "letalidade",
    "letargia": "letargiar",
    "letargiada": "letargiar",
    "letargiadas": "letargiar",
    "letargiado": "letargiar",
    "letargiados": "letargiar",
    "letargiai": "letargiar",
    "letargiais": "letargiar",
    "letargiam": "letargiar",
    "letargiamo": "letargiar",
    "letargiamos": "letargiar",
    "letargiando": "letargiar",
    "letargiara": "letargiar",
    "letargiaram": "letargiar",
    "letargiaras": "letargiar",
    "letargiarde": "letargiar",
    "letargiardes": "letargiar",
    "letargiare": "letargiar",
    "letargiarei": "letargiar",
    "letargiareis": "letargiar",
    "letargiarem": "letargiar",
    "letargiaremos": "letargiar",
    "letargiares": "letargiar",
    "letargiaria": "letargiar",
    "letargiariam": "letargiar",
    "letargiarias": "letargiar",
    "letargiarmo": "letargiar",
    "letargiarmos": "letargiar",
    "letargiará": "letargiar",
    "letargiarás": "letargiar",
    "letargiarão": "letargiar",
    "letargiaríamos": "letargiar",
    "letargiaríeis": "letargiar",
    "letargias": "letargiar",
    "letargiasse": "letargiar",
    "letargiassem": "letargiar",
    "letargiasses": "letargiar",
    "letargiaste": "letargiar",
    "letargiastes": "letargiar",
    "letargiava": "letargiar",
    "letargiavam": "letargiar",
    "letargiavas": "letargiar",
    "letargie": "letargiar",
    "letargiei": "letargiar",
    "letargieis": "letargiar",
    "letargiem": "letargiar",
    "letargiemo": "letargiar",
    "letargiemos": "letargiar",
    "letargies": "letargiar",
    "letargio": "letargiar",
    "letargiou": "letargiar",
    "letargiá": "letargiar",
    "letargiámo": "letargiar",
    "letargiámos": "letargiar",
    "letargiáramo": "letargiar",
    "letargiáramos": "letargiar",
    "letargiárei": "letargiar",
    "letargiáreis": "letargiar",
    "letargiásseis": "letargiar",
    "letargiássemos": "letargiar",
    "letargiávamo": "letargiar",
    "letargiávamos": "letargiar",
    "letargiávei": "letargiar",
    "letargiáveis": "letargiar",
    "letargos": "letargo",
    "leteia": "leteu",
    "leteias": "leteu",
    "leteus": "leteu",
    "letifica": "letificar",
    "letificada": "letificar",
    "letificadas": "letificar",
    "letificado": "letificar",
    "letificados": "letificar",
    "letificai": "letificar",
    "letificais": "letificar",
    "letificam": "letificar",
    "letificamo": "letificar",
    "letificamos": "letificar",
    "letificando": "letificar",
    "letificantes": "letificante",
    "letificara": "letificar",
    "letificaram": "letificar",
    "letificaras": "letificar",
    "letificarde": "letificar",
    "letificardes": "letificar",
    "letificare": "letificar",
    "letificarei": "letificar",
    "letificareis": "letificar",
    "letificarem": "letificar",
    "letificaremos": "letificar",
    "letificares": "letificar",
    "letificaria": "letificar",
    "letificariam": "letificar",
    "letificarias": "letificar",
    "letificarmo": "letificar",
    "letificarmos": "letificar",
    "letificará": "letificar",
    "letificarás": "letificar",
    "letificarão": "letificar",
    "letificaríamos": "letificar",
    "letificaríeis": "letificar",
    "letificas": "letificar",
    "letificasse": "letificar",
    "letificassem": "letificar",
    "letificasses": "letificar",
    "letificaste": "letificar",
    "letificastes": "letificar",
    "letificava": "letificar",
    "letificavam": "letificar",
    "letificavas": "letificar",
    "letifico": "letificar",
    "letificou": "letificar",
    "letificá": "letificar",
    "letificámo": "letificar",
    "letificámos": "letificar",
    "letificáramo": "letificar",
    "letificáramos": "letificar",
    "letificárei": "letificar",
    "letificáreis": "letificar",
    "letificásseis": "letificar",
    "letificássemos": "letificar",
    "letificávamo": "letificar",
    "letificávamos": "letificar",
    "letificávei": "letificar",
    "letificáveis": "letificar",
    "letifique": "letificar",
    "letifiquei": "letificar",
    "letifiqueis": "letificar",
    "letifiquem": "letificar",
    "letifiquemo": "letificar",
    "letifiquemos": "letificar",
    "letifiques": "letificar",
    "letissimulações": "letissimulação",
    "letomanias": "letomania",
    "letona": "letão",
    "letonas": "letão",
    "letraches": "letrache",
    "letrada": "letrado",
    "letradas": "letrado",
    "letradices": "letradice",
    "letrados": "letrado",
    "letraduras": "letradura",
    "letras": "letra",
    "letrasets": "letraset",
    "letreada": "letrear",
    "letreadas": "letrear",
    "letreado": "letrear",
    "letreados": "letrear",
    "letreai": "letrear",
    "letreais": "letrear",
    "letreamo": "letrear",
    "letreamos": "letrear",
    "letreando": "letrear",
    "letreara": "letrear",
    "letrearam": "letrear",
    "letrearas": "letrear",
    "letrearde": "letrear",
    "letreardes": "letrear",
    "letreare": "letrear",
    "letrearei": "letrear",
    "letreareis": "letrear",
    "letrearem": "letrear",
    "letrearemos": "letrear",
    "letreares": "letrear",
    "letrearia": "letrear",
    "letreariam": "letrear",
    "letrearias": "letrear",
    "letrearmo": "letrear",
    "letrearmos": "letrear",
    "letreará": "letrear",
    "letrearás": "letrear",
    "letrearão": "letrear",
    "letrearíamos": "letrear",
    "letrearíeis": "letrear",
    "letreasse": "letrear",
    "letreassem": "letrear",
    "letreasses": "letrear",
    "letreaste": "letrear",
    "letreastes": "letrear",
    "letreava": "letrear",
    "letreavam": "letrear",
    "letreavas": "letrear",
    "letreei": "letrear",
    "letreeis": "letrear",
    "letreemo": "letrear",
    "letreemos": "letrear",
    "letreia": "letrear",
    "letreiam": "letrear",
    "letreias": "letrear",
    "letreie": "letrear",
    "letreiem": "letrear",
    "letreies": "letrear",
    "letreio": "letrear",
    "letreiras": "letreira",
    "letreiristas": "letreirista",
    "letreiros": "letreiro",
    "letreou": "letrear",
    "letreá": "letrear",
    "letreámo": "letrear",
    "letreámos": "letrear",
    "letreáramo": "letrear",
    "letreáramos": "letrear",
    "letreárei": "letrear",
    "letreáreis": "letrear",
    "letreásseis": "letrear",
    "letreássemos": "letrear",
    "letreávamo": "letrear",
    "letreávamos": "letrear",
    "letreávei": "letrear",
    "letreáveis": "letrear",
    "letrias": "letria",
    "letrinas": "letrina",
    "letrinha": "letra",
    "letrinhas": "letra",
    "letristas": "letrista",
    "letrita": "letra",
    "letritas": "letra",
    "letruda": "letrudo",
    "letrudas": "letrudo",
    "letrudos": "letrudo",
    "letárgica": "letárgico",
    "letárgicas": "letárgico",
    "letárgicos": "letárgico",
    "letéia": "leteu",
    "letéias": "leteu",
    "letícias": "letícia",
    "letífera": "letífero",
    "letíferas": "letífero",
    "letíferos": "letífero",
    "letífica": "letífico",
    "letíficas": "letífico",
    "letíficos": "letífico",
    "letões": "letão",
    "leu": "ler",
    "leucemias": "leucemia",
    "leucinas": "leucina",
    "leucites": "leucite",
    "leucititos": "leucitito",
    "leucitos": "leucito",
    "leucitófiros": "leucitófiro",
    "leucocitemias": "leucocitemia",
    "leucocitometrias": "leucocitometria",
    "leucocitoses": "leucocitose",
    "leucocitária": "leucocitário",
    "leucocitárias": "leucocitário",
    "leucocitários": "leucocitário",
    "leucocrática": "leucocrático",
    "leucocráticas": "leucocrático",
    "leucocráticos": "leucocrático",
    "leucocéfala": "leucocéfalo",
    "leucocéfalas": "leucocéfalo",
    "leucocéfalos": "leucocéfalo",
    "leucodermias": "leucodermia",
    "leucoflegmasias": "leucoflegmasia",
    "leucomas": "leucoma",
    "leuconíquias": "leuconíquia",
    "leuconóides": "leuconóide",
    "leucopatias": "leucopatia",
    "leucopenias": "leucopenia",
    "leucoplasias": "leucoplasia",
    "leucoplasmas": "leucoplasma",
    "leucopoeses": "leucopoese",
    "leucopoieses": "leucopoiese",
    "leucopoiética": "leucopoiético",
    "leucopoiéticas": "leucopoiético",
    "leucopoiéticos": "leucopoiético",
    "leucopoética": "leucopoético",
    "leucopoéticas": "leucopoético",
    "leucopoéticos": "leucopoético",
    "leucorreias": "leucorreia",
    "leucorreica": "leucorreico",
    "leucorreicas": "leucorreico",
    "leucorreicos": "leucorreico",
    "leucoses": "leucose",
    "leucotomias": "leucotomia",
    "leucotrofinas": "leucotrofina",
    "leucoxenas": "leucoxena",
    "leucócitos": "leucócito",
    "leucópodes": "leucópode",
    "leucóptera": "leucóptero",
    "leucópteras": "leucóptero",
    "leucópteros": "leucóptero",
    "leus": "leu",
    "leva": "levar",
    "levada": "levar",
    "levadas": "levar",
    "levadazinha": "levado",
    "levadazinhas": "levado",
    "levadazita": "levado",
    "levadazitas": "levado",
    "levadia": "levadio",
    "levadias": "levadio",
    "levadinha": "levado",
    "levadinhas": "levado",
    "levadinho": "levado",
    "levadinhos": "levado",
    "levadios": "levadio",
    "levadita": "levado",
    "levaditas": "levado",
    "levadito": "levado",
    "levaditos": "levado",
    "levadiça": "levadiço",
    "levadiças": "levadiço",
    "levadiços": "levadiço",
    "levado": "levar",
    "levadoiras": "levadoira",
    "levadora": "levador",
    "levadoras": "levador",
    "levadores": "levador",
    "levados": "levar",
    "levadouras": "levadoura",
    "levadozinho": "levado",
    "levadozinhos": "levado",
    "levadozito": "levado",
    "levadozitos": "levado",
    "levaduras": "levadura",
    "levadurinas": "levadurina",
    "levadíssima": "levado",
    "levadíssimas": "levado",
    "levadíssimo": "levado",
    "levadíssimos": "levado",
    "levagantes": "levagante",
    "levai": "levar",
    "levais": "levar",
    "levam": "levar",
    "levamentos": "levamento",
    "levamo": "levar",
    "levamos": "levar",
    "levando": "levar",
    "levanta": "levantar",
    "levantada": "levantar",
    "levantadas": "levantar",
    "levantadiça": "levantadiço",
    "levantadiças": "levantadiço",
    "levantadiços": "levantadiço",
    "levantado": "levantar",
    "levantadora": "levantador",
    "levantadoras": "levantador",
    "levantadores": "levantador",
    "levantados": "levantar",
    "levantaduras": "levantadura",
    "levantai": "levantar",
    "levantais": "levantar",
    "levantam": "levantar",
    "levantamentos": "levantamento",
    "levantamo": "levantar",
    "levantamos": "levantar",
    "levantando": "levantar",
    "levantantes": "levantante",
    "levantara": "levantar",
    "levantaram": "levantar",
    "levantaras": "levantar",
    "levantarde": "levantar",
    "levantardes": "levantar",
    "levantare": "levantar",
    "levantarei": "levantar",
    "levantareis": "levantar",
    "levantarem": "levantar",
    "levantaremos": "levantar",
    "levantares": "levantar",
    "levantaria": "levantar",
    "levantariam": "levantar",
    "levantarias": "levantar",
    "levantarmo": "levantar",
    "levantarmos": "levantar",
    "levantará": "levantar",
    "levantarás": "levantar",
    "levantarão": "levantar",
    "levantaríamos": "levantar",
    "levantaríeis": "levantar",
    "levantas": "levantar",
    "levantasse": "levantar",
    "levantassem": "levantar",
    "levantasses": "levantar",
    "levantaste": "levantar",
    "levantastes": "levantar",
    "levantava": "levantar",
    "levantavam": "levantar",
    "levantavas": "levantar",
    "levante": "levantar",
    "levantei": "levantar",
    "levanteis": "levantar",
    "levantem": "levantar",
    "levantemo": "levantar",
    "levantemos": "levantar",
    "levantes": "levante",
    "levantina": "levantino",
    "levantinas": "levantino",
    "levantinos": "levantino",
    "levantiscos": "levantisco",
    "levanto": "levantar",
    "levantos": "levanto",
    "levantou": "levantar",
    "levantá": "levantar",
    "levantámo": "levantar",
    "levantámos": "levantar",
    "levantáramo": "levantar",
    "levantáramos": "levantar",
    "levantárei": "levantar",
    "levantáreis": "levantar",
    "levantásseis": "levantar",
    "levantássemos": "levantar",
    "levantávamo": "levantar",
    "levantávamos": "levantar",
    "levantávei": "levantar",
    "levantáveis": "levantável",
    "levara": "levar",
    "levaram": "levar",
    "levaras": "levar",
    "levarde": "levar",
    "levardes": "levar",
    "levare": "levar",
    "levarei": "levar",
    "levareis": "levar",
    "levarem": "levar",
    "levaremos": "levar",
    "levares": "levar",
    "levaria": "levar",
    "levariam": "levar",
    "levarias": "levar",
    "levarmo": "levar",
    "levarmos": "levar",
    "levará": "levar",
    "levarás": "levar",
    "levarão": "levar",
    "levaríamos": "levar",
    "levaríeis": "levar",
    "levas": "levar",
    "levasse": "levar",
    "levassem": "levar",
    "levasses": "levar",
    "levaste": "levar",
    "levastes": "levar",
    "levava": "levar",
    "levavam": "levar",
    "levavas": "levar",
    "leve": "levar",
    "leveda": "levedar",
    "levedada": "levedar",
    "levedadas": "levedar",
    "levedado": "levedar",
    "levedados": "levedar",
    "levedaduras": "levedadura",
    "levedai": "levedar",
    "levedais": "levedar",
    "levedam": "levedar",
    "levedamo": "levedar",
    "levedamos": "levedar",
    "levedando": "levedar",
    "levedara": "levedar",
    "levedaram": "levedar",
    "levedaras": "levedar",
    "levedarde": "levedar",
    "levedardes": "levedar",
    "levedare": "levedar",
    "levedarei": "levedar",
    "levedareis": "levedar",
    "levedarem": "levedar",
    "levedaremos": "levedar",
    "levedares": "levedar",
    "levedaria": "levedar",
    "levedariam": "levedar",
    "levedarias": "levedar",
    "levedarmo": "levedar",
    "levedarmos": "levedar",
    "levedará": "levedar",
    "levedarás": "levedar",
    "levedarão": "levedar",
    "levedaríamos": "levedar",
    "levedaríeis": "levedar",
    "levedas": "levedar",
    "levedasse": "levedar",
    "levedassem": "levedar",
    "levedasses": "levedar",
    "levedaste": "levedar",
    "levedastes": "levedar",
    "levedava": "levedar",
    "levedavam": "levedar",
    "levedavas": "levedar",
    "levedações": "levedação",
    "levede": "levedar",
    "levedei": "levedar",
    "levedeis": "levedar",
    "levedem": "levedar",
    "levedemo": "levedar",
    "levedemos": "levedar",
    "levedes": "levedar",
    "levedo": "levedar",
    "levedou": "levedar",
    "leveduras": "levedura",
    "levedurinas": "levedurina",
    "levedá": "levedar",
    "levedámo": "levedar",
    "levedámos": "levedar",
    "levedáramo": "levedar",
    "levedáramos": "levedar",
    "levedárei": "levedar",
    "levedáreis": "levedar",
    "levedásseis": "levedar",
    "levedássemos": "levedar",
    "levedávamo": "levedar",
    "levedávamos": "levedar",
    "levedávei": "levedar",
    "levedáveis": "levedar",
    "levei": "levar",
    "leveira": "leveiro",
    "leveiras": "leveiro",
    "leveiros": "leveiro",
    "leveis": "levar",
    "levem": "levar",
    "levemo": "levar",
    "levemos": "levar",
    "leves": "leve",
    "levezas": "leveza",
    "leviana": "leviano",
    "levianas": "leviano",
    "leviandades": "leviandade",
    "levianos": "leviano",
    "leviatãs": "leviatã",
    "leviatões": "leviatão",
    "levidades": "levidade",
    "levidões": "levidão",
    "leviga": "levigar",
    "levigada": "levigar",
    "levigadas": "levigar",
    "levigado": "levigar",
    "levigados": "levigar",
    "levigai": "levigar",
    "levigais": "levigar",
    "levigam": "levigar",
    "levigamo": "levigar",
    "levigamos": "levigar",
    "levigando": "levigar",
    "levigara": "levigar",
    "levigaram": "levigar",
    "levigaras": "levigar",
    "levigarde": "levigar",
    "levigardes": "levigar",
    "levigare": "levigar",
    "levigarei": "levigar",
    "levigareis": "levigar",
    "levigarem": "levigar",
    "levigaremos": "levigar",
    "levigares": "levigar",
    "levigaria": "levigar",
    "levigariam": "levigar",
    "levigarias": "levigar",
    "levigarmo": "levigar",
    "levigarmos": "levigar",
    "levigará": "levigar",
    "levigarás": "levigar",
    "levigarão": "levigar",
    "levigaríamos": "levigar",
    "levigaríeis": "levigar",
    "levigas": "levigar",
    "levigasse": "levigar",
    "levigassem": "levigar",
    "levigasses": "levigar",
    "levigaste": "levigar",
    "levigastes": "levigar",
    "levigava": "levigar",
    "levigavam": "levigar",
    "levigavas": "levigar",
    "levigações": "levigação",
    "levigo": "levigar",
    "levigou": "levigar",
    "levigue": "levigar",
    "leviguei": "levigar",
    "levigueis": "levigar",
    "leviguem": "levigar",
    "leviguemo": "levigar",
    "leviguemos": "levigar",
    "levigues": "levigar",
    "levigá": "levigar",
    "levigámo": "levigar",
    "levigámos": "levigar",
    "levigáramo": "levigar",
    "levigáramos": "levigar",
    "levigárei": "levigar",
    "levigáreis": "levigar",
    "levigásseis": "levigar",
    "levigássemos": "levigar",
    "levigávamo": "levigar",
    "levigávamos": "levigar",
    "levigávei": "levigar",
    "levigáveis": "levigar",
    "levirados": "levirado",
    "leviratos": "levirato",
    "levirrostra": "levirrostro",
    "levirrostras": "levirrostro",
    "levirrostros": "levirrostro",
    "levisitas": "levisita",
    "levita": "levitar",
    "levitada": "levitar",
    "levitadas": "levitar",
    "levitado": "levitar",
    "levitados": "levitar",
    "levitai": "levitar",
    "levitais": "levitar",
    "levitam": "levitar",
    "levitamo": "levitar",
    "levitamos": "levitar",
    "levitando": "levitar",
    "levitara": "levitar",
    "levitaram": "levitar",
    "levitaras": "levitar",
    "levitarde": "levitar",
    "levitardes": "levitar",
    "levitare": "levitar",
    "levitarei": "levitar",
    "levitareis": "levitar",
    "levitarem": "levitar",
    "levitaremos": "levitar",
    "levitares": "levitar",
    "levitaria": "levitar",
    "levitariam": "levitar",
    "levitarias": "levitar",
    "levitarmo": "levitar",
    "levitarmos": "levitar",
    "levitará": "levitar",
    "levitarás": "levitar",
    "levitarão": "levitar",
    "levitaríamos": "levitar",
    "levitaríeis": "levitar",
    "levitas": "levitar",
    "levitasse": "levitar",
    "levitassem": "levitar",
    "levitasses": "levitar",
    "levitaste": "levitar",
    "levitastes": "levitar",
    "levitava": "levitar",
    "levitavam": "levitar",
    "levitavas": "levitar",
    "levitações": "levitação",
    "levite": "levitar",
    "levitei": "levitar",
    "leviteis": "levitar",
    "levitem": "levitar",
    "levitemo": "levitar",
    "levitemos": "levitar",
    "levites": "levitar",
    "levito": "levitar",
    "levitou": "levitar",
    "levitá": "levitar",
    "levitámo": "levitar",
    "levitámos": "levitar",
    "levitáramo": "levitar",
    "levitáramos": "levitar",
    "levitárei": "levitar",
    "levitáreis": "levitar",
    "levitásseis": "levitar",
    "levitássemos": "levitar",
    "levitávamo": "levitar",
    "levitávamos": "levitar",
    "levitávei": "levitar",
    "levitáveis": "levitar",
    "levo": "levar",
    "levogira": "levogiro",
    "levogiras": "levogiro",
    "levogiros": "levogiro",
    "levou": "levar",
    "levs": "lev",
    "levuloses": "levulose",
    "levurómetros": "levurómetro",
    "levá": "levar",
    "levámo": "levar",
    "levámos": "levar",
    "leváramo": "levar",
    "leváramos": "levar",
    "levárei": "levar",
    "leváreis": "levar",
    "levásseis": "levar",
    "levássemos": "levar",
    "levávamo": "levar",
    "levávamos": "levar",
    "levávei": "levar",
    "leváveis": "levar",
    "levântica": "levântico",
    "levânticas": "levântico",
    "levânticos": "levântico",
    "levípedes": "levípede",
    "levítica": "levítico",
    "levíticas": "levítico",
    "levíticos": "levítico",
    "lexemas": "lexema",
    "lexicais": "lexical",
    "lexicaliza": "lexicalizar",
    "lexicalizada": "lexicalizar",
    "lexicalizadas": "lexicalizar",
    "lexicalizado": "lexicalizar",
    "lexicalizados": "lexicalizar",
    "lexicalizai": "lexicalizar",
    "lexicalizais": "lexicalizar",
    "lexicalizam": "lexicalizar",
    "lexicalizamo": "lexicalizar",
    "lexicalizamos": "lexicalizar",
    "lexicalizando": "lexicalizar",
    "lexicalizara": "lexicalizar",
    "lexicalizaram": "lexicalizar",
    "lexicalizaras": "lexicalizar",
    "lexicalizarde": "lexicalizar",
    "lexicalizardes": "lexicalizar",
    "lexicalizare": "lexicalizar",
    "lexicalizarei": "lexicalizar",
    "lexicalizareis": "lexicalizar",
    "lexicalizarem": "lexicalizar",
    "lexicalizaremos": "lexicalizar",
    "lexicalizares": "lexicalizar",
    "lexicalizaria": "lexicalizar",
    "lexicalizariam": "lexicalizar",
    "lexicalizarias": "lexicalizar",
    "lexicalizarmo": "lexicalizar",
    "lexicalizarmos": "lexicalizar",
    "lexicalizará": "lexicalizar",
    "lexicalizarás": "lexicalizar",
    "lexicalizarão": "lexicalizar",
    "lexicalizaríamos": "lexicalizar",
    "lexicalizaríeis": "lexicalizar",
    "lexicalizas": "lexicalizar",
    "lexicalizasse": "lexicalizar",
    "lexicalizassem": "lexicalizar",
    "lexicalizasses": "lexicalizar",
    "lexicalizaste": "lexicalizar",
    "lexicalizastes": "lexicalizar",
    "lexicalizava": "lexicalizar",
    "lexicalizavam": "lexicalizar",
    "lexicalizavas": "lexicalizar",
    "lexicalize": "lexicalizar",
    "lexicalizei": "lexicalizar",
    "lexicalizeis": "lexicalizar",
    "lexicalizem": "lexicalizar",
    "lexicalizemo": "lexicalizar",
    "lexicalizemos": "lexicalizar",
    "lexicalizes": "lexicalizar",
    "lexicalizo": "lexicalizar",
    "lexicalizou": "lexicalizar",
    "lexicalizá": "lexicalizar",
    "lexicalizámo": "lexicalizar",
    "lexicalizámos": "lexicalizar",
    "lexicalizáramo": "lexicalizar",
    "lexicalizáramos": "lexicalizar",
    "lexicalizárei": "lexicalizar",
    "lexicalizáreis": "lexicalizar",
    "lexicalizásseis": "lexicalizar",
    "lexicalizássemos": "lexicalizar",
    "lexicalizávamo": "lexicalizar",
    "lexicalizávamos": "lexicalizar",
    "lexicalizávei": "lexicalizar",
    "lexicalizáveis": "lexicalizável",
    "lexicografa": "lexicografar",
    "lexicografada": "lexicografar",
    "lexicografadas": "lexicografar",
    "lexicografado": "lexicografar",
    "lexicografados": "lexicografar",
    "lexicografai": "lexicografar",
    "lexicografais": "lexicografar",
    "lexicografam": "lexicografar",
    "lexicografamo": "lexicografar",
    "lexicografamos": "lexicografar",
    "lexicografando": "lexicografar",
    "lexicografara": "lexicografar",
    "lexicografaram": "lexicografar",
    "lexicografaras": "lexicografar",
    "lexicografarde": "lexicografar",
    "lexicografardes": "lexicografar",
    "lexicografare": "lexicografar",
    "lexicografarei": "lexicografar",
    "lexicografareis": "lexicografar",
    "lexicografarem": "lexicografar",
    "lexicografaremos": "lexicografar",
    "lexicografares": "lexicografar",
    "lexicografaria": "lexicografar",
    "lexicografariam": "lexicografar",
    "lexicografarias": "lexicografar",
    "lexicografarmo": "lexicografar",
    "lexicografarmos": "lexicografar",
    "lexicografará": "lexicografar",
    "lexicografarás": "lexicografar",
    "lexicografarão": "lexicografar",
    "lexicografaríamos": "lexicografar",
    "lexicografaríeis": "lexicografar",
    "lexicografas": "lexicografar",
    "lexicografasse": "lexicografar",
    "lexicografassem": "lexicografar",
    "lexicografasses": "lexicografar",
    "lexicografaste": "lexicografar",
    "lexicografastes": "lexicografar",
    "lexicografava": "lexicografar",
    "lexicografavam": "lexicografar",
    "lexicografavas": "lexicografar",
    "lexicografe": "lexicografar",
    "lexicografei": "lexicografar",
    "lexicografeis": "lexicografar",
    "lexicografem": "lexicografar",
    "lexicografemo": "lexicografar",
    "lexicografemos": "lexicografar",
    "lexicografes": "lexicografar",
    "lexicografias": "lexicografia",
    "lexicografo": "lexicografar",
    "lexicografou": "lexicografar",
    "lexicografá": "lexicografar",
    "lexicografámo": "lexicografar",
    "lexicografámos": "lexicografar",
    "lexicografáramo": "lexicografar",
    "lexicografáramos": "lexicografar",
    "lexicografárei": "lexicografar",
    "lexicografáreis": "lexicografar",
    "lexicografásseis": "lexicografar",
    "lexicografássemos": "lexicografar",
    "lexicografávamo": "lexicografar",
    "lexicografávamos": "lexicografar",
    "lexicografávei": "lexicografar",
    "lexicografáveis": "lexicografável",
    "lexicográfica": "lexicográfico",
    "lexicográficas": "lexicográfico",
    "lexicográficos": "lexicográfico",
    "lexicologias": "lexicologia",
    "lexicológica": "lexicológico",
    "lexicológicas": "lexicológico",
    "lexicológicos": "lexicológico",
    "lexicógrafa": "lexicógrafo",
    "lexicógrafas": "lexicógrafo",
    "lexicógrafos": "lexicógrafo",
    "lexicóloga": "lexicólogo",
    "lexicólogas": "lexicólogo",
    "lexicólogos": "lexicólogo",
    "lexiologias": "lexiologia",
    "lexiológica": "lexiológico",
    "lexiológicas": "lexiológico",
    "lexiológicos": "lexiológico",
    "lezirona": "lezirão",
    "lezironas": "lezirão",
    "lezirões": "lezirão",
    "lezírias": "lezíria",
    "leãozinho": "leão",
    "leãozito": "leão",
    "leãzetes": "leãzete",
    "leónica": "leónico",
    "leónicas": "leónico",
    "leónicos": "leónico",
    "leôncula": "leônculo",
    "leônculas": "leônculo",
    "leônculos": "leônculo",
    "leões": "leão",
    "leõezinhos": "leão",
    "leõezitos": "leão",
    "lhamas": "lhama",
    "lhana": "lhano",
    "lhanas": "lhano",
    "lhanezas": "lhaneza",
    "lhanos": "lhano",
    "lhanuras": "lhanura",
    "lherzolitos": "lherzolito",
    "lhes": "lhe",
    "li": "ler",
    "lia": "liar",
    "liada": "liar",
    "liadas": "liar",
    "liado": "liar",
    "liadoiros": "liadoiro",
    "liados": "liar",
    "liadouros": "liadouro",
    "liai": "liar",
    "liais": "liar",
    "liam": "liar",
    "liambas": "liamba",
    "liames": "liame",
    "liamo": "liar",
    "liamos": "liar",
    "lianas": "liana",
    "liando": "liar",
    "lianças": "liança",
    "liara": "liar",
    "liaram": "liar",
    "liaras": "liar",
    "liarde": "liar",
    "liardes": "liar",
    "liare": "liar",
    "liarei": "liar",
    "liareis": "liar",
    "liarem": "liar",
    "liaremos": "liar",
    "liares": "liar",
    "liaria": "liar",
    "liariam": "liar",
    "liarias": "liar",
    "liarmo": "liar",
    "liarmos": "liar",
    "liará": "liar",
    "liarás": "liar",
    "liarão": "liar",
    "liaríamos": "liar",
    "liaríeis": "liar",
    "lias": "liar",
    "liases": "lias",
    "liasse": "liar",
    "liassem": "liar",
    "liasses": "liar",
    "liaste": "liar",
    "liastes": "liar",
    "liava": "liar",
    "liavam": "liar",
    "liavas": "liar",
    "liaças": "liaça",
    "liações": "liação",
    "liba": "libar",
    "libada": "libar",
    "libadas": "libar",
    "libado": "libar",
    "libados": "libar",
    "libai": "libar",
    "libais": "libar",
    "libam": "libar",
    "libamentos": "libamento",
    "libames": "libame",
    "libamo": "libar",
    "libamos": "libar",
    "libando": "libar",
    "libanesa": "libanês",
    "libanesas": "libanês",
    "libaneses": "libanês",
    "libanomancias": "libanomancia",
    "libanomantes": "libanomante",
    "libara": "libar",
    "libaram": "libar",
    "libaras": "libar",
    "libardes": "libar",
    "libarei": "libar",
    "libareis": "libar",
    "libarem": "libar",
    "libaremos": "libar",
    "libares": "libar",
    "libaria": "libar",
    "libariam": "libar",
    "libarias": "libar",
    "libarmo": "libar",
    "libarmos": "libar",
    "libará": "libar",
    "libarás": "libar",
    "libarão": "libar",
    "libaríamos": "libar",
    "libaríeis": "libar",
    "libas": "libar",
    "libasse": "libar",
    "libassem": "libar",
    "libasses": "libar",
    "libaste": "libar",
    "libastes": "libar",
    "libatas": "libata",
    "libatórios": "libatório",
    "libava": "libar",
    "libavam": "libar",
    "libavas": "libar",
    "libações": "libação",
    "libe": "libar",
    "libei": "libar",
    "libeis": "libar",
    "libelinhas": "libelinha",
    "libelistas": "libelista",
    "libelos": "libelo",
    "libelulídeos": "libelulídeo",
    "libelática": "libelático",
    "libeláticas": "libelático",
    "libeláticos": "libelático",
    "libelúlidas": "libelúlida",
    "libem": "libar",
    "libemo": "libar",
    "libemos": "libar",
    "libentes": "libente",
    "libentíssima": "libente",
    "libentíssimas": "libente",
    "libentíssimo": "libente",
    "libentíssimos": "libente",
    "libera": "liberar",
    "liberada": "liberar",
    "liberadas": "liberar",
    "liberado": "liberar",
    "liberados": "liberar",
    "liberai": "liberar",
    "liberais": "liberar",
    "liberaizinhas": "liberal",
    "liberaizinhos": "liberal",
    "liberaizitas": "liberal",
    "liberaizitos": "liberal",
    "liberalidades": "liberalidade",
    "liberalismos": "liberalismo",
    "liberalistas": "liberalista",
    "liberaliza": "liberalizar",
    "liberalizada": "liberalizar",
    "liberalizadas": "liberalizar",
    "liberalizado": "liberalizar",
    "liberalizadora": "liberalizador",
    "liberalizadoras": "liberalizador",
    "liberalizadores": "liberalizador",
    "liberalizados": "liberalizar",
    "liberalizai": "liberalizar",
    "liberalizais": "liberalizar",
    "liberalizam": "liberalizar",
    "liberalizamo": "liberalizar",
    "liberalizamos": "liberalizar",
    "liberalizando": "liberalizar",
    "liberalizantes": "liberalizante",
    "liberalizara": "liberalizar",
    "liberalizaram": "liberalizar",
    "liberalizaras": "liberalizar",
    "liberalizarde": "liberalizar",
    "liberalizardes": "liberalizar",
    "liberalizare": "liberalizar",
    "liberalizarei": "liberalizar",
    "liberalizareis": "liberalizar",
    "liberalizarem": "liberalizar",
    "liberalizaremos": "liberalizar",
    "liberalizares": "liberalizar",
    "liberalizaria": "liberalizar",
    "liberalizariam": "liberalizar",
    "liberalizarias": "liberalizar",
    "liberalizarmo": "liberalizar",
    "liberalizarmos": "liberalizar",
    "liberalizará": "liberalizar",
    "liberalizarás": "liberalizar",
    "liberalizarão": "liberalizar",
    "liberalizaríamos": "liberalizar",
    "liberalizaríeis": "liberalizar",
    "liberalizas": "liberalizar",
    "liberalizasse": "liberalizar",
    "liberalizassem": "liberalizar",
    "liberalizasses": "liberalizar",
    "liberalizaste": "liberalizar",
    "liberalizastes": "liberalizar",
    "liberalizava": "liberalizar",
    "liberalizavam": "liberalizar",
    "liberalizavas": "liberalizar",
    "liberalizações": "liberalização",
    "liberalize": "liberalizar",
    "liberalizei": "liberalizar",
    "liberalizeis": "liberalizar",
    "liberalizem": "liberalizar",
    "liberalizemo": "liberalizar",
    "liberalizemos": "liberalizar",
    "liberalizes": "liberalizar",
    "liberalizo": "liberalizar",
    "liberalizou": "liberalizar",
    "liberalizá": "liberalizar",
    "liberalizámo": "liberalizar",
    "liberalizámos": "liberalizar",
    "liberalizáramo": "liberalizar",
    "liberalizáramos": "liberalizar",
    "liberalizárei": "liberalizar",
    "liberalizáreis": "liberalizar",
    "liberalizásseis": "liberalizar",
    "liberalizássemos": "liberalizar",
    "liberalizávamo": "liberalizar",
    "liberalizávamos": "liberalizar",
    "liberalizávei": "liberalizar",
    "liberalizáveis": "liberalizável",
    "liberalona": "liberalão",
    "liberalonas": "liberalão",
    "liberalzinha": "liberal",
    "liberalzinho": "liberal",
    "liberalzita": "liberal",
    "liberalzito": "liberal",
    "liberalão": "liberal",
    "liberalões": "liberalão",
    "liberam": "liberar",
    "liberamo": "liberar",
    "liberamos": "liberar",
    "liberanda": "liberando",
    "liberandas": "liberando",
    "liberando": "liberar",
    "liberandos": "liberando",
    "liberara": "liberar",
    "liberaram": "liberar",
    "liberaras": "liberar",
    "liberarde": "liberar",
    "liberardes": "liberar",
    "liberare": "liberar",
    "liberarei": "liberar",
    "liberareis": "liberar",
    "liberarem": "liberar",
    "liberaremos": "liberar",
    "liberares": "liberar",
    "liberaria": "liberar",
    "liberariam": "liberar",
    "liberarias": "liberar",
    "liberarmo": "liberar",
    "liberarmos": "liberar",
    "liberará": "liberar",
    "liberarás": "liberar",
    "liberarão": "liberar",
    "liberaríamos": "liberar",
    "liberaríeis": "liberar",
    "liberas": "liberar",
    "liberasse": "liberar",
    "liberassem": "liberar",
    "liberasses": "liberar",
    "liberaste": "liberar",
    "liberastes": "liberar",
    "liberativa": "liberativo",
    "liberativas": "liberativo",
    "liberativos": "liberativo",
    "liberatória": "liberatório",
    "liberatórias": "liberatório",
    "liberatórios": "liberatório",
    "liberava": "liberar",
    "liberavam": "liberar",
    "liberavas": "liberar",
    "liberações": "liberação",
    "liberdades": "liberdade",
    "libere": "liberar",
    "liberei": "liberar",
    "libereis": "liberar",
    "liberem": "liberar",
    "liberemo": "liberar",
    "liberemos": "liberar",
    "liberes": "liberar",
    "liberiana": "liberiano",
    "liberianas": "liberiano",
    "liberianos": "liberiano",
    "libero": "liberar",
    "liberou": "liberar",
    "liberta": "liberto",
    "libertada": "libertar",
    "libertadas": "libertar",
    "libertado": "libertar",
    "libertadora": "libertador",
    "libertadoras": "libertador",
    "libertadores": "libertador",
    "libertados": "libertar",
    "libertai": "libertar",
    "libertais": "libertar",
    "libertam": "libertar",
    "libertamo": "libertar",
    "libertamos": "libertar",
    "libertando": "libertar",
    "libertara": "libertar",
    "libertaram": "libertar",
    "libertaras": "libertar",
    "libertarde": "libertar",
    "libertardes": "libertar",
    "libertare": "libertar",
    "libertarei": "libertar",
    "libertareis": "libertar",
    "libertarem": "libertar",
    "libertaremos": "libertar",
    "libertares": "libertar",
    "libertaria": "libertar",
    "libertariam": "libertar",
    "libertarias": "libertar",
    "libertarmo": "libertar",
    "libertarmos": "libertar",
    "libertará": "libertar",
    "libertarás": "libertar",
    "libertarão": "libertar",
    "libertaríamos": "libertar",
    "libertaríeis": "libertar",
    "libertas": "liberto",
    "libertasse": "libertar",
    "libertassem": "libertar",
    "libertasses": "libertar",
    "libertaste": "libertar",
    "libertastes": "libertar",
    "libertava": "libertar",
    "libertavam": "libertar",
    "libertavas": "libertar",
    "libertações": "libertação",
    "liberte": "libertar",
    "libertei": "libertar",
    "liberteis": "libertar",
    "libertem": "libertar",
    "libertemo": "libertar",
    "libertemos": "libertar",
    "libertes": "libertar",
    "liberticidas": "liberticida",
    "liberticídios": "liberticídio",
    "libertina": "libertino",
    "libertinagens": "libertinagem",
    "libertinas": "libertino",
    "libertinos": "libertino",
    "libertistas": "libertista",
    "liberto": "libertar",
    "libertos": "liberto",
    "libertou": "libertar",
    "libertá": "libertar",
    "libertámo": "libertar",
    "libertámos": "libertar",
    "libertáramo": "libertar",
    "libertáramos": "libertar",
    "libertárei": "libertar",
    "libertáreis": "libertar",
    "libertária": "libertário",
    "libertárias": "libertário",
    "libertários": "libertário",
    "libertásseis": "libertar",
    "libertássemos": "libertar",
    "libertávamo": "libertar",
    "libertávamos": "libertar",
    "libertávei": "libertar",
    "libertáveis": "libertável",
    "liberá": "liberar",
    "liberámo": "liberar",
    "liberámos": "liberar",
    "liberáramo": "liberar",
    "liberáramos": "liberar",
    "liberárei": "liberar",
    "liberáreis": "liberar",
    "liberásseis": "liberar",
    "liberássemos": "liberar",
    "liberávamo": "liberar",
    "liberávamos": "liberar",
    "liberávei": "liberar",
    "liberáveis": "liberar",
    "libes": "libar",
    "libidinagens": "libidinagem",
    "libidinosa": "libidinoso",
    "libidinosas": "libidinoso",
    "libidinosidades": "libidinosidade",
    "libidinosos": "libidinoso",
    "libidos": "libido",
    "libitas": "libita",
    "libitinas": "libitina",
    "libo": "libar",
    "libongos": "libongo",
    "libou": "libar",
    "libra": "librar",
    "librada": "librar",
    "libradas": "librar",
    "librado": "librar",
    "librados": "librar",
    "librai": "librar",
    "librais": "librar",
    "libram": "librar",
    "librames": "librame",
    "libramo": "librar",
    "libramos": "librar",
    "librando": "librar",
    "librara": "librar",
    "libraram": "librar",
    "libraras": "librar",
    "librarde": "librar",
    "librardes": "librar",
    "librare": "librar",
    "librarei": "librar",
    "librareis": "librar",
    "librarem": "librar",
    "libraremos": "librar",
    "librares": "librar",
    "libraria": "librar",
    "librariam": "librar",
    "librarias": "librar",
    "librarmo": "librar",
    "librarmos": "librar",
    "librará": "librar",
    "librarás": "librar",
    "librarão": "librar",
    "libraríamos": "librar",
    "libraríeis": "librar",
    "libras": "librar",
    "librasse": "librar",
    "librassem": "librar",
    "librasses": "librar",
    "libraste": "librar",
    "librastes": "librar",
    "libratória": "libratório",
    "libratórias": "libratório",
    "libratórios": "libratório",
    "librava": "librar",
    "libravam": "librar",
    "libravas": "librar",
    "librações": "libração",
    "libre": "librar",
    "librei": "librar",
    "libreis": "librar",
    "librem": "librar",
    "libremo": "librar",
    "libremos": "librar",
    "libres": "librar",
    "libretistas": "libretista",
    "libretos": "libreto",
    "libriana": "libriano",
    "librianas": "libriano",
    "librianos": "libriano",
    "librina": "librinar",
    "librinada": "librinar",
    "librinadas": "librinar",
    "librinado": "librinar",
    "librinados": "librinar",
    "librinai": "librinar",
    "librinais": "librinar",
    "librinam": "librinar",
    "librinamo": "librinar",
    "librinamos": "librinar",
    "librinando": "librinar",
    "librinara": "librinar",
    "librinaram": "librinar",
    "librinaras": "librinar",
    "librinardes": "librinar",
    "librinarei": "librinar",
    "librinareis": "librinar",
    "librinarem": "librinar",
    "librinaremos": "librinar",
    "librinares": "librinar",
    "librinaria": "librinar",
    "librinariam": "librinar",
    "librinarias": "librinar",
    "librinarmo": "librinar",
    "librinarmos": "librinar",
    "librinará": "librinar",
    "librinarás": "librinar",
    "librinarão": "librinar",
    "librinaríamos": "librinar",
    "librinaríeis": "librinar",
    "librinas": "librinar",
    "librinasse": "librinar",
    "librinassem": "librinar",
    "librinasses": "librinar",
    "librinaste": "librinar",
    "librinastes": "librinar",
    "librinava": "librinar",
    "librinavam": "librinar",
    "librinavas": "librinar",
    "librine": "librinar",
    "librinei": "librinar",
    "librineis": "librinar",
    "librinem": "librinar",
    "librinemo": "librinar",
    "librinemos": "librinar",
    "librines": "librinar",
    "librino": "librinar",
    "librinou": "librinar",
    "librinámo": "librinar",
    "librinámos": "librinar",
    "librináramo": "librinar",
    "librináramos": "librinar",
    "librináreis": "librinar",
    "librinásseis": "librinar",
    "librinássemos": "librinar",
    "librinávamo": "librinar",
    "librinávamos": "librinar",
    "librináveis": "librinar",
    "libro": "librar",
    "librou": "librar",
    "librá": "librar",
    "librámo": "librar",
    "librámos": "librar",
    "libráramo": "librar",
    "libráramos": "librar",
    "librárei": "librar",
    "libráreis": "librar",
    "librásseis": "librar",
    "librássemos": "librar",
    "librávamo": "librar",
    "librávamos": "librar",
    "librávei": "librar",
    "libráveis": "librar",
    "librés": "libré",
    "libunos": "libuno",
    "liburna": "liburno",
    "liburnas": "liburno",
    "liburnos": "liburno",
    "libámo": "libar",
    "libámos": "libar",
    "libáramo": "libar",
    "libáramos": "libar",
    "libáreis": "libar",
    "libásseis": "libar",
    "libássemos": "libar",
    "libávamo": "libar",
    "libávamos": "libar",
    "libáveis": "libar",
    "libélulas": "libélula",
    "libéria": "libério",
    "libérias": "libério",
    "libérios": "libério",
    "libérrima": "livre",
    "libérrimas": "livre",
    "libérrimo": "livre",
    "libérrimos": "livre",
    "libúrnias": "libúrnia",
    "libúrnicas": "libúrnica",
    "libúzias": "libúzia",
    "licantropa": "licantropo",
    "licantropas": "licantropo",
    "licantropias": "licantropia",
    "licantropos": "licantropo",
    "licanços": "licanço",
    "liceais": "liceal",
    "liceaizinhas": "liceal",
    "liceaizinhos": "liceal",
    "liceaizitas": "liceal",
    "liceaizitos": "liceal",
    "licealzinha": "liceal",
    "licealzinho": "liceal",
    "licealzita": "liceal",
    "licealzito": "liceal",
    "liceidades": "liceidade",
    "licencia": "licenciar",
    "licenciada": "licenciar",
    "licenciadas": "licenciar",
    "licenciado": "licenciar",
    "licenciados": "licenciar",
    "licenciai": "licenciar",
    "licenciais": "licenciar",
    "licenciam": "licenciar",
    "licenciamentos": "licenciamento",
    "licenciamo": "licenciar",
    "licenciamos": "licenciar",
    "licenciando": "licenciar",
    "licenciandos": "licenciando",
    "licenciara": "licenciar",
    "licenciaram": "licenciar",
    "licenciaras": "licenciar",
    "licenciarde": "licenciar",
    "licenciardes": "licenciar",
    "licenciare": "licenciar",
    "licenciarei": "licenciar",
    "licenciareis": "licenciar",
    "licenciarem": "licenciar",
    "licenciaremos": "licenciar",
    "licenciares": "licenciar",
    "licenciaria": "licenciar",
    "licenciariam": "licenciar",
    "licenciarias": "licenciar",
    "licenciarmo": "licenciar",
    "licenciarmos": "licenciar",
    "licenciará": "licenciar",
    "licenciarás": "licenciar",
    "licenciarão": "licenciar",
    "licenciaríamos": "licenciar",
    "licenciaríeis": "licenciar",
    "licencias": "licenciar",
    "licenciasse": "licenciar",
    "licenciassem": "licenciar",
    "licenciasses": "licenciar",
    "licenciaste": "licenciar",
    "licenciastes": "licenciar",
    "licenciaturas": "licenciatura",
    "licenciava": "licenciar",
    "licenciavam": "licenciar",
    "licenciavas": "licenciar",
    "licenciações": "licenciação",
    "licencie": "licenciar",
    "licenciei": "licenciar",
    "licencieis": "licenciar",
    "licenciem": "licenciar",
    "licenciemo": "licenciar",
    "licenciemos": "licenciar",
    "licencies": "licenciar",
    "licencio": "licenciar",
    "licenciosa": "licencioso",
    "licenciosas": "licencioso",
    "licenciosidades": "licenciosidade",
    "licenciosos": "licencioso",
    "licenciou": "licenciar",
    "licenciá": "licenciar",
    "licenciámo": "licenciar",
    "licenciámos": "licenciar",
    "licenciáramo": "licenciar",
    "licenciáramos": "licenciar",
    "licenciárei": "licenciar",
    "licenciáreis": "licenciar",
    "licenciásseis": "licenciar",
    "licenciássemos": "licenciar",
    "licenciávamo": "licenciar",
    "licenciávamos": "licenciar",
    "licenciávei": "licenciar",
    "licenciáveis": "licenciável",
    "licenças": "licença",
    "licenídeos": "licenídeo",
    "lices": "lice",
    "liceus": "liceu",
    "lichias": "lichia",
    "lichis": "lichi",
    "liciatórios": "liciatório",
    "licita": "licitar",
    "licitada": "licitar",
    "licitadas": "licitar",
    "licitado": "licitar",
    "licitadora": "licitador",
    "licitadoras": "licitador",
    "licitadores": "licitador",
    "licitados": "licitar",
    "licitai": "licitar",
    "licitais": "licitar",
    "licitam": "licitar",
    "licitamo": "licitar",
    "licitamos": "licitar",
    "licitando": "licitar",
    "licitantes": "licitante",
    "licitara": "licitar",
    "licitaram": "licitar",
    "licitaras": "licitar",
    "licitardes": "licitar",
    "licitarei": "licitar",
    "licitareis": "licitar",
    "licitarem": "licitar",
    "licitaremos": "licitar",
    "licitares": "licitar",
    "licitaria": "licitar",
    "licitariam": "licitar",
    "licitarias": "licitar",
    "licitarmo": "licitar",
    "licitarmos": "licitar",
    "licitará": "licitar",
    "licitarás": "licitar",
    "licitarão": "licitar",
    "licitaríamos": "licitar",
    "licitaríeis": "licitar",
    "licitas": "licitar",
    "licitasse": "licitar",
    "licitassem": "licitar",
    "licitasses": "licitar",
    "licitaste": "licitar",
    "licitastes": "licitar",
    "licitava": "licitar",
    "licitavam": "licitar",
    "licitavas": "licitar",
    "licitações": "licitação",
    "licite": "licitar",
    "licitei": "licitar",
    "liciteis": "licitar",
    "licitem": "licitar",
    "licitemo": "licitar",
    "licitemos": "licitar",
    "licites": "licitar",
    "licito": "licitar",
    "licitou": "licitar",
    "licitudes": "licitude",
    "licitámo": "licitar",
    "licitámos": "licitar",
    "licitáramo": "licitar",
    "licitáramos": "licitar",
    "licitáreis": "licitar",
    "licitásseis": "licitar",
    "licitássemos": "licitar",
    "licitávamo": "licitar",
    "licitávamos": "licitar",
    "licitáveis": "licitável",
    "licnomacias": "licnomacia",
    "licnomantes": "licnomante",
    "licnucos": "licnuco",
    "licnídeas": "licnídea",
    "licnóbia": "licnóbio",
    "licnóbias": "licnóbio",
    "licnóbios": "licnóbio",
    "licoperdáceas": "licoperdácea",
    "licopodiácea": "licopodiáceo",
    "licopodiáceas": "licopodiáceo",
    "licopodiáceos": "licopodiáceo",
    "licopódios": "licopódio",
    "licoreiras": "licoreira",
    "licoreiros": "licoreiro",
    "licores": "licor",
    "licorexias": "licorexia",
    "licoristas": "licorista",
    "licornes": "licorne",
    "licorosa": "licoroso",
    "licorosas": "licoroso",
    "licorosos": "licoroso",
    "licranços": "licranço",
    "licras": "licra",
    "lictores": "lictor",
    "licícias": "licícia",
    "licómetros": "licómetro",
    "licórnios": "licórnio",
    "lida": "lido",
    "lidada": "lidar",
    "lidadas": "lidar",
    "lidado": "lidar",
    "lidadora": "lidador",
    "lidadoras": "lidador",
    "lidadores": "lidador",
    "lidados": "lidar",
    "lidai": "lidar",
    "lidais": "lidar",
    "lidam": "lidar",
    "lidamo": "lidar",
    "lidamos": "lidar",
    "lidando": "lidar",
    "lidara": "lidar",
    "lidaram": "lidar",
    "lidaras": "lidar",
    "lidardes": "lidar",
    "lidarei": "lidar",
    "lidareis": "lidar",
    "lidarem": "lidar",
    "lidaremos": "lidar",
    "lidares": "lidar",
    "lidaria": "lidar",
    "lidariam": "lidar",
    "lidarias": "lidar",
    "lidarmo": "lidar",
    "lidarmos": "lidar",
    "lidará": "lidar",
    "lidarás": "lidar",
    "lidarão": "lidar",
    "lidaríamos": "lidar",
    "lidaríeis": "lidar",
    "lidas": "lido",
    "lidasse": "lidar",
    "lidassem": "lidar",
    "lidasses": "lidar",
    "lidaste": "lidar",
    "lidastes": "lidar",
    "lidava": "lidar",
    "lidavam": "lidar",
    "lidavas": "lidar",
    "lidações": "lidação",
    "lide": "lidar",
    "lidei": "lidar",
    "lideis": "lidar",
    "lidem": "lidar",
    "lidemo": "lidar",
    "lidemos": "lidar",
    "lidera": "liderar",
    "liderada": "liderar",
    "lideradas": "liderar",
    "liderado": "liderar",
    "liderados": "liderar",
    "liderai": "liderar",
    "liderais": "liderar",
    "lideram": "liderar",
    "lideramo": "liderar",
    "lideramos": "liderar",
    "liderando": "liderar",
    "lideranças": "liderança",
    "liderara": "liderar",
    "lideraram": "liderar",
    "lideraras": "liderar",
    "liderarde": "liderar",
    "liderardes": "liderar",
    "liderare": "liderar",
    "liderarei": "liderar",
    "liderareis": "liderar",
    "liderarem": "liderar",
    "lideraremos": "liderar",
    "liderares": "liderar",
    "lideraria": "liderar",
    "liderariam": "liderar",
    "liderarias": "liderar",
    "liderarmo": "liderar",
    "liderarmos": "liderar",
    "liderará": "liderar",
    "liderarás": "liderar",
    "liderarão": "liderar",
    "lideraríamos": "liderar",
    "lideraríeis": "liderar",
    "lideras": "liderar",
    "liderasse": "liderar",
    "liderassem": "liderar",
    "liderasses": "liderar",
    "lideraste": "liderar",
    "liderastes": "liderar",
    "liderava": "liderar",
    "lideravam": "liderar",
    "lideravas": "liderar",
    "lidere": "liderar",
    "liderei": "liderar",
    "lidereis": "liderar",
    "liderem": "liderar",
    "lideremo": "liderar",
    "lideremos": "liderar",
    "lideres": "liderar",
    "lidero": "liderar",
    "liderou": "liderar",
    "liderá": "liderar",
    "liderámo": "liderar",
    "liderámos": "liderar",
    "lideráramo": "liderar",
    "lideráramos": "liderar",
    "liderárei": "liderar",
    "lideráreis": "liderar",
    "liderásseis": "liderar",
    "liderássemos": "liderar",
    "liderávamo": "liderar",
    "liderávamos": "liderar",
    "liderávei": "liderar",
    "lideráveis": "liderar",
    "lides": "lide",
    "lidima": "lidimar",
    "lidimada": "lidimar",
    "lidimadas": "lidimar",
    "lidimado": "lidimar",
    "lidimados": "lidimar",
    "lidimai": "lidimar",
    "lidimais": "lidimar",
    "lidimam": "lidimar",
    "lidimamo": "lidimar",
    "lidimamos": "lidimar",
    "lidimando": "lidimar",
    "lidimara": "lidimar",
    "lidimaram": "lidimar",
    "lidimaras": "lidimar",
    "lidimarde": "lidimar",
    "lidimardes": "lidimar",
    "lidimare": "lidimar",
    "lidimarei": "lidimar",
    "lidimareis": "lidimar",
    "lidimarem": "lidimar",
    "lidimaremos": "lidimar",
    "lidimares": "lidimar",
    "lidimaria": "lidimar",
    "lidimariam": "lidimar",
    "lidimarias": "lidimar",
    "lidimarmo": "lidimar",
    "lidimarmos": "lidimar",
    "lidimará": "lidimar",
    "lidimarás": "lidimar",
    "lidimarão": "lidimar",
    "lidimaríamos": "lidimar",
    "lidimaríeis": "lidimar",
    "lidimas": "lidimar",
    "lidimasse": "lidimar",
    "lidimassem": "lidimar",
    "lidimasses": "lidimar",
    "lidimaste": "lidimar",
    "lidimastes": "lidimar",
    "lidimava": "lidimar",
    "lidimavam": "lidimar",
    "lidimavas": "lidimar",
    "lidime": "lidimar",
    "lidimei": "lidimar",
    "lidimeis": "lidimar",
    "lidimem": "lidimar",
    "lidimemo": "lidimar",
    "lidimemos": "lidimar",
    "lidimes": "lidimar",
    "lidimidades": "lidimidade",
    "lidimo": "lidimar",
    "lidimou": "lidimar",
    "lidimá": "lidimar",
    "lidimámo": "lidimar",
    "lidimámos": "lidimar",
    "lidimáramo": "lidimar",
    "lidimáramos": "lidimar",
    "lidimárei": "lidimar",
    "lidimáreis": "lidimar",
    "lidimásseis": "lidimar",
    "lidimássemos": "lidimar",
    "lidimávamo": "lidimar",
    "lidimávamos": "lidimar",
    "lidimávei": "lidimar",
    "lidimáveis": "lidimar",
    "lidites": "lidite",
    "lido": "lidar",
    "lidos": "lido",
    "lidou": "lidar",
    "lidámo": "lidar",
    "lidámos": "lidar",
    "lidáramo": "lidar",
    "lidáramos": "lidar",
    "lidáreis": "lidar",
    "lidásseis": "lidar",
    "lidássemos": "lidar",
    "lidávamo": "lidar",
    "lidávamos": "lidar",
    "lidáveis": "lidável",
    "lie": "liar",
    "liechtensteinienses": "liechtensteiniense",
    "lieds": "lied",
    "liei": "liar",
    "lieis": "liar",
    "liem": "liar",
    "liemo": "liar",
    "liemos": "liar",
    "lienais": "lienal",
    "lienites": "lienite",
    "lienosa": "lienoso",
    "lienosas": "lienoso",
    "lienosos": "lienoso",
    "lienterias": "lienteria",
    "lientérica": "lientérico",
    "lientéricas": "lientérico",
    "lientéricos": "lientérico",
    "liernes": "lierne",
    "lies": "liar",
    "lifos": "lifo",
    "liga": "ligar",
    "ligada": "ligar",
    "ligadas": "ligar",
    "ligado": "ligar",
    "ligados": "ligar",
    "ligaduras": "ligadura",
    "ligadíssima": "ligado",
    "ligadíssimas": "ligado",
    "ligadíssimo": "ligado",
    "ligadíssimos": "ligado",
    "ligai": "ligar",
    "ligais": "ligar",
    "ligam": "ligar",
    "ligamentos": "ligamento",
    "ligamentosa": "ligamentoso",
    "ligamentosas": "ligamentoso",
    "ligamentosos": "ligamentoso",
    "ligames": "ligame",
    "ligamo": "ligar",
    "ligamos": "ligar",
    "ligando": "ligar",
    "ligantes": "ligante",
    "ligara": "ligar",
    "ligaram": "ligar",
    "ligaras": "ligar",
    "ligarde": "ligar",
    "ligardes": "ligar",
    "ligare": "ligar",
    "ligarei": "ligar",
    "ligareis": "ligar",
    "ligarem": "ligar",
    "ligaremos": "ligar",
    "ligares": "ligar",
    "ligaria": "ligar",
    "ligariam": "ligar",
    "ligarias": "ligar",
    "ligarmo": "ligar",
    "ligarmos": "ligar",
    "ligará": "ligar",
    "ligarás": "ligar",
    "ligarão": "ligar",
    "ligaríamos": "ligar",
    "ligaríeis": "ligar",
    "ligas": "ligar",
    "ligasse": "ligar",
    "ligassem": "ligar",
    "ligasses": "ligar",
    "ligaste": "ligar",
    "ligastes": "ligar",
    "ligaturas": "ligatura",
    "ligava": "ligar",
    "ligavam": "ligar",
    "ligavas": "ligar",
    "ligações": "ligação",
    "ligeira": "ligeiro",
    "ligeiras": "ligeiro",
    "ligeirezas": "ligeireza",
    "ligeirices": "ligeirice",
    "ligeiros": "ligeiro",
    "ligeirs": "ligeir",
    "ligeiríssima": "ligeiro",
    "ligeiríssimas": "ligeiro",
    "ligeiríssimo": "ligeiro",
    "ligeiríssimos": "ligeiro",
    "lignifica": "lignificar",
    "lignificada": "lignificar",
    "lignificadas": "lignificar",
    "lignificado": "lignificar",
    "lignificados": "lignificar",
    "lignificai": "lignificar",
    "lignificais": "lignificar",
    "lignificam": "lignificar",
    "lignificamo": "lignificar",
    "lignificamos": "lignificar",
    "lignificando": "lignificar",
    "lignificara": "lignificar",
    "lignificaram": "lignificar",
    "lignificaras": "lignificar",
    "lignificarde": "lignificar",
    "lignificardes": "lignificar",
    "lignificare": "lignificar",
    "lignificarei": "lignificar",
    "lignificareis": "lignificar",
    "lignificarem": "lignificar",
    "lignificaremos": "lignificar",
    "lignificares": "lignificar",
    "lignificaria": "lignificar",
    "lignificariam": "lignificar",
    "lignificarias": "lignificar",
    "lignificarmo": "lignificar",
    "lignificarmos": "lignificar",
    "lignificará": "lignificar",
    "lignificarás": "lignificar",
    "lignificarão": "lignificar",
    "lignificaríamos": "lignificar",
    "lignificaríeis": "lignificar",
    "lignificas": "lignificar",
    "lignificasse": "lignificar",
    "lignificassem": "lignificar",
    "lignificasses": "lignificar",
    "lignificaste": "lignificar",
    "lignificastes": "lignificar",
    "lignificava": "lignificar",
    "lignificavam": "lignificar",
    "lignificavas": "lignificar",
    "lignificações": "lignificação",
    "lignifico": "lignificar",
    "lignificou": "lignificar",
    "lignificá": "lignificar",
    "lignificámo": "lignificar",
    "lignificámos": "lignificar",
    "lignificáramo": "lignificar",
    "lignificáramos": "lignificar",
    "lignificárei": "lignificar",
    "lignificáreis": "lignificar",
    "lignificásseis": "lignificar",
    "lignificássemos": "lignificar",
    "lignificávamo": "lignificar",
    "lignificávamos": "lignificar",
    "lignificávei": "lignificar",
    "lignificáveis": "lignificável",
    "lignifique": "lignificar",
    "lignifiquei": "lignificar",
    "lignifiqueis": "lignificar",
    "lignifiquem": "lignificar",
    "lignifiquemo": "lignificar",
    "lignifiquemos": "lignificar",
    "lignifiques": "lignificar",
    "ligniformes": "ligniforme",
    "ligninas": "lignina",
    "lignites": "lignite",
    "lignívora": "lignívoro",
    "lignívoras": "lignívoro",
    "lignívoros": "lignívoro",
    "ligo": "ligar",
    "ligou": "ligar",
    "ligroínas": "ligroína",
    "ligue": "ligar",
    "liguei": "ligar",
    "ligueirões": "ligueirão",
    "ligueis": "ligar",
    "liguem": "ligar",
    "liguemo": "ligar",
    "liguemos": "ligar",
    "ligues": "ligar",
    "ligulada": "ligulado",
    "liguladas": "ligulado",
    "ligulados": "ligulado",
    "liguliflora": "ligulifloro",
    "ligulifloras": "ligulifloro",
    "ligulifloros": "ligulifloro",
    "liguliformes": "liguliforme",
    "ligulosa": "liguloso",
    "ligulosas": "liguloso",
    "liguloses": "ligulose",
    "ligulosos": "liguloso",
    "ligulácea": "liguláceo",
    "liguláceas": "liguláceo",
    "liguláceos": "liguláceo",
    "ligulífera": "ligulífero",
    "ligulíferas": "ligulífero",
    "ligulíferos": "ligulífero",
    "liguria": "ligurio",
    "ligurias": "ligurio",
    "ligurios": "ligurio",
    "ligustrinas": "ligustrina",
    "ligustros": "ligustro",
    "ligá": "ligar",
    "ligámo": "ligar",
    "ligámos": "ligar",
    "ligáramo": "ligar",
    "ligáramos": "ligar",
    "ligárei": "ligar",
    "ligáreis": "ligar",
    "ligásseis": "ligar",
    "ligássemos": "ligar",
    "ligávamo": "ligar",
    "ligávamos": "ligar",
    "ligávei": "ligar",
    "ligáveis": "ligável",
    "ligâmens": "ligâmen",
    "ligúrica": "ligúrico",
    "ligúricas": "ligúrico",
    "ligúricos": "ligúrico",
    "lilacínea": "lilacíneo",
    "lilacíneas": "lilacíneo",
    "lilacíneos": "lilacíneo",
    "lilas": "lila",
    "lilaseiros": "lilaseiro",
    "lilases": "lilás",
    "liliais": "lilial",
    "liliflora": "lilifloro",
    "lilifloras": "lilifloro",
    "lilifloros": "lilifloro",
    "liliputiana": "liliputiano",
    "liliputianas": "liliputiano",
    "liliputianos": "liliputiano",
    "liliácea": "liliáceo",
    "liliáceas": "liliáceo",
    "liliáceos": "liliáceo",
    "lilácea": "liláceo",
    "liláceas": "liláceo",
    "liláceos": "liláceo",
    "lilás": "lilá",
    "lima": "limar",
    "limacídeos": "limacídeo",
    "limada": "limar",
    "limadas": "limar",
    "limado": "limar",
    "limadora": "limador",
    "limadoras": "limador",
    "limadores": "limador",
    "limados": "limar",
    "limaduras": "limadura",
    "limagens": "limagem",
    "limai": "limar",
    "limais": "limar",
    "limalhas": "limalha",
    "limam": "limar",
    "limamo": "limar",
    "limamos": "limar",
    "limando": "limar",
    "limara": "limar",
    "limaram": "limar",
    "limaras": "limar",
    "limarde": "limar",
    "limardes": "limar",
    "limare": "limar",
    "limarei": "limar",
    "limareis": "limar",
    "limarem": "limar",
    "limaremos": "limar",
    "limarenses": "limarense",
    "limares": "limar",
    "limaria": "limar",
    "limariam": "limar",
    "limarias": "limar",
    "limarmo": "limar",
    "limarmos": "limar",
    "limará": "limar",
    "limarás": "limar",
    "limarão": "limar",
    "limaríamos": "limar",
    "limaríeis": "limar",
    "limas": "limar",
    "limasse": "limar",
    "limassem": "limar",
    "limasses": "limar",
    "limaste": "limar",
    "limastes": "limar",
    "limatões": "limatão",
    "limava": "limar",
    "limavam": "limar",
    "limavas": "limar",
    "limbos": "limbo",
    "limburgites": "limburgite",
    "limbífera": "limbífero",
    "limbíferas": "limbífero",
    "limbíferos": "limbífero",
    "lime": "limar",
    "limei": "limar",
    "limeiras": "limeira",
    "limeis": "limar",
    "limem": "limar",
    "limemo": "limar",
    "limemos": "limar",
    "limes": "limar",
    "limiana": "limiano",
    "limianas": "limiano",
    "limianos": "limiano",
    "limiares": "limiar",
    "limiformes": "limiforme",
    "liminares": "liminar",
    "limita": "limitar",
    "limitada": "limitar",
    "limitadas": "limitar",
    "limitado": "limitar",
    "limitadora": "limitador",
    "limitadoras": "limitador",
    "limitadores": "limitador",
    "limitadors": "limitador",
    "limitados": "limitar",
    "limitadíssima": "limitado",
    "limitadíssimas": "limitado",
    "limitadíssimo": "limitado",
    "limitadíssimos": "limitado",
    "limitai": "limitar",
    "limitais": "limitar",
    "limitam": "limitar",
    "limitamo": "limitar",
    "limitamos": "limitar",
    "limitando": "limitar",
    "limitara": "limitar",
    "limitaram": "limitar",
    "limitaras": "limitar",
    "limitarde": "limitar",
    "limitardes": "limitar",
    "limitare": "limitar",
    "limitarei": "limitar",
    "limitareis": "limitar",
    "limitarem": "limitar",
    "limitaremos": "limitar",
    "limitares": "limitar",
    "limitaria": "limitar",
    "limitariam": "limitar",
    "limitarias": "limitar",
    "limitarmo": "limitar",
    "limitarmos": "limitar",
    "limitará": "limitar",
    "limitarás": "limitar",
    "limitarão": "limitar",
    "limitaríamos": "limitar",
    "limitaríeis": "limitar",
    "limitas": "limitar",
    "limitasse": "limitar",
    "limitassem": "limitar",
    "limitasses": "limitar",
    "limitaste": "limitar",
    "limitastes": "limitar",
    "limitativa": "limitativo",
    "limitativas": "limitativo",
    "limitativos": "limitativo",
    "limitava": "limitar",
    "limitavam": "limitar",
    "limitavas": "limitar",
    "limitações": "limitação",
    "limite": "limitar",
    "limitei": "limitar",
    "limiteis": "limitar",
    "limitem": "limitar",
    "limitemo": "limitar",
    "limitemos": "limitar",
    "limites": "limite",
    "limito": "limitar",
    "limitou": "limitar",
    "limitá": "limitar",
    "limitámo": "limitar",
    "limitámos": "limitar",
    "limitáramo": "limitar",
    "limitáramos": "limitar",
    "limitárei": "limitar",
    "limitáreis": "limitar",
    "limitásseis": "limitar",
    "limitássemos": "limitar",
    "limitávamo": "limitar",
    "limitávamos": "limitar",
    "limitávei": "limitar",
    "limitáveis": "limitável",
    "limnantos": "limnanto",
    "limnantáceas": "limnantácea",
    "limnimetrias": "limnimetria",
    "limnites": "limnite",
    "limnografias": "limnografia",
    "limnologias": "limnologia",
    "limnologistas": "limnologista",
    "limnológica": "limnológico",
    "limnológicas": "limnológico",
    "limnológicos": "limnológico",
    "limnomedusas": "limnomedusa",
    "limnímetros": "limnímetro",
    "limnófila": "limnófilo",
    "limnófilas": "limnófilo",
    "limnófilos": "limnófilo",
    "limnóloga": "limnólogo",
    "limnólogas": "limnólogo",
    "limnólogos": "limnólogo",
    "limnómetros": "limnómetro",
    "limo": "limar",
    "limoais": "limoal",
    "limoeiros": "limoeiro",
    "limonadas": "limonada",
    "limonadeira": "limonadeiro",
    "limonadeiras": "limonadeiro",
    "limonadeiros": "limonadeiro",
    "limonetes": "limonete",
    "limonites": "limonite",
    "limos": "limo",
    "limosa": "limoso",
    "limosas": "limoso",
    "limosidades": "limosidade",
    "limosos": "limoso",
    "limou": "limar",
    "limousines": "limousine",
    "limpa": "limpo",
    "limpada": "limpar",
    "limpadas": "limpar",
    "limpadeiras": "limpadeira",
    "limpadelas": "limpadela",
    "limpado": "limpar",
    "limpadora": "limpador",
    "limpadoras": "limpador",
    "limpadores": "limpador",
    "limpados": "limpar",
    "limpaduras": "limpadura",
    "limpai": "limpar",
    "limpais": "limpar",
    "limpalhos": "limpalho",
    "limpam": "limpar",
    "limpamentos": "limpamento",
    "limpamo": "limpar",
    "limpamos": "limpar",
    "limpando": "limpar",
    "limpara": "limpar",
    "limparam": "limpar",
    "limparas": "limpar",
    "limparde": "limpar",
    "limpardes": "limpar",
    "limpare": "limpar",
    "limparei": "limpar",
    "limpareis": "limpar",
    "limparem": "limpar",
    "limparemos": "limpar",
    "limpares": "limpar",
    "limparia": "limpar",
    "limpariam": "limpar",
    "limparias": "limpar",
    "limparmo": "limpar",
    "limparmos": "limpar",
    "limpará": "limpar",
    "limparás": "limpar",
    "limparão": "limpar",
    "limparíamos": "limpar",
    "limparíeis": "limpar",
    "limpas": "limpo",
    "limpasse": "limpar",
    "limpassem": "limpar",
    "limpasses": "limpar",
    "limpaste": "limpar",
    "limpastes": "limpar",
    "limpava": "limpar",
    "limpavam": "limpar",
    "limpavas": "limpar",
    "limpazinha": "limpo",
    "limpazinhas": "limpo",
    "limpazita": "limpo",
    "limpazitas": "limpo",
    "limpações": "limpação",
    "limpe": "limpar",
    "limpei": "limpar",
    "limpeis": "limpar",
    "limpem": "limpar",
    "limpemo": "limpar",
    "limpemos": "limpar",
    "limpes": "limpar",
    "limpezas": "limpeza",
    "limpidezes": "limpidez",
    "limpidíssima": "límpido",
    "limpidíssimas": "límpido",
    "limpidíssimo": "límpido",
    "limpidíssimos": "límpido",
    "limpinha": "limpo",
    "limpinhas": "limpo",
    "limpinho": "limpo",
    "limpinhos": "limpo",
    "limpita": "limpo",
    "limpitas": "limpo",
    "limpito": "limpo",
    "limpitos": "limpo",
    "limpo": "limpar",
    "limpos": "limpo",
    "limposa": "limposo",
    "limposas": "limposo",
    "limposos": "limposo",
    "limpou": "limpar",
    "limpozinho": "limpo",
    "limpozinhos": "limpo",
    "limpozito": "limpo",
    "limpozitos": "limpo",
    "limpá": "limpar",
    "limpámo": "limpar",
    "limpámos": "limpar",
    "limpáramo": "limpar",
    "limpáramos": "limpar",
    "limpárei": "limpar",
    "limpáreis": "limpar",
    "limpásseis": "limpar",
    "limpássemos": "limpar",
    "limpávamo": "limpar",
    "limpávamos": "limpar",
    "limpávei": "limpar",
    "limpáveis": "limpável",
    "limpíssima": "limpo",
    "limpíssimas": "limpo",
    "limpíssimo": "limpo",
    "limpíssimos": "limpo",
    "limusina": "limusino",
    "limusinas": "limusino",
    "limusines": "limusine",
    "limusinos": "limusino",
    "limá": "limar",
    "limácidas": "limácida",
    "limámo": "limar",
    "limámos": "limar",
    "limáramo": "limar",
    "limáramos": "limar",
    "limárei": "limar",
    "limáreis": "limar",
    "limásseis": "limar",
    "limássemos": "limar",
    "limávamo": "limar",
    "limávamos": "limar",
    "limávei": "limar",
    "limáveis": "limável",
    "limícolas": "limícola",
    "limítrofes": "limítrofe",
    "limónios": "limónio",
    "limões": "limão",
    "lina": "lenir",
    "linais": "lenir",
    "linam": "lenir",
    "linamo": "lenir",
    "linamos": "lenir",
    "linas": "lenir",
    "linces": "lince",
    "lincha": "linchar",
    "linchada": "linchar",
    "linchadas": "linchar",
    "linchado": "linchar",
    "linchadora": "linchador",
    "linchadoras": "linchador",
    "linchadores": "linchador",
    "linchados": "linchar",
    "linchagens": "linchagem",
    "linchai": "linchar",
    "linchais": "linchar",
    "lincham": "linchar",
    "linchamentos": "linchamento",
    "linchamo": "linchar",
    "linchamos": "linchar",
    "linchando": "linchar",
    "linchara": "linchar",
    "lincharam": "linchar",
    "lincharas": "linchar",
    "lincharde": "linchar",
    "linchardes": "linchar",
    "linchare": "linchar",
    "lincharei": "linchar",
    "linchareis": "linchar",
    "lincharem": "linchar",
    "lincharemos": "linchar",
    "linchares": "linchar",
    "lincharia": "linchar",
    "linchariam": "linchar",
    "lincharias": "linchar",
    "lincharmo": "linchar",
    "lincharmos": "linchar",
    "linchará": "linchar",
    "lincharás": "linchar",
    "lincharão": "linchar",
    "lincharíamos": "linchar",
    "lincharíeis": "linchar",
    "linchas": "linchar",
    "linchasse": "linchar",
    "linchassem": "linchar",
    "linchasses": "linchar",
    "linchaste": "linchar",
    "linchastes": "linchar",
    "linchava": "linchar",
    "linchavam": "linchar",
    "linchavas": "linchar",
    "linche": "linchar",
    "linchei": "linchar",
    "lincheis": "linchar",
    "linchem": "linchar",
    "linchemo": "linchar",
    "linchemos": "linchar",
    "linches": "linchar",
    "lincho": "linchar",
    "linchou": "linchar",
    "linchá": "linchar",
    "linchámo": "linchar",
    "linchámos": "linchar",
    "lincháramo": "linchar",
    "lincháramos": "linchar",
    "linchárei": "linchar",
    "lincháreis": "linchar",
    "linchásseis": "linchar",
    "linchássemos": "linchar",
    "linchávamo": "linchar",
    "linchávamos": "linchar",
    "linchávei": "linchar",
    "lincháveis": "linchável",
    "linda": "lindo",
    "lindada": "lindar",
    "lindadas": "lindar",
    "lindado": "lindar",
    "lindados": "lindar",
    "lindai": "lindar",
    "lindais": "lindar",
    "lindam": "lindar",
    "lindamo": "lindar",
    "lindamos": "lindar",
    "lindando": "lindar",
    "lindara": "lindar",
    "lindaram": "lindar",
    "lindaras": "lindar",
    "lindarde": "lindar",
    "lindardes": "lindar",
    "lindare": "lindar",
    "lindarei": "lindar",
    "lindareis": "lindar",
    "lindarem": "lindar",
    "lindaremos": "lindar",
    "lindares": "lindar",
    "lindaria": "lindar",
    "lindariam": "lindar",
    "lindarias": "lindar",
    "lindarmo": "lindar",
    "lindarmos": "lindar",
    "lindará": "lindar",
    "lindarás": "lindar",
    "lindarão": "lindar",
    "lindaríamos": "lindar",
    "lindaríeis": "lindar",
    "lindas": "lindo",
    "lindasse": "lindar",
    "lindassem": "lindar",
    "lindasses": "lindar",
    "lindaste": "lindar",
    "lindastes": "lindar",
    "lindava": "lindar",
    "lindavam": "lindar",
    "lindavas": "lindar",
    "linde": "lindar",
    "lindei": "lindar",
    "lindeira": "lindeiro",
    "lindeiras": "lindeiro",
    "lindeiros": "lindeiro",
    "lindeis": "lindar",
    "lindem": "lindar",
    "lindemo": "lindar",
    "lindemos": "lindar",
    "lindes": "linde",
    "lindezas": "lindeza",
    "lindo": "lindar",
    "lindos": "lindo",
    "lindotes": "lindote",
    "lindou": "lindar",
    "lindá": "lindar",
    "lindámo": "lindar",
    "lindámos": "lindar",
    "lindáramo": "lindar",
    "lindáramos": "lindar",
    "lindárei": "lindar",
    "lindáreis": "lindar",
    "lindásseis": "lindar",
    "lindássemos": "lindar",
    "lindávamo": "lindar",
    "lindávamos": "lindar",
    "lindávei": "lindar",
    "lindáveis": "lindar",
    "lindíssima": "lindo",
    "lindíssimas": "lindo",
    "lindíssimo": "lindo",
    "lindíssimos": "lindo",
    "line": "lenir",
    "lineais": "lineal",
    "lineamentos": "lineamento",
    "lineana": "lineano",
    "lineanas": "lineano",
    "lineanos": "lineano",
    "lineares": "linear",
    "linearidades": "linearidade",
    "lineações": "lineação",
    "linem": "lenir",
    "lineolares": "lineolar",
    "lines": "lenir",
    "linfa": "linfar",
    "linfada": "linfar",
    "linfadas": "linfar",
    "linfado": "linfar",
    "linfados": "linfar",
    "linfai": "linfar",
    "linfais": "linfar",
    "linfam": "linfar",
    "linfamo": "linfar",
    "linfamos": "linfar",
    "linfando": "linfar",
    "linfangites": "linfangite",
    "linfara": "linfar",
    "linfaram": "linfar",
    "linfaras": "linfar",
    "linfarde": "linfar",
    "linfardes": "linfar",
    "linfare": "linfar",
    "linfarei": "linfar",
    "linfareis": "linfar",
    "linfarem": "linfar",
    "linfaremos": "linfar",
    "linfares": "linfar",
    "linfaria": "linfar",
    "linfariam": "linfar",
    "linfarias": "linfar",
    "linfarmo": "linfar",
    "linfarmos": "linfar",
    "linfará": "linfar",
    "linfarás": "linfar",
    "linfarão": "linfar",
    "linfaríamos": "linfar",
    "linfaríeis": "linfar",
    "linfas": "linfar",
    "linfasse": "linfar",
    "linfassem": "linfar",
    "linfasses": "linfar",
    "linfaste": "linfar",
    "linfastes": "linfar",
    "linfatismos": "linfatismo",
    "linfava": "linfar",
    "linfavam": "linfar",
    "linfavas": "linfar",
    "linfe": "linfar",
    "linfei": "linfar",
    "linfeis": "linfar",
    "linfem": "linfar",
    "linfemo": "linfar",
    "linfemos": "linfar",
    "linfes": "linfar",
    "linfo": "linfar",
    "linfoblástica": "linfoblástico",
    "linfoblásticas": "linfoblástico",
    "linfoblásticos": "linfoblástico",
    "linfocitoses": "linfocitose",
    "linfogéneses": "linfogénese",
    "linfomas": "linfoma",
    "linfopatias": "linfopatia",
    "linfopoética": "linfopoético",
    "linfopoéticas": "linfopoético",
    "linfopoéticos": "linfopoético",
    "linfoses": "linfose",
    "linfotrófica": "linfotrófico",
    "linfotróficas": "linfotrófico",
    "linfotróficos": "linfotrófico",
    "linfou": "linfar",
    "linfá": "linfar",
    "linfámo": "linfar",
    "linfámos": "linfar",
    "linfáramo": "linfar",
    "linfáramos": "linfar",
    "linfárei": "linfar",
    "linfáreis": "linfar",
    "linfásseis": "linfar",
    "linfássemos": "linfar",
    "linfática": "linfático",
    "linfáticas": "linfático",
    "linfáticos": "linfático",
    "linfávamo": "linfar",
    "linfávamos": "linfar",
    "linfávei": "linfar",
    "linfáveis": "linfar",
    "linfócitos": "linfócito",
    "linga": "lingar",
    "lingada": "lingar",
    "lingadas": "lingar",
    "lingado": "lingar",
    "lingados": "lingar",
    "lingai": "lingar",
    "lingais": "lingar",
    "lingam": "lingar",
    "lingamo": "lingar",
    "lingamos": "lingar",
    "lingando": "lingar",
    "lingara": "lingar",
    "lingaram": "lingar",
    "lingaras": "lingar",
    "lingarde": "lingar",
    "lingardes": "lingar",
    "lingare": "lingar",
    "lingarei": "lingar",
    "lingareis": "lingar",
    "lingarem": "lingar",
    "lingaremos": "lingar",
    "lingares": "lingar",
    "lingaria": "lingar",
    "lingariam": "lingar",
    "lingarias": "lingar",
    "lingarmo": "lingar",
    "lingarmos": "lingar",
    "lingará": "lingar",
    "lingarás": "lingar",
    "lingarão": "lingar",
    "lingaríamos": "lingar",
    "lingaríeis": "lingar",
    "lingas": "lingar",
    "lingasse": "lingar",
    "lingassem": "lingar",
    "lingasses": "lingar",
    "lingaste": "lingar",
    "lingastes": "lingar",
    "lingava": "lingar",
    "lingavam": "lingar",
    "lingavas": "lingar",
    "lingeis": "lingel",
    "lingeries": "lingerie",
    "lingo": "lingar",
    "lingoteiras": "lingoteira",
    "lingotes": "lingote",
    "lingou": "lingar",
    "linguados": "linguado",
    "linguafones": "linguafone",
    "linguagens": "linguagem",
    "linguais": "lingual",
    "linguaja": "linguajar",
    "linguajada": "linguajar",
    "linguajadas": "linguajar",
    "linguajado": "linguajar",
    "linguajados": "linguajar",
    "linguajai": "linguajar",
    "linguajais": "linguajar",
    "linguajam": "linguajar",
    "linguajamo": "linguajar",
    "linguajamos": "linguajar",
    "linguajando": "linguajar",
    "linguajara": "linguajar",
    "linguajaram": "linguajar",
    "linguajaras": "linguajar",
    "linguajardes": "linguajar",
    "linguajarei": "linguajar",
    "linguajareis": "linguajar",
    "linguajarem": "linguajar",
    "linguajaremos": "linguajar",
    "linguajares": "linguajar",
    "linguajaria": "linguajar",
    "linguajariam": "linguajar",
    "linguajarias": "linguajar",
    "linguajarmo": "linguajar",
    "linguajarmos": "linguajar",
    "linguajará": "linguajar",
    "linguajarás": "linguajar",
    "linguajarão": "linguajar",
    "linguajaríamos": "linguajar",
    "linguajaríeis": "linguajar",
    "linguajas": "linguajar",
    "linguajasse": "linguajar",
    "linguajassem": "linguajar",
    "linguajasses": "linguajar",
    "linguajaste": "linguajar",
    "linguajastes": "linguajar",
    "linguajava": "linguajar",
    "linguajavam": "linguajar",
    "linguajavas": "linguajar",
    "linguaje": "linguajar",
    "linguajei": "linguajar",
    "linguajeis": "linguajar",
    "linguajem": "linguajar",
    "linguajemo": "linguajar",
    "linguajemos": "linguajar",
    "linguajes": "linguajar",
    "linguajo": "linguajar",
    "linguajou": "linguajar",
    "linguajámo": "linguajar",
    "linguajámos": "linguajar",
    "linguajáramo": "linguajar",
    "linguajáramos": "linguajar",
    "linguajáreis": "linguajar",
    "linguajásseis": "linguajar",
    "linguajássemos": "linguajar",
    "linguajávamo": "linguajar",
    "linguajávamos": "linguajar",
    "linguajáveis": "linguajar",
    "linguarazes": "linguaraz",
    "linguareira": "linguareiro",
    "linguareiras": "linguareiro",
    "linguareiros": "linguareiro",
    "linguareja": "linguarejar",
    "linguarejada": "linguarejar",
    "linguarejadas": "linguarejar",
    "linguarejado": "linguarejar",
    "linguarejados": "linguarejar",
    "linguarejai": "linguarejar",
    "linguarejais": "linguarejar",
    "linguarejam": "linguarejar",
    "linguarejamo": "linguarejar",
    "linguarejamos": "linguarejar",
    "linguarejando": "linguarejar",
    "linguarejara": "linguarejar",
    "linguarejaram": "linguarejar",
    "linguarejaras": "linguarejar",
    "linguarejardes": "linguarejar",
    "linguarejarei": "linguarejar",
    "linguarejareis": "linguarejar",
    "linguarejarem": "linguarejar",
    "linguarejaremos": "linguarejar",
    "linguarejares": "linguarejar",
    "linguarejaria": "linguarejar",
    "linguarejariam": "linguarejar",
    "linguarejarias": "linguarejar",
    "linguarejarmo": "linguarejar",
    "linguarejarmos": "linguarejar",
    "linguarejará": "linguarejar",
    "linguarejarás": "linguarejar",
    "linguarejarão": "linguarejar",
    "linguarejaríamos": "linguarejar",
    "linguarejaríeis": "linguarejar",
    "linguarejas": "linguarejar",
    "linguarejasse": "linguarejar",
    "linguarejassem": "linguarejar",
    "linguarejasses": "linguarejar",
    "linguarejaste": "linguarejar",
    "linguarejastes": "linguarejar",
    "linguarejava": "linguarejar",
    "linguarejavam": "linguarejar",
    "linguarejavas": "linguarejar",
    "linguareje": "linguarejar",
    "linguarejei": "linguarejar",
    "linguarejeis": "linguarejar",
    "linguarejem": "linguarejar",
    "linguarejemo": "linguarejar",
    "linguarejemos": "linguarejar",
    "linguarejes": "linguarejar",
    "linguarejo": "linguarejar",
    "linguarejou": "linguarejar",
    "linguarejámo": "linguarejar",
    "linguarejámos": "linguarejar",
    "linguarejáramo": "linguarejar",
    "linguarejáramos": "linguarejar",
    "linguarejáreis": "linguarejar",
    "linguarejásseis": "linguarejar",
    "linguarejássemos": "linguarejar",
    "linguarejávamo": "linguarejar",
    "linguarejávamos": "linguarejar",
    "linguarejáveis": "linguarejar",
    "linguarices": "linguarice",
    "linguariças": "linguariça",
    "linguarona": "linguarão",
    "linguaronas": "linguarão",
    "linguaruda": "linguarudo",
    "linguarudas": "linguarudo",
    "linguarudos": "linguarudo",
    "linguarões": "linguarão",
    "linguazinha": "língua",
    "linguazinhas": "língua",
    "linguazita": "língua",
    "linguazitas": "língua",
    "lingue": "lingar",
    "linguei": "lingar",
    "lingueirona": "lingueirão",
    "lingueironas": "lingueirão",
    "lingueirões": "lingueirão",
    "lingueis": "lingar",
    "linguem": "lingar",
    "linguemo": "lingar",
    "linguemos": "lingar",
    "lingues": "lingar",
    "linguetas": "lingueta",
    "linguetes": "linguete",
    "linguiformes": "linguiforme",
    "linguistas": "linguista",
    "linguiças": "linguiça",
    "linguodentais": "linguodental",
    "linguopalatais": "linguopalatal",
    "lingurteira": "lingurteiro",
    "lingurteiras": "lingurteiro",
    "lingurteiros": "lingurteiro",
    "linguífera": "linguífero",
    "linguíferas": "linguífero",
    "linguíferos": "linguífero",
    "linguística": "linguístico",
    "linguísticas": "linguístico",
    "linguísticos": "linguístico",
    "lingá": "lingar",
    "lingámo": "lingar",
    "lingámos": "lingar",
    "lingáramo": "lingar",
    "lingáramos": "lingar",
    "lingárei": "lingar",
    "lingáreis": "lingar",
    "lingásseis": "lingar",
    "lingássemos": "lingar",
    "lingávamo": "lingar",
    "lingávamos": "lingar",
    "lingávei": "lingar",
    "lingáveis": "lingar",
    "lingões": "lingão",
    "linhaceiros": "linhaceiro",
    "linhagens": "linhagem",
    "linhagistas": "linhagista",
    "linhais": "linhal",
    "linharadas": "linharada",
    "linhares": "linhar",
    "linhas": "linha",
    "linhavões": "linhavão",
    "linhaças": "linhaça",
    "linheira": "linheiro",
    "linheiras": "linheiro",
    "linheiros": "linheiro",
    "linhites": "linhite",
    "linhos": "linho",
    "linhosa": "linhoso",
    "linhosas": "linhoso",
    "linhosos": "linhoso",
    "linhóis": "linhol",
    "linhões": "linhão",
    "linifícios": "linifício",
    "linimenta": "linimentar",
    "linimentada": "linimentar",
    "linimentadas": "linimentar",
    "linimentado": "linimentar",
    "linimentados": "linimentar",
    "linimentai": "linimentar",
    "linimentais": "linimentar",
    "linimentam": "linimentar",
    "linimentamo": "linimentar",
    "linimentamos": "linimentar",
    "linimentando": "linimentar",
    "linimentara": "linimentar",
    "linimentaram": "linimentar",
    "linimentaras": "linimentar",
    "linimentarde": "linimentar",
    "linimentardes": "linimentar",
    "linimentare": "linimentar",
    "linimentarei": "linimentar",
    "linimentareis": "linimentar",
    "linimentarem": "linimentar",
    "linimentaremos": "linimentar",
    "linimentares": "linimentar",
    "linimentaria": "linimentar",
    "linimentariam": "linimentar",
    "linimentarias": "linimentar",
    "linimentarmo": "linimentar",
    "linimentarmos": "linimentar",
    "linimentará": "linimentar",
    "linimentarás": "linimentar",
    "linimentarão": "linimentar",
    "linimentaríamos": "linimentar",
    "linimentaríeis": "linimentar",
    "linimentas": "linimentar",
    "linimentasse": "linimentar",
    "linimentassem": "linimentar",
    "linimentasses": "linimentar",
    "linimentaste": "linimentar",
    "linimentastes": "linimentar",
    "linimentava": "linimentar",
    "linimentavam": "linimentar",
    "linimentavas": "linimentar",
    "linimente": "linimentar",
    "linimentei": "linimentar",
    "linimenteis": "linimentar",
    "linimentem": "linimentar",
    "linimentemo": "linimentar",
    "linimentemos": "linimentar",
    "linimentes": "linimentar",
    "linimento": "linimentar",
    "linimentos": "linimento",
    "linimentou": "linimentar",
    "linimentá": "linimentar",
    "linimentámo": "linimentar",
    "linimentámos": "linimentar",
    "linimentáramo": "linimentar",
    "linimentáramos": "linimentar",
    "linimentárei": "linimentar",
    "linimentáreis": "linimentar",
    "linimentásseis": "linimentar",
    "linimentássemos": "linimentar",
    "linimentávamo": "linimentar",
    "linimentávamos": "linimentar",
    "linimentávei": "linimentar",
    "linimentáveis": "linimentar",
    "lininas": "linina",
    "links": "link",
    "lino": "lenir",
    "linocompositores": "linocompositor",
    "linografias": "linografia",
    "linoleogravuras": "linoleogravura",
    "linotipa": "linotipar",
    "linotipada": "linotipar",
    "linotipadas": "linotipar",
    "linotipado": "linotipar",
    "linotipadoras": "linotipadora",
    "linotipados": "linotipar",
    "linotipai": "linotipar",
    "linotipais": "linotipar",
    "linotipam": "linotipar",
    "linotipamo": "linotipar",
    "linotipamos": "linotipar",
    "linotipando": "linotipar",
    "linotipara": "linotipar",
    "linotiparam": "linotipar",
    "linotiparas": "linotipar",
    "linotiparde": "linotipar",
    "linotipardes": "linotipar",
    "linotipare": "linotipar",
    "linotiparei": "linotipar",
    "linotipareis": "linotipar",
    "linotiparem": "linotipar",
    "linotiparemos": "linotipar",
    "linotipares": "linotipar",
    "linotiparia": "linotipar",
    "linotipariam": "linotipar",
    "linotiparias": "linotipar",
    "linotiparmo": "linotipar",
    "linotiparmos": "linotipar",
    "linotipará": "linotipar",
    "linotiparás": "linotipar",
    "linotiparão": "linotipar",
    "linotiparíamos": "linotipar",
    "linotiparíeis": "linotipar",
    "linotipas": "linotipar",
    "linotipasse": "linotipar",
    "linotipassem": "linotipar",
    "linotipasses": "linotipar",
    "linotipaste": "linotipar",
    "linotipastes": "linotipar",
    "linotipava": "linotipar",
    "linotipavam": "linotipar",
    "linotipavas": "linotipar",
    "linotipe": "linotipar",
    "linotipei": "linotipar",
    "linotipeis": "linotipar",
    "linotipem": "linotipar",
    "linotipemo": "linotipar",
    "linotipemos": "linotipar",
    "linotipes": "linotipar",
    "linotipias": "linotipia",
    "linotipistas": "linotipista",
    "linotipo": "linotipar",
    "linotipou": "linotipar",
    "linotipá": "linotipar",
    "linotipámo": "linotipar",
    "linotipámos": "linotipar",
    "linotipáramo": "linotipar",
    "linotipáramos": "linotipar",
    "linotipárei": "linotipar",
    "linotipáreis": "linotipar",
    "linotipásseis": "linotipar",
    "linotipássemos": "linotipar",
    "linotipávamo": "linotipar",
    "linotipávamos": "linotipar",
    "linotipávei": "linotipar",
    "linotipáveis": "linotipável",
    "linotipógrafa": "linotipógrafo",
    "linotipógrafas": "linotipógrafo",
    "linotipógrafos": "linotipógrafo",
    "linpoiética": "linpoiético",
    "linpoiéticas": "linpoiético",
    "linpoiéticos": "linpoiético",
    "lintéis": "lintel",
    "linácea": "lináceo",
    "lináceas": "lináceo",
    "lináceos": "lináceo",
    "linárias": "linária",
    "linígera": "linígero",
    "linígeras": "linígero",
    "linígeros": "linígero",
    "linógrafos": "linógrafo",
    "linóleos": "linóleo",
    "linótipos": "linótipo",
    "lio": "liar",
    "liocarpa": "liocarpo",
    "liocarpas": "liocarpo",
    "liocarpos": "liocarpo",
    "lioderma": "liodermo",
    "liodermas": "liodermo",
    "liodermos": "liodermo",
    "liofilizada": "liofilizado",
    "liofilizadas": "liofilizado",
    "liofilizadores": "liofilizador",
    "liofilizados": "liofilizado",
    "liofilizações": "liofilização",
    "lionesa": "lionês",
    "lionesas": "lionês",
    "lioneses": "lionês",
    "liornesa": "liornês",
    "liornesas": "liornês",
    "liorneses": "liornês",
    "lios": "lio",
    "liou": "liar",
    "liozes": "lioz",
    "liparites": "liparite",
    "liparoceles": "liparocele",
    "lipas": "lipa",
    "lipemanias": "lipemania",
    "lipemias": "lipemia",
    "lipoaspirações": "lipoaspiração",
    "lipocromos": "lipocromo",
    "lipofrenias": "lipofrenia",
    "lipogramas": "lipograma",
    "lipogramistas": "lipogramista",
    "lipogramática": "lipogramático",
    "lipogramáticas": "lipogramático",
    "lipogramáticos": "lipogramático",
    "lipogéneses": "lipogénese",
    "lipomas": "lipoma",
    "lipomatosa": "lipomatoso",
    "lipomatosas": "lipomatoso",
    "lipomatoses": "lipomatose",
    "lipomatosos": "lipomatoso",
    "lipoproteínas": "lipoproteína",
    "liposa": "liposo",
    "liposas": "liposo",
    "liposos": "liposo",
    "lipotimias": "lipotimia",
    "lipsienses": "lipsiense",
    "lipídios": "lipídio",
    "lipógnatos": "lipógnato",
    "lipóides": "lipóide",
    "lipólises": "lipólise",
    "lipópteros": "lipóptero",
    "lipúrias": "lipúria",
    "liquações": "liquação",
    "liquefacta": "liquefacto",
    "liquefactas": "liquefacto",
    "liquefactiva": "liquefactivo",
    "liquefactivas": "liquefactivo",
    "liquefactivos": "liquefactivo",
    "liquefactores": "liquefactor",
    "liquefactos": "liquefacto",
    "liquefactíveis": "liquefactível",
    "liquefacções": "liquefacção",
    "liquefarei": "liquefazer",
    "liquefareis": "liquefazer",
    "liquefaremos": "liquefazer",
    "liquefaria": "liquefazer",
    "liquefariam": "liquefazer",
    "liquefarias": "liquefazer",
    "liquefará": "liquefazer",
    "liquefarás": "liquefazer",
    "liquefarão": "liquefazer",
    "liquefaríamos": "liquefazer",
    "liquefaríeis": "liquefazer",
    "liquefaz": "liquefazer",
    "liquefaze": "liquefazer",
    "liquefazei": "liquefazer",
    "liquefazeis": "liquefazer",
    "liquefazem": "liquefazer",
    "liquefazemo": "liquefazer",
    "liquefazemos": "liquefazer",
    "liquefazendo": "liquefazer",
    "liquefazerde": "liquefazer",
    "liquefazerdes": "liquefazer",
    "liquefazere": "liquefazer",
    "liquefazerem": "liquefazer",
    "liquefazeres": "liquefazer",
    "liquefazermo": "liquefazer",
    "liquefazermos": "liquefazer",
    "liquefazes": "liquefazer",
    "liquefazia": "liquefazer",
    "liquefaziam": "liquefazer",
    "liquefazias": "liquefazer",
    "liquefazê": "liquefazer",
    "liquefazíamo": "liquefazer",
    "liquefazíamos": "liquefazer",
    "liquefazíei": "liquefazer",
    "liquefazíeis": "liquefazer",
    "liquefaça": "liquefazer",
    "liquefaçais": "liquefazer",
    "liquefaçam": "liquefazer",
    "liquefaçamo": "liquefazer",
    "liquefaçamos": "liquefazer",
    "liquefaças": "liquefazer",
    "liquefaço": "liquefazer",
    "liquefeita": "liquefeito",
    "liquefeitas": "liquefeito",
    "liquefeito": "liquefazer",
    "liquefeitos": "liquefeito",
    "liquefez": "liquefazer",
    "liquefi": "liquefazer",
    "liquefiz": "liquefazer",
    "liquefizemo": "liquefazer",
    "liquefizemos": "liquefazer",
    "liquefizer": "liquefazer",
    "liquefizera": "liquefazer",
    "liquefizeram": "liquefazer",
    "liquefizeras": "liquefazer",
    "liquefizerdes": "liquefazer",
    "liquefizerem": "liquefazer",
    "liquefizeres": "liquefazer",
    "liquefizermos": "liquefazer",
    "liquefizesse": "liquefazer",
    "liquefizessem": "liquefazer",
    "liquefizesses": "liquefazer",
    "liquefizeste": "liquefazer",
    "liquefizestes": "liquefazer",
    "liquefizéramo": "liquefazer",
    "liquefizéramos": "liquefazer",
    "liquefizérei": "liquefazer",
    "liquefizéreis": "liquefazer",
    "liquefizésseis": "liquefazer",
    "liquefizéssemos": "liquefazer",
    "liquefá": "liquefazer",
    "liquefê": "liquefazer",
    "liquenografa": "liquenografo",
    "liquenografas": "liquenografo",
    "liquenografias": "liquenografia",
    "liquenografos": "liquenografo",
    "liquesce": "liquescer",
    "liquescei": "liquescer",
    "liquesceis": "liquescer",
    "liquescem": "liquescer",
    "liquescemo": "liquescer",
    "liquescemos": "liquescer",
    "liquescendo": "liquescer",
    "liquescera": "liquescer",
    "liquesceram": "liquescer",
    "liquesceras": "liquescer",
    "liquescerdes": "liquescer",
    "liquescerei": "liquescer",
    "liquescereis": "liquescer",
    "liquescerem": "liquescer",
    "liquesceremos": "liquescer",
    "liquesceres": "liquescer",
    "liquesceria": "liquescer",
    "liquesceriam": "liquescer",
    "liquescerias": "liquescer",
    "liquescermo": "liquescer",
    "liquescermos": "liquescer",
    "liquescerá": "liquescer",
    "liquescerás": "liquescer",
    "liquescerão": "liquescer",
    "liquesceríamos": "liquescer",
    "liquesceríeis": "liquescer",
    "liquesces": "liquescer",
    "liquescesse": "liquescer",
    "liquescessem": "liquescer",
    "liquescesses": "liquescer",
    "liquesceste": "liquescer",
    "liquescestes": "liquescer",
    "liquesceu": "liquescer",
    "liquesci": "liquescer",
    "liquescia": "liquescer",
    "liquesciam": "liquescer",
    "liquescias": "liquescer",
    "liquescida": "liquescer",
    "liquescidas": "liquescer",
    "liquescido": "liquescer",
    "liquescidos": "liquescer",
    "liquescêramo": "liquescer",
    "liquescêramos": "liquescer",
    "liquescêreis": "liquescer",
    "liquescêsseis": "liquescer",
    "liquescêssemos": "liquescer",
    "liquescíamo": "liquescer",
    "liquescíamos": "liquescer",
    "liquescíeis": "liquescer",
    "liquesça": "liquescer",
    "liquesçais": "liquescer",
    "liquesçam": "liquescer",
    "liquesçamo": "liquescer",
    "liquesçamos": "liquescer",
    "liquesças": "liquescer",
    "liquesço": "liquescer",
    "liquida": "liquidar",
    "liquidacionistas": "liquidacionista",
    "liquidada": "liquidar",
    "liquidadas": "liquidar",
    "liquidado": "liquidar",
    "liquidadora": "liquidador",
    "liquidadoras": "liquidador",
    "liquidadores": "liquidador",
    "liquidados": "liquidar",
    "liquidai": "liquidar",
    "liquidais": "liquidar",
    "liquidam": "liquidar",
    "liquidamo": "liquidar",
    "liquidamos": "liquidar",
    "liquidando": "liquidar",
    "liquidantes": "liquidante",
    "liquidara": "liquidar",
    "liquidaram": "liquidar",
    "liquidaras": "liquidar",
    "liquidarde": "liquidar",
    "liquidardes": "liquidar",
    "liquidare": "liquidar",
    "liquidarei": "liquidar",
    "liquidareis": "liquidar",
    "liquidarem": "liquidar",
    "liquidaremos": "liquidar",
    "liquidares": "liquidar",
    "liquidaria": "liquidar",
    "liquidariam": "liquidar",
    "liquidarias": "liquidar",
    "liquidarmo": "liquidar",
    "liquidarmos": "liquidar",
    "liquidará": "liquidar",
    "liquidarás": "liquidar",
    "liquidarão": "liquidar",
    "liquidaríamos": "liquidar",
    "liquidaríeis": "liquidar",
    "liquidas": "liquidar",
    "liquidasse": "liquidar",
    "liquidassem": "liquidar",
    "liquidasses": "liquidar",
    "liquidaste": "liquidar",
    "liquidastes": "liquidar",
    "liquidatária": "liquidatário",
    "liquidatárias": "liquidatário",
    "liquidatários": "liquidatário",
    "liquidava": "liquidar",
    "liquidavam": "liquidar",
    "liquidavas": "liquidar",
    "liquidações": "liquidação",
    "liquide": "liquidar",
    "liquidei": "liquidar",
    "liquideis": "liquidar",
    "liquidem": "liquidar",
    "liquidemo": "liquidar",
    "liquidemos": "liquidar",
    "liquides": "liquidar",
    "liquidezes": "liquidez",
    "liquidifica": "liquidificar",
    "liquidificada": "liquidificar",
    "liquidificadas": "liquidificar",
    "liquidificado": "liquidificar",
    "liquidificadores": "liquidificador",
    "liquidificados": "liquidificar",
    "liquidificai": "liquidificar",
    "liquidificais": "liquidificar",
    "liquidificam": "liquidificar",
    "liquidificamo": "liquidificar",
    "liquidificamos": "liquidificar",
    "liquidificando": "liquidificar",
    "liquidificantes": "liquidificante",
    "liquidificara": "liquidificar",
    "liquidificaram": "liquidificar",
    "liquidificaras": "liquidificar",
    "liquidificarde": "liquidificar",
    "liquidificardes": "liquidificar",
    "liquidificare": "liquidificar",
    "liquidificarei": "liquidificar",
    "liquidificareis": "liquidificar",
    "liquidificarem": "liquidificar",
    "liquidificaremos": "liquidificar",
    "liquidificares": "liquidificar",
    "liquidificaria": "liquidificar",
    "liquidificariam": "liquidificar",
    "liquidificarias": "liquidificar",
    "liquidificarmo": "liquidificar",
    "liquidificarmos": "liquidificar",
    "liquidificará": "liquidificar",
    "liquidificarás": "liquidificar",
    "liquidificarão": "liquidificar",
    "liquidificaríamos": "liquidificar",
    "liquidificaríeis": "liquidificar",
    "liquidificas": "liquidificar",
    "liquidificasse": "liquidificar",
    "liquidificassem": "liquidificar",
    "liquidificasses": "liquidificar",
    "liquidificaste": "liquidificar",
    "liquidificastes": "liquidificar",
    "liquidificava": "liquidificar",
    "liquidificavam": "liquidificar",
    "liquidificavas": "liquidificar",
    "liquidificações": "liquidificação",
    "liquidifico": "liquidificar",
    "liquidificou": "liquidificar",
    "liquidificá": "liquidificar",
    "liquidificámo": "liquidificar",
    "liquidificámos": "liquidificar",
    "liquidificáramo": "liquidificar",
    "liquidificáramos": "liquidificar",
    "liquidificárei": "liquidificar",
    "liquidificáreis": "liquidificar",
    "liquidificásseis": "liquidificar",
    "liquidificássemos": "liquidificar",
    "liquidificávamo": "liquidificar",
    "liquidificávamos": "liquidificar",
    "liquidificávei": "liquidificar",
    "liquidificáveis": "liquidificável",
    "liquidifique": "liquidificar",
    "liquidifiquei": "liquidificar",
    "liquidifiqueis": "liquidificar",
    "liquidifiquem": "liquidificar",
    "liquidifiquemo": "liquidificar",
    "liquidifiquemos": "liquidificar",
    "liquidifiques": "liquidificar",
    "liquido": "liquidar",
    "liquidou": "liquidar",
    "liquidá": "liquidar",
    "liquidámo": "liquidar",
    "liquidámos": "liquidar",
    "liquidáramo": "liquidar",
    "liquidáramos": "liquidar",
    "liquidárei": "liquidar",
    "liquidáreis": "liquidar",
    "liquidásseis": "liquidar",
    "liquidássemos": "liquidar",
    "liquidávamo": "liquidar",
    "liquidávamos": "liquidar",
    "liquidávei": "liquidar",
    "liquidáveis": "liquidável",
    "liquidâmbares": "liquidâmbar",
    "liquómetros": "liquómetro",
    "liras": "lira",
    "lirismos": "lirismo",
    "liristas": "lirista",
    "lirus": "liru",
    "lirós": "liró",
    "lis": "li",
    "lisa": "liso",
    "lisas": "liso",
    "lisboas": "lisboa",
    "lisboesa": "lisboês",
    "lisboesas": "lisboês",
    "lisboeses": "lisboês",
    "lisboetas": "lisboeta",
    "lisboetazinha": "lisboeta",
    "lisboetazinhas": "lisboeta",
    "lisboetazinho": "lisboeta",
    "lisboetazinhos": "lisboeta",
    "lisboetazita": "lisboeta",
    "lisboetazitas": "lisboeta",
    "lisboetazito": "lisboeta",
    "lisboetazitos": "lisboeta",
    "lisbonenses": "lisbonense",
    "lisbonesa": "lisbonês",
    "lisbonesas": "lisbonês",
    "lisboneses": "lisbonês",
    "lisbonina": "lisbonino",
    "lisboninas": "lisbonino",
    "lisboninos": "lisbonino",
    "lisemias": "lisemia",
    "lises": "lise",
    "liseuses": "liseuse",
    "lisimáquias": "lisimáquia",
    "lisinas": "lisina",
    "lisma": "lismar",
    "lismada": "lismar",
    "lismadas": "lismar",
    "lismado": "lismar",
    "lismados": "lismar",
    "lismai": "lismar",
    "lismais": "lismar",
    "lismam": "lismar",
    "lismamo": "lismar",
    "lismamos": "lismar",
    "lismando": "lismar",
    "lismara": "lismar",
    "lismaram": "lismar",
    "lismaras": "lismar",
    "lismarde": "lismar",
    "lismardes": "lismar",
    "lismare": "lismar",
    "lismarei": "lismar",
    "lismareis": "lismar",
    "lismarem": "lismar",
    "lismaremos": "lismar",
    "lismares": "lismar",
    "lismaria": "lismar",
    "lismariam": "lismar",
    "lismarias": "lismar",
    "lismarmo": "lismar",
    "lismarmos": "lismar",
    "lismará": "lismar",
    "lismarás": "lismar",
    "lismarão": "lismar",
    "lismaríamos": "lismar",
    "lismaríeis": "lismar",
    "lismas": "lismar",
    "lismasse": "lismar",
    "lismassem": "lismar",
    "lismasses": "lismar",
    "lismaste": "lismar",
    "lismastes": "lismar",
    "lismava": "lismar",
    "lismavam": "lismar",
    "lismavas": "lismar",
    "lisme": "lismar",
    "lismei": "lismar",
    "lismeis": "lismar",
    "lismem": "lismar",
    "lismemo": "lismar",
    "lismemos": "lismar",
    "lismes": "lismar",
    "lismo": "lismar",
    "lismos": "lismo",
    "lismou": "lismar",
    "lismá": "lismar",
    "lismámo": "lismar",
    "lismámos": "lismar",
    "lismáramo": "lismar",
    "lismáramos": "lismar",
    "lismárei": "lismar",
    "lismáreis": "lismar",
    "lismásseis": "lismar",
    "lismássemos": "lismar",
    "lismávamo": "lismar",
    "lismávamos": "lismar",
    "lismávei": "lismar",
    "lismáveis": "lismar",
    "lisogenias": "lisogenia",
    "lisonjarias": "lisonjaria",
    "lisonjas": "lisonja",
    "lisonjeada": "lisonjear",
    "lisonjeadas": "lisonjear",
    "lisonjeado": "lisonjear",
    "lisonjeadora": "lisonjeador",
    "lisonjeadoras": "lisonjeador",
    "lisonjeadores": "lisonjeador",
    "lisonjeados": "lisonjear",
    "lisonjeadíssima": "lisonjeado",
    "lisonjeadíssimas": "lisonjeado",
    "lisonjeadíssimo": "lisonjeado",
    "lisonjeadíssimos": "lisonjeado",
    "lisonjeai": "lisonjear",
    "lisonjeais": "lisonjear",
    "lisonjeamo": "lisonjear",
    "lisonjeamos": "lisonjear",
    "lisonjeando": "lisonjear",
    "lisonjeara": "lisonjear",
    "lisonjearam": "lisonjear",
    "lisonjearas": "lisonjear",
    "lisonjearde": "lisonjear",
    "lisonjeardes": "lisonjear",
    "lisonjeare": "lisonjear",
    "lisonjearei": "lisonjear",
    "lisonjeareis": "lisonjear",
    "lisonjearem": "lisonjear",
    "lisonjearemos": "lisonjear",
    "lisonjeares": "lisonjear",
    "lisonjearia": "lisonjear",
    "lisonjeariam": "lisonjear",
    "lisonjearias": "lisonjear",
    "lisonjearmo": "lisonjear",
    "lisonjearmos": "lisonjear",
    "lisonjeará": "lisonjear",
    "lisonjearás": "lisonjear",
    "lisonjearão": "lisonjear",
    "lisonjearíamos": "lisonjear",
    "lisonjearíeis": "lisonjear",
    "lisonjeasse": "lisonjear",
    "lisonjeassem": "lisonjear",
    "lisonjeasses": "lisonjear",
    "lisonjeaste": "lisonjear",
    "lisonjeastes": "lisonjear",
    "lisonjeava": "lisonjear",
    "lisonjeavam": "lisonjear",
    "lisonjeavas": "lisonjear",
    "lisonjeei": "lisonjear",
    "lisonjeeis": "lisonjear",
    "lisonjeemo": "lisonjear",
    "lisonjeemos": "lisonjear",
    "lisonjeia": "lisonjear",
    "lisonjeiam": "lisonjear",
    "lisonjeias": "lisonjear",
    "lisonjeie": "lisonjear",
    "lisonjeiem": "lisonjear",
    "lisonjeies": "lisonjear",
    "lisonjeio": "lisonjear",
    "lisonjeira": "lisonjeiro",
    "lisonjeiras": "lisonjeiro",
    "lisonjeiros": "lisonjeiro",
    "lisonjeou": "lisonjear",
    "lisonjeá": "lisonjear",
    "lisonjeámo": "lisonjear",
    "lisonjeámos": "lisonjear",
    "lisonjeáramo": "lisonjear",
    "lisonjeáramos": "lisonjear",
    "lisonjeárei": "lisonjear",
    "lisonjeáreis": "lisonjear",
    "lisonjeásseis": "lisonjear",
    "lisonjeássemos": "lisonjear",
    "lisonjeávamo": "lisonjear",
    "lisonjeávamos": "lisonjear",
    "lisonjeávei": "lisonjear",
    "lisonjeáveis": "lisonjear",
    "lisos": "liso",
    "lissadeiras": "lissadeira",
    "lissas": "lissa",
    "lisseiras": "lisseira",
    "listada": "listado",
    "listadas": "listado",
    "listados": "listado",
    "listagens": "listagem",
    "listas": "lista",
    "listelos": "listelo",
    "listelões": "listelão",
    "listona": "listão",
    "listonas": "listão",
    "listra": "listrar",
    "listrada": "listrar",
    "listradas": "listrar",
    "listrado": "listrar",
    "listrados": "listrar",
    "listrai": "listrar",
    "listrais": "listrar",
    "listram": "listrar",
    "listramo": "listrar",
    "listramos": "listrar",
    "listrando": "listrar",
    "listrara": "listrar",
    "listraram": "listrar",
    "listraras": "listrar",
    "listrarde": "listrar",
    "listrardes": "listrar",
    "listrare": "listrar",
    "listrarei": "listrar",
    "listrareis": "listrar",
    "listrarem": "listrar",
    "listraremos": "listrar",
    "listrares": "listrar",
    "listraria": "listrar",
    "listrariam": "listrar",
    "listrarias": "listrar",
    "listrarmo": "listrar",
    "listrarmos": "listrar",
    "listrará": "listrar",
    "listrarás": "listrar",
    "listrarão": "listrar",
    "listraríamos": "listrar",
    "listraríeis": "listrar",
    "listras": "listrar",
    "listrasse": "listrar",
    "listrassem": "listrar",
    "listrasses": "listrar",
    "listraste": "listrar",
    "listrastes": "listrar",
    "listrava": "listrar",
    "listravam": "listrar",
    "listravas": "listrar",
    "listre": "listrar",
    "listrei": "listrar",
    "listreis": "listrar",
    "listrem": "listrar",
    "listremo": "listrar",
    "listremos": "listrar",
    "listres": "listrar",
    "listro": "listrar",
    "listrou": "listrar",
    "listrá": "listrar",
    "listrámo": "listrar",
    "listrámos": "listrar",
    "listráramo": "listrar",
    "listráramos": "listrar",
    "listrárei": "listrar",
    "listráreis": "listrar",
    "listrásseis": "listrar",
    "listrássemos": "listrar",
    "listrávamo": "listrar",
    "listrávamos": "listrar",
    "listrávei": "listrar",
    "listráveis": "listrar",
    "listrões": "listrão",
    "listéis": "listel",
    "listões": "listão",
    "lisuras": "lisura",
    "lisímetros": "lisímetro",
    "lisóis": "lisol",
    "lita": "litar",
    "litada": "litar",
    "litadas": "litar",
    "litado": "litar",
    "litados": "litar",
    "litagoga": "litagogo",
    "litagogas": "litagogo",
    "litagogias": "litagogia",
    "litagogos": "litagogo",
    "litai": "litar",
    "litais": "litar",
    "litam": "litar",
    "litamo": "litar",
    "litamos": "litar",
    "litando": "litar",
    "litanias": "litania",
    "litara": "litar",
    "litaram": "litar",
    "litaras": "litar",
    "litarde": "litar",
    "litardes": "litar",
    "litare": "litar",
    "litarei": "litar",
    "litareis": "litar",
    "litarem": "litar",
    "litaremos": "litar",
    "litares": "litar",
    "litargírios": "litargírio",
    "litaria": "litar",
    "litariam": "litar",
    "litarias": "litar",
    "litarmo": "litar",
    "litarmos": "litar",
    "litará": "litar",
    "litarás": "litar",
    "litarão": "litar",
    "litaríamos": "litar",
    "litaríeis": "litar",
    "litas": "litar",
    "litasse": "litar",
    "litassem": "litar",
    "litasses": "litar",
    "litaste": "litar",
    "litastes": "litar",
    "litava": "litar",
    "litavam": "litar",
    "litavas": "litar",
    "litações": "litação",
    "lite": "litar",
    "litei": "litar",
    "liteiras": "liteira",
    "liteireira": "liteireiro",
    "liteireiras": "liteireiro",
    "liteireiros": "liteireiro",
    "liteiros": "liteiro",
    "liteis": "litar",
    "litem": "litar",
    "litemo": "litar",
    "litemos": "litar",
    "literacias": "literacia",
    "literais": "literal",
    "literalidades": "literalidade",
    "literalismos": "literalismo",
    "literalistas": "literalista",
    "literariedades": "literariedade",
    "literata": "literato",
    "literatas": "literato",
    "literataça": "literataço",
    "literataças": "literataço",
    "literataços": "literataço",
    "literateja": "literatejar",
    "literatejada": "literatejar",
    "literatejadas": "literatejar",
    "literatejado": "literatejar",
    "literatejados": "literatejar",
    "literatejai": "literatejar",
    "literatejais": "literatejar",
    "literatejam": "literatejar",
    "literatejamo": "literatejar",
    "literatejamos": "literatejar",
    "literatejando": "literatejar",
    "literatejara": "literatejar",
    "literatejaram": "literatejar",
    "literatejaras": "literatejar",
    "literatejarde": "literatejar",
    "literatejardes": "literatejar",
    "literatejare": "literatejar",
    "literatejarei": "literatejar",
    "literatejareis": "literatejar",
    "literatejarem": "literatejar",
    "literatejaremos": "literatejar",
    "literatejares": "literatejar",
    "literatejaria": "literatejar",
    "literatejariam": "literatejar",
    "literatejarias": "literatejar",
    "literatejarmo": "literatejar",
    "literatejarmos": "literatejar",
    "literatejará": "literatejar",
    "literatejarás": "literatejar",
    "literatejarão": "literatejar",
    "literatejaríamos": "literatejar",
    "literatejaríeis": "literatejar",
    "literatejas": "literatejar",
    "literatejasse": "literatejar",
    "literatejassem": "literatejar",
    "literatejasses": "literatejar",
    "literatejaste": "literatejar",
    "literatejastes": "literatejar",
    "literatejava": "literatejar",
    "literatejavam": "literatejar",
    "literatejavas": "literatejar",
    "literateje": "literatejar",
    "literatejei": "literatejar",
    "literatejeis": "literatejar",
    "literatejem": "literatejar",
    "literatejemo": "literatejar",
    "literatejemos": "literatejar",
    "literatejes": "literatejar",
    "literatejo": "literatejar",
    "literatejou": "literatejar",
    "literatejá": "literatejar",
    "literatejámo": "literatejar",
    "literatejámos": "literatejar",
    "literatejáramo": "literatejar",
    "literatejáramos": "literatejar",
    "literatejárei": "literatejar",
    "literatejáreis": "literatejar",
    "literatejásseis": "literatejar",
    "literatejássemos": "literatejar",
    "literatejávamo": "literatejar",
    "literatejávamos": "literatejar",
    "literatejávei": "literatejar",
    "literatejáveis": "literatejar",
    "literatelha": "literatelho",
    "literatelhas": "literatelho",
    "literatelhos": "literatelho",
    "literatices": "literatice",
    "literatiqueira": "literatiqueiro",
    "literatiqueiras": "literatiqueiro",
    "literatiqueiros": "literatiqueiro",
    "literatismos": "literatismo",
    "literatos": "literato",
    "literaturas": "literatura",
    "literomanias": "literomania",
    "literomaníaca": "literomaníaco",
    "literomaníacas": "literomaníaco",
    "literomaníacos": "literomaníaco",
    "literária": "literário",
    "literárias": "literário",
    "literários": "literário",
    "lites": "litar",
    "litificações": "litificação",
    "litiga": "litigar",
    "litigada": "litigar",
    "litigadas": "litigar",
    "litigado": "litigar",
    "litigados": "litigar",
    "litigai": "litigar",
    "litigais": "litigar",
    "litigam": "litigar",
    "litigamo": "litigar",
    "litigamos": "litigar",
    "litigando": "litigar",
    "litigantes": "litigante",
    "litigara": "litigar",
    "litigaram": "litigar",
    "litigaras": "litigar",
    "litigardes": "litigar",
    "litigarei": "litigar",
    "litigareis": "litigar",
    "litigarem": "litigar",
    "litigaremos": "litigar",
    "litigares": "litigar",
    "litigaria": "litigar",
    "litigariam": "litigar",
    "litigarias": "litigar",
    "litigarmo": "litigar",
    "litigarmos": "litigar",
    "litigará": "litigar",
    "litigarás": "litigar",
    "litigarão": "litigar",
    "litigaríamos": "litigar",
    "litigaríeis": "litigar",
    "litigas": "litigar",
    "litigasse": "litigar",
    "litigassem": "litigar",
    "litigasses": "litigar",
    "litigaste": "litigar",
    "litigastes": "litigar",
    "litigava": "litigar",
    "litigavam": "litigar",
    "litigavas": "litigar",
    "litigações": "litigação",
    "litigia": "litigiar",
    "litigiada": "litigiar",
    "litigiadas": "litigiar",
    "litigiado": "litigiar",
    "litigiados": "litigiar",
    "litigiai": "litigiar",
    "litigiais": "litigiar",
    "litigiam": "litigiar",
    "litigiamo": "litigiar",
    "litigiamos": "litigiar",
    "litigiando": "litigiar",
    "litigiara": "litigiar",
    "litigiaram": "litigiar",
    "litigiaras": "litigiar",
    "litigiarde": "litigiar",
    "litigiardes": "litigiar",
    "litigiare": "litigiar",
    "litigiarei": "litigiar",
    "litigiareis": "litigiar",
    "litigiarem": "litigiar",
    "litigiaremos": "litigiar",
    "litigiares": "litigiar",
    "litigiaria": "litigiar",
    "litigiariam": "litigiar",
    "litigiarias": "litigiar",
    "litigiarmo": "litigiar",
    "litigiarmos": "litigiar",
    "litigiará": "litigiar",
    "litigiarás": "litigiar",
    "litigiarão": "litigiar",
    "litigiaríamos": "litigiar",
    "litigiaríeis": "litigiar",
    "litigias": "litigiar",
    "litigiasse": "litigiar",
    "litigiassem": "litigiar",
    "litigiasses": "litigiar",
    "litigiaste": "litigiar",
    "litigiastes": "litigiar",
    "litigiava": "litigiar",
    "litigiavam": "litigiar",
    "litigiavas": "litigiar",
    "litigie": "litigiar",
    "litigiei": "litigiar",
    "litigieis": "litigiar",
    "litigiem": "litigiar",
    "litigiemo": "litigiar",
    "litigiemos": "litigiar",
    "litigies": "litigiar",
    "litigio": "litigiar",
    "litigiosa": "litigioso",
    "litigiosas": "litigioso",
    "litigiosos": "litigioso",
    "litigiou": "litigiar",
    "litigiá": "litigiar",
    "litigiámo": "litigiar",
    "litigiámos": "litigiar",
    "litigiáramo": "litigiar",
    "litigiáramos": "litigiar",
    "litigiárei": "litigiar",
    "litigiáreis": "litigiar",
    "litigiásseis": "litigiar",
    "litigiássemos": "litigiar",
    "litigiávamo": "litigiar",
    "litigiávamos": "litigiar",
    "litigiávei": "litigiar",
    "litigiáveis": "litigiar",
    "litigo": "litigar",
    "litigou": "litigar",
    "litigue": "litigar",
    "litiguei": "litigar",
    "litigueis": "litigar",
    "litiguem": "litigar",
    "litiguemo": "litigar",
    "litiguemos": "litigar",
    "litigues": "litigar",
    "litigámo": "litigar",
    "litigámos": "litigar",
    "litigáramo": "litigar",
    "litigáramos": "litigar",
    "litigáreis": "litigar",
    "litigásseis": "litigar",
    "litigássemos": "litigar",
    "litigávamo": "litigar",
    "litigávamos": "litigar",
    "litigáveis": "litigável",
    "litinada": "litinado",
    "litinadas": "litinado",
    "litinados": "litinado",
    "litinas": "litina",
    "litinífera": "litinífero",
    "litiníferas": "litinífero",
    "litiníferos": "litinífero",
    "litisconsortes": "litisconsorte",
    "litisconsórcios": "litisconsórcio",
    "litiscontestações": "litiscontestação",
    "litispendências": "litispendência",
    "litizontes": "litizonte",
    "lito": "litar",
    "litobiomorfos": "litobiomorfo",
    "litobiídeos": "litobiídeo",
    "litobíidas": "litobíida",
    "litocarpos": "litocarpo",
    "litocenoses": "litocenose",
    "litoclasias": "litoclasia",
    "litoclastias": "litoclastia",
    "litoclastos": "litoclasto",
    "litocolas": "litocola",
    "litocromias": "litocromia",
    "litocromistas": "litocromista",
    "litocrómica": "litocrómico",
    "litocrómicas": "litocrómico",
    "litocrómicos": "litocrómico",
    "litodiálises": "litodiálise",
    "litofagias": "litofagia",
    "litofilos": "litofilo",
    "litogenesias": "litogenesia",
    "litoglifias": "litoglifia",
    "litografa": "litografar",
    "litografada": "litografar",
    "litografadas": "litografar",
    "litografado": "litografar",
    "litografados": "litografar",
    "litografai": "litografar",
    "litografais": "litografar",
    "litografam": "litografar",
    "litografamo": "litografar",
    "litografamos": "litografar",
    "litografando": "litografar",
    "litografara": "litografar",
    "litografaram": "litografar",
    "litografaras": "litografar",
    "litografarde": "litografar",
    "litografardes": "litografar",
    "litografare": "litografar",
    "litografarei": "litografar",
    "litografareis": "litografar",
    "litografarem": "litografar",
    "litografaremos": "litografar",
    "litografares": "litografar",
    "litografaria": "litografar",
    "litografariam": "litografar",
    "litografarias": "litografar",
    "litografarmo": "litografar",
    "litografarmos": "litografar",
    "litografará": "litografar",
    "litografarás": "litografar",
    "litografarão": "litografar",
    "litografaríamos": "litografar",
    "litografaríeis": "litografar",
    "litografas": "litografar",
    "litografasse": "litografar",
    "litografassem": "litografar",
    "litografasses": "litografar",
    "litografaste": "litografar",
    "litografastes": "litografar",
    "litografava": "litografar",
    "litografavam": "litografar",
    "litografavas": "litografar",
    "litografe": "litografar",
    "litografei": "litografar",
    "litografeis": "litografar",
    "litografem": "litografar",
    "litografemo": "litografar",
    "litografemos": "litografar",
    "litografes": "litografar",
    "litografias": "litografia",
    "litografo": "litografar",
    "litografou": "litografar",
    "litografá": "litografar",
    "litografámo": "litografar",
    "litografámos": "litografar",
    "litografáramo": "litografar",
    "litografáramos": "litografar",
    "litografárei": "litografar",
    "litografáreis": "litografar",
    "litografásseis": "litografar",
    "litografássemos": "litografar",
    "litografávamo": "litografar",
    "litografávamos": "litografar",
    "litografávei": "litografar",
    "litografáveis": "litografável",
    "litogravuras": "litogravura",
    "litográfica": "litográfico",
    "litográficas": "litográfico",
    "litográficos": "litográfico",
    "litolatrias": "litolatria",
    "litologias": "litologia",
    "litologistas": "litologista",
    "litolábios": "litolábio",
    "litomancias": "litomancia",
    "litomantes": "litomante",
    "litopográfica": "litopográfico",
    "litopográficas": "litopográfico",
    "litopográficos": "litopográfico",
    "litopédios": "litopédio",
    "litorais": "litoral",
    "litoralizações": "litoralização",
    "litorinídeos": "litorinídeo",
    "litorânea": "litorâneo",
    "litorâneas": "litorâneo",
    "litorâneos": "litorâneo",
    "litorínidas": "litorínida",
    "litosferas": "litosfera",
    "litosperma": "litospermo",
    "litospermas": "litospermo",
    "litospermos": "litospermo",
    "litotecas": "litoteca",
    "litotipografias": "litotipografia",
    "litotomias": "litotomia",
    "litotomistas": "litotomista",
    "litotripsias": "litotripsia",
    "litotâmnios": "litotâmnio",
    "litou": "litar",
    "litragens": "litragem",
    "litros": "litro",
    "litráceas": "litrácea",
    "lituana": "lituano",
    "lituanas": "lituano",
    "lituanos": "lituano",
    "lituras": "litura",
    "liturgias": "liturgia",
    "liturgistas": "liturgista",
    "liturgos": "liturgo",
    "lituânica": "lituânico",
    "lituânicas": "lituânico",
    "lituânicos": "lituânico",
    "litá": "litar",
    "litámo": "litar",
    "litámos": "litar",
    "litáramo": "litar",
    "litáramos": "litar",
    "litárei": "litar",
    "litáreis": "litar",
    "litásseis": "litar",
    "litássemos": "litar",
    "litávamo": "litar",
    "litávamos": "litar",
    "litávei": "litar",
    "litáveis": "litar",
    "litíases": "litíase",
    "litígios": "litígio",
    "litínica": "litínico",
    "litínicas": "litínico",
    "litínicos": "litínico",
    "litóclases": "litóclase",
    "litófaga": "litófago",
    "litófagas": "litófago",
    "litófagos": "litófago",
    "litófila": "litófilo",
    "litófilas": "litófilo",
    "litófilos": "litófilo",
    "litófitos": "litófito",
    "litóglifa": "litóglifo",
    "litóglifas": "litóglifo",
    "litóglifos": "litóglifo",
    "litógrafa": "litógrafo",
    "litógrafas": "litógrafo",
    "litógrafos": "litógrafo",
    "litóides": "litóide",
    "litólatras": "litólatra",
    "litóloga": "litólogo",
    "litólogas": "litólogo",
    "litólogos": "litólogo",
    "litórea": "litóreo",
    "litóreas": "litóreo",
    "litóreos": "litóreo",
    "litótomos": "litótomo",
    "litótopos": "litótopo",
    "litões": "litão",
    "litúrgica": "litúrgico",
    "litúrgicas": "litúrgico",
    "litúrgicos": "litúrgico",
    "livedos": "livedo",
    "liveis": "livel",
    "lividesce": "lividescer",
    "lividescei": "lividescer",
    "lividesceis": "lividescer",
    "lividescem": "lividescer",
    "lividescemo": "lividescer",
    "lividescemos": "lividescer",
    "lividescendo": "lividescer",
    "lividescera": "lividescer",
    "lividesceram": "lividescer",
    "lividesceras": "lividescer",
    "lividescerde": "lividescer",
    "lividescerdes": "lividescer",
    "lividescere": "lividescer",
    "lividescerei": "lividescer",
    "lividescereis": "lividescer",
    "lividescerem": "lividescer",
    "lividesceremos": "lividescer",
    "lividesceres": "lividescer",
    "lividesceria": "lividescer",
    "lividesceriam": "lividescer",
    "lividescerias": "lividescer",
    "lividescermo": "lividescer",
    "lividescermos": "lividescer",
    "lividescerá": "lividescer",
    "lividescerás": "lividescer",
    "lividescerão": "lividescer",
    "lividesceríamos": "lividescer",
    "lividesceríeis": "lividescer",
    "lividesces": "lividescer",
    "lividescesse": "lividescer",
    "lividescessem": "lividescer",
    "lividescesses": "lividescer",
    "lividesceste": "lividescer",
    "lividescestes": "lividescer",
    "lividesceu": "lividescer",
    "lividesci": "lividescer",
    "lividescia": "lividescer",
    "lividesciam": "lividescer",
    "lividescias": "lividescer",
    "lividescida": "lividescer",
    "lividescidas": "lividescer",
    "lividescido": "lividescer",
    "lividescidos": "lividescer",
    "lividescê": "lividescer",
    "lividescêramo": "lividescer",
    "lividescêramos": "lividescer",
    "lividescêrei": "lividescer",
    "lividescêreis": "lividescer",
    "lividescêsseis": "lividescer",
    "lividescêssemos": "lividescer",
    "lividescíamo": "lividescer",
    "lividescíamos": "lividescer",
    "lividescíei": "lividescer",
    "lividescíeis": "lividescer",
    "lividesça": "lividescer",
    "lividesçais": "lividescer",
    "lividesçam": "lividescer",
    "lividesçamo": "lividescer",
    "lividesçamos": "lividescer",
    "lividesças": "lividescer",
    "lividesço": "lividescer",
    "livilhos": "livilho",
    "livings": "living",
    "livoniana": "livoniano",
    "livonianas": "livoniano",
    "livonianos": "livoniano",
    "livonica": "livonico",
    "livonicas": "livonico",
    "livonicos": "livonico",
    "livores": "livor",
    "livra": "livrar",
    "livrada": "livrar",
    "livradas": "livrar",
    "livrado": "livrar",
    "livradora": "livrador",
    "livradoras": "livrador",
    "livradores": "livrador",
    "livrados": "livrar",
    "livrai": "livrar",
    "livrais": "livrar",
    "livralhadas": "livralhada",
    "livram": "livrar",
    "livramentos": "livramento",
    "livramo": "livrar",
    "livramos": "livrar",
    "livrando": "livrar",
    "livranças": "livrança",
    "livrara": "livrar",
    "livraram": "livrar",
    "livraras": "livrar",
    "livrarde": "livrar",
    "livrardes": "livrar",
    "livrare": "livrar",
    "livrarei": "livrar",
    "livrareis": "livrar",
    "livrarem": "livrar",
    "livraremos": "livrar",
    "livrares": "livrar",
    "livraria": "livrar",
    "livrariam": "livrar",
    "livrarias": "livraria",
    "livrarmo": "livrar",
    "livrarmos": "livrar",
    "livrará": "livrar",
    "livrarás": "livrar",
    "livrarão": "livrar",
    "livraríamos": "livrar",
    "livraríeis": "livrar",
    "livras": "livrar",
    "livrasse": "livrar",
    "livrassem": "livrar",
    "livrasses": "livrar",
    "livraste": "livrar",
    "livrastes": "livrar",
    "livrava": "livrar",
    "livravam": "livrar",
    "livravas": "livrar",
    "livrações": "livração",
    "livre": "livrar",
    "livrecos": "livreco",
    "livrei": "livrar",
    "livreira": "livreiro",
    "livreiras": "livreiro",
    "livreiros": "livreiro",
    "livreis": "livrar",
    "livrem": "livrar",
    "livremo": "livrar",
    "livremos": "livrar",
    "livres": "livre",
    "livresca": "livresco",
    "livrescas": "livresco",
    "livrescos": "livresco",
    "livretes": "livrete",
    "livrilhos": "livrilho",
    "livrinho": "livro",
    "livrinhos": "livro",
    "livrito": "livro",
    "livritos": "livro",
    "livro": "livrar",
    "livros": "livro",
    "livrou": "livrar",
    "livroxadas": "livroxada",
    "livrá": "livrar",
    "livrámo": "livrar",
    "livrámos": "livrar",
    "livráramo": "livrar",
    "livráramos": "livrar",
    "livrárei": "livrar",
    "livráreis": "livrar",
    "livrásseis": "livrar",
    "livrássemos": "livrar",
    "livrávamo": "livrar",
    "livrávamos": "livrar",
    "livrávei": "livrar",
    "livráveis": "livrar",
    "livrórios": "livrório",
    "livónia": "livónio",
    "livónias": "livónio",
    "livónicos": "livónico",
    "livónios": "livónio",
    "lixa": "lixar",
    "lixada": "lixar",
    "lixadas": "lixar",
    "lixadeiras": "lixadeira",
    "lixadelas": "lixadela",
    "lixado": "lixar",
    "lixadora": "lixador",
    "lixadoras": "lixador",
    "lixadores": "lixador",
    "lixados": "lixar",
    "lixadíssima": "lixado",
    "lixadíssimas": "lixado",
    "lixadíssimo": "lixado",
    "lixadíssimos": "lixado",
    "lixai": "lixar",
    "lixais": "lixar",
    "lixam": "lixar",
    "lixamentos": "lixamento",
    "lixamo": "lixar",
    "lixamos": "lixar",
    "lixando": "lixar",
    "lixanços": "lixanço",
    "lixara": "lixar",
    "lixaram": "lixar",
    "lixaras": "lixar",
    "lixarde": "lixar",
    "lixardes": "lixar",
    "lixare": "lixar",
    "lixarei": "lixar",
    "lixareis": "lixar",
    "lixarem": "lixar",
    "lixaremos": "lixar",
    "lixares": "lixar",
    "lixaria": "lixar",
    "lixariam": "lixar",
    "lixarias": "lixar",
    "lixarmo": "lixar",
    "lixarmos": "lixar",
    "lixará": "lixar",
    "lixarás": "lixar",
    "lixarão": "lixar",
    "lixaríamos": "lixar",
    "lixaríeis": "lixar",
    "lixas": "lixar",
    "lixasse": "lixar",
    "lixassem": "lixar",
    "lixasses": "lixar",
    "lixaste": "lixar",
    "lixastes": "lixar",
    "lixava": "lixar",
    "lixavam": "lixar",
    "lixavas": "lixar",
    "lixações": "lixação",
    "lixe": "lixar",
    "lixei": "lixar",
    "lixeira": "lixeiro",
    "lixeiras": "lixeiro",
    "lixeiros": "lixeiro",
    "lixeis": "lixar",
    "lixem": "lixar",
    "lixemo": "lixar",
    "lixemos": "lixar",
    "lixenta": "lixento",
    "lixentas": "lixento",
    "lixentos": "lixento",
    "lixes": "lixar",
    "lixivia": "lixiviar",
    "lixiviada": "lixiviar",
    "lixiviadas": "lixiviar",
    "lixiviado": "lixiviar",
    "lixiviadores": "lixiviador",
    "lixiviados": "lixiviar",
    "lixiviai": "lixiviar",
    "lixiviais": "lixiviar",
    "lixiviam": "lixiviar",
    "lixiviamo": "lixiviar",
    "lixiviamos": "lixiviar",
    "lixiviando": "lixiviar",
    "lixiviara": "lixiviar",
    "lixiviaram": "lixiviar",
    "lixiviaras": "lixiviar",
    "lixiviarde": "lixiviar",
    "lixiviardes": "lixiviar",
    "lixiviare": "lixiviar",
    "lixiviarei": "lixiviar",
    "lixiviareis": "lixiviar",
    "lixiviarem": "lixiviar",
    "lixiviaremos": "lixiviar",
    "lixiviares": "lixiviar",
    "lixiviaria": "lixiviar",
    "lixiviariam": "lixiviar",
    "lixiviarias": "lixiviar",
    "lixiviarmo": "lixiviar",
    "lixiviarmos": "lixiviar",
    "lixiviará": "lixiviar",
    "lixiviarás": "lixiviar",
    "lixiviarão": "lixiviar",
    "lixiviaríamos": "lixiviar",
    "lixiviaríeis": "lixiviar",
    "lixivias": "lixiviar",
    "lixiviasse": "lixiviar",
    "lixiviassem": "lixiviar",
    "lixiviasses": "lixiviar",
    "lixiviaste": "lixiviar",
    "lixiviastes": "lixiviar",
    "lixiviava": "lixiviar",
    "lixiviavam": "lixiviar",
    "lixiviavas": "lixiviar",
    "lixiviações": "lixiviação",
    "lixivie": "lixiviar",
    "lixiviei": "lixiviar",
    "lixivieis": "lixiviar",
    "lixiviem": "lixiviar",
    "lixiviemo": "lixiviar",
    "lixiviemos": "lixiviar",
    "lixivies": "lixiviar",
    "lixivio": "lixiviar",
    "lixiviosa": "lixivioso",
    "lixiviosas": "lixivioso",
    "lixiviosos": "lixivioso",
    "lixiviou": "lixiviar",
    "lixiviá": "lixiviar",
    "lixiviámo": "lixiviar",
    "lixiviámos": "lixiviar",
    "lixiviáramo": "lixiviar",
    "lixiviáramos": "lixiviar",
    "lixiviárei": "lixiviar",
    "lixiviáreis": "lixiviar",
    "lixiviásseis": "lixiviar",
    "lixiviássemos": "lixiviar",
    "lixiviávamo": "lixiviar",
    "lixiviávamos": "lixiviar",
    "lixiviávei": "lixiviar",
    "lixiviáveis": "lixiviar",
    "lixo": "lixar",
    "lixos": "lixo",
    "lixosa": "lixoso",
    "lixosas": "lixoso",
    "lixosos": "lixoso",
    "lixou": "lixar",
    "lixá": "lixar",
    "lixámo": "lixar",
    "lixámos": "lixar",
    "lixáramo": "lixar",
    "lixáramos": "lixar",
    "lixárei": "lixar",
    "lixáreis": "lixar",
    "lixásseis": "lixar",
    "lixássemos": "lixar",
    "lixávamo": "lixar",
    "lixávamos": "lixar",
    "lixávei": "lixar",
    "lixáveis": "lixável",
    "lixívias": "lixívia",
    "liza": "lizar",
    "lizada": "lizar",
    "lizadas": "lizar",
    "lizado": "lizar",
    "lizados": "lizar",
    "lizai": "lizar",
    "lizais": "lizar",
    "lizam": "lizar",
    "lizamo": "lizar",
    "lizamos": "lizar",
    "lizando": "lizar",
    "lizara": "lizar",
    "lizaram": "lizar",
    "lizaras": "lizar",
    "lizarde": "lizar",
    "lizardes": "lizar",
    "lizare": "lizar",
    "lizarei": "lizar",
    "lizareis": "lizar",
    "lizarem": "lizar",
    "lizaremos": "lizar",
    "lizares": "lizar",
    "lizaria": "lizar",
    "lizariam": "lizar",
    "lizarias": "lizar",
    "lizarmo": "lizar",
    "lizarmos": "lizar",
    "lizará": "lizar",
    "lizarás": "lizar",
    "lizarão": "lizar",
    "lizaríamos": "lizar",
    "lizaríeis": "lizar",
    "lizas": "lizar",
    "lizasse": "lizar",
    "lizassem": "lizar",
    "lizasses": "lizar",
    "lizaste": "lizar",
    "lizastes": "lizar",
    "lizava": "lizar",
    "lizavam": "lizar",
    "lizavas": "lizar",
    "lize": "lizar",
    "lizei": "lizar",
    "lizeis": "lizar",
    "lizem": "lizar",
    "lizemo": "lizar",
    "lizemos": "lizar",
    "lizes": "lizar",
    "lizo": "lizar",
    "lizou": "lizar",
    "lizá": "lizar",
    "lizámo": "lizar",
    "lizámos": "lizar",
    "lizáramo": "lizar",
    "lizáramos": "lizar",
    "lizárei": "lizar",
    "lizáreis": "lizar",
    "lizásseis": "lizar",
    "lizássemos": "lizar",
    "lizávamo": "lizar",
    "lizávamos": "lizar",
    "lizávei": "lizar",
    "lizáveis": "lizar",
    "liá": "liar",
    "liámo": "liar",
    "liámos": "liar",
    "liáramo": "liar",
    "liáramos": "liar",
    "liárei": "liar",
    "liáreis": "liar",
    "liásica": "liásico",
    "liásicas": "liásico",
    "liásicos": "liásico",
    "liásseis": "liar",
    "liássemos": "liar",
    "liávamo": "liar",
    "liávamos": "liar",
    "liávei": "liar",
    "liáveis": "liar",
    "liçaróis": "liçarol",
    "liças": "liça",
    "liços": "liço",
    "lições": "lição",
    "liócoma": "liócomo",
    "liócomas": "liócomo",
    "liócomos": "liócomo",
    "liótrica": "liótrico",
    "liótricas": "liótrico",
    "liótricos": "liótrico",
    "ll": "l",
    "lo": "o",
    "loas": "loa",
    "loasáceas": "loasácea",
    "loba": "lobo",
    "lobachos": "lobacho",
    "lobados": "lobado",
    "lobagantes": "lobagante",
    "lobais": "lobal",
    "lobas": "lobo",
    "lobata": "lobato",
    "lobatas": "lobato",
    "lobatos": "lobato",
    "lobazes": "lobaz",
    "lobbies": "lobby",
    "lobectomias": "lobectomia",
    "lobecões": "lobecão",
    "lobegantes": "lobegante",
    "lobegões": "lobegão",
    "lobeira": "lobeiro",
    "lobeiras": "lobeiro",
    "lobeiros": "lobeiro",
    "lobelinas": "lobelina",
    "lobeliáceas": "lobeliácea",
    "lobetes": "lobete",
    "lobetos": "lobeto",
    "lobinha": "lobo",
    "lobinhas": "lobo",
    "lobinho": "lobo",
    "lobinhos": "lobo",
    "lobisomens": "lobisomem",
    "lobistas": "lobista",
    "lobita": "lobo",
    "lobitas": "lobo",
    "lobito": "lobo",
    "lobitos": "lobo",
    "lobona": "lobão",
    "lobonas": "lobão",
    "lobos": "lobo",
    "lobotomias": "lobotomia",
    "lobrega": "lobregar",
    "lobregada": "lobregar",
    "lobregadas": "lobregar",
    "lobregado": "lobregar",
    "lobregados": "lobregar",
    "lobregai": "lobregar",
    "lobregais": "lobregar",
    "lobregam": "lobregar",
    "lobregamo": "lobregar",
    "lobregamos": "lobregar",
    "lobregando": "lobregar",
    "lobregara": "lobregar",
    "lobregaram": "lobregar",
    "lobregaras": "lobregar",
    "lobregarde": "lobregar",
    "lobregardes": "lobregar",
    "lobregare": "lobregar",
    "lobregarei": "lobregar",
    "lobregareis": "lobregar",
    "lobregarem": "lobregar",
    "lobregaremos": "lobregar",
    "lobregares": "lobregar",
    "lobregaria": "lobregar",
    "lobregariam": "lobregar",
    "lobregarias": "lobregar",
    "lobregarmo": "lobregar",
    "lobregarmos": "lobregar",
    "lobregará": "lobregar",
    "lobregarás": "lobregar",
    "lobregarão": "lobregar",
    "lobregaríamos": "lobregar",
    "lobregaríeis": "lobregar",
    "lobregas": "lobregar",
    "lobregasse": "lobregar",
    "lobregassem": "lobregar",
    "lobregasses": "lobregar",
    "lobregaste": "lobregar",
    "lobregastes": "lobregar",
    "lobregava": "lobregar",
    "lobregavam": "lobregar",
    "lobregavas": "lobregar",
    "lobrego": "lobregar",
    "lobregou": "lobregar",
    "lobregue": "lobregar",
    "lobreguei": "lobregar",
    "lobregueis": "lobregar",
    "lobreguem": "lobregar",
    "lobreguemo": "lobregar",
    "lobreguemos": "lobregar",
    "lobregues": "lobregar",
    "lobreguidões": "lobreguidão",
    "lobregá": "lobregar",
    "lobregámo": "lobregar",
    "lobregámos": "lobregar",
    "lobregáramo": "lobregar",
    "lobregáramos": "lobregar",
    "lobregárei": "lobregar",
    "lobregáreis": "lobregar",
    "lobregásseis": "lobregar",
    "lobregássemos": "lobregar",
    "lobregávamo": "lobregar",
    "lobregávamos": "lobregar",
    "lobregávei": "lobregar",
    "lobregáveis": "lobregar",
    "lobriga": "lobrigar",
    "lobrigada": "lobrigar",
    "lobrigadas": "lobrigar",
    "lobrigado": "lobrigar",
    "lobrigadora": "lobrigador",
    "lobrigadoras": "lobrigador",
    "lobrigadores": "lobrigador",
    "lobrigados": "lobrigar",
    "lobrigai": "lobrigar",
    "lobrigais": "lobrigar",
    "lobrigam": "lobrigar",
    "lobrigamo": "lobrigar",
    "lobrigamos": "lobrigar",
    "lobrigando": "lobrigar",
    "lobrigara": "lobrigar",
    "lobrigaram": "lobrigar",
    "lobrigaras": "lobrigar",
    "lobrigarde": "lobrigar",
    "lobrigardes": "lobrigar",
    "lobrigare": "lobrigar",
    "lobrigarei": "lobrigar",
    "lobrigareis": "lobrigar",
    "lobrigarem": "lobrigar",
    "lobrigaremos": "lobrigar",
    "lobrigares": "lobrigar",
    "lobrigaria": "lobrigar",
    "lobrigariam": "lobrigar",
    "lobrigarias": "lobrigar",
    "lobrigarmo": "lobrigar",
    "lobrigarmos": "lobrigar",
    "lobrigará": "lobrigar",
    "lobrigarás": "lobrigar",
    "lobrigarão": "lobrigar",
    "lobrigaríamos": "lobrigar",
    "lobrigaríeis": "lobrigar",
    "lobrigas": "lobrigar",
    "lobrigasse": "lobrigar",
    "lobrigassem": "lobrigar",
    "lobrigasses": "lobrigar",
    "lobrigaste": "lobrigar",
    "lobrigastes": "lobrigar",
    "lobrigava": "lobrigar",
    "lobrigavam": "lobrigar",
    "lobrigavas": "lobrigar",
    "lobrigo": "lobrigar",
    "lobrigou": "lobrigar",
    "lobrigue": "lobrigar",
    "lobriguei": "lobrigar",
    "lobrigueis": "lobrigar",
    "lobriguem": "lobrigar",
    "lobriguemo": "lobrigar",
    "lobriguemos": "lobrigar",
    "lobrigues": "lobrigar",
    "lobrigá": "lobrigar",
    "lobrigámo": "lobrigar",
    "lobrigámos": "lobrigar",
    "lobrigáramo": "lobrigar",
    "lobrigáramos": "lobrigar",
    "lobrigárei": "lobrigar",
    "lobrigáreis": "lobrigar",
    "lobrigásseis": "lobrigar",
    "lobrigássemos": "lobrigar",
    "lobrigávamo": "lobrigar",
    "lobrigávamos": "lobrigar",
    "lobrigávei": "lobrigar",
    "lobrigáveis": "lobrigável",
    "lobulada": "lobulado",
    "lobuladas": "lobulado",
    "lobulados": "lobulado",
    "lobulares": "lobular",
    "lobulações": "lobulação",
    "lobulosa": "lobuloso",
    "lobulosas": "lobuloso",
    "lobulosos": "lobuloso",
    "lobélias": "lobélia",
    "lobélios": "lobélio",
    "lobões": "lobão",
    "loca": "locar",
    "locada": "locar",
    "locadas": "locar",
    "locado": "locar",
    "locadora": "locador",
    "locadoras": "locador",
    "locadores": "locador",
    "locados": "locar",
    "locagos": "locago",
    "locai": "locar",
    "locaias": "locaia",
    "locais": "locar",
    "localidades": "localidade",
    "localismos": "localismo",
    "localistas": "localista",
    "localiza": "localizar",
    "localizada": "localizar",
    "localizadas": "localizar",
    "localizado": "localizar",
    "localizados": "localizar",
    "localizai": "localizar",
    "localizais": "localizar",
    "localizam": "localizar",
    "localizamo": "localizar",
    "localizamos": "localizar",
    "localizando": "localizar",
    "localizara": "localizar",
    "localizaram": "localizar",
    "localizaras": "localizar",
    "localizarde": "localizar",
    "localizardes": "localizar",
    "localizare": "localizar",
    "localizarei": "localizar",
    "localizareis": "localizar",
    "localizarem": "localizar",
    "localizaremos": "localizar",
    "localizares": "localizar",
    "localizaria": "localizar",
    "localizariam": "localizar",
    "localizarias": "localizar",
    "localizarmo": "localizar",
    "localizarmos": "localizar",
    "localizará": "localizar",
    "localizarás": "localizar",
    "localizarão": "localizar",
    "localizaríamos": "localizar",
    "localizaríeis": "localizar",
    "localizas": "localizar",
    "localizasse": "localizar",
    "localizassem": "localizar",
    "localizasses": "localizar",
    "localizaste": "localizar",
    "localizastes": "localizar",
    "localizava": "localizar",
    "localizavam": "localizar",
    "localizavas": "localizar",
    "localizações": "localização",
    "localize": "localizar",
    "localizei": "localizar",
    "localizeis": "localizar",
    "localizem": "localizar",
    "localizemo": "localizar",
    "localizemos": "localizar",
    "localizes": "localizar",
    "localizo": "localizar",
    "localizou": "localizar",
    "localizá": "localizar",
    "localizámo": "localizar",
    "localizámos": "localizar",
    "localizáramo": "localizar",
    "localizáramos": "localizar",
    "localizárei": "localizar",
    "localizáreis": "localizar",
    "localizásseis": "localizar",
    "localizássemos": "localizar",
    "localizávamo": "localizar",
    "localizávamos": "localizar",
    "localizávei": "localizar",
    "localizáveis": "localizável",
    "locam": "locar",
    "locamo": "locar",
    "locamos": "locar",
    "locandas": "locanda",
    "locandeira": "locandeiro",
    "locandeiras": "locandeiro",
    "locandeiros": "locandeiro",
    "locando": "locar",
    "locara": "locar",
    "locaram": "locar",
    "locaras": "locar",
    "locarde": "locar",
    "locardes": "locar",
    "locare": "locar",
    "locarei": "locar",
    "locareis": "locar",
    "locarem": "locar",
    "locaremos": "locar",
    "locares": "locar",
    "locaria": "locar",
    "locariam": "locar",
    "locarias": "locar",
    "locarmo": "locar",
    "locarmos": "locar",
    "locará": "locar",
    "locarás": "locar",
    "locarão": "locar",
    "locaríamos": "locar",
    "locaríeis": "locar",
    "locas": "locar",
    "locasse": "locar",
    "locassem": "locar",
    "locasses": "locar",
    "locaste": "locar",
    "locastes": "locar",
    "locativa": "locativo",
    "locativas": "locativo",
    "locativos": "locativo",
    "locatária": "locatário",
    "locatárias": "locatário",
    "locatários": "locatário",
    "locava": "locar",
    "locavam": "locar",
    "locavas": "locar",
    "locações": "locação",
    "lociona": "locionar",
    "locionada": "locionar",
    "locionadas": "locionar",
    "locionado": "locionar",
    "locionados": "locionar",
    "locionai": "locionar",
    "locionais": "locionar",
    "locionam": "locionar",
    "locionamo": "locionar",
    "locionamos": "locionar",
    "locionando": "locionar",
    "locionara": "locionar",
    "locionaram": "locionar",
    "locionaras": "locionar",
    "locionarde": "locionar",
    "locionardes": "locionar",
    "locionare": "locionar",
    "locionarei": "locionar",
    "locionareis": "locionar",
    "locionarem": "locionar",
    "locionaremos": "locionar",
    "locionares": "locionar",
    "locionaria": "locionar",
    "locionariam": "locionar",
    "locionarias": "locionar",
    "locionarmo": "locionar",
    "locionarmos": "locionar",
    "locionará": "locionar",
    "locionarás": "locionar",
    "locionarão": "locionar",
    "locionaríamos": "locionar",
    "locionaríeis": "locionar",
    "locionas": "locionar",
    "locionasse": "locionar",
    "locionassem": "locionar",
    "locionasses": "locionar",
    "locionaste": "locionar",
    "locionastes": "locionar",
    "locionava": "locionar",
    "locionavam": "locionar",
    "locionavas": "locionar",
    "locione": "locionar",
    "locionei": "locionar",
    "locioneis": "locionar",
    "locionem": "locionar",
    "locionemo": "locionar",
    "locionemos": "locionar",
    "lociones": "locionar",
    "lociono": "locionar",
    "locionou": "locionar",
    "locioná": "locionar",
    "locionámo": "locionar",
    "locionámos": "locionar",
    "locionáramo": "locionar",
    "locionáramos": "locionar",
    "locionárei": "locionar",
    "locionáreis": "locionar",
    "locionásseis": "locionar",
    "locionássemos": "locionar",
    "locionávamo": "locionar",
    "locionávamos": "locionar",
    "locionávei": "locionar",
    "locionáveis": "locionar",
    "loco": "locar",
    "locomobilidades": "locomobilidade",
    "locomotiva": "locomotivo",
    "locomotivas": "locomotivo",
    "locomotividades": "locomotividade",
    "locomotivos": "locomotivo",
    "locomotora": "locomotor",
    "locomotoras": "locomotor",
    "locomotores": "locomotor",
    "locomotriz": "locomotor",
    "locomotrizes": "locomotor",
    "locomova": "locomover",
    "locomovais": "locomover",
    "locomovam": "locomover",
    "locomovamo": "locomover",
    "locomovamos": "locomover",
    "locomovas": "locomover",
    "locomove": "locomover",
    "locomovei": "locomover",
    "locomoveis": "locomover",
    "locomovem": "locomover",
    "locomovemo": "locomover",
    "locomovemos": "locomover",
    "locomovendo": "locomover",
    "locomovera": "locomover",
    "locomoveram": "locomover",
    "locomoveras": "locomover",
    "locomoverde": "locomover",
    "locomoverdes": "locomover",
    "locomovere": "locomover",
    "locomoverei": "locomover",
    "locomovereis": "locomover",
    "locomoverem": "locomover",
    "locomoveremos": "locomover",
    "locomoveres": "locomover",
    "locomoveria": "locomover",
    "locomoveriam": "locomover",
    "locomoverias": "locomover",
    "locomovermo": "locomover",
    "locomovermos": "locomover",
    "locomoverá": "locomover",
    "locomoverás": "locomover",
    "locomoverão": "locomover",
    "locomoveríamos": "locomover",
    "locomoveríeis": "locomover",
    "locomoves": "locomover",
    "locomovesse": "locomover",
    "locomovessem": "locomover",
    "locomovesses": "locomover",
    "locomoveste": "locomover",
    "locomovestes": "locomover",
    "locomoveu": "locomover",
    "locomovi": "locomover",
    "locomovia": "locomover",
    "locomoviam": "locomover",
    "locomovias": "locomover",
    "locomovida": "locomover",
    "locomovidas": "locomover",
    "locomovido": "locomover",
    "locomovidos": "locomover",
    "locomovo": "locomover",
    "locomovê": "locomover",
    "locomovêramo": "locomover",
    "locomovêramos": "locomover",
    "locomovêrei": "locomover",
    "locomovêreis": "locomover",
    "locomovêsseis": "locomover",
    "locomovêssemos": "locomover",
    "locomovíamo": "locomover",
    "locomovíamos": "locomover",
    "locomovíei": "locomover",
    "locomovíeis": "locomover",
    "locomoções": "locomoção",
    "locomóveis": "locomóvel",
    "locos": "loco",
    "locou": "locar",
    "loculada": "loculado",
    "loculadas": "loculado",
    "loculados": "loculado",
    "loculamentos": "loculamento",
    "loculares": "locular",
    "loculicidas": "loculicida",
    "loculosa": "loculoso",
    "loculosas": "loculoso",
    "loculosos": "loculoso",
    "locuplamentos": "locuplamento",
    "locuplações": "locuplação",
    "locupleta": "locupletar",
    "locupletada": "locupletar",
    "locupletadas": "locupletar",
    "locupletado": "locupletar",
    "locupletados": "locupletar",
    "locupletai": "locupletar",
    "locupletais": "locupletar",
    "locupletam": "locupletar",
    "locupletamo": "locupletar",
    "locupletamos": "locupletar",
    "locupletando": "locupletar",
    "locupletara": "locupletar",
    "locupletaram": "locupletar",
    "locupletaras": "locupletar",
    "locupletarde": "locupletar",
    "locupletardes": "locupletar",
    "locupletare": "locupletar",
    "locupletarei": "locupletar",
    "locupletareis": "locupletar",
    "locupletarem": "locupletar",
    "locupletaremos": "locupletar",
    "locupletares": "locupletar",
    "locupletaria": "locupletar",
    "locupletariam": "locupletar",
    "locupletarias": "locupletar",
    "locupletarmo": "locupletar",
    "locupletarmos": "locupletar",
    "locupletará": "locupletar",
    "locupletarás": "locupletar",
    "locupletarão": "locupletar",
    "locupletaríamos": "locupletar",
    "locupletaríeis": "locupletar",
    "locupletas": "locupletar",
    "locupletasse": "locupletar",
    "locupletassem": "locupletar",
    "locupletasses": "locupletar",
    "locupletaste": "locupletar",
    "locupletastes": "locupletar",
    "locupletava": "locupletar",
    "locupletavam": "locupletar",
    "locupletavas": "locupletar",
    "locuplete": "locupletar",
    "locupletei": "locupletar",
    "locupleteis": "locupletar",
    "locupletem": "locupletar",
    "locupletemo": "locupletar",
    "locupletemos": "locupletar",
    "locupletes": "locupletar",
    "locupleto": "locupletar",
    "locupletou": "locupletar",
    "locupletá": "locupletar",
    "locupletámo": "locupletar",
    "locupletámos": "locupletar",
    "locupletáramo": "locupletar",
    "locupletáramos": "locupletar",
    "locupletárei": "locupletar",
    "locupletáreis": "locupletar",
    "locupletásseis": "locupletar",
    "locupletássemos": "locupletar",
    "locupletávamo": "locupletar",
    "locupletávamos": "locupletar",
    "locupletávei": "locupletar",
    "locupletáveis": "locupletar",
    "locustídeos": "locustídeo",
    "locutora": "locutor",
    "locutoras": "locutor",
    "locutores": "locutor",
    "locutórios": "locutório",
    "locuções": "locução",
    "locá": "locar",
    "locámo": "locar",
    "locámos": "locar",
    "locáramo": "locar",
    "locáramos": "locar",
    "locárei": "locar",
    "locáreis": "locar",
    "locásseis": "locar",
    "locássemos": "locar",
    "locávamo": "locar",
    "locávamos": "locar",
    "locávei": "locar",
    "locáveis": "locar",
    "locústidas": "locústida",
    "lodacenta": "lodacento",
    "lodacentas": "lodacento",
    "lodacentos": "lodacento",
    "lodaçais": "lodaçal",
    "lodeiras": "lodeira",
    "lodeiros": "lodeiro",
    "lodos": "lodo",
    "lodosa": "lodoso",
    "lodosas": "lodoso",
    "lodosos": "lodoso",
    "lodículas": "lodícula",
    "loendrais": "loendral",
    "loendreiras": "loendreira",
    "loendros": "loendro",
    "loesses": "loesse",
    "loessitos": "loessito",
    "loesss": "loess",
    "loestes": "loeste",
    "lofobrânquios": "lofobrânquio",
    "lofodontes": "lofodonte",
    "lofócoma": "lofócomo",
    "lofócomas": "lofócomo",
    "lofócomos": "lofócomo",
    "lofóforos": "lofóforo",
    "lofópodes": "lofópode",
    "logadectomias": "logadectomia",
    "loganiáceas": "loganiácea",
    "logaritmações": "logaritmação",
    "logaritmos": "logaritmo",
    "logarítmica": "logarítmico",
    "logarítmicas": "logarítmico",
    "logarítmicos": "logarítmico",
    "logastenias": "logastenia",
    "logaédica": "logaédico",
    "logaédicas": "logaédico",
    "logaédicos": "logaédico",
    "logicismos": "logicismo",
    "logoclonias": "logoclonia",
    "logofobias": "logofobia",
    "logografias": "logografia",
    "logogrifos": "logogrifo",
    "logogrífica": "logogrífico",
    "logogríficas": "logogrífico",
    "logogríficos": "logogrífico",
    "logomaniaca": "logomaniaco",
    "logomaniacas": "logomaniaco",
    "logomaniacos": "logomaniaco",
    "logomanias": "logomania",
    "logomaquias": "logomaquia",
    "logomarcas": "logomarca",
    "logopedias": "logopedia",
    "logopedistas": "logopedista",
    "logorreias": "logorreia",
    "logos": "logo",
    "logosofias": "logosofia",
    "logotecnias": "logotecnia",
    "logotipias": "logotipia",
    "logotipos": "logotipo",
    "logotécnica": "logotécnico",
    "logotécnicas": "logotécnico",
    "logotécnicos": "logotécnico",
    "logra": "lograr",
    "lograda": "lograr",
    "logradas": "lograr",
    "logradeira": "logrador",
    "logradeiras": "logrador",
    "logrado": "lograr",
    "logradoiros": "logradoiro",
    "logradores": "logrador",
    "logrados": "lograr",
    "logradouros": "logradouro",
    "lograi": "lograr",
    "lograis": "lograr",
    "logram": "lograr",
    "logramentos": "logramento",
    "logramo": "lograr",
    "logramos": "lograr",
    "logrando": "lograr",
    "lograra": "lograr",
    "lograram": "lograr",
    "lograras": "lograr",
    "lograrde": "lograr",
    "logrardes": "lograr",
    "lograre": "lograr",
    "lograrei": "lograr",
    "lograreis": "lograr",
    "lograrem": "lograr",
    "lograremos": "lograr",
    "lograres": "lograr",
    "lograria": "lograr",
    "lograriam": "lograr",
    "lograrias": "lograr",
    "lograrmo": "lograr",
    "lograrmos": "lograr",
    "logrará": "lograr",
    "lograrás": "lograr",
    "lograrão": "lograr",
    "lograríamos": "lograr",
    "lograríeis": "lograr",
    "logras": "lograr",
    "lograsse": "lograr",
    "lograssem": "lograr",
    "lograsses": "lograr",
    "lograste": "lograr",
    "lograstes": "lograr",
    "logrativa": "logrativo",
    "logrativas": "logrativo",
    "logrativos": "logrativo",
    "lograva": "lograr",
    "logravam": "lograr",
    "logravas": "lograr",
    "lograções": "logração",
    "logre": "lograr",
    "logrei": "lograr",
    "logreira": "logreiro",
    "logreiras": "logreiro",
    "logreiros": "logreiro",
    "logreis": "lograr",
    "logrem": "lograr",
    "logremo": "lograr",
    "logremos": "lograr",
    "logres": "lograr",
    "logro": "lograr",
    "logrona": "logrão",
    "logronas": "logrão",
    "logros": "logro",
    "logrou": "lograr",
    "lográ": "lograr",
    "lográmo": "lograr",
    "lográmos": "lograr",
    "lográramo": "lograr",
    "lográramos": "lograr",
    "lográrei": "lograr",
    "lográreis": "lograr",
    "lográsseis": "lograr",
    "lográssemos": "lograr",
    "lográvamo": "lograr",
    "lográvamos": "lograr",
    "lográvei": "lograr",
    "lográveis": "logrável",
    "logrões": "logrão",
    "logudoresa": "logudorês",
    "logudoresas": "logudorês",
    "logudoreses": "logudorês",
    "loguinho": "logo",
    "logística": "logístico",
    "logísticas": "logístico",
    "logísticos": "logístico",
    "logógrafa": "logógrafo",
    "logógrafas": "logógrafo",
    "logógrafos": "logógrafo",
    "logósofa": "logósofo",
    "logósofas": "logósofo",
    "logósofos": "logósofo",
    "loiceira": "loiceiro",
    "loiceiras": "loiceiro",
    "loiceiros": "loiceiro",
    "loira": "loiro",
    "loirada": "loirar",
    "loiradas": "loirar",
    "loirado": "loirar",
    "loirados": "loirar",
    "loirai": "loirar",
    "loirais": "loirar",
    "loiram": "loirar",
    "loiramo": "loirar",
    "loiramos": "loirar",
    "loirando": "loirar",
    "loirara": "loirar",
    "loiraram": "loirar",
    "loiraras": "loirar",
    "loirardes": "loirar",
    "loirarei": "loirar",
    "loirareis": "loirar",
    "loirarem": "loirar",
    "loiraremos": "loirar",
    "loirares": "loirar",
    "loiraria": "loirar",
    "loirariam": "loirar",
    "loirarias": "loirar",
    "loirarmo": "loirar",
    "loirarmos": "loirar",
    "loirará": "loirar",
    "loirarás": "loirar",
    "loirarão": "loirar",
    "loiraríamos": "loirar",
    "loiraríeis": "loirar",
    "loiras": "loiro",
    "loirasse": "loirar",
    "loirassem": "loirar",
    "loirasses": "loirar",
    "loiraste": "loirar",
    "loirastes": "loirar",
    "loirava": "loirar",
    "loiravam": "loirar",
    "loiravas": "loirar",
    "loiraça": "loiro",
    "loiraças": "loiro",
    "loiraço": "loiro",
    "loiraços": "loiro",
    "loire": "loirar",
    "loirei": "loirar",
    "loireirais": "loireiral",
    "loireiras": "loireira",
    "loireiros": "loireiro",
    "loireis": "loirar",
    "loireja": "loirejar",
    "loirejada": "loirejar",
    "loirejadas": "loirejar",
    "loirejado": "loirejar",
    "loirejados": "loirejar",
    "loirejai": "loirejar",
    "loirejais": "loirejar",
    "loirejam": "loirejar",
    "loirejamo": "loirejar",
    "loirejamos": "loirejar",
    "loirejando": "loirejar",
    "loirejantes": "loirejante",
    "loirejara": "loirejar",
    "loirejaram": "loirejar",
    "loirejaras": "loirejar",
    "loirejardes": "loirejar",
    "loirejarei": "loirejar",
    "loirejareis": "loirejar",
    "loirejarem": "loirejar",
    "loirejaremos": "loirejar",
    "loirejares": "loirejar",
    "loirejaria": "loirejar",
    "loirejariam": "loirejar",
    "loirejarias": "loirejar",
    "loirejarmo": "loirejar",
    "loirejarmos": "loirejar",
    "loirejará": "loirejar",
    "loirejarás": "loirejar",
    "loirejarão": "loirejar",
    "loirejaríamos": "loirejar",
    "loirejaríeis": "loirejar",
    "loirejas": "loirejar",
    "loirejasse": "loirejar",
    "loirejassem": "loirejar",
    "loirejasses": "loirejar",
    "loirejaste": "loirejar",
    "loirejastes": "loirejar",
    "loirejava": "loirejar",
    "loirejavam": "loirejar",
    "loirejavas": "loirejar",
    "loireje": "loirejar",
    "loirejei": "loirejar",
    "loirejeis": "loirejar",
    "loirejem": "loirejar",
    "loirejemo": "loirejar",
    "loirejemos": "loirejar",
    "loirejes": "loirejar",
    "loirejo": "loirejar",
    "loirejou": "loirejar",
    "loirejámo": "loirejar",
    "loirejámos": "loirejar",
    "loirejáramo": "loirejar",
    "loirejáramos": "loirejar",
    "loirejáreis": "loirejar",
    "loirejásseis": "loirejar",
    "loirejássemos": "loirejar",
    "loirejávamo": "loirejar",
    "loirejávamos": "loirejar",
    "loirejáveis": "loirejar",
    "loirem": "loirar",
    "loiremo": "loirar",
    "loiremos": "loirar",
    "loires": "loirar",
    "loirinha": "loiro",
    "loirinhas": "loiro",
    "loirinho": "loiro",
    "loirinhos": "loiro",
    "loirita": "loiro",
    "loiritas": "loiro",
    "loirito": "loiro",
    "loiritos": "loiro",
    "loiro": "loirar",
    "loiros": "loiro",
    "loirou": "loirar",
    "loirámo": "loirar",
    "loirámos": "loirar",
    "loiráramo": "loirar",
    "loiráramos": "loirar",
    "loiráreis": "loirar",
    "loirásseis": "loirar",
    "loirássemos": "loirar",
    "loirávamo": "loirar",
    "loirávamos": "loirar",
    "loiráveis": "loirar",
    "loiríssima": "loiro",
    "loiríssimas": "loiro",
    "loiríssimo": "loiro",
    "loiríssimos": "loiro",
    "loisas": "loisa",
    "loiseira": "loiseiro",
    "loiseiras": "loiseiro",
    "loiseiros": "loiseiro",
    "loisífera": "loisífero",
    "loisíferas": "loisífero",
    "loisíferos": "loisífero",
    "loisões": "loisão",
    "loiçarias": "loiçaria",
    "loiças": "loiça",
    "lojas": "loja",
    "lojecas": "lojeca",
    "lojinha": "loja",
    "lojinhas": "loja",
    "lojistas": "lojista",
    "lojita": "loja",
    "lojitas": "loja",
    "loliginídeos": "loliginídeo",
    "loligínidas": "loligínida",
    "lombadas": "lombada",
    "lombais": "lombal",
    "lombalgias": "lombalgia",
    "lombarda": "lombardo",
    "lombardas": "lombardo",
    "lombardeira": "lombardeiro",
    "lombardeiras": "lombardeiro",
    "lombardeiros": "lombardeiro",
    "lombardina": "lombardino",
    "lombardinas": "lombardino",
    "lombardinos": "lombardino",
    "lombardos": "lombardo",
    "lombares": "lombar",
    "lombas": "lomba",
    "lombeira": "lombeiro",
    "lombeiras": "lombeiro",
    "lombeiros": "lombeiro",
    "lombelos": "lombelo",
    "lombinho": "lombo",
    "lombinhos": "lombo",
    "lombito": "lombo",
    "lombitos": "lombo",
    "lombocostais": "lombocostal",
    "lombos": "lombo",
    "lombricais": "lombrical",
    "lombricóides": "lombricóide",
    "lombrigas": "lombriga",
    "lombrigueiras": "lombrigueira",
    "lombumerais": "lombumeral",
    "lomdresa": "lomdrês",
    "lomdresas": "lomdrês",
    "lomdreses": "lomdrês",
    "lomentos": "lomento",
    "lomentácea": "lomentáceo",
    "lomentáceas": "lomentáceo",
    "lomentáceos": "lomentáceo",
    "lonas": "lona",
    "loncas": "lonca",
    "londrina": "londrino",
    "londrinas": "londrino",
    "londrinos": "londrino",
    "longa": "longo",
    "longadas": "longada",
    "longais": "longal",
    "longanas": "longana",
    "longanimidades": "longanimidade",
    "longarinas": "longarina",
    "longarinos": "longarino",
    "longas": "longo",
    "longerões": "longerão",
    "longeva": "longevo",
    "longevas": "longevo",
    "longevidades": "longevidade",
    "longevos": "longevo",
    "longicaules": "longicaule",
    "longicórnea": "longicórneo",
    "longicórneas": "longicórneo",
    "longicórneos": "longicórneo",
    "longilobada": "longilobado",
    "longilobadas": "longilobado",
    "longilobados": "longilobado",
    "longimetrias": "longimetria",
    "longinho": "longe",
    "longinquidades": "longinquidade",
    "longipenes": "longipene",
    "longipétala": "longipétalo",
    "longipétalas": "longipétalo",
    "longipétalos": "longipétalo",
    "longirrostra": "longirrostro",
    "longirrostras": "longirrostro",
    "longirrostros": "longirrostro",
    "longitarsa": "longitarso",
    "longitarsas": "longitarso",
    "longitarsos": "longitarso",
    "longito": "longe",
    "longitroantes": "longitroante",
    "longitudes": "longitude",
    "longitudinais": "longitudinal",
    "longores": "longor",
    "longos": "longo",
    "longrinas": "longrina",
    "longueira": "longueiro",
    "longueiras": "longueiro",
    "longueiros": "longueiro",
    "longueirões": "longueirão",
    "longuezas": "longueza",
    "longuidões": "longuidão",
    "longuras": "longura",
    "longuíssima": "longo",
    "longuíssimas": "longo",
    "longuíssimo": "longo",
    "longuíssimos": "longo",
    "longânima": "longânimo",
    "longânimas": "longânimo",
    "longânimes": "longânime",
    "longânimos": "longânimo",
    "longínqua": "longínquo",
    "longínquas": "longínquo",
    "longínquos": "longínquo",
    "longípedes": "longípede",
    "longíssimo": "longe",
    "loniceráceas": "lonicerácea",
    "lonitas": "lonita",
    "lonjuras": "lonjura",
    "lonqueada": "lonquear",
    "lonqueadas": "lonquear",
    "lonqueado": "lonquear",
    "lonqueados": "lonquear",
    "lonqueai": "lonquear",
    "lonqueais": "lonquear",
    "lonqueamo": "lonquear",
    "lonqueamos": "lonquear",
    "lonqueando": "lonquear",
    "lonqueara": "lonquear",
    "lonquearam": "lonquear",
    "lonquearas": "lonquear",
    "lonquearde": "lonquear",
    "lonqueardes": "lonquear",
    "lonqueare": "lonquear",
    "lonquearei": "lonquear",
    "lonqueareis": "lonquear",
    "lonquearem": "lonquear",
    "lonquearemos": "lonquear",
    "lonqueares": "lonquear",
    "lonquearia": "lonquear",
    "lonqueariam": "lonquear",
    "lonquearias": "lonquear",
    "lonquearmo": "lonquear",
    "lonquearmos": "lonquear",
    "lonqueará": "lonquear",
    "lonquearás": "lonquear",
    "lonquearão": "lonquear",
    "lonquearíamos": "lonquear",
    "lonquearíeis": "lonquear",
    "lonqueasse": "lonquear",
    "lonqueassem": "lonquear",
    "lonqueasses": "lonquear",
    "lonqueaste": "lonquear",
    "lonqueastes": "lonquear",
    "lonqueava": "lonquear",
    "lonqueavam": "lonquear",
    "lonqueavas": "lonquear",
    "lonqueei": "lonquear",
    "lonqueeis": "lonquear",
    "lonqueemo": "lonquear",
    "lonqueemos": "lonquear",
    "lonqueia": "lonquear",
    "lonqueiam": "lonquear",
    "lonqueias": "lonquear",
    "lonqueie": "lonquear",
    "lonqueiem": "lonquear",
    "lonqueies": "lonquear",
    "lonqueio": "lonquear",
    "lonqueou": "lonquear",
    "lonqueá": "lonquear",
    "lonqueámo": "lonquear",
    "lonqueámos": "lonquear",
    "lonqueáramo": "lonquear",
    "lonqueáramos": "lonquear",
    "lonqueárei": "lonquear",
    "lonqueáreis": "lonquear",
    "lonqueásseis": "lonquear",
    "lonqueássemos": "lonquear",
    "lonqueávamo": "lonquear",
    "lonqueávamos": "lonquear",
    "lonqueávei": "lonquear",
    "lonqueáveis": "lonquear",
    "lontras": "lontra",
    "lontros": "lontro",
    "lonímana": "lonímano",
    "lonímanas": "lonímano",
    "lonímanos": "lonímano",
    "loops": "loop",
    "loquacidades": "loquacidade",
    "loquazes": "loquaz",
    "loque": "locar",
    "loquei": "locar",
    "loqueis": "locar",
    "loquelas": "loquela",
    "loquem": "locar",
    "loquemo": "locar",
    "loquemos": "locar",
    "loques": "loque",
    "loquetes": "loquete",
    "loquiometrias": "loquiometria",
    "loquiorragias": "loquiorragia",
    "lorantáceas": "lorantácea",
    "loras": "lora",
    "lorcas": "lorca",
    "lorchas": "lorcha",
    "lordes": "lorde",
    "lordoses": "lordose",
    "lords": "lord",
    "lorena": "loreno",
    "lorenas": "loreno",
    "lorenos": "loreno",
    "lorgas": "lorga",
    "loricados": "loricado",
    "lorigada": "lorigado",
    "lorigadas": "lorigado",
    "lorigados": "lorigado",
    "lorigas": "loriga",
    "lorigões": "lorigão",
    "lornhões": "lornhão",
    "loroiês": "loroiê",
    "loros": "loro",
    "lorpas": "lorpa",
    "lorpices": "lorpice",
    "lorquiana": "lorquiano",
    "lorquianas": "lorquiano",
    "lorquianos": "lorquiano",
    "los": "o",
    "losangos": "losango",
    "losnas": "losna",
    "lostras": "lostra",
    "lota": "lotar",
    "lotada": "lotar",
    "lotadas": "lotar",
    "lotado": "lotar",
    "lotadora": "lotador",
    "lotadoras": "lotador",
    "lotadores": "lotador",
    "lotados": "lotar",
    "lotai": "lotar",
    "lotais": "lotar",
    "lotam": "lotar",
    "lotamo": "lotar",
    "lotamos": "lotar",
    "lotando": "lotar",
    "lotara": "lotar",
    "lotaram": "lotar",
    "lotaras": "lotar",
    "lotarde": "lotar",
    "lotardes": "lotar",
    "lotare": "lotar",
    "lotarei": "lotar",
    "lotareis": "lotar",
    "lotarem": "lotar",
    "lotaremos": "lotar",
    "lotares": "lotar",
    "lotaria": "lotar",
    "lotariam": "lotar",
    "lotarias": "lotaria",
    "lotaringianos": "lotaringiano",
    "lotarmo": "lotar",
    "lotarmos": "lotar",
    "lotará": "lotar",
    "lotarás": "lotar",
    "lotarão": "lotar",
    "lotaríamos": "lotar",
    "lotaríeis": "lotar",
    "lotas": "lotar",
    "lotasse": "lotar",
    "lotassem": "lotar",
    "lotasses": "lotar",
    "lotaste": "lotar",
    "lotastes": "lotar",
    "lotava": "lotar",
    "lotavam": "lotar",
    "lotavas": "lotar",
    "lotações": "lotação",
    "lote": "lotar",
    "loteada": "lotear",
    "loteadas": "lotear",
    "loteado": "lotear",
    "loteados": "lotear",
    "loteai": "lotear",
    "loteais": "lotear",
    "loteamentos": "loteamento",
    "loteamo": "lotear",
    "loteamos": "lotear",
    "loteando": "lotear",
    "loteara": "lotear",
    "lotearam": "lotear",
    "lotearas": "lotear",
    "lotearde": "lotear",
    "loteardes": "lotear",
    "loteare": "lotear",
    "lotearei": "lotear",
    "loteareis": "lotear",
    "lotearem": "lotear",
    "lotearemos": "lotear",
    "loteares": "lotear",
    "lotearia": "lotear",
    "loteariam": "lotear",
    "lotearias": "lotear",
    "lotearmo": "lotear",
    "lotearmos": "lotear",
    "loteará": "lotear",
    "lotearás": "lotear",
    "lotearão": "lotear",
    "lotearíamos": "lotear",
    "lotearíeis": "lotear",
    "loteasse": "lotear",
    "loteassem": "lotear",
    "loteasses": "lotear",
    "loteaste": "lotear",
    "loteastes": "lotear",
    "loteava": "lotear",
    "loteavam": "lotear",
    "loteavas": "lotear",
    "loteei": "lotear",
    "loteeis": "lotear",
    "loteemo": "lotear",
    "loteemos": "lotear",
    "lotei": "lotar",
    "loteia": "lotear",
    "loteiam": "lotear",
    "loteias": "lotear",
    "loteie": "lotear",
    "loteiem": "lotear",
    "loteies": "lotear",
    "loteio": "lotear",
    "loteis": "lotar",
    "lotem": "lotar",
    "lotemo": "lotar",
    "lotemos": "lotar",
    "loteou": "lotear",
    "loterias": "loteria",
    "lotes": "lote",
    "loteá": "lotear",
    "loteámo": "lotear",
    "loteámos": "lotear",
    "loteáramo": "lotear",
    "loteáramos": "lotear",
    "loteárei": "lotear",
    "loteáreis": "lotear",
    "loteásseis": "lotear",
    "loteássemos": "lotear",
    "loteávamo": "lotear",
    "loteávamos": "lotear",
    "loteávei": "lotear",
    "loteáveis": "loteável",
    "loto": "lotar",
    "lotos": "loto",
    "lotou": "lotar",
    "lotá": "lotar",
    "lotámo": "lotar",
    "lotámos": "lotar",
    "lotáramo": "lotar",
    "lotáramos": "lotar",
    "lotárei": "lotar",
    "lotáreis": "lotar",
    "lotásseis": "lotar",
    "lotássemos": "lotar",
    "lotávamo": "lotar",
    "lotávamos": "lotar",
    "lotávei": "lotar",
    "lotáveis": "lotar",
    "lotófaga": "lotófago",
    "lotófagas": "lotófago",
    "lotófagos": "lotófago",
    "louca": "louco",
    "loucas": "louco",
    "louceira": "louceiro",
    "louceiras": "louceiro",
    "louceiros": "louceiro",
    "loucos": "louco",
    "loucuras": "loucura",
    "loudéis": "loudel",
    "louletana": "louletano",
    "louletanas": "louletano",
    "louletanos": "louletano",
    "louqueja": "louquejar",
    "louquejada": "louquejar",
    "louquejadas": "louquejar",
    "louquejado": "louquejar",
    "louquejados": "louquejar",
    "louquejai": "louquejar",
    "louquejais": "louquejar",
    "louquejam": "louquejar",
    "louquejamo": "louquejar",
    "louquejamos": "louquejar",
    "louquejando": "louquejar",
    "louquejara": "louquejar",
    "louquejaram": "louquejar",
    "louquejaras": "louquejar",
    "louquejardes": "louquejar",
    "louquejarei": "louquejar",
    "louquejareis": "louquejar",
    "louquejarem": "louquejar",
    "louquejaremos": "louquejar",
    "louquejares": "louquejar",
    "louquejaria": "louquejar",
    "louquejariam": "louquejar",
    "louquejarias": "louquejar",
    "louquejarmo": "louquejar",
    "louquejarmos": "louquejar",
    "louquejará": "louquejar",
    "louquejarás": "louquejar",
    "louquejarão": "louquejar",
    "louquejaríamos": "louquejar",
    "louquejaríeis": "louquejar",
    "louquejas": "louquejar",
    "louquejasse": "louquejar",
    "louquejassem": "louquejar",
    "louquejasses": "louquejar",
    "louquejaste": "louquejar",
    "louquejastes": "louquejar",
    "louquejava": "louquejar",
    "louquejavam": "louquejar",
    "louquejavas": "louquejar",
    "louqueje": "louquejar",
    "louquejei": "louquejar",
    "louquejeis": "louquejar",
    "louquejem": "louquejar",
    "louquejemo": "louquejar",
    "louquejemos": "louquejar",
    "louquejes": "louquejar",
    "louquejo": "louquejar",
    "louquejou": "louquejar",
    "louquejámo": "louquejar",
    "louquejámos": "louquejar",
    "louquejáramo": "louquejar",
    "louquejáramos": "louquejar",
    "louquejáreis": "louquejar",
    "louquejásseis": "louquejar",
    "louquejássemos": "louquejar",
    "louquejávamo": "louquejar",
    "louquejávamos": "louquejar",
    "louquejáveis": "louquejar",
    "louquices": "louquice",
    "loura": "louro",
    "lourada": "lourar",
    "louradas": "lourar",
    "lourado": "lourar",
    "lourados": "lourar",
    "lourai": "lourar",
    "lourais": "lourar",
    "louram": "lourar",
    "louramo": "lourar",
    "louramos": "lourar",
    "lourando": "lourar",
    "lourara": "lourar",
    "louraram": "lourar",
    "louraras": "lourar",
    "lourardes": "lourar",
    "lourarei": "lourar",
    "lourareis": "lourar",
    "lourarem": "lourar",
    "louraremos": "lourar",
    "lourares": "lourar",
    "louraria": "lourar",
    "lourariam": "lourar",
    "lourarias": "lourar",
    "lourarmo": "lourar",
    "lourarmos": "lourar",
    "lourará": "lourar",
    "lourarás": "lourar",
    "lourarão": "lourar",
    "louraríamos": "lourar",
    "louraríeis": "lourar",
    "louras": "louro",
    "lourasse": "lourar",
    "lourassem": "lourar",
    "lourasses": "lourar",
    "louraste": "lourar",
    "lourastes": "lourar",
    "lourava": "lourar",
    "louravam": "lourar",
    "louravas": "lourar",
    "louraça": "louro",
    "louraças": "louro",
    "louraço": "louro",
    "louraços": "louro",
    "loure": "lourar",
    "lourece": "lourecer",
    "lourecei": "lourecer",
    "loureceis": "lourecer",
    "lourecem": "lourecer",
    "lourecemo": "lourecer",
    "lourecemos": "lourecer",
    "lourecendo": "lourecer",
    "lourecera": "lourecer",
    "loureceram": "lourecer",
    "loureceras": "lourecer",
    "lourecerdes": "lourecer",
    "lourecerei": "lourecer",
    "lourecereis": "lourecer",
    "lourecerem": "lourecer",
    "loureceremos": "lourecer",
    "loureceres": "lourecer",
    "loureceria": "lourecer",
    "loureceriam": "lourecer",
    "lourecerias": "lourecer",
    "lourecermo": "lourecer",
    "lourecermos": "lourecer",
    "lourecerá": "lourecer",
    "lourecerás": "lourecer",
    "lourecerão": "lourecer",
    "loureceríamos": "lourecer",
    "loureceríeis": "lourecer",
    "loureces": "lourecer",
    "lourecesse": "lourecer",
    "lourecessem": "lourecer",
    "lourecesses": "lourecer",
    "loureceste": "lourecer",
    "lourecestes": "lourecer",
    "loureceu": "lourecer",
    "loureci": "lourecer",
    "lourecia": "lourecer",
    "loureciam": "lourecer",
    "lourecias": "lourecer",
    "lourecida": "lourecer",
    "lourecidas": "lourecer",
    "lourecido": "lourecer",
    "lourecidos": "lourecer",
    "lourecêramo": "lourecer",
    "lourecêramos": "lourecer",
    "lourecêreis": "lourecer",
    "lourecêsseis": "lourecer",
    "lourecêssemos": "lourecer",
    "lourecíamo": "lourecer",
    "lourecíamos": "lourecer",
    "lourecíeis": "lourecer",
    "lourei": "lourar",
    "loureirais": "loureiral",
    "loureiras": "loureira",
    "loureiros": "loureiro",
    "loureis": "lourar",
    "loureja": "lourejar",
    "lourejada": "lourejar",
    "lourejadas": "lourejar",
    "lourejado": "lourejar",
    "lourejados": "lourejar",
    "lourejai": "lourejar",
    "lourejais": "lourejar",
    "lourejam": "lourejar",
    "lourejamo": "lourejar",
    "lourejamos": "lourejar",
    "lourejando": "lourejar",
    "lourejantes": "lourejante",
    "lourejara": "lourejar",
    "lourejaram": "lourejar",
    "lourejaras": "lourejar",
    "lourejardes": "lourejar",
    "lourejarei": "lourejar",
    "lourejareis": "lourejar",
    "lourejarem": "lourejar",
    "lourejaremos": "lourejar",
    "lourejares": "lourejar",
    "lourejaria": "lourejar",
    "lourejariam": "lourejar",
    "lourejarias": "lourejar",
    "lourejarmo": "lourejar",
    "lourejarmos": "lourejar",
    "lourejará": "lourejar",
    "lourejarás": "lourejar",
    "lourejarão": "lourejar",
    "lourejaríamos": "lourejar",
    "lourejaríeis": "lourejar",
    "lourejas": "lourejar",
    "lourejasse": "lourejar",
    "lourejassem": "lourejar",
    "lourejasses": "lourejar",
    "lourejaste": "lourejar",
    "lourejastes": "lourejar",
    "lourejava": "lourejar",
    "lourejavam": "lourejar",
    "lourejavas": "lourejar",
    "loureje": "lourejar",
    "lourejei": "lourejar",
    "lourejeis": "lourejar",
    "lourejem": "lourejar",
    "lourejemo": "lourejar",
    "lourejemos": "lourejar",
    "lourejes": "lourejar",
    "lourejo": "lourejar",
    "lourejos": "lourejo",
    "lourejou": "lourejar",
    "lourejámo": "lourejar",
    "lourejámos": "lourejar",
    "lourejáramo": "lourejar",
    "lourejáramos": "lourejar",
    "lourejáreis": "lourejar",
    "lourejásseis": "lourejar",
    "lourejássemos": "lourejar",
    "lourejávamo": "lourejar",
    "lourejávamos": "lourejar",
    "lourejáveis": "lourejar",
    "lourem": "lourar",
    "louremo": "lourar",
    "louremos": "lourar",
    "loures": "lourar",
    "loureça": "lourecer",
    "loureçais": "lourecer",
    "loureçam": "lourecer",
    "loureçamo": "lourecer",
    "loureçamos": "lourecer",
    "loureças": "lourecer",
    "loureço": "lourecer",
    "louridões": "louridão",
    "lourinha": "louro",
    "lourinhas": "louro",
    "lourinho": "louro",
    "lourinhos": "louro",
    "lourita": "louro",
    "louritas": "louro",
    "lourito": "louro",
    "louritos": "louro",
    "louro": "lourar",
    "louros": "louro",
    "lourou": "lourar",
    "lourámo": "lourar",
    "lourámos": "lourar",
    "louráramo": "lourar",
    "louráramos": "lourar",
    "louráreis": "lourar",
    "lourásseis": "lourar",
    "lourássemos": "lourar",
    "lourávamo": "lourar",
    "lourávamos": "lourar",
    "louráveis": "lourar",
    "louríssima": "louro",
    "louríssimas": "louro",
    "louríssimo": "louro",
    "louríssimos": "louro",
    "lousas": "lousa",
    "louseira": "louseiro",
    "louseiras": "louseiro",
    "louseiros": "louseiro",
    "lousífera": "lousífero",
    "lousíferas": "lousífero",
    "lousíferos": "lousífero",
    "lousões": "lousão",
    "louva": "louvar",
    "louvabilidades": "louvabilidade",
    "louvada": "louvar",
    "louvadas": "louvar",
    "louvado": "louvar",
    "louvadora": "louvador",
    "louvadoras": "louvador",
    "louvadores": "louvador",
    "louvados": "louvar",
    "louvai": "louvar",
    "louvais": "louvar",
    "louvam": "louvar",
    "louvamentos": "louvamento",
    "louvaminha": "louvaminhar",
    "louvaminhada": "louvaminhar",
    "louvaminhadas": "louvaminhar",
    "louvaminhado": "louvaminhar",
    "louvaminhados": "louvaminhar",
    "louvaminhai": "louvaminhar",
    "louvaminhais": "louvaminhar",
    "louvaminham": "louvaminhar",
    "louvaminhamo": "louvaminhar",
    "louvaminhamos": "louvaminhar",
    "louvaminhando": "louvaminhar",
    "louvaminhara": "louvaminhar",
    "louvaminharam": "louvaminhar",
    "louvaminharas": "louvaminhar",
    "louvaminharde": "louvaminhar",
    "louvaminhardes": "louvaminhar",
    "louvaminhare": "louvaminhar",
    "louvaminharei": "louvaminhar",
    "louvaminhareis": "louvaminhar",
    "louvaminharem": "louvaminhar",
    "louvaminharemos": "louvaminhar",
    "louvaminhares": "louvaminhar",
    "louvaminharia": "louvaminhar",
    "louvaminhariam": "louvaminhar",
    "louvaminharias": "louvaminhar",
    "louvaminharmo": "louvaminhar",
    "louvaminharmos": "louvaminhar",
    "louvaminhará": "louvaminhar",
    "louvaminharás": "louvaminhar",
    "louvaminharão": "louvaminhar",
    "louvaminharíamos": "louvaminhar",
    "louvaminharíeis": "louvaminhar",
    "louvaminhas": "louvaminhar",
    "louvaminhasse": "louvaminhar",
    "louvaminhassem": "louvaminhar",
    "louvaminhasses": "louvaminhar",
    "louvaminhaste": "louvaminhar",
    "louvaminhastes": "louvaminhar",
    "louvaminhava": "louvaminhar",
    "louvaminhavam": "louvaminhar",
    "louvaminhavas": "louvaminhar",
    "louvaminhe": "louvaminhar",
    "louvaminhei": "louvaminhar",
    "louvaminheira": "louvaminheiro",
    "louvaminheiras": "louvaminheiro",
    "louvaminheiros": "louvaminheiro",
    "louvaminheis": "louvaminhar",
    "louvaminhem": "louvaminhar",
    "louvaminhemo": "louvaminhar",
    "louvaminhemos": "louvaminhar",
    "louvaminhes": "louvaminhar",
    "louvaminhices": "louvaminhice",
    "louvaminho": "louvaminhar",
    "louvaminhou": "louvaminhar",
    "louvaminhá": "louvaminhar",
    "louvaminhámo": "louvaminhar",
    "louvaminhámos": "louvaminhar",
    "louvaminháramo": "louvaminhar",
    "louvaminháramos": "louvaminhar",
    "louvaminhárei": "louvaminhar",
    "louvaminháreis": "louvaminhar",
    "louvaminhásseis": "louvaminhar",
    "louvaminhássemos": "louvaminhar",
    "louvaminhávamo": "louvaminhar",
    "louvaminhávamos": "louvaminhar",
    "louvaminhávei": "louvaminhar",
    "louvaminháveis": "louvaminhar",
    "louvamo": "louvar",
    "louvamos": "louvar",
    "louvando": "louvar",
    "louvara": "louvar",
    "louvaram": "louvar",
    "louvaras": "louvar",
    "louvarde": "louvar",
    "louvardes": "louvar",
    "louvare": "louvar",
    "louvarei": "louvar",
    "louvareis": "louvar",
    "louvarem": "louvar",
    "louvaremos": "louvar",
    "louvares": "louvar",
    "louvaria": "louvar",
    "louvariam": "louvar",
    "louvarias": "louvar",
    "louvarmo": "louvar",
    "louvarmos": "louvar",
    "louvará": "louvar",
    "louvarás": "louvar",
    "louvarão": "louvar",
    "louvaríamos": "louvar",
    "louvaríeis": "louvar",
    "louvas": "louvar",
    "louvasse": "louvar",
    "louvassem": "louvar",
    "louvasses": "louvar",
    "louvaste": "louvar",
    "louvastes": "louvar",
    "louvava": "louvar",
    "louvavam": "louvar",
    "louvavas": "louvar",
    "louvações": "louvação",
    "louve": "louvar",
    "louvei": "louvar",
    "louveis": "louvar",
    "louvem": "louvar",
    "louvemo": "louvar",
    "louvemos": "louvar",
    "louves": "louvar",
    "louvo": "louvar",
    "louvores": "louvor",
    "louvou": "louvar",
    "louvá": "louvar",
    "louvámo": "louvar",
    "louvámos": "louvar",
    "louváramo": "louvar",
    "louváramos": "louvar",
    "louvárei": "louvar",
    "louváreis": "louvar",
    "louvásseis": "louvar",
    "louvássemos": "louvar",
    "louvávamo": "louvar",
    "louvávamos": "louvar",
    "louvávei": "louvar",
    "louváveis": "louvável",
    "louçainha": "louçainho",
    "louçainhada": "louçainhar",
    "louçainhadas": "louçainhar",
    "louçainhado": "louçainhar",
    "louçainhados": "louçainhar",
    "louçainhai": "louçainhar",
    "louçainhais": "louçainhar",
    "louçainham": "louçainhar",
    "louçainhamo": "louçainhar",
    "louçainhamos": "louçainhar",
    "louçainhando": "louçainhar",
    "louçainhar": "ainhar",
    "louçainhara": "louçainhar",
    "louçainharam": "louçainhar",
    "louçainharas": "louçainhar",
    "louçainharde": "louçainhar",
    "louçainhardes": "louçainhar",
    "louçainhare": "louçainhar",
    "louçainharei": "louçainhar",
    "louçainhareis": "louçainhar",
    "louçainharem": "louçainhar",
    "louçainharemos": "louçainhar",
    "louçainhares": "louçainhar",
    "louçainharia": "louçainhar",
    "louçainhariam": "louçainhar",
    "louçainharias": "louçainhar",
    "louçainharmo": "louçainhar",
    "louçainharmos": "louçainhar",
    "louçainhará": "louçainhar",
    "louçainharás": "louçainhar",
    "louçainharão": "louçainhar",
    "louçainharíamos": "louçainhar",
    "louçainharíeis": "louçainhar",
    "louçainhas": "louçainho",
    "louçainhasse": "louçainhar",
    "louçainhassem": "louçainhar",
    "louçainhasses": "louçainhar",
    "louçainhaste": "louçainhar",
    "louçainhastes": "louçainhar",
    "louçainhava": "louçainhar",
    "louçainhavam": "louçainhar",
    "louçainhavas": "louçainhar",
    "louçainhe": "louçainhar",
    "louçainhei": "louçainhar",
    "louçainheis": "louçainhar",
    "louçainhem": "louçainhar",
    "louçainhemo": "louçainhar",
    "louçainhemos": "louçainhar",
    "louçainhes": "louçainhar",
    "louçainho": "louçainhar",
    "louçainhos": "louçainho",
    "louçainhou": "louçainhar",
    "louçainhá": "louçainhar",
    "louçainhámo": "louçainhar",
    "louçainhámos": "louçainhar",
    "louçainháramo": "louçainhar",
    "louçainháramos": "louçainhar",
    "louçainhárei": "louçainhar",
    "louçainháreis": "louçainhar",
    "louçainhásseis": "louçainhar",
    "louçainhássemos": "louçainhar",
    "louçainhávamo": "louçainhar",
    "louçainhávamos": "louçainhar",
    "louçainhávei": "louçainhar",
    "louçainháveis": "louçainhar",
    "louçanias": "louçania",
    "louçarias": "louçaria",
    "louças": "louça",
    "louçã": "loução",
    "louçãos": "loução",
    "louçãs": "loução",
    "lovelaces": "lovelace",
    "loxodromias": "loxodromia",
    "loxodromismos": "loxodromismo",
    "loxodrómica": "loxodrómico",
    "loxodrómicas": "loxodrómico",
    "loxodrómicos": "loxodrómico",
    "loxsomáceas": "loxsomácea",
    "loyolas": "loyola",
    "loções": "loção",
    "luadas": "luada",
    "luandenses": "luandense",
    "luandos": "luando",
    "luareja": "luarejar",
    "luarejada": "luarejar",
    "luarejadas": "luarejar",
    "luarejado": "luarejar",
    "luarejados": "luarejar",
    "luarejai": "luarejar",
    "luarejais": "luarejar",
    "luarejam": "luarejar",
    "luarejamo": "luarejar",
    "luarejamos": "luarejar",
    "luarejando": "luarejar",
    "luarejara": "luarejar",
    "luarejaram": "luarejar",
    "luarejaras": "luarejar",
    "luarejarde": "luarejar",
    "luarejardes": "luarejar",
    "luarejare": "luarejar",
    "luarejarei": "luarejar",
    "luarejareis": "luarejar",
    "luarejarem": "luarejar",
    "luarejaremos": "luarejar",
    "luarejares": "luarejar",
    "luarejaria": "luarejar",
    "luarejariam": "luarejar",
    "luarejarias": "luarejar",
    "luarejarmo": "luarejar",
    "luarejarmos": "luarejar",
    "luarejará": "luarejar",
    "luarejarás": "luarejar",
    "luarejarão": "luarejar",
    "luarejaríamos": "luarejar",
    "luarejaríeis": "luarejar",
    "luarejas": "luarejar",
    "luarejasse": "luarejar",
    "luarejassem": "luarejar",
    "luarejasses": "luarejar",
    "luarejaste": "luarejar",
    "luarejastes": "luarejar",
    "luarejava": "luarejar",
    "luarejavam": "luarejar",
    "luarejavas": "luarejar",
    "luareje": "luarejar",
    "luarejei": "luarejar",
    "luarejeis": "luarejar",
    "luarejem": "luarejar",
    "luarejemo": "luarejar",
    "luarejemos": "luarejar",
    "luarejes": "luarejar",
    "luarejo": "luarejar",
    "luarejou": "luarejar",
    "luarejá": "luarejar",
    "luarejámo": "luarejar",
    "luarejámos": "luarejar",
    "luarejáramo": "luarejar",
    "luarejáramos": "luarejar",
    "luarejárei": "luarejar",
    "luarejáreis": "luarejar",
    "luarejásseis": "luarejar",
    "luarejássemos": "luarejar",
    "luarejávamo": "luarejar",
    "luarejávamos": "luarejar",
    "luarejávei": "luarejar",
    "luarejáveis": "luarejar",
    "luarenta": "luarento",
    "luarentas": "luarento",
    "luarentos": "luarento",
    "luares": "luar",
    "luariza": "luarizar",
    "luarizada": "luarizar",
    "luarizadas": "luarizar",
    "luarizado": "luarizar",
    "luarizados": "luarizar",
    "luarizai": "luarizar",
    "luarizais": "luarizar",
    "luarizam": "luarizar",
    "luarizamo": "luarizar",
    "luarizamos": "luarizar",
    "luarizando": "luarizar",
    "luarizara": "luarizar",
    "luarizaram": "luarizar",
    "luarizaras": "luarizar",
    "luarizarde": "luarizar",
    "luarizardes": "luarizar",
    "luarizare": "luarizar",
    "luarizarei": "luarizar",
    "luarizareis": "luarizar",
    "luarizarem": "luarizar",
    "luarizaremos": "luarizar",
    "luarizares": "luarizar",
    "luarizaria": "luarizar",
    "luarizariam": "luarizar",
    "luarizarias": "luarizar",
    "luarizarmo": "luarizar",
    "luarizarmos": "luarizar",
    "luarizará": "luarizar",
    "luarizarás": "luarizar",
    "luarizarão": "luarizar",
    "luarizaríamos": "luarizar",
    "luarizaríeis": "luarizar",
    "luarizas": "luarizar",
    "luarizasse": "luarizar",
    "luarizassem": "luarizar",
    "luarizasses": "luarizar",
    "luarizaste": "luarizar",
    "luarizastes": "luarizar",
    "luarizava": "luarizar",
    "luarizavam": "luarizar",
    "luarizavas": "luarizar",
    "luarize": "luarizar",
    "luarizei": "luarizar",
    "luarizeis": "luarizar",
    "luarizem": "luarizar",
    "luarizemo": "luarizar",
    "luarizemos": "luarizar",
    "luarizes": "luarizar",
    "luarizo": "luarizar",
    "luarizou": "luarizar",
    "luarizá": "luarizar",
    "luarizámo": "luarizar",
    "luarizámos": "luarizar",
    "luarizáramo": "luarizar",
    "luarizáramos": "luarizar",
    "luarizárei": "luarizar",
    "luarizáreis": "luarizar",
    "luarizásseis": "luarizar",
    "luarizássemos": "luarizar",
    "luarizávamo": "luarizar",
    "luarizávamos": "luarizar",
    "luarizávei": "luarizar",
    "luarizáveis": "luarizar",
    "luas": "lua",
    "lubrica": "lubricar",
    "lubricada": "lubricar",
    "lubricadas": "lubricar",
    "lubricado": "lubricar",
    "lubricados": "lubricar",
    "lubricai": "lubricar",
    "lubricais": "lubricar",
    "lubricam": "lubricar",
    "lubricamo": "lubricar",
    "lubricamos": "lubricar",
    "lubricando": "lubricar",
    "lubricara": "lubricar",
    "lubricaram": "lubricar",
    "lubricaras": "lubricar",
    "lubricarde": "lubricar",
    "lubricardes": "lubricar",
    "lubricare": "lubricar",
    "lubricarei": "lubricar",
    "lubricareis": "lubricar",
    "lubricarem": "lubricar",
    "lubricaremos": "lubricar",
    "lubricares": "lubricar",
    "lubricaria": "lubricar",
    "lubricariam": "lubricar",
    "lubricarias": "lubricar",
    "lubricarmo": "lubricar",
    "lubricarmos": "lubricar",
    "lubricará": "lubricar",
    "lubricarás": "lubricar",
    "lubricarão": "lubricar",
    "lubricaríamos": "lubricar",
    "lubricaríeis": "lubricar",
    "lubricas": "lubricar",
    "lubricasse": "lubricar",
    "lubricassem": "lubricar",
    "lubricasses": "lubricar",
    "lubricaste": "lubricar",
    "lubricastes": "lubricar",
    "lubricava": "lubricar",
    "lubricavam": "lubricar",
    "lubricavas": "lubricar",
    "lubricidades": "lubricidade",
    "lubrico": "lubricar",
    "lubricou": "lubricar",
    "lubricá": "lubricar",
    "lubricámo": "lubricar",
    "lubricámos": "lubricar",
    "lubricáramo": "lubricar",
    "lubricáramos": "lubricar",
    "lubricárei": "lubricar",
    "lubricáreis": "lubricar",
    "lubricásseis": "lubricar",
    "lubricássemos": "lubricar",
    "lubricávamo": "lubricar",
    "lubricávamos": "lubricar",
    "lubricávei": "lubricar",
    "lubricáveis": "lubricar",
    "lubrifica": "lubrificar",
    "lubrificada": "lubrificar",
    "lubrificadas": "lubrificar",
    "lubrificado": "lubrificar",
    "lubrificados": "lubrificar",
    "lubrificai": "lubrificar",
    "lubrificais": "lubrificar",
    "lubrificam": "lubrificar",
    "lubrificamo": "lubrificar",
    "lubrificamos": "lubrificar",
    "lubrificando": "lubrificar",
    "lubrificantes": "lubrificante",
    "lubrificara": "lubrificar",
    "lubrificaram": "lubrificar",
    "lubrificaras": "lubrificar",
    "lubrificarde": "lubrificar",
    "lubrificardes": "lubrificar",
    "lubrificare": "lubrificar",
    "lubrificarei": "lubrificar",
    "lubrificareis": "lubrificar",
    "lubrificarem": "lubrificar",
    "lubrificaremos": "lubrificar",
    "lubrificares": "lubrificar",
    "lubrificaria": "lubrificar",
    "lubrificariam": "lubrificar",
    "lubrificarias": "lubrificar",
    "lubrificarmo": "lubrificar",
    "lubrificarmos": "lubrificar",
    "lubrificará": "lubrificar",
    "lubrificarás": "lubrificar",
    "lubrificarão": "lubrificar",
    "lubrificaríamos": "lubrificar",
    "lubrificaríeis": "lubrificar",
    "lubrificas": "lubrificar",
    "lubrificasse": "lubrificar",
    "lubrificassem": "lubrificar",
    "lubrificasses": "lubrificar",
    "lubrificaste": "lubrificar",
    "lubrificastes": "lubrificar",
    "lubrificava": "lubrificar",
    "lubrificavam": "lubrificar",
    "lubrificavas": "lubrificar",
    "lubrificações": "lubrificação",
    "lubrifico": "lubrificar",
    "lubrificou": "lubrificar",
    "lubrificá": "lubrificar",
    "lubrificámo": "lubrificar",
    "lubrificámos": "lubrificar",
    "lubrificáramo": "lubrificar",
    "lubrificáramos": "lubrificar",
    "lubrificárei": "lubrificar",
    "lubrificáreis": "lubrificar",
    "lubrificásseis": "lubrificar",
    "lubrificássemos": "lubrificar",
    "lubrificávamo": "lubrificar",
    "lubrificávamos": "lubrificar",
    "lubrificávei": "lubrificar",
    "lubrificáveis": "lubrificável",
    "lubrifique": "lubrificar",
    "lubrifiquei": "lubrificar",
    "lubrifiqueis": "lubrificar",
    "lubrifiquem": "lubrificar",
    "lubrifiquemo": "lubrificar",
    "lubrifiquemos": "lubrificar",
    "lubrifiques": "lubrificar",
    "lubrique": "lubricar",
    "lubriquei": "lubricar",
    "lubriqueis": "lubricar",
    "lubriquem": "lubricar",
    "lubriquemo": "lubricar",
    "lubriquemos": "lubricar",
    "lubriques": "lubricar",
    "lucana": "lucano",
    "lucanas": "lucano",
    "lucanos": "lucano",
    "lucantes": "lucante",
    "lucanídeos": "lucanídeo",
    "lucarnas": "lucarna",
    "lucas": "luca",
    "lucernas": "lucerna",
    "lucernários": "lucernário",
    "lucescentes": "lucescente",
    "lucha": "luchar",
    "luchada": "luchar",
    "luchadas": "luchar",
    "luchado": "luchar",
    "luchados": "luchar",
    "luchai": "luchar",
    "luchais": "luchar",
    "lucham": "luchar",
    "luchamo": "luchar",
    "luchamos": "luchar",
    "luchando": "luchar",
    "luchara": "luchar",
    "lucharam": "luchar",
    "lucharas": "luchar",
    "lucharde": "luchar",
    "luchardes": "luchar",
    "luchare": "luchar",
    "lucharei": "luchar",
    "luchareis": "luchar",
    "lucharem": "luchar",
    "lucharemos": "luchar",
    "luchares": "luchar",
    "lucharia": "luchar",
    "luchariam": "luchar",
    "lucharias": "luchar",
    "lucharmo": "luchar",
    "lucharmos": "luchar",
    "luchará": "luchar",
    "lucharás": "luchar",
    "lucharão": "luchar",
    "lucharíamos": "luchar",
    "lucharíeis": "luchar",
    "luchas": "luchar",
    "luchasse": "luchar",
    "luchassem": "luchar",
    "luchasses": "luchar",
    "luchaste": "luchar",
    "luchastes": "luchar",
    "luchava": "luchar",
    "luchavam": "luchar",
    "luchavas": "luchar",
    "luche": "luchar",
    "luchei": "luchar",
    "lucheis": "luchar",
    "luchem": "luchar",
    "luchemo": "luchar",
    "luchemos": "luchar",
    "luches": "luchar",
    "lucho": "luchar",
    "luchos": "lucho",
    "luchosa": "luchoso",
    "luchosas": "luchoso",
    "luchosos": "luchoso",
    "luchou": "luchar",
    "luchá": "luchar",
    "luchámo": "luchar",
    "luchámos": "luchar",
    "lucháramo": "luchar",
    "lucháramos": "luchar",
    "luchárei": "luchar",
    "lucháreis": "luchar",
    "luchásseis": "luchar",
    "luchássemos": "luchar",
    "luchávamo": "luchar",
    "luchávamos": "luchar",
    "luchávei": "luchar",
    "lucháveis": "luchar",
    "lucida": "lucidar",
    "lucidada": "lucidar",
    "lucidadas": "lucidar",
    "lucidado": "lucidar",
    "lucidados": "lucidar",
    "lucidai": "lucidar",
    "lucidais": "lucidar",
    "lucidam": "lucidar",
    "lucidamo": "lucidar",
    "lucidamos": "lucidar",
    "lucidando": "lucidar",
    "lucidara": "lucidar",
    "lucidaram": "lucidar",
    "lucidaras": "lucidar",
    "lucidarde": "lucidar",
    "lucidardes": "lucidar",
    "lucidare": "lucidar",
    "lucidarei": "lucidar",
    "lucidareis": "lucidar",
    "lucidarem": "lucidar",
    "lucidaremos": "lucidar",
    "lucidares": "lucidar",
    "lucidaria": "lucidar",
    "lucidariam": "lucidar",
    "lucidarias": "lucidar",
    "lucidarmo": "lucidar",
    "lucidarmos": "lucidar",
    "lucidará": "lucidar",
    "lucidarás": "lucidar",
    "lucidarão": "lucidar",
    "lucidaríamos": "lucidar",
    "lucidaríeis": "lucidar",
    "lucidas": "lucidar",
    "lucidasse": "lucidar",
    "lucidassem": "lucidar",
    "lucidasses": "lucidar",
    "lucidaste": "lucidar",
    "lucidastes": "lucidar",
    "lucidava": "lucidar",
    "lucidavam": "lucidar",
    "lucidavas": "lucidar",
    "lucide": "lucidar",
    "lucidei": "lucidar",
    "lucideis": "lucidar",
    "lucidem": "lucidar",
    "lucidemo": "lucidar",
    "lucidemos": "lucidar",
    "lucides": "lucidar",
    "lucido": "lucidar",
    "lucidou": "lucidar",
    "lucidá": "lucidar",
    "lucidámo": "lucidar",
    "lucidámos": "lucidar",
    "lucidáramo": "lucidar",
    "lucidáramos": "lucidar",
    "lucidárei": "lucidar",
    "lucidáreis": "lucidar",
    "lucidásseis": "lucidar",
    "lucidássemos": "lucidar",
    "lucidávamo": "lucidar",
    "lucidávamos": "lucidar",
    "lucidávei": "lucidar",
    "lucidáveis": "lucidar",
    "luciferes": "lúcifer",
    "luciferiana": "luciferiano",
    "luciferianas": "luciferiano",
    "luciferianismos": "luciferianismo",
    "luciferianos": "luciferiano",
    "luciferina": "luciferino",
    "luciferinas": "luciferino",
    "luciferinos": "luciferino",
    "luciferismos": "luciferismo",
    "luciferária": "luciferário",
    "luciferárias": "luciferário",
    "luciferários": "luciferário",
    "luciférica": "luciférico",
    "luciféricas": "luciférico",
    "luciféricos": "luciférico",
    "lucila": "lucilar",
    "lucilada": "lucilar",
    "luciladas": "lucilar",
    "lucilado": "lucilar",
    "lucilados": "lucilar",
    "lucilai": "lucilar",
    "lucilais": "lucilar",
    "lucilam": "lucilar",
    "lucilamo": "lucilar",
    "lucilamos": "lucilar",
    "lucilando": "lucilar",
    "lucilantes": "lucilante",
    "lucilara": "lucilar",
    "lucilaram": "lucilar",
    "lucilaras": "lucilar",
    "lucilardes": "lucilar",
    "lucilarei": "lucilar",
    "lucilareis": "lucilar",
    "lucilarem": "lucilar",
    "lucilaremos": "lucilar",
    "lucilares": "lucilar",
    "lucilaria": "lucilar",
    "lucilariam": "lucilar",
    "lucilarias": "lucilar",
    "lucilarmo": "lucilar",
    "lucilarmos": "lucilar",
    "lucilará": "lucilar",
    "lucilarás": "lucilar",
    "lucilarão": "lucilar",
    "lucilaríamos": "lucilar",
    "lucilaríeis": "lucilar",
    "lucilas": "lucilar",
    "lucilasse": "lucilar",
    "lucilassem": "lucilar",
    "lucilasses": "lucilar",
    "lucilaste": "lucilar",
    "lucilastes": "lucilar",
    "lucilava": "lucilar",
    "lucilavam": "lucilar",
    "lucilavas": "lucilar",
    "lucilações": "lucilação",
    "lucile": "lucilar",
    "lucilei": "lucilar",
    "lucileis": "lucilar",
    "lucilem": "lucilar",
    "lucilemo": "lucilar",
    "lucilemos": "lucilar",
    "luciles": "lucilar",
    "lucilo": "lucilar",
    "lucilou": "lucilar",
    "luciluz": "luciluzir",
    "luciluza": "luciluzir",
    "luciluzais": "luciluzir",
    "luciluzam": "luciluzir",
    "luciluzamo": "luciluzir",
    "luciluzamos": "luciluzir",
    "luciluzas": "luciluzir",
    "luciluze": "luciluzir",
    "luciluzem": "luciluzir",
    "luciluzes": "luciluzir",
    "luciluzi": "luciluzir",
    "luciluzia": "luciluzir",
    "luciluziam": "luciluzir",
    "luciluzias": "luciluzir",
    "luciluzida": "luciluzir",
    "luciluzidas": "luciluzir",
    "luciluzido": "luciluzir",
    "luciluzidos": "luciluzir",
    "luciluzimo": "luciluzir",
    "luciluzimos": "luciluzir",
    "luciluzindo": "luciluzir",
    "luciluzira": "luciluzir",
    "luciluziram": "luciluzir",
    "luciluziras": "luciluzir",
    "luciluzirdes": "luciluzir",
    "luciluzirei": "luciluzir",
    "luciluzireis": "luciluzir",
    "luciluzirem": "luciluzir",
    "luciluziremos": "luciluzir",
    "luciluzires": "luciluzir",
    "luciluziria": "luciluzir",
    "luciluziriam": "luciluzir",
    "luciluzirias": "luciluzir",
    "luciluzirmo": "luciluzir",
    "luciluzirmos": "luciluzir",
    "luciluzirá": "luciluzir",
    "luciluzirás": "luciluzir",
    "luciluzirão": "luciluzir",
    "luciluziríamos": "luciluzir",
    "luciluziríeis": "luciluzir",
    "luciluzis": "luciluzir",
    "luciluzisse": "luciluzir",
    "luciluzissem": "luciluzir",
    "luciluzisses": "luciluzir",
    "luciluziste": "luciluzir",
    "luciluzistes": "luciluzir",
    "luciluziu": "luciluzir",
    "luciluzo": "luciluzir",
    "luciluzíamo": "luciluzir",
    "luciluzíamos": "luciluzir",
    "luciluzíeis": "luciluzir",
    "luciluzíramo": "luciluzir",
    "luciluzíramos": "luciluzir",
    "luciluzíreis": "luciluzir",
    "luciluzísseis": "luciluzir",
    "luciluzíssemos": "luciluzir",
    "lucilámo": "lucilar",
    "lucilámos": "lucilar",
    "luciláramo": "lucilar",
    "luciláramos": "lucilar",
    "luciláreis": "lucilar",
    "lucilásseis": "lucilar",
    "lucilássemos": "lucilar",
    "lucilávamo": "lucilar",
    "lucilávamos": "lucilar",
    "luciláveis": "lucilar",
    "lucilâncias": "lucilância",
    "lucinas": "lucina",
    "lucinídeos": "lucinídeo",
    "lucipotentes": "lucipotente",
    "lucivela": "lucivelo",
    "lucivelas": "lucivelo",
    "lucivelos": "lucivelo",
    "lucos": "luco",
    "lucra": "lucrar",
    "lucrada": "lucrar",
    "lucradas": "lucrar",
    "lucrado": "lucrar",
    "lucrados": "lucrar",
    "lucrai": "lucrar",
    "lucrais": "lucrar",
    "lucram": "lucrar",
    "lucramo": "lucrar",
    "lucramos": "lucrar",
    "lucrando": "lucrar",
    "lucrara": "lucrar",
    "lucraram": "lucrar",
    "lucraras": "lucrar",
    "lucrarde": "lucrar",
    "lucrardes": "lucrar",
    "lucrare": "lucrar",
    "lucrarei": "lucrar",
    "lucrareis": "lucrar",
    "lucrarem": "lucrar",
    "lucraremos": "lucrar",
    "lucrares": "lucrar",
    "lucraria": "lucrar",
    "lucrariam": "lucrar",
    "lucrarias": "lucrar",
    "lucrarmo": "lucrar",
    "lucrarmos": "lucrar",
    "lucrará": "lucrar",
    "lucrarás": "lucrar",
    "lucrarão": "lucrar",
    "lucraríamos": "lucrar",
    "lucraríeis": "lucrar",
    "lucras": "lucrar",
    "lucrasse": "lucrar",
    "lucrassem": "lucrar",
    "lucrasses": "lucrar",
    "lucraste": "lucrar",
    "lucrastes": "lucrar",
    "lucrativa": "lucrativo",
    "lucrativas": "lucrativo",
    "lucratividades": "lucratividade",
    "lucrativos": "lucrativo",
    "lucrava": "lucrar",
    "lucravam": "lucrar",
    "lucravas": "lucrar",
    "lucre": "lucrar",
    "lucrei": "lucrar",
    "lucreis": "lucrar",
    "lucrem": "lucrar",
    "lucremo": "lucrar",
    "lucremos": "lucrar",
    "lucres": "lucrar",
    "lucro": "lucrar",
    "lucros": "lucro",
    "lucrosa": "lucroso",
    "lucrosas": "lucroso",
    "lucrosos": "lucroso",
    "lucrou": "lucrar",
    "lucrá": "lucrar",
    "lucrámo": "lucrar",
    "lucrámos": "lucrar",
    "lucráramo": "lucrar",
    "lucráramos": "lucrar",
    "lucrárei": "lucrar",
    "lucráreis": "lucrar",
    "lucrásseis": "lucrar",
    "lucrássemos": "lucrar",
    "lucrávamo": "lucrar",
    "lucrávamos": "lucrar",
    "lucrávei": "lucrar",
    "lucráveis": "lucrar",
    "luctífera": "luctífero",
    "luctíferas": "luctífero",
    "luctíferos": "luctífero",
    "luctífica": "luctífico",
    "luctíficas": "luctífico",
    "luctíficos": "luctífico",
    "luctíssona": "luctíssono",
    "luctíssonas": "luctíssono",
    "luctíssonos": "luctíssono",
    "lucubra": "lucubrar",
    "lucubrada": "lucubrar",
    "lucubradas": "lucubrar",
    "lucubrado": "lucubrar",
    "lucubrados": "lucubrar",
    "lucubrai": "lucubrar",
    "lucubrais": "lucubrar",
    "lucubram": "lucubrar",
    "lucubramo": "lucubrar",
    "lucubramos": "lucubrar",
    "lucubrando": "lucubrar",
    "lucubrara": "lucubrar",
    "lucubraram": "lucubrar",
    "lucubraras": "lucubrar",
    "lucubrardes": "lucubrar",
    "lucubrarei": "lucubrar",
    "lucubrareis": "lucubrar",
    "lucubrarem": "lucubrar",
    "lucubraremos": "lucubrar",
    "lucubrares": "lucubrar",
    "lucubraria": "lucubrar",
    "lucubrariam": "lucubrar",
    "lucubrarias": "lucubrar",
    "lucubrarmo": "lucubrar",
    "lucubrarmos": "lucubrar",
    "lucubrará": "lucubrar",
    "lucubrarás": "lucubrar",
    "lucubrarão": "lucubrar",
    "lucubraríamos": "lucubrar",
    "lucubraríeis": "lucubrar",
    "lucubras": "lucubrar",
    "lucubrasse": "lucubrar",
    "lucubrassem": "lucubrar",
    "lucubrasses": "lucubrar",
    "lucubraste": "lucubrar",
    "lucubrastes": "lucubrar",
    "lucubrava": "lucubrar",
    "lucubravam": "lucubrar",
    "lucubravas": "lucubrar",
    "lucubrações": "lucubração",
    "lucubre": "lucubrar",
    "lucubrei": "lucubrar",
    "lucubreis": "lucubrar",
    "lucubrem": "lucubrar",
    "lucubremo": "lucubrar",
    "lucubremos": "lucubrar",
    "lucubres": "lucubrar",
    "lucubro": "lucubrar",
    "lucubrou": "lucubrar",
    "lucubrámo": "lucubrar",
    "lucubrámos": "lucubrar",
    "lucubráramo": "lucubrar",
    "lucubráramos": "lucubrar",
    "lucubráreis": "lucubrar",
    "lucubrásseis": "lucubrar",
    "lucubrássemos": "lucubrar",
    "lucubrávamo": "lucubrar",
    "lucubrávamos": "lucubrar",
    "lucubráveis": "lucubrar",
    "lucula": "luculo",
    "luculas": "luculo",
    "luculenta": "luculento",
    "luculentas": "luculento",
    "luculentos": "luculento",
    "luculiana": "luculiano",
    "luculianas": "luculiano",
    "luculianos": "luculiano",
    "luculos": "luculo",
    "lucânidas": "lucânida",
    "lucífera": "lucífero",
    "lucíferas": "lucífero",
    "lucíferos": "lucífero",
    "lucífila": "lucífilo",
    "lucífilas": "lucífilo",
    "lucífilos": "lucífilo",
    "lucífuga": "lucífugo",
    "lucífugas": "lucífugo",
    "lucífugos": "lucífugo",
    "lucímetros": "lucímetro",
    "lucínidas": "lucínida",
    "lucões": "lucão",
    "ludianos": "ludiano",
    "ludibria": "ludibriar",
    "ludibriada": "ludibriar",
    "ludibriadas": "ludibriar",
    "ludibriado": "ludibriar",
    "ludibriados": "ludibriar",
    "ludibriai": "ludibriar",
    "ludibriais": "ludibriar",
    "ludibriam": "ludibriar",
    "ludibriamo": "ludibriar",
    "ludibriamos": "ludibriar",
    "ludibriando": "ludibriar",
    "ludibriantes": "ludibriante",
    "ludibriara": "ludibriar",
    "ludibriaram": "ludibriar",
    "ludibriaras": "ludibriar",
    "ludibriarde": "ludibriar",
    "ludibriardes": "ludibriar",
    "ludibriare": "ludibriar",
    "ludibriarei": "ludibriar",
    "ludibriareis": "ludibriar",
    "ludibriarem": "ludibriar",
    "ludibriaremos": "ludibriar",
    "ludibriares": "ludibriar",
    "ludibriaria": "ludibriar",
    "ludibriariam": "ludibriar",
    "ludibriarias": "ludibriar",
    "ludibriarmo": "ludibriar",
    "ludibriarmos": "ludibriar",
    "ludibriará": "ludibriar",
    "ludibriarás": "ludibriar",
    "ludibriarão": "ludibriar",
    "ludibriaríamos": "ludibriar",
    "ludibriaríeis": "ludibriar",
    "ludibrias": "ludibriar",
    "ludibriasse": "ludibriar",
    "ludibriassem": "ludibriar",
    "ludibriasses": "ludibriar",
    "ludibriaste": "ludibriar",
    "ludibriastes": "ludibriar",
    "ludibriava": "ludibriar",
    "ludibriavam": "ludibriar",
    "ludibriavas": "ludibriar",
    "ludibrie": "ludibriar",
    "ludibriei": "ludibriar",
    "ludibrieis": "ludibriar",
    "ludibriem": "ludibriar",
    "ludibriemo": "ludibriar",
    "ludibriemos": "ludibriar",
    "ludibries": "ludibriar",
    "ludibrio": "ludibriar",
    "ludibriosa": "ludibrioso",
    "ludibriosas": "ludibrioso",
    "ludibriosos": "ludibrioso",
    "ludibriou": "ludibriar",
    "ludibriá": "ludibriar",
    "ludibriámo": "ludibriar",
    "ludibriámos": "ludibriar",
    "ludibriáramo": "ludibriar",
    "ludibriáramos": "ludibriar",
    "ludibriárei": "ludibriar",
    "ludibriáreis": "ludibriar",
    "ludibriásseis": "ludibriar",
    "ludibriássemos": "ludibriar",
    "ludibriávamo": "ludibriar",
    "ludibriávamos": "ludibriar",
    "ludibriávei": "ludibriar",
    "ludibriáveis": "ludibriável",
    "ludiões": "ludião",
    "ludlovianos": "ludloviano",
    "ludomanias": "ludomania",
    "ludos": "ludo",
    "ludotecas": "ludoteca",
    "ludoterapias": "ludoterapia",
    "ludra": "ludro",
    "ludras": "ludro",
    "ludreiros": "ludreiro",
    "ludros": "ludro",
    "ludrosa": "ludroso",
    "ludrosas": "ludroso",
    "ludrosos": "ludroso",
    "luduns": "ludum",
    "ludus": "ludu",
    "ludíbrios": "ludíbrio",
    "lufa": "lufar",
    "lufada": "lufar",
    "lufadas": "lufar",
    "lufado": "lufar",
    "lufados": "lufar",
    "lufai": "lufar",
    "lufais": "lufar",
    "lufam": "lufar",
    "lufamo": "lufar",
    "lufamos": "lufar",
    "lufando": "lufar",
    "lufara": "lufar",
    "lufaram": "lufar",
    "lufaras": "lufar",
    "lufardes": "lufar",
    "lufarei": "lufar",
    "lufareis": "lufar",
    "lufarem": "lufar",
    "lufaremos": "lufar",
    "lufares": "lufar",
    "lufaria": "lufar",
    "lufariam": "lufar",
    "lufarias": "lufar",
    "lufarmo": "lufar",
    "lufarmos": "lufar",
    "lufará": "lufar",
    "lufarás": "lufar",
    "lufarão": "lufar",
    "lufaríamos": "lufar",
    "lufaríeis": "lufar",
    "lufas": "lufar",
    "lufasse": "lufar",
    "lufassem": "lufar",
    "lufasses": "lufar",
    "lufaste": "lufar",
    "lufastes": "lufar",
    "lufava": "lufar",
    "lufavam": "lufar",
    "lufavas": "lufar",
    "lufe": "lufar",
    "lufei": "lufar",
    "lufeis": "lufar",
    "lufem": "lufar",
    "lufemo": "lufar",
    "lufemos": "lufar",
    "lufes": "lufar",
    "lufo": "lufar",
    "lufou": "lufar",
    "lufámo": "lufar",
    "lufámos": "lufar",
    "lufáramo": "lufar",
    "lufáramos": "lufar",
    "lufáreis": "lufar",
    "lufásseis": "lufar",
    "lufássemos": "lufar",
    "lufávamo": "lufar",
    "lufávamos": "lufar",
    "lufáveis": "lufar",
    "lugarejos": "lugarejo",
    "lugares": "lugar",
    "lugdunenses": "lugdunense",
    "lugentes": "lugente",
    "lugres": "lugre",
    "lugubridades": "lugubridade",
    "luises": "luís",
    "lulas": "lula",
    "lulinha": "lula",
    "lulinhas": "lula",
    "lulita": "lula",
    "lulitas": "lula",
    "lulus": "lulu",
    "lulões": "lulão",
    "lumaquelas": "lumaquela",
    "lumaréus": "lumaréu",
    "lumbagos": "lumbago",
    "lumbricais": "lumbrical",
    "lumbricidas": "lumbricida",
    "lumbricária": "lumbricário",
    "lumbricárias": "lumbricário",
    "lumbricários": "lumbricário",
    "lumbricídeos": "lumbricídeo",
    "lumbricóides": "lumbricóide",
    "lumbrícidas": "lumbrícida",
    "lumes": "lume",
    "lumiares": "lumiar",
    "lumieiras": "lumieira",
    "lumieiros": "lumieiro",
    "luminancímetros": "luminancímetro",
    "luminares": "luminar",
    "luminaristas": "luminarista",
    "luminescentes": "luminescente",
    "luminescências": "luminescência",
    "luministas": "luminista",
    "luminosa": "luminoso",
    "luminosas": "luminoso",
    "luminosidades": "luminosidade",
    "luminosos": "luminoso",
    "luminárias": "luminária",
    "luminâncias": "luminância",
    "luminímetros": "luminímetro",
    "luminóforos": "luminóforo",
    "lumiosa": "lumioso",
    "lumiosas": "lumioso",
    "lumiosos": "lumioso",
    "lumos": "lumo",
    "lumpemproletariados": "lumpemproletariado",
    "lunada": "lunado",
    "lunadas": "lunado",
    "lunados": "lunado",
    "lunares": "lunar",
    "lunas": "luna",
    "lunautas": "lunauta",
    "lunações": "lunação",
    "lundesa": "lundês",
    "lundesas": "lundês",
    "lundeses": "lundês",
    "lunetas": "luneta",
    "lungunguas": "lungungua",
    "luniformes": "luniforme",
    "lunissolares": "lunissolar",
    "lunulada": "lunulado",
    "lunuladas": "lunulado",
    "lunulados": "lunulado",
    "lunulares": "lunular",
    "lunários": "lunário",
    "lunática": "lunático",
    "lunáticas": "lunático",
    "lunáticos": "lunático",
    "lunícolas": "lunícola",
    "lupadas": "lupada",
    "lupambas": "lupamba",
    "lupanares": "lupanar",
    "lupangas": "lupanga",
    "lupanária": "lupanário",
    "lupanárias": "lupanário",
    "lupanários": "lupanário",
    "lupas": "lupa",
    "lupercos": "luperco",
    "lupina": "lupino",
    "lupinas": "lupino",
    "lupinastros": "lupinastro",
    "lupinos": "lupino",
    "lupinoses": "lupinose",
    "lupinotoxinas": "lupinotoxina",
    "lupos": "lupo",
    "lupulinas": "lupulina",
    "lura": "lurar",
    "lurada": "lurar",
    "luradas": "lurar",
    "lurado": "lurar",
    "lurados": "lurar",
    "lurai": "lurar",
    "lurais": "lurar",
    "luram": "lurar",
    "luramo": "lurar",
    "luramos": "lurar",
    "lurando": "lurar",
    "lurara": "lurar",
    "luraram": "lurar",
    "luraras": "lurar",
    "lurarde": "lurar",
    "lurardes": "lurar",
    "lurare": "lurar",
    "lurarei": "lurar",
    "lurareis": "lurar",
    "lurarem": "lurar",
    "luraremos": "lurar",
    "lurares": "lurar",
    "luraria": "lurar",
    "lurariam": "lurar",
    "lurarias": "lurar",
    "lurarmo": "lurar",
    "lurarmos": "lurar",
    "lurará": "lurar",
    "lurarás": "lurar",
    "lurarão": "lurar",
    "luraríamos": "lurar",
    "luraríeis": "lurar",
    "luras": "lurar",
    "lurasse": "lurar",
    "lurassem": "lurar",
    "lurasses": "lurar",
    "luraste": "lurar",
    "lurastes": "lurar",
    "lurava": "lurar",
    "luravam": "lurar",
    "luravas": "lurar",
    "lure": "lurar",
    "lurei": "lurar",
    "lureis": "lurar",
    "lurem": "lurar",
    "luremo": "lurar",
    "luremos": "lurar",
    "lures": "lurar",
    "luro": "lurar",
    "lurou": "lurar",
    "lurqua": "lurquir",
    "lurquais": "lurquir",
    "lurquam": "lurquir",
    "lurquamo": "lurquir",
    "lurquamos": "lurquir",
    "lurquas": "lurquir",
    "lurque": "lurquir",
    "lurquem": "lurquir",
    "lurques": "lurquir",
    "lurqui": "lurquir",
    "lurquia": "lurquir",
    "lurquiam": "lurquir",
    "lurquias": "lurquir",
    "lurquida": "lurquir",
    "lurquidas": "lurquir",
    "lurquido": "lurquir",
    "lurquidos": "lurquir",
    "lurquimo": "lurquir",
    "lurquimos": "lurquir",
    "lurquindo": "lurquir",
    "lurquira": "lurquir",
    "lurquiram": "lurquir",
    "lurquiras": "lurquir",
    "lurquirde": "lurquir",
    "lurquirdes": "lurquir",
    "lurquire": "lurquir",
    "lurquirei": "lurquir",
    "lurquireis": "lurquir",
    "lurquirem": "lurquir",
    "lurquiremos": "lurquir",
    "lurquires": "lurquir",
    "lurquiria": "lurquir",
    "lurquiriam": "lurquir",
    "lurquirias": "lurquir",
    "lurquirmo": "lurquir",
    "lurquirmos": "lurquir",
    "lurquirá": "lurquir",
    "lurquirás": "lurquir",
    "lurquirão": "lurquir",
    "lurquiríamos": "lurquir",
    "lurquiríeis": "lurquir",
    "lurquis": "lurquir",
    "lurquisse": "lurquir",
    "lurquissem": "lurquir",
    "lurquisses": "lurquir",
    "lurquiste": "lurquir",
    "lurquistes": "lurquir",
    "lurquiu": "lurquir",
    "lurquo": "lurquir",
    "lurquíamo": "lurquir",
    "lurquíamos": "lurquir",
    "lurquíei": "lurquir",
    "lurquíeis": "lurquir",
    "lurquíramo": "lurquir",
    "lurquíramos": "lurquir",
    "lurquírei": "lurquir",
    "lurquíreis": "lurquir",
    "lurquísseis": "lurquir",
    "lurquíssemos": "lurquir",
    "lurá": "lurar",
    "lurámo": "lurar",
    "lurámos": "lurar",
    "luráramo": "lurar",
    "luráramos": "lurar",
    "lurárei": "lurar",
    "luráreis": "lurar",
    "lurásseis": "lurar",
    "lurássemos": "lurar",
    "lurávamo": "lurar",
    "lurávamos": "lurar",
    "lurávei": "lurar",
    "luráveis": "lurar",
    "lusa": "luso",
    "lusas": "luso",
    "lusca": "lusco",
    "luscas": "lusco",
    "luscos": "lusco",
    "lusifica": "lusificar",
    "lusificada": "lusificar",
    "lusificadas": "lusificar",
    "lusificado": "lusificar",
    "lusificados": "lusificar",
    "lusificai": "lusificar",
    "lusificais": "lusificar",
    "lusificam": "lusificar",
    "lusificamo": "lusificar",
    "lusificamos": "lusificar",
    "lusificando": "lusificar",
    "lusificara": "lusificar",
    "lusificaram": "lusificar",
    "lusificaras": "lusificar",
    "lusificarde": "lusificar",
    "lusificardes": "lusificar",
    "lusificare": "lusificar",
    "lusificarei": "lusificar",
    "lusificareis": "lusificar",
    "lusificarem": "lusificar",
    "lusificaremos": "lusificar",
    "lusificares": "lusificar",
    "lusificaria": "lusificar",
    "lusificariam": "lusificar",
    "lusificarias": "lusificar",
    "lusificarmo": "lusificar",
    "lusificarmos": "lusificar",
    "lusificará": "lusificar",
    "lusificarás": "lusificar",
    "lusificarão": "lusificar",
    "lusificaríamos": "lusificar",
    "lusificaríeis": "lusificar",
    "lusificas": "lusificar",
    "lusificasse": "lusificar",
    "lusificassem": "lusificar",
    "lusificasses": "lusificar",
    "lusificaste": "lusificar",
    "lusificastes": "lusificar",
    "lusificava": "lusificar",
    "lusificavam": "lusificar",
    "lusificavas": "lusificar",
    "lusifico": "lusificar",
    "lusificou": "lusificar",
    "lusificá": "lusificar",
    "lusificámo": "lusificar",
    "lusificámos": "lusificar",
    "lusificáramo": "lusificar",
    "lusificáramos": "lusificar",
    "lusificárei": "lusificar",
    "lusificáreis": "lusificar",
    "lusificásseis": "lusificar",
    "lusificássemos": "lusificar",
    "lusificávamo": "lusificar",
    "lusificávamos": "lusificar",
    "lusificávei": "lusificar",
    "lusificáveis": "lusificar",
    "lusifique": "lusificar",
    "lusifiquei": "lusificar",
    "lusifiqueis": "lusificar",
    "lusifiquem": "lusificar",
    "lusifiquemo": "lusificar",
    "lusifiquemos": "lusificar",
    "lusifiques": "lusificar",
    "lusismos": "lusismo",
    "lusitana": "lusitano",
    "lusitanas": "lusitano",
    "lusitanianos": "lusitaniano",
    "lusitanidades": "lusitanidade",
    "lusitanismos": "lusitanismo",
    "lusitanistas": "lusitanista",
    "lusitanizações": "lusitanização",
    "lusitanos": "lusitano",
    "lusitânica": "lusitânico",
    "lusitânicas": "lusitânico",
    "lusitânicos": "lusitânico",
    "lusofalantes": "lusofalante",
    "lusofilias": "lusofilia",
    "lusofobias": "lusofobia",
    "lusofonias": "lusofonia",
    "lusos": "luso",
    "lustra": "lustrar",
    "lustrada": "lustrar",
    "lustradas": "lustrar",
    "lustradeiras": "lustradeira",
    "lustradelas": "lustradela",
    "lustrado": "lustrar",
    "lustradora": "lustrador",
    "lustradoras": "lustrador",
    "lustradores": "lustrador",
    "lustrados": "lustrar",
    "lustrai": "lustrar",
    "lustrais": "lustrar",
    "lustram": "lustrar",
    "lustramo": "lustrar",
    "lustramos": "lustrar",
    "lustrando": "lustrar",
    "lustrara": "lustrar",
    "lustraram": "lustrar",
    "lustraras": "lustrar",
    "lustrarde": "lustrar",
    "lustrardes": "lustrar",
    "lustrare": "lustrar",
    "lustrarei": "lustrar",
    "lustrareis": "lustrar",
    "lustrarem": "lustrar",
    "lustraremos": "lustrar",
    "lustrares": "lustrar",
    "lustraria": "lustrar",
    "lustrariam": "lustrar",
    "lustrarias": "lustrar",
    "lustrarmo": "lustrar",
    "lustrarmos": "lustrar",
    "lustrará": "lustrar",
    "lustrarás": "lustrar",
    "lustrarão": "lustrar",
    "lustraríamos": "lustrar",
    "lustraríeis": "lustrar",
    "lustras": "lustrar",
    "lustrasse": "lustrar",
    "lustrassem": "lustrar",
    "lustrasses": "lustrar",
    "lustraste": "lustrar",
    "lustrastes": "lustrar",
    "lustrava": "lustrar",
    "lustravam": "lustrar",
    "lustravas": "lustrar",
    "lustrações": "lustração",
    "lustre": "lustrar",
    "lustrei": "lustrar",
    "lustreis": "lustrar",
    "lustrem": "lustrar",
    "lustremo": "lustrar",
    "lustremos": "lustrar",
    "lustres": "lustre",
    "lustrilhos": "lustrilho",
    "lustrina": "lustrino",
    "lustrinas": "lustrino",
    "lustrinos": "lustrino",
    "lustro": "lustrar",
    "lustros": "lustro",
    "lustrosa": "lustroso",
    "lustrosas": "lustroso",
    "lustrosos": "lustroso",
    "lustrou": "lustrar",
    "lustrá": "lustrar",
    "lustrámo": "lustrar",
    "lustrámos": "lustrar",
    "lustráramo": "lustrar",
    "lustráramos": "lustrar",
    "lustrárei": "lustrar",
    "lustráreis": "lustrar",
    "lustrásseis": "lustrar",
    "lustrássemos": "lustrar",
    "lustrávamo": "lustrar",
    "lustrávamos": "lustrar",
    "lustrávei": "lustrar",
    "lustráveis": "lustrar",
    "lusíadas": "lusíada",
    "lusófila": "lusófilo",
    "lusófilas": "lusófilo",
    "lusófilos": "lusófilo",
    "lusófoba": "lusófobo",
    "lusófobas": "lusófobo",
    "lusófobos": "lusófobo",
    "lusófona": "lusófono",
    "lusófonas": "lusófono",
    "lusófonos": "lusófono",
    "lusória": "lusório",
    "lusórias": "lusório",
    "lusórios": "lusório",
    "luta": "lutar",
    "lutada": "lutar",
    "lutadas": "lutar",
    "lutado": "lutar",
    "lutadora": "lutador",
    "lutadoras": "lutador",
    "lutadorazinha": "lutador",
    "lutadorazinhas": "lutador",
    "lutadorazita": "lutador",
    "lutadorazitas": "lutador",
    "lutadores": "lutador",
    "lutadorzinho": "lutador",
    "lutadorzinhos": "lutador",
    "lutadorzito": "lutador",
    "lutadorzitos": "lutador",
    "lutados": "lutar",
    "lutagens": "lutagem",
    "lutai": "lutar",
    "lutais": "lutar",
    "lutam": "lutar",
    "lutamo": "lutar",
    "lutamos": "lutar",
    "lutando": "lutar",
    "lutara": "lutar",
    "lutaram": "lutar",
    "lutaras": "lutar",
    "lutardes": "lutar",
    "lutarei": "lutar",
    "lutareis": "lutar",
    "lutarem": "lutar",
    "lutaremos": "lutar",
    "lutares": "lutar",
    "lutaria": "lutar",
    "lutariam": "lutar",
    "lutarias": "lutar",
    "lutarmo": "lutar",
    "lutarmos": "lutar",
    "lutará": "lutar",
    "lutarás": "lutar",
    "lutarão": "lutar",
    "lutaríamos": "lutar",
    "lutaríeis": "lutar",
    "lutas": "lutar",
    "lutasse": "lutar",
    "lutassem": "lutar",
    "lutasses": "lutar",
    "lutaste": "lutar",
    "lutastes": "lutar",
    "lutava": "lutar",
    "lutavam": "lutar",
    "lutavas": "lutar",
    "lute": "lutar",
    "lutecianos": "luteciano",
    "lutei": "lutar",
    "luteicórnea": "luteicórneo",
    "luteicórneas": "luteicórneo",
    "luteicórneos": "luteicórneo",
    "luteis": "lutar",
    "lutem": "lutar",
    "lutemo": "lutar",
    "lutemos": "lutar",
    "luterana": "luterano",
    "luteranas": "luterano",
    "luteranismos": "luteranismo",
    "luteranos": "luterano",
    "luterarias": "luteraria",
    "lutes": "lutar",
    "luteínas": "luteína",
    "lutinas": "lutina",
    "lutitos": "lutito",
    "luto": "lutar",
    "lutos": "luto",
    "lutou": "lutar",
    "lutulenta": "lutulento",
    "lutulentas": "lutulento",
    "lutulentos": "lutulento",
    "lutulências": "lutulência",
    "lutuosa": "lutuoso",
    "lutuosas": "lutuoso",
    "lutuosos": "lutuoso",
    "lutámo": "lutar",
    "lutámos": "lutar",
    "lutáramo": "lutar",
    "lutáramos": "lutar",
    "lutáreis": "lutar",
    "lutásseis": "lutar",
    "lutássemos": "lutar",
    "lutávamo": "lutar",
    "lutávamos": "lutar",
    "lutáveis": "lutar",
    "lutécios": "lutécio",
    "luvarias": "luvaria",
    "luvas": "luva",
    "luveira": "luveiro",
    "luveiras": "luveiro",
    "luveiros": "luveiro",
    "luvistas": "luvista",
    "luxa": "luxar",
    "luxada": "luxar",
    "luxadas": "luxar",
    "luxado": "luxar",
    "luxados": "luxar",
    "luxai": "luxar",
    "luxais": "luxar",
    "luxam": "luxar",
    "luxamo": "luxar",
    "luxamos": "luxar",
    "luxando": "luxar",
    "luxara": "luxar",
    "luxaram": "luxar",
    "luxaras": "luxar",
    "luxarde": "luxar",
    "luxardes": "luxar",
    "luxare": "luxar",
    "luxarei": "luxar",
    "luxareis": "luxar",
    "luxarem": "luxar",
    "luxaremos": "luxar",
    "luxares": "luxar",
    "luxaria": "luxar",
    "luxariam": "luxar",
    "luxarias": "luxar",
    "luxarmo": "luxar",
    "luxarmos": "luxar",
    "luxará": "luxar",
    "luxarás": "luxar",
    "luxarão": "luxar",
    "luxaríamos": "luxar",
    "luxaríeis": "luxar",
    "luxas": "luxar",
    "luxasse": "luxar",
    "luxassem": "luxar",
    "luxasses": "luxar",
    "luxaste": "luxar",
    "luxastes": "luxar",
    "luxava": "luxar",
    "luxavam": "luxar",
    "luxavas": "luxar",
    "luxações": "luxação",
    "luxe": "luxar",
    "luxei": "luxar",
    "luxeis": "luxar",
    "luxem": "luxar",
    "luxemburguesa": "luxemburguês",
    "luxemburguesas": "luxemburguês",
    "luxemburgueses": "luxemburguês",
    "luxemo": "luxar",
    "luxemos": "luxar",
    "luxenta": "luxento",
    "luxentas": "luxento",
    "luxentos": "luxento",
    "luxes": "luxar",
    "luxo": "luxar",
    "luxos": "luxo",
    "luxosa": "luxoso",
    "luxosas": "luxoso",
    "luxosos": "luxoso",
    "luxou": "luxar",
    "luxuosa": "luxuoso",
    "luxuosas": "luxuoso",
    "luxuosidades": "luxuosidade",
    "luxuosos": "luxuoso",
    "luxuosíssima": "luxuoso",
    "luxuosíssimas": "luxuoso",
    "luxuosíssimo": "luxuoso",
    "luxuosíssimos": "luxuoso",
    "luxuria": "luxuriar",
    "luxuriada": "luxuriar",
    "luxuriadas": "luxuriar",
    "luxuriado": "luxuriar",
    "luxuriados": "luxuriar",
    "luxuriai": "luxuriar",
    "luxuriais": "luxuriar",
    "luxuriam": "luxuriar",
    "luxuriamo": "luxuriar",
    "luxuriamos": "luxuriar",
    "luxuriando": "luxuriar",
    "luxuriantes": "luxuriante",
    "luxuriara": "luxuriar",
    "luxuriaram": "luxuriar",
    "luxuriaras": "luxuriar",
    "luxuriardes": "luxuriar",
    "luxuriarei": "luxuriar",
    "luxuriareis": "luxuriar",
    "luxuriarem": "luxuriar",
    "luxuriaremos": "luxuriar",
    "luxuriares": "luxuriar",
    "luxuriaria": "luxuriar",
    "luxuriariam": "luxuriar",
    "luxuriarias": "luxuriar",
    "luxuriarmo": "luxuriar",
    "luxuriarmos": "luxuriar",
    "luxuriará": "luxuriar",
    "luxuriarás": "luxuriar",
    "luxuriarão": "luxuriar",
    "luxuriaríamos": "luxuriar",
    "luxuriaríeis": "luxuriar",
    "luxurias": "luxuriar",
    "luxuriasse": "luxuriar",
    "luxuriassem": "luxuriar",
    "luxuriasses": "luxuriar",
    "luxuriaste": "luxuriar",
    "luxuriastes": "luxuriar",
    "luxuriava": "luxuriar",
    "luxuriavam": "luxuriar",
    "luxuriavas": "luxuriar",
    "luxurie": "luxuriar",
    "luxuriei": "luxuriar",
    "luxurieis": "luxuriar",
    "luxuriem": "luxuriar",
    "luxuriemo": "luxuriar",
    "luxuriemos": "luxuriar",
    "luxuries": "luxuriar",
    "luxurio": "luxuriar",
    "luxuriosa": "luxurioso",
    "luxuriosas": "luxurioso",
    "luxuriosos": "luxurioso",
    "luxuriou": "luxuriar",
    "luxuriámo": "luxuriar",
    "luxuriámos": "luxuriar",
    "luxuriáramo": "luxuriar",
    "luxuriáramos": "luxuriar",
    "luxuriáreis": "luxuriar",
    "luxuriásseis": "luxuriar",
    "luxuriássemos": "luxuriar",
    "luxuriávamo": "luxuriar",
    "luxuriávamos": "luxuriar",
    "luxuriáveis": "luxuriável",
    "luxuária": "luxuário",
    "luxuárias": "luxuário",
    "luxuários": "luxuário",
    "luxá": "luxar",
    "luxámo": "luxar",
    "luxámos": "luxar",
    "luxáramo": "luxar",
    "luxáramos": "luxar",
    "luxárei": "luxar",
    "luxáreis": "luxar",
    "luxásseis": "luxar",
    "luxássemos": "luxar",
    "luxávamo": "luxar",
    "luxávamos": "luxar",
    "luxávei": "luxar",
    "luxáveis": "luxar",
    "luxímetros": "luxímetro",
    "luxúrias": "luxúria",
    "luz": "luzir",
    "luza": "luzir",
    "luzais": "luzir",
    "luzam": "luzir",
    "luzamo": "luzir",
    "luzamos": "luzir",
    "luzas": "luzir",
    "luze": "luzir",
    "luzeiros": "luzeiro",
    "luzem": "luzir",
    "luzendros": "luzendro",
    "luzentes": "luzente",
    "luzernais": "luzernal",
    "luzernas": "luzerna",
    "luzerneiras": "luzerneira",
    "luzes": "luzir",
    "luzetros": "luzetro",
    "luzi": "luzir",
    "luzia": "luzir",
    "luziam": "luzir",
    "luzias": "luzir",
    "luzida": "luzir",
    "luzidas": "luzir",
    "luzidia": "luzidio",
    "luzidias": "luzidio",
    "luzidios": "luzidio",
    "luzido": "luzir",
    "luzidos": "luzir",
    "luzilumes": "luzilume",
    "luziluz": "luziluzir",
    "luziluza": "luziluzir",
    "luziluzais": "luziluzir",
    "luziluzam": "luziluzir",
    "luziluzamo": "luziluzir",
    "luziluzamos": "luziluzir",
    "luziluzas": "luziluzir",
    "luziluze": "luziluzir",
    "luziluzem": "luziluzir",
    "luziluzes": "luziluzir",
    "luziluzi": "luziluzir",
    "luziluzia": "luziluzir",
    "luziluziam": "luziluzir",
    "luziluzias": "luziluzir",
    "luziluzida": "luziluzir",
    "luziluzidas": "luziluzir",
    "luziluzido": "luziluzir",
    "luziluzidos": "luziluzir",
    "luziluzimo": "luziluzir",
    "luziluzimos": "luziluzir",
    "luziluzindo": "luziluzir",
    "luziluzira": "luziluzir",
    "luziluziram": "luziluzir",
    "luziluziras": "luziluzir",
    "luziluzirdes": "luziluzir",
    "luziluzirei": "luziluzir",
    "luziluzireis": "luziluzir",
    "luziluzirem": "luziluzir",
    "luziluziremos": "luziluzir",
    "luziluzires": "luziluzir",
    "luziluziria": "luziluzir",
    "luziluziriam": "luziluzir",
    "luziluzirias": "luziluzir",
    "luziluzirmo": "luziluzir",
    "luziluzirmos": "luziluzir",
    "luziluzirá": "luziluzir",
    "luziluzirás": "luziluzir",
    "luziluzirão": "luziluzir",
    "luziluziríamos": "luziluzir",
    "luziluziríeis": "luziluzir",
    "luziluzis": "luziluzir",
    "luziluzisse": "luziluzir",
    "luziluzissem": "luziluzir",
    "luziluzisses": "luziluzir",
    "luziluziste": "luziluzir",
    "luziluzistes": "luziluzir",
    "luziluziu": "luziluzir",
    "luziluzo": "luziluzir",
    "luziluzíamo": "luziluzir",
    "luziluzíamos": "luziluzir",
    "luziluzíeis": "luziluzir",
    "luziluzíramo": "luziluzir",
    "luziluzíramos": "luziluzir",
    "luziluzíreis": "luziluzir",
    "luziluzísseis": "luziluzir",
    "luziluzíssemos": "luziluzir",
    "luzimentos": "luzimento",
    "luzimo": "luzir",
    "luzimos": "luzir",
    "luzincus": "luzincu",
    "luzindo": "luzir",
    "luzinha": "luz",
    "luzinhas": "luz",
    "luzios": "luzio",
    "luzira": "luzir",
    "luziram": "luzir",
    "luziras": "luzir",
    "luzirdes": "luzir",
    "luzirei": "luzir",
    "luzireis": "luzir",
    "luzirem": "luzir",
    "luziremos": "luzir",
    "luzires": "luzir",
    "luziria": "luzir",
    "luziriam": "luzir",
    "luzirias": "luzir",
    "luzirmo": "luzir",
    "luzirmos": "luzir",
    "luzirá": "luzir",
    "luzirás": "luzir",
    "luzirão": "luzir",
    "luziríamos": "luzir",
    "luziríeis": "luzir",
    "luzis": "luzir",
    "luzisse": "luzir",
    "luzissem": "luzir",
    "luzisses": "luzir",
    "luziste": "luzir",
    "luzistes": "luzir",
    "luzita": "luz",
    "luzitas": "luz",
    "luziu": "luzir",
    "luzo": "luzir",
    "luzuânguas": "luzuângua",
    "luzíamo": "luzir",
    "luzíamos": "luzir",
    "luzíeis": "luzir",
    "luzíramo": "luzir",
    "luzíramos": "luzir",
    "luzíreis": "luzir",
    "luzísseis": "luzir",
    "luzíssemos": "luzir",
    "luética": "luético",
    "luéticas": "luético",
    "luéticos": "luético",
    "lycras": "lycra",
    "lábaros": "lábaro",
    "lábdanos": "lábdano",
    "lábias": "lábia",
    "lábios": "lábio",
    "lábis": "lábil",
    "lábridas": "lábrida",
    "lácera": "lácero",
    "láceras": "lácero",
    "láceros": "lácero",
    "lácia": "lácio",
    "lácias": "lácio",
    "lácios": "lácio",
    "láctea": "lácteo",
    "lácteas": "lácteo",
    "lácteos": "lácteo",
    "láctica": "láctico",
    "lácticas": "láctico",
    "lácticos": "láctico",
    "ládanos": "ládano",
    "lágrimas": "lágrima",
    "lájeas": "lájea",
    "láparos": "láparo",
    "lápidas": "lápida",
    "lápides": "lápide",
    "láridas": "lárida",
    "lás": "lá",
    "lástimas": "lástima",
    "lástricos": "lástrico",
    "látegos": "látego",
    "látexes": "látex",
    "látices": "látice",
    "láudanos": "láudano",
    "láurea": "láureo",
    "láureas": "láureo",
    "láureos": "láureo",
    "lázara": "lázaro",
    "lázaras": "lázaro",
    "lázaros": "lázaro",
    "lâmias": "lâmia",
    "lâminas": "lâmina",
    "lâmios": "lâmio",
    "lâmnidas": "lâmnida",
    "lâmpadas": "lâmpada",
    "lâmpona": "lâmpão",
    "lâmponas": "lâmpão",
    "lâmpsanas": "lâmpsana",
    "lâmpões": "lâmpão",
    "lânguida": "lânguido",
    "lânguidas": "lânguido",
    "lânguidos": "lânguido",
    "lãs": "lã",
    "lãzeiras": "lãzeira",
    "lãzinhas": "lãzinha",
    "lãzuda": "lãzudo",
    "lãzudas": "lãzudo",
    "lãzudos": "lãzudo",
    "lécitos": "lécito",
    "lécticas": "léctica",
    "léguas": "légua",
    "lémures": "lémure",
    "lépida": "lépido",
    "lépidas": "lépido",
    "lépidos": "lépido",
    "lérias": "léria",
    "lésbia": "lésbio",
    "lésbias": "lésbio",
    "lésbica": "lésbico",
    "lésbicas": "lésbico",
    "lésbicos": "lésbico",
    "lésbios": "lésbio",
    "léses": "lés",
    "lética": "lético",
    "léticas": "lético",
    "léticos": "lético",
    "léus": "léu",
    "léxica": "léxico",
    "léxicas": "léxico",
    "léxicons": "léxicon",
    "léxicos": "léxico",
    "lê": "ler",
    "lêem": "ler",
    "lêndeas": "lêndea",
    "lêramo": "ler",
    "lêramos": "ler",
    "lêrei": "ler",
    "lêreis": "ler",
    "lês": "ler",
    "lêsseis": "ler",
    "lêssemos": "ler",
    "lêucons": "lêucon",
    "lêveda": "lêvedo",
    "lêvedas": "lêvedo",
    "lêvedos": "lêvedo",
    "líamo": "ler",
    "líamos": "ler",
    "líberes": "líber",
    "líbia": "líbio",
    "líbias": "líbio",
    "líbica": "líbico",
    "líbicas": "líbico",
    "líbicos": "líbico",
    "líbios": "líbio",
    "líbitos": "líbito",
    "lícia": "lício",
    "lícias": "lício",
    "lícios": "lício",
    "lícita": "lícito",
    "lícitas": "lícito",
    "lícitos": "lícito",
    "líderes": "líder",
    "lídia": "lídio",
    "lídias": "lídio",
    "lídima": "lídimo",
    "lídimas": "lídimo",
    "lídimos": "lídimo",
    "lídios": "lídio",
    "líei": "ler",
    "líeis": "ler",
    "lígia": "lígio",
    "lígias": "lígio",
    "lígios": "lígio",
    "lígnea": "lígneo",
    "lígneas": "lígneo",
    "lígneos": "lígneo",
    "lígulas": "lígula",
    "lígulos": "lígulo",
    "lígures": "lígure",
    "límbica": "límbico",
    "límbicas": "límbico",
    "límbicos": "límbico",
    "límnica": "límnico",
    "límnicas": "límnico",
    "límnicos": "límnico",
    "límpida": "límpido",
    "límpidas": "límpido",
    "límpidos": "límpido",
    "línea": "líneo",
    "líneas": "líneo",
    "líneos": "líneo",
    "línguas": "língua",
    "língulas": "língula",
    "lípases": "lípase",
    "lípidos": "lípido",
    "líquens": "líquen",
    "líquida": "líquido",
    "líquidas": "líquido",
    "líquidos": "líquido",
    "lírias": "líria",
    "lírica": "lírico",
    "líricas": "lírico",
    "líricos": "lírico",
    "lírios": "lírio",
    "lísia": "lísio",
    "lísias": "lísio",
    "lísios": "lísio",
    "lítias": "lítia",
    "lítica": "lítico",
    "líticas": "lítico",
    "líticos": "lítico",
    "lítios": "lítio",
    "lítuos": "lítuo",
    "lívias": "lívia",
    "lívida": "lívido",
    "lívidas": "lívido",
    "lívidos": "lívido",
    "lóbis": "lóbi",
    "lóbulos": "lóbulo",
    "lóculos": "lóculo",
    "lódões": "lódão",
    "lógias": "lógia",
    "lógica": "lógico",
    "lógicas": "lógico",
    "lógicos": "lógico",
    "lóia": "lóio",
    "lóias": "lóio",
    "lóios": "lóio",
    "lólios": "lólio",
    "lós": "ló",
    "lôbrega": "lôbrego",
    "lôbregas": "lôbrego",
    "lôbregos": "lôbrego",
    "lúbrica": "lúbrico",
    "lúbricas": "lúbrico",
    "lúbricos": "lúbrico",
    "lúcida": "lúcido",
    "lúcidas": "lúcido",
    "lúcidos": "lúcido",
    "lúcios": "lúcio",
    "lúculas": "lúcula",
    "lúdica": "lúdico",
    "lúdicas": "lúdico",
    "lúdicos": "lúdico",
    "lúdions": "lúdion",
    "lúdios": "lúdio",
    "lúdrica": "lúdrico",
    "lúdricas": "lúdrico",
    "lúdricos": "lúdrico",
    "lúgares": "lúgar",
    "lúgubres": "lúgubre",
    "lúmens": "lúmen",
    "lúmpens": "lúmpen",
    "lúnulas": "lúnula",
    "lúparos": "lúparo",
    "lúpias": "lúpia",
    "lúpulos": "lúpulo",
    "lúpuros": "lúpuro",
    "lúrias": "lúria",
    "lúrica": "lúrico",
    "lúricas": "lúrico",
    "lúricos": "lúrico",
    "lúzios": "lúzio",
    "maaianas": "maaiana",
    "mabecos": "mabeco",
    "mabeias": "mabeia",
    "mabelas": "mabela",
    "maboungas": "mabounga",
    "mabus": "mabu",
    "macabeia": "macabeu",
    "macabeias": "macabeu",
    "macabeus": "macabeu",
    "macabra": "macabro",
    "macabras": "macabro",
    "macabrismos": "macabrismo",
    "macabros": "macabro",
    "macaca": "macaco",
    "macacadas": "macacada",
    "macacais": "macacal",
    "macacarias": "macacaria",
    "macacas": "macaco",
    "macacaúbas": "macacaúba",
    "macacoas": "macacoa",
    "macacona": "macacão",
    "macaconas": "macacão",
    "macacos": "macaco",
    "macacória": "macacório",
    "macacórias": "macacório",
    "macacórios": "macacório",
    "macacões": "macacão",
    "macadames": "macadame",
    "macadamiza": "macadamizar",
    "macadamizada": "macadamizar",
    "macadamizadas": "macadamizar",
    "macadamizado": "macadamizar",
    "macadamizados": "macadamizar",
    "macadamizai": "macadamizar",
    "macadamizais": "macadamizar",
    "macadamizam": "macadamizar",
    "macadamizamo": "macadamizar",
    "macadamizamos": "macadamizar",
    "macadamizando": "macadamizar",
    "macadamizara": "macadamizar",
    "macadamizaram": "macadamizar",
    "macadamizaras": "macadamizar",
    "macadamizarde": "macadamizar",
    "macadamizardes": "macadamizar",
    "macadamizare": "macadamizar",
    "macadamizarei": "macadamizar",
    "macadamizareis": "macadamizar",
    "macadamizarem": "macadamizar",
    "macadamizaremos": "macadamizar",
    "macadamizares": "macadamizar",
    "macadamizaria": "macadamizar",
    "macadamizariam": "macadamizar",
    "macadamizarias": "macadamizar",
    "macadamizarmo": "macadamizar",
    "macadamizarmos": "macadamizar",
    "macadamizará": "macadamizar",
    "macadamizarás": "macadamizar",
    "macadamizarão": "macadamizar",
    "macadamizaríamos": "macadamizar",
    "macadamizaríeis": "macadamizar",
    "macadamizas": "macadamizar",
    "macadamizasse": "macadamizar",
    "macadamizassem": "macadamizar",
    "macadamizasses": "macadamizar",
    "macadamizaste": "macadamizar",
    "macadamizastes": "macadamizar",
    "macadamizava": "macadamizar",
    "macadamizavam": "macadamizar",
    "macadamizavas": "macadamizar",
    "macadamizações": "macadamização",
    "macadamize": "macadamizar",
    "macadamizei": "macadamizar",
    "macadamizeis": "macadamizar",
    "macadamizem": "macadamizar",
    "macadamizemo": "macadamizar",
    "macadamizemos": "macadamizar",
    "macadamizes": "macadamizar",
    "macadamizo": "macadamizar",
    "macadamizou": "macadamizar",
    "macadamizá": "macadamizar",
    "macadamizámo": "macadamizar",
    "macadamizámos": "macadamizar",
    "macadamizáramo": "macadamizar",
    "macadamizáramos": "macadamizar",
    "macadamizárei": "macadamizar",
    "macadamizáreis": "macadamizar",
    "macadamizásseis": "macadamizar",
    "macadamizássemos": "macadamizar",
    "macadamizávamo": "macadamizar",
    "macadamizávamos": "macadamizar",
    "macadamizávei": "macadamizar",
    "macadamizáveis": "macadamizar",
    "macaenses": "macaense",
    "macaios": "macaio",
    "macambuzices": "macambuzice",
    "macambúzia": "macambúzio",
    "macambúzias": "macambúzio",
    "macambúzios": "macambúzio",
    "macanja": "macanjo",
    "macanjas": "macanjo",
    "macanjices": "macanjice",
    "macanjos": "macanjo",
    "macanás": "macaná",
    "macaqueada": "macaquear",
    "macaqueadas": "macaquear",
    "macaqueado": "macaquear",
    "macaqueadora": "macaqueador",
    "macaqueadoras": "macaqueador",
    "macaqueadores": "macaqueador",
    "macaqueados": "macaquear",
    "macaqueai": "macaquear",
    "macaqueais": "macaquear",
    "macaqueamo": "macaquear",
    "macaqueamos": "macaquear",
    "macaqueando": "macaquear",
    "macaqueara": "macaquear",
    "macaquearam": "macaquear",
    "macaquearas": "macaquear",
    "macaquearde": "macaquear",
    "macaqueardes": "macaquear",
    "macaqueare": "macaquear",
    "macaquearei": "macaquear",
    "macaqueareis": "macaquear",
    "macaquearem": "macaquear",
    "macaquearemos": "macaquear",
    "macaqueares": "macaquear",
    "macaquearia": "macaquear",
    "macaqueariam": "macaquear",
    "macaquearias": "macaquear",
    "macaquearmo": "macaquear",
    "macaquearmos": "macaquear",
    "macaqueará": "macaquear",
    "macaquearás": "macaquear",
    "macaquearão": "macaquear",
    "macaquearíamos": "macaquear",
    "macaquearíeis": "macaquear",
    "macaqueasse": "macaquear",
    "macaqueassem": "macaquear",
    "macaqueasses": "macaquear",
    "macaqueaste": "macaquear",
    "macaqueastes": "macaquear",
    "macaqueava": "macaquear",
    "macaqueavam": "macaquear",
    "macaqueavas": "macaquear",
    "macaqueações": "macaqueação",
    "macaqueei": "macaquear",
    "macaqueeis": "macaquear",
    "macaqueemo": "macaquear",
    "macaqueemos": "macaquear",
    "macaqueia": "macaquear",
    "macaqueiam": "macaquear",
    "macaqueias": "macaquear",
    "macaqueie": "macaquear",
    "macaqueiem": "macaquear",
    "macaqueies": "macaquear",
    "macaqueio": "macaquear",
    "macaqueira": "macaqueiro",
    "macaqueiras": "macaqueiro",
    "macaqueiros": "macaqueiro",
    "macaqueou": "macaquear",
    "macaqueá": "macaquear",
    "macaqueámo": "macaquear",
    "macaqueámos": "macaquear",
    "macaqueáramo": "macaquear",
    "macaqueáramos": "macaquear",
    "macaqueárei": "macaquear",
    "macaqueáreis": "macaquear",
    "macaqueásseis": "macaquear",
    "macaqueássemos": "macaquear",
    "macaqueávamo": "macaquear",
    "macaqueávamos": "macaquear",
    "macaqueávei": "macaquear",
    "macaqueáveis": "macaquear",
    "macaquices": "macaquice",
    "macaquinha": "macaco",
    "macaquinhas": "macaco",
    "macaquinho": "macaco",
    "macaquinhos": "macaco",
    "macaquita": "macaco",
    "macaquitas": "macaco",
    "macaquito": "macaco",
    "macaquitos": "macaco",
    "macarena": "macareno",
    "macarenas": "macareno",
    "macarenos": "macareno",
    "macarites": "macarite",
    "macarronadas": "macarronada",
    "macarroneira": "macarroneiro",
    "macarroneiras": "macarroneiro",
    "macarroneiros": "macarroneiro",
    "macarrones": "macarrone",
    "macarronetes": "macarronete",
    "macarronismos": "macarronismo",
    "macarronistas": "macarronista",
    "macarróneas": "macarrónea",
    "macarrónica": "macarrónico",
    "macarrónicas": "macarrónico",
    "macarrónicos": "macarrónico",
    "macarrões": "macarrão",
    "macaréus": "macaréu",
    "macas": "maca",
    "macaus": "macau",
    "macavenca": "macavenco",
    "macavencada": "macavencar",
    "macavencadas": "macavencar",
    "macavencado": "macavencar",
    "macavencados": "macavencar",
    "macavencais": "macavencar",
    "macavencam": "macavencar",
    "macavencamo": "macavencar",
    "macavencamos": "macavencar",
    "macavencando": "macavencar",
    "macavencara": "macavencar",
    "macavencaram": "macavencar",
    "macavencaras": "macavencar",
    "macavencardes": "macavencar",
    "macavencarei": "macavencar",
    "macavencareis": "macavencar",
    "macavencarem": "macavencar",
    "macavencaremos": "macavencar",
    "macavencares": "macavencar",
    "macavencaria": "macavencar",
    "macavencariam": "macavencar",
    "macavencarias": "macavencar",
    "macavencarmo": "macavencar",
    "macavencarmos": "macavencar",
    "macavencará": "macavencar",
    "macavencarás": "macavencar",
    "macavencarão": "macavencar",
    "macavencaríamos": "macavencar",
    "macavencaríeis": "macavencar",
    "macavencas": "macavenco",
    "macavencasse": "macavencar",
    "macavencassem": "macavencar",
    "macavencasses": "macavencar",
    "macavencaste": "macavencar",
    "macavencastes": "macavencar",
    "macavencava": "macavencar",
    "macavencavam": "macavencar",
    "macavencavas": "macavencar",
    "macavenco": "macavencar",
    "macavencos": "macavenco",
    "macavencou": "macavencar",
    "macavencámo": "macavencar",
    "macavencámos": "macavencar",
    "macavencáramo": "macavencar",
    "macavencáramos": "macavencar",
    "macavencáreis": "macavencar",
    "macavencásseis": "macavencar",
    "macavencássemos": "macavencar",
    "macavencávamo": "macavencar",
    "macavencávamos": "macavencar",
    "macavencáveis": "macavencar",
    "macavenque": "macavencar",
    "macavenquei": "macavencar",
    "macavenqueis": "macavencar",
    "macavenquem": "macavencar",
    "macavenquemos": "macavencar",
    "macavenques": "macavencar",
    "macaçotes": "macaçote",
    "macaístas": "macaísta",
    "macaúbas": "macaúba",
    "maccartismos": "maccartismo",
    "maccartistas": "maccartista",
    "mace": "maçar",
    "macedónia": "macedónio",
    "macedónias": "macedónio",
    "macedónica": "macedónico",
    "macedónicas": "macedónico",
    "macedónicos": "macedónico",
    "macedónios": "macedónio",
    "macegais": "macegal",
    "macegas": "macega",
    "macei": "maçar",
    "maceiras": "maceira",
    "maceiros": "maceiro",
    "maceis": "maçar",
    "macelas": "macela",
    "macelões": "macelão",
    "macem": "maçar",
    "macemo": "maçar",
    "macemos": "maçar",
    "macera": "macerar",
    "macerada": "macerar",
    "maceradas": "macerar",
    "macerado": "macerar",
    "macerados": "macerar",
    "macerai": "macerar",
    "macerais": "macerar",
    "maceram": "macerar",
    "maceramentos": "maceramento",
    "maceramo": "macerar",
    "maceramos": "macerar",
    "macerando": "macerar",
    "macerara": "macerar",
    "maceraram": "macerar",
    "maceraras": "macerar",
    "macerarde": "macerar",
    "macerardes": "macerar",
    "macerare": "macerar",
    "macerarei": "macerar",
    "macerareis": "macerar",
    "macerarem": "macerar",
    "maceraremos": "macerar",
    "macerares": "macerar",
    "maceraria": "macerar",
    "macerariam": "macerar",
    "macerarias": "macerar",
    "macerarmo": "macerar",
    "macerarmos": "macerar",
    "macerará": "macerar",
    "macerarás": "macerar",
    "macerarão": "macerar",
    "maceraríamos": "macerar",
    "maceraríeis": "macerar",
    "maceras": "macerar",
    "macerasse": "macerar",
    "macerassem": "macerar",
    "macerasses": "macerar",
    "maceraste": "macerar",
    "macerastes": "macerar",
    "macerava": "macerar",
    "maceravam": "macerar",
    "maceravas": "macerar",
    "macerações": "maceração",
    "macere": "macerar",
    "macerei": "macerar",
    "macereis": "macerar",
    "macerem": "macerar",
    "maceremo": "macerar",
    "maceremos": "macerar",
    "maceres": "macerar",
    "macero": "macerar",
    "macerou": "macerar",
    "macerá": "macerar",
    "macerámo": "macerar",
    "macerámos": "macerar",
    "maceráramo": "macerar",
    "maceráramos": "macerar",
    "macerárei": "macerar",
    "maceráreis": "macerar",
    "macerásseis": "macerar",
    "macerássemos": "macerar",
    "macerávamo": "macerar",
    "macerávamos": "macerar",
    "macerávei": "macerar",
    "maceráveis": "macerável",
    "maces": "maçar",
    "maceta": "macetar",
    "macetada": "macetar",
    "macetadas": "macetar",
    "macetado": "macetar",
    "macetados": "macetar",
    "macetai": "macetar",
    "macetais": "macetar",
    "macetam": "macetar",
    "macetamo": "macetar",
    "macetamos": "macetar",
    "macetando": "macetar",
    "macetara": "macetar",
    "macetaram": "macetar",
    "macetaras": "macetar",
    "macetarde": "macetar",
    "macetardes": "macetar",
    "macetare": "macetar",
    "macetarei": "macetar",
    "macetareis": "macetar",
    "macetarem": "macetar",
    "macetaremos": "macetar",
    "macetares": "macetar",
    "macetaria": "macetar",
    "macetariam": "macetar",
    "macetarias": "macetar",
    "macetarmo": "macetar",
    "macetarmos": "macetar",
    "macetará": "macetar",
    "macetarás": "macetar",
    "macetarão": "macetar",
    "macetaríamos": "macetar",
    "macetaríeis": "macetar",
    "macetas": "macetar",
    "macetasse": "macetar",
    "macetassem": "macetar",
    "macetasses": "macetar",
    "macetaste": "macetar",
    "macetastes": "macetar",
    "macetava": "macetar",
    "macetavam": "macetar",
    "macetavas": "macetar",
    "macete": "macetar",
    "maceteada": "macetear",
    "maceteadas": "macetear",
    "maceteado": "macetear",
    "maceteados": "macetear",
    "maceteai": "macetear",
    "maceteais": "macetear",
    "maceteamo": "macetear",
    "maceteamos": "macetear",
    "maceteando": "macetear",
    "maceteara": "macetear",
    "macetearam": "macetear",
    "macetearas": "macetear",
    "maceteardes": "macetear",
    "macetearei": "macetear",
    "maceteareis": "macetear",
    "macetearem": "macetear",
    "macetearemos": "macetear",
    "maceteares": "macetear",
    "macetearia": "macetear",
    "maceteariam": "macetear",
    "macetearias": "macetear",
    "macetearmo": "macetear",
    "macetearmos": "macetear",
    "maceteará": "macetear",
    "macetearás": "macetear",
    "macetearão": "macetear",
    "macetearíamos": "macetear",
    "macetearíeis": "macetear",
    "maceteasse": "macetear",
    "maceteassem": "macetear",
    "maceteasses": "macetear",
    "maceteaste": "macetear",
    "maceteastes": "macetear",
    "maceteava": "macetear",
    "maceteavam": "macetear",
    "maceteavas": "macetear",
    "maceteei": "macetear",
    "maceteeis": "macetear",
    "maceteemo": "macetear",
    "maceteemos": "macetear",
    "macetei": "macetar",
    "maceteia": "macetear",
    "maceteiam": "macetear",
    "maceteias": "macetear",
    "maceteie": "macetear",
    "maceteiem": "macetear",
    "maceteies": "macetear",
    "maceteio": "macetear",
    "maceteis": "macetar",
    "macetem": "macetar",
    "macetemo": "macetar",
    "macetemos": "macetar",
    "maceteou": "macetear",
    "macetes": "macete",
    "maceteámo": "macetear",
    "maceteámos": "macetear",
    "maceteáramo": "macetear",
    "maceteáramos": "macetear",
    "maceteáreis": "macetear",
    "maceteásseis": "macetear",
    "maceteássemos": "macetear",
    "maceteávamo": "macetear",
    "maceteávamos": "macetear",
    "maceteáveis": "macetear",
    "maceto": "macetar",
    "macetou": "macetar",
    "macetá": "macetar",
    "macetámo": "macetar",
    "macetámos": "macetar",
    "macetáramo": "macetar",
    "macetáramos": "macetar",
    "macetárei": "macetar",
    "macetáreis": "macetar",
    "macetásseis": "macetar",
    "macetássemos": "macetar",
    "macetávamo": "macetar",
    "macetávamos": "macetar",
    "macetávei": "macetar",
    "macetáveis": "macetar",
    "macha": "macho",
    "machacazes": "machacaz",
    "machacazs": "machacaz",
    "machada": "machadar",
    "machadada": "machadar",
    "machadadas": "machadar",
    "machadado": "machadar",
    "machadados": "machadar",
    "machadai": "machadar",
    "machadais": "machadar",
    "machadam": "machadar",
    "machadamo": "machadar",
    "machadamos": "machadar",
    "machadando": "machadar",
    "machadara": "machadar",
    "machadaram": "machadar",
    "machadaras": "machadar",
    "machadardes": "machadar",
    "machadarei": "machadar",
    "machadareis": "machadar",
    "machadarem": "machadar",
    "machadaremos": "machadar",
    "machadares": "machadar",
    "machadaria": "machadar",
    "machadariam": "machadar",
    "machadarias": "machadar",
    "machadarmo": "machadar",
    "machadarmos": "machadar",
    "machadará": "machadar",
    "machadarás": "machadar",
    "machadarão": "machadar",
    "machadaríamos": "machadar",
    "machadaríeis": "machadar",
    "machadas": "machadar",
    "machadasse": "machadar",
    "machadassem": "machadar",
    "machadasses": "machadar",
    "machadaste": "machadar",
    "machadastes": "machadar",
    "machadava": "machadar",
    "machadavam": "machadar",
    "machadavas": "machadar",
    "machade": "machadar",
    "machadei": "machadar",
    "machadeis": "machadar",
    "machadem": "machadar",
    "machademo": "machadar",
    "machademos": "machadar",
    "machades": "machadar",
    "machadiana": "machadiano",
    "machadianas": "machadiano",
    "machadianos": "machadiano",
    "machado": "machadar",
    "machados": "machado",
    "machadou": "machadar",
    "machadámo": "machadar",
    "machadámos": "machadar",
    "machadáramo": "machadar",
    "machadáramos": "machadar",
    "machadáreis": "machadar",
    "machadásseis": "machadar",
    "machadássemos": "machadar",
    "machadávamo": "machadar",
    "machadávamos": "machadar",
    "machadáveis": "machadar",
    "machaquezes": "machaquez",
    "macharrões": "macharrão",
    "machas": "macho",
    "machatins": "machatim",
    "macheada": "machear",
    "macheadas": "machear",
    "macheado": "machear",
    "macheados": "machear",
    "macheai": "machear",
    "macheais": "machear",
    "macheamo": "machear",
    "macheamos": "machear",
    "macheando": "machear",
    "macheara": "machear",
    "machearam": "machear",
    "machearas": "machear",
    "machearde": "machear",
    "macheardes": "machear",
    "macheare": "machear",
    "machearei": "machear",
    "macheareis": "machear",
    "machearem": "machear",
    "machearemos": "machear",
    "macheares": "machear",
    "machearia": "machear",
    "macheariam": "machear",
    "machearias": "machear",
    "machearmo": "machear",
    "machearmos": "machear",
    "macheará": "machear",
    "machearás": "machear",
    "machearão": "machear",
    "machearíamos": "machear",
    "machearíeis": "machear",
    "macheasse": "machear",
    "macheassem": "machear",
    "macheasses": "machear",
    "macheaste": "machear",
    "macheastes": "machear",
    "macheava": "machear",
    "macheavam": "machear",
    "macheavas": "machear",
    "macheei": "machear",
    "macheeis": "machear",
    "macheemo": "machear",
    "macheemos": "machear",
    "macheia": "machear",
    "macheiam": "machear",
    "macheias": "macheia",
    "macheiazinha": "macheia",
    "macheiazinhas": "macheia",
    "macheiazita": "macheia",
    "macheiazitas": "macheia",
    "macheie": "machear",
    "macheiem": "machear",
    "macheies": "machear",
    "macheio": "machear",
    "macheiros": "macheiro",
    "macheou": "machear",
    "machetadas": "machetada",
    "machetes": "machete",
    "macheá": "machear",
    "macheámo": "machear",
    "macheámos": "machear",
    "macheáramo": "machear",
    "macheáramos": "machear",
    "macheárei": "machear",
    "macheáreis": "machear",
    "macheásseis": "machear",
    "macheássemos": "machear",
    "macheávamo": "machear",
    "macheávamos": "machear",
    "macheávei": "machear",
    "macheáveis": "machear",
    "machia": "machio",
    "machiada": "machiar",
    "machiadas": "machiar",
    "machiado": "machiar",
    "machiados": "machiar",
    "machiai": "machiar",
    "machiais": "machiar",
    "machiam": "machiar",
    "machiamo": "machiar",
    "machiamos": "machiar",
    "machiando": "machiar",
    "machiara": "machiar",
    "machiaram": "machiar",
    "machiaras": "machiar",
    "machiardes": "machiar",
    "machiarei": "machiar",
    "machiareis": "machiar",
    "machiarem": "machiar",
    "machiaremos": "machiar",
    "machiares": "machiar",
    "machiaria": "machiar",
    "machiariam": "machiar",
    "machiarias": "machiar",
    "machiarmo": "machiar",
    "machiarmos": "machiar",
    "machiará": "machiar",
    "machiarás": "machiar",
    "machiarão": "machiar",
    "machiaríamos": "machiar",
    "machiaríeis": "machiar",
    "machias": "machio",
    "machiasse": "machiar",
    "machiassem": "machiar",
    "machiasses": "machiar",
    "machiaste": "machiar",
    "machiastes": "machiar",
    "machiava": "machiar",
    "machiavam": "machiar",
    "machiavas": "machiar",
    "machie": "machiar",
    "machiei": "machiar",
    "machieirais": "machieiral",
    "machieis": "machiar",
    "machiem": "machiar",
    "machiemo": "machiar",
    "machiemos": "machiar",
    "machies": "machiar",
    "machilas": "machila",
    "machileira": "machileiro",
    "machileiras": "machileiro",
    "machileiros": "machileiro",
    "machimbombos": "machimbombo",
    "machinhas": "machinha",
    "machins": "machim",
    "machio": "machiar",
    "machios": "machio",
    "machiou": "machiar",
    "machiras": "machira",
    "machismos": "machismo",
    "machistas": "machista",
    "machiámo": "machiar",
    "machiámos": "machiar",
    "machiáramo": "machiar",
    "machiáramos": "machiar",
    "machiáreis": "machiar",
    "machiásseis": "machiar",
    "machiássemos": "machiar",
    "machiávamo": "machiar",
    "machiávamos": "machiar",
    "machiáveis": "machiar",
    "machocas": "machoca",
    "machocos": "machoco",
    "machona": "machão",
    "machonas": "machona",
    "machorras": "machorra",
    "machos": "macho",
    "machuca": "machucar",
    "machucada": "machucar",
    "machucadas": "machucar",
    "machucado": "machucar",
    "machucadora": "machucador",
    "machucadoras": "machucador",
    "machucadores": "machucador",
    "machucados": "machucar",
    "machucaduras": "machucadura",
    "machucai": "machucar",
    "machucais": "machucar",
    "machucam": "machucar",
    "machucamo": "machucar",
    "machucamos": "machucar",
    "machucando": "machucar",
    "machucara": "machucar",
    "machucaram": "machucar",
    "machucaras": "machucar",
    "machucarde": "machucar",
    "machucardes": "machucar",
    "machucare": "machucar",
    "machucarei": "machucar",
    "machucareis": "machucar",
    "machucarem": "machucar",
    "machucaremos": "machucar",
    "machucares": "machucar",
    "machucaria": "machucar",
    "machucariam": "machucar",
    "machucarias": "machucar",
    "machucarmo": "machucar",
    "machucarmos": "machucar",
    "machucará": "machucar",
    "machucarás": "machucar",
    "machucarão": "machucar",
    "machucaríamos": "machucar",
    "machucaríeis": "machucar",
    "machucas": "machucar",
    "machucasse": "machucar",
    "machucassem": "machucar",
    "machucasses": "machucar",
    "machucaste": "machucar",
    "machucastes": "machucar",
    "machucava": "machucar",
    "machucavam": "machucar",
    "machucavas": "machucar",
    "machucações": "machucação",
    "machucha": "machucho",
    "machuchas": "machucho",
    "machuchos": "machucho",
    "machuco": "machucar",
    "machucos": "machuco",
    "machucou": "machucar",
    "machucá": "machucar",
    "machucámo": "machucar",
    "machucámos": "machucar",
    "machucáramo": "machucar",
    "machucáramos": "machucar",
    "machucárei": "machucar",
    "machucáreis": "machucar",
    "machucásseis": "machucar",
    "machucássemos": "machucar",
    "machucávamo": "machucar",
    "machucávamos": "machucar",
    "machucávei": "machucar",
    "machucáveis": "machucar",
    "machuque": "machucar",
    "machuquei": "machucar",
    "machuqueiras": "machuqueira",
    "machuqueiros": "machuqueiro",
    "machuqueis": "machucar",
    "machuquem": "machucar",
    "machuquemo": "machucar",
    "machuquemos": "machucar",
    "machuques": "machucar",
    "machões": "machão",
    "macia": "macio",
    "maciada": "maciar",
    "maciadas": "maciar",
    "maciado": "maciar",
    "maciados": "maciar",
    "maciai": "maciar",
    "maciais": "maciar",
    "maciam": "maciar",
    "maciamo": "maciar",
    "maciamos": "maciar",
    "maciando": "maciar",
    "maciara": "maciar",
    "maciaram": "maciar",
    "maciaras": "maciar",
    "maciarde": "maciar",
    "maciardes": "maciar",
    "maciare": "maciar",
    "maciarei": "maciar",
    "maciareis": "maciar",
    "maciarem": "maciar",
    "maciaremos": "maciar",
    "maciares": "maciar",
    "maciaria": "maciar",
    "maciariam": "maciar",
    "maciarias": "maciar",
    "maciarmo": "maciar",
    "maciarmos": "maciar",
    "maciará": "maciar",
    "maciarás": "maciar",
    "maciarão": "maciar",
    "maciaríamos": "maciar",
    "maciaríeis": "maciar",
    "macias": "macio",
    "maciasse": "maciar",
    "maciassem": "maciar",
    "maciasses": "maciar",
    "maciaste": "maciar",
    "maciastes": "maciar",
    "maciava": "maciar",
    "maciavam": "maciar",
    "maciavas": "maciar",
    "maciazinha": "macio",
    "maciazinhas": "macio",
    "maciazita": "macio",
    "maciazitas": "macio",
    "macicezes": "macicez",
    "macie": "maciar",
    "maciei": "maciar",
    "macieiras": "macieira",
    "macieis": "maciar",
    "maciem": "maciar",
    "maciemo": "maciar",
    "maciemos": "maciar",
    "macies": "maciar",
    "maciez": "macieza",
    "maciezas": "macieza",
    "macilenta": "macilento",
    "macilentas": "macilento",
    "macilentos": "macilento",
    "macilências": "macilência",
    "macinas": "macina",
    "macinho": "maço",
    "macinhos": "maço",
    "macio": "maciar",
    "macios": "macio",
    "maciotas": "maciota",
    "maciou": "maciar",
    "maciozinho": "macio",
    "maciozinhos": "macio",
    "maciozito": "macio",
    "maciozitos": "macio",
    "macises": "macis",
    "macito": "maço",
    "macitos": "maço",
    "maciá": "maciar",
    "maciámo": "maciar",
    "maciámos": "maciar",
    "maciáramo": "maciar",
    "maciáramos": "maciar",
    "maciárei": "maciar",
    "maciáreis": "maciar",
    "maciásseis": "maciar",
    "maciássemos": "maciar",
    "maciávamo": "maciar",
    "maciávamos": "maciar",
    "maciávei": "maciar",
    "maciáveis": "maciar",
    "maciça": "maciço",
    "maciças": "maciço",
    "maciços": "maciço",
    "maciíssima": "macio",
    "maciíssimas": "macio",
    "maciíssimo": "macio",
    "maciíssimos": "macio",
    "maclada": "maclado",
    "macladas": "maclado",
    "maclados": "maclado",
    "maclas": "macla",
    "macolola": "macololo",
    "macololas": "macololo",
    "macololos": "macololo",
    "macomas": "macoma",
    "macombas": "macomba",
    "macombeiras": "macombeira",
    "macomeiras": "macomeira",
    "macotas": "macota",
    "macradénias": "macradénia",
    "macramés": "macramé",
    "macrandros": "macrandro",
    "macranta": "macranto",
    "macrantas": "macranto",
    "macrantos": "macranto",
    "macrobias": "macrobia",
    "macrobiotismos": "macrobiotismo",
    "macrobiótica": "macrobiótico",
    "macrobióticas": "macrobiótico",
    "macrobióticos": "macrobiótico",
    "macrocefalias": "macrocefalia",
    "macrocefálica": "macrocefálico",
    "macrocefálicas": "macrocefálico",
    "macrocefálicos": "macrocefálico",
    "macrocistes": "macrociste",
    "macrocistos": "macrocisto",
    "macrocosmologias": "macrocosmologia",
    "macrocosmos": "macrocosmo",
    "macrocéfala": "macrocéfalo",
    "macrocéfalas": "macrocéfalo",
    "macrocéfalos": "macrocéfalo",
    "macrocósmica": "macrocósmico",
    "macrocósmicas": "macrocósmico",
    "macrocósmicos": "macrocósmico",
    "macrodiagonais": "macrodiagonal",
    "macrodomas": "macrodoma",
    "macrodontes": "macrodonte",
    "macrodáctila": "macrodáctilo",
    "macrodáctilas": "macrodáctilo",
    "macrodáctilos": "macrodáctilo",
    "macroeconomias": "macroeconomia",
    "macroeconómica": "macroeconómico",
    "macroeconómicas": "macroeconómico",
    "macroeconómicos": "macroeconómico",
    "macroencefalias": "macroencefalia",
    "macroestados": "macroestado",
    "macroglossa": "macroglosso",
    "macroglossas": "macroglosso",
    "macroglossos": "macroglosso",
    "macrologias": "macrologia",
    "macrológica": "macrológico",
    "macrológicas": "macrológico",
    "macrológicos": "macrológico",
    "macromelias": "macromelia",
    "macromélica": "macromélico",
    "macromélicas": "macromélico",
    "macromélicos": "macromélico",
    "macromérica": "macromérico",
    "macroméricas": "macromérico",
    "macroméricos": "macromérico",
    "macronúcleos": "macronúcleo",
    "macropias": "macropia",
    "macropsias": "macropsia",
    "macropétala": "macropétalo",
    "macropétalas": "macropétalo",
    "macropétalos": "macropétalo",
    "macroreligiões": "macroreligião",
    "macrorriza": "macrorrizo",
    "macrorrizas": "macrorrizo",
    "macrorrizos": "macrorrizo",
    "macros": "macro",
    "macroscelias": "macroscelia",
    "macroscelídeos": "macroscelídeo",
    "macroscélica": "macroscélico",
    "macroscélicas": "macroscélico",
    "macroscélicos": "macroscélico",
    "macroscélidas": "macroscélida",
    "macroscópica": "macroscópico",
    "macroscópicas": "macroscópico",
    "macroscópicos": "macroscópico",
    "macrosporofilos": "macrosporofilo",
    "macrosporângios": "macrosporângio",
    "macrossismos": "macrossismo",
    "macrossísmica": "macrossísmico",
    "macrossísmicas": "macrossísmico",
    "macrossísmicos": "macrossísmico",
    "macrostila": "macrostilo",
    "macrostilas": "macrostilo",
    "macrostilos": "macrostilo",
    "macrotársica": "macrotársico",
    "macrotársicas": "macrotársico",
    "macrotársicos": "macrotársico",
    "macrura": "macruro",
    "macruras": "macruro",
    "macruros": "macruro",
    "macrurídeos": "macrurídeo",
    "macróbia": "macróbio",
    "macróbias": "macróbio",
    "macróbios": "macróbio",
    "macrócera": "macrócero",
    "macróceras": "macrócero",
    "macróceros": "macrócero",
    "macrócitos": "macrócito",
    "macrócoma": "macrócomo",
    "macrócomas": "macrócomo",
    "macrócomos": "macrócomo",
    "macrófagos": "macrófago",
    "macrófitos": "macrófito",
    "macrómeros": "macrómero",
    "macrópodes": "macrópode",
    "macrópsica": "macrópsico",
    "macrópsicas": "macrópsico",
    "macrópsicos": "macrópsico",
    "macróptera": "macróptero",
    "macrópteras": "macróptero",
    "macrópteros": "macróptero",
    "macróscia": "macróscio",
    "macróscias": "macróscio",
    "macróscios": "macróscio",
    "macrósporos": "macrósporo",
    "macróstica": "macróstico",
    "macrósticas": "macróstico",
    "macrósticos": "macróstico",
    "macrúridas": "macrúrida",
    "mactrismos": "mactrismo",
    "macuanas": "macuana",
    "macuas": "macua",
    "macucas": "macuca",
    "macucos": "macuco",
    "macucus": "macucu",
    "macula": "macular",
    "maculada": "macular",
    "maculadas": "macular",
    "maculado": "macular",
    "maculadora": "maculador",
    "maculadoras": "maculador",
    "maculadores": "maculador",
    "maculados": "macular",
    "maculai": "macular",
    "maculais": "macular",
    "maculam": "macular",
    "maculamo": "macular",
    "maculamos": "macular",
    "maculando": "macular",
    "maculara": "macular",
    "macularam": "macular",
    "macularas": "macular",
    "macularde": "macular",
    "maculardes": "macular",
    "maculare": "macular",
    "macularei": "macular",
    "maculareis": "macular",
    "macularem": "macular",
    "macularemos": "macular",
    "maculares": "macular",
    "macularia": "macular",
    "maculariam": "macular",
    "macularias": "macular",
    "macularmo": "macular",
    "macularmos": "macular",
    "maculará": "macular",
    "macularás": "macular",
    "macularão": "macular",
    "macularíamos": "macular",
    "macularíeis": "macular",
    "maculas": "macular",
    "maculasse": "macular",
    "maculassem": "macular",
    "maculasses": "macular",
    "maculaste": "macular",
    "maculastes": "macular",
    "maculaturas": "maculatura",
    "maculava": "macular",
    "maculavam": "macular",
    "maculavas": "macular",
    "macule": "macular",
    "maculei": "macular",
    "maculeis": "macular",
    "maculem": "macular",
    "maculemo": "macular",
    "maculemos": "macular",
    "macules": "macular",
    "maculiformes": "maculiforme",
    "maculirrostra": "maculirrostro",
    "maculirrostras": "maculirrostro",
    "maculirrostros": "maculirrostro",
    "maculo": "macular",
    "maculosa": "maculoso",
    "maculosas": "maculoso",
    "maculosos": "maculoso",
    "maculou": "macular",
    "maculá": "macular",
    "maculámo": "macular",
    "maculámos": "macular",
    "maculáramo": "macular",
    "maculáramos": "macular",
    "maculárei": "macular",
    "maculáreis": "macular",
    "maculásseis": "macular",
    "maculássemos": "macular",
    "maculávamo": "macular",
    "maculávamos": "macular",
    "maculávei": "macular",
    "maculáveis": "maculável",
    "macumas": "macuma",
    "macumbas": "macumba",
    "macumbeira": "macumbeiro",
    "macumbeiras": "macumbeiro",
    "macumbeiros": "macumbeiro",
    "macumãs": "macumã",
    "macungos": "macungo",
    "macuás": "macuá",
    "macérias": "macéria",
    "macóbios": "macóbio",
    "madagascarenses": "madagascarense",
    "madalenas": "madalena",
    "madamas": "madama",
    "madames": "madame",
    "madamismos": "madamismo",
    "madapolões": "madapolão",
    "madaroses": "madarose",
    "madefacta": "madefacto",
    "madefactas": "madefacto",
    "madefactos": "madefacto",
    "madefacções": "madefacção",
    "madefica": "madeficar",
    "madeficada": "madeficar",
    "madeficadas": "madeficar",
    "madeficado": "madeficar",
    "madeficados": "madeficar",
    "madeficai": "madeficar",
    "madeficais": "madeficar",
    "madeficam": "madeficar",
    "madeficamo": "madeficar",
    "madeficamos": "madeficar",
    "madeficando": "madeficar",
    "madeficara": "madeficar",
    "madeficaram": "madeficar",
    "madeficaras": "madeficar",
    "madeficarde": "madeficar",
    "madeficardes": "madeficar",
    "madeficare": "madeficar",
    "madeficarei": "madeficar",
    "madeficareis": "madeficar",
    "madeficarem": "madeficar",
    "madeficaremos": "madeficar",
    "madeficares": "madeficar",
    "madeficaria": "madeficar",
    "madeficariam": "madeficar",
    "madeficarias": "madeficar",
    "madeficarmo": "madeficar",
    "madeficarmos": "madeficar",
    "madeficará": "madeficar",
    "madeficarás": "madeficar",
    "madeficarão": "madeficar",
    "madeficaríamos": "madeficar",
    "madeficaríeis": "madeficar",
    "madeficas": "madeficar",
    "madeficasse": "madeficar",
    "madeficassem": "madeficar",
    "madeficasses": "madeficar",
    "madeficaste": "madeficar",
    "madeficastes": "madeficar",
    "madeficava": "madeficar",
    "madeficavam": "madeficar",
    "madeficavas": "madeficar",
    "madefico": "madeficar",
    "madeficou": "madeficar",
    "madeficá": "madeficar",
    "madeficámo": "madeficar",
    "madeficámos": "madeficar",
    "madeficáramo": "madeficar",
    "madeficáramos": "madeficar",
    "madeficárei": "madeficar",
    "madeficáreis": "madeficar",
    "madeficásseis": "madeficar",
    "madeficássemos": "madeficar",
    "madeficávamo": "madeficar",
    "madeficávamos": "madeficar",
    "madeficávei": "madeficar",
    "madeficáveis": "madeficar",
    "madefique": "madeficar",
    "madefiquei": "madeficar",
    "madefiqueis": "madeficar",
    "madefiquem": "madeficar",
    "madefiquemo": "madeficar",
    "madefiquemos": "madeficar",
    "madefiques": "madeficar",
    "madeira": "madeirar",
    "madeirada": "madeirar",
    "madeiradas": "madeirar",
    "madeirado": "madeirar",
    "madeirados": "madeirar",
    "madeirai": "madeirar",
    "madeirais": "madeirar",
    "madeiram": "madeirar",
    "madeiramentos": "madeiramento",
    "madeirames": "madeirame",
    "madeiramo": "madeirar",
    "madeiramos": "madeirar",
    "madeirando": "madeirar",
    "madeirara": "madeirar",
    "madeiraram": "madeirar",
    "madeiraras": "madeirar",
    "madeirarde": "madeirar",
    "madeirardes": "madeirar",
    "madeirare": "madeirar",
    "madeirarei": "madeirar",
    "madeirareis": "madeirar",
    "madeirarem": "madeirar",
    "madeiraremos": "madeirar",
    "madeirares": "madeirar",
    "madeiraria": "madeirar",
    "madeirariam": "madeirar",
    "madeirarias": "madeirar",
    "madeirarmo": "madeirar",
    "madeirarmos": "madeirar",
    "madeirará": "madeirar",
    "madeirarás": "madeirar",
    "madeirarão": "madeirar",
    "madeiraríamos": "madeirar",
    "madeiraríeis": "madeirar",
    "madeiras": "madeirar",
    "madeirasse": "madeirar",
    "madeirassem": "madeirar",
    "madeirasses": "madeirar",
    "madeiraste": "madeirar",
    "madeirastes": "madeirar",
    "madeirava": "madeirar",
    "madeiravam": "madeirar",
    "madeiravas": "madeirar",
    "madeire": "madeirar",
    "madeirei": "madeirar",
    "madeireira": "madeireiro",
    "madeireiras": "madeireiro",
    "madeireiros": "madeireiro",
    "madeireis": "madeirar",
    "madeirem": "madeirar",
    "madeiremo": "madeirar",
    "madeiremos": "madeirar",
    "madeirenses": "madeirense",
    "madeires": "madeirar",
    "madeirinha": "madeira",
    "madeirinhas": "madeira",
    "madeirita": "madeira",
    "madeiritas": "madeira",
    "madeiro": "madeirar",
    "madeiros": "madeiro",
    "madeirou": "madeirar",
    "madeirá": "madeirar",
    "madeirámo": "madeirar",
    "madeirámos": "madeirar",
    "madeiráramo": "madeirar",
    "madeiráramos": "madeirar",
    "madeirárei": "madeirar",
    "madeiráreis": "madeirar",
    "madeirásseis": "madeirar",
    "madeirássemos": "madeirar",
    "madeirávamo": "madeirar",
    "madeirávamos": "madeirar",
    "madeirávei": "madeirar",
    "madeiráveis": "madeirar",
    "madeixa": "madeixar",
    "madeixada": "madeixar",
    "madeixadas": "madeixar",
    "madeixado": "madeixar",
    "madeixados": "madeixar",
    "madeixai": "madeixar",
    "madeixais": "madeixar",
    "madeixam": "madeixar",
    "madeixamo": "madeixar",
    "madeixamos": "madeixar",
    "madeixando": "madeixar",
    "madeixara": "madeixar",
    "madeixaram": "madeixar",
    "madeixaras": "madeixar",
    "madeixarde": "madeixar",
    "madeixardes": "madeixar",
    "madeixare": "madeixar",
    "madeixarei": "madeixar",
    "madeixareis": "madeixar",
    "madeixarem": "madeixar",
    "madeixaremos": "madeixar",
    "madeixares": "madeixar",
    "madeixaria": "madeixar",
    "madeixariam": "madeixar",
    "madeixarias": "madeixar",
    "madeixarmo": "madeixar",
    "madeixarmos": "madeixar",
    "madeixará": "madeixar",
    "madeixarás": "madeixar",
    "madeixarão": "madeixar",
    "madeixaríamos": "madeixar",
    "madeixaríeis": "madeixar",
    "madeixas": "madeixar",
    "madeixasse": "madeixar",
    "madeixassem": "madeixar",
    "madeixasses": "madeixar",
    "madeixaste": "madeixar",
    "madeixastes": "madeixar",
    "madeixava": "madeixar",
    "madeixavam": "madeixar",
    "madeixavas": "madeixar",
    "madeixe": "madeixar",
    "madeixei": "madeixar",
    "madeixeis": "madeixar",
    "madeixem": "madeixar",
    "madeixemo": "madeixar",
    "madeixemos": "madeixar",
    "madeixes": "madeixar",
    "madeixo": "madeixar",
    "madeixou": "madeixar",
    "madeixá": "madeixar",
    "madeixámo": "madeixar",
    "madeixámos": "madeixar",
    "madeixáramo": "madeixar",
    "madeixáramos": "madeixar",
    "madeixárei": "madeixar",
    "madeixáreis": "madeixar",
    "madeixásseis": "madeixar",
    "madeixássemos": "madeixar",
    "madeixávamo": "madeixar",
    "madeixávamos": "madeixar",
    "madeixávei": "madeixar",
    "madeixáveis": "madeixar",
    "mademoiselles": "mademoiselle",
    "madepueiras": "madepueira",
    "madgiares": "madgiar",
    "madianitas": "madianita",
    "madidezes": "madidez",
    "madonas": "madona",
    "madornas": "madorna",
    "madorneiras": "madorneira",
    "madornices": "madornice",
    "madorras": "madorra",
    "madraceada": "madracear",
    "madraceadas": "madracear",
    "madraceado": "madracear",
    "madraceadora": "madraceador",
    "madraceadoras": "madraceador",
    "madraceadores": "madraceador",
    "madraceados": "madracear",
    "madraceai": "madracear",
    "madraceais": "madracear",
    "madraceamo": "madracear",
    "madraceamos": "madracear",
    "madraceando": "madracear",
    "madraceara": "madracear",
    "madracearam": "madracear",
    "madracearas": "madracear",
    "madraceardes": "madracear",
    "madracearei": "madracear",
    "madraceareis": "madracear",
    "madracearem": "madracear",
    "madracearemos": "madracear",
    "madraceares": "madracear",
    "madracearia": "madracear",
    "madraceariam": "madracear",
    "madracearias": "madracear",
    "madracearmo": "madracear",
    "madracearmos": "madracear",
    "madraceará": "madracear",
    "madracearás": "madracear",
    "madracearão": "madracear",
    "madracearíamos": "madracear",
    "madracearíeis": "madracear",
    "madraceasse": "madracear",
    "madraceassem": "madracear",
    "madraceasses": "madracear",
    "madraceaste": "madracear",
    "madraceastes": "madracear",
    "madraceava": "madracear",
    "madraceavam": "madracear",
    "madraceavas": "madracear",
    "madraceei": "madracear",
    "madraceeis": "madracear",
    "madraceemo": "madracear",
    "madraceemos": "madracear",
    "madraceia": "madracear",
    "madraceiam": "madracear",
    "madraceias": "madracear",
    "madraceie": "madracear",
    "madraceiem": "madracear",
    "madraceies": "madracear",
    "madraceio": "madracear",
    "madraceira": "madraceiro",
    "madraceirada": "madraceirar",
    "madraceiradas": "madraceirar",
    "madraceirado": "madraceirar",
    "madraceirados": "madraceirar",
    "madraceirai": "madraceirar",
    "madraceirais": "madraceirar",
    "madraceiram": "madraceirar",
    "madraceiramo": "madraceirar",
    "madraceiramos": "madraceirar",
    "madraceirando": "madraceirar",
    "madraceirara": "madraceirar",
    "madraceiraram": "madraceirar",
    "madraceiraras": "madraceirar",
    "madraceirardes": "madraceirar",
    "madraceirarei": "madraceirar",
    "madraceirareis": "madraceirar",
    "madraceirarem": "madraceirar",
    "madraceiraremos": "madraceirar",
    "madraceirares": "madraceirar",
    "madraceiraria": "madraceirar",
    "madraceirariam": "madraceirar",
    "madraceirarias": "madraceirar",
    "madraceirarmo": "madraceirar",
    "madraceirarmos": "madraceirar",
    "madraceirará": "madraceirar",
    "madraceirarás": "madraceirar",
    "madraceirarão": "madraceirar",
    "madraceiraríamos": "madraceirar",
    "madraceiraríeis": "madraceirar",
    "madraceiras": "madraceiro",
    "madraceirasse": "madraceirar",
    "madraceirassem": "madraceirar",
    "madraceirasses": "madraceirar",
    "madraceiraste": "madraceirar",
    "madraceirastes": "madraceirar",
    "madraceirava": "madraceirar",
    "madraceiravam": "madraceirar",
    "madraceiravas": "madraceirar",
    "madraceire": "madraceirar",
    "madraceirei": "madraceirar",
    "madraceireis": "madraceirar",
    "madraceirem": "madraceirar",
    "madraceiremo": "madraceirar",
    "madraceiremos": "madraceirar",
    "madraceires": "madraceirar",
    "madraceiro": "madraceirar",
    "madraceirona": "madraceirão",
    "madraceironas": "madraceirão",
    "madraceiros": "madraceiro",
    "madraceirou": "madraceirar",
    "madraceirámo": "madraceirar",
    "madraceirámos": "madraceirar",
    "madraceiráramo": "madraceirar",
    "madraceiráramos": "madraceirar",
    "madraceiráreis": "madraceirar",
    "madraceirásseis": "madraceirar",
    "madraceirássemos": "madraceirar",
    "madraceirávamo": "madraceirar",
    "madraceirávamos": "madraceirar",
    "madraceiráveis": "madraceirar",
    "madraceirões": "madraceirão",
    "madraceou": "madracear",
    "madraceámo": "madracear",
    "madraceámos": "madracear",
    "madraceáramo": "madracear",
    "madraceáramos": "madracear",
    "madraceáreis": "madracear",
    "madraceásseis": "madracear",
    "madraceássemos": "madracear",
    "madraceávamo": "madracear",
    "madraceávamos": "madracear",
    "madraceáveis": "madracear",
    "madracices": "madracice",
    "madragoas": "madragoa",
    "madrastas": "madrasta",
    "madrastos": "madrasto",
    "madraça": "madraço",
    "madraçarias": "madraçaria",
    "madraças": "madraço",
    "madraços": "madraço",
    "madrecravos": "madrecravo",
    "madreporiformes": "madreporiforme",
    "madreporites": "madreporite",
    "madreporários": "madreporário",
    "madreporídeos": "madreporídeo",
    "madreporífera": "madreporífero",
    "madreporíferas": "madreporífero",
    "madreporíferos": "madreporífero",
    "madrepérolas": "madrepérola",
    "madrepórica": "madrepórico",
    "madrepóricas": "madrepórico",
    "madrepóricos": "madrepórico",
    "madrepóridas": "madrepórida",
    "madres": "madre",
    "madressilvas": "madressilva",
    "madrias": "madria",
    "madrigais": "madrigal",
    "madrigalesca": "madrigalesco",
    "madrigalescas": "madrigalesco",
    "madrigalescos": "madrigalesco",
    "madrigalistas": "madrigalista",
    "madrigaliza": "madrigalizar",
    "madrigalizada": "madrigalizar",
    "madrigalizadas": "madrigalizar",
    "madrigalizado": "madrigalizar",
    "madrigalizados": "madrigalizar",
    "madrigalizai": "madrigalizar",
    "madrigalizais": "madrigalizar",
    "madrigalizam": "madrigalizar",
    "madrigalizamo": "madrigalizar",
    "madrigalizamos": "madrigalizar",
    "madrigalizando": "madrigalizar",
    "madrigalizara": "madrigalizar",
    "madrigalizaram": "madrigalizar",
    "madrigalizaras": "madrigalizar",
    "madrigalizardes": "madrigalizar",
    "madrigalizarei": "madrigalizar",
    "madrigalizareis": "madrigalizar",
    "madrigalizarem": "madrigalizar",
    "madrigalizaremos": "madrigalizar",
    "madrigalizares": "madrigalizar",
    "madrigalizaria": "madrigalizar",
    "madrigalizariam": "madrigalizar",
    "madrigalizarias": "madrigalizar",
    "madrigalizarmo": "madrigalizar",
    "madrigalizarmos": "madrigalizar",
    "madrigalizará": "madrigalizar",
    "madrigalizarás": "madrigalizar",
    "madrigalizarão": "madrigalizar",
    "madrigalizaríamos": "madrigalizar",
    "madrigalizaríeis": "madrigalizar",
    "madrigalizas": "madrigalizar",
    "madrigalizasse": "madrigalizar",
    "madrigalizassem": "madrigalizar",
    "madrigalizasses": "madrigalizar",
    "madrigalizaste": "madrigalizar",
    "madrigalizastes": "madrigalizar",
    "madrigalizava": "madrigalizar",
    "madrigalizavam": "madrigalizar",
    "madrigalizavas": "madrigalizar",
    "madrigalize": "madrigalizar",
    "madrigalizei": "madrigalizar",
    "madrigalizeis": "madrigalizar",
    "madrigalizem": "madrigalizar",
    "madrigalizemo": "madrigalizar",
    "madrigalizemos": "madrigalizar",
    "madrigalizes": "madrigalizar",
    "madrigalizo": "madrigalizar",
    "madrigalizou": "madrigalizar",
    "madrigalizámo": "madrigalizar",
    "madrigalizámos": "madrigalizar",
    "madrigalizáramo": "madrigalizar",
    "madrigalizáramos": "madrigalizar",
    "madrigalizáreis": "madrigalizar",
    "madrigalizásseis": "madrigalizar",
    "madrigalizássemos": "madrigalizar",
    "madrigalizávamo": "madrigalizar",
    "madrigalizávamos": "madrigalizar",
    "madrigalizáveis": "madrigalizar",
    "madrigazes": "madrigaz",
    "madrigoas": "madrigoa",
    "madrigueiras": "madrigueira",
    "madrigálica": "madrigálico",
    "madrigálicas": "madrigálico",
    "madrigálicos": "madrigálico",
    "madrilena": "madrileno",
    "madrilenas": "madrileno",
    "madrilenos": "madrileno",
    "madrilenses": "madrilense",
    "madrilesa": "madrilês",
    "madrilesas": "madrilês",
    "madrileses": "madrilês",
    "madrilheiras": "madrilheira",
    "madrinha": "padrinho",
    "madrinhas": "padrinho",
    "madrizes": "madriz",
    "madruga": "madrugar",
    "madrugada": "madrugar",
    "madrugadas": "madrugar",
    "madrugado": "madrugar",
    "madrugadora": "madrugador",
    "madrugadoras": "madrugador",
    "madrugadores": "madrugador",
    "madrugados": "madrugar",
    "madrugai": "madrugar",
    "madrugais": "madrugar",
    "madrugam": "madrugar",
    "madrugamo": "madrugar",
    "madrugamos": "madrugar",
    "madrugando": "madrugar",
    "madrugara": "madrugar",
    "madrugaram": "madrugar",
    "madrugaras": "madrugar",
    "madrugardes": "madrugar",
    "madrugarei": "madrugar",
    "madrugareis": "madrugar",
    "madrugarem": "madrugar",
    "madrugaremos": "madrugar",
    "madrugares": "madrugar",
    "madrugaria": "madrugar",
    "madrugariam": "madrugar",
    "madrugarias": "madrugar",
    "madrugarmo": "madrugar",
    "madrugarmos": "madrugar",
    "madrugará": "madrugar",
    "madrugarás": "madrugar",
    "madrugarão": "madrugar",
    "madrugaríamos": "madrugar",
    "madrugaríeis": "madrugar",
    "madrugas": "madrugar",
    "madrugasse": "madrugar",
    "madrugassem": "madrugar",
    "madrugasses": "madrugar",
    "madrugaste": "madrugar",
    "madrugastes": "madrugar",
    "madrugava": "madrugar",
    "madrugavam": "madrugar",
    "madrugavas": "madrugar",
    "madrugo": "madrugar",
    "madrugou": "madrugar",
    "madrugue": "madrugar",
    "madruguei": "madrugar",
    "madrugueis": "madrugar",
    "madruguem": "madrugar",
    "madruguemo": "madrugar",
    "madruguemos": "madrugar",
    "madrugues": "madrugar",
    "madrugámo": "madrugar",
    "madrugámos": "madrugar",
    "madrugáramo": "madrugar",
    "madrugáramos": "madrugar",
    "madrugáreis": "madrugar",
    "madrugásseis": "madrugar",
    "madrugássemos": "madrugar",
    "madrugávamo": "madrugar",
    "madrugávamos": "madrugar",
    "madrugáveis": "madrugar",
    "madréporas": "madrépora",
    "madura": "maduro",
    "madurada": "madurar",
    "maduradas": "madurar",
    "madurado": "madurar",
    "maduradora": "madurador",
    "maduradoras": "madurador",
    "maduradores": "madurador",
    "madurados": "madurar",
    "madurai": "madurar",
    "madurais": "madurar",
    "maduram": "madurar",
    "maduramo": "madurar",
    "maduramos": "madurar",
    "madurando": "madurar",
    "madurara": "madurar",
    "maduraram": "madurar",
    "maduraras": "madurar",
    "madurarde": "madurar",
    "madurardes": "madurar",
    "madurare": "madurar",
    "madurarei": "madurar",
    "madurareis": "madurar",
    "madurarem": "madurar",
    "maduraremos": "madurar",
    "madurares": "madurar",
    "maduraria": "madurar",
    "madurariam": "madurar",
    "madurarias": "madurar",
    "madurarmo": "madurar",
    "madurarmos": "madurar",
    "madurará": "madurar",
    "madurarás": "madurar",
    "madurarão": "madurar",
    "maduraríamos": "madurar",
    "maduraríeis": "madurar",
    "maduras": "maduro",
    "madurasse": "madurar",
    "madurassem": "madurar",
    "madurasses": "madurar",
    "maduraste": "madurar",
    "madurastes": "madurar",
    "madurava": "madurar",
    "maduravam": "madurar",
    "maduravas": "madurar",
    "madurazinha": "maduro",
    "madurazinhas": "maduro",
    "madurazita": "maduro",
    "madurazitas": "maduro",
    "madurações": "maduração",
    "madure": "madurar",
    "madurece": "madurecer",
    "madurecei": "madurecer",
    "madureceis": "madurecer",
    "madurecem": "madurecer",
    "madurecemo": "madurecer",
    "madurecemos": "madurecer",
    "madurecendo": "madurecer",
    "madurecera": "madurecer",
    "madureceram": "madurecer",
    "madureceras": "madurecer",
    "madurecerde": "madurecer",
    "madurecerdes": "madurecer",
    "madurecere": "madurecer",
    "madurecerei": "madurecer",
    "madurecereis": "madurecer",
    "madurecerem": "madurecer",
    "madureceremos": "madurecer",
    "madureceres": "madurecer",
    "madureceria": "madurecer",
    "madureceriam": "madurecer",
    "madurecerias": "madurecer",
    "madurecermo": "madurecer",
    "madurecermos": "madurecer",
    "madurecerá": "madurecer",
    "madurecerás": "madurecer",
    "madurecerão": "madurecer",
    "madureceríamos": "madurecer",
    "madureceríeis": "madurecer",
    "madureces": "madurecer",
    "madurecesse": "madurecer",
    "madurecessem": "madurecer",
    "madurecesses": "madurecer",
    "madureceste": "madurecer",
    "madurecestes": "madurecer",
    "madureceu": "madurecer",
    "madureci": "madurecer",
    "madurecia": "madurecer",
    "madureciam": "madurecer",
    "madurecias": "madurecer",
    "madurecida": "madurecer",
    "madurecidas": "madurecer",
    "madurecido": "madurecer",
    "madurecidos": "madurecer",
    "madurecê": "madurecer",
    "madurecêramo": "madurecer",
    "madurecêramos": "madurecer",
    "madurecêrei": "madurecer",
    "madurecêreis": "madurecer",
    "madurecêsseis": "madurecer",
    "madurecêssemos": "madurecer",
    "madurecíamo": "madurecer",
    "madurecíamos": "madurecer",
    "madurecíei": "madurecer",
    "madurecíeis": "madurecer",
    "madurei": "madurar",
    "madureiros": "madureiro",
    "madureis": "madurar",
    "madurem": "madurar",
    "maduremo": "madurar",
    "maduremos": "madurar",
    "madures": "madurar",
    "madurez": "madureza",
    "madurezas": "madureza",
    "madureça": "madurecer",
    "madureçais": "madurecer",
    "madureçam": "madurecer",
    "madureçamo": "madurecer",
    "madureçamos": "madurecer",
    "madureças": "madurecer",
    "madureço": "madurecer",
    "madurinha": "maduro",
    "madurinhas": "maduro",
    "madurinho": "maduro",
    "madurinhos": "maduro",
    "madurita": "maduro",
    "maduritas": "maduro",
    "madurito": "maduro",
    "maduritos": "maduro",
    "maduro": "madurar",
    "madurona": "maduro",
    "maduronas": "maduro",
    "maduros": "maduro",
    "madurou": "madurar",
    "madurozinho": "maduro",
    "madurozinhos": "maduro",
    "madurozito": "maduro",
    "madurozitos": "maduro",
    "madurá": "madurar",
    "madurámo": "madurar",
    "madurámos": "madurar",
    "maduráramo": "madurar",
    "maduráramos": "madurar",
    "madurárei": "madurar",
    "maduráreis": "madurar",
    "madurásseis": "madurar",
    "madurássemos": "madurar",
    "madurávamo": "madurar",
    "madurávamos": "madurar",
    "madurávei": "madurar",
    "maduráveis": "madurar",
    "madurão": "maduro",
    "maduríssima": "maduro",
    "maduríssimas": "maduro",
    "maduríssimo": "maduro",
    "maduríssimos": "maduro",
    "madurões": "maduro",
    "maestra": "maestro",
    "maestras": "maestro",
    "maestrias": "maestria",
    "maestrichtianos": "maestrichtiano",
    "maestrina": "maestrino",
    "maestrinas": "maestrino",
    "maestrinos": "maestrino",
    "maestros": "maestro",
    "mafamedes": "mafamede",
    "mafamética": "mafamético",
    "mafaméticas": "mafamético",
    "mafaméticos": "mafamético",
    "mafarrica": "mafarrico",
    "mafarricas": "mafarrico",
    "mafarricos": "mafarrico",
    "mafias": "mafia",
    "mafiosa": "mafioso",
    "mafiosas": "mafioso",
    "mafiosos": "mafioso",
    "mafomistas": "mafomista",
    "mafraítos": "mafraíto",
    "mafrenses": "mafrense",
    "mafumeiras": "mafumeira",
    "mafureiras": "mafureira",
    "mafurras": "mafurra",
    "mafurreiras": "mafurreira",
    "maga": "mago",
    "magais": "magal",
    "magalas": "magala",
    "magalómana": "magalómano",
    "magalómanas": "magalómano",
    "magalómanos": "magalómano",
    "magana": "magano",
    "maganagens": "maganagem",
    "maganas": "magano",
    "maganeada": "maganear",
    "maganeadas": "maganear",
    "maganeado": "maganear",
    "maganeados": "maganear",
    "maganeai": "maganear",
    "maganeais": "maganear",
    "maganeamo": "maganear",
    "maganeamos": "maganear",
    "maganeando": "maganear",
    "maganeara": "maganear",
    "maganearam": "maganear",
    "maganearas": "maganear",
    "maganeardes": "maganear",
    "maganearei": "maganear",
    "maganeareis": "maganear",
    "maganearem": "maganear",
    "maganearemos": "maganear",
    "maganeares": "maganear",
    "maganearia": "maganear",
    "maganeariam": "maganear",
    "maganearias": "maganear",
    "maganearmo": "maganear",
    "maganearmos": "maganear",
    "maganeará": "maganear",
    "maganearás": "maganear",
    "maganearão": "maganear",
    "maganearíamos": "maganear",
    "maganearíeis": "maganear",
    "maganeasse": "maganear",
    "maganeassem": "maganear",
    "maganeasses": "maganear",
    "maganeaste": "maganear",
    "maganeastes": "maganear",
    "maganeava": "maganear",
    "maganeavam": "maganear",
    "maganeavas": "maganear",
    "maganeei": "maganear",
    "maganeeis": "maganear",
    "maganeemo": "maganear",
    "maganeemos": "maganear",
    "maganeia": "maganear",
    "maganeiam": "maganear",
    "maganeias": "maganear",
    "maganeie": "maganear",
    "maganeiem": "maganear",
    "maganeies": "maganear",
    "maganeio": "maganear",
    "maganeiras": "maganeira",
    "maganeou": "maganear",
    "maganeámo": "maganear",
    "maganeámos": "maganear",
    "maganeáramo": "maganear",
    "maganeáramos": "maganear",
    "maganeáreis": "maganear",
    "maganeásseis": "maganear",
    "maganeássemos": "maganear",
    "maganeávamo": "maganear",
    "maganeávamos": "maganear",
    "maganeáveis": "maganear",
    "maganices": "maganice",
    "maganona": "magano",
    "maganonas": "magano",
    "maganos": "magano",
    "maganão": "magano",
    "maganões": "magano",
    "magarebes": "magarebe",
    "magarefes": "magarefe",
    "magarins": "magarim",
    "magarças": "magarça",
    "magas": "mago",
    "magazines": "magazine",
    "magaças": "magaça",
    "magbás": "magbá",
    "magdalenianos": "magdaleniano",
    "magdaleões": "magdaleão",
    "magentas": "magenta",
    "magiares": "magiar",
    "magias": "magia",
    "magica": "magico",
    "magicada": "magicar",
    "magicadas": "magicar",
    "magicado": "magicar",
    "magicados": "magicar",
    "magicai": "magicar",
    "magicais": "magicar",
    "magicam": "magicar",
    "magicamo": "magicar",
    "magicamos": "magicar",
    "magicando": "magicar",
    "magicara": "magicar",
    "magicaram": "magicar",
    "magicaras": "magicar",
    "magicarde": "magicar",
    "magicardes": "magicar",
    "magicare": "magicar",
    "magicarei": "magicar",
    "magicareis": "magicar",
    "magicarem": "magicar",
    "magicaremos": "magicar",
    "magicares": "magicar",
    "magicaria": "magicar",
    "magicariam": "magicar",
    "magicarias": "magicar",
    "magicarmo": "magicar",
    "magicarmos": "magicar",
    "magicará": "magicar",
    "magicarás": "magicar",
    "magicarão": "magicar",
    "magicaríamos": "magicar",
    "magicaríeis": "magicar",
    "magicas": "magico",
    "magicasse": "magicar",
    "magicassem": "magicar",
    "magicasses": "magicar",
    "magicaste": "magicar",
    "magicastes": "magicar",
    "magicava": "magicar",
    "magicavam": "magicar",
    "magicavas": "magicar",
    "magico": "magicar",
    "magicos": "magico",
    "magicou": "magicar",
    "magicá": "magicar",
    "magicámo": "magicar",
    "magicámos": "magicar",
    "magicáramo": "magicar",
    "magicáramos": "magicar",
    "magicárei": "magicar",
    "magicáreis": "magicar",
    "magicásseis": "magicar",
    "magicássemos": "magicar",
    "magicávamo": "magicar",
    "magicávamos": "magicar",
    "magicávei": "magicar",
    "magicáveis": "magicar",
    "magique": "magicar",
    "magiquei": "magicar",
    "magiqueis": "magicar",
    "magiquem": "magicar",
    "magiquemo": "magicar",
    "magiquemos": "magicar",
    "magiques": "magicar",
    "magismos": "magismo",
    "magistrada": "magistrado",
    "magistradas": "magistrado",
    "magistrados": "magistrado",
    "magistrais": "magistral",
    "magistralidades": "magistralidade",
    "magistranda": "magistrando",
    "magistrandas": "magistrando",
    "magistrandos": "magistrando",
    "magistraturas": "magistratura",
    "magistrática": "magistrático",
    "magistráticas": "magistrático",
    "magistráticos": "magistrático",
    "magistérios": "magistério",
    "magmas": "magma",
    "magmatismos": "magmatismo",
    "magmática": "magmático",
    "magmáticas": "magmático",
    "magmáticos": "magmático",
    "magna": "magno",
    "magnanimidades": "magnanimidade",
    "magnas": "magno",
    "magnatas": "magnata",
    "magnates": "magnate",
    "magnesiana": "magnesiano",
    "magnesianas": "magnesiano",
    "magnesianos": "magnesiano",
    "magnesites": "magnesite",
    "magnetes": "magnete",
    "magnetismos": "magnetismo",
    "magnetites": "magnetite",
    "magnetiza": "magnetizar",
    "magnetizada": "magnetizar",
    "magnetizadas": "magnetizar",
    "magnetizado": "magnetizar",
    "magnetizadora": "magnetizador",
    "magnetizadoras": "magnetizador",
    "magnetizadores": "magnetizador",
    "magnetizados": "magnetizar",
    "magnetizai": "magnetizar",
    "magnetizais": "magnetizar",
    "magnetizam": "magnetizar",
    "magnetizamo": "magnetizar",
    "magnetizamos": "magnetizar",
    "magnetizando": "magnetizar",
    "magnetizantes": "magnetizante",
    "magnetizara": "magnetizar",
    "magnetizaram": "magnetizar",
    "magnetizaras": "magnetizar",
    "magnetizarde": "magnetizar",
    "magnetizardes": "magnetizar",
    "magnetizare": "magnetizar",
    "magnetizarei": "magnetizar",
    "magnetizareis": "magnetizar",
    "magnetizarem": "magnetizar",
    "magnetizaremos": "magnetizar",
    "magnetizares": "magnetizar",
    "magnetizaria": "magnetizar",
    "magnetizariam": "magnetizar",
    "magnetizarias": "magnetizar",
    "magnetizarmo": "magnetizar",
    "magnetizarmos": "magnetizar",
    "magnetizará": "magnetizar",
    "magnetizarás": "magnetizar",
    "magnetizarão": "magnetizar",
    "magnetizaríamos": "magnetizar",
    "magnetizaríeis": "magnetizar",
    "magnetizas": "magnetizar",
    "magnetizasse": "magnetizar",
    "magnetizassem": "magnetizar",
    "magnetizasses": "magnetizar",
    "magnetizaste": "magnetizar",
    "magnetizastes": "magnetizar",
    "magnetizava": "magnetizar",
    "magnetizavam": "magnetizar",
    "magnetizavas": "magnetizar",
    "magnetizações": "magnetização",
    "magnetize": "magnetizar",
    "magnetizei": "magnetizar",
    "magnetizeis": "magnetizar",
    "magnetizem": "magnetizar",
    "magnetizemo": "magnetizar",
    "magnetizemos": "magnetizar",
    "magnetizes": "magnetizar",
    "magnetizo": "magnetizar",
    "magnetizou": "magnetizar",
    "magnetizá": "magnetizar",
    "magnetizámo": "magnetizar",
    "magnetizámos": "magnetizar",
    "magnetizáramo": "magnetizar",
    "magnetizáramos": "magnetizar",
    "magnetizárei": "magnetizar",
    "magnetizáreis": "magnetizar",
    "magnetizásseis": "magnetizar",
    "magnetizássemos": "magnetizar",
    "magnetizávamo": "magnetizar",
    "magnetizávamos": "magnetizar",
    "magnetizávei": "magnetizar",
    "magnetizáveis": "magnetizável",
    "magnetocalórica": "magnetocalórico",
    "magnetocalóricas": "magnetocalórico",
    "magnetocalóricos": "magnetocalórico",
    "magnetofones": "magnetofone",
    "magnetogenias": "magnetogenia",
    "magnetogramas": "magnetograma",
    "magnetográfica": "magnetográfico",
    "magnetográficas": "magnetográfico",
    "magnetográficos": "magnetográfico",
    "magnetoidrodinâmicas": "magnetoidrodinâmica",
    "magnetologias": "magnetologia",
    "magnetológica": "magnetológico",
    "magnetológicas": "magnetológico",
    "magnetológicos": "magnetológico",
    "magnetométrica": "magnetométrico",
    "magnetométricas": "magnetométrico",
    "magnetométricos": "magnetométrico",
    "magnetos": "magneto",
    "magnetoscópica": "magnetoscópico",
    "magnetoscópicas": "magnetoscópico",
    "magnetoscópicos": "magnetoscópico",
    "magnetosferas": "magnetosfera",
    "magnetostrições": "magnetostrição",
    "magnetostática": "magnetostático",
    "magnetostáticas": "magnetostático",
    "magnetostáticos": "magnetostático",
    "magnetotecnias": "magnetotecnia",
    "magnetrões": "magnetrão",
    "magnetógrafos": "magnetógrafo",
    "magnetómetros": "magnetómetro",
    "magnetões": "magnetão",
    "magnicidas": "magnicida",
    "magnicídios": "magnicídio",
    "magnifica": "magnificar",
    "magnificada": "magnificar",
    "magnificadas": "magnificar",
    "magnificado": "magnificar",
    "magnificadora": "magnificador",
    "magnificadoras": "magnificador",
    "magnificadores": "magnificador",
    "magnificados": "magnificar",
    "magnificai": "magnificar",
    "magnificais": "magnificar",
    "magnificam": "magnificar",
    "magnificamo": "magnificar",
    "magnificamos": "magnificar",
    "magnificando": "magnificar",
    "magnificara": "magnificar",
    "magnificaram": "magnificar",
    "magnificaras": "magnificar",
    "magnificarde": "magnificar",
    "magnificardes": "magnificar",
    "magnificare": "magnificar",
    "magnificarei": "magnificar",
    "magnificareis": "magnificar",
    "magnificarem": "magnificar",
    "magnificaremos": "magnificar",
    "magnificares": "magnificar",
    "magnificaria": "magnificar",
    "magnificariam": "magnificar",
    "magnificarias": "magnificar",
    "magnificarmo": "magnificar",
    "magnificarmos": "magnificar",
    "magnificará": "magnificar",
    "magnificarás": "magnificar",
    "magnificarão": "magnificar",
    "magnificaríamos": "magnificar",
    "magnificaríeis": "magnificar",
    "magnificas": "magnificar",
    "magnificasse": "magnificar",
    "magnificassem": "magnificar",
    "magnificasses": "magnificar",
    "magnificaste": "magnificar",
    "magnificastes": "magnificar",
    "magnificatória": "magnificatório",
    "magnificatórias": "magnificatório",
    "magnificatórios": "magnificatório",
    "magnificava": "magnificar",
    "magnificavam": "magnificar",
    "magnificavas": "magnificar",
    "magnificações": "magnificação",
    "magnificentes": "magnificente",
    "magnificentíssima": "magnífico",
    "magnificentíssimas": "magnífico",
    "magnificentíssimo": "magnífico",
    "magnificentíssimos": "magnífico",
    "magnifico": "magnificar",
    "magnificou": "magnificar",
    "magnificá": "magnificar",
    "magnificámo": "magnificar",
    "magnificámos": "magnificar",
    "magnificáramo": "magnificar",
    "magnificáramos": "magnificar",
    "magnificárei": "magnificar",
    "magnificáreis": "magnificar",
    "magnificásseis": "magnificar",
    "magnificássemos": "magnificar",
    "magnificávamo": "magnificar",
    "magnificávamos": "magnificar",
    "magnificávei": "magnificar",
    "magnificáveis": "magnificar",
    "magnificências": "magnificência",
    "magnificíssima": "magnífico",
    "magnificíssimas": "magnífico",
    "magnificíssimo": "magnífico",
    "magnificíssimos": "magnífico",
    "magnifique": "magnificar",
    "magnifiquei": "magnificar",
    "magnifiqueis": "magnificar",
    "magnifiquem": "magnificar",
    "magnifiquemo": "magnificar",
    "magnifiquemos": "magnificar",
    "magnifiques": "magnificar",
    "magniloquências": "magniloquência",
    "magnissonantes": "magnissonante",
    "magnitudes": "magnitude",
    "magnoliácea": "magnoliáceo",
    "magnoliáceas": "magnoliáceo",
    "magnoliáceos": "magnoliáceo",
    "magnos": "magno",
    "magnálios": "magnálio",
    "magnânima": "magnânimo",
    "magnânimas": "magnânimo",
    "magnânimos": "magnânimo",
    "magnésias": "magnésia",
    "magnésica": "magnésico",
    "magnésicas": "magnésico",
    "magnésicos": "magnésico",
    "magnésios": "magnésio",
    "magnética": "magnético",
    "magnéticas": "magnético",
    "magnéticos": "magnético",
    "magnífica": "magnífico",
    "magníficas": "magnífico",
    "magníficos": "magnífico",
    "magníloqua": "magníloquo",
    "magníloquas": "magníloquo",
    "magníloquos": "magníloquo",
    "magnólias": "magnólia",
    "magnólios": "magnólio",
    "magnórios": "magnório",
    "magoa": "magoar",
    "magoada": "magoar",
    "magoadas": "magoar",
    "magoadinha": "magoado",
    "magoadinhas": "magoado",
    "magoadinho": "magoado",
    "magoadinhos": "magoado",
    "magoadita": "magoado",
    "magoaditas": "magoado",
    "magoadito": "magoado",
    "magoaditos": "magoado",
    "magoado": "magoar",
    "magoados": "magoar",
    "magoadíssima": "magoado",
    "magoadíssimas": "magoado",
    "magoadíssimo": "magoado",
    "magoadíssimos": "magoado",
    "magoai": "magoar",
    "magoais": "magoar",
    "magoam": "magoar",
    "magoamo": "magoar",
    "magoamos": "magoar",
    "magoando": "magoar",
    "magoara": "magoar",
    "magoaram": "magoar",
    "magoaras": "magoar",
    "magoarde": "magoar",
    "magoardes": "magoar",
    "magoare": "magoar",
    "magoarei": "magoar",
    "magoareis": "magoar",
    "magoarem": "magoar",
    "magoaremos": "magoar",
    "magoares": "magoar",
    "magoaria": "magoar",
    "magoariam": "magoar",
    "magoarias": "magoar",
    "magoarmo": "magoar",
    "magoarmos": "magoar",
    "magoará": "magoar",
    "magoarás": "magoar",
    "magoarão": "magoar",
    "magoaríamos": "magoar",
    "magoaríeis": "magoar",
    "magoas": "magoar",
    "magoasse": "magoar",
    "magoassem": "magoar",
    "magoasses": "magoar",
    "magoaste": "magoar",
    "magoastes": "magoar",
    "magoativa": "magoativo",
    "magoativas": "magoativo",
    "magoativos": "magoativo",
    "magoava": "magoar",
    "magoavam": "magoar",
    "magoavas": "magoar",
    "magodos": "magodo",
    "magoe": "magoar",
    "magoei": "magoar",
    "magoeis": "magoar",
    "magoem": "magoar",
    "magoemo": "magoar",
    "magoemos": "magoar",
    "magoes": "magoar",
    "magofonias": "magofonia",
    "magogonçalos": "magogonçalo",
    "magonguês": "magonguê",
    "magoo": "magoar",
    "magoou": "magoar",
    "magos": "mago",
    "magotes": "magote",
    "magoá": "magoar",
    "magoámo": "magoar",
    "magoámos": "magoar",
    "magoáramo": "magoar",
    "magoáramos": "magoar",
    "magoárei": "magoar",
    "magoáreis": "magoar",
    "magoásseis": "magoar",
    "magoássemos": "magoar",
    "magoávamo": "magoar",
    "magoávamos": "magoar",
    "magoávei": "magoar",
    "magoáveis": "magoar",
    "magra": "magro",
    "magras": "magro",
    "magrazinha": "magro",
    "magrazinhas": "magro",
    "magrazita": "magro",
    "magrazitas": "magro",
    "magrebina": "magrebino",
    "magrebinas": "magrebino",
    "magrebinos": "magrebino",
    "magreiras": "magreira",
    "magretes": "magrete",
    "magrezas": "magreza",
    "magricela": "magricelas",
    "magridades": "magridade",
    "magridazes": "magridaz",
    "magrinha": "magro",
    "magrinhas": "magro",
    "magrinho": "magro",
    "magrinhos": "magro",
    "magrita": "magro",
    "magritas": "magro",
    "magrito": "magro",
    "magritos": "magro",
    "magrizelas": "magrizela",
    "magriços": "magriço",
    "magros": "magro",
    "magrotes": "magrote",
    "magrozinho": "magro",
    "magrozinhos": "magro",
    "magrozito": "magro",
    "magrozitos": "magro",
    "magréns": "magrém",
    "magríssima": "magro",
    "magríssimas": "magro",
    "magríssimo": "magro",
    "magríssimos": "magro",
    "maguilhos": "maguilho",
    "magujos": "magujo",
    "magustais": "magustal",
    "magustos": "magusto",
    "maia": "maio",
    "maiana": "maiano",
    "maianas": "maiano",
    "maianos": "maiano",
    "maias": "maio",
    "maiata": "maiato",
    "maiatas": "maiato",
    "maiatos": "maiato",
    "mails": "mail",
    "mainates": "mainate",
    "mainato": "mainate",
    "mainatos": "mainate",
    "mainibus": "mainibu",
    "mainças": "mainça",
    "mainéis": "mainel",
    "maioneses": "maionese",
    "maiorais": "maioral",
    "maiores": "maior",
    "maiorias": "maioria",
    "maioriazinha": "maioria",
    "maioriazinhas": "maioria",
    "maioriazita": "maioria",
    "maioriazitas": "maioria",
    "maioridades": "maioridade",
    "maioritária": "maioritário",
    "maioritárias": "maioritário",
    "maioritários": "maioritário",
    "maiorquina": "maiorquino",
    "maiorquinas": "maiorquino",
    "maiorquinos": "maiorquino",
    "maios": "maio",
    "maisais": "maisal",
    "maisenas": "maisena",
    "maitacas": "maitaca",
    "maitucas": "maituca",
    "maiêutica": "maiêutico",
    "maiêuticas": "maiêutico",
    "maiêuticos": "maiêutico",
    "maiólicas": "maiólica",
    "maiôs": "maiô",
    "maiúscula": "maiúsculo",
    "maiúsculas": "maiúsculo",
    "maiúsculos": "maiúsculo",
    "majaricos": "majarico",
    "majaricões": "majaricão",
    "majengros": "majengro",
    "majestades": "majestade",
    "majestosa": "majestoso",
    "majestosas": "majestoso",
    "majestosos": "majestoso",
    "majestática": "majestático",
    "majestáticas": "majestático",
    "majestáticos": "majestático",
    "majoeiras": "majoeira",
    "majorações": "majoração",
    "majoretes": "majorete",
    "majorias": "majoria",
    "majoritária": "majoritário",
    "majoritárias": "majoritário",
    "majoritários": "majoritário",
    "majors": "major",
    "majólicas": "majólica",
    "mala": "malo",
    "malabares": "malabar",
    "malabaresca": "malabaresco",
    "malabarescas": "malabaresco",
    "malabarescos": "malabaresco",
    "malabarismos": "malabarismo",
    "malabaristas": "malabarista",
    "malabrutos": "malabruto",
    "malabárica": "malabárico",
    "malabáricas": "malabárico",
    "malabáricos": "malabárico",
    "malacaras": "malacara",
    "malacas": "malaca",
    "malacates": "malacate",
    "malacias": "malacia",
    "malacoderma": "malacodermo",
    "malacodermas": "malacodermo",
    "malacodermos": "malacodermo",
    "malacofilias": "malacofilia",
    "malacogamias": "malacogamia",
    "malacologias": "malacologia",
    "malacologistas": "malacologista",
    "malacológica": "malacológico",
    "malacológicas": "malacológico",
    "malacológicos": "malacológico",
    "malacopterígia": "malacopterígio",
    "malacopterígias": "malacopterígio",
    "malacopterígios": "malacopterígio",
    "malacostrácea": "malacostráceo",
    "malacostráceas": "malacostráceo",
    "malacostráceos": "malacostráceo",
    "malacozoária": "malacozoário",
    "malacozoárias": "malacozoário",
    "malacozoários": "malacozoário",
    "malacueca": "malacueco",
    "malacuecas": "malacueco",
    "malacuecos": "malacueco",
    "malacuecozinho": "malacueco",
    "malacuecozinhos": "malacueco",
    "malacuecozito": "malacueco",
    "malacuecozitos": "malacueco",
    "malacófila": "malacófilo",
    "malacófilas": "malacófilo",
    "malacófilos": "malacófilo",
    "malacógama": "malacógamo",
    "malacógamas": "malacógamo",
    "malacógamos": "malacógamo",
    "malacões": "malacão",
    "malada": "malado",
    "maladas": "malado",
    "maladias": "maladia",
    "malados": "malado",
    "malafaias": "malafaia",
    "malaguenha": "malaguenho",
    "malaguenhas": "malaguenho",
    "malaguenhos": "malaguenho",
    "malaguesa": "malaguês",
    "malaguesas": "malaguês",
    "malagueses": "malaguês",
    "malaguetas": "malagueta",
    "malaia": "malaio",
    "malaialas": "malaiala",
    "malaias": "malaio",
    "malaios": "malaio",
    "malandra": "malandro",
    "malandrada": "malandrar",
    "malandradas": "malandrar",
    "malandrado": "malandrar",
    "malandrados": "malandrar",
    "malandragens": "malandragem",
    "malandrai": "malandrar",
    "malandrais": "malandrar",
    "malandram": "malandrar",
    "malandramo": "malandrar",
    "malandramos": "malandrar",
    "malandrando": "malandrar",
    "malandrara": "malandrar",
    "malandraram": "malandrar",
    "malandraras": "malandrar",
    "malandrardes": "malandrar",
    "malandrarei": "malandrar",
    "malandrareis": "malandrar",
    "malandrarem": "malandrar",
    "malandraremos": "malandrar",
    "malandrares": "malandrar",
    "malandraria": "malandrar",
    "malandrariam": "malandrar",
    "malandrarias": "malandrar",
    "malandrarmo": "malandrar",
    "malandrarmos": "malandrar",
    "malandrará": "malandrar",
    "malandrarás": "malandrar",
    "malandrarão": "malandrar",
    "malandraríamos": "malandrar",
    "malandraríeis": "malandrar",
    "malandras": "malandro",
    "malandrasse": "malandrar",
    "malandrassem": "malandrar",
    "malandrasses": "malandrar",
    "malandraste": "malandrar",
    "malandrastes": "malandrar",
    "malandrava": "malandrar",
    "malandravam": "malandrar",
    "malandravas": "malandrar",
    "malandraça": "malandraço",
    "malandraças": "malandraço",
    "malandraços": "malandraço",
    "malandre": "malandrar",
    "malandreca": "malandreco",
    "malandrecas": "malandreco",
    "malandrecos": "malandreco",
    "malandrei": "malandrar",
    "malandreis": "malandrar",
    "malandrem": "malandrar",
    "malandremo": "malandrar",
    "malandremos": "malandrar",
    "malandres": "malandrar",
    "malandreta": "malandrete",
    "malandretas": "malandrete",
    "malandretes": "malandrete",
    "malandrices": "malandrice",
    "malandrina": "malandrino",
    "malandrinas": "malandrino",
    "malandrinha": "malandro",
    "malandrinhas": "malandro",
    "malandrinho": "malandro",
    "malandrinhos": "malandro",
    "malandrinos": "malandrino",
    "malandrins": "malandrim",
    "malandrita": "malandro",
    "malandritas": "malandro",
    "malandrito": "malandro",
    "malandritos": "malandro",
    "malandro": "malandrar",
    "malandrona": "malandro",
    "malandronas": "malandro",
    "malandros": "malandro",
    "malandrota": "malandrote",
    "malandrotas": "malandrote",
    "malandrotes": "malandrote",
    "malandrou": "malandrar",
    "malandrámo": "malandrar",
    "malandrámos": "malandrar",
    "malandráramo": "malandrar",
    "malandráramos": "malandrar",
    "malandráreis": "malandrar",
    "malandrásseis": "malandrar",
    "malandrássemos": "malandrar",
    "malandrávamo": "malandrar",
    "malandrávamos": "malandrar",
    "malandráveis": "malandrar",
    "malandrão": "malandro",
    "malandríssima": "malandro",
    "malandríssimas": "malandro",
    "malandríssimo": "malandro",
    "malandríssimos": "malandro",
    "malandrões": "malandro",
    "malapeiras": "malapeira",
    "malapeiros": "malapeiro",
    "malaqueira": "malaqueiro",
    "malaqueiras": "malaqueiro",
    "malaqueiros": "malaqueiro",
    "malaquesa": "malaquês",
    "malaquesas": "malaquês",
    "malaqueses": "malaquês",
    "malaquistas": "malaquista",
    "malaquites": "malaquite",
    "malares": "malar",
    "malarias": "malaria",
    "malariologias": "malariologia",
    "malariologistas": "malariologista",
    "malarioterapias": "malarioterapia",
    "malarífera": "malarífero",
    "malaríferas": "malarífero",
    "malaríferos": "malarífero",
    "malarígena": "malarígeno",
    "malarígenas": "malarígeno",
    "malarígenos": "malarígeno",
    "malas": "malo",
    "malatecas": "malateca",
    "malatos": "malato",
    "malauiana": "malauiano",
    "malauianas": "malauiano",
    "malauianos": "malauiano",
    "malaxa": "malaxar",
    "malaxada": "malaxar",
    "malaxadas": "malaxar",
    "malaxadeira": "malaxador",
    "malaxadeiras": "malaxador",
    "malaxado": "malaxar",
    "malaxadores": "malaxador",
    "malaxados": "malaxar",
    "malaxai": "malaxar",
    "malaxais": "malaxar",
    "malaxam": "malaxar",
    "malaxamo": "malaxar",
    "malaxamos": "malaxar",
    "malaxando": "malaxar",
    "malaxara": "malaxar",
    "malaxaram": "malaxar",
    "malaxaras": "malaxar",
    "malaxarde": "malaxar",
    "malaxardes": "malaxar",
    "malaxare": "malaxar",
    "malaxarei": "malaxar",
    "malaxareis": "malaxar",
    "malaxarem": "malaxar",
    "malaxaremos": "malaxar",
    "malaxares": "malaxar",
    "malaxaria": "malaxar",
    "malaxariam": "malaxar",
    "malaxarias": "malaxar",
    "malaxarmo": "malaxar",
    "malaxarmos": "malaxar",
    "malaxará": "malaxar",
    "malaxarás": "malaxar",
    "malaxarão": "malaxar",
    "malaxaríamos": "malaxar",
    "malaxaríeis": "malaxar",
    "malaxas": "malaxar",
    "malaxasse": "malaxar",
    "malaxassem": "malaxar",
    "malaxasses": "malaxar",
    "malaxaste": "malaxar",
    "malaxastes": "malaxar",
    "malaxava": "malaxar",
    "malaxavam": "malaxar",
    "malaxavas": "malaxar",
    "malaxações": "malaxação",
    "malaxe": "malaxar",
    "malaxei": "malaxar",
    "malaxeis": "malaxar",
    "malaxem": "malaxar",
    "malaxemo": "malaxar",
    "malaxemos": "malaxar",
    "malaxes": "malaxar",
    "malaxo": "malaxar",
    "malaxou": "malaxar",
    "malaxá": "malaxar",
    "malaxámo": "malaxar",
    "malaxámos": "malaxar",
    "malaxáramo": "malaxar",
    "malaxáramos": "malaxar",
    "malaxárei": "malaxar",
    "malaxáreis": "malaxar",
    "malaxásseis": "malaxar",
    "malaxássemos": "malaxar",
    "malaxávamo": "malaxar",
    "malaxávamos": "malaxar",
    "malaxávei": "malaxar",
    "malaxáveis": "malaxar",
    "malbarata": "malbaratar",
    "malbaratada": "malbaratar",
    "malbaratadas": "malbaratar",
    "malbaratado": "malbaratar",
    "malbaratadora": "malbaratador",
    "malbaratadoras": "malbaratador",
    "malbaratadores": "malbaratador",
    "malbaratados": "malbaratar",
    "malbaratai": "malbaratar",
    "malbaratais": "malbaratar",
    "malbaratam": "malbaratar",
    "malbaratamentos": "malbaratamento",
    "malbaratamo": "malbaratar",
    "malbaratamos": "malbaratar",
    "malbaratando": "malbaratar",
    "malbaratara": "malbaratar",
    "malbarataram": "malbaratar",
    "malbarataras": "malbaratar",
    "malbaratarde": "malbaratar",
    "malbaratardes": "malbaratar",
    "malbaratare": "malbaratar",
    "malbaratarei": "malbaratar",
    "malbaratareis": "malbaratar",
    "malbaratarem": "malbaratar",
    "malbarataremos": "malbaratar",
    "malbaratares": "malbaratar",
    "malbarataria": "malbaratar",
    "malbaratariam": "malbaratar",
    "malbaratarias": "malbaratar",
    "malbaratarmo": "malbaratar",
    "malbaratarmos": "malbaratar",
    "malbaratará": "malbaratar",
    "malbaratarás": "malbaratar",
    "malbaratarão": "malbaratar",
    "malbarataríamos": "malbaratar",
    "malbarataríeis": "malbaratar",
    "malbaratas": "malbaratar",
    "malbaratasse": "malbaratar",
    "malbaratassem": "malbaratar",
    "malbaratasses": "malbaratar",
    "malbarataste": "malbaratar",
    "malbaratastes": "malbaratar",
    "malbaratava": "malbaratar",
    "malbaratavam": "malbaratar",
    "malbaratavas": "malbaratar",
    "malbarate": "malbaratar",
    "malbarateada": "malbaratear",
    "malbarateadas": "malbaratear",
    "malbarateado": "malbaratear",
    "malbarateados": "malbaratear",
    "malbarateai": "malbaratear",
    "malbarateais": "malbaratear",
    "malbarateamo": "malbaratear",
    "malbarateamos": "malbaratear",
    "malbarateando": "malbaratear",
    "malbarateara": "malbaratear",
    "malbaratearam": "malbaratear",
    "malbaratearas": "malbaratear",
    "malbaratearde": "malbaratear",
    "malbarateardes": "malbaratear",
    "malbarateare": "malbaratear",
    "malbaratearei": "malbaratear",
    "malbarateareis": "malbaratear",
    "malbaratearem": "malbaratear",
    "malbaratearemos": "malbaratear",
    "malbarateares": "malbaratear",
    "malbaratearia": "malbaratear",
    "malbarateariam": "malbaratear",
    "malbaratearias": "malbaratear",
    "malbaratearmo": "malbaratear",
    "malbaratearmos": "malbaratear",
    "malbarateará": "malbaratear",
    "malbaratearás": "malbaratear",
    "malbaratearão": "malbaratear",
    "malbaratearíamos": "malbaratear",
    "malbaratearíeis": "malbaratear",
    "malbarateasse": "malbaratear",
    "malbarateassem": "malbaratear",
    "malbarateasses": "malbaratear",
    "malbarateaste": "malbaratear",
    "malbarateastes": "malbaratear",
    "malbarateava": "malbaratear",
    "malbarateavam": "malbaratear",
    "malbarateavas": "malbaratear",
    "malbarateei": "malbaratear",
    "malbarateeis": "malbaratear",
    "malbarateemo": "malbaratear",
    "malbarateemos": "malbaratear",
    "malbaratei": "malbaratar",
    "malbarateia": "malbaratear",
    "malbarateiam": "malbaratear",
    "malbarateias": "malbaratear",
    "malbarateie": "malbaratear",
    "malbarateiem": "malbaratear",
    "malbarateies": "malbaratear",
    "malbarateio": "malbaratear",
    "malbarateis": "malbaratar",
    "malbaratem": "malbaratar",
    "malbaratemo": "malbaratar",
    "malbaratemos": "malbaratar",
    "malbarateou": "malbaratear",
    "malbarates": "malbaratar",
    "malbarateá": "malbaratear",
    "malbarateámo": "malbaratear",
    "malbarateámos": "malbaratear",
    "malbarateáramo": "malbaratear",
    "malbarateáramos": "malbaratear",
    "malbarateárei": "malbaratear",
    "malbarateáreis": "malbaratear",
    "malbarateásseis": "malbaratear",
    "malbarateássemos": "malbaratear",
    "malbarateávamo": "malbaratear",
    "malbarateávamos": "malbaratear",
    "malbarateávei": "malbaratear",
    "malbarateáveis": "malbaratear",
    "malbarato": "malbaratar",
    "malbaratos": "malbarato",
    "malbaratou": "malbaratar",
    "malbaratá": "malbaratar",
    "malbaratámo": "malbaratar",
    "malbaratámos": "malbaratar",
    "malbaratáramo": "malbaratar",
    "malbaratáramos": "malbaratar",
    "malbaratárei": "malbaratar",
    "malbaratáreis": "malbaratar",
    "malbaratásseis": "malbaratar",
    "malbaratássemos": "malbaratar",
    "malbaratávamo": "malbaratar",
    "malbaratávamos": "malbaratar",
    "malbaratávei": "malbaratar",
    "malbaratáveis": "malbaratar",
    "malcasada": "malcasado",
    "malcasadas": "malcasado",
    "malcasados": "malcasado",
    "malcheirosa": "malcheiroso",
    "malcheirosas": "malcheiroso",
    "malcheirosos": "malcheiroso",
    "malcomida": "malcomido",
    "malcomidas": "malcomido",
    "malcomidos": "malcomido",
    "malcontentes": "malcontente",
    "malcorrentes": "malcorrente",
    "malcoza": "malcozer",
    "malcozais": "malcozer",
    "malcozam": "malcozer",
    "malcozamo": "malcozer",
    "malcozamos": "malcozer",
    "malcozas": "malcozer",
    "malcoze": "malcozer",
    "malcozei": "malcozer",
    "malcozeis": "malcozer",
    "malcozem": "malcozer",
    "malcozemo": "malcozer",
    "malcozemos": "malcozer",
    "malcozendo": "malcozer",
    "malcozera": "malcozer",
    "malcozeram": "malcozer",
    "malcozeras": "malcozer",
    "malcozerde": "malcozer",
    "malcozerdes": "malcozer",
    "malcozere": "malcozer",
    "malcozerei": "malcozer",
    "malcozereis": "malcozer",
    "malcozerem": "malcozer",
    "malcozeremos": "malcozer",
    "malcozeres": "malcozer",
    "malcozeria": "malcozer",
    "malcozeriam": "malcozer",
    "malcozerias": "malcozer",
    "malcozermo": "malcozer",
    "malcozermos": "malcozer",
    "malcozerá": "malcozer",
    "malcozerás": "malcozer",
    "malcozerão": "malcozer",
    "malcozeríamos": "malcozer",
    "malcozeríeis": "malcozer",
    "malcozes": "malcozer",
    "malcozesse": "malcozer",
    "malcozessem": "malcozer",
    "malcozesses": "malcozer",
    "malcozeste": "malcozer",
    "malcozestes": "malcozer",
    "malcozeu": "malcozer",
    "malcozi": "malcozer",
    "malcozia": "malcozer",
    "malcoziam": "malcozer",
    "malcozias": "malcozer",
    "malcozida": "malcozer",
    "malcozidas": "malcozer",
    "malcozido": "malcozer",
    "malcozidos": "malcozer",
    "malcozinhada": "malcozinhado",
    "malcozinhadas": "malcozinhado",
    "malcozinhados": "malcozinhado",
    "malcozo": "malcozer",
    "malcozê": "malcozer",
    "malcozêramo": "malcozer",
    "malcozêramos": "malcozer",
    "malcozêrei": "malcozer",
    "malcozêreis": "malcozer",
    "malcozêsseis": "malcozer",
    "malcozêssemos": "malcozer",
    "malcozíamo": "malcozer",
    "malcozíamos": "malcozer",
    "malcozíei": "malcozer",
    "malcozíeis": "malcozer",
    "malcriada": "malcriado",
    "malcriadas": "malcriado",
    "malcriadezes": "malcriadez",
    "malcriadices": "malcriadice",
    "malcriados": "malcriado",
    "malcriadíssima": "malcriado",
    "malcriadíssimas": "malcriado",
    "malcriadíssimo": "malcriado",
    "malcriadíssimos": "malcriado",
    "maldades": "maldade",
    "maldiga": "maldizer",
    "maldigais": "maldizer",
    "maldigam": "maldizer",
    "maldigamo": "maldizer",
    "maldigamos": "maldizer",
    "maldigas": "maldizer",
    "maldigo": "maldizer",
    "maldirei": "maldizer",
    "maldireis": "maldizer",
    "maldiremos": "maldizer",
    "maldiria": "maldizer",
    "maldiriam": "maldizer",
    "maldirias": "maldizer",
    "maldirá": "maldizer",
    "maldirás": "maldizer",
    "maldirão": "maldizer",
    "maldiríamos": "maldizer",
    "maldiríeis": "maldizer",
    "maldisse": "maldizer",
    "maldissemo": "maldizer",
    "maldissemos": "maldizer",
    "maldisser": "maldizer",
    "maldissera": "maldizer",
    "maldisseram": "maldizer",
    "maldisseras": "maldizer",
    "maldisserdes": "maldizer",
    "maldisserem": "maldizer",
    "maldisseres": "maldizer",
    "maldissermos": "maldizer",
    "maldissesse": "maldizer",
    "maldissessem": "maldizer",
    "maldissesses": "maldizer",
    "maldisseste": "maldizer",
    "maldissestes": "maldizer",
    "maldisséramo": "maldizer",
    "maldisséramos": "maldizer",
    "maldissérei": "maldizer",
    "maldisséreis": "maldizer",
    "maldissésseis": "maldizer",
    "maldisséssemos": "maldizer",
    "maldita": "maldizer",
    "malditas": "maldizer",
    "maldito": "maldizer",
    "malditos": "maldizer",
    "malditosa": "malditoso",
    "malditosas": "malditoso",
    "malditosos": "malditoso",
    "maldiva": "maldivo",
    "maldivana": "maldivano",
    "maldivanas": "maldivano",
    "maldivanos": "maldivano",
    "maldivas": "maldivo",
    "maldivos": "maldivo",
    "maldiz": "maldizer",
    "maldize": "maldizer",
    "maldizei": "maldizer",
    "maldizeis": "maldizer",
    "maldizem": "maldizer",
    "maldizemo": "maldizer",
    "maldizemos": "maldizer",
    "maldizendo": "maldizer",
    "maldizentes": "maldizente",
    "maldizerde": "maldizer",
    "maldizerdes": "maldizer",
    "maldizere": "maldizer",
    "maldizerem": "maldizer",
    "maldizeres": "maldizer",
    "maldizermo": "maldizer",
    "maldizermos": "maldizer",
    "maldizes": "maldizer",
    "maldizia": "maldizer",
    "maldiziam": "maldizer",
    "maldizias": "maldizer",
    "maldizê": "maldizer",
    "maldizíamo": "maldizer",
    "maldizíamos": "maldizer",
    "maldizíei": "maldizer",
    "maldizíeis": "maldizer",
    "maldiçoa": "maldiçoar",
    "maldiçoada": "maldiçoar",
    "maldiçoadas": "maldiçoar",
    "maldiçoado": "maldiçoar",
    "maldiçoados": "maldiçoar",
    "maldiçoai": "maldiçoar",
    "maldiçoais": "maldiçoar",
    "maldiçoam": "maldiçoar",
    "maldiçoamo": "maldiçoar",
    "maldiçoamos": "maldiçoar",
    "maldiçoando": "maldiçoar",
    "maldiçoara": "maldiçoar",
    "maldiçoaram": "maldiçoar",
    "maldiçoaras": "maldiçoar",
    "maldiçoarde": "maldiçoar",
    "maldiçoardes": "maldiçoar",
    "maldiçoare": "maldiçoar",
    "maldiçoarei": "maldiçoar",
    "maldiçoareis": "maldiçoar",
    "maldiçoarem": "maldiçoar",
    "maldiçoaremos": "maldiçoar",
    "maldiçoares": "maldiçoar",
    "maldiçoaria": "maldiçoar",
    "maldiçoariam": "maldiçoar",
    "maldiçoarias": "maldiçoar",
    "maldiçoarmo": "maldiçoar",
    "maldiçoarmos": "maldiçoar",
    "maldiçoará": "maldiçoar",
    "maldiçoarás": "maldiçoar",
    "maldiçoarão": "maldiçoar",
    "maldiçoaríamos": "maldiçoar",
    "maldiçoaríeis": "maldiçoar",
    "maldiçoas": "maldiçoar",
    "maldiçoasse": "maldiçoar",
    "maldiçoassem": "maldiçoar",
    "maldiçoasses": "maldiçoar",
    "maldiçoaste": "maldiçoar",
    "maldiçoastes": "maldiçoar",
    "maldiçoava": "maldiçoar",
    "maldiçoavam": "maldiçoar",
    "maldiçoavas": "maldiçoar",
    "maldiçoe": "maldiçoar",
    "maldiçoei": "maldiçoar",
    "maldiçoeis": "maldiçoar",
    "maldiçoem": "maldiçoar",
    "maldiçoemo": "maldiçoar",
    "maldiçoemos": "maldiçoar",
    "maldiçoes": "maldiçoar",
    "maldiçoo": "maldiçoar",
    "maldiçoou": "maldiçoar",
    "maldiçoá": "maldiçoar",
    "maldiçoámo": "maldiçoar",
    "maldiçoámos": "maldiçoar",
    "maldiçoáramo": "maldiçoar",
    "maldiçoáramos": "maldiçoar",
    "maldiçoárei": "maldiçoar",
    "maldiçoáreis": "maldiçoar",
    "maldiçoásseis": "maldiçoar",
    "maldiçoássemos": "maldiçoar",
    "maldiçoávamo": "maldiçoar",
    "maldiçoávamos": "maldiçoar",
    "maldiçoávei": "maldiçoar",
    "maldiçoáveis": "maldiçoar",
    "maldições": "maldição",
    "maldoentes": "maldoente",
    "maldosa": "maldoso",
    "maldosas": "maldoso",
    "maldosos": "maldoso",
    "maleabilidades": "maleabilidade",
    "maleabiliza": "maleabilizar",
    "maleabilizada": "maleabilizar",
    "maleabilizadas": "maleabilizar",
    "maleabilizado": "maleabilizar",
    "maleabilizados": "maleabilizar",
    "maleabilizai": "maleabilizar",
    "maleabilizais": "maleabilizar",
    "maleabilizam": "maleabilizar",
    "maleabilizamo": "maleabilizar",
    "maleabilizamos": "maleabilizar",
    "maleabilizando": "maleabilizar",
    "maleabilizara": "maleabilizar",
    "maleabilizaram": "maleabilizar",
    "maleabilizaras": "maleabilizar",
    "maleabilizarde": "maleabilizar",
    "maleabilizardes": "maleabilizar",
    "maleabilizare": "maleabilizar",
    "maleabilizarei": "maleabilizar",
    "maleabilizareis": "maleabilizar",
    "maleabilizarem": "maleabilizar",
    "maleabilizaremos": "maleabilizar",
    "maleabilizares": "maleabilizar",
    "maleabilizaria": "maleabilizar",
    "maleabilizariam": "maleabilizar",
    "maleabilizarias": "maleabilizar",
    "maleabilizarmo": "maleabilizar",
    "maleabilizarmos": "maleabilizar",
    "maleabilizará": "maleabilizar",
    "maleabilizarás": "maleabilizar",
    "maleabilizarão": "maleabilizar",
    "maleabilizaríamos": "maleabilizar",
    "maleabilizaríeis": "maleabilizar",
    "maleabilizas": "maleabilizar",
    "maleabilizasse": "maleabilizar",
    "maleabilizassem": "maleabilizar",
    "maleabilizasses": "maleabilizar",
    "maleabilizaste": "maleabilizar",
    "maleabilizastes": "maleabilizar",
    "maleabilizava": "maleabilizar",
    "maleabilizavam": "maleabilizar",
    "maleabilizavas": "maleabilizar",
    "maleabilize": "maleabilizar",
    "maleabilizei": "maleabilizar",
    "maleabilizeis": "maleabilizar",
    "maleabilizem": "maleabilizar",
    "maleabilizemo": "maleabilizar",
    "maleabilizemos": "maleabilizar",
    "maleabilizes": "maleabilizar",
    "maleabilizo": "maleabilizar",
    "maleabilizou": "maleabilizar",
    "maleabilizá": "maleabilizar",
    "maleabilizámo": "maleabilizar",
    "maleabilizámos": "maleabilizar",
    "maleabilizáramo": "maleabilizar",
    "maleabilizáramos": "maleabilizar",
    "maleabilizárei": "maleabilizar",
    "maleabilizáreis": "maleabilizar",
    "maleabilizásseis": "maleabilizar",
    "maleabilizássemos": "maleabilizar",
    "maleabilizávamo": "maleabilizar",
    "maleabilizávamos": "maleabilizar",
    "maleabilizávei": "maleabilizar",
    "maleabilizáveis": "maleabilizável",
    "maleada": "malear",
    "maleadas": "malear",
    "maleado": "malear",
    "maleadora": "maleador",
    "maleadoras": "maleador",
    "maleadores": "maleador",
    "maleados": "malear",
    "maleai": "malear",
    "maleais": "malear",
    "maleamo": "malear",
    "maleamos": "malear",
    "maleando": "malear",
    "maleara": "malear",
    "malearam": "malear",
    "malearas": "malear",
    "malearde": "malear",
    "maleardes": "malear",
    "maleare": "malear",
    "malearei": "malear",
    "maleareis": "malear",
    "malearem": "malear",
    "malearemos": "malear",
    "maleares": "malear",
    "malearia": "malear",
    "maleariam": "malear",
    "malearias": "malear",
    "malearmo": "malear",
    "malearmos": "malear",
    "maleará": "malear",
    "malearás": "malear",
    "malearão": "malear",
    "malearíamos": "malear",
    "malearíeis": "malear",
    "maleasse": "malear",
    "maleassem": "malear",
    "maleasses": "malear",
    "maleaste": "malear",
    "maleastes": "malear",
    "maleava": "malear",
    "maleavam": "malear",
    "maleavas": "malear",
    "maledicentes": "maledicente",
    "maledicências": "maledicência",
    "maledos": "maledo",
    "maleei": "malear",
    "maleeis": "malear",
    "maleemo": "malear",
    "maleemos": "malear",
    "maleficia": "maleficiar",
    "maleficiada": "maleficiar",
    "maleficiadas": "maleficiar",
    "maleficiado": "maleficiar",
    "maleficiados": "maleficiar",
    "maleficiai": "maleficiar",
    "maleficiais": "maleficiar",
    "maleficiam": "maleficiar",
    "maleficiamo": "maleficiar",
    "maleficiamos": "maleficiar",
    "maleficiando": "maleficiar",
    "maleficiara": "maleficiar",
    "maleficiaram": "maleficiar",
    "maleficiaras": "maleficiar",
    "maleficiarde": "maleficiar",
    "maleficiardes": "maleficiar",
    "maleficiare": "maleficiar",
    "maleficiarei": "maleficiar",
    "maleficiareis": "maleficiar",
    "maleficiarem": "maleficiar",
    "maleficiaremos": "maleficiar",
    "maleficiares": "maleficiar",
    "maleficiaria": "maleficiar",
    "maleficiariam": "maleficiar",
    "maleficiarias": "maleficiar",
    "maleficiarmo": "maleficiar",
    "maleficiarmos": "maleficiar",
    "maleficiará": "maleficiar",
    "maleficiarás": "maleficiar",
    "maleficiarão": "maleficiar",
    "maleficiaríamos": "maleficiar",
    "maleficiaríeis": "maleficiar",
    "maleficias": "maleficiar",
    "maleficiasse": "maleficiar",
    "maleficiassem": "maleficiar",
    "maleficiasses": "maleficiar",
    "maleficiaste": "maleficiar",
    "maleficiastes": "maleficiar",
    "maleficiava": "maleficiar",
    "maleficiavam": "maleficiar",
    "maleficiavas": "maleficiar",
    "maleficie": "maleficiar",
    "maleficiei": "maleficiar",
    "maleficieis": "maleficiar",
    "maleficiem": "maleficiar",
    "maleficiemo": "maleficiar",
    "maleficiemos": "maleficiar",
    "maleficientes": "maleficiente",
    "maleficientíssima": "maleficiente",
    "maleficientíssimas": "maleficiente",
    "maleficientíssimo": "maleficiente",
    "maleficientíssimos": "maleficiente",
    "maleficies": "maleficiar",
    "maleficio": "maleficiar",
    "maleficiou": "maleficiar",
    "maleficiá": "maleficiar",
    "maleficiámo": "maleficiar",
    "maleficiámos": "maleficiar",
    "maleficiáramo": "maleficiar",
    "maleficiáramos": "maleficiar",
    "maleficiárei": "maleficiar",
    "maleficiáreis": "maleficiar",
    "maleficiásseis": "maleficiar",
    "maleficiássemos": "maleficiar",
    "maleficiávamo": "maleficiar",
    "maleficiávamos": "maleficiar",
    "maleficiávei": "maleficiar",
    "maleficiáveis": "maleficiar",
    "maleficiências": "maleficiência",
    "malefícios": "malefício",
    "maleia": "malear",
    "maleiam": "malear",
    "maleias": "malear",
    "maleie": "malear",
    "maleiem": "malear",
    "maleies": "malear",
    "maleiformes": "maleiforme",
    "maleio": "malear",
    "maleira": "maleiro",
    "maleiras": "maleiro",
    "maleiros": "maleiro",
    "maleitas": "maleita",
    "maleiteiras": "maleiteira",
    "maleitosa": "maleitoso",
    "maleitosas": "maleitoso",
    "maleitosos": "maleitoso",
    "maleolares": "maleolar",
    "maleotomias": "maleotomia",
    "maleou": "malear",
    "males": "mal",
    "malesa": "malês",
    "malesas": "malês",
    "maleses": "malês",
    "malessa": "malesso",
    "malessas": "malesso",
    "malessos": "malesso",
    "maletas": "maleta",
    "malevolentes": "malevolente",
    "malevolentíssima": "malevolente",
    "malevolentíssimas": "malevolente",
    "malevolentíssimo": "malevolente",
    "malevolentíssimos": "malevolente",
    "malevolências": "malevolência",
    "malezas": "maleza",
    "maleá": "malear",
    "maleácea": "maleáceo",
    "maleáceas": "maleáceo",
    "maleáceos": "maleáceo",
    "maleámo": "malear",
    "maleámos": "malear",
    "maleáramo": "malear",
    "maleáramos": "malear",
    "maleárei": "malear",
    "maleáreis": "malear",
    "maleásseis": "malear",
    "maleássemos": "malear",
    "maleávamo": "malear",
    "maleávamos": "malear",
    "maleávei": "malear",
    "maleáveis": "maleável",
    "malfada": "malfadar",
    "malfadada": "malfadar",
    "malfadadas": "malfadar",
    "malfadado": "malfadar",
    "malfadados": "malfadar",
    "malfadai": "malfadar",
    "malfadais": "malfadar",
    "malfadam": "malfadar",
    "malfadamo": "malfadar",
    "malfadamos": "malfadar",
    "malfadando": "malfadar",
    "malfadara": "malfadar",
    "malfadaram": "malfadar",
    "malfadaras": "malfadar",
    "malfadarde": "malfadar",
    "malfadardes": "malfadar",
    "malfadare": "malfadar",
    "malfadarei": "malfadar",
    "malfadareis": "malfadar",
    "malfadarem": "malfadar",
    "malfadaremos": "malfadar",
    "malfadares": "malfadar",
    "malfadaria": "malfadar",
    "malfadariam": "malfadar",
    "malfadarias": "malfadar",
    "malfadarmo": "malfadar",
    "malfadarmos": "malfadar",
    "malfadará": "malfadar",
    "malfadarás": "malfadar",
    "malfadarão": "malfadar",
    "malfadaríamos": "malfadar",
    "malfadaríeis": "malfadar",
    "malfadas": "malfadar",
    "malfadasse": "malfadar",
    "malfadassem": "malfadar",
    "malfadasses": "malfadar",
    "malfadaste": "malfadar",
    "malfadastes": "malfadar",
    "malfadava": "malfadar",
    "malfadavam": "malfadar",
    "malfadavas": "malfadar",
    "malfade": "malfadar",
    "malfadei": "malfadar",
    "malfadeis": "malfadar",
    "malfadem": "malfadar",
    "malfademo": "malfadar",
    "malfademos": "malfadar",
    "malfades": "malfadar",
    "malfado": "malfadar",
    "malfadou": "malfadar",
    "malfadá": "malfadar",
    "malfadámo": "malfadar",
    "malfadámos": "malfadar",
    "malfadáramo": "malfadar",
    "malfadáramos": "malfadar",
    "malfadárei": "malfadar",
    "malfadáreis": "malfadar",
    "malfadásseis": "malfadar",
    "malfadássemos": "malfadar",
    "malfadávamo": "malfadar",
    "malfadávamos": "malfadar",
    "malfadávei": "malfadar",
    "malfadáveis": "malfadar",
    "malfalantes": "malfalante",
    "malfarei": "malfazer",
    "malfareis": "malfazer",
    "malfaremos": "malfazer",
    "malfaria": "malfazer",
    "malfariam": "malfazer",
    "malfarias": "malfazer",
    "malfará": "malfazer",
    "malfarás": "malfazer",
    "malfarão": "malfazer",
    "malfaríamos": "malfazer",
    "malfaríeis": "malfazer",
    "malfaz": "malfazer",
    "malfaze": "malfazer",
    "malfazei": "malfazer",
    "malfazeis": "malfazer",
    "malfazeja": "malfazejo",
    "malfazejas": "malfazejo",
    "malfazejos": "malfazejo",
    "malfazem": "malfazer",
    "malfazemo": "malfazer",
    "malfazemos": "malfazer",
    "malfazendo": "malfazer",
    "malfazentes": "malfazente",
    "malfazerde": "malfazer",
    "malfazerdes": "malfazer",
    "malfazere": "malfazer",
    "malfazerem": "malfazer",
    "malfazeres": "malfazer",
    "malfazermo": "malfazer",
    "malfazermos": "malfazer",
    "malfazes": "malfazer",
    "malfazia": "malfazer",
    "malfaziam": "malfazer",
    "malfazias": "malfazer",
    "malfazê": "malfazer",
    "malfazíamo": "malfazer",
    "malfazíamos": "malfazer",
    "malfazíei": "malfazer",
    "malfazíeis": "malfazer",
    "malfaça": "malfazer",
    "malfaçais": "malfazer",
    "malfaçam": "malfazer",
    "malfaçamo": "malfazer",
    "malfaçamos": "malfazer",
    "malfaças": "malfazer",
    "malfaço": "malfazer",
    "malfeita": "malfeito",
    "malfeitas": "malfeito",
    "malfeito": "malfazer",
    "malfeitora": "malfeitor",
    "malfeitoras": "malfeitor",
    "malfeitores": "malfeitor",
    "malfeitorias": "malfeitoria",
    "malfeitos": "malfeito",
    "malfere": "malferir",
    "malferem": "malferir",
    "malferes": "malferir",
    "malferi": "malferir",
    "malferia": "malferir",
    "malferiam": "malferir",
    "malferias": "malferir",
    "malferida": "malferir",
    "malferidas": "malferir",
    "malferido": "malferir",
    "malferidos": "malferir",
    "malferimo": "malferir",
    "malferimos": "malferir",
    "malferindo": "malferir",
    "malferira": "malferir",
    "malferiram": "malferir",
    "malferiras": "malferir",
    "malferirde": "malferir",
    "malferirdes": "malferir",
    "malferire": "malferir",
    "malferirei": "malferir",
    "malferireis": "malferir",
    "malferirem": "malferir",
    "malferiremos": "malferir",
    "malferires": "malferir",
    "malferiria": "malferir",
    "malfeririam": "malferir",
    "malferirias": "malferir",
    "malferirmo": "malferir",
    "malferirmos": "malferir",
    "malferirá": "malferir",
    "malferirás": "malferir",
    "malferirão": "malferir",
    "malferiríamos": "malferir",
    "malferiríeis": "malferir",
    "malferis": "malferir",
    "malferisse": "malferir",
    "malferissem": "malferir",
    "malferisses": "malferir",
    "malferiste": "malferir",
    "malferistes": "malferir",
    "malferiu": "malferir",
    "malferíamo": "malferir",
    "malferíamos": "malferir",
    "malferíei": "malferir",
    "malferíeis": "malferir",
    "malferíramo": "malferir",
    "malferíramos": "malferir",
    "malferírei": "malferir",
    "malferíreis": "malferir",
    "malferísseis": "malferir",
    "malferíssemos": "malferir",
    "malfez": "malfazer",
    "malfi": "malfazer",
    "malfira": "malferir",
    "malfirais": "malferir",
    "malfiram": "malferir",
    "malfiramo": "malferir",
    "malfiramos": "malferir",
    "malfiras": "malferir",
    "malfiro": "malferir",
    "malfiz": "malfazer",
    "malfizemo": "malfazer",
    "malfizemos": "malfazer",
    "malfizer": "malfazer",
    "malfizera": "malfazer",
    "malfizeram": "malfazer",
    "malfizeras": "malfazer",
    "malfizerdes": "malfazer",
    "malfizerem": "malfazer",
    "malfizeres": "malfazer",
    "malfizermos": "malfazer",
    "malfizesse": "malfazer",
    "malfizessem": "malfazer",
    "malfizesses": "malfazer",
    "malfizeste": "malfazer",
    "malfizestes": "malfazer",
    "malfizéramo": "malfazer",
    "malfizéramos": "malfazer",
    "malfizérei": "malfazer",
    "malfizéreis": "malfazer",
    "malfizésseis": "malfazer",
    "malfizéssemos": "malfazer",
    "malformada": "malformado",
    "malformadas": "malformado",
    "malformados": "malformado",
    "malformações": "malformação",
    "malfá": "malfazer",
    "malfê": "malfazer",
    "malgalantes": "malgalante",
    "malgas": "malga",
    "malgasta": "malgastar",
    "malgastada": "malgastar",
    "malgastadas": "malgastar",
    "malgastado": "malgastar",
    "malgastados": "malgastar",
    "malgastai": "malgastar",
    "malgastais": "malgastar",
    "malgastam": "malgastar",
    "malgastamo": "malgastar",
    "malgastamos": "malgastar",
    "malgastando": "malgastar",
    "malgastara": "malgastar",
    "malgastaram": "malgastar",
    "malgastaras": "malgastar",
    "malgastarde": "malgastar",
    "malgastardes": "malgastar",
    "malgastare": "malgastar",
    "malgastarei": "malgastar",
    "malgastareis": "malgastar",
    "malgastarem": "malgastar",
    "malgastaremos": "malgastar",
    "malgastares": "malgastar",
    "malgastaria": "malgastar",
    "malgastariam": "malgastar",
    "malgastarias": "malgastar",
    "malgastarmo": "malgastar",
    "malgastarmos": "malgastar",
    "malgastará": "malgastar",
    "malgastarás": "malgastar",
    "malgastarão": "malgastar",
    "malgastaríamos": "malgastar",
    "malgastaríeis": "malgastar",
    "malgastas": "malgastar",
    "malgastasse": "malgastar",
    "malgastassem": "malgastar",
    "malgastasses": "malgastar",
    "malgastaste": "malgastar",
    "malgastastes": "malgastar",
    "malgastava": "malgastar",
    "malgastavam": "malgastar",
    "malgastavas": "malgastar",
    "malgaste": "malgastar",
    "malgastei": "malgastar",
    "malgasteis": "malgastar",
    "malgastem": "malgastar",
    "malgastemo": "malgastar",
    "malgastemos": "malgastar",
    "malgastes": "malgastar",
    "malgasto": "malgastar",
    "malgastou": "malgastar",
    "malgastá": "malgastar",
    "malgastámo": "malgastar",
    "malgastámos": "malgastar",
    "malgastáramo": "malgastar",
    "malgastáramos": "malgastar",
    "malgastárei": "malgastar",
    "malgastáreis": "malgastar",
    "malgastásseis": "malgastar",
    "malgastássemos": "malgastar",
    "malgastávamo": "malgastar",
    "malgastávamos": "malgastar",
    "malgastávei": "malgastar",
    "malgastáveis": "malgastar",
    "malgaxes": "malgaxe",
    "malgoverna": "malgovernar",
    "malgovernada": "malgovernar",
    "malgovernadas": "malgovernar",
    "malgovernado": "malgovernar",
    "malgovernados": "malgovernar",
    "malgovernai": "malgovernar",
    "malgovernais": "malgovernar",
    "malgovernam": "malgovernar",
    "malgovernamo": "malgovernar",
    "malgovernamos": "malgovernar",
    "malgovernando": "malgovernar",
    "malgovernara": "malgovernar",
    "malgovernaram": "malgovernar",
    "malgovernaras": "malgovernar",
    "malgovernarde": "malgovernar",
    "malgovernardes": "malgovernar",
    "malgovernare": "malgovernar",
    "malgovernarei": "malgovernar",
    "malgovernareis": "malgovernar",
    "malgovernarem": "malgovernar",
    "malgovernaremos": "malgovernar",
    "malgovernares": "malgovernar",
    "malgovernaria": "malgovernar",
    "malgovernariam": "malgovernar",
    "malgovernarias": "malgovernar",
    "malgovernarmo": "malgovernar",
    "malgovernarmos": "malgovernar",
    "malgovernará": "malgovernar",
    "malgovernarás": "malgovernar",
    "malgovernarão": "malgovernar",
    "malgovernaríamos": "malgovernar",
    "malgovernaríeis": "malgovernar",
    "malgovernas": "malgovernar",
    "malgovernasse": "malgovernar",
    "malgovernassem": "malgovernar",
    "malgovernasses": "malgovernar",
    "malgovernaste": "malgovernar",
    "malgovernastes": "malgovernar",
    "malgovernava": "malgovernar",
    "malgovernavam": "malgovernar",
    "malgovernavas": "malgovernar",
    "malgoverne": "malgovernar",
    "malgovernei": "malgovernar",
    "malgoverneis": "malgovernar",
    "malgovernem": "malgovernar",
    "malgovernemo": "malgovernar",
    "malgovernemos": "malgovernar",
    "malgovernes": "malgovernar",
    "malgoverno": "malgovernar",
    "malgovernou": "malgovernar",
    "malgoverná": "malgovernar",
    "malgovernámo": "malgovernar",
    "malgovernámos": "malgovernar",
    "malgovernáramo": "malgovernar",
    "malgovernáramos": "malgovernar",
    "malgovernárei": "malgovernar",
    "malgovernáreis": "malgovernar",
    "malgovernásseis": "malgovernar",
    "malgovernássemos": "malgovernar",
    "malgovernávamo": "malgovernar",
    "malgovernávamos": "malgovernar",
    "malgovernávei": "malgovernar",
    "malgovernáveis": "malgovernar",
    "malgrados": "malgrado",
    "malgueira": "malgueiro",
    "malgueiras": "malgueiro",
    "malgueiros": "malgueiro",
    "malgáveis": "malgável",
    "malha": "malhar",
    "malhada": "malhar",
    "malhadais": "malhadal",
    "malhadas": "malhar",
    "malhadazinha": "malhado",
    "malhadazinhas": "malhado",
    "malhadazita": "malhado",
    "malhadazitas": "malhado",
    "malhadeira": "malhadeiro",
    "malhadeiras": "malhadeiro",
    "malhadeiros": "malhadeiro",
    "malhadinha": "malhado",
    "malhadinhas": "malhado",
    "malhadinho": "malhado",
    "malhadinhos": "malhado",
    "malhadis": "malhadil",
    "malhadita": "malhado",
    "malhaditas": "malhado",
    "malhadito": "malhado",
    "malhaditos": "malhado",
    "malhadiça": "malhadiço",
    "malhadiças": "malhadiço",
    "malhadiços": "malhadiço",
    "malhado": "malhar",
    "malhadoiros": "malhadoiro",
    "malhadora": "malhador",
    "malhadoras": "malhador",
    "malhadores": "malhador",
    "malhados": "malhar",
    "malhadouros": "malhadouro",
    "malhadozinho": "malhado",
    "malhadozinhos": "malhado",
    "malhadozito": "malhado",
    "malhadozitos": "malhado",
    "malhagens": "malhagem",
    "malhai": "malhar",
    "malhais": "malhar",
    "malham": "malhar",
    "malhamo": "malhar",
    "malhamos": "malhar",
    "malhando": "malhar",
    "malhantes": "malhante",
    "malhanços": "malhanço",
    "malhara": "malhar",
    "malharam": "malhar",
    "malharas": "malhar",
    "malharde": "malhar",
    "malhardes": "malhar",
    "malhare": "malhar",
    "malharei": "malhar",
    "malhareis": "malhar",
    "malharem": "malhar",
    "malharemos": "malhar",
    "malhares": "malhar",
    "malharia": "malhar",
    "malhariam": "malhar",
    "malharias": "malharia",
    "malharmo": "malhar",
    "malharmos": "malhar",
    "malhará": "malhar",
    "malharás": "malhar",
    "malharão": "malhar",
    "malharíamos": "malhar",
    "malharíeis": "malhar",
    "malhas": "malhar",
    "malhasse": "malhar",
    "malhassem": "malhar",
    "malhasses": "malhar",
    "malhaste": "malhar",
    "malhastes": "malhar",
    "malhava": "malhar",
    "malhavam": "malhar",
    "malhavas": "malhar",
    "malhações": "malhação",
    "malhe": "malhar",
    "malhei": "malhar",
    "malheiros": "malheiro",
    "malheirões": "malheirão",
    "malheis": "malhar",
    "malhem": "malhar",
    "malhemo": "malhar",
    "malhemos": "malhar",
    "malhes": "malhar",
    "malheta": "malhetar",
    "malhetada": "malhetar",
    "malhetadas": "malhetar",
    "malhetado": "malhetar",
    "malhetados": "malhetar",
    "malhetai": "malhetar",
    "malhetais": "malhetar",
    "malhetam": "malhetar",
    "malhetamo": "malhetar",
    "malhetamos": "malhetar",
    "malhetando": "malhetar",
    "malhetara": "malhetar",
    "malhetaram": "malhetar",
    "malhetaras": "malhetar",
    "malhetarde": "malhetar",
    "malhetardes": "malhetar",
    "malhetare": "malhetar",
    "malhetarei": "malhetar",
    "malhetareis": "malhetar",
    "malhetarem": "malhetar",
    "malhetaremos": "malhetar",
    "malhetares": "malhetar",
    "malhetaria": "malhetar",
    "malhetariam": "malhetar",
    "malhetarias": "malhetar",
    "malhetarmo": "malhetar",
    "malhetarmos": "malhetar",
    "malhetará": "malhetar",
    "malhetarás": "malhetar",
    "malhetarão": "malhetar",
    "malhetaríamos": "malhetar",
    "malhetaríeis": "malhetar",
    "malhetas": "malhetar",
    "malhetasse": "malhetar",
    "malhetassem": "malhetar",
    "malhetasses": "malhetar",
    "malhetaste": "malhetar",
    "malhetastes": "malhetar",
    "malhetava": "malhetar",
    "malhetavam": "malhetar",
    "malhetavas": "malhetar",
    "malhete": "malhetar",
    "malhetei": "malhetar",
    "malheteis": "malhetar",
    "malhetem": "malhetar",
    "malhetemo": "malhetar",
    "malhetemos": "malhetar",
    "malhetes": "malhete",
    "malheto": "malhetar",
    "malhetou": "malhetar",
    "malhetá": "malhetar",
    "malhetámo": "malhetar",
    "malhetámos": "malhetar",
    "malhetáramo": "malhetar",
    "malhetáramos": "malhetar",
    "malhetárei": "malhetar",
    "malhetáreis": "malhetar",
    "malhetásseis": "malhetar",
    "malhetássemos": "malhetar",
    "malhetávamo": "malhetar",
    "malhetávamos": "malhetar",
    "malhetávei": "malhetar",
    "malhetáveis": "malhetar",
    "malho": "malhar",
    "malhoadas": "malhoada",
    "malhorcos": "malhorco",
    "malhos": "malho",
    "malhou": "malhar",
    "malhá": "malhar",
    "malhámo": "malhar",
    "malhámos": "malhar",
    "malháramo": "malhar",
    "malháramos": "malhar",
    "malhárei": "malhar",
    "malháreis": "malhar",
    "malhásseis": "malhar",
    "malhássemos": "malhar",
    "malhávamo": "malhar",
    "malhávamos": "malhar",
    "malhávei": "malhar",
    "malháveis": "malhável",
    "malhões": "malhão",
    "malicia": "maliciar",
    "maliciada": "maliciar",
    "maliciadas": "maliciar",
    "maliciado": "maliciar",
    "maliciados": "maliciar",
    "maliciai": "maliciar",
    "maliciais": "maliciar",
    "maliciam": "maliciar",
    "maliciamo": "maliciar",
    "maliciamos": "maliciar",
    "maliciando": "maliciar",
    "maliciara": "maliciar",
    "maliciaram": "maliciar",
    "maliciaras": "maliciar",
    "maliciarde": "maliciar",
    "maliciardes": "maliciar",
    "maliciare": "maliciar",
    "maliciarei": "maliciar",
    "maliciareis": "maliciar",
    "maliciarem": "maliciar",
    "maliciaremos": "maliciar",
    "maliciares": "maliciar",
    "maliciaria": "maliciar",
    "maliciariam": "maliciar",
    "maliciarias": "maliciar",
    "maliciarmo": "maliciar",
    "maliciarmos": "maliciar",
    "maliciará": "maliciar",
    "maliciarás": "maliciar",
    "maliciarão": "maliciar",
    "maliciaríamos": "maliciar",
    "maliciaríeis": "maliciar",
    "malicias": "maliciar",
    "maliciasse": "maliciar",
    "maliciassem": "maliciar",
    "maliciasses": "maliciar",
    "maliciaste": "maliciar",
    "maliciastes": "maliciar",
    "maliciava": "maliciar",
    "maliciavam": "maliciar",
    "maliciavas": "maliciar",
    "maliciazinha": "malícia",
    "maliciazinhas": "malícia",
    "maliciazita": "malícia",
    "maliciazitas": "malícia",
    "malicie": "maliciar",
    "maliciei": "maliciar",
    "malicieis": "maliciar",
    "maliciem": "maliciar",
    "maliciemo": "maliciar",
    "maliciemos": "maliciar",
    "malicies": "maliciar",
    "malicio": "maliciar",
    "maliciosa": "malicioso",
    "maliciosas": "malicioso",
    "maliciosidades": "maliciosidade",
    "maliciosos": "malicioso",
    "maliciou": "maliciar",
    "maliciá": "maliciar",
    "maliciámo": "maliciar",
    "maliciámos": "maliciar",
    "maliciáramo": "maliciar",
    "maliciáramos": "maliciar",
    "maliciárei": "maliciar",
    "maliciáreis": "maliciar",
    "maliciásseis": "maliciar",
    "maliciássemos": "maliciar",
    "maliciávamo": "maliciar",
    "maliciávamos": "maliciar",
    "maliciávei": "maliciar",
    "maliciáveis": "maliciar",
    "maliformes": "maliforme",
    "maligna": "maligno",
    "malignada": "malignar",
    "malignadas": "malignar",
    "malignado": "malignar",
    "malignados": "malignar",
    "malignai": "malignar",
    "malignais": "malignar",
    "malignam": "malignar",
    "malignamo": "malignar",
    "malignamos": "malignar",
    "malignando": "malignar",
    "malignantes": "malignante",
    "malignara": "malignar",
    "malignaram": "malignar",
    "malignaras": "malignar",
    "malignarde": "malignar",
    "malignardes": "malignar",
    "malignare": "malignar",
    "malignarei": "malignar",
    "malignareis": "malignar",
    "malignarem": "malignar",
    "malignaremos": "malignar",
    "malignares": "malignar",
    "malignaria": "malignar",
    "malignariam": "malignar",
    "malignarias": "malignar",
    "malignarmo": "malignar",
    "malignarmos": "malignar",
    "malignará": "malignar",
    "malignarás": "malignar",
    "malignarão": "malignar",
    "malignaríamos": "malignar",
    "malignaríeis": "malignar",
    "malignas": "maligno",
    "malignasse": "malignar",
    "malignassem": "malignar",
    "malignasses": "malignar",
    "malignaste": "malignar",
    "malignastes": "malignar",
    "malignava": "malignar",
    "malignavam": "malignar",
    "malignavas": "malignar",
    "maligne": "malignar",
    "malignei": "malignar",
    "maligneis": "malignar",
    "malignem": "malignar",
    "malignemo": "malignar",
    "malignemos": "malignar",
    "malignes": "malignar",
    "malignidades": "malignidade",
    "maligno": "malignar",
    "malignos": "maligno",
    "malignou": "malignar",
    "maligná": "malignar",
    "malignámo": "malignar",
    "malignámos": "malignar",
    "malignáramo": "malignar",
    "malignáramos": "malignar",
    "malignárei": "malignar",
    "malignáreis": "malignar",
    "malignásseis": "malignar",
    "malignássemos": "malignar",
    "malignávamo": "malignar",
    "malignávamos": "malignar",
    "malignávei": "malignar",
    "malignáveis": "malignar",
    "malina": "malinar",
    "malinada": "malinar",
    "malinadas": "malinar",
    "malinado": "malinar",
    "malinados": "malinar",
    "malinai": "malinar",
    "malinais": "malinar",
    "malinam": "malinar",
    "malinamo": "malinar",
    "malinamos": "malinar",
    "malinando": "malinar",
    "malinara": "malinar",
    "malinaram": "malinar",
    "malinaras": "malinar",
    "malinarde": "malinar",
    "malinardes": "malinar",
    "malinare": "malinar",
    "malinarei": "malinar",
    "malinareis": "malinar",
    "malinarem": "malinar",
    "malinaremos": "malinar",
    "malinares": "malinar",
    "malinaria": "malinar",
    "malinariam": "malinar",
    "malinarias": "malinar",
    "malinarmo": "malinar",
    "malinarmos": "malinar",
    "malinará": "malinar",
    "malinarás": "malinar",
    "malinarão": "malinar",
    "malinaríamos": "malinar",
    "malinaríeis": "malinar",
    "malinas": "malinar",
    "malinasse": "malinar",
    "malinassem": "malinar",
    "malinasses": "malinar",
    "malinaste": "malinar",
    "malinastes": "malinar",
    "malinava": "malinar",
    "malinavam": "malinar",
    "malinavas": "malinar",
    "maline": "malinar",
    "malinei": "malinar",
    "malineis": "malinar",
    "malinem": "malinar",
    "malinemo": "malinar",
    "malinemos": "malinar",
    "malines": "malinar",
    "malinha": "mala",
    "malinhas": "mala",
    "malino": "malinar",
    "malinou": "malinar",
    "malins": "malim",
    "maliná": "malinar",
    "malinámo": "malinar",
    "malinámos": "malinar",
    "malináramo": "malinar",
    "malináramos": "malinar",
    "malinárei": "malinar",
    "malináreis": "malinar",
    "malinásseis": "malinar",
    "malinássemos": "malinar",
    "malinávamo": "malinar",
    "malinávamos": "malinar",
    "malinávei": "malinar",
    "malináveis": "malinar",
    "malita": "mala",
    "malitas": "mala",
    "maljeitosa": "maljeitoso",
    "maljeitosas": "maljeitoso",
    "maljeitosos": "maljeitoso",
    "malmajudas": "malmajuda",
    "malmandada": "malmandado",
    "malmandadas": "malmandado",
    "malmandados": "malmandado",
    "malmaridadas": "malmaridada",
    "malmequeres": "malmequer",
    "malmequerzinho": "malmequer",
    "malmequerzinhos": "malmequer",
    "malmequerzito": "malmequer",
    "malmequerzitos": "malmequer",
    "malmes": "malm",
    "malnascida": "malnascido",
    "malnascidas": "malnascido",
    "malnascidos": "malnascido",
    "malnutrida": "malnutrido",
    "malnutridas": "malnutrido",
    "malnutridos": "malnutrido",
    "malnutrições": "malnutrição",
    "malocas": "maloca",
    "malogra": "malograr",
    "malograda": "malograr",
    "malogradas": "malograr",
    "malogrado": "malograr",
    "malogrados": "malograr",
    "malograi": "malograr",
    "malograis": "malograr",
    "malogram": "malograr",
    "malogramo": "malograr",
    "malogramos": "malograr",
    "malogrando": "malograr",
    "malograra": "malograr",
    "malograram": "malograr",
    "malograras": "malograr",
    "malograrde": "malograr",
    "malogrardes": "malograr",
    "malograre": "malograr",
    "malograrei": "malograr",
    "malograreis": "malograr",
    "malograrem": "malograr",
    "malograremos": "malograr",
    "malograres": "malograr",
    "malograria": "malograr",
    "malograriam": "malograr",
    "malograrias": "malograr",
    "malograrmo": "malograr",
    "malograrmos": "malograr",
    "malogrará": "malograr",
    "malograrás": "malograr",
    "malograrão": "malograr",
    "malograríamos": "malograr",
    "malograríeis": "malograr",
    "malogras": "malograr",
    "malograsse": "malograr",
    "malograssem": "malograr",
    "malograsses": "malograr",
    "malograste": "malograr",
    "malograstes": "malograr",
    "malograva": "malograr",
    "malogravam": "malograr",
    "malogravas": "malograr",
    "malogre": "malograr",
    "malogrei": "malograr",
    "malogreis": "malograr",
    "malogrem": "malograr",
    "malogremo": "malograr",
    "malogremos": "malograr",
    "malogres": "malograr",
    "malogro": "malograr",
    "malogros": "malogro",
    "malogrou": "malograr",
    "malográ": "malograr",
    "malográmo": "malograr",
    "malográmos": "malograr",
    "malográramo": "malograr",
    "malográramos": "malograr",
    "malográrei": "malograr",
    "malográreis": "malograr",
    "malográsseis": "malograr",
    "malográssemos": "malograr",
    "malográvamo": "malograr",
    "malográvamos": "malograr",
    "malográvei": "malograr",
    "malográveis": "malograr",
    "maloios": "maloio",
    "malonas": "malona",
    "malos": "malo",
    "malotes": "malote",
    "malotões": "malotão",
    "malpara": "malparir",
    "malparada": "malparar",
    "malparadas": "malparar",
    "malparado": "malparar",
    "malparados": "malparar",
    "malparai": "malparar",
    "malparais": "malparir",
    "malparam": "malparir",
    "malparamo": "malparir",
    "malparamos": "malparir",
    "malparando": "malparar",
    "malparara": "malparar",
    "malpararam": "malparar",
    "malpararas": "malparar",
    "malpararde": "malparar",
    "malparardes": "malparar",
    "malparare": "malparar",
    "malpararei": "malparar",
    "malparareis": "malparar",
    "malpararem": "malparar",
    "malpararemos": "malparar",
    "malparares": "malparar",
    "malpararia": "malparar",
    "malparariam": "malparar",
    "malpararias": "malparar",
    "malpararmo": "malparar",
    "malpararmos": "malparar",
    "malparará": "malparar",
    "malpararás": "malparar",
    "malpararão": "malparar",
    "malpararíamos": "malparar",
    "malpararíeis": "malparar",
    "malparas": "malparir",
    "malparasse": "malparar",
    "malparassem": "malparar",
    "malparasses": "malparar",
    "malparaste": "malparar",
    "malparastes": "malparar",
    "malparava": "malparar",
    "malparavam": "malparar",
    "malparavas": "malparar",
    "malpare": "malparir",
    "malparei": "malparar",
    "malpareis": "malparar",
    "malparem": "malparir",
    "malparemo": "malparar",
    "malparemos": "malparar",
    "malpares": "malparir",
    "malpari": "malparir",
    "malparia": "malparir",
    "malpariam": "malparir",
    "malparias": "malparir",
    "malparida": "malparir",
    "malparidas": "malparir",
    "malparido": "malparir",
    "malparidos": "malparir",
    "malparimo": "malparir",
    "malparimos": "malparir",
    "malparindo": "malparir",
    "malparira": "malparir",
    "malpariram": "malparir",
    "malpariras": "malparir",
    "malparirdes": "malparir",
    "malparirei": "malparir",
    "malparireis": "malparir",
    "malparirem": "malparir",
    "malpariremos": "malparir",
    "malparires": "malparir",
    "malpariria": "malparir",
    "malpaririam": "malparir",
    "malparirias": "malparir",
    "malparirmo": "malparir",
    "malparirmos": "malparir",
    "malparirá": "malparir",
    "malparirás": "malparir",
    "malparirão": "malparir",
    "malpariríamos": "malparir",
    "malpariríeis": "malparir",
    "malparis": "malparir",
    "malparisse": "malparir",
    "malparissem": "malparir",
    "malparisses": "malparir",
    "malpariste": "malparir",
    "malparistes": "malparir",
    "malpariu": "malparir",
    "malparo": "malparir",
    "malparou": "malparar",
    "malpará": "malparar",
    "malparámo": "malparar",
    "malparámos": "malparar",
    "malparáramo": "malparar",
    "malparáramos": "malparar",
    "malparárei": "malparar",
    "malparáreis": "malparar",
    "malparásseis": "malparar",
    "malparássemos": "malparar",
    "malparávamo": "malparar",
    "malparávamos": "malparar",
    "malparávei": "malparar",
    "malparáveis": "malparar",
    "malparíamo": "malparir",
    "malparíamos": "malparir",
    "malparíeis": "malparir",
    "malparíramo": "malparir",
    "malparíramos": "malparir",
    "malparíreis": "malparir",
    "malparísseis": "malparir",
    "malparíssemos": "malparir",
    "malpighiáceas": "malpighiácea",
    "malpronta": "malpronto",
    "malprontas": "malpronto",
    "malprontos": "malpronto",
    "malpropícia": "malpropício",
    "malpropícias": "malpropício",
    "malpropícios": "malpropício",
    "malpíghias": "malpíghia",
    "malqueira": "malquerer",
    "malqueirais": "malquerer",
    "malqueiram": "malquerer",
    "malqueiramo": "malquerer",
    "malqueiramos": "malquerer",
    "malqueiras": "malquerer",
    "malquer": "malquerer",
    "malquere": "malquerer",
    "malquerei": "malquerer",
    "malquereis": "malquerer",
    "malquerem": "malquerer",
    "malqueremo": "malquerer",
    "malqueremos": "malquerer",
    "malquerendo": "malquerer",
    "malquerentes": "malquerente",
    "malquerenças": "malquerença",
    "malquererde": "malquerer",
    "malquererdes": "malquerer",
    "malquerere": "malquerer",
    "malquererei": "malquerer",
    "malquerereis": "malquerer",
    "malquererem": "malquerer",
    "malquereremos": "malquerer",
    "malquereres": "malquerer",
    "malquereria": "malquerer",
    "malquereriam": "malquerer",
    "malquererias": "malquerer",
    "malquerermo": "malquerer",
    "malquerermos": "malquerer",
    "malquererá": "malquerer",
    "malquererás": "malquerer",
    "malquererão": "malquerer",
    "malquereríamos": "malquerer",
    "malquereríeis": "malquerer",
    "malqueres": "malquerer",
    "malqueria": "malquerer",
    "malqueriam": "malquerer",
    "malquerias": "malquerer",
    "malquerida": "malquerer",
    "malqueridas": "malquerer",
    "malquerido": "malquerer",
    "malqueridos": "malquerer",
    "malquero": "malquerer",
    "malquerê": "malquerer",
    "malqueríamo": "malquerer",
    "malqueríamos": "malquerer",
    "malqueríei": "malquerer",
    "malqueríeis": "malquerer",
    "malquis": "malquerer",
    "malquisemo": "malquerer",
    "malquisemos": "malquerer",
    "malquiser": "malquerer",
    "malquisera": "malquerer",
    "malquiseram": "malquerer",
    "malquiseras": "malquerer",
    "malquiserdes": "malquerer",
    "malquiserem": "malquerer",
    "malquiseres": "malquerer",
    "malquisermos": "malquerer",
    "malquisesse": "malquerer",
    "malquisessem": "malquerer",
    "malquisesses": "malquerer",
    "malquiseste": "malquerer",
    "malquisestes": "malquerer",
    "malquista": "malquisto",
    "malquistada": "malquistar",
    "malquistadas": "malquistar",
    "malquistado": "malquistar",
    "malquistados": "malquistar",
    "malquistai": "malquistar",
    "malquistais": "malquistar",
    "malquistam": "malquistar",
    "malquistamo": "malquistar",
    "malquistamos": "malquistar",
    "malquistando": "malquistar",
    "malquistara": "malquistar",
    "malquistaram": "malquistar",
    "malquistaras": "malquistar",
    "malquistarde": "malquistar",
    "malquistardes": "malquistar",
    "malquistare": "malquistar",
    "malquistarei": "malquistar",
    "malquistareis": "malquistar",
    "malquistarem": "malquistar",
    "malquistaremos": "malquistar",
    "malquistares": "malquistar",
    "malquistaria": "malquistar",
    "malquistariam": "malquistar",
    "malquistarias": "malquistar",
    "malquistarmo": "malquistar",
    "malquistarmos": "malquistar",
    "malquistará": "malquistar",
    "malquistarás": "malquistar",
    "malquistarão": "malquistar",
    "malquistaríamos": "malquistar",
    "malquistaríeis": "malquistar",
    "malquistas": "malquisto",
    "malquistasse": "malquistar",
    "malquistassem": "malquistar",
    "malquistasses": "malquistar",
    "malquistaste": "malquistar",
    "malquistastes": "malquistar",
    "malquistava": "malquistar",
    "malquistavam": "malquistar",
    "malquistavas": "malquistar",
    "malquiste": "malquistar",
    "malquistei": "malquistar",
    "malquisteis": "malquistar",
    "malquistem": "malquistar",
    "malquistemo": "malquistar",
    "malquistemos": "malquistar",
    "malquistes": "malquistar",
    "malquisto": "malquistar",
    "malquistos": "malquisto",
    "malquistou": "malquistar",
    "malquistá": "malquistar",
    "malquistámo": "malquistar",
    "malquistámos": "malquistar",
    "malquistáramo": "malquistar",
    "malquistáramos": "malquistar",
    "malquistárei": "malquistar",
    "malquistáreis": "malquistar",
    "malquistásseis": "malquistar",
    "malquistássemos": "malquistar",
    "malquistávamo": "malquistar",
    "malquistávamos": "malquistar",
    "malquistávei": "malquistar",
    "malquistáveis": "malquistar",
    "malquiséramo": "malquerer",
    "malquiséramos": "malquerer",
    "malquisérei": "malquerer",
    "malquiséreis": "malquerer",
    "malquisésseis": "malquerer",
    "malquiséssemos": "malquerer",
    "malregida": "malregido",
    "malregidas": "malregido",
    "malregidos": "malregido",
    "malroupida": "malroupido",
    "malroupidas": "malroupido",
    "malroupidos": "malroupido",
    "malsina": "malsinar",
    "malsinada": "malsinar",
    "malsinadas": "malsinar",
    "malsinado": "malsinar",
    "malsinados": "malsinar",
    "malsinai": "malsinar",
    "malsinais": "malsinar",
    "malsinam": "malsinar",
    "malsinamo": "malsinar",
    "malsinamos": "malsinar",
    "malsinando": "malsinar",
    "malsinara": "malsinar",
    "malsinaram": "malsinar",
    "malsinaras": "malsinar",
    "malsinarde": "malsinar",
    "malsinardes": "malsinar",
    "malsinare": "malsinar",
    "malsinarei": "malsinar",
    "malsinareis": "malsinar",
    "malsinarem": "malsinar",
    "malsinaremos": "malsinar",
    "malsinares": "malsinar",
    "malsinaria": "malsinar",
    "malsinariam": "malsinar",
    "malsinarias": "malsinar",
    "malsinarmo": "malsinar",
    "malsinarmos": "malsinar",
    "malsinará": "malsinar",
    "malsinarás": "malsinar",
    "malsinarão": "malsinar",
    "malsinaríamos": "malsinar",
    "malsinaríeis": "malsinar",
    "malsinas": "malsinar",
    "malsinasse": "malsinar",
    "malsinassem": "malsinar",
    "malsinasses": "malsinar",
    "malsinaste": "malsinar",
    "malsinastes": "malsinar",
    "malsinava": "malsinar",
    "malsinavam": "malsinar",
    "malsinavas": "malsinar",
    "malsinações": "malsinação",
    "malsine": "malsinar",
    "malsinei": "malsinar",
    "malsineis": "malsinar",
    "malsinem": "malsinar",
    "malsinemo": "malsinar",
    "malsinemos": "malsinar",
    "malsines": "malsinar",
    "malsino": "malsinar",
    "malsinou": "malsinar",
    "malsins": "malsim",
    "malsiná": "malsinar",
    "malsinámo": "malsinar",
    "malsinámos": "malsinar",
    "malsináramo": "malsinar",
    "malsináramos": "malsinar",
    "malsinárei": "malsinar",
    "malsináreis": "malsinar",
    "malsinásseis": "malsinar",
    "malsinássemos": "malsinar",
    "malsinávamo": "malsinar",
    "malsinávamos": "malsinar",
    "malsinávei": "malsinar",
    "malsináveis": "malsinar",
    "malsofrida": "malsofrido",
    "malsofridas": "malsofrido",
    "malsofridos": "malsofrido",
    "malsona": "malsão",
    "malsonantes": "malsonante",
    "malsonas": "malsão",
    "malsonâncias": "malsonância",
    "malsorteada": "malsorteado",
    "malsorteadas": "malsorteado",
    "malsorteados": "malsorteado",
    "malsões": "malsão",
    "malta": "maltar",
    "maltada": "maltar",
    "maltadas": "maltar",
    "maltado": "maltar",
    "maltados": "maltar",
    "maltagens": "maltagem",
    "maltai": "maltar",
    "maltais": "maltar",
    "maltam": "maltar",
    "maltamo": "maltar",
    "maltamos": "maltar",
    "maltando": "maltar",
    "maltara": "maltar",
    "maltaram": "maltar",
    "maltaras": "maltar",
    "maltarde": "maltar",
    "maltardes": "maltar",
    "maltare": "maltar",
    "maltarei": "maltar",
    "maltareis": "maltar",
    "maltarem": "maltar",
    "maltaremos": "maltar",
    "maltares": "maltar",
    "maltaria": "maltar",
    "maltariam": "maltar",
    "maltarias": "maltar",
    "maltarmo": "maltar",
    "maltarmos": "maltar",
    "maltará": "maltar",
    "maltarás": "maltar",
    "maltarão": "maltar",
    "maltaríamos": "maltar",
    "maltaríeis": "maltar",
    "maltas": "maltar",
    "maltases": "maltase",
    "maltasse": "maltar",
    "maltassem": "maltar",
    "maltasses": "maltar",
    "maltaste": "maltar",
    "maltastes": "maltar",
    "maltava": "maltar",
    "maltavam": "maltar",
    "maltavas": "maltar",
    "malte": "maltar",
    "maltei": "maltar",
    "malteis": "maltar",
    "maltem": "maltar",
    "maltemo": "maltar",
    "maltemos": "maltar",
    "maltes": "malte",
    "maltesa": "maltês",
    "maltesarias": "maltesaria",
    "maltesas": "maltês",
    "malteses": "maltês",
    "maltesias": "maltesia",
    "malthusiana": "malthusiano",
    "malthusianas": "malthusiano",
    "malthusianismos": "malthusianismo",
    "malthusianos": "malthusiano",
    "maltinas": "maltina",
    "malto": "maltar",
    "maltoses": "maltose",
    "maltou": "maltar",
    "maltrapida": "maltrapido",
    "maltrapidas": "maltrapido",
    "maltrapidos": "maltrapido",
    "maltrapilha": "maltrapilho",
    "maltrapilhas": "maltrapilho",
    "maltrapilhos": "maltrapilho",
    "maltrata": "maltratar",
    "maltratada": "maltratar",
    "maltratadas": "maltratar",
    "maltratado": "maltratar",
    "maltratados": "maltratar",
    "maltratai": "maltratar",
    "maltratais": "maltratar",
    "maltratam": "maltratar",
    "maltratamo": "maltratar",
    "maltratamos": "maltratar",
    "maltratando": "maltratar",
    "maltratara": "maltratar",
    "maltrataram": "maltratar",
    "maltrataras": "maltratar",
    "maltratarde": "maltratar",
    "maltratardes": "maltratar",
    "maltratare": "maltratar",
    "maltratarei": "maltratar",
    "maltratareis": "maltratar",
    "maltratarem": "maltratar",
    "maltrataremos": "maltratar",
    "maltratares": "maltratar",
    "maltrataria": "maltratar",
    "maltratariam": "maltratar",
    "maltratarias": "maltratar",
    "maltratarmo": "maltratar",
    "maltratarmos": "maltratar",
    "maltratará": "maltratar",
    "maltratarás": "maltratar",
    "maltratarão": "maltratar",
    "maltrataríamos": "maltratar",
    "maltrataríeis": "maltratar",
    "maltratas": "maltratar",
    "maltratasse": "maltratar",
    "maltratassem": "maltratar",
    "maltratasses": "maltratar",
    "maltrataste": "maltratar",
    "maltratastes": "maltratar",
    "maltratava": "maltratar",
    "maltratavam": "maltratar",
    "maltratavas": "maltratar",
    "maltrate": "maltratar",
    "maltratei": "maltratar",
    "maltrateis": "maltratar",
    "maltratem": "maltratar",
    "maltratemo": "maltratar",
    "maltratemos": "maltratar",
    "maltrates": "maltratar",
    "maltrato": "maltratar",
    "maltratou": "maltratar",
    "maltratá": "maltratar",
    "maltratámo": "maltratar",
    "maltratámos": "maltratar",
    "maltratáramo": "maltratar",
    "maltratáramos": "maltratar",
    "maltratárei": "maltratar",
    "maltratáreis": "maltratar",
    "maltratásseis": "maltratar",
    "maltratássemos": "maltratar",
    "maltratávamo": "maltratar",
    "maltratávamos": "maltratar",
    "maltratávei": "maltratar",
    "maltratáveis": "maltratável",
    "maltreita": "maltreito",
    "maltreitas": "maltreito",
    "maltreitos": "maltreito",
    "maltá": "maltar",
    "maltámo": "maltar",
    "maltámos": "maltar",
    "maltáramo": "maltar",
    "maltáramos": "maltar",
    "maltárei": "maltar",
    "maltáreis": "maltar",
    "maltásseis": "maltar",
    "maltássemos": "maltar",
    "maltávamo": "maltar",
    "maltávamos": "maltar",
    "maltávei": "maltar",
    "maltáveis": "maltar",
    "maluca": "maluco",
    "malucada": "malucar",
    "malucadas": "malucar",
    "malucado": "malucar",
    "malucados": "malucar",
    "malucais": "malucar",
    "malucam": "malucar",
    "malucamo": "malucar",
    "malucamos": "malucar",
    "malucando": "malucar",
    "malucara": "malucar",
    "malucaram": "malucar",
    "malucaras": "malucar",
    "malucardes": "malucar",
    "malucarei": "malucar",
    "malucareis": "malucar",
    "malucarem": "malucar",
    "malucaremos": "malucar",
    "malucares": "malucar",
    "malucaria": "malucar",
    "malucariam": "malucar",
    "malucarias": "malucar",
    "malucarmo": "malucar",
    "malucarmos": "malucar",
    "malucará": "malucar",
    "malucarás": "malucar",
    "malucarão": "malucar",
    "malucaríamos": "malucar",
    "malucaríeis": "malucar",
    "malucas": "maluco",
    "malucasse": "malucar",
    "malucassem": "malucar",
    "malucasses": "malucar",
    "malucaste": "malucar",
    "malucastes": "malucar",
    "malucava": "malucar",
    "malucavam": "malucar",
    "malucavas": "malucar",
    "maluco": "malucar",
    "malucos": "maluco",
    "malucou": "malucar",
    "malucámo": "malucar",
    "malucámos": "malucar",
    "malucáramo": "malucar",
    "malucáramos": "malucar",
    "malucáreis": "malucar",
    "malucásseis": "malucar",
    "malucássemos": "malucar",
    "malucávamo": "malucar",
    "malucávamos": "malucar",
    "malucáveis": "malucar",
    "maluque": "malucar",
    "maluqueada": "maluquear",
    "maluqueadas": "maluquear",
    "maluqueado": "maluquear",
    "maluqueados": "maluquear",
    "maluqueai": "maluquear",
    "maluqueais": "maluquear",
    "maluqueamo": "maluquear",
    "maluqueamos": "maluquear",
    "maluqueando": "maluquear",
    "maluqueara": "maluquear",
    "maluquearam": "maluquear",
    "maluquearas": "maluquear",
    "maluqueardes": "maluquear",
    "maluquearei": "maluquear",
    "maluqueareis": "maluquear",
    "maluquearem": "maluquear",
    "maluquearemos": "maluquear",
    "maluqueares": "maluquear",
    "maluquearia": "maluquear",
    "maluqueariam": "maluquear",
    "maluquearias": "maluquear",
    "maluquearmo": "maluquear",
    "maluquearmos": "maluquear",
    "maluqueará": "maluquear",
    "maluquearás": "maluquear",
    "maluquearão": "maluquear",
    "maluquearíamos": "maluquear",
    "maluquearíeis": "maluquear",
    "maluqueasse": "maluquear",
    "maluqueassem": "maluquear",
    "maluqueasses": "maluquear",
    "maluqueaste": "maluquear",
    "maluqueastes": "maluquear",
    "maluqueava": "maluquear",
    "maluqueavam": "maluquear",
    "maluqueavas": "maluquear",
    "maluqueei": "maluquear",
    "maluqueeis": "maluquear",
    "maluqueemo": "maluquear",
    "maluqueemos": "maluquear",
    "maluquei": "malucar",
    "maluqueia": "maluquear",
    "maluqueiam": "maluquear",
    "maluqueias": "maluquear",
    "maluqueie": "maluquear",
    "maluqueiem": "maluquear",
    "maluqueies": "maluquear",
    "maluqueio": "maluquear",
    "maluqueiras": "maluqueira",
    "maluqueis": "malucar",
    "maluquem": "malucar",
    "maluquemos": "malucar",
    "maluqueou": "maluquear",
    "maluques": "malucar",
    "maluqueámo": "maluquear",
    "maluqueámos": "maluquear",
    "maluqueáramo": "maluquear",
    "maluqueáramos": "maluquear",
    "maluqueáreis": "maluquear",
    "maluqueásseis": "maluquear",
    "maluqueássemos": "maluquear",
    "maluqueávamo": "maluquear",
    "maluqueávamos": "maluquear",
    "maluqueáveis": "maluquear",
    "maluquices": "maluquice",
    "maluquinha": "maluco",
    "maluquinhas": "maluco",
    "maluquinho": "maluco",
    "maluquinhos": "maluco",
    "maluquita": "maluco",
    "maluquitas": "maluco",
    "maluquito": "maluco",
    "maluquitos": "maluco",
    "maluquíssima": "maluco",
    "maluquíssimas": "maluco",
    "maluquíssimo": "maluco",
    "maluquíssimos": "maluco",
    "malvaceiras": "malvaceira",
    "malvada": "malvado",
    "malvadas": "malvado",
    "malvadazinha": "malvado",
    "malvadazinhas": "malvado",
    "malvadazita": "malvado",
    "malvadazitas": "malvado",
    "malvadez": "malvadeza",
    "malvadezas": "malvadeza",
    "malvadinha": "malvado",
    "malvadinhas": "malvado",
    "malvadinho": "malvado",
    "malvadinhos": "malvado",
    "malvadita": "malvado",
    "malvaditas": "malvado",
    "malvadito": "malvado",
    "malvaditos": "malvado",
    "malvadona": "malvado",
    "malvadonas": "malvado",
    "malvados": "malvado",
    "malvadozinho": "malvado",
    "malvadozinhos": "malvado",
    "malvadozito": "malvado",
    "malvadozitos": "malvado",
    "malvadão": "malvado",
    "malvadíssima": "malvado",
    "malvadíssimas": "malvado",
    "malvadíssimo": "malvado",
    "malvadíssimos": "malvado",
    "malvadões": "malvado",
    "malvalistros": "malvalistro",
    "malvares": "malvar",
    "malvas": "malva",
    "malvasias": "malvasia",
    "malvaíscos": "malvaísco",
    "malveiros": "malveiro",
    "malventurosa": "malventuroso",
    "malventurosas": "malventuroso",
    "malventurosos": "malventuroso",
    "malversa": "malversar",
    "malversada": "malversar",
    "malversadas": "malversar",
    "malversado": "malversar",
    "malversadora": "malversador",
    "malversadoras": "malversador",
    "malversadores": "malversador",
    "malversados": "malversar",
    "malversai": "malversar",
    "malversais": "malversar",
    "malversam": "malversar",
    "malversamo": "malversar",
    "malversamos": "malversar",
    "malversando": "malversar",
    "malversara": "malversar",
    "malversaram": "malversar",
    "malversaras": "malversar",
    "malversarde": "malversar",
    "malversardes": "malversar",
    "malversare": "malversar",
    "malversarei": "malversar",
    "malversareis": "malversar",
    "malversarem": "malversar",
    "malversaremos": "malversar",
    "malversares": "malversar",
    "malversaria": "malversar",
    "malversariam": "malversar",
    "malversarias": "malversar",
    "malversarmo": "malversar",
    "malversarmos": "malversar",
    "malversará": "malversar",
    "malversarás": "malversar",
    "malversarão": "malversar",
    "malversaríamos": "malversar",
    "malversaríeis": "malversar",
    "malversas": "malversar",
    "malversasse": "malversar",
    "malversassem": "malversar",
    "malversasses": "malversar",
    "malversaste": "malversar",
    "malversastes": "malversar",
    "malversava": "malversar",
    "malversavam": "malversar",
    "malversavas": "malversar",
    "malversações": "malversação",
    "malverse": "malversar",
    "malversei": "malversar",
    "malverseis": "malversar",
    "malversem": "malversar",
    "malversemo": "malversar",
    "malversemos": "malversar",
    "malverses": "malversar",
    "malverso": "malversar",
    "malversou": "malversar",
    "malversá": "malversar",
    "malversámo": "malversar",
    "malversámos": "malversar",
    "malversáramo": "malversar",
    "malversáramos": "malversar",
    "malversárei": "malversar",
    "malversáreis": "malversar",
    "malversásseis": "malversar",
    "malversássemos": "malversar",
    "malversávamo": "malversar",
    "malversávamos": "malversar",
    "malversávei": "malversar",
    "malversáveis": "malversar",
    "malvises": "malvis",
    "malvista": "malvisto",
    "malvistas": "malvisto",
    "malvistos": "malvisto",
    "malvos": "malvo",
    "malvácea": "malváceo",
    "malváceas": "malváceo",
    "malváceos": "malváceo",
    "malápia": "malápio",
    "malápias": "malápio",
    "malápios": "malápio",
    "malárias": "malária",
    "malárica": "malárico",
    "maláricas": "malárico",
    "maláricos": "malárico",
    "malásia": "malásio",
    "malásias": "malásio",
    "malásios": "malásio",
    "malédica": "malédico",
    "malédicas": "malédico",
    "malédicos": "malédico",
    "maléfica": "maléfico",
    "maléficas": "maléfico",
    "maléficos": "maléfico",
    "maléolos": "maléolo",
    "malévola": "malévolo",
    "malévolas": "malévolo",
    "malévolos": "malévolo",
    "malícias": "malícia",
    "malíssima": "mau",
    "malíssimas": "mau",
    "malíssimo": "mau",
    "malíssimos": "mau",
    "malónica": "malónico",
    "malónicas": "malónico",
    "malónicos": "malónico",
    "malões": "malão",
    "mama": "mamar",
    "mamada": "mamar",
    "mamadas": "mamar",
    "mamadeiras": "mamadeira",
    "mamado": "mamar",
    "mamados": "mamar",
    "mamadouros": "mamadouro",
    "mamaduras": "mamadura",
    "mamai": "mamar",
    "mamais": "mamar",
    "mamalhuda": "mamalhudo",
    "mamalhudas": "mamalhudo",
    "mamalhudos": "mamalhudo",
    "mamalogias": "mamalogia",
    "mamalogistas": "mamalogista",
    "mamalógica": "mamalógico",
    "mamalógicas": "mamalógico",
    "mamalógicos": "mamalógico",
    "mamam": "mamar",
    "mamamo": "mamar",
    "mamamos": "mamar",
    "mamando": "mamar",
    "mamangas": "mamanga",
    "mamara": "mamar",
    "mamaram": "mamar",
    "mamaras": "mamar",
    "mamarde": "mamar",
    "mamardes": "mamar",
    "mamare": "mamar",
    "mamarei": "mamar",
    "mamareis": "mamar",
    "mamarem": "mamar",
    "mamaremos": "mamar",
    "mamares": "mamar",
    "mamaria": "mamar",
    "mamariam": "mamar",
    "mamarias": "mamar",
    "mamarmo": "mamar",
    "mamarmos": "mamar",
    "mamarrachos": "mamarracho",
    "mamará": "mamar",
    "mamarás": "mamar",
    "mamarão": "mamar",
    "mamaríamos": "mamar",
    "mamaríeis": "mamar",
    "mamas": "mamar",
    "mamasse": "mamar",
    "mamassem": "mamar",
    "mamasses": "mamar",
    "mamaste": "mamar",
    "mamastes": "mamar",
    "mamava": "mamar",
    "mamavam": "mamar",
    "mamavas": "mamar",
    "mamaçuda": "mamaçudo",
    "mamaçudas": "mamaçudo",
    "mamaçudos": "mamaçudo",
    "mambares": "mambar",
    "mambos": "mambo",
    "mame": "mamar",
    "mamei": "mamar",
    "mameis": "mamar",
    "mamelada": "mamelado",
    "mameladas": "mamelado",
    "mamelados": "mamelado",
    "mameliformes": "mameliforme",
    "mamelucos": "mameluco",
    "mamelões": "mamelão",
    "mamem": "mamar",
    "mamemo": "mamar",
    "mamemos": "mamar",
    "mames": "mamar",
    "mamiformes": "mamiforme",
    "mamilares": "mamilar",
    "mamilas": "mamila",
    "mamiliformes": "mamiliforme",
    "mamilos": "mamilo",
    "mamilosa": "mamiloso",
    "mamilosas": "mamiloso",
    "mamilosos": "mamiloso",
    "maminha": "mama",
    "maminhas": "mama",
    "mamita": "mama",
    "mamitas": "mama",
    "mamo": "mamar",
    "mamoas": "mamoa",
    "mamocas": "mamoca",
    "mamoeiros": "mamoeiro",
    "mamografias": "mamografia",
    "mamolas": "mamola",
    "mamologias": "mamologia",
    "mamologistas": "mamologista",
    "mamona": "mamão",
    "mamonas": "mamona",
    "mamoneiros": "mamoneiro",
    "mamosa": "mamoso",
    "mamosas": "mamoso",
    "mamosos": "mamoso",
    "mamotas": "mamota",
    "mamou": "mamar",
    "mampostarias": "mampostaria",
    "mampostas": "mamposta",
    "mamposteiros": "mamposteiro",
    "mamuda": "mamudo",
    "mamudas": "mamudo",
    "mamudos": "mamudo",
    "mamuja": "mamujar",
    "mamujada": "mamujar",
    "mamujadas": "mamujar",
    "mamujado": "mamujar",
    "mamujados": "mamujar",
    "mamujai": "mamujar",
    "mamujais": "mamujar",
    "mamujam": "mamujar",
    "mamujamo": "mamujar",
    "mamujamos": "mamujar",
    "mamujando": "mamujar",
    "mamujara": "mamujar",
    "mamujaram": "mamujar",
    "mamujaras": "mamujar",
    "mamujardes": "mamujar",
    "mamujarei": "mamujar",
    "mamujareis": "mamujar",
    "mamujarem": "mamujar",
    "mamujaremos": "mamujar",
    "mamujares": "mamujar",
    "mamujaria": "mamujar",
    "mamujariam": "mamujar",
    "mamujarias": "mamujar",
    "mamujarmo": "mamujar",
    "mamujarmos": "mamujar",
    "mamujará": "mamujar",
    "mamujarás": "mamujar",
    "mamujarão": "mamujar",
    "mamujaríamos": "mamujar",
    "mamujaríeis": "mamujar",
    "mamujas": "mamujar",
    "mamujasse": "mamujar",
    "mamujassem": "mamujar",
    "mamujasses": "mamujar",
    "mamujaste": "mamujar",
    "mamujastes": "mamujar",
    "mamujava": "mamujar",
    "mamujavam": "mamujar",
    "mamujavas": "mamujar",
    "mamuje": "mamujar",
    "mamujei": "mamujar",
    "mamujeis": "mamujar",
    "mamujem": "mamujar",
    "mamujemo": "mamujar",
    "mamujemos": "mamujar",
    "mamujes": "mamujar",
    "mamujo": "mamujar",
    "mamujou": "mamujar",
    "mamujámo": "mamujar",
    "mamujámos": "mamujar",
    "mamujáramo": "mamujar",
    "mamujáramos": "mamujar",
    "mamujáreis": "mamujar",
    "mamujásseis": "mamujar",
    "mamujássemos": "mamujar",
    "mamujávamo": "mamujar",
    "mamujávamos": "mamujar",
    "mamujáveis": "mamujar",
    "mamulengos": "mamulengo",
    "mamunhas": "mamunha",
    "mamutes": "mamute",
    "mamá": "mamar",
    "mamámo": "mamar",
    "mamámos": "mamar",
    "mamáramo": "mamar",
    "mamáramos": "mamar",
    "mamárei": "mamar",
    "mamáreis": "mamar",
    "mamária": "mamário",
    "mamárias": "mamário",
    "mamários": "mamário",
    "mamásseis": "mamar",
    "mamássemos": "mamar",
    "mamávamo": "mamar",
    "mamávamos": "mamar",
    "mamávei": "mamar",
    "mamáveis": "mamar",
    "mamãs": "mamã",
    "mamífera": "mamífero",
    "mamíferas": "mamífero",
    "mamíferos": "mamífero",
    "mamões": "mamão",
    "mana": "mano",
    "manada": "manar",
    "manadas": "manar",
    "manadeiras": "manadeira",
    "manadeiros": "manadeiro",
    "manadia": "manadio",
    "manadias": "manadio",
    "manadios": "manadio",
    "manado": "manar",
    "manados": "manar",
    "managers": "manager",
    "manai": "manar",
    "manais": "manir",
    "manajeira": "manajeiro",
    "manajeiras": "manajeiro",
    "manajeiros": "manajeiro",
    "manalva": "manalvo",
    "manalvas": "manalvo",
    "manalvos": "manalvo",
    "manam": "manir",
    "manamo": "manir",
    "manamos": "manir",
    "mananas": "manana",
    "mananciais": "manancial",
    "manando": "manar",
    "manantes": "manante",
    "manantéus": "manantéu",
    "manaquins": "manaquim",
    "manara": "manar",
    "manaram": "manar",
    "manaras": "manar",
    "manarde": "manar",
    "manardes": "manar",
    "manare": "manar",
    "manarei": "manar",
    "manareis": "manar",
    "manarem": "manar",
    "manaremos": "manar",
    "manares": "manar",
    "manaria": "manar",
    "manariam": "manar",
    "manarias": "manar",
    "manarmo": "manar",
    "manarmos": "manar",
    "manará": "manar",
    "manarás": "manar",
    "manarão": "manar",
    "manaríamos": "manar",
    "manaríeis": "manar",
    "manas": "mano",
    "manasse": "manar",
    "manassem": "manar",
    "manasses": "manar",
    "manaste": "manar",
    "manastes": "manar",
    "manatas": "manata",
    "manatos": "manato",
    "manava": "manar",
    "manavam": "manar",
    "manavas": "manar",
    "manazinha": "mano",
    "manazinhas": "mano",
    "manazita": "mano",
    "manazitas": "mano",
    "manca": "manco",
    "mancada": "mancar",
    "mancadas": "mancar",
    "mancado": "mancar",
    "mancados": "mancar",
    "mancai": "mancar",
    "mancais": "mancar",
    "mancam": "mancar",
    "mancamo": "mancar",
    "mancamos": "mancar",
    "mancando": "mancar",
    "mancara": "mancar",
    "mancaram": "mancar",
    "mancaras": "mancar",
    "mancarde": "mancar",
    "mancardes": "mancar",
    "mancare": "mancar",
    "mancarei": "mancar",
    "mancareis": "mancar",
    "mancarem": "mancar",
    "mancaremos": "mancar",
    "mancares": "mancar",
    "mancaria": "mancar",
    "mancariam": "mancar",
    "mancarias": "mancar",
    "mancarmo": "mancar",
    "mancarmos": "mancar",
    "mancarras": "mancarra",
    "mancará": "mancar",
    "mancarás": "mancar",
    "mancarão": "mancar",
    "mancaríamos": "mancar",
    "mancaríeis": "mancar",
    "mancas": "manco",
    "mancasse": "mancar",
    "mancassem": "mancar",
    "mancasses": "mancar",
    "mancaste": "mancar",
    "mancastes": "mancar",
    "mancava": "mancar",
    "mancavam": "mancar",
    "mancavas": "mancar",
    "manceba": "mancebo",
    "mancebas": "mancebo",
    "mancebias": "mancebia",
    "mancebis": "mancebil",
    "mancebos": "mancebo",
    "mancenilhas": "mancenilha",
    "mancenilheiras": "mancenilheira",
    "mancha": "manchar",
    "manchada": "manchar",
    "manchadas": "manchar",
    "manchado": "manchar",
    "manchados": "manchar",
    "manchadíssima": "manchado",
    "manchadíssimas": "manchado",
    "manchadíssimo": "manchado",
    "manchadíssimos": "manchado",
    "manchai": "manchar",
    "manchais": "manchar",
    "mancham": "manchar",
    "manchamo": "manchar",
    "manchamos": "manchar",
    "manchando": "manchar",
    "manchara": "manchar",
    "mancharam": "manchar",
    "mancharas": "manchar",
    "mancharde": "manchar",
    "manchardes": "manchar",
    "manchare": "manchar",
    "mancharei": "manchar",
    "manchareis": "manchar",
    "mancharem": "manchar",
    "mancharemos": "manchar",
    "manchares": "manchar",
    "mancharia": "manchar",
    "manchariam": "manchar",
    "mancharias": "manchar",
    "mancharmo": "manchar",
    "mancharmos": "manchar",
    "manchará": "manchar",
    "mancharás": "manchar",
    "mancharão": "manchar",
    "mancharíamos": "manchar",
    "mancharíeis": "manchar",
    "manchas": "manchar",
    "manchasse": "manchar",
    "manchassem": "manchar",
    "manchasses": "manchar",
    "manchaste": "manchar",
    "manchastes": "manchar",
    "manchava": "manchar",
    "manchavam": "manchar",
    "manchavas": "manchar",
    "manche": "manchar",
    "manchega": "manchego",
    "manchegas": "manchego",
    "manchegos": "manchego",
    "manchei": "manchar",
    "mancheias": "mancheia",
    "mancheis": "manchar",
    "manchem": "manchar",
    "manchemo": "manchar",
    "manchemos": "manchar",
    "manches": "manchar",
    "manchesteriana": "manchesteriano",
    "manchesterianas": "manchesteriano",
    "manchesterianos": "manchesteriano",
    "manchetes": "manchete",
    "manchinha": "mancha",
    "manchinhas": "manchinha",
    "manchis": "manchil",
    "manchita": "mancha",
    "manchitas": "mancha",
    "mancho": "manchar",
    "manchocos": "manchoco",
    "manchoqueiras": "manchoqueira",
    "manchoquinhas": "manchoquinha",
    "manchou": "manchar",
    "manchus": "manchu",
    "manchá": "manchar",
    "manchámo": "manchar",
    "manchámos": "manchar",
    "mancháramo": "manchar",
    "mancháramos": "manchar",
    "manchárei": "manchar",
    "mancháreis": "manchar",
    "manchásseis": "manchar",
    "manchássemos": "manchar",
    "manchávamo": "manchar",
    "manchávamos": "manchar",
    "manchávei": "manchar",
    "mancháveis": "manchável",
    "manchões": "manchão",
    "mancinelas": "mancinela",
    "mancinismos": "mancinismo",
    "mancipa": "mancipar",
    "mancipada": "mancipar",
    "mancipadas": "mancipar",
    "mancipado": "mancipar",
    "mancipados": "mancipar",
    "mancipai": "mancipar",
    "mancipais": "mancipar",
    "mancipam": "mancipar",
    "mancipamo": "mancipar",
    "mancipamos": "mancipar",
    "mancipando": "mancipar",
    "mancipara": "mancipar",
    "manciparam": "mancipar",
    "manciparas": "mancipar",
    "manciparde": "mancipar",
    "mancipardes": "mancipar",
    "mancipare": "mancipar",
    "manciparei": "mancipar",
    "mancipareis": "mancipar",
    "manciparem": "mancipar",
    "manciparemos": "mancipar",
    "mancipares": "mancipar",
    "manciparia": "mancipar",
    "mancipariam": "mancipar",
    "manciparias": "mancipar",
    "manciparmo": "mancipar",
    "manciparmos": "mancipar",
    "mancipará": "mancipar",
    "manciparás": "mancipar",
    "manciparão": "mancipar",
    "manciparíamos": "mancipar",
    "manciparíeis": "mancipar",
    "mancipas": "mancipar",
    "mancipasse": "mancipar",
    "mancipassem": "mancipar",
    "mancipasses": "mancipar",
    "mancipaste": "mancipar",
    "mancipastes": "mancipar",
    "mancipava": "mancipar",
    "mancipavam": "mancipar",
    "mancipavas": "mancipar",
    "mancipações": "mancipação",
    "mancipe": "mancipar",
    "mancipei": "mancipar",
    "mancipeis": "mancipar",
    "mancipem": "mancipar",
    "mancipemo": "mancipar",
    "mancipemos": "mancipar",
    "mancipes": "mancipar",
    "mancipo": "mancipar",
    "mancipou": "mancipar",
    "mancipá": "mancipar",
    "mancipámo": "mancipar",
    "mancipámos": "mancipar",
    "mancipáramo": "mancipar",
    "mancipáramos": "mancipar",
    "mancipárei": "mancipar",
    "mancipáreis": "mancipar",
    "mancipásseis": "mancipar",
    "mancipássemos": "mancipar",
    "mancipávamo": "mancipar",
    "mancipávamos": "mancipar",
    "mancipávei": "mancipar",
    "mancipáveis": "mancipável",
    "manco": "mancar",
    "mancomuna": "mancomunar",
    "mancomunada": "mancomunar",
    "mancomunadas": "mancomunar",
    "mancomunado": "mancomunar",
    "mancomunados": "mancomunar",
    "mancomunai": "mancomunar",
    "mancomunais": "mancomunar",
    "mancomunam": "mancomunar",
    "mancomunamo": "mancomunar",
    "mancomunamos": "mancomunar",
    "mancomunando": "mancomunar",
    "mancomunara": "mancomunar",
    "mancomunaram": "mancomunar",
    "mancomunaras": "mancomunar",
    "mancomunarde": "mancomunar",
    "mancomunardes": "mancomunar",
    "mancomunare": "mancomunar",
    "mancomunarei": "mancomunar",
    "mancomunareis": "mancomunar",
    "mancomunarem": "mancomunar",
    "mancomunaremos": "mancomunar",
    "mancomunares": "mancomunar",
    "mancomunaria": "mancomunar",
    "mancomunariam": "mancomunar",
    "mancomunarias": "mancomunar",
    "mancomunarmo": "mancomunar",
    "mancomunarmos": "mancomunar",
    "mancomunará": "mancomunar",
    "mancomunarás": "mancomunar",
    "mancomunarão": "mancomunar",
    "mancomunaríamos": "mancomunar",
    "mancomunaríeis": "mancomunar",
    "mancomunas": "mancomunar",
    "mancomunasse": "mancomunar",
    "mancomunassem": "mancomunar",
    "mancomunasses": "mancomunar",
    "mancomunaste": "mancomunar",
    "mancomunastes": "mancomunar",
    "mancomunava": "mancomunar",
    "mancomunavam": "mancomunar",
    "mancomunavas": "mancomunar",
    "mancomunações": "mancomunação",
    "mancomune": "mancomunar",
    "mancomunei": "mancomunar",
    "mancomuneis": "mancomunar",
    "mancomunem": "mancomunar",
    "mancomunemo": "mancomunar",
    "mancomunemos": "mancomunar",
    "mancomunes": "mancomunar",
    "mancomuno": "mancomunar",
    "mancomunou": "mancomunar",
    "mancomuná": "mancomunar",
    "mancomunámo": "mancomunar",
    "mancomunámos": "mancomunar",
    "mancomunáramo": "mancomunar",
    "mancomunáramos": "mancomunar",
    "mancomunárei": "mancomunar",
    "mancomunáreis": "mancomunar",
    "mancomunásseis": "mancomunar",
    "mancomunássemos": "mancomunar",
    "mancomunávamo": "mancomunar",
    "mancomunávamos": "mancomunar",
    "mancomunávei": "mancomunar",
    "mancomunáveis": "mancomunar",
    "mancorna": "mancornar",
    "mancornada": "mancornar",
    "mancornadas": "mancornar",
    "mancornado": "mancornar",
    "mancornados": "mancornar",
    "mancornai": "mancornar",
    "mancornais": "mancornar",
    "mancornam": "mancornar",
    "mancornamo": "mancornar",
    "mancornamos": "mancornar",
    "mancornando": "mancornar",
    "mancornara": "mancornar",
    "mancornaram": "mancornar",
    "mancornaras": "mancornar",
    "mancornarde": "mancornar",
    "mancornardes": "mancornar",
    "mancornare": "mancornar",
    "mancornarei": "mancornar",
    "mancornareis": "mancornar",
    "mancornarem": "mancornar",
    "mancornaremos": "mancornar",
    "mancornares": "mancornar",
    "mancornaria": "mancornar",
    "mancornariam": "mancornar",
    "mancornarias": "mancornar",
    "mancornarmo": "mancornar",
    "mancornarmos": "mancornar",
    "mancornará": "mancornar",
    "mancornarás": "mancornar",
    "mancornarão": "mancornar",
    "mancornaríamos": "mancornar",
    "mancornaríeis": "mancornar",
    "mancornas": "mancornar",
    "mancornasse": "mancornar",
    "mancornassem": "mancornar",
    "mancornasses": "mancornar",
    "mancornaste": "mancornar",
    "mancornastes": "mancornar",
    "mancornava": "mancornar",
    "mancornavam": "mancornar",
    "mancornavas": "mancornar",
    "mancorne": "mancornar",
    "mancornei": "mancornar",
    "mancorneis": "mancornar",
    "mancornem": "mancornar",
    "mancornemo": "mancornar",
    "mancornemos": "mancornar",
    "mancornes": "mancornar",
    "mancorno": "mancornar",
    "mancornou": "mancornar",
    "mancorná": "mancornar",
    "mancornámo": "mancornar",
    "mancornámos": "mancornar",
    "mancornáramo": "mancornar",
    "mancornáramos": "mancornar",
    "mancornárei": "mancornar",
    "mancornáreis": "mancornar",
    "mancornásseis": "mancornar",
    "mancornássemos": "mancornar",
    "mancornávamo": "mancornar",
    "mancornávamos": "mancornar",
    "mancornávei": "mancornar",
    "mancornáveis": "mancornar",
    "mancos": "manco",
    "mancou": "mancar",
    "mancá": "mancar",
    "mancámo": "mancar",
    "mancámos": "mancar",
    "mancáramo": "mancar",
    "mancáramos": "mancar",
    "mancárei": "mancar",
    "mancáreis": "mancar",
    "mancásseis": "mancar",
    "mancássemos": "mancar",
    "mancávamo": "mancar",
    "mancávamos": "mancar",
    "mancávei": "mancar",
    "mancáveis": "mancar",
    "mancípia": "mancípio",
    "mancípias": "mancípio",
    "mancípios": "mancípio",
    "mancões": "mancão",
    "manda": "mandar",
    "mandachuvas": "mandachuva",
    "mandada": "mandar",
    "mandadas": "mandar",
    "mandadeira": "mandadeiro",
    "mandadeiras": "mandadeiro",
    "mandadeiros": "mandadeiro",
    "mandado": "mandar",
    "mandadora": "mandador",
    "mandadoras": "mandador",
    "mandadores": "mandador",
    "mandados": "mandar",
    "mandai": "mandar",
    "mandais": "mandar",
    "mandam": "mandar",
    "mandamentos": "mandamento",
    "mandamo": "mandar",
    "mandamos": "mandar",
    "mandando": "mandar",
    "mandantes": "mandante",
    "mandaques": "mandaque",
    "mandara": "mandar",
    "mandaram": "mandar",
    "mandaras": "mandar",
    "mandarde": "mandar",
    "mandardes": "mandar",
    "mandare": "mandar",
    "mandarei": "mandar",
    "mandareis": "mandar",
    "mandarem": "mandar",
    "mandaremos": "mandar",
    "mandares": "mandar",
    "mandaretes": "mandarete",
    "mandaria": "mandar",
    "mandariam": "mandar",
    "mandarias": "mandar",
    "mandarina": "mandarim",
    "mandarinas": "mandarim",
    "mandarinatos": "mandarinato",
    "mandarinetes": "mandarinete",
    "mandarinismos": "mandarinismo",
    "mandarins": "mandarim",
    "mandaris": "mandari",
    "mandarmo": "mandar",
    "mandarmos": "mandar",
    "mandará": "mandar",
    "mandarás": "mandar",
    "mandarão": "mandar",
    "mandaríamos": "mandar",
    "mandaríeis": "mandar",
    "mandarínica": "mandarínico",
    "mandarínicas": "mandarínico",
    "mandarínicos": "mandarínico",
    "mandas": "mandar",
    "mandasse": "mandar",
    "mandassem": "mandar",
    "mandasses": "mandar",
    "mandaste": "mandar",
    "mandastes": "mandar",
    "mandata": "mandatar",
    "mandatada": "mandatar",
    "mandatadas": "mandatar",
    "mandatado": "mandatar",
    "mandatados": "mandatar",
    "mandatai": "mandatar",
    "mandatais": "mandatar",
    "mandatam": "mandatar",
    "mandatamo": "mandatar",
    "mandatamos": "mandatar",
    "mandatando": "mandatar",
    "mandatara": "mandatar",
    "mandataram": "mandatar",
    "mandataras": "mandatar",
    "mandatarde": "mandatar",
    "mandatardes": "mandatar",
    "mandatare": "mandatar",
    "mandatarei": "mandatar",
    "mandatareis": "mandatar",
    "mandatarem": "mandatar",
    "mandataremos": "mandatar",
    "mandatares": "mandatar",
    "mandataria": "mandatar",
    "mandatariam": "mandatar",
    "mandatarias": "mandatar",
    "mandatarmo": "mandatar",
    "mandatarmos": "mandatar",
    "mandatará": "mandatar",
    "mandatarás": "mandatar",
    "mandatarão": "mandatar",
    "mandataríamos": "mandatar",
    "mandataríeis": "mandatar",
    "mandatas": "mandatar",
    "mandatasse": "mandatar",
    "mandatassem": "mandatar",
    "mandatasses": "mandatar",
    "mandataste": "mandatar",
    "mandatastes": "mandatar",
    "mandatava": "mandatar",
    "mandatavam": "mandatar",
    "mandatavas": "mandatar",
    "mandate": "mandatar",
    "mandatei": "mandatar",
    "mandateis": "mandatar",
    "mandatem": "mandatar",
    "mandatemo": "mandatar",
    "mandatemos": "mandatar",
    "mandates": "mandatar",
    "mandato": "mandatar",
    "mandatos": "mandato",
    "mandatou": "mandatar",
    "mandatá": "mandatar",
    "mandatámo": "mandatar",
    "mandatámos": "mandatar",
    "mandatáramo": "mandatar",
    "mandatáramos": "mandatar",
    "mandatárei": "mandatar",
    "mandatáreis": "mandatar",
    "mandatária": "mandatário",
    "mandatárias": "mandatário",
    "mandatários": "mandatário",
    "mandatásseis": "mandatar",
    "mandatássemos": "mandatar",
    "mandatávamo": "mandatar",
    "mandatávamos": "mandatar",
    "mandatávei": "mandatar",
    "mandatáveis": "mandatar",
    "mandava": "mandar",
    "mandavam": "mandar",
    "mandavas": "mandar",
    "mande": "mandar",
    "mandei": "mandar",
    "mandeis": "mandar",
    "mandem": "mandar",
    "mandemo": "mandar",
    "mandemos": "mandar",
    "mandes": "mandar",
    "mandibas": "mandiba",
    "mandibula": "mandibular",
    "mandibulada": "mandibular",
    "mandibuladas": "mandibular",
    "mandibulado": "mandibular",
    "mandibulados": "mandibular",
    "mandibulai": "mandibular",
    "mandibulais": "mandibular",
    "mandibulam": "mandibular",
    "mandibulamo": "mandibular",
    "mandibulamos": "mandibular",
    "mandibulando": "mandibular",
    "mandibulara": "mandibular",
    "mandibularam": "mandibular",
    "mandibularas": "mandibular",
    "mandibularde": "mandibular",
    "mandibulardes": "mandibular",
    "mandibulare": "mandibular",
    "mandibularei": "mandibular",
    "mandibulareis": "mandibular",
    "mandibularem": "mandibular",
    "mandibularemos": "mandibular",
    "mandibulares": "mandibular",
    "mandibularia": "mandibular",
    "mandibulariam": "mandibular",
    "mandibularias": "mandibular",
    "mandibularmo": "mandibular",
    "mandibularmos": "mandibular",
    "mandibulará": "mandibular",
    "mandibularás": "mandibular",
    "mandibularão": "mandibular",
    "mandibularíamos": "mandibular",
    "mandibularíeis": "mandibular",
    "mandibulas": "mandibular",
    "mandibulasse": "mandibular",
    "mandibulassem": "mandibular",
    "mandibulasses": "mandibular",
    "mandibulaste": "mandibular",
    "mandibulastes": "mandibular",
    "mandibulava": "mandibular",
    "mandibulavam": "mandibular",
    "mandibulavas": "mandibular",
    "mandibulações": "mandibulação",
    "mandibule": "mandibular",
    "mandibulei": "mandibular",
    "mandibuleis": "mandibular",
    "mandibulem": "mandibular",
    "mandibulemo": "mandibular",
    "mandibulemos": "mandibular",
    "mandibules": "mandibular",
    "mandibuliformes": "mandibuliforme",
    "mandibulo": "mandibular",
    "mandibulou": "mandibular",
    "mandibulá": "mandibular",
    "mandibulámo": "mandibular",
    "mandibulámos": "mandibular",
    "mandibuláramo": "mandibular",
    "mandibuláramos": "mandibular",
    "mandibulárei": "mandibular",
    "mandibuláreis": "mandibular",
    "mandibulásseis": "mandibular",
    "mandibulássemos": "mandibular",
    "mandibulávamo": "mandibular",
    "mandibulávamos": "mandibular",
    "mandibulávei": "mandibular",
    "mandibuláveis": "mandibular",
    "mandinga": "mandingar",
    "mandingada": "mandingar",
    "mandingadas": "mandingar",
    "mandingado": "mandingar",
    "mandingados": "mandingar",
    "mandingai": "mandingar",
    "mandingais": "mandingar",
    "mandingam": "mandingar",
    "mandingamo": "mandingar",
    "mandingamos": "mandingar",
    "mandingando": "mandingar",
    "mandingara": "mandingar",
    "mandingaram": "mandingar",
    "mandingaras": "mandingar",
    "mandingarde": "mandingar",
    "mandingardes": "mandingar",
    "mandingare": "mandingar",
    "mandingarei": "mandingar",
    "mandingareis": "mandingar",
    "mandingarem": "mandingar",
    "mandingaremos": "mandingar",
    "mandingares": "mandingar",
    "mandingaria": "mandingar",
    "mandingariam": "mandingar",
    "mandingarias": "mandingar",
    "mandingarmo": "mandingar",
    "mandingarmos": "mandingar",
    "mandingará": "mandingar",
    "mandingarás": "mandingar",
    "mandingarão": "mandingar",
    "mandingaríamos": "mandingar",
    "mandingaríeis": "mandingar",
    "mandingas": "mandingar",
    "mandingasse": "mandingar",
    "mandingassem": "mandingar",
    "mandingasses": "mandingar",
    "mandingaste": "mandingar",
    "mandingastes": "mandingar",
    "mandingava": "mandingar",
    "mandingavam": "mandingar",
    "mandingavas": "mandingar",
    "mandingo": "mandingar",
    "mandingou": "mandingar",
    "mandingue": "mandingar",
    "mandinguei": "mandingar",
    "mandingueira": "mandingueiro",
    "mandingueiras": "mandingueiro",
    "mandingueiros": "mandingueiro",
    "mandingueis": "mandingar",
    "mandinguem": "mandingar",
    "mandinguemo": "mandingar",
    "mandinguemos": "mandingar",
    "mandingues": "mandingar",
    "mandingá": "mandingar",
    "mandingámo": "mandingar",
    "mandingámos": "mandingar",
    "mandingáramo": "mandingar",
    "mandingáramos": "mandingar",
    "mandingárei": "mandingar",
    "mandingáreis": "mandingar",
    "mandingásseis": "mandingar",
    "mandingássemos": "mandingar",
    "mandingávamo": "mandingar",
    "mandingávamos": "mandingar",
    "mandingávei": "mandingar",
    "mandingáveis": "mandingar",
    "mandiocabas": "mandiocaba",
    "mandiocais": "mandiocal",
    "mandiocas": "mandioca",
    "mandis": "mandil",
    "mandivas": "mandiva",
    "mando": "mandar",
    "mandolas": "mandola",
    "mandolinas": "mandolina",
    "mandolinatas": "mandolinata",
    "mandolinetes": "mandolinete",
    "mandolins": "mandolim",
    "mandona": "mandão",
    "mandonas": "mandão",
    "mandonguices": "mandonguice",
    "mandoras": "mandora",
    "mandos": "mando",
    "mandou": "mandar",
    "mandovins": "mandovim",
    "mandovis": "mandovi",
    "mandranas": "mandrana",
    "mandranices": "mandranice",
    "mandria": "mandriar",
    "mandriada": "mandriar",
    "mandriadas": "mandriar",
    "mandriado": "mandriar",
    "mandriados": "mandriar",
    "mandriai": "mandriar",
    "mandriais": "mandriar",
    "mandriam": "mandriar",
    "mandriamo": "mandriar",
    "mandriamos": "mandriar",
    "mandriana": "mandrianar",
    "mandrianada": "mandrianar",
    "mandrianadas": "mandrianar",
    "mandrianado": "mandrianar",
    "mandrianados": "mandrianar",
    "mandrianai": "mandrianar",
    "mandrianais": "mandrianar",
    "mandrianam": "mandrianar",
    "mandrianamo": "mandrianar",
    "mandrianamos": "mandrianar",
    "mandrianando": "mandrianar",
    "mandrianara": "mandrianar",
    "mandrianaram": "mandrianar",
    "mandrianaras": "mandrianar",
    "mandrianardes": "mandrianar",
    "mandrianarei": "mandrianar",
    "mandrianareis": "mandrianar",
    "mandrianarem": "mandrianar",
    "mandrianaremos": "mandrianar",
    "mandrianares": "mandrianar",
    "mandrianaria": "mandrianar",
    "mandrianariam": "mandrianar",
    "mandrianarias": "mandrianar",
    "mandrianarmo": "mandrianar",
    "mandrianarmos": "mandrianar",
    "mandrianará": "mandrianar",
    "mandrianarás": "mandrianar",
    "mandrianarão": "mandrianar",
    "mandrianaríamos": "mandrianar",
    "mandrianaríeis": "mandrianar",
    "mandrianas": "mandrianar",
    "mandrianasse": "mandrianar",
    "mandrianassem": "mandrianar",
    "mandrianasses": "mandrianar",
    "mandrianaste": "mandrianar",
    "mandrianastes": "mandrianar",
    "mandrianava": "mandrianar",
    "mandrianavam": "mandrianar",
    "mandrianavas": "mandrianar",
    "mandriando": "mandriar",
    "mandriane": "mandrianar",
    "mandrianei": "mandrianar",
    "mandrianeis": "mandrianar",
    "mandrianem": "mandrianar",
    "mandrianemo": "mandrianar",
    "mandrianemos": "mandrianar",
    "mandrianes": "mandrianar",
    "mandriano": "mandrianar",
    "mandrianou": "mandrianar",
    "mandrianámo": "mandrianar",
    "mandrianámos": "mandrianar",
    "mandrianáramo": "mandrianar",
    "mandrianáramos": "mandrianar",
    "mandrianáreis": "mandrianar",
    "mandrianásseis": "mandrianar",
    "mandrianássemos": "mandrianar",
    "mandrianávamo": "mandrianar",
    "mandrianávamos": "mandrianar",
    "mandrianáveis": "mandrianar",
    "mandriara": "mandriar",
    "mandriaram": "mandriar",
    "mandriaras": "mandriar",
    "mandriardes": "mandriar",
    "mandriarei": "mandriar",
    "mandriareis": "mandriar",
    "mandriarem": "mandriar",
    "mandriaremos": "mandriar",
    "mandriares": "mandriar",
    "mandriaria": "mandriar",
    "mandriariam": "mandriar",
    "mandriarias": "mandriar",
    "mandriarmo": "mandriar",
    "mandriarmos": "mandriar",
    "mandriará": "mandriar",
    "mandriarás": "mandriar",
    "mandriarão": "mandriar",
    "mandriaríamos": "mandriar",
    "mandriaríeis": "mandriar",
    "mandrias": "mandriar",
    "mandriasse": "mandriar",
    "mandriassem": "mandriar",
    "mandriasses": "mandriar",
    "mandriaste": "mandriar",
    "mandriastes": "mandriar",
    "mandriava": "mandriar",
    "mandriavam": "mandriar",
    "mandriavas": "mandriar",
    "mandrie": "mandriar",
    "mandriei": "mandriar",
    "mandrieis": "mandriar",
    "mandriem": "mandriar",
    "mandriemo": "mandriar",
    "mandriemos": "mandriar",
    "mandries": "mandriar",
    "mandriices": "mandriice",
    "mandrila": "mandrilar",
    "mandrilada": "mandrilar",
    "mandriladas": "mandrilar",
    "mandrilado": "mandrilar",
    "mandrilados": "mandrilar",
    "mandrilagens": "mandrilagem",
    "mandrilai": "mandrilar",
    "mandrilais": "mandrilar",
    "mandrilam": "mandrilar",
    "mandrilamo": "mandrilar",
    "mandrilamos": "mandrilar",
    "mandrilando": "mandrilar",
    "mandrilara": "mandrilar",
    "mandrilaram": "mandrilar",
    "mandrilaras": "mandrilar",
    "mandrilarde": "mandrilar",
    "mandrilardes": "mandrilar",
    "mandrilare": "mandrilar",
    "mandrilarei": "mandrilar",
    "mandrilareis": "mandrilar",
    "mandrilarem": "mandrilar",
    "mandrilaremos": "mandrilar",
    "mandrilares": "mandrilar",
    "mandrilaria": "mandrilar",
    "mandrilariam": "mandrilar",
    "mandrilarias": "mandrilar",
    "mandrilarmo": "mandrilar",
    "mandrilarmos": "mandrilar",
    "mandrilará": "mandrilar",
    "mandrilarás": "mandrilar",
    "mandrilarão": "mandrilar",
    "mandrilaríamos": "mandrilar",
    "mandrilaríeis": "mandrilar",
    "mandrilas": "mandrilar",
    "mandrilasse": "mandrilar",
    "mandrilassem": "mandrilar",
    "mandrilasses": "mandrilar",
    "mandrilaste": "mandrilar",
    "mandrilastes": "mandrilar",
    "mandrilava": "mandrilar",
    "mandrilavam": "mandrilar",
    "mandrilavas": "mandrilar",
    "mandrile": "mandrilar",
    "mandrilei": "mandrilar",
    "mandrileis": "mandrilar",
    "mandrilem": "mandrilar",
    "mandrilemo": "mandrilar",
    "mandrilemos": "mandrilar",
    "mandriles": "mandrilar",
    "mandrilo": "mandrilar",
    "mandrilou": "mandrilar",
    "mandrilá": "mandrilar",
    "mandrilámo": "mandrilar",
    "mandrilámos": "mandrilar",
    "mandriláramo": "mandrilar",
    "mandriláramos": "mandrilar",
    "mandrilárei": "mandrilar",
    "mandriláreis": "mandrilar",
    "mandrilásseis": "mandrilar",
    "mandrilássemos": "mandrilar",
    "mandrilávamo": "mandrilar",
    "mandrilávamos": "mandrilar",
    "mandrilávei": "mandrilar",
    "mandriláveis": "mandrilar",
    "mandrio": "mandriar",
    "mandriona": "mandrionar",
    "mandrionada": "mandrionar",
    "mandrionadas": "mandrionar",
    "mandrionado": "mandrionar",
    "mandrionados": "mandrionar",
    "mandrionai": "mandrionar",
    "mandrionais": "mandrionar",
    "mandrionam": "mandrionar",
    "mandrionamo": "mandrionar",
    "mandrionamos": "mandrionar",
    "mandrionando": "mandrionar",
    "mandrionara": "mandrionar",
    "mandrionaram": "mandrionar",
    "mandrionaras": "mandrionar",
    "mandrionardes": "mandrionar",
    "mandrionarei": "mandrionar",
    "mandrionareis": "mandrionar",
    "mandrionarem": "mandrionar",
    "mandrionaremos": "mandrionar",
    "mandrionares": "mandrionar",
    "mandrionaria": "mandrionar",
    "mandrionariam": "mandrionar",
    "mandrionarias": "mandrionar",
    "mandrionarmo": "mandrionar",
    "mandrionarmos": "mandrionar",
    "mandrionará": "mandrionar",
    "mandrionarás": "mandrionar",
    "mandrionarão": "mandrionar",
    "mandrionaríamos": "mandrionar",
    "mandrionaríeis": "mandrionar",
    "mandrionas": "mandrionar",
    "mandrionasse": "mandrionar",
    "mandrionassem": "mandrionar",
    "mandrionasses": "mandrionar",
    "mandrionaste": "mandrionar",
    "mandrionastes": "mandrionar",
    "mandrionava": "mandrionar",
    "mandrionavam": "mandrionar",
    "mandrionavas": "mandrionar",
    "mandrione": "mandrionar",
    "mandrionei": "mandrionar",
    "mandrioneis": "mandrionar",
    "mandrionem": "mandrionar",
    "mandrionemo": "mandrionar",
    "mandrionemos": "mandrionar",
    "mandriones": "mandrionar",
    "mandriono": "mandrionar",
    "mandrionou": "mandrionar",
    "mandrionámo": "mandrionar",
    "mandrionámos": "mandrionar",
    "mandrionáramo": "mandrionar",
    "mandrionáramos": "mandrionar",
    "mandrionáreis": "mandrionar",
    "mandrionásseis": "mandrionar",
    "mandrionássemos": "mandrionar",
    "mandrionávamo": "mandrionar",
    "mandrionávamos": "mandrionar",
    "mandrionáveis": "mandrionar",
    "mandriou": "mandriar",
    "mandris": "mandril",
    "mandriámo": "mandriar",
    "mandriámos": "mandriar",
    "mandriáramo": "mandriar",
    "mandriáramos": "mandriar",
    "mandriáreis": "mandriar",
    "mandriásseis": "mandriar",
    "mandriássemos": "mandriar",
    "mandriávamo": "mandriar",
    "mandriávamos": "mandriar",
    "mandriáveis": "mandriar",
    "mandriões": "mandrião",
    "mandrongas": "mandronga",
    "mandronguices": "mandronguice",
    "mandrágoras": "mandrágora",
    "mandubas": "manduba",
    "mandubis": "mandubi",
    "manduca": "manducar",
    "manducada": "manducar",
    "manducadas": "manducar",
    "manducado": "manducar",
    "manducados": "manducar",
    "manducai": "manducar",
    "manducais": "manducar",
    "manducam": "manducar",
    "manducamo": "manducar",
    "manducamos": "manducar",
    "manducando": "manducar",
    "manducara": "manducar",
    "manducaram": "manducar",
    "manducaras": "manducar",
    "manducarde": "manducar",
    "manducardes": "manducar",
    "manducare": "manducar",
    "manducarei": "manducar",
    "manducareis": "manducar",
    "manducarem": "manducar",
    "manducaremos": "manducar",
    "manducares": "manducar",
    "manducaria": "manducar",
    "manducariam": "manducar",
    "manducarias": "manducar",
    "manducarmo": "manducar",
    "manducarmos": "manducar",
    "manducará": "manducar",
    "manducarás": "manducar",
    "manducarão": "manducar",
    "manducaríamos": "manducar",
    "manducaríeis": "manducar",
    "manducas": "manducar",
    "manducasse": "manducar",
    "manducassem": "manducar",
    "manducasses": "manducar",
    "manducaste": "manducar",
    "manducastes": "manducar",
    "manducativa": "manducativo",
    "manducativas": "manducativo",
    "manducativos": "manducativo",
    "manducava": "manducar",
    "manducavam": "manducar",
    "manducavas": "manducar",
    "manducações": "manducação",
    "manduco": "manducar",
    "manducos": "manduco",
    "manducou": "manducar",
    "manducá": "manducar",
    "manducámo": "manducar",
    "manducámos": "manducar",
    "manducáramo": "manducar",
    "manducáramos": "manducar",
    "manducárei": "manducar",
    "manducáreis": "manducar",
    "manducásseis": "manducar",
    "manducássemos": "manducar",
    "manducávamo": "manducar",
    "manducávamos": "manducar",
    "manducávei": "manducar",
    "manducáveis": "manducável",
    "mandupitiús": "mandupitiú",
    "manduque": "manducar",
    "manduquei": "manducar",
    "manduqueis": "manducar",
    "manduquem": "manducar",
    "manduquemo": "manducar",
    "manduquemos": "manducar",
    "manduques": "manducar",
    "mandurebas": "mandureba",
    "mandá": "mandar",
    "mandámo": "mandar",
    "mandámos": "mandar",
    "mandáramo": "mandar",
    "mandáramos": "mandar",
    "mandárei": "mandar",
    "mandáreis": "mandar",
    "mandásseis": "mandar",
    "mandássemos": "mandar",
    "mandávamo": "mandar",
    "mandávamos": "mandar",
    "mandávei": "mandar",
    "mandáveis": "mandar",
    "mandíbulas": "mandíbula",
    "mandões": "mandão",
    "mane": "manir",
    "maneabilidades": "maneabilidade",
    "maneada": "manear",
    "maneadas": "manear",
    "maneado": "manear",
    "maneadora": "maneador",
    "maneadoras": "maneador",
    "maneadores": "maneador",
    "maneados": "manear",
    "maneai": "manear",
    "maneais": "manear",
    "maneamo": "manear",
    "maneamos": "manear",
    "maneando": "manear",
    "maneara": "manear",
    "manearam": "manear",
    "manearas": "manear",
    "manearde": "manear",
    "maneardes": "manear",
    "maneare": "manear",
    "manearei": "manear",
    "maneareis": "manear",
    "manearem": "manear",
    "manearemos": "manear",
    "maneares": "manear",
    "manearia": "manear",
    "maneariam": "manear",
    "manearias": "manear",
    "manearmo": "manear",
    "manearmos": "manear",
    "maneará": "manear",
    "manearás": "manear",
    "manearão": "manear",
    "manearíamos": "manear",
    "manearíeis": "manear",
    "maneasse": "manear",
    "maneassem": "manear",
    "maneasses": "manear",
    "maneaste": "manear",
    "maneastes": "manear",
    "maneava": "manear",
    "maneavam": "manear",
    "maneavas": "manear",
    "maneei": "manear",
    "maneeis": "manear",
    "maneemo": "manear",
    "maneemos": "manear",
    "manei": "manar",
    "maneia": "manear",
    "maneiam": "manear",
    "maneias": "maneia",
    "maneie": "manear",
    "maneiem": "manear",
    "maneies": "manear",
    "maneio": "manear",
    "maneios": "maneio",
    "maneira": "maneiro",
    "maneirada": "maneirado",
    "maneiradas": "maneirado",
    "maneirados": "maneirado",
    "maneiras": "maneiro",
    "maneirinha": "maneiro",
    "maneirinhas": "maneiro",
    "maneirinho": "maneiro",
    "maneirinhos": "maneiro",
    "maneirismos": "maneirismo",
    "maneiristas": "maneirista",
    "maneirita": "maneiro",
    "maneiritas": "maneiro",
    "maneirito": "maneiro",
    "maneiritos": "maneiro",
    "maneiros": "maneiro",
    "maneirosa": "maneiroso",
    "maneirosas": "maneiroso",
    "maneirosos": "maneiroso",
    "maneis": "manar",
    "maneja": "manejar",
    "manejada": "manejar",
    "manejadas": "manejar",
    "manejado": "manejar",
    "manejadora": "manejador",
    "manejadoras": "manejador",
    "manejadores": "manejador",
    "manejados": "manejar",
    "manejai": "manejar",
    "manejais": "manejar",
    "manejam": "manejar",
    "manejamo": "manejar",
    "manejamos": "manejar",
    "manejando": "manejar",
    "manejara": "manejar",
    "manejaram": "manejar",
    "manejaras": "manejar",
    "manejarde": "manejar",
    "manejardes": "manejar",
    "manejare": "manejar",
    "manejarei": "manejar",
    "manejareis": "manejar",
    "manejarem": "manejar",
    "manejaremos": "manejar",
    "manejares": "manejar",
    "manejaria": "manejar",
    "manejariam": "manejar",
    "manejarias": "manejar",
    "manejarmo": "manejar",
    "manejarmos": "manejar",
    "manejará": "manejar",
    "manejarás": "manejar",
    "manejarão": "manejar",
    "manejaríamos": "manejar",
    "manejaríeis": "manejar",
    "manejas": "manejar",
    "manejasse": "manejar",
    "manejassem": "manejar",
    "manejasses": "manejar",
    "manejaste": "manejar",
    "manejastes": "manejar",
    "manejava": "manejar",
    "manejavam": "manejar",
    "manejavas": "manejar",
    "maneje": "manejar",
    "manejei": "manejar",
    "manejeis": "manejar",
    "manejem": "manejar",
    "manejemo": "manejar",
    "manejemos": "manejar",
    "manejes": "manejar",
    "manejo": "manejar",
    "manejos": "manejo",
    "manejou": "manejar",
    "manejá": "manejar",
    "manejámo": "manejar",
    "manejámos": "manejar",
    "manejáramo": "manejar",
    "manejáramos": "manejar",
    "manejárei": "manejar",
    "manejáreis": "manejar",
    "manejásseis": "manejar",
    "manejássemos": "manejar",
    "manejávamo": "manejar",
    "manejávamos": "manejar",
    "manejávei": "manejar",
    "manejáveis": "manejável",
    "manelos": "manelo",
    "manem": "manir",
    "manemo": "manar",
    "manemos": "manar",
    "manentes": "manente",
    "maneou": "manear",
    "manequins": "manequim",
    "manes": "manir",
    "manetas": "maneta",
    "manetes": "manete",
    "maneá": "manear",
    "maneámo": "manear",
    "maneámos": "manear",
    "maneáramo": "manear",
    "maneáramos": "manear",
    "maneárei": "manear",
    "maneáreis": "manear",
    "maneásseis": "manear",
    "maneássemos": "manear",
    "maneávamo": "manear",
    "maneávamos": "manear",
    "maneávei": "manear",
    "maneáveis": "maneável",
    "manfarricos": "manfarrico",
    "manga": "mangar",
    "mangabais": "mangabal",
    "mangabas": "mangaba",
    "mangada": "mangar",
    "mangadas": "mangar",
    "mangado": "mangar",
    "mangadora": "mangador",
    "mangadoras": "mangador",
    "mangadores": "mangador",
    "mangados": "mangar",
    "mangai": "mangar",
    "mangais": "mangar",
    "mangalaça": "mangalaço",
    "mangalaças": "mangalaço",
    "mangalaços": "mangalaço",
    "mangalhões": "mangalhão",
    "mangalôs": "mangalô",
    "mangam": "mangar",
    "mangamo": "mangar",
    "mangamos": "mangar",
    "manganatos": "manganato",
    "mangando": "mangar",
    "manganelas": "manganela",
    "manganeses": "manganês",
    "mangangadora": "mangangador",
    "mangangadoras": "mangangador",
    "mangangadores": "mangangador",
    "manganilhas": "manganilha",
    "manganinas": "manganina",
    "manganites": "manganite",
    "manganitos": "manganito",
    "manganésios": "manganésio",
    "manganífera": "manganífero",
    "manganíferas": "manganífero",
    "manganíferos": "manganífero",
    "mangara": "mangar",
    "mangaram": "mangar",
    "mangaras": "mangar",
    "mangarde": "mangar",
    "mangardes": "mangar",
    "mangare": "mangar",
    "mangarei": "mangar",
    "mangareis": "mangar",
    "mangarem": "mangar",
    "mangaremos": "mangar",
    "mangares": "mangar",
    "mangarezes": "mangarez",
    "mangaria": "mangar",
    "mangariam": "mangar",
    "mangarias": "mangar",
    "mangarmo": "mangar",
    "mangarmos": "mangar",
    "mangarobeiras": "mangarobeira",
    "mangará": "mangar",
    "mangarás": "mangará",
    "mangarão": "mangar",
    "mangaríamos": "mangar",
    "mangaríeis": "mangar",
    "mangas": "mangar",
    "mangasse": "mangar",
    "mangassem": "mangar",
    "mangasses": "mangar",
    "mangaste": "mangar",
    "mangastes": "mangar",
    "mangativa": "mangativo",
    "mangativas": "mangativo",
    "mangativos": "mangativo",
    "mangava": "mangar",
    "mangavam": "mangar",
    "mangavas": "mangar",
    "mangazes": "mangaz",
    "mangações": "mangação",
    "mangaíbas": "mangaíba",
    "mango": "mangar",
    "mangona": "mangonar",
    "mangonada": "mangonar",
    "mangonadas": "mangonar",
    "mangonado": "mangonar",
    "mangonados": "mangonar",
    "mangonai": "mangonar",
    "mangonais": "mangonar",
    "mangonam": "mangonar",
    "mangonamo": "mangonar",
    "mangonamos": "mangonar",
    "mangonando": "mangonar",
    "mangonara": "mangonar",
    "mangonaram": "mangonar",
    "mangonaras": "mangonar",
    "mangonardes": "mangonar",
    "mangonarei": "mangonar",
    "mangonareis": "mangonar",
    "mangonarem": "mangonar",
    "mangonaremos": "mangonar",
    "mangonares": "mangonar",
    "mangonaria": "mangonar",
    "mangonariam": "mangonar",
    "mangonarias": "mangonar",
    "mangonarmo": "mangonar",
    "mangonarmos": "mangonar",
    "mangonará": "mangonar",
    "mangonarás": "mangonar",
    "mangonarão": "mangonar",
    "mangonaríamos": "mangonar",
    "mangonaríeis": "mangonar",
    "mangonas": "mangonar",
    "mangonasse": "mangonar",
    "mangonassem": "mangonar",
    "mangonasses": "mangonar",
    "mangonaste": "mangonar",
    "mangonastes": "mangonar",
    "mangonava": "mangonar",
    "mangonavam": "mangonar",
    "mangonavas": "mangonar",
    "mangone": "mangonar",
    "mangonei": "mangonar",
    "mangoneis": "mangonar",
    "mangonem": "mangonar",
    "mangonemo": "mangonar",
    "mangonemos": "mangonar",
    "mangones": "mangonar",
    "mangono": "mangonar",
    "mangonou": "mangonar",
    "mangonámo": "mangonar",
    "mangonámos": "mangonar",
    "mangonáramo": "mangonar",
    "mangonáramos": "mangonar",
    "mangonáreis": "mangonar",
    "mangonásseis": "mangonar",
    "mangonássemos": "mangonar",
    "mangonávamo": "mangonar",
    "mangonávamos": "mangonar",
    "mangonáveis": "mangonar",
    "mangos": "mango",
    "mangostas": "mangosta",
    "mangostinas": "mangostina",
    "mangostões": "mangostão",
    "mangotes": "mangote",
    "mangou": "mangar",
    "mangra": "mangrar",
    "mangrada": "mangrar",
    "mangradas": "mangrar",
    "mangrado": "mangrar",
    "mangrados": "mangrar",
    "mangrai": "mangrar",
    "mangrais": "mangrar",
    "mangram": "mangrar",
    "mangramo": "mangrar",
    "mangramos": "mangrar",
    "mangrando": "mangrar",
    "mangrara": "mangrar",
    "mangraram": "mangrar",
    "mangraras": "mangrar",
    "mangrarde": "mangrar",
    "mangrardes": "mangrar",
    "mangrare": "mangrar",
    "mangrarei": "mangrar",
    "mangrareis": "mangrar",
    "mangrarem": "mangrar",
    "mangraremos": "mangrar",
    "mangrares": "mangrar",
    "mangraria": "mangrar",
    "mangrariam": "mangrar",
    "mangrarias": "mangrar",
    "mangrarmo": "mangrar",
    "mangrarmos": "mangrar",
    "mangrará": "mangrar",
    "mangrarás": "mangrar",
    "mangrarão": "mangrar",
    "mangraríamos": "mangrar",
    "mangraríeis": "mangrar",
    "mangras": "mangrar",
    "mangrasse": "mangrar",
    "mangrassem": "mangrar",
    "mangrasses": "mangrar",
    "mangraste": "mangrar",
    "mangrastes": "mangrar",
    "mangrava": "mangrar",
    "mangravam": "mangrar",
    "mangravas": "mangrar",
    "mangre": "mangrar",
    "mangrei": "mangrar",
    "mangreis": "mangrar",
    "mangrem": "mangrar",
    "mangremo": "mangrar",
    "mangremos": "mangrar",
    "mangres": "mangrar",
    "mangro": "mangrar",
    "mangrou": "mangrar",
    "mangrá": "mangrar",
    "mangrámo": "mangrar",
    "mangrámos": "mangrar",
    "mangráramo": "mangrar",
    "mangráramos": "mangrar",
    "mangrárei": "mangrar",
    "mangráreis": "mangrar",
    "mangrásseis": "mangrar",
    "mangrássemos": "mangrar",
    "mangrávamo": "mangrar",
    "mangrávamos": "mangrar",
    "mangrávei": "mangrar",
    "mangráveis": "mangrar",
    "manguais": "mangual",
    "mangualadas": "mangualada",
    "mangualdes": "mangualde",
    "mangue": "mangar",
    "mangueada": "manguear",
    "mangueadas": "manguear",
    "mangueado": "manguear",
    "mangueados": "manguear",
    "mangueai": "manguear",
    "mangueais": "manguear",
    "mangueamo": "manguear",
    "mangueamos": "manguear",
    "mangueando": "manguear",
    "mangueara": "manguear",
    "manguearam": "manguear",
    "manguearas": "manguear",
    "manguearde": "manguear",
    "mangueardes": "manguear",
    "mangueare": "manguear",
    "manguearei": "manguear",
    "mangueareis": "manguear",
    "manguearem": "manguear",
    "manguearemos": "manguear",
    "mangueares": "manguear",
    "manguearia": "manguear",
    "mangueariam": "manguear",
    "manguearias": "manguear",
    "manguearmo": "manguear",
    "manguearmos": "manguear",
    "mangueará": "manguear",
    "manguearás": "manguear",
    "manguearão": "manguear",
    "manguearíamos": "manguear",
    "manguearíeis": "manguear",
    "mangueasse": "manguear",
    "mangueassem": "manguear",
    "mangueasses": "manguear",
    "mangueaste": "manguear",
    "mangueastes": "manguear",
    "mangueava": "manguear",
    "mangueavam": "manguear",
    "mangueavas": "manguear",
    "mangueei": "manguear",
    "mangueeis": "manguear",
    "mangueemo": "manguear",
    "mangueemos": "manguear",
    "manguei": "mangar",
    "mangueia": "manguear",
    "mangueiam": "manguear",
    "mangueias": "manguear",
    "mangueie": "manguear",
    "mangueiem": "manguear",
    "mangueies": "manguear",
    "mangueio": "manguear",
    "mangueirais": "mangueiral",
    "mangueiras": "mangueira",
    "mangueis": "mangar",
    "manguem": "mangar",
    "manguemo": "mangar",
    "manguemos": "mangar",
    "mangueou": "manguear",
    "mangues": "mangue",
    "manguezais": "manguezal",
    "mangueá": "manguear",
    "mangueámo": "manguear",
    "mangueámos": "manguear",
    "mangueáramo": "manguear",
    "mangueáramos": "manguear",
    "mangueárei": "manguear",
    "mangueáreis": "manguear",
    "mangueásseis": "manguear",
    "mangueássemos": "manguear",
    "mangueávamo": "manguear",
    "mangueávamos": "manguear",
    "mangueávei": "manguear",
    "mangueáveis": "manguear",
    "manguinha": "manga",
    "manguinhas": "manga",
    "manguita": "manga",
    "manguitas": "manga",
    "manguitos": "manguito",
    "mangulas": "mangula",
    "mangustas": "mangusta",
    "mangustos": "mangusto",
    "manguços": "manguço",
    "mangá": "mangar",
    "mangámo": "mangar",
    "mangámos": "mangar",
    "mangáramo": "mangar",
    "mangáramos": "mangar",
    "mangárei": "mangar",
    "mangáreis": "mangar",
    "mangásseis": "mangar",
    "mangássemos": "mangar",
    "mangávamo": "mangar",
    "mangávamos": "mangar",
    "mangávei": "mangar",
    "mangáveis": "mangar",
    "mangânica": "mangânico",
    "mangânicas": "mangânico",
    "mangânicos": "mangânico",
    "mangões": "mangão",
    "manhas": "manha",
    "manhocos": "manhoco",
    "manhosa": "manhoso",
    "manhosas": "manhoso",
    "manhosidades": "manhosidade",
    "manhosos": "manhoso",
    "manhuças": "manhuça",
    "manhuços": "manhuço",
    "manhãs": "manhã",
    "manhãzinha": "manhã",
    "manhãzinhas": "manhã",
    "manhãzita": "manhã",
    "manhãzitas": "manhã",
    "mani": "manir",
    "mania": "manir",
    "maniada": "maniado",
    "maniadas": "maniado",
    "maniados": "maniado",
    "maniam": "manir",
    "manias": "manir",
    "maniata": "maniatar",
    "maniatada": "maniatar",
    "maniatadas": "maniatar",
    "maniatado": "maniatar",
    "maniatados": "maniatar",
    "maniatai": "maniatar",
    "maniatais": "maniatar",
    "maniatam": "maniatar",
    "maniatamo": "maniatar",
    "maniatamos": "maniatar",
    "maniatando": "maniatar",
    "maniatara": "maniatar",
    "maniataram": "maniatar",
    "maniataras": "maniatar",
    "maniatarde": "maniatar",
    "maniatardes": "maniatar",
    "maniatare": "maniatar",
    "maniatarei": "maniatar",
    "maniatareis": "maniatar",
    "maniatarem": "maniatar",
    "maniataremos": "maniatar",
    "maniatares": "maniatar",
    "maniataria": "maniatar",
    "maniatariam": "maniatar",
    "maniatarias": "maniatar",
    "maniatarmo": "maniatar",
    "maniatarmos": "maniatar",
    "maniatará": "maniatar",
    "maniatarás": "maniatar",
    "maniatarão": "maniatar",
    "maniataríamos": "maniatar",
    "maniataríeis": "maniatar",
    "maniatas": "maniatar",
    "maniatasse": "maniatar",
    "maniatassem": "maniatar",
    "maniatasses": "maniatar",
    "maniataste": "maniatar",
    "maniatastes": "maniatar",
    "maniatava": "maniatar",
    "maniatavam": "maniatar",
    "maniatavas": "maniatar",
    "maniate": "maniatar",
    "maniatei": "maniatar",
    "maniateis": "maniatar",
    "maniatem": "maniatar",
    "maniatemo": "maniatar",
    "maniatemos": "maniatar",
    "maniates": "maniatar",
    "maniato": "maniatar",
    "maniatou": "maniatar",
    "maniatá": "maniatar",
    "maniatámo": "maniatar",
    "maniatámos": "maniatar",
    "maniatáramo": "maniatar",
    "maniatáramos": "maniatar",
    "maniatárei": "maniatar",
    "maniatáreis": "maniatar",
    "maniatásseis": "maniatar",
    "maniatássemos": "maniatar",
    "maniatávamo": "maniatar",
    "maniatávamos": "maniatar",
    "maniatávei": "maniatar",
    "maniatáveis": "maniatar",
    "manicomiais": "manicomial",
    "manicura": "manicuro",
    "manicuras": "manicuro",
    "manicures": "manicure",
    "manicuros": "manicuro",
    "manicurta": "manicurto",
    "manicurtas": "manicurto",
    "manicurtos": "manicurto",
    "manicus": "manicu",
    "manicómios": "manicómio",
    "manicórdios": "manicórdio",
    "manida": "manir",
    "manidas": "manir",
    "manidextra": "manidextro",
    "manidextras": "manidextro",
    "manidextros": "manidextro",
    "manido": "manir",
    "manidos": "manir",
    "manietada": "manietado",
    "manietadas": "manietado",
    "manietados": "manietado",
    "manifesta": "manifesto",
    "manifestada": "manifestar",
    "manifestadas": "manifestar",
    "manifestado": "manifestar",
    "manifestadora": "manifestador",
    "manifestadoras": "manifestador",
    "manifestadores": "manifestador",
    "manifestados": "manifestar",
    "manifestai": "manifestar",
    "manifestais": "manifestar",
    "manifestam": "manifestar",
    "manifestamo": "manifestar",
    "manifestamos": "manifestar",
    "manifestando": "manifestar",
    "manifestantes": "manifestante",
    "manifestara": "manifestar",
    "manifestaram": "manifestar",
    "manifestaras": "manifestar",
    "manifestarde": "manifestar",
    "manifestardes": "manifestar",
    "manifestare": "manifestar",
    "manifestarei": "manifestar",
    "manifestareis": "manifestar",
    "manifestarem": "manifestar",
    "manifestaremos": "manifestar",
    "manifestares": "manifestar",
    "manifestaria": "manifestar",
    "manifestariam": "manifestar",
    "manifestarias": "manifestar",
    "manifestarmo": "manifestar",
    "manifestarmos": "manifestar",
    "manifestará": "manifestar",
    "manifestarás": "manifestar",
    "manifestarão": "manifestar",
    "manifestaríamos": "manifestar",
    "manifestaríeis": "manifestar",
    "manifestas": "manifesto",
    "manifestasse": "manifestar",
    "manifestassem": "manifestar",
    "manifestasses": "manifestar",
    "manifestaste": "manifestar",
    "manifestastes": "manifestar",
    "manifestava": "manifestar",
    "manifestavam": "manifestar",
    "manifestavas": "manifestar",
    "manifestações": "manifestação",
    "manifeste": "manifestar",
    "manifestei": "manifestar",
    "manifesteis": "manifestar",
    "manifestem": "manifestar",
    "manifestemo": "manifestar",
    "manifestemos": "manifestar",
    "manifestes": "manifestar",
    "manifesto": "manifestar",
    "manifestos": "manifesto",
    "manifestou": "manifestar",
    "manifestá": "manifestar",
    "manifestámo": "manifestar",
    "manifestámos": "manifestar",
    "manifestáramo": "manifestar",
    "manifestáramos": "manifestar",
    "manifestárei": "manifestar",
    "manifestáreis": "manifestar",
    "manifestásseis": "manifestar",
    "manifestássemos": "manifestar",
    "manifestávamo": "manifestar",
    "manifestávamos": "manifestar",
    "manifestávei": "manifestar",
    "manifestáveis": "manifestar",
    "maniflautistas": "maniflautista",
    "maniformes": "maniforme",
    "manifs": "manif",
    "maniguetes": "maniguete",
    "manigâncias": "manigância",
    "manilas": "manila",
    "manilha": "manilhar",
    "manilhada": "manilhar",
    "manilhadas": "manilhar",
    "manilhado": "manilhar",
    "manilhados": "manilhar",
    "manilhai": "manilhar",
    "manilhais": "manilhar",
    "manilham": "manilhar",
    "manilhamo": "manilhar",
    "manilhamos": "manilhar",
    "manilhando": "manilhar",
    "manilhara": "manilhar",
    "manilharam": "manilhar",
    "manilharas": "manilhar",
    "manilharde": "manilhar",
    "manilhardes": "manilhar",
    "manilhare": "manilhar",
    "manilharei": "manilhar",
    "manilhareis": "manilhar",
    "manilharem": "manilhar",
    "manilharemos": "manilhar",
    "manilhares": "manilhar",
    "manilharia": "manilhar",
    "manilhariam": "manilhar",
    "manilharias": "manilhar",
    "manilharmo": "manilhar",
    "manilharmos": "manilhar",
    "manilhará": "manilhar",
    "manilharás": "manilhar",
    "manilharão": "manilhar",
    "manilharíamos": "manilhar",
    "manilharíeis": "manilhar",
    "manilhas": "manilhar",
    "manilhasse": "manilhar",
    "manilhassem": "manilhar",
    "manilhasses": "manilhar",
    "manilhaste": "manilhar",
    "manilhastes": "manilhar",
    "manilhava": "manilhar",
    "manilhavam": "manilhar",
    "manilhavas": "manilhar",
    "manilhe": "manilhar",
    "manilhei": "manilhar",
    "manilheira": "manilheiro",
    "manilheiras": "manilheiro",
    "manilheiros": "manilheiro",
    "manilheis": "manilhar",
    "manilhem": "manilhar",
    "manilhemo": "manilhar",
    "manilhemos": "manilhar",
    "manilhes": "manilhar",
    "manilho": "manilhar",
    "manilhou": "manilhar",
    "manilhá": "manilhar",
    "manilhámo": "manilhar",
    "manilhámos": "manilhar",
    "manilháramo": "manilhar",
    "manilháramos": "manilhar",
    "manilhárei": "manilhar",
    "manilháreis": "manilhar",
    "manilhásseis": "manilhar",
    "manilhássemos": "manilhar",
    "manilhávamo": "manilhar",
    "manilhávamos": "manilhar",
    "manilhávei": "manilhar",
    "manilháveis": "manilhar",
    "manilhões": "manilhão",
    "manilúvios": "manilúvio",
    "manimbas": "manimba",
    "manimbés": "manimbé",
    "manimo": "manir",
    "manimos": "manir",
    "manina": "manino",
    "maninas": "manino",
    "manindo": "manir",
    "maninela": "maninelo",
    "maninelas": "maninelo",
    "maninelos": "maninelo",
    "maninha": "maninho",
    "maninhada": "maninhar",
    "maninhadas": "maninhar",
    "maninhado": "maninhar",
    "maninhados": "maninhar",
    "maninhai": "maninhar",
    "maninhais": "maninhar",
    "maninham": "maninhar",
    "maninhamo": "maninhar",
    "maninhamos": "maninhar",
    "maninhando": "maninhar",
    "maninhara": "maninhar",
    "maninharam": "maninhar",
    "maninharas": "maninhar",
    "maninharde": "maninhar",
    "maninhardes": "maninhar",
    "maninhare": "maninhar",
    "maninharei": "maninhar",
    "maninhareis": "maninhar",
    "maninharem": "maninhar",
    "maninharemos": "maninhar",
    "maninhares": "maninhar",
    "maninharia": "maninhar",
    "maninhariam": "maninhar",
    "maninharias": "maninhar",
    "maninharmo": "maninhar",
    "maninharmos": "maninhar",
    "maninhará": "maninhar",
    "maninharás": "maninhar",
    "maninharão": "maninhar",
    "maninharíamos": "maninhar",
    "maninharíeis": "maninhar",
    "maninhas": "maninho",
    "maninhasse": "maninhar",
    "maninhassem": "maninhar",
    "maninhasses": "maninhar",
    "maninhaste": "maninhar",
    "maninhastes": "maninhar",
    "maninhava": "maninhar",
    "maninhavam": "maninhar",
    "maninhavas": "maninhar",
    "maninhe": "maninhar",
    "maninhei": "maninhar",
    "maninheis": "maninhar",
    "maninhem": "maninhar",
    "maninhemo": "maninhar",
    "maninhemos": "maninhar",
    "maninhes": "maninhar",
    "maninhezes": "maninhez",
    "maninho": "maninhar",
    "maninhos": "maninho",
    "maninhou": "maninhar",
    "maninhá": "maninhar",
    "maninhádegos": "maninhádego",
    "maninhámo": "maninhar",
    "maninhámos": "maninhar",
    "maninháramo": "maninhar",
    "maninháramos": "maninhar",
    "maninhárei": "maninhar",
    "maninháreis": "maninhar",
    "maninhásseis": "maninhar",
    "maninhássemos": "maninhar",
    "maninhávamo": "maninhar",
    "maninhávamos": "maninhar",
    "maninhávei": "maninhar",
    "maninháveis": "maninhar",
    "maninos": "manino",
    "maniografias": "maniografia",
    "maniotas": "maniota",
    "manipansos": "manipanso",
    "manipanços": "manipanço",
    "manipresta": "manipresto",
    "maniprestas": "manipresto",
    "maniprestos": "manipresto",
    "manipueiras": "manipueira",
    "manipueras": "manipuera",
    "manipula": "manipular",
    "manipulada": "manipular",
    "manipuladas": "manipular",
    "manipulado": "manipular",
    "manipuladora": "manipulador",
    "manipuladoras": "manipulador",
    "manipuladores": "manipulador",
    "manipulados": "manipular",
    "manipuladíssima": "manipulado",
    "manipuladíssimas": "manipulado",
    "manipuladíssimo": "manipulado",
    "manipuladíssimos": "manipulado",
    "manipulai": "manipular",
    "manipulais": "manipular",
    "manipulam": "manipular",
    "manipulamo": "manipular",
    "manipulamos": "manipular",
    "manipulando": "manipular",
    "manipulara": "manipular",
    "manipularam": "manipular",
    "manipularas": "manipular",
    "manipularde": "manipular",
    "manipulardes": "manipular",
    "manipulare": "manipular",
    "manipularei": "manipular",
    "manipulareis": "manipular",
    "manipularem": "manipular",
    "manipularemos": "manipular",
    "manipulares": "manipular",
    "manipularia": "manipular",
    "manipulariam": "manipular",
    "manipularias": "manipular",
    "manipularmo": "manipular",
    "manipularmos": "manipular",
    "manipulará": "manipular",
    "manipularás": "manipular",
    "manipularão": "manipular",
    "manipularíamos": "manipular",
    "manipularíeis": "manipular",
    "manipulas": "manipular",
    "manipulasse": "manipular",
    "manipulassem": "manipular",
    "manipulasses": "manipular",
    "manipulaste": "manipular",
    "manipulastes": "manipular",
    "manipulava": "manipular",
    "manipulavam": "manipular",
    "manipulavas": "manipular",
    "manipulações": "manipulação",
    "manipule": "manipular",
    "manipulei": "manipular",
    "manipuleis": "manipular",
    "manipulem": "manipular",
    "manipulemo": "manipular",
    "manipulemos": "manipular",
    "manipules": "manipular",
    "manipulo": "manipular",
    "manipulou": "manipular",
    "manipulá": "manipular",
    "manipulámo": "manipular",
    "manipulámos": "manipular",
    "manipuláramo": "manipular",
    "manipuláramos": "manipular",
    "manipulárei": "manipular",
    "manipuláreis": "manipular",
    "manipulários": "manipulário",
    "manipulásseis": "manipular",
    "manipulássemos": "manipular",
    "manipulávamo": "manipular",
    "manipulávamos": "manipular",
    "manipulávei": "manipular",
    "manipuláveis": "manipulável",
    "maniputos": "maniputo",
    "maniqueia": "maniqueu",
    "maniqueias": "maniqueu",
    "maniquetes": "maniquete",
    "maniqueus": "maniqueu",
    "maniqueísmos": "maniqueísmo",
    "maniqueístas": "maniqueísta",
    "manira": "manir",
    "maniram": "manir",
    "maniras": "manir",
    "manirde": "manir",
    "manirdes": "manir",
    "manire": "manir",
    "manirei": "manir",
    "manireis": "manir",
    "manirem": "manir",
    "maniremos": "manir",
    "manires": "manir",
    "maniria": "manir",
    "maniriam": "manir",
    "manirias": "manir",
    "manirmo": "manir",
    "manirmos": "manir",
    "manirrota": "manirroto",
    "manirrotas": "manirroto",
    "manirrotos": "manirroto",
    "manirá": "manir",
    "manirás": "manir",
    "manirão": "manir",
    "maniríamos": "manir",
    "maniríeis": "manir",
    "manis": "manir",
    "manismos": "manismo",
    "manisse": "manir",
    "manissem": "manir",
    "manisses": "manir",
    "manistas": "manista",
    "maniste": "manir",
    "manistes": "manir",
    "manistérgios": "manistérgio",
    "manitas": "manita",
    "manites": "manite",
    "manitinas": "manitina",
    "manitus": "manitu",
    "manitóis": "manitol",
    "manitós": "manitó",
    "manitôs": "manitô",
    "maniu": "manir",
    "manivela": "manivelar",
    "manivelada": "manivelar",
    "maniveladas": "manivelar",
    "manivelado": "manivelar",
    "manivelados": "manivelar",
    "manivelai": "manivelar",
    "manivelais": "manivelar",
    "manivelam": "manivelar",
    "manivelamo": "manivelar",
    "manivelamos": "manivelar",
    "manivelando": "manivelar",
    "manivelara": "manivelar",
    "manivelaram": "manivelar",
    "manivelaras": "manivelar",
    "manivelardes": "manivelar",
    "manivelarei": "manivelar",
    "manivelareis": "manivelar",
    "manivelarem": "manivelar",
    "manivelaremos": "manivelar",
    "manivelares": "manivelar",
    "manivelaria": "manivelar",
    "manivelariam": "manivelar",
    "manivelarias": "manivelar",
    "manivelarmo": "manivelar",
    "manivelarmos": "manivelar",
    "manivelará": "manivelar",
    "manivelarás": "manivelar",
    "manivelarão": "manivelar",
    "manivelaríamos": "manivelar",
    "manivelaríeis": "manivelar",
    "manivelas": "manivelar",
    "manivelasse": "manivelar",
    "manivelassem": "manivelar",
    "manivelasses": "manivelar",
    "manivelaste": "manivelar",
    "manivelastes": "manivelar",
    "manivelava": "manivelar",
    "manivelavam": "manivelar",
    "manivelavas": "manivelar",
    "manivele": "manivelar",
    "manivelei": "manivelar",
    "maniveleis": "manivelar",
    "manivelem": "manivelar",
    "manivelemo": "manivelar",
    "manivelemos": "manivelar",
    "maniveles": "manivelar",
    "manivelo": "manivelar",
    "manivelou": "manivelar",
    "manivelámo": "manivelar",
    "manivelámos": "manivelar",
    "maniveláramo": "manivelar",
    "maniveláramos": "manivelar",
    "maniveláreis": "manivelar",
    "manivelásseis": "manivelar",
    "manivelássemos": "manivelar",
    "manivelávamo": "manivelar",
    "manivelávamos": "manivelar",
    "maniveláveis": "manivelar",
    "maniversa": "maniverso",
    "maniversas": "maniverso",
    "maniversos": "maniverso",
    "manivérsias": "manivérsia",
    "maniçobas": "maniçoba",
    "manja": "manjar",
    "manjada": "manjar",
    "manjadas": "manjar",
    "manjado": "manjar",
    "manjados": "manjar",
    "manjai": "manjar",
    "manjais": "manjar",
    "manjam": "manjar",
    "manjamo": "manjar",
    "manjamos": "manjar",
    "manjando": "manjar",
    "manjara": "manjar",
    "manjaram": "manjar",
    "manjaras": "manjar",
    "manjarde": "manjar",
    "manjardes": "manjar",
    "manjare": "manjar",
    "manjarei": "manjar",
    "manjareis": "manjar",
    "manjarem": "manjar",
    "manjaremos": "manjar",
    "manjares": "manjar",
    "manjaria": "manjar",
    "manjariam": "manjar",
    "manjarias": "manjar",
    "manjarmo": "manjar",
    "manjarmos": "manjar",
    "manjará": "manjar",
    "manjarás": "manjar",
    "manjarão": "manjar",
    "manjaríamos": "manjar",
    "manjaríeis": "manjar",
    "manjas": "manjar",
    "manjasse": "manjar",
    "manjassem": "manjar",
    "manjasses": "manjar",
    "manjaste": "manjar",
    "manjastes": "manjar",
    "manjava": "manjar",
    "manjavam": "manjar",
    "manjavas": "manjar",
    "manje": "manjar",
    "manjedoiras": "manjedoira",
    "manjedouras": "manjedoura",
    "manjei": "manjar",
    "manjeis": "manjar",
    "manjelins": "manjelim",
    "manjem": "manjar",
    "manjemo": "manjar",
    "manjemos": "manjar",
    "manjericos": "manjerico",
    "manjericões": "manjericão",
    "manjeronas": "manjerona",
    "manjerões": "manjerão",
    "manjes": "manjar",
    "manjis": "manjil",
    "manjo": "manjar",
    "manjorras": "manjorra",
    "manjou": "manjar",
    "manjuas": "manjua",
    "manjá": "manjar",
    "manjámo": "manjar",
    "manjámos": "manjar",
    "manjáramo": "manjar",
    "manjáramos": "manjar",
    "manjárei": "manjar",
    "manjáreis": "manjar",
    "manjásseis": "manjar",
    "manjássemos": "manjar",
    "manjávamo": "manjar",
    "manjávamos": "manjar",
    "manjávei": "manjar",
    "manjáveis": "manjar",
    "mano": "manir",
    "manobra": "manobrar",
    "manobrada": "manobrar",
    "manobradas": "manobrar",
    "manobrado": "manobrar",
    "manobradora": "manobrador",
    "manobradoras": "manobrador",
    "manobradores": "manobrador",
    "manobrados": "manobrar",
    "manobrai": "manobrar",
    "manobrais": "manobrar",
    "manobram": "manobrar",
    "manobramo": "manobrar",
    "manobramos": "manobrar",
    "manobrando": "manobrar",
    "manobrara": "manobrar",
    "manobraram": "manobrar",
    "manobraras": "manobrar",
    "manobrarde": "manobrar",
    "manobrardes": "manobrar",
    "manobrare": "manobrar",
    "manobrarei": "manobrar",
    "manobrareis": "manobrar",
    "manobrarem": "manobrar",
    "manobraremos": "manobrar",
    "manobrares": "manobrar",
    "manobraria": "manobrar",
    "manobrariam": "manobrar",
    "manobrarias": "manobrar",
    "manobrarmo": "manobrar",
    "manobrarmos": "manobrar",
    "manobrará": "manobrar",
    "manobrarás": "manobrar",
    "manobrarão": "manobrar",
    "manobraríamos": "manobrar",
    "manobraríeis": "manobrar",
    "manobras": "manobrar",
    "manobrasse": "manobrar",
    "manobrassem": "manobrar",
    "manobrasses": "manobrar",
    "manobraste": "manobrar",
    "manobrastes": "manobrar",
    "manobrava": "manobrar",
    "manobravam": "manobrar",
    "manobravas": "manobrar",
    "manobre": "manobrar",
    "manobrei": "manobrar",
    "manobreira": "manobreiro",
    "manobreiras": "manobreiro",
    "manobreiros": "manobreiro",
    "manobreis": "manobrar",
    "manobrem": "manobrar",
    "manobremo": "manobrar",
    "manobremos": "manobrar",
    "manobres": "manobrar",
    "manobristas": "manobrista",
    "manobro": "manobrar",
    "manobrou": "manobrar",
    "manobrá": "manobrar",
    "manobrámo": "manobrar",
    "manobrámos": "manobrar",
    "manobráramo": "manobrar",
    "manobráramos": "manobrar",
    "manobrárei": "manobrar",
    "manobráreis": "manobrar",
    "manobrásseis": "manobrar",
    "manobrássemos": "manobrar",
    "manobrávamo": "manobrar",
    "manobrávamos": "manobrar",
    "manobrávei": "manobrar",
    "manobráveis": "manobrável",
    "manoca": "manocar",
    "manocada": "manocar",
    "manocadas": "manocar",
    "manocado": "manocar",
    "manocados": "manocar",
    "manocai": "manocar",
    "manocais": "manocar",
    "manocam": "manocar",
    "manocamo": "manocar",
    "manocamos": "manocar",
    "manocando": "manocar",
    "manocara": "manocar",
    "manocaram": "manocar",
    "manocaras": "manocar",
    "manocarde": "manocar",
    "manocardes": "manocar",
    "manocare": "manocar",
    "manocarei": "manocar",
    "manocareis": "manocar",
    "manocarem": "manocar",
    "manocaremos": "manocar",
    "manocares": "manocar",
    "manocaria": "manocar",
    "manocariam": "manocar",
    "manocarias": "manocar",
    "manocarmo": "manocar",
    "manocarmos": "manocar",
    "manocará": "manocar",
    "manocarás": "manocar",
    "manocarão": "manocar",
    "manocaríamos": "manocar",
    "manocaríeis": "manocar",
    "manocas": "manocar",
    "manocasse": "manocar",
    "manocassem": "manocar",
    "manocasses": "manocar",
    "manocaste": "manocar",
    "manocastes": "manocar",
    "manocava": "manocar",
    "manocavam": "manocar",
    "manocavas": "manocar",
    "manoco": "manocar",
    "manocou": "manocar",
    "manocá": "manocar",
    "manocámo": "manocar",
    "manocámos": "manocar",
    "manocáramo": "manocar",
    "manocáramos": "manocar",
    "manocárei": "manocar",
    "manocáreis": "manocar",
    "manocásseis": "manocar",
    "manocássemos": "manocar",
    "manocávamo": "manocar",
    "manocávamos": "manocar",
    "manocávei": "manocar",
    "manocáveis": "manocar",
    "manocórdios": "manocórdio",
    "manojeira": "manojeiro",
    "manojeiras": "manojeiro",
    "manojeiros": "manojeiro",
    "manojos": "manojo",
    "manolas": "manola",
    "manometrias": "manometria",
    "manométrica": "manométrico",
    "manométricas": "manométrico",
    "manométricos": "manométrico",
    "manoplas": "manopla",
    "manoque": "manocar",
    "manoquei": "manocar",
    "manoqueis": "manocar",
    "manoquem": "manocar",
    "manoquemo": "manocar",
    "manoquemos": "manocar",
    "manoques": "manocar",
    "manos": "mano",
    "manotaços": "manotaço",
    "manoteada": "manotear",
    "manoteadas": "manotear",
    "manoteado": "manotear",
    "manoteados": "manotear",
    "manoteai": "manotear",
    "manoteais": "manotear",
    "manoteamo": "manotear",
    "manoteamos": "manotear",
    "manoteando": "manotear",
    "manoteara": "manotear",
    "manotearam": "manotear",
    "manotearas": "manotear",
    "manoteardes": "manotear",
    "manotearei": "manotear",
    "manoteareis": "manotear",
    "manotearem": "manotear",
    "manotearemos": "manotear",
    "manoteares": "manotear",
    "manotearia": "manotear",
    "manoteariam": "manotear",
    "manotearias": "manotear",
    "manotearmo": "manotear",
    "manotearmos": "manotear",
    "manoteará": "manotear",
    "manotearás": "manotear",
    "manotearão": "manotear",
    "manotearíamos": "manotear",
    "manotearíeis": "manotear",
    "manoteasse": "manotear",
    "manoteassem": "manotear",
    "manoteasses": "manotear",
    "manoteaste": "manotear",
    "manoteastes": "manotear",
    "manoteava": "manotear",
    "manoteavam": "manotear",
    "manoteavas": "manotear",
    "manoteei": "manotear",
    "manoteeis": "manotear",
    "manoteemo": "manotear",
    "manoteemos": "manotear",
    "manoteia": "manotear",
    "manoteiam": "manotear",
    "manoteias": "manotear",
    "manoteie": "manotear",
    "manoteiem": "manotear",
    "manoteies": "manotear",
    "manoteio": "manotear",
    "manoteou": "manotear",
    "manoteámo": "manotear",
    "manoteámos": "manotear",
    "manoteáramo": "manotear",
    "manoteáramos": "manotear",
    "manoteáreis": "manotear",
    "manoteásseis": "manotear",
    "manoteássemos": "manotear",
    "manoteávamo": "manotear",
    "manoteávamos": "manotear",
    "manoteáveis": "manotear",
    "manou": "manar",
    "manozinho": "mano",
    "manozinhos": "mano",
    "manozito": "mano",
    "manozitos": "mano",
    "manque": "mancar",
    "manquece": "manquecer",
    "manquecei": "manquecer",
    "manqueceis": "manquecer",
    "manquecem": "manquecer",
    "manquecemo": "manquecer",
    "manquecemos": "manquecer",
    "manquecendo": "manquecer",
    "manquecera": "manquecer",
    "manqueceram": "manquecer",
    "manqueceras": "manquecer",
    "manquecerdes": "manquecer",
    "manquecerei": "manquecer",
    "manquecereis": "manquecer",
    "manquecerem": "manquecer",
    "manqueceremos": "manquecer",
    "manqueceres": "manquecer",
    "manqueceria": "manquecer",
    "manqueceriam": "manquecer",
    "manquecerias": "manquecer",
    "manquecermo": "manquecer",
    "manquecermos": "manquecer",
    "manquecerá": "manquecer",
    "manquecerás": "manquecer",
    "manquecerão": "manquecer",
    "manqueceríamos": "manquecer",
    "manqueceríeis": "manquecer",
    "manqueces": "manquecer",
    "manquecesse": "manquecer",
    "manquecessem": "manquecer",
    "manquecesses": "manquecer",
    "manqueceste": "manquecer",
    "manquecestes": "manquecer",
    "manqueceu": "manquecer",
    "manqueci": "manquecer",
    "manquecia": "manquecer",
    "manqueciam": "manquecer",
    "manquecias": "manquecer",
    "manquecida": "manquecer",
    "manquecidas": "manquecer",
    "manquecido": "manquecer",
    "manquecidos": "manquecer",
    "manquecêramo": "manquecer",
    "manquecêramos": "manquecer",
    "manquecêreis": "manquecer",
    "manquecêsseis": "manquecer",
    "manquecêssemos": "manquecer",
    "manquecíamo": "manquecer",
    "manquecíamos": "manquecer",
    "manquecíeis": "manquecer",
    "manquei": "mancar",
    "manqueiras": "manqueira",
    "manqueis": "mancar",
    "manqueja": "manquejar",
    "manquejada": "manquejar",
    "manquejadas": "manquejar",
    "manquejado": "manquejar",
    "manquejados": "manquejar",
    "manquejai": "manquejar",
    "manquejais": "manquejar",
    "manquejam": "manquejar",
    "manquejamo": "manquejar",
    "manquejamos": "manquejar",
    "manquejando": "manquejar",
    "manquejantes": "manquejante",
    "manquejara": "manquejar",
    "manquejaram": "manquejar",
    "manquejaras": "manquejar",
    "manquejardes": "manquejar",
    "manquejarei": "manquejar",
    "manquejareis": "manquejar",
    "manquejarem": "manquejar",
    "manquejaremos": "manquejar",
    "manquejares": "manquejar",
    "manquejaria": "manquejar",
    "manquejariam": "manquejar",
    "manquejarias": "manquejar",
    "manquejarmo": "manquejar",
    "manquejarmos": "manquejar",
    "manquejará": "manquejar",
    "manquejarás": "manquejar",
    "manquejarão": "manquejar",
    "manquejaríamos": "manquejar",
    "manquejaríeis": "manquejar",
    "manquejas": "manquejar",
    "manquejasse": "manquejar",
    "manquejassem": "manquejar",
    "manquejasses": "manquejar",
    "manquejaste": "manquejar",
    "manquejastes": "manquejar",
    "manquejava": "manquejar",
    "manquejavam": "manquejar",
    "manquejavas": "manquejar",
    "manqueje": "manquejar",
    "manquejei": "manquejar",
    "manquejeis": "manquejar",
    "manquejem": "manquejar",
    "manquejemo": "manquejar",
    "manquejemos": "manquejar",
    "manquejes": "manquejar",
    "manquejo": "manquejar",
    "manquejou": "manquejar",
    "manquejámo": "manquejar",
    "manquejámos": "manquejar",
    "manquejáramo": "manquejar",
    "manquejáramos": "manquejar",
    "manquejáreis": "manquejar",
    "manquejásseis": "manquejar",
    "manquejássemos": "manquejar",
    "manquejávamo": "manquejar",
    "manquejávamos": "manquejar",
    "manquejáveis": "manquejar",
    "manquem": "mancar",
    "manquemo": "mancar",
    "manquemos": "mancar",
    "manques": "mancar",
    "manqueça": "manquecer",
    "manqueçais": "manquecer",
    "manqueçam": "manquecer",
    "manqueçamo": "manquecer",
    "manqueçamos": "manquecer",
    "manqueças": "manquecer",
    "manqueço": "manquecer",
    "manquita": "manquitar",
    "manquitada": "manquitar",
    "manquitadas": "manquitar",
    "manquitado": "manquitar",
    "manquitados": "manquitar",
    "manquitai": "manquitar",
    "manquitais": "manquitar",
    "manquitam": "manquitar",
    "manquitamo": "manquitar",
    "manquitamos": "manquitar",
    "manquitando": "manquitar",
    "manquitara": "manquitar",
    "manquitaram": "manquitar",
    "manquitaras": "manquitar",
    "manquitardes": "manquitar",
    "manquitarei": "manquitar",
    "manquitareis": "manquitar",
    "manquitarem": "manquitar",
    "manquitaremos": "manquitar",
    "manquitares": "manquitar",
    "manquitaria": "manquitar",
    "manquitariam": "manquitar",
    "manquitarias": "manquitar",
    "manquitarmo": "manquitar",
    "manquitarmos": "manquitar",
    "manquitará": "manquitar",
    "manquitarás": "manquitar",
    "manquitarão": "manquitar",
    "manquitaríamos": "manquitar",
    "manquitaríeis": "manquitar",
    "manquitas": "manquitar",
    "manquitasse": "manquitar",
    "manquitassem": "manquitar",
    "manquitasses": "manquitar",
    "manquitaste": "manquitar",
    "manquitastes": "manquitar",
    "manquitava": "manquitar",
    "manquitavam": "manquitar",
    "manquitavas": "manquitar",
    "manquite": "manquitar",
    "manquitei": "manquitar",
    "manquiteis": "manquitar",
    "manquitem": "manquitar",
    "manquitemo": "manquitar",
    "manquitemos": "manquitar",
    "manquites": "manquitar",
    "manquito": "manquitar",
    "manquitolas": "manquitola",
    "manquitou": "manquitar",
    "manquitámo": "manquitar",
    "manquitámos": "manquitar",
    "manquitáramo": "manquitar",
    "manquitáramos": "manquitar",
    "manquitáreis": "manquitar",
    "manquitásseis": "manquitar",
    "manquitássemos": "manquitar",
    "manquitávamo": "manquitar",
    "manquitávamos": "manquitar",
    "manquitáveis": "manquitar",
    "manquitós": "manquitó",
    "mansa": "manso",
    "mansardas": "mansarda",
    "mansarrona": "manso",
    "mansarronas": "manso",
    "mansarrão": "manso",
    "mansarrões": "manso",
    "mansas": "manso",
    "mansazinha": "manso",
    "mansazinhas": "manso",
    "mansazita": "manso",
    "mansazitas": "manso",
    "mansidões": "mansidão",
    "mansinha": "manso",
    "mansinhas": "manso",
    "mansinho": "manso",
    "mansinhos": "manso",
    "mansionária": "mansionário",
    "mansionárias": "mansionário",
    "mansionários": "mansionário",
    "mansita": "manso",
    "mansitas": "manso",
    "mansito": "manso",
    "mansitos": "manso",
    "mansos": "manso",
    "mansozinho": "manso",
    "mansozinhos": "manso",
    "mansozito": "manso",
    "mansozitos": "manso",
    "mansuetudes": "mansuetude",
    "mansuetários": "mansuetário",
    "mansões": "mansão",
    "manta": "mantar",
    "mantada": "mantar",
    "mantadas": "mantar",
    "mantado": "mantar",
    "mantados": "mantar",
    "mantai": "mantar",
    "mantais": "mantar",
    "mantalonas": "mantalona",
    "mantam": "mantar",
    "mantamo": "mantar",
    "mantamos": "mantar",
    "mantanas": "mantana",
    "mantando": "mantar",
    "mantara": "mantar",
    "mantaram": "mantar",
    "mantaras": "mantar",
    "mantardes": "mantar",
    "mantarei": "mantar",
    "mantareis": "mantar",
    "mantarem": "mantar",
    "mantaremos": "mantar",
    "mantares": "mantar",
    "mantaria": "mantar",
    "mantariam": "mantar",
    "mantarias": "mantar",
    "mantarmo": "mantar",
    "mantarmos": "mantar",
    "mantará": "mantar",
    "mantarás": "mantar",
    "mantarão": "mantar",
    "mantaríamos": "mantar",
    "mantaríeis": "mantar",
    "mantas": "mantar",
    "mantasse": "mantar",
    "mantassem": "mantar",
    "mantasses": "mantar",
    "mantaste": "mantar",
    "mantastes": "mantar",
    "mantava": "mantar",
    "mantavam": "mantar",
    "mantavas": "mantar",
    "mante": "mantar",
    "manteada": "mantear",
    "manteadas": "mantear",
    "manteado": "mantear",
    "manteadora": "manteador",
    "manteadoras": "manteador",
    "manteadores": "manteador",
    "manteados": "mantear",
    "manteai": "mantear",
    "manteais": "mantear",
    "manteamo": "mantear",
    "manteamos": "mantear",
    "manteando": "mantear",
    "manteara": "mantear",
    "mantearam": "mantear",
    "mantearas": "mantear",
    "mantearde": "mantear",
    "manteardes": "mantear",
    "manteare": "mantear",
    "mantearei": "mantear",
    "manteareis": "mantear",
    "mantearem": "mantear",
    "mantearemos": "mantear",
    "manteares": "mantear",
    "mantearia": "mantear",
    "manteariam": "mantear",
    "mantearias": "mantearia",
    "mantearmo": "mantear",
    "mantearmos": "mantear",
    "manteará": "mantear",
    "mantearás": "mantear",
    "mantearão": "mantear",
    "mantearíamos": "mantear",
    "mantearíeis": "mantear",
    "manteasse": "mantear",
    "manteassem": "mantear",
    "manteasses": "mantear",
    "manteaste": "mantear",
    "manteastes": "mantear",
    "manteava": "mantear",
    "manteavam": "mantear",
    "manteavas": "mantear",
    "manteações": "manteação",
    "manteei": "mantear",
    "manteeira": "manteeiro",
    "manteeiras": "manteeiro",
    "manteeiros": "manteeiro",
    "manteeis": "mantear",
    "manteemo": "mantear",
    "manteemos": "mantear",
    "mantei": "mantar",
    "manteia": "mantear",
    "manteiam": "mantear",
    "manteias": "mantear",
    "manteie": "mantear",
    "manteiem": "mantear",
    "manteies": "mantear",
    "manteigarias": "manteigaria",
    "manteigas": "manteiga",
    "manteigosa": "manteigoso",
    "manteigosas": "manteigoso",
    "manteigosos": "manteigoso",
    "manteigueira": "manteigueiro",
    "manteigueiras": "manteigueiro",
    "manteigueiros": "manteigueiro",
    "manteiguenta": "manteiguento",
    "manteiguentas": "manteiguento",
    "manteiguentos": "manteiguento",
    "manteiguilhas": "manteiguilha",
    "manteiguinha": "manteiga",
    "manteiguinhas": "manteiga",
    "manteiguita": "manteiga",
    "manteiguitas": "manteiga",
    "manteio": "mantear",
    "manteira": "manteiro",
    "manteiras": "manteiro",
    "manteiros": "manteiro",
    "manteis": "mantar",
    "mantelada": "mantelado",
    "manteladas": "mantelado",
    "mantelados": "mantelado",
    "manteleres": "manteler",
    "manteletas": "manteleta",
    "manteletes": "mantelete",
    "mantelões": "mantelão",
    "mantem": "mantar",
    "mantemo": "manter",
    "mantemos": "manter",
    "mantende": "manter",
    "mantendes": "manter",
    "mantendo": "manter",
    "mantenedora": "mantenedor",
    "mantenedoras": "mantenedor",
    "mantenedores": "mantenedor",
    "mantenha": "manter",
    "mantenhais": "manter",
    "mantenham": "manter",
    "mantenhamo": "manter",
    "mantenhamos": "manter",
    "mantenhas": "manter",
    "mantenho": "manter",
    "mantenças": "mantença",
    "manteou": "mantear",
    "manterde": "manter",
    "manterdes": "manter",
    "mantere": "manter",
    "manterei": "manter",
    "mantereis": "manter",
    "manterem": "manter",
    "manteremos": "manter",
    "manteres": "manter",
    "manteria": "manter",
    "manteriam": "manter",
    "manterias": "manter",
    "mantermo": "manter",
    "mantermos": "manter",
    "manterá": "manter",
    "manterás": "manter",
    "manterão": "manter",
    "manteríamos": "manter",
    "manteríeis": "manter",
    "mantes": "mantar",
    "manteve": "manter",
    "manteá": "mantear",
    "manteámo": "mantear",
    "manteámos": "mantear",
    "manteáramo": "mantear",
    "manteáramos": "mantear",
    "manteárei": "mantear",
    "manteáreis": "mantear",
    "manteásseis": "mantear",
    "manteássemos": "mantear",
    "manteávamo": "mantear",
    "manteávamos": "mantear",
    "manteávei": "mantear",
    "manteáveis": "mantear",
    "manteúda": "manteúdo",
    "manteúdas": "manteúdo",
    "manteúdos": "manteúdo",
    "mantida": "mantido",
    "mantidas": "mantido",
    "mantido": "manter",
    "mantidos": "mantido",
    "mantieira": "mantieiro",
    "mantieiras": "mantieiro",
    "mantieiros": "mantieiro",
    "mantilhas": "mantilha",
    "mantimentos": "mantimento",
    "mantinha": "manter",
    "mantinham": "manter",
    "mantinhas": "mantinha",
    "mantinho": "manto",
    "mantinhos": "manto",
    "mantissas": "mantissa",
    "mantita": "manta",
    "mantitas": "manta",
    "mantito": "manto",
    "mantitos": "manto",
    "mantive": "manter",
    "mantivemo": "manter",
    "mantivemos": "manter",
    "mantiver": "manter",
    "mantivera": "manter",
    "mantiveram": "manter",
    "mantiveras": "manter",
    "mantiverdes": "manter",
    "mantiverem": "manter",
    "mantiveres": "manter",
    "mantivermos": "manter",
    "mantivesse": "manter",
    "mantivessem": "manter",
    "mantivesses": "manter",
    "mantiveste": "manter",
    "mantivestes": "manter",
    "mantivéramo": "manter",
    "mantivéramos": "manter",
    "mantivérei": "manter",
    "mantivéreis": "manter",
    "mantivésseis": "manter",
    "mantivéssemos": "manter",
    "manto": "mantar",
    "mantos": "manto",
    "mantou": "mantar",
    "mantuana": "mantuano",
    "mantuanas": "mantuano",
    "mantuanos": "mantuano",
    "mantámo": "mantar",
    "mantámos": "mantar",
    "mantáramo": "mantar",
    "mantáramos": "mantar",
    "mantáreis": "mantar",
    "mantásseis": "mantar",
    "mantássemos": "mantar",
    "mantávamo": "mantar",
    "mantávamos": "mantar",
    "mantáveis": "mantar",
    "mantéis": "mantel",
    "mantém": "manter",
    "manténs": "manter",
    "mantéus": "mantéu",
    "mantê": "manter",
    "mantêm": "manter",
    "mantídeos": "mantídeo",
    "mantínhamo": "manter",
    "mantínhamos": "manter",
    "mantínhei": "manter",
    "mantínheis": "manter",
    "mantós": "mantó",
    "mantões": "mantão",
    "manuais": "manual",
    "manubiais": "manubial",
    "manucodiatas": "manucodiata",
    "manucódios": "manucódio",
    "manudutora": "manudutor",
    "manudutoras": "manudutor",
    "manudutores": "manudutor",
    "manuduções": "manudução",
    "manuelina": "manuelino",
    "manuelinas": "manuelino",
    "manuelinos": "manuelino",
    "manuelistas": "manuelista",
    "manufactora": "manufactor",
    "manufactoras": "manufactor",
    "manufactores": "manufactor",
    "manufactos": "manufacto",
    "manufactura": "manufacturar",
    "manufacturada": "manufacturar",
    "manufacturadas": "manufacturar",
    "manufacturado": "manufacturar",
    "manufacturados": "manufacturar",
    "manufacturai": "manufacturar",
    "manufacturais": "manufacturar",
    "manufacturam": "manufacturar",
    "manufacturamo": "manufacturar",
    "manufacturamos": "manufacturar",
    "manufacturando": "manufacturar",
    "manufacturara": "manufacturar",
    "manufacturaram": "manufacturar",
    "manufacturaras": "manufacturar",
    "manufacturarde": "manufacturar",
    "manufacturardes": "manufacturar",
    "manufacturare": "manufacturar",
    "manufacturarei": "manufacturar",
    "manufacturareis": "manufacturar",
    "manufacturarem": "manufacturar",
    "manufacturaremos": "manufacturar",
    "manufacturares": "manufacturar",
    "manufacturaria": "manufacturar",
    "manufacturariam": "manufacturar",
    "manufacturarias": "manufacturar",
    "manufacturarmo": "manufacturar",
    "manufacturarmos": "manufacturar",
    "manufacturará": "manufacturar",
    "manufacturarás": "manufacturar",
    "manufacturarão": "manufacturar",
    "manufacturaríamos": "manufacturar",
    "manufacturaríeis": "manufacturar",
    "manufacturas": "manufacturar",
    "manufacturasse": "manufacturar",
    "manufacturassem": "manufacturar",
    "manufacturasses": "manufacturar",
    "manufacturaste": "manufacturar",
    "manufacturastes": "manufacturar",
    "manufacturava": "manufacturar",
    "manufacturavam": "manufacturar",
    "manufacturavas": "manufacturar",
    "manufacture": "manufacturar",
    "manufacturei": "manufacturar",
    "manufactureira": "manufactureiro",
    "manufactureiras": "manufactureiro",
    "manufactureiros": "manufactureiro",
    "manufactureis": "manufacturar",
    "manufacturem": "manufacturar",
    "manufacturemo": "manufacturar",
    "manufacturemos": "manufacturar",
    "manufactures": "manufacturar",
    "manufacturo": "manufacturar",
    "manufacturou": "manufacturar",
    "manufacturá": "manufacturar",
    "manufacturámo": "manufacturar",
    "manufacturámos": "manufacturar",
    "manufacturáramo": "manufacturar",
    "manufacturáramos": "manufacturar",
    "manufacturárei": "manufacturar",
    "manufacturáreis": "manufacturar",
    "manufacturásseis": "manufacturar",
    "manufacturássemos": "manufacturar",
    "manufacturávamo": "manufacturar",
    "manufacturávamos": "manufacturar",
    "manufacturávei": "manufacturar",
    "manufacturáveis": "manufacturável",
    "manulúvios": "manulúvio",
    "manumissa": "manumisso",
    "manumissas": "manumisso",
    "manumissora": "manumissor",
    "manumissoras": "manumissor",
    "manumissores": "manumissor",
    "manumissos": "manumisso",
    "manumissões": "manumissão",
    "manumita": "manumitir",
    "manumitais": "manumitir",
    "manumitam": "manumitir",
    "manumitamo": "manumitir",
    "manumitamos": "manumitir",
    "manumitas": "manumitir",
    "manumite": "manumitir",
    "manumitem": "manumitir",
    "manumitentes": "manumitente",
    "manumites": "manumitir",
    "manumiti": "manumitir",
    "manumitia": "manumitir",
    "manumitiam": "manumitir",
    "manumitias": "manumitir",
    "manumitida": "manumitir",
    "manumitidas": "manumitir",
    "manumitido": "manumitir",
    "manumitidos": "manumitir",
    "manumitimo": "manumitir",
    "manumitimos": "manumitir",
    "manumitindo": "manumitir",
    "manumitira": "manumitir",
    "manumitiram": "manumitir",
    "manumitiras": "manumitir",
    "manumitirde": "manumitir",
    "manumitirdes": "manumitir",
    "manumitire": "manumitir",
    "manumitirei": "manumitir",
    "manumitireis": "manumitir",
    "manumitirem": "manumitir",
    "manumitiremos": "manumitir",
    "manumitires": "manumitir",
    "manumitiria": "manumitir",
    "manumitiriam": "manumitir",
    "manumitirias": "manumitir",
    "manumitirmo": "manumitir",
    "manumitirmos": "manumitir",
    "manumitirá": "manumitir",
    "manumitirás": "manumitir",
    "manumitirão": "manumitir",
    "manumitiríamos": "manumitir",
    "manumitiríeis": "manumitir",
    "manumitis": "manumitir",
    "manumitisse": "manumitir",
    "manumitissem": "manumitir",
    "manumitisses": "manumitir",
    "manumitiste": "manumitir",
    "manumitistes": "manumitir",
    "manumitiu": "manumitir",
    "manumito": "manumitir",
    "manumitíamo": "manumitir",
    "manumitíamos": "manumitir",
    "manumitíei": "manumitir",
    "manumitíeis": "manumitir",
    "manumitíramo": "manumitir",
    "manumitíramos": "manumitir",
    "manumitírei": "manumitir",
    "manumitíreis": "manumitir",
    "manumitísseis": "manumitir",
    "manumitíssemos": "manumitir",
    "manuscreva": "manuscrever",
    "manuscrevais": "manuscrever",
    "manuscrevam": "manuscrever",
    "manuscrevamo": "manuscrever",
    "manuscrevamos": "manuscrever",
    "manuscrevas": "manuscrever",
    "manuscreve": "manuscrever",
    "manuscrevei": "manuscrever",
    "manuscreveis": "manuscrever",
    "manuscrevem": "manuscrever",
    "manuscrevemo": "manuscrever",
    "manuscrevemos": "manuscrever",
    "manuscrevendo": "manuscrever",
    "manuscrevera": "manuscrever",
    "manuscreveram": "manuscrever",
    "manuscreveras": "manuscrever",
    "manuscreverde": "manuscrever",
    "manuscreverdes": "manuscrever",
    "manuscrevere": "manuscrever",
    "manuscreverei": "manuscrever",
    "manuscrevereis": "manuscrever",
    "manuscreverem": "manuscrever",
    "manuscreveremos": "manuscrever",
    "manuscreveres": "manuscrever",
    "manuscreveria": "manuscrever",
    "manuscreveriam": "manuscrever",
    "manuscreverias": "manuscrever",
    "manuscrevermo": "manuscrever",
    "manuscrevermos": "manuscrever",
    "manuscreverá": "manuscrever",
    "manuscreverás": "manuscrever",
    "manuscreverão": "manuscrever",
    "manuscreveríamos": "manuscrever",
    "manuscreveríeis": "manuscrever",
    "manuscreves": "manuscrever",
    "manuscrevesse": "manuscrever",
    "manuscrevessem": "manuscrever",
    "manuscrevesses": "manuscrever",
    "manuscreveste": "manuscrever",
    "manuscrevestes": "manuscrever",
    "manuscreveu": "manuscrever",
    "manuscrevi": "manuscrever",
    "manuscrevia": "manuscrever",
    "manuscreviam": "manuscrever",
    "manuscrevias": "manuscrever",
    "manuscrevida": "manuscrever",
    "manuscrevidas": "manuscrever",
    "manuscrevido": "manuscrever",
    "manuscrevidos": "manuscrever",
    "manuscrevo": "manuscrever",
    "manuscrevê": "manuscrever",
    "manuscrevêramo": "manuscrever",
    "manuscrevêramos": "manuscrever",
    "manuscrevêrei": "manuscrever",
    "manuscrevêreis": "manuscrever",
    "manuscrevêsseis": "manuscrever",
    "manuscrevêssemos": "manuscrever",
    "manuscrevíamo": "manuscrever",
    "manuscrevíamos": "manuscrever",
    "manuscrevíei": "manuscrever",
    "manuscrevíeis": "manuscrever",
    "manuscrita": "manuscrito",
    "manuscritas": "manuscrito",
    "manuscritos": "manuscrito",
    "manusdeis": "manusdei",
    "manuseada": "manusear",
    "manuseadas": "manusear",
    "manuseado": "manusear",
    "manuseados": "manusear",
    "manuseai": "manusear",
    "manuseais": "manusear",
    "manuseamentos": "manuseamento",
    "manuseamo": "manusear",
    "manuseamos": "manusear",
    "manuseando": "manusear",
    "manuseara": "manusear",
    "manusearam": "manusear",
    "manusearas": "manusear",
    "manusearde": "manusear",
    "manuseardes": "manusear",
    "manuseare": "manusear",
    "manusearei": "manusear",
    "manuseareis": "manusear",
    "manusearem": "manusear",
    "manusearemos": "manusear",
    "manuseares": "manusear",
    "manusearia": "manusear",
    "manuseariam": "manusear",
    "manusearias": "manusear",
    "manusearmo": "manusear",
    "manusearmos": "manusear",
    "manuseará": "manusear",
    "manusearás": "manusear",
    "manusearão": "manusear",
    "manusearíamos": "manusear",
    "manusearíeis": "manusear",
    "manuseasse": "manusear",
    "manuseassem": "manusear",
    "manuseasses": "manusear",
    "manuseaste": "manusear",
    "manuseastes": "manusear",
    "manuseava": "manusear",
    "manuseavam": "manusear",
    "manuseavas": "manusear",
    "manuseações": "manuseação",
    "manuseei": "manusear",
    "manuseeis": "manusear",
    "manuseemo": "manusear",
    "manuseemos": "manusear",
    "manuseia": "manusear",
    "manuseiam": "manusear",
    "manuseias": "manusear",
    "manuseie": "manusear",
    "manuseiem": "manusear",
    "manuseies": "manusear",
    "manuseio": "manusear",
    "manuseios": "manuseio",
    "manuseou": "manusear",
    "manuseá": "manusear",
    "manuseámo": "manusear",
    "manuseámos": "manusear",
    "manuseáramo": "manusear",
    "manuseáramos": "manusear",
    "manuseárei": "manusear",
    "manuseáreis": "manusear",
    "manuseásseis": "manusear",
    "manuseássemos": "manusear",
    "manuseávamo": "manusear",
    "manuseávamos": "manusear",
    "manuseávei": "manusear",
    "manuseáveis": "manuseável",
    "manutenções": "manutenção",
    "manutenências": "manutenência",
    "manuteníveis": "manutenível",
    "manutérgios": "manutérgio",
    "manuários": "manuário",
    "manuês": "manuê",
    "manvios": "manvio",
    "manzaris": "manzari",
    "manzorras": "manzorra",
    "maná": "manar",
    "manámo": "manar",
    "manámos": "manar",
    "manápulas": "manápula",
    "manáramo": "manar",
    "manáramos": "manar",
    "manárei": "manar",
    "manáreis": "manar",
    "manás": "maná",
    "manásseis": "manar",
    "manássemos": "manar",
    "manávamo": "manar",
    "manávamos": "manar",
    "manávei": "manar",
    "manáveis": "manar",
    "mançaneiras": "mançaneira",
    "mançanilhas": "mançanilha",
    "mançanilheiras": "mançanilheira",
    "mançupa": "upir",
    "mançupais": "mançupir",
    "mançupam": "upir",
    "mançupamo": "mançupir",
    "mançupamos": "mançupir",
    "mançupas": "mançupir",
    "mançupe": "upir",
    "mançupem": "mançupir",
    "mançupes": "mançupir",
    "mançupi": "upir",
    "mançupia": "upir",
    "mançupiam": "mançupir",
    "mançupias": "mançupir",
    "mançupida": "mançupir",
    "mançupidas": "mançupir",
    "mançupido": "mançupir",
    "mançupidos": "mançupir",
    "mançupimo": "mançupir",
    "mançupimos": "mançupir",
    "mançupindo": "mançupir",
    "mançupir": "upir",
    "mançupira": "upir",
    "mançupiram": "upir",
    "mançupiras": "mançupir",
    "mançupirde": "mançupir",
    "mançupirdes": "mançupir",
    "mançupire": "mançupir",
    "mançupirei": "mançupir",
    "mançupireis": "mançupir",
    "mançupirem": "upir",
    "mançupiremos": "mançupir",
    "mançupires": "mançupir",
    "mançupiria": "upir",
    "mançupiriam": "mançupir",
    "mançupirias": "mançupir",
    "mançupirmo": "mançupir",
    "mançupirmos": "mançupir",
    "mançupirá": "mançupir",
    "mançupirás": "mançupir",
    "mançupirão": "mançupir",
    "mançupiríamos": "mançupir",
    "mançupiríeis": "mançupir",
    "mançupis": "mançupir",
    "mançupisse": "upir",
    "mançupissem": "mançupir",
    "mançupisses": "mançupir",
    "mançupiste": "mançupir",
    "mançupistes": "mançupir",
    "mançupiu": "mançupir",
    "mançupo": "mançupir",
    "mançupíamo": "mançupir",
    "mançupíamos": "mançupir",
    "mançupíei": "mançupir",
    "mançupíeis": "mançupir",
    "mançupíramo": "mançupir",
    "mançupíramos": "mançupir",
    "mançupírei": "mançupir",
    "mançupíreis": "mançupir",
    "mançupísseis": "mançupir",
    "mançupíssemos": "mançupir",
    "manés": "mané",
    "maníaca": "maníaco",
    "maníacas": "maníaco",
    "maníacos": "maníaco",
    "maníamo": "manir",
    "maníamos": "manir",
    "maníei": "manir",
    "maníeis": "manir",
    "manípulas": "manípula",
    "manípulos": "manípulo",
    "maníramo": "manir",
    "maníramos": "manir",
    "manírei": "manir",
    "maníreis": "manir",
    "manísseis": "manir",
    "maníssemos": "manir",
    "manística": "manístico",
    "manísticas": "manístico",
    "manísticos": "manístico",
    "manómetros": "manómetro",
    "manóstatos": "manóstato",
    "manúbrios": "manúbrio",
    "maoismos": "maoismo",
    "maoistas": "maoista",
    "maometana": "maometano",
    "maometanas": "maometano",
    "maometanismos": "maometanismo",
    "maometaniza": "maometanizar",
    "maometanizada": "maometanizar",
    "maometanizadas": "maometanizar",
    "maometanizado": "maometanizar",
    "maometanizados": "maometanizar",
    "maometanizai": "maometanizar",
    "maometanizais": "maometanizar",
    "maometanizam": "maometanizar",
    "maometanizamo": "maometanizar",
    "maometanizamos": "maometanizar",
    "maometanizando": "maometanizar",
    "maometanizara": "maometanizar",
    "maometanizaram": "maometanizar",
    "maometanizaras": "maometanizar",
    "maometanizarde": "maometanizar",
    "maometanizardes": "maometanizar",
    "maometanizare": "maometanizar",
    "maometanizarei": "maometanizar",
    "maometanizareis": "maometanizar",
    "maometanizarem": "maometanizar",
    "maometanizaremos": "maometanizar",
    "maometanizares": "maometanizar",
    "maometanizaria": "maometanizar",
    "maometanizariam": "maometanizar",
    "maometanizarias": "maometanizar",
    "maometanizarmo": "maometanizar",
    "maometanizarmos": "maometanizar",
    "maometanizará": "maometanizar",
    "maometanizarás": "maometanizar",
    "maometanizarão": "maometanizar",
    "maometanizaríamos": "maometanizar",
    "maometanizaríeis": "maometanizar",
    "maometanizas": "maometanizar",
    "maometanizasse": "maometanizar",
    "maometanizassem": "maometanizar",
    "maometanizasses": "maometanizar",
    "maometanizaste": "maometanizar",
    "maometanizastes": "maometanizar",
    "maometanizava": "maometanizar",
    "maometanizavam": "maometanizar",
    "maometanizavas": "maometanizar",
    "maometanize": "maometanizar",
    "maometanizei": "maometanizar",
    "maometanizeis": "maometanizar",
    "maometanizem": "maometanizar",
    "maometanizemo": "maometanizar",
    "maometanizemos": "maometanizar",
    "maometanizes": "maometanizar",
    "maometanizo": "maometanizar",
    "maometanizou": "maometanizar",
    "maometanizá": "maometanizar",
    "maometanizámo": "maometanizar",
    "maometanizámos": "maometanizar",
    "maometanizáramo": "maometanizar",
    "maometanizáramos": "maometanizar",
    "maometanizárei": "maometanizar",
    "maometanizáreis": "maometanizar",
    "maometanizásseis": "maometanizar",
    "maometanizássemos": "maometanizar",
    "maometanizávamo": "maometanizar",
    "maometanizávamos": "maometanizar",
    "maometanizávei": "maometanizar",
    "maometanizáveis": "maometanizável",
    "maometanos": "maometano",
    "maometas": "maometa",
    "maometismos": "maometismo",
    "maoris": "maori",
    "maoístas": "maoísta",
    "mapas": "mapa",
    "mapeamentos": "mapeamento",
    "mapilas": "mapila",
    "mapiras": "mapira",
    "mapirungas": "mapirunga",
    "mapoões": "mapoão",
    "maputenses": "maputense",
    "maqueira": "maqueiro",
    "maqueiras": "maqueiro",
    "maqueiros": "maqueiro",
    "maques": "maque",
    "maquetas": "maqueta",
    "maquetes": "maquete",
    "maquetistas": "maquetista",
    "maquia": "maquiar",
    "maquiada": "maquiar",
    "maquiadas": "maquiar",
    "maquiado": "maquiar",
    "maquiadora": "maquiador",
    "maquiadoras": "maquiador",
    "maquiadores": "maquiador",
    "maquiados": "maquiar",
    "maquiaduras": "maquiadura",
    "maquiagens": "maquiagem",
    "maquiai": "maquiar",
    "maquiais": "maquiar",
    "maquiam": "maquiar",
    "maquiamo": "maquiar",
    "maquiamos": "maquiar",
    "maquiando": "maquiar",
    "maquiara": "maquiar",
    "maquiaram": "maquiar",
    "maquiaras": "maquiar",
    "maquiarde": "maquiar",
    "maquiardes": "maquiar",
    "maquiare": "maquiar",
    "maquiarei": "maquiar",
    "maquiareis": "maquiar",
    "maquiarem": "maquiar",
    "maquiaremos": "maquiar",
    "maquiares": "maquiar",
    "maquiaria": "maquiar",
    "maquiariam": "maquiar",
    "maquiarias": "maquiar",
    "maquiarmo": "maquiar",
    "maquiarmos": "maquiar",
    "maquiará": "maquiar",
    "maquiarás": "maquiar",
    "maquiarão": "maquiar",
    "maquiaríamos": "maquiar",
    "maquiaríeis": "maquiar",
    "maquias": "maquiar",
    "maquiasse": "maquiar",
    "maquiassem": "maquiar",
    "maquiasses": "maquiar",
    "maquiaste": "maquiar",
    "maquiastes": "maquiar",
    "maquiava": "maquiar",
    "maquiavam": "maquiar",
    "maquiavas": "maquiar",
    "maquiavelices": "maquiavelice",
    "maquiavelismos": "maquiavelismo",
    "maquiavelistas": "maquiavelista",
    "maquiaveliza": "maquiavelizar",
    "maquiavelizada": "maquiavelizar",
    "maquiavelizadas": "maquiavelizar",
    "maquiavelizado": "maquiavelizar",
    "maquiavelizados": "maquiavelizar",
    "maquiavelizai": "maquiavelizar",
    "maquiavelizais": "maquiavelizar",
    "maquiavelizam": "maquiavelizar",
    "maquiavelizamo": "maquiavelizar",
    "maquiavelizamos": "maquiavelizar",
    "maquiavelizando": "maquiavelizar",
    "maquiavelizara": "maquiavelizar",
    "maquiavelizaram": "maquiavelizar",
    "maquiavelizaras": "maquiavelizar",
    "maquiavelizardes": "maquiavelizar",
    "maquiavelizarei": "maquiavelizar",
    "maquiavelizareis": "maquiavelizar",
    "maquiavelizarem": "maquiavelizar",
    "maquiavelizaremos": "maquiavelizar",
    "maquiavelizares": "maquiavelizar",
    "maquiavelizaria": "maquiavelizar",
    "maquiavelizariam": "maquiavelizar",
    "maquiavelizarias": "maquiavelizar",
    "maquiavelizarmo": "maquiavelizar",
    "maquiavelizarmos": "maquiavelizar",
    "maquiavelizará": "maquiavelizar",
    "maquiavelizarás": "maquiavelizar",
    "maquiavelizarão": "maquiavelizar",
    "maquiavelizaríamos": "maquiavelizar",
    "maquiavelizaríeis": "maquiavelizar",
    "maquiavelizas": "maquiavelizar",
    "maquiavelizasse": "maquiavelizar",
    "maquiavelizassem": "maquiavelizar",
    "maquiavelizasses": "maquiavelizar",
    "maquiavelizaste": "maquiavelizar",
    "maquiavelizastes": "maquiavelizar",
    "maquiavelizava": "maquiavelizar",
    "maquiavelizavam": "maquiavelizar",
    "maquiavelizavas": "maquiavelizar",
    "maquiavelize": "maquiavelizar",
    "maquiavelizei": "maquiavelizar",
    "maquiavelizeis": "maquiavelizar",
    "maquiavelizem": "maquiavelizar",
    "maquiavelizemo": "maquiavelizar",
    "maquiavelizemos": "maquiavelizar",
    "maquiavelizes": "maquiavelizar",
    "maquiavelizo": "maquiavelizar",
    "maquiavelizou": "maquiavelizar",
    "maquiavelizámo": "maquiavelizar",
    "maquiavelizámos": "maquiavelizar",
    "maquiavelizáramo": "maquiavelizar",
    "maquiavelizáramos": "maquiavelizar",
    "maquiavelizáreis": "maquiavelizar",
    "maquiavelizásseis": "maquiavelizar",
    "maquiavelizássemos": "maquiavelizar",
    "maquiavelizávamo": "maquiavelizar",
    "maquiavelizávamos": "maquiavelizar",
    "maquiavelizáveis": "maquiavelizar",
    "maquiavélica": "maquiavélico",
    "maquiavélicas": "maquiavélico",
    "maquiavélicos": "maquiavélico",
    "maquiduns": "maquidum",
    "maquiduras": "maquidura",
    "maquie": "maquiar",
    "maquiei": "maquiar",
    "maquieiros": "maquieiro",
    "maquieis": "maquiar",
    "maquiem": "maquiar",
    "maquiemo": "maquiar",
    "maquiemos": "maquiar",
    "maquies": "maquiar",
    "maquietas": "maquieta",
    "maquilha": "maquilhar",
    "maquilhada": "maquilhar",
    "maquilhadas": "maquilhar",
    "maquilhado": "maquilhar",
    "maquilhadora": "maquilhador",
    "maquilhadoras": "maquilhador",
    "maquilhadores": "maquilhador",
    "maquilhados": "maquilhar",
    "maquilhadíssima": "maquilhado",
    "maquilhadíssimas": "maquilhado",
    "maquilhadíssimo": "maquilhado",
    "maquilhadíssimos": "maquilhado",
    "maquilhagens": "maquilhagem",
    "maquilhai": "maquilhar",
    "maquilhais": "maquilhar",
    "maquilham": "maquilhar",
    "maquilhamo": "maquilhar",
    "maquilhamos": "maquilhar",
    "maquilhando": "maquilhar",
    "maquilhara": "maquilhar",
    "maquilharam": "maquilhar",
    "maquilharas": "maquilhar",
    "maquilharde": "maquilhar",
    "maquilhardes": "maquilhar",
    "maquilhare": "maquilhar",
    "maquilharei": "maquilhar",
    "maquilhareis": "maquilhar",
    "maquilharem": "maquilhar",
    "maquilharemos": "maquilhar",
    "maquilhares": "maquilhar",
    "maquilharia": "maquilhar",
    "maquilhariam": "maquilhar",
    "maquilharias": "maquilhar",
    "maquilharmo": "maquilhar",
    "maquilharmos": "maquilhar",
    "maquilhará": "maquilhar",
    "maquilharás": "maquilhar",
    "maquilharão": "maquilhar",
    "maquilharíamos": "maquilhar",
    "maquilharíeis": "maquilhar",
    "maquilhas": "maquilhar",
    "maquilhasse": "maquilhar",
    "maquilhassem": "maquilhar",
    "maquilhasses": "maquilhar",
    "maquilhaste": "maquilhar",
    "maquilhastes": "maquilhar",
    "maquilhava": "maquilhar",
    "maquilhavam": "maquilhar",
    "maquilhavas": "maquilhar",
    "maquilhe": "maquilhar",
    "maquilhei": "maquilhar",
    "maquilheis": "maquilhar",
    "maquilhem": "maquilhar",
    "maquilhemo": "maquilhar",
    "maquilhemos": "maquilhar",
    "maquilhes": "maquilhar",
    "maquilho": "maquilhar",
    "maquilhou": "maquilhar",
    "maquilhá": "maquilhar",
    "maquilhámo": "maquilhar",
    "maquilhámos": "maquilhar",
    "maquilháramo": "maquilhar",
    "maquilháramos": "maquilhar",
    "maquilhárei": "maquilhar",
    "maquilháreis": "maquilhar",
    "maquilhásseis": "maquilhar",
    "maquilhássemos": "maquilhar",
    "maquilhávamo": "maquilhar",
    "maquilhávamos": "maquilhar",
    "maquilhávei": "maquilhar",
    "maquilháveis": "maquilhar",
    "maquilona": "maquilão",
    "maquilonas": "maquilão",
    "maquilões": "maquilão",
    "maquimonos": "maquimono",
    "maquina": "maquinar",
    "maquinada": "maquinar",
    "maquinadas": "maquinar",
    "maquinado": "maquinar",
    "maquinadora": "maquinador",
    "maquinadoras": "maquinador",
    "maquinadores": "maquinador",
    "maquinados": "maquinar",
    "maquinai": "maquinar",
    "maquinais": "maquinar",
    "maquinam": "maquinar",
    "maquinamo": "maquinar",
    "maquinamos": "maquinar",
    "maquinando": "maquinar",
    "maquinara": "maquinar",
    "maquinaram": "maquinar",
    "maquinaras": "maquinar",
    "maquinarde": "maquinar",
    "maquinardes": "maquinar",
    "maquinare": "maquinar",
    "maquinarei": "maquinar",
    "maquinareis": "maquinar",
    "maquinarem": "maquinar",
    "maquinaremos": "maquinar",
    "maquinares": "maquinar",
    "maquinaria": "maquinar",
    "maquinariam": "maquinar",
    "maquinarias": "maquinaria",
    "maquinarmo": "maquinar",
    "maquinarmos": "maquinar",
    "maquinará": "maquinar",
    "maquinarás": "maquinar",
    "maquinarão": "maquinar",
    "maquinaríamos": "maquinar",
    "maquinaríeis": "maquinar",
    "maquinas": "maquinar",
    "maquinasse": "maquinar",
    "maquinassem": "maquinar",
    "maquinasses": "maquinar",
    "maquinaste": "maquinar",
    "maquinastes": "maquinar",
    "maquinava": "maquinar",
    "maquinavam": "maquinar",
    "maquinavas": "maquinar",
    "maquinações": "maquinação",
    "maquine": "maquinar",
    "maquinei": "maquinar",
    "maquineis": "maquinar",
    "maquinem": "maquinar",
    "maquinemo": "maquinar",
    "maquinemos": "maquinar",
    "maquines": "maquinar",
    "maquinetas": "maquineta",
    "maquinismos": "maquinismo",
    "maquinistas": "maquinista",
    "maquino": "maquinar",
    "maquinou": "maquinar",
    "maquiná": "maquinar",
    "maquinámo": "maquinar",
    "maquinámos": "maquinar",
    "maquináramo": "maquinar",
    "maquináramos": "maquinar",
    "maquinárei": "maquinar",
    "maquináreis": "maquinar",
    "maquinásseis": "maquinar",
    "maquinássemos": "maquinar",
    "maquinávamo": "maquinar",
    "maquinávamos": "maquinar",
    "maquinávei": "maquinar",
    "maquináveis": "maquinável",
    "maquio": "maquiar",
    "maquiou": "maquiar",
    "maquis": "maqui",
    "maquiá": "maquiar",
    "maquiámo": "maquiar",
    "maquiámos": "maquiar",
    "maquiáramo": "maquiar",
    "maquiáramos": "maquiar",
    "maquiárei": "maquiar",
    "maquiáreis": "maquiar",
    "maquiásseis": "maquiar",
    "maquiássemos": "maquiar",
    "maquiávamo": "maquiar",
    "maquiávamos": "maquiar",
    "maquiávei": "maquiar",
    "maquiáveis": "maquiar",
    "marabumbos": "marabumbo",
    "marabus": "marabu",
    "marabutos": "marabuto",
    "maracachões": "maracachão",
    "maracajás": "maracajá",
    "maracanás": "maracaná",
    "maracanãs": "maracanã",
    "maracatins": "maracatim",
    "marachas": "maracha",
    "marachombas": "marachomba",
    "marachões": "marachão",
    "maracoteiros": "maracoteiro",
    "maracotões": "maracotão",
    "maracujazeiros": "maracujazeiro",
    "maracujás": "maracujá",
    "maracutas": "maracuta",
    "maracás": "maracá",
    "marada": "marado",
    "maradas": "marado",
    "marados": "marado",
    "marafada": "marafado",
    "marafadas": "marafado",
    "marafados": "marafado",
    "marafonas": "marafona",
    "marafoneada": "marafonear",
    "marafoneadas": "marafonear",
    "marafoneado": "marafonear",
    "marafoneados": "marafonear",
    "marafoneai": "marafonear",
    "marafoneais": "marafonear",
    "marafoneamo": "marafonear",
    "marafoneamos": "marafonear",
    "marafoneando": "marafonear",
    "marafoneara": "marafonear",
    "marafonearam": "marafonear",
    "marafonearas": "marafonear",
    "marafoneardes": "marafonear",
    "marafonearei": "marafonear",
    "marafoneareis": "marafonear",
    "marafonearem": "marafonear",
    "marafonearemos": "marafonear",
    "marafoneares": "marafonear",
    "marafonearia": "marafonear",
    "marafoneariam": "marafonear",
    "marafonearias": "marafonear",
    "marafonearmo": "marafonear",
    "marafonearmos": "marafonear",
    "marafoneará": "marafonear",
    "marafonearás": "marafonear",
    "marafonearão": "marafonear",
    "marafonearíamos": "marafonear",
    "marafonearíeis": "marafonear",
    "marafoneasse": "marafonear",
    "marafoneassem": "marafonear",
    "marafoneasses": "marafonear",
    "marafoneaste": "marafonear",
    "marafoneastes": "marafonear",
    "marafoneava": "marafonear",
    "marafoneavam": "marafonear",
    "marafoneavas": "marafonear",
    "marafoneei": "marafonear",
    "marafoneeis": "marafonear",
    "marafoneemo": "marafonear",
    "marafoneemos": "marafonear",
    "marafoneia": "marafonear",
    "marafoneiam": "marafonear",
    "marafoneias": "marafonear",
    "marafoneie": "marafonear",
    "marafoneiem": "marafonear",
    "marafoneies": "marafonear",
    "marafoneio": "marafonear",
    "marafoneira": "marafoneiro",
    "marafoneiras": "marafoneiro",
    "marafoneiros": "marafoneiro",
    "marafoneou": "marafonear",
    "marafoneámo": "marafonear",
    "marafoneámos": "marafonear",
    "marafoneáramo": "marafonear",
    "marafoneáramos": "marafonear",
    "marafoneáreis": "marafonear",
    "marafoneásseis": "marafonear",
    "marafoneássemos": "marafonear",
    "marafoneávamo": "marafonear",
    "marafoneávamos": "marafonear",
    "marafoneáveis": "marafonear",
    "maragotas": "maragota",
    "marajás": "marajá",
    "maralhais": "maralhal",
    "maranduvas": "maranduva",
    "maranha": "maranhar",
    "maranhada": "maranhar",
    "maranhadas": "maranhar",
    "maranhado": "maranhar",
    "maranhados": "maranhar",
    "maranhai": "maranhar",
    "maranhais": "maranhar",
    "maranham": "maranhar",
    "maranhamo": "maranhar",
    "maranhamos": "maranhar",
    "maranhando": "maranhar",
    "maranhara": "maranhar",
    "maranharam": "maranhar",
    "maranharas": "maranhar",
    "maranharde": "maranhar",
    "maranhardes": "maranhar",
    "maranhare": "maranhar",
    "maranharei": "maranhar",
    "maranhareis": "maranhar",
    "maranharem": "maranhar",
    "maranharemos": "maranhar",
    "maranhares": "maranhar",
    "maranharia": "maranhar",
    "maranhariam": "maranhar",
    "maranharias": "maranhar",
    "maranharmo": "maranhar",
    "maranharmos": "maranhar",
    "maranhará": "maranhar",
    "maranharás": "maranhar",
    "maranharão": "maranhar",
    "maranharíamos": "maranhar",
    "maranharíeis": "maranhar",
    "maranhas": "maranhar",
    "maranhasse": "maranhar",
    "maranhassem": "maranhar",
    "maranhasses": "maranhar",
    "maranhaste": "maranhar",
    "maranhastes": "maranhar",
    "maranhava": "maranhar",
    "maranhavam": "maranhar",
    "maranhavas": "maranhar",
    "maranhe": "maranhar",
    "maranhei": "maranhar",
    "maranheis": "maranhar",
    "maranhem": "maranhar",
    "maranhemo": "maranhar",
    "maranhemos": "maranhar",
    "maranhenses": "maranhense",
    "maranhes": "maranhar",
    "maranho": "maranhar",
    "maranhonas": "maranhona",
    "maranhos": "maranho",
    "maranhosa": "maranhoso",
    "maranhosas": "maranhoso",
    "maranhosos": "maranhoso",
    "maranhou": "maranhar",
    "maranhá": "maranhar",
    "maranhámo": "maranhar",
    "maranhámos": "maranhar",
    "maranháramo": "maranhar",
    "maranháramos": "maranhar",
    "maranhárei": "maranhar",
    "maranháreis": "maranhar",
    "maranhásseis": "maranhar",
    "maranhássemos": "maranhar",
    "maranhávamo": "maranhar",
    "maranhávamos": "maranhar",
    "maranhávei": "maranhar",
    "maranháveis": "maranhar",
    "maranhões": "maranhão",
    "maranis": "marani",
    "marantas": "maranta",
    "marantáceas": "marantácea",
    "marantéus": "marantéu",
    "mararilhas": "mararilha",
    "marascas": "marasca",
    "marasma": "marasmar",
    "marasmada": "marasmar",
    "marasmadas": "marasmar",
    "marasmado": "marasmar",
    "marasmados": "marasmar",
    "marasmai": "marasmar",
    "marasmais": "marasmar",
    "marasmam": "marasmar",
    "marasmamo": "marasmar",
    "marasmamos": "marasmar",
    "marasmando": "marasmar",
    "marasmara": "marasmar",
    "marasmaram": "marasmar",
    "marasmaras": "marasmar",
    "marasmarde": "marasmar",
    "marasmardes": "marasmar",
    "marasmare": "marasmar",
    "marasmarei": "marasmar",
    "marasmareis": "marasmar",
    "marasmarem": "marasmar",
    "marasmaremos": "marasmar",
    "marasmares": "marasmar",
    "marasmaria": "marasmar",
    "marasmariam": "marasmar",
    "marasmarias": "marasmar",
    "marasmarmo": "marasmar",
    "marasmarmos": "marasmar",
    "marasmará": "marasmar",
    "marasmarás": "marasmar",
    "marasmarão": "marasmar",
    "marasmaríamos": "marasmar",
    "marasmaríeis": "marasmar",
    "marasmas": "marasmar",
    "marasmasse": "marasmar",
    "marasmassem": "marasmar",
    "marasmasses": "marasmar",
    "marasmaste": "marasmar",
    "marasmastes": "marasmar",
    "marasmava": "marasmar",
    "marasmavam": "marasmar",
    "marasmavas": "marasmar",
    "marasme": "marasmar",
    "marasmei": "marasmar",
    "marasmeis": "marasmar",
    "marasmem": "marasmar",
    "marasmemo": "marasmar",
    "marasmemos": "marasmar",
    "marasmes": "marasmar",
    "marasmo": "marasmar",
    "marasmos": "marasmo",
    "marasmou": "marasmar",
    "marasmá": "marasmar",
    "marasmámo": "marasmar",
    "marasmámos": "marasmar",
    "marasmáramo": "marasmar",
    "marasmáramos": "marasmar",
    "marasmárei": "marasmar",
    "marasmáreis": "marasmar",
    "marasmásseis": "marasmar",
    "marasmássemos": "marasmar",
    "marasmática": "marasmático",
    "marasmáticas": "marasmático",
    "marasmáticos": "marasmático",
    "marasmávamo": "marasmar",
    "marasmávamos": "marasmar",
    "marasmávei": "marasmar",
    "marasmáveis": "marasmar",
    "marasmódica": "marasmódico",
    "marasmódicas": "marasmódico",
    "marasmódicos": "marasmódico",
    "marasquinos": "marasquino",
    "maratas": "marata",
    "maratonas": "maratona",
    "maratonistas": "maratonista",
    "maratros": "maratro",
    "maraus": "marau",
    "maravedil": "maravedi",
    "maravedis": "maravedi",
    "maravilha": "maravilhar",
    "maravilhada": "maravilhar",
    "maravilhadas": "maravilhar",
    "maravilhado": "maravilhar",
    "maravilhadora": "maravilhador",
    "maravilhadoras": "maravilhador",
    "maravilhadores": "maravilhador",
    "maravilhados": "maravilhar",
    "maravilhai": "maravilhar",
    "maravilhais": "maravilhar",
    "maravilham": "maravilhar",
    "maravilhamo": "maravilhar",
    "maravilhamos": "maravilhar",
    "maravilhando": "maravilhar",
    "maravilhara": "maravilhar",
    "maravilharam": "maravilhar",
    "maravilharas": "maravilhar",
    "maravilharde": "maravilhar",
    "maravilhardes": "maravilhar",
    "maravilhare": "maravilhar",
    "maravilharei": "maravilhar",
    "maravilhareis": "maravilhar",
    "maravilharem": "maravilhar",
    "maravilharemos": "maravilhar",
    "maravilhares": "maravilhar",
    "maravilharia": "maravilhar",
    "maravilhariam": "maravilhar",
    "maravilharias": "maravilhar",
    "maravilharmo": "maravilhar",
    "maravilharmos": "maravilhar",
    "maravilhará": "maravilhar",
    "maravilharás": "maravilhar",
    "maravilharão": "maravilhar",
    "maravilharíamos": "maravilhar",
    "maravilharíeis": "maravilhar",
    "maravilhas": "maravilhar",
    "maravilhasse": "maravilhar",
    "maravilhassem": "maravilhar",
    "maravilhasses": "maravilhar",
    "maravilhaste": "maravilhar",
    "maravilhastes": "maravilhar",
    "maravilhava": "maravilhar",
    "maravilhavam": "maravilhar",
    "maravilhavas": "maravilhar",
    "maravilhazinha": "maravilha",
    "maravilhazinhas": "maravilha",
    "maravilhazita": "maravilha",
    "maravilhazitas": "maravilha",
    "maravilhe": "maravilhar",
    "maravilhei": "maravilhar",
    "maravilheis": "maravilhar",
    "maravilhem": "maravilhar",
    "maravilhemo": "maravilhar",
    "maravilhemos": "maravilhar",
    "maravilhes": "maravilhar",
    "maravilho": "maravilhar",
    "maravilhosa": "maravilhoso",
    "maravilhosas": "maravilhoso",
    "maravilhosos": "maravilhoso",
    "maravilhou": "maravilhar",
    "maravilhá": "maravilhar",
    "maravilhámo": "maravilhar",
    "maravilhámos": "maravilhar",
    "maravilháramo": "maravilhar",
    "maravilháramos": "maravilhar",
    "maravilhárei": "maravilhar",
    "maravilháreis": "maravilhar",
    "maravilhásseis": "maravilhar",
    "maravilhássemos": "maravilhar",
    "maravilhávamo": "maravilhar",
    "maravilhávamos": "maravilhar",
    "maravilhávei": "maravilhar",
    "maravilháveis": "maravilhar",
    "maravinhas": "maravinha",
    "marca": "marcar",
    "marcada": "marcar",
    "marcadas": "marcar",
    "marcadinha": "marcado",
    "marcadinhas": "marcado",
    "marcadinho": "marcado",
    "marcadinhos": "marcado",
    "marcadita": "marcado",
    "marcaditas": "marcado",
    "marcadito": "marcado",
    "marcaditos": "marcado",
    "marcado": "marcar",
    "marcadoira": "marcadoiro",
    "marcadoiras": "marcadoiro",
    "marcadoiros": "marcadoiro",
    "marcadora": "marcador",
    "marcadoras": "marcador",
    "marcadores": "marcador",
    "marcados": "marcar",
    "marcadoura": "marcadouro",
    "marcadouras": "marcadouro",
    "marcadouros": "marcadouro",
    "marcadíssima": "marcado",
    "marcadíssimas": "marcado",
    "marcadíssimo": "marcado",
    "marcadíssimos": "marcado",
    "marcai": "marcar",
    "marcais": "marcar",
    "marcam": "marcar",
    "marcamo": "marcar",
    "marcamos": "marcar",
    "marcando": "marcar",
    "marcantes": "marcante",
    "marcara": "marcar",
    "marcaram": "marcar",
    "marcaras": "marcar",
    "marcarde": "marcar",
    "marcardes": "marcar",
    "marcare": "marcar",
    "marcarei": "marcar",
    "marcareis": "marcar",
    "marcarem": "marcar",
    "marcaremos": "marcar",
    "marcares": "marcar",
    "marcaria": "marcar",
    "marcariam": "marcar",
    "marcarias": "marcar",
    "marcarmo": "marcar",
    "marcarmos": "marcar",
    "marcará": "marcar",
    "marcarás": "marcar",
    "marcarão": "marcar",
    "marcaríamos": "marcar",
    "marcaríeis": "marcar",
    "marcas": "marcar",
    "marcasse": "marcar",
    "marcassem": "marcar",
    "marcasses": "marcar",
    "marcassitas": "marcassita",
    "marcassites": "marcassite",
    "marcaste": "marcar",
    "marcastes": "marcar",
    "marcava": "marcar",
    "marcavalas": "marcavala",
    "marcavam": "marcar",
    "marcavas": "marcar",
    "marcações": "marcação",
    "marcelas": "marcela",
    "marcelina": "marcelino",
    "marcelinas": "marcelino",
    "marcelinos": "marcelino",
    "marcelistas": "marcelista",
    "marcenarias": "marcenaria",
    "marceneira": "marceneiro",
    "marceneirada": "marceneirar",
    "marceneiradas": "marceneirar",
    "marceneirado": "marceneirar",
    "marceneirados": "marceneirar",
    "marceneirai": "marceneirar",
    "marceneirais": "marceneirar",
    "marceneiram": "marceneirar",
    "marceneiramo": "marceneirar",
    "marceneiramos": "marceneirar",
    "marceneirando": "marceneirar",
    "marceneirara": "marceneirar",
    "marceneiraram": "marceneirar",
    "marceneiraras": "marceneirar",
    "marceneirardes": "marceneirar",
    "marceneirarei": "marceneirar",
    "marceneirareis": "marceneirar",
    "marceneirarem": "marceneirar",
    "marceneiraremos": "marceneirar",
    "marceneirares": "marceneirar",
    "marceneiraria": "marceneirar",
    "marceneirariam": "marceneirar",
    "marceneirarias": "marceneirar",
    "marceneirarmo": "marceneirar",
    "marceneirarmos": "marceneirar",
    "marceneirará": "marceneirar",
    "marceneirarás": "marceneirar",
    "marceneirarão": "marceneirar",
    "marceneiraríamos": "marceneirar",
    "marceneiraríeis": "marceneirar",
    "marceneiras": "marceneiro",
    "marceneirasse": "marceneirar",
    "marceneirassem": "marceneirar",
    "marceneirasses": "marceneirar",
    "marceneiraste": "marceneirar",
    "marceneirastes": "marceneirar",
    "marceneirava": "marceneirar",
    "marceneiravam": "marceneirar",
    "marceneiravas": "marceneirar",
    "marceneire": "marceneirar",
    "marceneirei": "marceneirar",
    "marceneireis": "marceneirar",
    "marceneirem": "marceneirar",
    "marceneiremo": "marceneirar",
    "marceneiremos": "marceneirar",
    "marceneires": "marceneirar",
    "marceneiro": "marceneirar",
    "marceneiros": "marceneiro",
    "marceneirou": "marceneirar",
    "marceneirámo": "marceneirar",
    "marceneirámos": "marceneirar",
    "marceneiráramo": "marceneirar",
    "marceneiráramos": "marceneirar",
    "marceneiráreis": "marceneirar",
    "marceneirásseis": "marceneirar",
    "marceneirássemos": "marceneirar",
    "marceneirávamo": "marceneirar",
    "marceneirávamos": "marceneirar",
    "marceneiráveis": "marceneirar",
    "marcescentes": "marcescente",
    "marcescências": "marcescência",
    "marcescíveis": "marcescível",
    "marcha": "marchar",
    "marchada": "marchar",
    "marchadas": "marchar",
    "marchado": "marchar",
    "marchadora": "marchador",
    "marchadoras": "marchador",
    "marchadores": "marchador",
    "marchados": "marchar",
    "marchai": "marchar",
    "marchais": "marchar",
    "marcham": "marchar",
    "marchamo": "marchar",
    "marchamos": "marchar",
    "marchando": "marchar",
    "marchantarias": "marchantaria",
    "marchantes": "marchante",
    "marchara": "marchar",
    "marcharam": "marchar",
    "marcharas": "marchar",
    "marchardes": "marchar",
    "marcharei": "marchar",
    "marchareis": "marchar",
    "marcharem": "marchar",
    "marcharemos": "marchar",
    "marchares": "marchar",
    "marcharia": "marchar",
    "marchariam": "marchar",
    "marcharias": "marchar",
    "marcharmo": "marchar",
    "marcharmos": "marchar",
    "marchará": "marchar",
    "marcharás": "marchar",
    "marcharão": "marchar",
    "marcharíamos": "marchar",
    "marcharíeis": "marchar",
    "marchas": "marchar",
    "marchasse": "marchar",
    "marchassem": "marchar",
    "marchasses": "marchar",
    "marchaste": "marchar",
    "marchastes": "marchar",
    "marchava": "marchar",
    "marchavam": "marchar",
    "marchavas": "marchar",
    "marche": "marchar",
    "marchei": "marchar",
    "marcheis": "marchar",
    "marchem": "marchar",
    "marchemo": "marchar",
    "marchemos": "marchar",
    "marches": "marchar",
    "marcheta": "marchetar",
    "marchetada": "marchetar",
    "marchetadas": "marchetar",
    "marchetado": "marchetar",
    "marchetados": "marchetar",
    "marchetai": "marchetar",
    "marchetais": "marchetar",
    "marchetam": "marchetar",
    "marchetamo": "marchetar",
    "marchetamos": "marchetar",
    "marchetando": "marchetar",
    "marchetara": "marchetar",
    "marchetaram": "marchetar",
    "marchetaras": "marchetar",
    "marchetarde": "marchetar",
    "marchetardes": "marchetar",
    "marchetare": "marchetar",
    "marchetarei": "marchetar",
    "marchetareis": "marchetar",
    "marchetarem": "marchetar",
    "marchetaremos": "marchetar",
    "marchetares": "marchetar",
    "marchetaria": "marchetar",
    "marchetariam": "marchetar",
    "marchetarias": "marchetaria",
    "marchetarmo": "marchetar",
    "marchetarmos": "marchetar",
    "marchetará": "marchetar",
    "marchetarás": "marchetar",
    "marchetarão": "marchetar",
    "marchetaríamos": "marchetar",
    "marchetaríeis": "marchetar",
    "marchetas": "marchetar",
    "marchetasse": "marchetar",
    "marchetassem": "marchetar",
    "marchetasses": "marchetar",
    "marchetaste": "marchetar",
    "marchetastes": "marchetar",
    "marchetava": "marchetar",
    "marchetavam": "marchetar",
    "marchetavas": "marchetar",
    "marchete": "marchetar",
    "marchetei": "marchetar",
    "marcheteira": "marcheteiro",
    "marcheteiras": "marcheteiro",
    "marcheteiros": "marcheteiro",
    "marcheteis": "marchetar",
    "marchetem": "marchetar",
    "marchetemo": "marchetar",
    "marchetemos": "marchetar",
    "marchetes": "marchete",
    "marcheto": "marchetar",
    "marchetou": "marchetar",
    "marchetá": "marchetar",
    "marchetámo": "marchetar",
    "marchetámos": "marchetar",
    "marchetáramo": "marchetar",
    "marchetáramos": "marchetar",
    "marchetárei": "marchetar",
    "marchetáreis": "marchetar",
    "marchetásseis": "marchetar",
    "marchetássemos": "marchetar",
    "marchetávamo": "marchetar",
    "marchetávamos": "marchetar",
    "marchetávei": "marchetar",
    "marchetáveis": "marchetar",
    "marchinha": "marcha",
    "marchinhas": "marchinha",
    "marchita": "marcha",
    "marchitas": "marcha",
    "marcho": "marchar",
    "marchou": "marchar",
    "marchámo": "marchar",
    "marchámos": "marchar",
    "marcháramo": "marchar",
    "marcháramos": "marchar",
    "marcháreis": "marchar",
    "marchásseis": "marchar",
    "marchássemos": "marchar",
    "marchávamo": "marchar",
    "marchávamos": "marchar",
    "marcháveis": "marchar",
    "marciais": "marcial",
    "marcialidades": "marcialidade",
    "marciana": "marciano",
    "marcianas": "marciano",
    "marcianos": "marciano",
    "marciática": "marciático",
    "marciáticas": "marciático",
    "marciáticos": "marciático",
    "marco": "marcar",
    "marcofilias": "marcofilia",
    "marcomana": "marcomano",
    "marcomanas": "marcomano",
    "marcomanos": "marcomano",
    "marconigramas": "marconigrama",
    "marcos": "marco",
    "marcou": "marcar",
    "marcuenses": "marcuense",
    "marcá": "marcar",
    "marcámo": "marcar",
    "marcámos": "marcar",
    "marcáramo": "marcar",
    "marcáramos": "marcar",
    "marcárei": "marcar",
    "marcáreis": "marcar",
    "marcásseis": "marcar",
    "marcássemos": "marcar",
    "marcávamo": "marcar",
    "marcávamos": "marcar",
    "marcávei": "marcar",
    "marcáveis": "marcável",
    "mareada": "marear",
    "mareadas": "marear",
    "mareado": "marear",
    "mareados": "marear",
    "mareagens": "mareagem",
    "mareai": "marear",
    "mareais": "marear",
    "mareamo": "marear",
    "mareamos": "marear",
    "mareando": "marear",
    "mareantes": "mareante",
    "mareara": "marear",
    "marearam": "marear",
    "marearas": "marear",
    "marearde": "marear",
    "mareardes": "marear",
    "mareare": "marear",
    "marearei": "marear",
    "mareareis": "marear",
    "marearem": "marear",
    "marearemos": "marear",
    "mareares": "marear",
    "marearia": "marear",
    "mareariam": "marear",
    "marearias": "marear",
    "marearmo": "marear",
    "marearmos": "marear",
    "mareará": "marear",
    "marearás": "marear",
    "marearão": "marear",
    "marearíamos": "marear",
    "marearíeis": "marear",
    "mareasse": "marear",
    "mareassem": "marear",
    "mareasses": "marear",
    "mareaste": "marear",
    "mareastes": "marear",
    "mareava": "marear",
    "mareavam": "marear",
    "mareavas": "marear",
    "mareações": "mareação",
    "marechais": "marechal",
    "marechala": "marechal",
    "marechalados": "marechalado",
    "marechalas": "marechal",
    "marechalatos": "marechalato",
    "mareei": "marear",
    "mareeis": "marear",
    "mareemo": "marear",
    "mareemos": "marear",
    "maregrafistas": "maregrafista",
    "maregramas": "maregrama",
    "mareia": "marear",
    "mareiam": "marear",
    "mareias": "marear",
    "mareie": "marear",
    "mareiem": "marear",
    "mareies": "marear",
    "mareio": "marear",
    "mareira": "mareiro",
    "mareiras": "mareiro",
    "mareiros": "mareiro",
    "mareja": "marejar",
    "marejada": "marejar",
    "marejadas": "marejar",
    "marejado": "marejar",
    "marejados": "marejar",
    "marejai": "marejar",
    "marejais": "marejar",
    "marejam": "marejar",
    "marejamo": "marejar",
    "marejamos": "marejar",
    "marejando": "marejar",
    "marejara": "marejar",
    "marejaram": "marejar",
    "marejaras": "marejar",
    "marejardes": "marejar",
    "marejarei": "marejar",
    "marejareis": "marejar",
    "marejarem": "marejar",
    "marejaremos": "marejar",
    "marejares": "marejar",
    "marejaria": "marejar",
    "marejariam": "marejar",
    "marejarias": "marejar",
    "marejarmo": "marejar",
    "marejarmos": "marejar",
    "marejará": "marejar",
    "marejarás": "marejar",
    "marejarão": "marejar",
    "marejaríamos": "marejar",
    "marejaríeis": "marejar",
    "marejas": "marejar",
    "marejasse": "marejar",
    "marejassem": "marejar",
    "marejasses": "marejar",
    "marejaste": "marejar",
    "marejastes": "marejar",
    "marejava": "marejar",
    "marejavam": "marejar",
    "marejavas": "marejar",
    "mareje": "marejar",
    "marejei": "marejar",
    "marejeis": "marejar",
    "marejem": "marejar",
    "marejemo": "marejar",
    "marejemos": "marejar",
    "marejes": "marejar",
    "marejo": "marejar",
    "marejou": "marejar",
    "marejámo": "marejar",
    "marejámos": "marejar",
    "marejáramo": "marejar",
    "marejáramos": "marejar",
    "marejáreis": "marejar",
    "marejásseis": "marejar",
    "marejássemos": "marejar",
    "marejávamo": "marejar",
    "marejávamos": "marejar",
    "marejáveis": "marejar",
    "marelantes": "marelante",
    "marelões": "marelão",
    "maremas": "marema",
    "maremotos": "maremoto",
    "maremática": "maremático",
    "maremáticas": "maremático",
    "maremáticos": "maremático",
    "mareografistas": "mareografista",
    "mareogramas": "mareograma",
    "mareoramas": "mareorama",
    "mareou": "marear",
    "mares": "mar",
    "maresias": "maresia",
    "maretas": "mareta",
    "mareá": "marear",
    "mareámo": "marear",
    "mareámos": "marear",
    "mareáramo": "marear",
    "mareáramos": "marear",
    "mareárei": "marear",
    "mareáreis": "marear",
    "mareásseis": "marear",
    "mareássemos": "marear",
    "mareávamo": "marear",
    "mareávamos": "marear",
    "mareávei": "marear",
    "mareáveis": "marear",
    "mareógrafos": "mareógrafo",
    "mareómetros": "mareómetro",
    "marfa": "marfar",
    "marfada": "marfar",
    "marfadas": "marfar",
    "marfado": "marfar",
    "marfados": "marfar",
    "marfai": "marfar",
    "marfais": "marfar",
    "marfam": "marfar",
    "marfamo": "marfar",
    "marfamos": "marfar",
    "marfando": "marfar",
    "marfara": "marfar",
    "marfaram": "marfar",
    "marfaras": "marfar",
    "marfarde": "marfar",
    "marfardes": "marfar",
    "marfare": "marfar",
    "marfarei": "marfar",
    "marfareis": "marfar",
    "marfarem": "marfar",
    "marfaremos": "marfar",
    "marfares": "marfar",
    "marfaria": "marfar",
    "marfariam": "marfar",
    "marfarias": "marfar",
    "marfarmo": "marfar",
    "marfarmos": "marfar",
    "marfará": "marfar",
    "marfarás": "marfar",
    "marfarão": "marfar",
    "marfaríamos": "marfar",
    "marfaríeis": "marfar",
    "marfas": "marfar",
    "marfasse": "marfar",
    "marfassem": "marfar",
    "marfasses": "marfar",
    "marfaste": "marfar",
    "marfastes": "marfar",
    "marfava": "marfar",
    "marfavam": "marfar",
    "marfavas": "marfar",
    "marfe": "marfar",
    "marfei": "marfar",
    "marfeis": "marfar",
    "marfem": "marfar",
    "marfemo": "marfar",
    "marfemos": "marfar",
    "marfes": "marfar",
    "marfinosa": "marfinoso",
    "marfinosas": "marfinoso",
    "marfinosos": "marfinoso",
    "marfins": "marfim",
    "marfo": "marfar",
    "marfolha": "marfolhar",
    "marfolhada": "marfolhar",
    "marfolhadas": "marfolhar",
    "marfolhado": "marfolhar",
    "marfolhados": "marfolhar",
    "marfolhai": "marfolhar",
    "marfolhais": "marfolhar",
    "marfolham": "marfolhar",
    "marfolhamo": "marfolhar",
    "marfolhamos": "marfolhar",
    "marfolhando": "marfolhar",
    "marfolhara": "marfolhar",
    "marfolharam": "marfolhar",
    "marfolharas": "marfolhar",
    "marfolhardes": "marfolhar",
    "marfolharei": "marfolhar",
    "marfolhareis": "marfolhar",
    "marfolharem": "marfolhar",
    "marfolharemos": "marfolhar",
    "marfolhares": "marfolhar",
    "marfolharia": "marfolhar",
    "marfolhariam": "marfolhar",
    "marfolharias": "marfolhar",
    "marfolharmo": "marfolhar",
    "marfolharmos": "marfolhar",
    "marfolhará": "marfolhar",
    "marfolharás": "marfolhar",
    "marfolharão": "marfolhar",
    "marfolharíamos": "marfolhar",
    "marfolharíeis": "marfolhar",
    "marfolhas": "marfolhar",
    "marfolhasse": "marfolhar",
    "marfolhassem": "marfolhar",
    "marfolhasses": "marfolhar",
    "marfolhaste": "marfolhar",
    "marfolhastes": "marfolhar",
    "marfolhava": "marfolhar",
    "marfolhavam": "marfolhar",
    "marfolhavas": "marfolhar",
    "marfolhe": "marfolhar",
    "marfolhei": "marfolhar",
    "marfolheis": "marfolhar",
    "marfolhem": "marfolhar",
    "marfolhemo": "marfolhar",
    "marfolhemos": "marfolhar",
    "marfolhes": "marfolhar",
    "marfolho": "marfolhar",
    "marfolhos": "marfolho",
    "marfolhou": "marfolhar",
    "marfolhámo": "marfolhar",
    "marfolhámos": "marfolhar",
    "marfolháramo": "marfolhar",
    "marfolháramos": "marfolhar",
    "marfolháreis": "marfolhar",
    "marfolhásseis": "marfolhar",
    "marfolhássemos": "marfolhar",
    "marfolhávamo": "marfolhar",
    "marfolhávamos": "marfolhar",
    "marfolháveis": "marfolhar",
    "marfou": "marfar",
    "marfá": "marfar",
    "marfámo": "marfar",
    "marfámos": "marfar",
    "marfáramo": "marfar",
    "marfáramos": "marfar",
    "marfárei": "marfar",
    "marfáreis": "marfar",
    "marfásseis": "marfar",
    "marfássemos": "marfar",
    "marfávamo": "marfar",
    "marfávamos": "marfar",
    "marfávei": "marfar",
    "marfáveis": "marfar",
    "marfínica": "marfínico",
    "marfínicas": "marfínico",
    "marfínicos": "marfínico",
    "marga": "margar",
    "margada": "margar",
    "margadas": "margar",
    "margado": "margar",
    "margados": "margar",
    "margagens": "margagem",
    "margai": "margar",
    "margais": "margar",
    "margam": "margar",
    "margamo": "margar",
    "margamos": "margar",
    "margando": "margar",
    "margara": "margar",
    "margaram": "margar",
    "margaras": "margar",
    "margaratos": "margarato",
    "margarde": "margar",
    "margardes": "margar",
    "margare": "margar",
    "margarei": "margar",
    "margareis": "margar",
    "margarem": "margar",
    "margaremos": "margar",
    "margares": "margar",
    "margaria": "margar",
    "margariam": "margar",
    "margarias": "margar",
    "margaridas": "margarida",
    "margaridinhas": "margaridinha",
    "margarinas": "margarina",
    "margaritas": "margarita",
    "margarites": "margarite",
    "margaritos": "margarito",
    "margaritífera": "margaritífero",
    "margaritíferas": "margaritífero",
    "margaritíferos": "margaritífero",
    "margarmo": "margar",
    "margarmos": "margar",
    "margará": "margar",
    "margarás": "margar",
    "margarão": "margar",
    "margaríamos": "margar",
    "margaríeis": "margar",
    "margas": "margar",
    "margasse": "margar",
    "margassem": "margar",
    "margasses": "margar",
    "margaste": "margar",
    "margastes": "margar",
    "margava": "margar",
    "margavam": "margar",
    "margavas": "margar",
    "margaças": "margaça",
    "margeada": "margear",
    "margeadas": "margear",
    "margeado": "margear",
    "margeadores": "margeador",
    "margeados": "margear",
    "margeai": "margear",
    "margeais": "margear",
    "margeamo": "margear",
    "margeamos": "margear",
    "margeando": "margear",
    "margeara": "margear",
    "margearam": "margear",
    "margearas": "margear",
    "margearde": "margear",
    "margeardes": "margear",
    "margeare": "margear",
    "margearei": "margear",
    "margeareis": "margear",
    "margearem": "margear",
    "margearemos": "margear",
    "margeares": "margear",
    "margearia": "margear",
    "margeariam": "margear",
    "margearias": "margear",
    "margearmo": "margear",
    "margearmos": "margear",
    "margeará": "margear",
    "margearás": "margear",
    "margearão": "margear",
    "margearíamos": "margear",
    "margearíeis": "margear",
    "margeasse": "margear",
    "margeassem": "margear",
    "margeasses": "margear",
    "margeaste": "margear",
    "margeastes": "margear",
    "margeava": "margear",
    "margeavam": "margear",
    "margeavas": "margear",
    "margeações": "margeação",
    "margeei": "margear",
    "margeeiros": "margeeiro",
    "margeeis": "margear",
    "margeemo": "margear",
    "margeemos": "margear",
    "margeia": "margear",
    "margeiam": "margear",
    "margeias": "margear",
    "margeie": "margear",
    "margeiem": "margear",
    "margeies": "margear",
    "margeio": "margear",
    "margens": "margem",
    "margeou": "margear",
    "margeá": "margear",
    "margeámo": "margear",
    "margeámos": "margear",
    "margeáramo": "margear",
    "margeáramos": "margear",
    "margeárei": "margear",
    "margeáreis": "margear",
    "margeásseis": "margear",
    "margeássemos": "margear",
    "margeávamo": "margear",
    "margeávamos": "margear",
    "margeávei": "margear",
    "margeáveis": "margear",
    "margina": "marginar",
    "marginada": "marginar",
    "marginadas": "marginar",
    "marginado": "marginar",
    "marginadores": "marginador",
    "marginados": "marginar",
    "marginai": "marginar",
    "marginais": "marginar",
    "marginalidades": "marginalidade",
    "marginalismos": "marginalismo",
    "marginaliza": "marginalizar",
    "marginalizada": "marginalizar",
    "marginalizadas": "marginalizar",
    "marginalizado": "marginalizar",
    "marginalizados": "marginalizar",
    "marginalizadíssima": "marginalizado",
    "marginalizadíssimas": "marginalizado",
    "marginalizadíssimo": "marginalizado",
    "marginalizadíssimos": "marginalizado",
    "marginalizai": "marginalizar",
    "marginalizais": "marginalizar",
    "marginalizam": "marginalizar",
    "marginalizamo": "marginalizar",
    "marginalizamos": "marginalizar",
    "marginalizando": "marginalizar",
    "marginalizara": "marginalizar",
    "marginalizaram": "marginalizar",
    "marginalizaras": "marginalizar",
    "marginalizarde": "marginalizar",
    "marginalizardes": "marginalizar",
    "marginalizare": "marginalizar",
    "marginalizarei": "marginalizar",
    "marginalizareis": "marginalizar",
    "marginalizarem": "marginalizar",
    "marginalizaremos": "marginalizar",
    "marginalizares": "marginalizar",
    "marginalizaria": "marginalizar",
    "marginalizariam": "marginalizar",
    "marginalizarias": "marginalizar",
    "marginalizarmo": "marginalizar",
    "marginalizarmos": "marginalizar",
    "marginalizará": "marginalizar",
    "marginalizarás": "marginalizar",
    "marginalizarão": "marginalizar",
    "marginalizaríamos": "marginalizar",
    "marginalizaríeis": "marginalizar",
    "marginalizas": "marginalizar",
    "marginalizasse": "marginalizar",
    "marginalizassem": "marginalizar",
    "marginalizasses": "marginalizar",
    "marginalizaste": "marginalizar",
    "marginalizastes": "marginalizar",
    "marginalizava": "marginalizar",
    "marginalizavam": "marginalizar",
    "marginalizavas": "marginalizar",
    "marginalizações": "marginalização",
    "marginalize": "marginalizar",
    "marginalizei": "marginalizar",
    "marginalizeis": "marginalizar",
    "marginalizem": "marginalizar",
    "marginalizemo": "marginalizar",
    "marginalizemos": "marginalizar",
    "marginalizes": "marginalizar",
    "marginalizo": "marginalizar",
    "marginalizou": "marginalizar",
    "marginalizá": "marginalizar",
    "marginalizámo": "marginalizar",
    "marginalizámos": "marginalizar",
    "marginalizáramo": "marginalizar",
    "marginalizáramos": "marginalizar",
    "marginalizárei": "marginalizar",
    "marginalizáreis": "marginalizar",
    "marginalizásseis": "marginalizar",
    "marginalizássemos": "marginalizar",
    "marginalizávamo": "marginalizar",
    "marginalizávamos": "marginalizar",
    "marginalizávei": "marginalizar",
    "marginalizáveis": "marginalizar",
    "marginam": "marginar",
    "marginamo": "marginar",
    "marginamos": "marginar",
    "marginando": "marginar",
    "marginara": "marginar",
    "marginaram": "marginar",
    "marginaras": "marginar",
    "marginarde": "marginar",
    "marginardes": "marginar",
    "marginare": "marginar",
    "marginarei": "marginar",
    "marginareis": "marginar",
    "marginarem": "marginar",
    "marginaremos": "marginar",
    "marginares": "marginar",
    "marginaria": "marginar",
    "marginariam": "marginar",
    "marginarias": "marginar",
    "marginarmo": "marginar",
    "marginarmos": "marginar",
    "marginará": "marginar",
    "marginarás": "marginar",
    "marginarão": "marginar",
    "marginaríamos": "marginar",
    "marginaríeis": "marginar",
    "marginas": "marginar",
    "marginasse": "marginar",
    "marginassem": "marginar",
    "marginasses": "marginar",
    "marginaste": "marginar",
    "marginastes": "marginar",
    "marginava": "marginar",
    "marginavam": "marginar",
    "marginavas": "marginar",
    "marginações": "marginação",
    "margine": "marginar",
    "marginei": "marginar",
    "margineis": "marginar",
    "marginem": "marginar",
    "marginemo": "marginar",
    "marginemos": "marginar",
    "margines": "marginar",
    "marginiformes": "marginiforme",
    "margino": "marginar",
    "marginou": "marginar",
    "marginá": "marginar",
    "marginámo": "marginar",
    "marginámos": "marginar",
    "margináramo": "marginar",
    "margináramos": "marginar",
    "marginárei": "marginar",
    "margináreis": "marginar",
    "marginária": "marginário",
    "marginárias": "marginário",
    "marginários": "marginário",
    "marginásseis": "marginar",
    "marginássemos": "marginar",
    "marginávamo": "marginar",
    "marginávamos": "marginar",
    "marginávei": "marginar",
    "margináveis": "marginar",
    "margo": "margar",
    "margosa": "margoso",
    "margosas": "margoso",
    "margosos": "margoso",
    "margotas": "margota",
    "margou": "margar",
    "margraves": "margrave",
    "margraviados": "margraviado",
    "margraviatos": "margraviato",
    "margue": "margar",
    "marguei": "margar",
    "margueira": "margueiro",
    "margueiras": "margueiro",
    "margueiros": "margueiro",
    "margueis": "margar",
    "marguem": "margar",
    "marguemo": "margar",
    "marguemos": "margar",
    "margues": "margar",
    "margá": "margar",
    "margámo": "margar",
    "margámos": "margar",
    "margáramo": "margar",
    "margáramos": "margar",
    "margárei": "margar",
    "margáreis": "margar",
    "margárica": "margárico",
    "margáricas": "margárico",
    "margáricos": "margárico",
    "margásseis": "margar",
    "margássemos": "margar",
    "margávamo": "margar",
    "margávamos": "margar",
    "margávei": "margar",
    "margáveis": "margar",
    "mariais": "marial",
    "marialvas": "marialva",
    "mariana": "mariano",
    "marianas": "mariano",
    "marianinhas": "marianinha",
    "marianismos": "marianismo",
    "marianos": "mariano",
    "marias": "maria",
    "mariatos": "mariato",
    "maribondos": "maribondo",
    "maricagens": "maricagem",
    "mariconas": "maricona",
    "maricões": "maricão",
    "marida": "maridar",
    "maridada": "maridar",
    "maridadas": "maridar",
    "maridado": "maridar",
    "maridados": "maridar",
    "maridagens": "maridagem",
    "maridai": "maridar",
    "maridais": "maridar",
    "maridam": "maridar",
    "maridamo": "maridar",
    "maridamos": "maridar",
    "maridando": "maridar",
    "maridanças": "maridança",
    "maridara": "maridar",
    "maridaram": "maridar",
    "maridaras": "maridar",
    "maridarde": "maridar",
    "maridardes": "maridar",
    "maridare": "maridar",
    "maridarei": "maridar",
    "maridareis": "maridar",
    "maridarem": "maridar",
    "maridaremos": "maridar",
    "maridares": "maridar",
    "maridaria": "maridar",
    "maridariam": "maridar",
    "maridarias": "maridar",
    "maridarmo": "maridar",
    "maridarmos": "maridar",
    "maridará": "maridar",
    "maridarás": "maridar",
    "maridarão": "maridar",
    "maridaríamos": "maridar",
    "maridaríeis": "maridar",
    "maridas": "maridar",
    "maridasse": "maridar",
    "maridassem": "maridar",
    "maridasses": "maridar",
    "maridaste": "maridar",
    "maridastes": "maridar",
    "maridava": "maridar",
    "maridavam": "maridar",
    "maridavas": "maridar",
    "maride": "maridar",
    "maridei": "maridar",
    "marideis": "maridar",
    "maridem": "maridar",
    "maridemo": "maridar",
    "maridemos": "maridar",
    "marides": "maridar",
    "maridinho": "marido",
    "maridinhos": "marido",
    "maridito": "marido",
    "mariditos": "marido",
    "marido": "maridar",
    "maridos": "marido",
    "maridou": "maridar",
    "maridá": "maridar",
    "maridámo": "maridar",
    "maridámos": "maridar",
    "maridáramo": "maridar",
    "maridáramos": "maridar",
    "maridárei": "maridar",
    "maridáreis": "maridar",
    "maridásseis": "maridar",
    "maridássemos": "maridar",
    "maridávamo": "maridar",
    "maridávamos": "maridar",
    "maridávei": "maridar",
    "maridáveis": "maridável",
    "marijuanas": "marijuana",
    "marimachos": "marimacho",
    "marimba": "marimbar",
    "marimbada": "marimbar",
    "marimbadas": "marimbar",
    "marimbado": "marimbar",
    "marimbados": "marimbar",
    "marimbai": "marimbar",
    "marimbais": "marimbar",
    "marimbam": "marimbar",
    "marimbamo": "marimbar",
    "marimbamos": "marimbar",
    "marimbando": "marimbar",
    "marimbara": "marimbar",
    "marimbaram": "marimbar",
    "marimbaras": "marimbar",
    "marimbarde": "marimbar",
    "marimbardes": "marimbar",
    "marimbare": "marimbar",
    "marimbarei": "marimbar",
    "marimbareis": "marimbar",
    "marimbarem": "marimbar",
    "marimbaremos": "marimbar",
    "marimbares": "marimbar",
    "marimbaria": "marimbar",
    "marimbariam": "marimbar",
    "marimbarias": "marimbar",
    "marimbarmo": "marimbar",
    "marimbarmos": "marimbar",
    "marimbará": "marimbar",
    "marimbarás": "marimbar",
    "marimbarão": "marimbar",
    "marimbaríamos": "marimbar",
    "marimbaríeis": "marimbar",
    "marimbas": "marimbar",
    "marimbasse": "marimbar",
    "marimbassem": "marimbar",
    "marimbasses": "marimbar",
    "marimbaste": "marimbar",
    "marimbastes": "marimbar",
    "marimbava": "marimbar",
    "marimbavam": "marimbar",
    "marimbavas": "marimbar",
    "marimbe": "marimbar",
    "marimbei": "marimbar",
    "marimbeira": "marimbeiro",
    "marimbeiras": "marimbeiro",
    "marimbeiros": "marimbeiro",
    "marimbeis": "marimbar",
    "marimbem": "marimbar",
    "marimbemo": "marimbar",
    "marimbemos": "marimbar",
    "marimbes": "marimbar",
    "marimbo": "marimbar",
    "marimbos": "marimbo",
    "marimbou": "marimbar",
    "marimbá": "marimbar",
    "marimbámo": "marimbar",
    "marimbámos": "marimbar",
    "marimbáramo": "marimbar",
    "marimbáramos": "marimbar",
    "marimbárei": "marimbar",
    "marimbáreis": "marimbar",
    "marimbásseis": "marimbar",
    "marimbássemos": "marimbar",
    "marimbávamo": "marimbar",
    "marimbávamos": "marimbar",
    "marimbávei": "marimbar",
    "marimbáveis": "marimbar",
    "marina": "marino",
    "marinada": "marinar",
    "marinadas": "marinar",
    "marinado": "marinar",
    "marinados": "marinar",
    "marinai": "marinar",
    "marinais": "marinar",
    "marinam": "marinar",
    "marinamo": "marinar",
    "marinamos": "marinar",
    "marinando": "marinar",
    "marinara": "marinar",
    "marinaram": "marinar",
    "marinaras": "marinar",
    "marinarde": "marinar",
    "marinardes": "marinar",
    "marinare": "marinar",
    "marinarei": "marinar",
    "marinareis": "marinar",
    "marinarem": "marinar",
    "marinaremos": "marinar",
    "marinares": "marinar",
    "marinaria": "marinar",
    "marinariam": "marinar",
    "marinarias": "marinar",
    "marinarmo": "marinar",
    "marinarmos": "marinar",
    "marinará": "marinar",
    "marinarás": "marinar",
    "marinarão": "marinar",
    "marinaríamos": "marinar",
    "marinaríeis": "marinar",
    "marinas": "marino",
    "marinasse": "marinar",
    "marinassem": "marinar",
    "marinasses": "marinar",
    "marinaste": "marinar",
    "marinastes": "marinar",
    "marinava": "marinar",
    "marinavam": "marinar",
    "marinavas": "marinar",
    "marine": "marinar",
    "marinei": "marinar",
    "marineis": "marinar",
    "marinem": "marinar",
    "marinemo": "marinar",
    "marinemos": "marinar",
    "marines": "marine",
    "marinha": "marinho",
    "marinhada": "marinhar",
    "marinhadas": "marinhar",
    "marinhadeiras": "marinhadeira",
    "marinhado": "marinhar",
    "marinhados": "marinhar",
    "marinhagens": "marinhagem",
    "marinhai": "marinhar",
    "marinhais": "marinhar",
    "marinham": "marinhar",
    "marinhamo": "marinhar",
    "marinhamos": "marinhar",
    "marinhando": "marinhar",
    "marinhara": "marinhar",
    "marinharam": "marinhar",
    "marinharas": "marinhar",
    "marinharde": "marinhar",
    "marinhardes": "marinhar",
    "marinhare": "marinhar",
    "marinharei": "marinhar",
    "marinhareis": "marinhar",
    "marinharem": "marinhar",
    "marinharemos": "marinhar",
    "marinhares": "marinhar",
    "marinharesca": "marinharesco",
    "marinharescas": "marinharesco",
    "marinharescos": "marinharesco",
    "marinharia": "marinhar",
    "marinhariam": "marinhar",
    "marinharias": "marinharia",
    "marinharmo": "marinhar",
    "marinharmos": "marinhar",
    "marinhará": "marinhar",
    "marinharás": "marinhar",
    "marinharão": "marinhar",
    "marinharíamos": "marinhar",
    "marinharíeis": "marinhar",
    "marinhas": "marinho",
    "marinhasse": "marinhar",
    "marinhassem": "marinhar",
    "marinhasses": "marinhar",
    "marinhaste": "marinhar",
    "marinhastes": "marinhar",
    "marinhava": "marinhar",
    "marinhavam": "marinhar",
    "marinhavas": "marinhar",
    "marinhe": "marinhar",
    "marinhei": "marinhar",
    "marinheira": "marinheiro",
    "marinheirada": "marinheirar",
    "marinheiradas": "marinheirar",
    "marinheirado": "marinheirar",
    "marinheirados": "marinheirar",
    "marinheirai": "marinheirar",
    "marinheirais": "marinheirar",
    "marinheiram": "marinheirar",
    "marinheiramo": "marinheirar",
    "marinheiramos": "marinheirar",
    "marinheirando": "marinheirar",
    "marinheirara": "marinheirar",
    "marinheiraram": "marinheirar",
    "marinheiraras": "marinheirar",
    "marinheirardes": "marinheirar",
    "marinheirarei": "marinheirar",
    "marinheirareis": "marinheirar",
    "marinheirarem": "marinheirar",
    "marinheiraremos": "marinheirar",
    "marinheirares": "marinheirar",
    "marinheiraria": "marinheirar",
    "marinheirariam": "marinheirar",
    "marinheirarias": "marinheiraria",
    "marinheirarmo": "marinheirar",
    "marinheirarmos": "marinheirar",
    "marinheirará": "marinheirar",
    "marinheirarás": "marinheirar",
    "marinheirarão": "marinheirar",
    "marinheiraríamos": "marinheirar",
    "marinheiraríeis": "marinheirar",
    "marinheiras": "marinheiro",
    "marinheirasse": "marinheirar",
    "marinheirassem": "marinheirar",
    "marinheirasses": "marinheirar",
    "marinheiraste": "marinheirar",
    "marinheirastes": "marinheirar",
    "marinheirava": "marinheirar",
    "marinheiravam": "marinheirar",
    "marinheiravas": "marinheirar",
    "marinheire": "marinheirar",
    "marinheirei": "marinheirar",
    "marinheireis": "marinheirar",
    "marinheirem": "marinheirar",
    "marinheiremo": "marinheirar",
    "marinheiremos": "marinheirar",
    "marinheires": "marinheirar",
    "marinheiresca": "marinheiresco",
    "marinheirescas": "marinheiresco",
    "marinheirescos": "marinheiresco",
    "marinheiro": "marinheirar",
    "marinheiros": "marinheiro",
    "marinheirou": "marinheirar",
    "marinheirámo": "marinheirar",
    "marinheirámos": "marinheirar",
    "marinheiráramo": "marinheirar",
    "marinheiráramos": "marinheirar",
    "marinheiráreis": "marinheirar",
    "marinheirásseis": "marinheirar",
    "marinheirássemos": "marinheirar",
    "marinheirávamo": "marinheirar",
    "marinheirávamos": "marinheirar",
    "marinheiráveis": "marinheirar",
    "marinheis": "marinhar",
    "marinhem": "marinhar",
    "marinhemo": "marinhar",
    "marinhemos": "marinhar",
    "marinhes": "marinhar",
    "marinhesca": "marinhesco",
    "marinhescas": "marinhesco",
    "marinhescos": "marinhesco",
    "marinhistas": "marinhista",
    "marinho": "marinhar",
    "marinhona": "marinhão",
    "marinhonas": "marinhão",
    "marinhos": "marinho",
    "marinhota": "marinhoto",
    "marinhotas": "marinhoto",
    "marinhotos": "marinhoto",
    "marinhou": "marinhar",
    "marinhá": "marinhar",
    "marinhámo": "marinhar",
    "marinhámos": "marinhar",
    "marinháramo": "marinhar",
    "marinháramos": "marinhar",
    "marinhárei": "marinhar",
    "marinháreis": "marinhar",
    "marinhásseis": "marinhar",
    "marinhássemos": "marinhar",
    "marinhávamo": "marinhar",
    "marinhávamos": "marinhar",
    "marinhávei": "marinhar",
    "marinháveis": "marinhar",
    "marinhões": "marinhão",
    "marinismos": "marinismo",
    "marinistas": "marinista",
    "marino": "marinar",
    "marinos": "marino",
    "marinou": "marinar",
    "mariná": "marinar",
    "marinámo": "marinar",
    "marinámos": "marinar",
    "marináramo": "marinar",
    "marináramos": "marinar",
    "marinárei": "marinar",
    "marináreis": "marinar",
    "marinásseis": "marinar",
    "marinássemos": "marinar",
    "marinávamo": "marinar",
    "marinávamos": "marinar",
    "marinávei": "marinar",
    "marináveis": "marinar",
    "marioilas": "marioila",
    "mariola": "mariolar",
    "mariolada": "mariolar",
    "marioladas": "mariolar",
    "mariolado": "mariolar",
    "mariolados": "mariolar",
    "mariolagens": "mariolagem",
    "mariolai": "mariolar",
    "mariolais": "mariolar",
    "mariolam": "mariolar",
    "mariolamo": "mariolar",
    "mariolamos": "mariolar",
    "mariolando": "mariolar",
    "mariolara": "mariolar",
    "mariolaram": "mariolar",
    "mariolaras": "mariolar",
    "mariolardes": "mariolar",
    "mariolarei": "mariolar",
    "mariolareis": "mariolar",
    "mariolarem": "mariolar",
    "mariolaremos": "mariolar",
    "mariolares": "mariolar",
    "mariolaria": "mariolar",
    "mariolariam": "mariolar",
    "mariolarias": "mariolar",
    "mariolarmo": "mariolar",
    "mariolarmos": "mariolar",
    "mariolará": "mariolar",
    "mariolarás": "mariolar",
    "mariolarão": "mariolar",
    "mariolaríamos": "mariolar",
    "mariolaríeis": "mariolar",
    "mariolas": "mariolar",
    "mariolasse": "mariolar",
    "mariolassem": "mariolar",
    "mariolasses": "mariolar",
    "mariolaste": "mariolar",
    "mariolastes": "mariolar",
    "mariolatrias": "mariolatria",
    "mariolava": "mariolar",
    "mariolavam": "mariolar",
    "mariolavas": "mariolar",
    "mariole": "mariolar",
    "mariolei": "mariolar",
    "marioleis": "mariolar",
    "mariolem": "mariolar",
    "mariolemo": "mariolar",
    "mariolemos": "mariolar",
    "marioles": "mariolar",
    "mariolices": "mariolice",
    "mariolo": "mariolar",
    "mariolona": "mariolão",
    "mariolonas": "mariolão",
    "mariolou": "mariolar",
    "mariolámo": "mariolar",
    "mariolámos": "mariolar",
    "marioláramo": "mariolar",
    "marioláramos": "mariolar",
    "marioláreis": "mariolar",
    "mariolásseis": "mariolar",
    "mariolássemos": "mariolar",
    "mariolávamo": "mariolar",
    "mariolávamos": "mariolar",
    "marioláveis": "mariolar",
    "mariológica": "mariológico",
    "mariológicas": "mariológico",
    "mariológicos": "mariológico",
    "mariolões": "mariolão",
    "marionetas": "marioneta",
    "marionetes": "marionete",
    "mariposas": "mariposa",
    "mariposeada": "mariposear",
    "mariposeadas": "mariposear",
    "mariposeado": "mariposear",
    "mariposeados": "mariposear",
    "mariposeai": "mariposear",
    "mariposeais": "mariposear",
    "mariposeamo": "mariposear",
    "mariposeamos": "mariposear",
    "mariposeando": "mariposear",
    "mariposeara": "mariposear",
    "mariposearam": "mariposear",
    "mariposearas": "mariposear",
    "mariposeardes": "mariposear",
    "mariposearei": "mariposear",
    "mariposeareis": "mariposear",
    "mariposearem": "mariposear",
    "mariposearemos": "mariposear",
    "mariposeares": "mariposear",
    "mariposearia": "mariposear",
    "mariposeariam": "mariposear",
    "mariposearias": "mariposear",
    "mariposearmo": "mariposear",
    "mariposearmos": "mariposear",
    "mariposeará": "mariposear",
    "mariposearás": "mariposear",
    "mariposearão": "mariposear",
    "mariposearíamos": "mariposear",
    "mariposearíeis": "mariposear",
    "mariposeasse": "mariposear",
    "mariposeassem": "mariposear",
    "mariposeasses": "mariposear",
    "mariposeaste": "mariposear",
    "mariposeastes": "mariposear",
    "mariposeava": "mariposear",
    "mariposeavam": "mariposear",
    "mariposeavas": "mariposear",
    "mariposeei": "mariposear",
    "mariposeeis": "mariposear",
    "mariposeemo": "mariposear",
    "mariposeemos": "mariposear",
    "mariposeia": "mariposear",
    "mariposeiam": "mariposear",
    "mariposeias": "mariposear",
    "mariposeie": "mariposear",
    "mariposeiem": "mariposear",
    "mariposeies": "mariposear",
    "mariposeio": "mariposear",
    "mariposeou": "mariposear",
    "mariposeámo": "mariposear",
    "mariposeámos": "mariposear",
    "mariposeáramo": "mariposear",
    "mariposeáramos": "mariposear",
    "mariposeáreis": "mariposear",
    "mariposeásseis": "mariposear",
    "mariposeássemos": "mariposear",
    "mariposeávamo": "mariposear",
    "mariposeávamos": "mariposear",
    "mariposeáveis": "mariposear",
    "mariquices": "mariquice",
    "maris": "mari",
    "marisca": "mariscar",
    "mariscada": "mariscar",
    "mariscadas": "mariscar",
    "mariscado": "mariscar",
    "mariscados": "mariscar",
    "mariscais": "mariscar",
    "mariscam": "mariscar",
    "mariscamo": "mariscar",
    "mariscamos": "mariscar",
    "mariscando": "mariscar",
    "mariscara": "mariscar",
    "mariscaram": "mariscar",
    "mariscaras": "mariscar",
    "mariscardes": "mariscar",
    "mariscarei": "mariscar",
    "mariscareis": "mariscar",
    "mariscarem": "mariscar",
    "mariscaremos": "mariscar",
    "mariscares": "mariscar",
    "mariscaria": "mariscar",
    "mariscariam": "mariscar",
    "mariscarias": "mariscar",
    "mariscarmo": "mariscar",
    "mariscarmos": "mariscar",
    "mariscará": "mariscar",
    "mariscarás": "mariscar",
    "mariscarão": "mariscar",
    "mariscaríamos": "mariscar",
    "mariscaríeis": "mariscar",
    "mariscas": "mariscar",
    "mariscasse": "mariscar",
    "mariscassem": "mariscar",
    "mariscasses": "mariscar",
    "mariscaste": "mariscar",
    "mariscastes": "mariscar",
    "mariscava": "mariscar",
    "mariscavam": "mariscar",
    "mariscavas": "mariscar",
    "marisco": "mariscar",
    "mariscos": "marisco",
    "mariscou": "mariscar",
    "mariscámo": "mariscar",
    "mariscámos": "mariscar",
    "mariscáramo": "mariscar",
    "mariscáramos": "mariscar",
    "mariscáreis": "mariscar",
    "mariscásseis": "mariscar",
    "mariscássemos": "mariscar",
    "mariscávamo": "mariscar",
    "mariscávamos": "mariscar",
    "mariscáveis": "mariscar",
    "marismas": "marisma",
    "marisque": "mariscar",
    "marisquei": "mariscar",
    "marisqueira": "marisqueiro",
    "marisqueiras": "marisqueiro",
    "marisqueiros": "marisqueiro",
    "marisqueis": "mariscar",
    "marisquem": "mariscar",
    "marisquemos": "mariscar",
    "marisques": "mariscar",
    "maristas": "marista",
    "maritabilidades": "maritabilidade",
    "maritais": "marital",
    "mariticidas": "mariticida",
    "mariticídios": "mariticídio",
    "maritimidades": "maritimidade",
    "maritágios": "maritágio",
    "mariânica": "mariânico",
    "mariânicas": "mariânico",
    "mariânicos": "mariânico",
    "marióloga": "mariólogo",
    "mariólogas": "mariólogo",
    "mariólogos": "mariólogo",
    "marketings": "marketing",
    "marlota": "marlotar",
    "marlotada": "marlotar",
    "marlotadas": "marlotar",
    "marlotado": "marlotar",
    "marlotados": "marlotar",
    "marlotai": "marlotar",
    "marlotais": "marlotar",
    "marlotam": "marlotar",
    "marlotamo": "marlotar",
    "marlotamos": "marlotar",
    "marlotando": "marlotar",
    "marlotara": "marlotar",
    "marlotaram": "marlotar",
    "marlotaras": "marlotar",
    "marlotarde": "marlotar",
    "marlotardes": "marlotar",
    "marlotare": "marlotar",
    "marlotarei": "marlotar",
    "marlotareis": "marlotar",
    "marlotarem": "marlotar",
    "marlotaremos": "marlotar",
    "marlotares": "marlotar",
    "marlotaria": "marlotar",
    "marlotariam": "marlotar",
    "marlotarias": "marlotar",
    "marlotarmo": "marlotar",
    "marlotarmos": "marlotar",
    "marlotará": "marlotar",
    "marlotarás": "marlotar",
    "marlotarão": "marlotar",
    "marlotaríamos": "marlotar",
    "marlotaríeis": "marlotar",
    "marlotas": "marlotar",
    "marlotasse": "marlotar",
    "marlotassem": "marlotar",
    "marlotasses": "marlotar",
    "marlotaste": "marlotar",
    "marlotastes": "marlotar",
    "marlotava": "marlotar",
    "marlotavam": "marlotar",
    "marlotavas": "marlotar",
    "marlote": "marlotar",
    "marlotei": "marlotar",
    "marloteis": "marlotar",
    "marlotem": "marlotar",
    "marlotemo": "marlotar",
    "marlotemos": "marlotar",
    "marlotes": "marlotar",
    "marloto": "marlotar",
    "marlotou": "marlotar",
    "marlotá": "marlotar",
    "marlotámo": "marlotar",
    "marlotámos": "marlotar",
    "marlotáramo": "marlotar",
    "marlotáramos": "marlotar",
    "marlotárei": "marlotar",
    "marlotáreis": "marlotar",
    "marlotásseis": "marlotar",
    "marlotássemos": "marlotar",
    "marlotávamo": "marlotar",
    "marlotávamos": "marlotar",
    "marlotávei": "marlotar",
    "marlotáveis": "marlotar",
    "marma": "marmar",
    "marmada": "marmar",
    "marmadas": "marmar",
    "marmado": "marmar",
    "marmados": "marmar",
    "marmai": "marmar",
    "marmais": "marmar",
    "marmam": "marmar",
    "marmamo": "marmar",
    "marmamos": "marmar",
    "marmando": "marmar",
    "marmanja": "marmanjo",
    "marmanjarias": "marmanjaria",
    "marmanjas": "marmanjo",
    "marmanjolas": "marmanjola",
    "marmanjona": "marmanjão",
    "marmanjonas": "marmanjão",
    "marmanjos": "marmanjo",
    "marmanjões": "marmanjão",
    "marmara": "marmar",
    "marmaram": "marmar",
    "marmaras": "marmar",
    "marmardes": "marmar",
    "marmarei": "marmar",
    "marmareis": "marmar",
    "marmarem": "marmar",
    "marmaremos": "marmar",
    "marmares": "marmar",
    "marmaria": "marmar",
    "marmariam": "marmar",
    "marmarias": "marmar",
    "marmarmo": "marmar",
    "marmarmos": "marmar",
    "marmará": "marmar",
    "marmarás": "marmar",
    "marmarão": "marmar",
    "marmaríamos": "marmar",
    "marmaríeis": "marmar",
    "marmas": "marmar",
    "marmasse": "marmar",
    "marmassem": "marmar",
    "marmasses": "marmar",
    "marmaste": "marmar",
    "marmastes": "marmar",
    "marmava": "marmar",
    "marmavam": "marmar",
    "marmavas": "marmar",
    "marme": "marmar",
    "marmei": "marmar",
    "marmeis": "marmar",
    "marmeladas": "marmelada",
    "marmeladeiras": "marmeladeira",
    "marmeladinha": "marmelada",
    "marmeladinhas": "marmelada",
    "marmeladita": "marmelada",
    "marmeladitas": "marmelada",
    "marmelas": "marmela",
    "marmeleiros": "marmeleiro",
    "marmelos": "marmelo",
    "marmem": "marmar",
    "marmemo": "marmar",
    "marmemos": "marmar",
    "marmes": "marmar",
    "marmitas": "marmita",
    "marmo": "marmar",
    "marmoreada": "marmorear",
    "marmoreadas": "marmorear",
    "marmoreado": "marmorear",
    "marmoreados": "marmorear",
    "marmoreai": "marmorear",
    "marmoreais": "marmorear",
    "marmoreamo": "marmorear",
    "marmoreamos": "marmorear",
    "marmoreando": "marmorear",
    "marmoreara": "marmorear",
    "marmorearam": "marmorear",
    "marmorearas": "marmorear",
    "marmorearde": "marmorear",
    "marmoreardes": "marmorear",
    "marmoreare": "marmorear",
    "marmorearei": "marmorear",
    "marmoreareis": "marmorear",
    "marmorearem": "marmorear",
    "marmorearemos": "marmorear",
    "marmoreares": "marmorear",
    "marmorearia": "marmorear",
    "marmoreariam": "marmorear",
    "marmorearias": "marmorear",
    "marmorearmo": "marmorear",
    "marmorearmos": "marmorear",
    "marmoreará": "marmorear",
    "marmorearás": "marmorear",
    "marmorearão": "marmorear",
    "marmorearíamos": "marmorear",
    "marmorearíeis": "marmorear",
    "marmoreasse": "marmorear",
    "marmoreassem": "marmorear",
    "marmoreasses": "marmorear",
    "marmoreaste": "marmorear",
    "marmoreastes": "marmorear",
    "marmoreava": "marmorear",
    "marmoreavam": "marmorear",
    "marmoreavas": "marmorear",
    "marmoreações": "marmoreação",
    "marmoreei": "marmorear",
    "marmoreeis": "marmorear",
    "marmoreemo": "marmorear",
    "marmoreemos": "marmorear",
    "marmoreia": "marmorear",
    "marmoreiam": "marmorear",
    "marmoreias": "marmorear",
    "marmoreie": "marmorear",
    "marmoreiem": "marmorear",
    "marmoreies": "marmorear",
    "marmoreio": "marmorear",
    "marmoreira": "marmoreiro",
    "marmoreiras": "marmoreiro",
    "marmoreiros": "marmoreiro",
    "marmoreou": "marmorear",
    "marmoreá": "marmorear",
    "marmoreámo": "marmorear",
    "marmoreámos": "marmorear",
    "marmoreáramo": "marmorear",
    "marmoreáramos": "marmorear",
    "marmoreárei": "marmorear",
    "marmoreáreis": "marmorear",
    "marmoreásseis": "marmorear",
    "marmoreássemos": "marmorear",
    "marmoreávamo": "marmorear",
    "marmoreávamos": "marmorear",
    "marmoreávei": "marmorear",
    "marmoreáveis": "marmorear",
    "marmoristas": "marmorista",
    "marmorites": "marmorite",
    "marmoriza": "marmorizar",
    "marmorizada": "marmorizar",
    "marmorizadas": "marmorizar",
    "marmorizado": "marmorizar",
    "marmorizados": "marmorizar",
    "marmorizai": "marmorizar",
    "marmorizais": "marmorizar",
    "marmorizam": "marmorizar",
    "marmorizamo": "marmorizar",
    "marmorizamos": "marmorizar",
    "marmorizando": "marmorizar",
    "marmorizara": "marmorizar",
    "marmorizaram": "marmorizar",
    "marmorizaras": "marmorizar",
    "marmorizarde": "marmorizar",
    "marmorizardes": "marmorizar",
    "marmorizare": "marmorizar",
    "marmorizarei": "marmorizar",
    "marmorizareis": "marmorizar",
    "marmorizarem": "marmorizar",
    "marmorizaremos": "marmorizar",
    "marmorizares": "marmorizar",
    "marmorizaria": "marmorizar",
    "marmorizariam": "marmorizar",
    "marmorizarias": "marmorizar",
    "marmorizarmo": "marmorizar",
    "marmorizarmos": "marmorizar",
    "marmorizará": "marmorizar",
    "marmorizarás": "marmorizar",
    "marmorizarão": "marmorizar",
    "marmorizaríamos": "marmorizar",
    "marmorizaríeis": "marmorizar",
    "marmorizas": "marmorizar",
    "marmorizasse": "marmorizar",
    "marmorizassem": "marmorizar",
    "marmorizasses": "marmorizar",
    "marmorizaste": "marmorizar",
    "marmorizastes": "marmorizar",
    "marmorizava": "marmorizar",
    "marmorizavam": "marmorizar",
    "marmorizavas": "marmorizar",
    "marmorizações": "marmorização",
    "marmorize": "marmorizar",
    "marmorizei": "marmorizar",
    "marmorizeis": "marmorizar",
    "marmorizem": "marmorizar",
    "marmorizemo": "marmorizar",
    "marmorizemos": "marmorizar",
    "marmorizes": "marmorizar",
    "marmorizo": "marmorizar",
    "marmorizou": "marmorizar",
    "marmorizá": "marmorizar",
    "marmorizámo": "marmorizar",
    "marmorizámos": "marmorizar",
    "marmorizáramo": "marmorizar",
    "marmorizáramos": "marmorizar",
    "marmorizárei": "marmorizar",
    "marmorizáreis": "marmorizar",
    "marmorizásseis": "marmorizar",
    "marmorizássemos": "marmorizar",
    "marmorizávamo": "marmorizar",
    "marmorizávamos": "marmorizar",
    "marmorizávei": "marmorizar",
    "marmorizáveis": "marmorizar",
    "marmorária": "marmorário",
    "marmorárias": "marmorário",
    "marmorários": "marmorário",
    "marmoríformes": "marmoríforme",
    "marmotas": "marmota",
    "marmotos": "marmoto",
    "marmou": "marmar",
    "marmámo": "marmar",
    "marmámos": "marmar",
    "marmáramo": "marmar",
    "marmáramos": "marmar",
    "marmáreis": "marmar",
    "marmásseis": "marmar",
    "marmássemos": "marmar",
    "marmávamo": "marmar",
    "marmávamos": "marmar",
    "marmáveis": "marmar",
    "marmórea": "marmóreo",
    "marmóreas": "marmóreo",
    "marmóreos": "marmóreo",
    "marnas": "marna",
    "marneca": "marneco",
    "marnecas": "marneco",
    "marnecos": "marneco",
    "marnoceiros": "marnoceiro",
    "marnota": "marnoto",
    "marnotagens": "marnotagem",
    "marnotais": "marnotal",
    "marnotas": "marnoto",
    "marnoteira": "marnoteiro",
    "marnoteiras": "marnoteiro",
    "marnoteiros": "marnoteiro",
    "marnotos": "marnoto",
    "marnéis": "marnel",
    "maroiços": "maroiço",
    "maromas": "maroma",
    "maromba": "marombar",
    "marombada": "marombar",
    "marombadas": "marombar",
    "marombado": "marombar",
    "marombados": "marombar",
    "marombai": "marombar",
    "marombais": "marombar",
    "marombam": "marombar",
    "marombamo": "marombar",
    "marombamos": "marombar",
    "marombando": "marombar",
    "marombara": "marombar",
    "marombaram": "marombar",
    "marombaras": "marombar",
    "marombarde": "marombar",
    "marombardes": "marombar",
    "marombare": "marombar",
    "marombarei": "marombar",
    "marombareis": "marombar",
    "marombarem": "marombar",
    "marombaremos": "marombar",
    "marombares": "marombar",
    "marombaria": "marombar",
    "marombariam": "marombar",
    "marombarias": "marombar",
    "marombarmo": "marombar",
    "marombarmos": "marombar",
    "marombará": "marombar",
    "marombarás": "marombar",
    "marombarão": "marombar",
    "marombaríamos": "marombar",
    "marombaríeis": "marombar",
    "marombas": "marombar",
    "marombasse": "marombar",
    "marombassem": "marombar",
    "marombasses": "marombar",
    "marombaste": "marombar",
    "marombastes": "marombar",
    "marombava": "marombar",
    "marombavam": "marombar",
    "marombavas": "marombar",
    "marombe": "marombar",
    "marombei": "marombar",
    "marombeira": "marombeiro",
    "marombeiras": "marombeiro",
    "marombeiros": "marombeiro",
    "marombeis": "marombar",
    "marombem": "marombar",
    "marombemo": "marombar",
    "marombemos": "marombar",
    "marombes": "marombar",
    "marombo": "marombar",
    "marombou": "marombar",
    "marombá": "marombar",
    "marombámo": "marombar",
    "marombámos": "marombar",
    "marombáramo": "marombar",
    "marombáramos": "marombar",
    "marombárei": "marombar",
    "marombáreis": "marombar",
    "marombásseis": "marombar",
    "marombássemos": "marombar",
    "marombávamo": "marombar",
    "marombávamos": "marombar",
    "marombávei": "marombar",
    "marombáveis": "marombar",
    "maronesa": "maronês",
    "maronesas": "maronês",
    "maroneses": "maronês",
    "maronitas": "maronita",
    "maros": "maro",
    "maroscas": "marosca",
    "marota": "maroto",
    "marotagens": "marotagem",
    "marotas": "maroto",
    "maroteada": "marotear",
    "maroteadas": "marotear",
    "maroteado": "marotear",
    "maroteados": "marotear",
    "maroteai": "marotear",
    "maroteais": "marotear",
    "maroteamo": "marotear",
    "maroteamos": "marotear",
    "maroteando": "marotear",
    "maroteara": "marotear",
    "marotearam": "marotear",
    "marotearas": "marotear",
    "maroteardes": "marotear",
    "marotearei": "marotear",
    "maroteareis": "marotear",
    "marotearem": "marotear",
    "marotearemos": "marotear",
    "maroteares": "marotear",
    "marotearia": "marotear",
    "maroteariam": "marotear",
    "marotearias": "marotear",
    "marotearmo": "marotear",
    "marotearmos": "marotear",
    "maroteará": "marotear",
    "marotearás": "marotear",
    "marotearão": "marotear",
    "marotearíamos": "marotear",
    "marotearíeis": "marotear",
    "maroteasse": "marotear",
    "maroteassem": "marotear",
    "maroteasses": "marotear",
    "maroteaste": "marotear",
    "maroteastes": "marotear",
    "maroteava": "marotear",
    "maroteavam": "marotear",
    "maroteavas": "marotear",
    "maroteei": "marotear",
    "maroteeis": "marotear",
    "maroteemo": "marotear",
    "maroteemos": "marotear",
    "maroteia": "marotear",
    "maroteiam": "marotear",
    "maroteias": "marotear",
    "maroteie": "marotear",
    "maroteiem": "marotear",
    "maroteies": "marotear",
    "maroteio": "marotear",
    "maroteiras": "maroteira",
    "maroteou": "marotear",
    "maroteámo": "marotear",
    "maroteámos": "marotear",
    "maroteáramo": "marotear",
    "maroteáramos": "marotear",
    "maroteáreis": "marotear",
    "maroteásseis": "marotear",
    "maroteássemos": "marotear",
    "maroteávamo": "marotear",
    "maroteávamos": "marotear",
    "maroteáveis": "marotear",
    "marotinha": "maroto",
    "marotinhas": "maroto",
    "marotinho": "maroto",
    "marotinhos": "maroto",
    "marotita": "maroto",
    "marotitas": "maroto",
    "marotito": "maroto",
    "marotitos": "maroto",
    "marotona": "maroto",
    "marotonas": "maroto",
    "marotos": "maroto",
    "marotão": "maroto",
    "marotíssima": "maroto",
    "marotíssimas": "maroto",
    "marotíssimo": "maroto",
    "marotíssimos": "maroto",
    "marotões": "maroto",
    "maroucos": "marouco",
    "maroufas": "maroufa",
    "marouvas": "marouva",
    "marouvazes": "marouvaz",
    "marouços": "marouço",
    "marque": "marcar",
    "marquei": "marcar",
    "marqueis": "marcar",
    "marquem": "marcar",
    "marquemo": "marcar",
    "marquemos": "marcar",
    "marques": "marcar",
    "marquesa": "marquês",
    "marquesados": "marquesado",
    "marquesas": "marquesa",
    "marqueses": "marquês",
    "marquesinhas": "marquesinha",
    "marquesotas": "marquesota",
    "marquinha": "marca",
    "marquinhas": "marca",
    "marquises": "marquise",
    "marquita": "marca",
    "marquitas": "marca",
    "marra": "marrar",
    "marrachos": "marracho",
    "marracos": "marraco",
    "marrada": "marrar",
    "marradas": "marrar",
    "marradinha": "marrada",
    "marradinhas": "marrada",
    "marradita": "marrada",
    "marraditas": "marrada",
    "marrado": "marrar",
    "marrados": "marrar",
    "marrafas": "marrafa",
    "marrafona": "marrafão",
    "marrafonas": "marrafão",
    "marrafões": "marrafão",
    "marrai": "marrar",
    "marrais": "marrar",
    "marralha": "marralhar",
    "marralhada": "marralhar",
    "marralhadas": "marralhar",
    "marralhado": "marralhar",
    "marralhados": "marralhar",
    "marralhai": "marralhar",
    "marralhais": "marralhar",
    "marralham": "marralhar",
    "marralhamo": "marralhar",
    "marralhamos": "marralhar",
    "marralhando": "marralhar",
    "marralhara": "marralhar",
    "marralharam": "marralhar",
    "marralharas": "marralhar",
    "marralhardes": "marralhar",
    "marralharei": "marralhar",
    "marralhareis": "marralhar",
    "marralharem": "marralhar",
    "marralharemos": "marralhar",
    "marralhares": "marralhar",
    "marralharia": "marralhar",
    "marralhariam": "marralhar",
    "marralharias": "marralharia",
    "marralharmo": "marralhar",
    "marralharmos": "marralhar",
    "marralhará": "marralhar",
    "marralharás": "marralhar",
    "marralharão": "marralhar",
    "marralharíamos": "marralhar",
    "marralharíeis": "marralhar",
    "marralhas": "marralhar",
    "marralhasse": "marralhar",
    "marralhassem": "marralhar",
    "marralhasses": "marralhar",
    "marralhaste": "marralhar",
    "marralhastes": "marralhar",
    "marralhava": "marralhar",
    "marralhavam": "marralhar",
    "marralhavas": "marralhar",
    "marralhe": "marralhar",
    "marralhei": "marralhar",
    "marralheira": "marralheiro",
    "marralheiras": "marralheiro",
    "marralheiros": "marralheiro",
    "marralheis": "marralhar",
    "marralhem": "marralhar",
    "marralhemo": "marralhar",
    "marralhemos": "marralhar",
    "marralhes": "marralhar",
    "marralhices": "marralhice",
    "marralho": "marralhar",
    "marralhona": "marralhão",
    "marralhonas": "marralhão",
    "marralhou": "marralhar",
    "marralhámo": "marralhar",
    "marralhámos": "marralhar",
    "marralháramo": "marralhar",
    "marralháramos": "marralhar",
    "marralháreis": "marralhar",
    "marralhásseis": "marralhar",
    "marralhássemos": "marralhar",
    "marralhávamo": "marralhar",
    "marralhávamos": "marralhar",
    "marralháveis": "marralhar",
    "marralhões": "marralhão",
    "marram": "marrar",
    "marramo": "marrar",
    "marramos": "marrar",
    "marrana": "marrano",
    "marranas": "marrano",
    "marrancha": "marrancho",
    "marranchas": "marrancho",
    "marranchos": "marrancho",
    "marrando": "marrar",
    "marraneira": "marraneiro",
    "marraneiras": "marraneiro",
    "marraneiros": "marraneiro",
    "marranicas": "marranica",
    "marranitas": "marranita",
    "marranos": "marrano",
    "marranços": "marranço",
    "marrara": "marrar",
    "marraram": "marrar",
    "marraras": "marrar",
    "marrarde": "marrar",
    "marrardes": "marrar",
    "marrare": "marrar",
    "marrarei": "marrar",
    "marrareis": "marrar",
    "marrarem": "marrar",
    "marraremos": "marrar",
    "marrares": "marrar",
    "marraria": "marrar",
    "marrariam": "marrar",
    "marrarias": "marrar",
    "marrarmo": "marrar",
    "marrarmos": "marrar",
    "marrará": "marrar",
    "marrarás": "marrar",
    "marrarão": "marrar",
    "marraríamos": "marrar",
    "marraríeis": "marrar",
    "marras": "marrar",
    "marrasquinos": "marrasquino",
    "marrasse": "marrar",
    "marrassem": "marrar",
    "marrasses": "marrar",
    "marraste": "marrar",
    "marrastes": "marrar",
    "marrava": "marrar",
    "marravam": "marrar",
    "marravas": "marrar",
    "marraxa": "marraxo",
    "marraxas": "marraxo",
    "marraxos": "marraxo",
    "marre": "marrar",
    "marreca": "marreco",
    "marrecas": "marreco",
    "marrecazinha": "marreco",
    "marrecazinhas": "marreco",
    "marrecazita": "marreco",
    "marrecazitas": "marreco",
    "marrecos": "marreco",
    "marrecozinho": "marreco",
    "marrecozinhos": "marreco",
    "marrecozito": "marreco",
    "marrecozitos": "marreco",
    "marrei": "marrar",
    "marreis": "marrar",
    "marrem": "marrar",
    "marremo": "marrar",
    "marremos": "marrar",
    "marrequinha": "marreco",
    "marrequinhas": "marreco",
    "marrequinho": "marreco",
    "marrequinhos": "marrequinho",
    "marrequita": "marreco",
    "marrequitas": "marreco",
    "marrequito": "marreco",
    "marrequitos": "marreco",
    "marres": "marrar",
    "marreta": "marretar",
    "marretada": "marretar",
    "marretadas": "marretar",
    "marretado": "marretar",
    "marretados": "marretar",
    "marretai": "marretar",
    "marretais": "marretar",
    "marretam": "marretar",
    "marretamo": "marretar",
    "marretamos": "marretar",
    "marretando": "marretar",
    "marretara": "marretar",
    "marretaram": "marretar",
    "marretaras": "marretar",
    "marretardes": "marretar",
    "marretarei": "marretar",
    "marretareis": "marretar",
    "marretarem": "marretar",
    "marretaremos": "marretar",
    "marretares": "marretar",
    "marretaria": "marretar",
    "marretariam": "marretar",
    "marretarias": "marretar",
    "marretarmo": "marretar",
    "marretarmos": "marretar",
    "marretará": "marretar",
    "marretarás": "marretar",
    "marretarão": "marretar",
    "marretaríamos": "marretar",
    "marretaríeis": "marretar",
    "marretas": "marretar",
    "marretasse": "marretar",
    "marretassem": "marretar",
    "marretasses": "marretar",
    "marretaste": "marretar",
    "marretastes": "marretar",
    "marretava": "marretar",
    "marretavam": "marretar",
    "marretavas": "marretar",
    "marrete": "marretar",
    "marretei": "marretar",
    "marreteira": "marreteiro",
    "marreteiras": "marreteiro",
    "marreteiros": "marreteiro",
    "marreteis": "marretar",
    "marretem": "marretar",
    "marretemo": "marretar",
    "marretemos": "marretar",
    "marretes": "marretar",
    "marreto": "marretar",
    "marretou": "marretar",
    "marretámo": "marretar",
    "marretámos": "marretar",
    "marretáramo": "marretar",
    "marretáramos": "marretar",
    "marretáreis": "marretar",
    "marretásseis": "marretar",
    "marretássemos": "marretar",
    "marretávamo": "marretar",
    "marretávamos": "marretar",
    "marretáveis": "marretar",
    "marro": "marrar",
    "marroadas": "marroada",
    "marroazes": "marroaz",
    "marroios": "marroio",
    "marrona": "marrão",
    "marronas": "marrão",
    "marrons": "marrom",
    "marroquina": "marroquino",
    "marroquinada": "marroquinar",
    "marroquinadas": "marroquinar",
    "marroquinado": "marroquinar",
    "marroquinados": "marroquinar",
    "marroquinai": "marroquinar",
    "marroquinais": "marroquinar",
    "marroquinam": "marroquinar",
    "marroquinamo": "marroquinar",
    "marroquinamos": "marroquinar",
    "marroquinando": "marroquinar",
    "marroquinara": "marroquinar",
    "marroquinaram": "marroquinar",
    "marroquinaras": "marroquinar",
    "marroquinarde": "marroquinar",
    "marroquinardes": "marroquinar",
    "marroquinare": "marroquinar",
    "marroquinarei": "marroquinar",
    "marroquinareis": "marroquinar",
    "marroquinarem": "marroquinar",
    "marroquinaremos": "marroquinar",
    "marroquinares": "marroquinar",
    "marroquinaria": "marroquinar",
    "marroquinariam": "marroquinar",
    "marroquinarias": "marroquinaria",
    "marroquinarmo": "marroquinar",
    "marroquinarmos": "marroquinar",
    "marroquinará": "marroquinar",
    "marroquinarás": "marroquinar",
    "marroquinarão": "marroquinar",
    "marroquinaríamos": "marroquinar",
    "marroquinaríeis": "marroquinar",
    "marroquinas": "marroquino",
    "marroquinasse": "marroquinar",
    "marroquinassem": "marroquinar",
    "marroquinasses": "marroquinar",
    "marroquinaste": "marroquinar",
    "marroquinastes": "marroquinar",
    "marroquinava": "marroquinar",
    "marroquinavam": "marroquinar",
    "marroquinavas": "marroquinar",
    "marroquine": "marroquinar",
    "marroquinei": "marroquinar",
    "marroquineis": "marroquinar",
    "marroquinem": "marroquinar",
    "marroquinemo": "marroquinar",
    "marroquinemos": "marroquinar",
    "marroquines": "marroquinar",
    "marroquino": "marroquinar",
    "marroquinos": "marroquino",
    "marroquinou": "marroquinar",
    "marroquins": "marroquim",
    "marroquiná": "marroquinar",
    "marroquinámo": "marroquinar",
    "marroquinámos": "marroquinar",
    "marroquináramo": "marroquinar",
    "marroquináramos": "marroquinar",
    "marroquinárei": "marroquinar",
    "marroquináreis": "marroquinar",
    "marroquinásseis": "marroquinar",
    "marroquinássemos": "marroquinar",
    "marroquinávamo": "marroquinar",
    "marroquinávamos": "marroquinar",
    "marroquinávei": "marroquinar",
    "marroquináveis": "marroquinar",
    "marroteira": "marroteiro",
    "marroteiras": "marroteiro",
    "marroteiros": "marroteiro",
    "marrou": "marrar",
    "marroxa": "marroxo",
    "marroxas": "marroxo",
    "marroxos": "marroxo",
    "marruazes": "marruaz",
    "marruca": "marrucar",
    "marrucada": "marrucar",
    "marrucadas": "marrucar",
    "marrucado": "marrucar",
    "marrucados": "marrucar",
    "marrucais": "marrucar",
    "marrucam": "marrucar",
    "marrucamo": "marrucar",
    "marrucamos": "marrucar",
    "marrucando": "marrucar",
    "marrucara": "marrucar",
    "marrucaram": "marrucar",
    "marrucaras": "marrucar",
    "marrucardes": "marrucar",
    "marrucarei": "marrucar",
    "marrucareis": "marrucar",
    "marrucarem": "marrucar",
    "marrucaremos": "marrucar",
    "marrucares": "marrucar",
    "marrucaria": "marrucar",
    "marrucariam": "marrucar",
    "marrucarias": "marrucar",
    "marrucarmo": "marrucar",
    "marrucarmos": "marrucar",
    "marrucará": "marrucar",
    "marrucarás": "marrucar",
    "marrucarão": "marrucar",
    "marrucaríamos": "marrucar",
    "marrucaríeis": "marrucar",
    "marrucas": "marrucar",
    "marrucasse": "marrucar",
    "marrucassem": "marrucar",
    "marrucasses": "marrucar",
    "marrucaste": "marrucar",
    "marrucastes": "marrucar",
    "marrucava": "marrucar",
    "marrucavam": "marrucar",
    "marrucavas": "marrucar",
    "marruco": "marrucar",
    "marrucou": "marrucar",
    "marrucámo": "marrucar",
    "marrucámos": "marrucar",
    "marrucáramo": "marrucar",
    "marrucáramos": "marrucar",
    "marrucáreis": "marrucar",
    "marrucásseis": "marrucar",
    "marrucássemos": "marrucar",
    "marrucávamo": "marrucar",
    "marrucávamos": "marrucar",
    "marrucáveis": "marrucar",
    "marrugens": "marrugem",
    "marruque": "marrucar",
    "marruquei": "marrucar",
    "marruqueis": "marrucar",
    "marruquem": "marrucar",
    "marruquemos": "marrucar",
    "marruques": "marrucar",
    "marrá": "marrar",
    "marrámo": "marrar",
    "marrámos": "marrar",
    "marráramo": "marrar",
    "marráramos": "marrar",
    "marrárei": "marrar",
    "marráreis": "marrar",
    "marrásseis": "marrar",
    "marrássemos": "marrar",
    "marrávamo": "marrar",
    "marrávamos": "marrar",
    "marrávei": "marrar",
    "marráveis": "marrar",
    "marrãs": "marrã",
    "marrões": "marrão",
    "marselhesa": "marselhês",
    "marselhesas": "marselhesa",
    "marselheses": "marselhês",
    "marsileáceas": "marsileácea",
    "marsipobrânquios": "marsipobrânquio",
    "marsupiais": "marsupial",
    "marsupialidades": "marsupialidade",
    "marsuínos": "marsuíno",
    "marsíleas": "marsílea",
    "marsúpios": "marsúpio",
    "martagões": "martagão",
    "martaranhos": "martaranho",
    "martas": "marta",
    "martela": "martelar",
    "martelada": "martelar",
    "marteladas": "martelar",
    "marteladinha": "martelada",
    "marteladinhas": "martelada",
    "marteladita": "martelada",
    "marteladitas": "martelada",
    "martelado": "martelar",
    "marteladora": "martelador",
    "marteladoras": "martelador",
    "marteladores": "martelador",
    "martelados": "martelar",
    "martelagens": "martelagem",
    "martelai": "martelar",
    "martelais": "martelar",
    "martelam": "martelar",
    "martelamentos": "martelamento",
    "martelamo": "martelar",
    "martelamos": "martelar",
    "martelando": "martelar",
    "martelara": "martelar",
    "martelaram": "martelar",
    "martelaras": "martelar",
    "martelarde": "martelar",
    "martelardes": "martelar",
    "martelare": "martelar",
    "martelarei": "martelar",
    "martelareis": "martelar",
    "martelarem": "martelar",
    "martelaremos": "martelar",
    "martelares": "martelar",
    "martelaria": "martelar",
    "martelariam": "martelar",
    "martelarias": "martelar",
    "martelarmo": "martelar",
    "martelarmos": "martelar",
    "martelará": "martelar",
    "martelarás": "martelar",
    "martelarão": "martelar",
    "martelaríamos": "martelar",
    "martelaríeis": "martelar",
    "martelas": "martelar",
    "martelasse": "martelar",
    "martelassem": "martelar",
    "martelasses": "martelar",
    "martelaste": "martelar",
    "martelastes": "martelar",
    "martelava": "martelar",
    "martelavam": "martelar",
    "martelavas": "martelar",
    "martele": "martelar",
    "martelei": "martelar",
    "marteleira": "marteleiro",
    "marteleiras": "marteleiro",
    "marteleiros": "marteleiro",
    "marteleis": "martelar",
    "marteleja": "martelejar",
    "martelejada": "martelejar",
    "martelejadas": "martelejar",
    "martelejado": "martelejar",
    "martelejados": "martelejar",
    "martelejai": "martelejar",
    "martelejais": "martelejar",
    "martelejam": "martelejar",
    "martelejamo": "martelejar",
    "martelejamos": "martelejar",
    "martelejando": "martelejar",
    "martelejara": "martelejar",
    "martelejaram": "martelejar",
    "martelejaras": "martelejar",
    "martelejarde": "martelejar",
    "martelejardes": "martelejar",
    "martelejare": "martelejar",
    "martelejarei": "martelejar",
    "martelejareis": "martelejar",
    "martelejarem": "martelejar",
    "martelejaremos": "martelejar",
    "martelejares": "martelejar",
    "martelejaria": "martelejar",
    "martelejariam": "martelejar",
    "martelejarias": "martelejar",
    "martelejarmo": "martelejar",
    "martelejarmos": "martelejar",
    "martelejará": "martelejar",
    "martelejarás": "martelejar",
    "martelejarão": "martelejar",
    "martelejaríamos": "martelejar",
    "martelejaríeis": "martelejar",
    "martelejas": "martelejar",
    "martelejasse": "martelejar",
    "martelejassem": "martelejar",
    "martelejasses": "martelejar",
    "martelejaste": "martelejar",
    "martelejastes": "martelejar",
    "martelejava": "martelejar",
    "martelejavam": "martelejar",
    "martelejavas": "martelejar",
    "marteleje": "martelejar",
    "martelejei": "martelejar",
    "martelejeis": "martelejar",
    "martelejem": "martelejar",
    "martelejemo": "martelejar",
    "martelejemos": "martelejar",
    "martelejes": "martelejar",
    "martelejo": "martelejar",
    "martelejou": "martelejar",
    "martelejá": "martelejar",
    "martelejámo": "martelejar",
    "martelejámos": "martelejar",
    "martelejáramo": "martelejar",
    "martelejáramos": "martelejar",
    "martelejárei": "martelejar",
    "martelejáreis": "martelejar",
    "martelejásseis": "martelejar",
    "martelejássemos": "martelejar",
    "martelejávamo": "martelejar",
    "martelejávamos": "martelejar",
    "martelejávei": "martelejar",
    "martelejáveis": "martelejar",
    "martelem": "martelar",
    "martelemo": "martelar",
    "martelemos": "martelar",
    "marteles": "martelar",
    "marteletes": "martelete",
    "martelinho": "martelo",
    "martelinhos": "martelo",
    "martelito": "martelo",
    "martelitos": "martelo",
    "martelo": "martelar",
    "martelos": "martelo",
    "martelou": "martelar",
    "martelá": "martelar",
    "martelámo": "martelar",
    "martelámos": "martelar",
    "marteláramo": "martelar",
    "marteláramos": "martelar",
    "martelárei": "martelar",
    "marteláreis": "martelar",
    "martelásseis": "martelar",
    "martelássemos": "martelar",
    "martelávamo": "martelar",
    "martelávamos": "martelar",
    "martelávei": "martelar",
    "marteláveis": "martelar",
    "martelões": "martelão",
    "martenots": "martenot",
    "martinetes": "martinete",
    "martinhos": "martinho",
    "martins": "martim",
    "martiriza": "martirizar",
    "martirizada": "martirizar",
    "martirizadas": "martirizar",
    "martirizado": "martirizar",
    "martirizados": "martirizar",
    "martirizai": "martirizar",
    "martirizais": "martirizar",
    "martirizam": "martirizar",
    "martirizamo": "martirizar",
    "martirizamos": "martirizar",
    "martirizando": "martirizar",
    "martirizara": "martirizar",
    "martirizaram": "martirizar",
    "martirizaras": "martirizar",
    "martirizarde": "martirizar",
    "martirizardes": "martirizar",
    "martirizare": "martirizar",
    "martirizarei": "martirizar",
    "martirizareis": "martirizar",
    "martirizarem": "martirizar",
    "martirizaremos": "martirizar",
    "martirizares": "martirizar",
    "martirizaria": "martirizar",
    "martirizariam": "martirizar",
    "martirizarias": "martirizar",
    "martirizarmo": "martirizar",
    "martirizarmos": "martirizar",
    "martirizará": "martirizar",
    "martirizarás": "martirizar",
    "martirizarão": "martirizar",
    "martirizaríamos": "martirizar",
    "martirizaríeis": "martirizar",
    "martirizas": "martirizar",
    "martirizasse": "martirizar",
    "martirizassem": "martirizar",
    "martirizasses": "martirizar",
    "martirizaste": "martirizar",
    "martirizastes": "martirizar",
    "martirizava": "martirizar",
    "martirizavam": "martirizar",
    "martirizavas": "martirizar",
    "martirizações": "martirização",
    "martirize": "martirizar",
    "martirizei": "martirizar",
    "martirizeis": "martirizar",
    "martirizem": "martirizar",
    "martirizemo": "martirizar",
    "martirizemos": "martirizar",
    "martirizes": "martirizar",
    "martirizo": "martirizar",
    "martirizou": "martirizar",
    "martirizá": "martirizar",
    "martirizámo": "martirizar",
    "martirizámos": "martirizar",
    "martirizáramo": "martirizar",
    "martirizáramos": "martirizar",
    "martirizárei": "martirizar",
    "martirizáreis": "martirizar",
    "martirizásseis": "martirizar",
    "martirizássemos": "martirizar",
    "martirizávamo": "martirizar",
    "martirizávamos": "martirizar",
    "martirizávei": "martirizar",
    "martirizáveis": "martirizar",
    "martirologistas": "martirologista",
    "martirológios": "martirológio",
    "martites": "martite",
    "martos": "marto",
    "martínis": "martíni",
    "martírios": "martírio",
    "marubás": "marubá",
    "marufles": "marufle",
    "marufos": "marufo",
    "marugens": "marugem",
    "maruins": "maruim",
    "maruja": "marujo",
    "marujada": "marujar",
    "marujadas": "marujar",
    "marujado": "marujar",
    "marujados": "marujar",
    "marujai": "marujar",
    "marujais": "marujar",
    "marujam": "marujar",
    "marujamo": "marujar",
    "marujamos": "marujar",
    "marujando": "marujar",
    "marujara": "marujar",
    "marujaram": "marujar",
    "marujaras": "marujar",
    "marujardes": "marujar",
    "marujarei": "marujar",
    "marujareis": "marujar",
    "marujarem": "marujar",
    "marujaremos": "marujar",
    "marujares": "marujar",
    "marujaria": "marujar",
    "marujariam": "marujar",
    "marujarias": "marujar",
    "marujarmo": "marujar",
    "marujarmos": "marujar",
    "marujará": "marujar",
    "marujarás": "marujar",
    "marujarão": "marujar",
    "marujaríamos": "marujar",
    "marujaríeis": "marujar",
    "marujas": "marujo",
    "marujasse": "marujar",
    "marujassem": "marujar",
    "marujasses": "marujar",
    "marujaste": "marujar",
    "marujastes": "marujar",
    "marujava": "marujar",
    "marujavam": "marujar",
    "marujavas": "marujar",
    "maruje": "marujar",
    "marujei": "marujar",
    "marujeis": "marujar",
    "marujem": "marujar",
    "marujemo": "marujar",
    "marujemos": "marujar",
    "marujes": "marujar",
    "marujinhas": "marujinha",
    "marujo": "marujar",
    "marujos": "marujo",
    "marujou": "marujar",
    "marujámo": "marujar",
    "marujámos": "marujar",
    "marujáramo": "marujar",
    "marujáramos": "marujar",
    "marujáreis": "marujar",
    "marujásseis": "marujar",
    "marujássemos": "marujar",
    "marujávamo": "marujar",
    "marujávamos": "marujar",
    "marujáveis": "marujar",
    "marulha": "marulhar",
    "marulhada": "marulhar",
    "marulhadas": "marulhar",
    "marulhado": "marulhar",
    "marulhados": "marulhar",
    "marulhai": "marulhar",
    "marulhais": "marulhar",
    "marulham": "marulhar",
    "marulhamo": "marulhar",
    "marulhamos": "marulhar",
    "marulhando": "marulhar",
    "marulhara": "marulhar",
    "marulharam": "marulhar",
    "marulharas": "marulhar",
    "marulhardes": "marulhar",
    "marulharei": "marulhar",
    "marulhareis": "marulhar",
    "marulharem": "marulhar",
    "marulharemos": "marulhar",
    "marulhares": "marulhar",
    "marulharia": "marulhar",
    "marulhariam": "marulhar",
    "marulharias": "marulhar",
    "marulharmo": "marulhar",
    "marulharmos": "marulhar",
    "marulhará": "marulhar",
    "marulharás": "marulhar",
    "marulharão": "marulhar",
    "marulharíamos": "marulhar",
    "marulharíeis": "marulhar",
    "marulhas": "marulhar",
    "marulhasse": "marulhar",
    "marulhassem": "marulhar",
    "marulhasses": "marulhar",
    "marulhaste": "marulhar",
    "marulhastes": "marulhar",
    "marulhava": "marulhar",
    "marulhavam": "marulhar",
    "marulhavas": "marulhar",
    "marulhe": "marulhar",
    "marulhei": "marulhar",
    "marulheira": "marulheiro",
    "marulheiras": "marulheiro",
    "marulheiros": "marulheiro",
    "marulheis": "marulhar",
    "marulhem": "marulhar",
    "marulhemo": "marulhar",
    "marulhemos": "marulhar",
    "marulhenta": "marulhento",
    "marulhentas": "marulhento",
    "marulhentos": "marulhento",
    "marulhes": "marulhar",
    "marulho": "marulhar",
    "marulhos": "marulho",
    "marulhosa": "marulhoso",
    "marulhosas": "marulhoso",
    "marulhosos": "marulhoso",
    "marulhou": "marulhar",
    "marulhámo": "marulhar",
    "marulhámos": "marulhar",
    "marulháramo": "marulhar",
    "marulháramos": "marulhar",
    "marulháreis": "marulhar",
    "marulhásseis": "marulhar",
    "marulhássemos": "marulhar",
    "marulhávamo": "marulhar",
    "marulhávamos": "marulhar",
    "marulháveis": "marulhar",
    "maruoranas": "maruorana",
    "marupaúbas": "marupaúba",
    "marupás": "marupá",
    "marurus": "maruru",
    "maruís": "maruí",
    "marxismos": "marxismo",
    "marxistas": "marxista",
    "marzinho": "mar",
    "marzinhos": "mar",
    "marzito": "mar",
    "marzitos": "mar",
    "marás": "mará",
    "marçagões": "marçagão",
    "marçalina": "marçalino",
    "marçalinas": "marçalino",
    "marçalinos": "marçalino",
    "marçana": "marçano",
    "marçanas": "marçano",
    "marçanos": "marçano",
    "marégrafos": "marégrafo",
    "maréis": "marel",
    "marémetros": "marémetro",
    "marés": "maré",
    "marítima": "marítimo",
    "marítimas": "marítimo",
    "marítimos": "marítimo",
    "masarulhos": "masarulho",
    "masca": "mascar",
    "mascada": "mascar",
    "mascadas": "mascar",
    "mascado": "mascar",
    "mascadora": "mascador",
    "mascadoras": "mascador",
    "mascadores": "mascador",
    "mascados": "mascar",
    "mascai": "mascar",
    "mascais": "mascar",
    "mascam": "mascar",
    "mascamo": "mascar",
    "mascamos": "mascar",
    "mascando": "mascar",
    "mascara": "mascarar",
    "mascarada": "mascarar",
    "mascaradas": "mascarar",
    "mascaradinha": "mascarado",
    "mascaradinhas": "mascarado",
    "mascaradinho": "mascarado",
    "mascaradinhos": "mascarado",
    "mascaradita": "mascarado",
    "mascaraditas": "mascarado",
    "mascaradito": "mascarado",
    "mascaraditos": "mascarado",
    "mascarado": "mascarar",
    "mascarados": "mascarar",
    "mascaradíssima": "mascarado",
    "mascaradíssimas": "mascarado",
    "mascaradíssimo": "mascarado",
    "mascaradíssimos": "mascarado",
    "mascarai": "mascarar",
    "mascarais": "mascarar",
    "mascaram": "mascarar",
    "mascaramo": "mascarar",
    "mascaramos": "mascarar",
    "mascarando": "mascarar",
    "mascarara": "mascarar",
    "mascararam": "mascarar",
    "mascararas": "mascarar",
    "mascararde": "mascarar",
    "mascarardes": "mascarar",
    "mascarare": "mascarar",
    "mascararei": "mascarar",
    "mascarareis": "mascarar",
    "mascararem": "mascarar",
    "mascararemos": "mascarar",
    "mascarares": "mascarar",
    "mascararia": "mascarar",
    "mascarariam": "mascarar",
    "mascararias": "mascarar",
    "mascararmo": "mascarar",
    "mascararmos": "mascarar",
    "mascarará": "mascarar",
    "mascararás": "mascarar",
    "mascararão": "mascarar",
    "mascararíamos": "mascarar",
    "mascararíeis": "mascarar",
    "mascaras": "mascarar",
    "mascarasse": "mascarar",
    "mascarassem": "mascarar",
    "mascarasses": "mascarar",
    "mascaraste": "mascarar",
    "mascarastes": "mascarar",
    "mascarava": "mascarar",
    "mascaravam": "mascarar",
    "mascaravas": "mascarar",
    "mascarde": "mascar",
    "mascardes": "mascar",
    "mascare": "mascarar",
    "mascarei": "mascarar",
    "mascareis": "mascarar",
    "mascarem": "mascarar",
    "mascaremo": "mascarar",
    "mascaremos": "mascarar",
    "mascares": "mascarar",
    "mascaria": "mascar",
    "mascariam": "mascar",
    "mascarias": "mascar",
    "mascarilhas": "mascarilha",
    "mascarina": "mascarino",
    "mascarinas": "mascarino",
    "mascarinos": "mascarino",
    "mascarmo": "mascar",
    "mascarmos": "mascar",
    "mascaro": "mascarar",
    "mascarou": "mascarar",
    "mascarra": "mascarrar",
    "mascarrada": "mascarrar",
    "mascarradas": "mascarrar",
    "mascarrado": "mascarrar",
    "mascarrados": "mascarrar",
    "mascarrai": "mascarrar",
    "mascarrais": "mascarrar",
    "mascarram": "mascarrar",
    "mascarramo": "mascarrar",
    "mascarramos": "mascarrar",
    "mascarrando": "mascarrar",
    "mascarrara": "mascarrar",
    "mascarraram": "mascarrar",
    "mascarraras": "mascarrar",
    "mascarrarde": "mascarrar",
    "mascarrardes": "mascarrar",
    "mascarrare": "mascarrar",
    "mascarrarei": "mascarrar",
    "mascarrareis": "mascarrar",
    "mascarrarem": "mascarrar",
    "mascarraremos": "mascarrar",
    "mascarrares": "mascarrar",
    "mascarraria": "mascarrar",
    "mascarrariam": "mascarrar",
    "mascarrarias": "mascarrar",
    "mascarrarmo": "mascarrar",
    "mascarrarmos": "mascarrar",
    "mascarrará": "mascarrar",
    "mascarrarás": "mascarrar",
    "mascarrarão": "mascarrar",
    "mascarraríamos": "mascarrar",
    "mascarraríeis": "mascarrar",
    "mascarras": "mascarrar",
    "mascarrasse": "mascarrar",
    "mascarrassem": "mascarrar",
    "mascarrasses": "mascarrar",
    "mascarraste": "mascarrar",
    "mascarrastes": "mascarrar",
    "mascarrava": "mascarrar",
    "mascarravam": "mascarrar",
    "mascarravas": "mascarrar",
    "mascarre": "mascarrar",
    "mascarrei": "mascarrar",
    "mascarreis": "mascarrar",
    "mascarrem": "mascarrar",
    "mascarremo": "mascarrar",
    "mascarremos": "mascarrar",
    "mascarres": "mascarrar",
    "mascarro": "mascarrar",
    "mascarrou": "mascarrar",
    "mascarrá": "mascarrar",
    "mascarrámo": "mascarrar",
    "mascarrámos": "mascarrar",
    "mascarráramo": "mascarrar",
    "mascarráramos": "mascarrar",
    "mascarrárei": "mascarrar",
    "mascarráreis": "mascarrar",
    "mascarrásseis": "mascarrar",
    "mascarrássemos": "mascarrar",
    "mascarrávamo": "mascarrar",
    "mascarrávamos": "mascarrar",
    "mascarrávei": "mascarrar",
    "mascarráveis": "mascarrar",
    "mascará": "mascarar",
    "mascarámo": "mascarar",
    "mascarámos": "mascarar",
    "mascaráramo": "mascarar",
    "mascaráramos": "mascarar",
    "mascarárei": "mascarar",
    "mascaráreis": "mascarar",
    "mascarás": "mascar",
    "mascarásseis": "mascarar",
    "mascarássemos": "mascarar",
    "mascarávamo": "mascarar",
    "mascarávamos": "mascarar",
    "mascarávei": "mascarar",
    "mascaráveis": "mascarável",
    "mascarão": "mascar",
    "mascaríamos": "mascar",
    "mascaríeis": "mascar",
    "mascarões": "mascarão",
    "mascas": "mascar",
    "mascasse": "mascar",
    "mascassem": "mascar",
    "mascasses": "mascar",
    "mascaste": "mascar",
    "mascastes": "mascar",
    "mascateada": "mascatear",
    "mascateadas": "mascatear",
    "mascateado": "mascatear",
    "mascateados": "mascatear",
    "mascateai": "mascatear",
    "mascateais": "mascatear",
    "mascateamo": "mascatear",
    "mascateamos": "mascatear",
    "mascateando": "mascatear",
    "mascateara": "mascatear",
    "mascatearam": "mascatear",
    "mascatearas": "mascatear",
    "mascateardes": "mascatear",
    "mascatearei": "mascatear",
    "mascateareis": "mascatear",
    "mascatearem": "mascatear",
    "mascatearemos": "mascatear",
    "mascateares": "mascatear",
    "mascatearia": "mascatear",
    "mascateariam": "mascatear",
    "mascatearias": "mascatear",
    "mascatearmo": "mascatear",
    "mascatearmos": "mascatear",
    "mascateará": "mascatear",
    "mascatearás": "mascatear",
    "mascatearão": "mascatear",
    "mascatearíamos": "mascatear",
    "mascatearíeis": "mascatear",
    "mascateasse": "mascatear",
    "mascateassem": "mascatear",
    "mascateasses": "mascatear",
    "mascateaste": "mascatear",
    "mascateastes": "mascatear",
    "mascateava": "mascatear",
    "mascateavam": "mascatear",
    "mascateavas": "mascatear",
    "mascateações": "mascateação",
    "mascateei": "mascatear",
    "mascateeis": "mascatear",
    "mascateemo": "mascatear",
    "mascateemos": "mascatear",
    "mascateia": "mascatear",
    "mascateiam": "mascatear",
    "mascateias": "mascatear",
    "mascateie": "mascatear",
    "mascateiem": "mascatear",
    "mascateies": "mascatear",
    "mascateio": "mascatear",
    "mascateiras": "mascateira",
    "mascateou": "mascatear",
    "mascates": "mascate",
    "mascateámo": "mascatear",
    "mascateámos": "mascatear",
    "mascateáramo": "mascatear",
    "mascateáramos": "mascatear",
    "mascateáreis": "mascatear",
    "mascateásseis": "mascatear",
    "mascateássemos": "mascatear",
    "mascateávamo": "mascatear",
    "mascateávamos": "mascatear",
    "mascateáveis": "mascatear",
    "mascatos": "mascato",
    "mascava": "mascavo",
    "mascavada": "mascavar",
    "mascavadas": "mascavar",
    "mascavado": "mascavar",
    "mascavados": "mascavar",
    "mascavai": "mascavar",
    "mascavais": "mascavar",
    "mascavam": "mascavar",
    "mascavamo": "mascavar",
    "mascavamos": "mascavar",
    "mascavando": "mascavar",
    "mascavara": "mascavar",
    "mascavaram": "mascavar",
    "mascavaras": "mascavar",
    "mascavarde": "mascavar",
    "mascavardes": "mascavar",
    "mascavare": "mascavar",
    "mascavarei": "mascavar",
    "mascavareis": "mascavar",
    "mascavarem": "mascavar",
    "mascavaremos": "mascavar",
    "mascavares": "mascavar",
    "mascavaria": "mascavar",
    "mascavariam": "mascavar",
    "mascavarias": "mascavar",
    "mascavarmo": "mascavar",
    "mascavarmos": "mascavar",
    "mascavará": "mascavar",
    "mascavarás": "mascavar",
    "mascavarão": "mascavar",
    "mascavaríamos": "mascavar",
    "mascavaríeis": "mascavar",
    "mascavas": "mascavo",
    "mascavasse": "mascavar",
    "mascavassem": "mascavar",
    "mascavasses": "mascavar",
    "mascavaste": "mascavar",
    "mascavastes": "mascavar",
    "mascavava": "mascavar",
    "mascavavam": "mascavar",
    "mascavavas": "mascavar",
    "mascave": "mascavar",
    "mascavei": "mascavar",
    "mascaveis": "mascavar",
    "mascavem": "mascavar",
    "mascavemo": "mascavar",
    "mascavemos": "mascavar",
    "mascaves": "mascavar",
    "mascavinhos": "mascavinho",
    "mascavo": "mascavar",
    "mascavos": "mascavo",
    "mascavou": "mascavar",
    "mascavá": "mascavar",
    "mascavámo": "mascavar",
    "mascavámos": "mascavar",
    "mascaváramo": "mascavar",
    "mascaváramos": "mascavar",
    "mascavárei": "mascavar",
    "mascaváreis": "mascavar",
    "mascavásseis": "mascavar",
    "mascavássemos": "mascavar",
    "mascavávamo": "mascavar",
    "mascavávamos": "mascavar",
    "mascavávei": "mascavar",
    "mascaváveis": "mascavar",
    "masco": "mascar",
    "mascota": "mascotar",
    "mascotada": "mascotar",
    "mascotadas": "mascotar",
    "mascotado": "mascotar",
    "mascotados": "mascotar",
    "mascotai": "mascotar",
    "mascotais": "mascotar",
    "mascotam": "mascotar",
    "mascotamo": "mascotar",
    "mascotamos": "mascotar",
    "mascotando": "mascotar",
    "mascotara": "mascotar",
    "mascotaram": "mascotar",
    "mascotaras": "mascotar",
    "mascotarde": "mascotar",
    "mascotardes": "mascotar",
    "mascotare": "mascotar",
    "mascotarei": "mascotar",
    "mascotareis": "mascotar",
    "mascotarem": "mascotar",
    "mascotaremos": "mascotar",
    "mascotares": "mascotar",
    "mascotaria": "mascotar",
    "mascotariam": "mascotar",
    "mascotarias": "mascotar",
    "mascotarmo": "mascotar",
    "mascotarmos": "mascotar",
    "mascotará": "mascotar",
    "mascotarás": "mascotar",
    "mascotarão": "mascotar",
    "mascotaríamos": "mascotar",
    "mascotaríeis": "mascotar",
    "mascotas": "mascotar",
    "mascotasse": "mascotar",
    "mascotassem": "mascotar",
    "mascotasses": "mascotar",
    "mascotaste": "mascotar",
    "mascotastes": "mascotar",
    "mascotava": "mascotar",
    "mascotavam": "mascotar",
    "mascotavas": "mascotar",
    "mascote": "mascotar",
    "mascotei": "mascotar",
    "mascoteis": "mascotar",
    "mascotem": "mascotar",
    "mascotemo": "mascotar",
    "mascotemos": "mascotar",
    "mascotes": "mascote",
    "mascoto": "mascotar",
    "mascotos": "mascoto",
    "mascotou": "mascotar",
    "mascotá": "mascotar",
    "mascotámo": "mascotar",
    "mascotámos": "mascotar",
    "mascotáramo": "mascotar",
    "mascotáramos": "mascotar",
    "mascotárei": "mascotar",
    "mascotáreis": "mascotar",
    "mascotásseis": "mascotar",
    "mascotássemos": "mascotar",
    "mascotávamo": "mascotar",
    "mascotávamos": "mascotar",
    "mascotávei": "mascotar",
    "mascotáveis": "mascotar",
    "mascou": "mascar",
    "masculiflora": "masculifloro",
    "masculifloras": "masculifloro",
    "masculifloros": "masculifloro",
    "masculina": "masculino",
    "masculinas": "masculino",
    "masculinidades": "masculinidade",
    "masculinismos": "masculinismo",
    "masculiniza": "masculinizar",
    "masculinizada": "masculinizar",
    "masculinizadas": "masculinizar",
    "masculinizado": "masculinizar",
    "masculinizados": "masculinizar",
    "masculinizai": "masculinizar",
    "masculinizais": "masculinizar",
    "masculinizam": "masculinizar",
    "masculinizamo": "masculinizar",
    "masculinizamos": "masculinizar",
    "masculinizando": "masculinizar",
    "masculinizara": "masculinizar",
    "masculinizaram": "masculinizar",
    "masculinizaras": "masculinizar",
    "masculinizarde": "masculinizar",
    "masculinizardes": "masculinizar",
    "masculinizare": "masculinizar",
    "masculinizarei": "masculinizar",
    "masculinizareis": "masculinizar",
    "masculinizarem": "masculinizar",
    "masculinizaremos": "masculinizar",
    "masculinizares": "masculinizar",
    "masculinizaria": "masculinizar",
    "masculinizariam": "masculinizar",
    "masculinizarias": "masculinizar",
    "masculinizarmo": "masculinizar",
    "masculinizarmos": "masculinizar",
    "masculinizará": "masculinizar",
    "masculinizarás": "masculinizar",
    "masculinizarão": "masculinizar",
    "masculinizaríamos": "masculinizar",
    "masculinizaríeis": "masculinizar",
    "masculinizas": "masculinizar",
    "masculinizasse": "masculinizar",
    "masculinizassem": "masculinizar",
    "masculinizasses": "masculinizar",
    "masculinizaste": "masculinizar",
    "masculinizastes": "masculinizar",
    "masculinizava": "masculinizar",
    "masculinizavam": "masculinizar",
    "masculinizavas": "masculinizar",
    "masculinizações": "masculinização",
    "masculinize": "masculinizar",
    "masculinizei": "masculinizar",
    "masculinizeis": "masculinizar",
    "masculinizem": "masculinizar",
    "masculinizemo": "masculinizar",
    "masculinizemos": "masculinizar",
    "masculinizes": "masculinizar",
    "masculinizo": "masculinizar",
    "masculinizou": "masculinizar",
    "masculinizá": "masculinizar",
    "masculinizámo": "masculinizar",
    "masculinizámos": "masculinizar",
    "masculinizáramo": "masculinizar",
    "masculinizáramos": "masculinizar",
    "masculinizárei": "masculinizar",
    "masculinizáreis": "masculinizar",
    "masculinizásseis": "masculinizar",
    "masculinizássemos": "masculinizar",
    "masculinizávamo": "masculinizar",
    "masculinizávamos": "masculinizar",
    "masculinizávei": "masculinizar",
    "masculinizáveis": "masculinizável",
    "masculinos": "masculino",
    "mascá": "mascar",
    "mascámo": "mascar",
    "mascámos": "mascar",
    "mascáramo": "mascar",
    "mascáramos": "mascar",
    "mascárei": "mascar",
    "mascáreis": "mascar",
    "mascásseis": "mascar",
    "mascássemos": "mascar",
    "mascávamo": "mascar",
    "mascávamos": "mascar",
    "mascávei": "mascar",
    "mascáveis": "mascável",
    "masdeísmos": "masdeísmo",
    "masdeístas": "masdeísta",
    "maseres": "maser",
    "masmarra": "masmarro",
    "masmarras": "masmarro",
    "masmarros": "masmarro",
    "masmorras": "masmorra",
    "masmorreira": "masmorreiro",
    "masmorreiras": "masmorreiro",
    "masmorreiros": "masmorreiro",
    "masochismos": "masochismo",
    "masochistas": "masochista",
    "masochistazinha": "masochista",
    "masochistazinhas": "masochista",
    "masochistazinho": "masochista",
    "masochistazinhos": "masochista",
    "masochistazita": "masochista",
    "masochistazitas": "masochista",
    "masochistazito": "masochista",
    "masochistazitos": "masochista",
    "masoquismos": "masoquismo",
    "masoquistas": "masoquista",
    "masque": "mascar",
    "masquei": "mascar",
    "masqueis": "mascar",
    "masquem": "mascar",
    "masquemo": "mascar",
    "masquemos": "mascar",
    "masques": "mascar",
    "massacatos": "massacato",
    "massacra": "massacrar",
    "massacrada": "massacrar",
    "massacradas": "massacrar",
    "massacrado": "massacrar",
    "massacrados": "massacrar",
    "massacrai": "massacrar",
    "massacrais": "massacrar",
    "massacram": "massacrar",
    "massacramo": "massacrar",
    "massacramos": "massacrar",
    "massacrando": "massacrar",
    "massacrara": "massacrar",
    "massacraram": "massacrar",
    "massacraras": "massacrar",
    "massacrarde": "massacrar",
    "massacrardes": "massacrar",
    "massacrare": "massacrar",
    "massacrarei": "massacrar",
    "massacrareis": "massacrar",
    "massacrarem": "massacrar",
    "massacraremos": "massacrar",
    "massacrares": "massacrar",
    "massacraria": "massacrar",
    "massacrariam": "massacrar",
    "massacrarias": "massacrar",
    "massacrarmo": "massacrar",
    "massacrarmos": "massacrar",
    "massacrará": "massacrar",
    "massacrarás": "massacrar",
    "massacrarão": "massacrar",
    "massacraríamos": "massacrar",
    "massacraríeis": "massacrar",
    "massacras": "massacrar",
    "massacrasse": "massacrar",
    "massacrassem": "massacrar",
    "massacrasses": "massacrar",
    "massacraste": "massacrar",
    "massacrastes": "massacrar",
    "massacrava": "massacrar",
    "massacravam": "massacrar",
    "massacravas": "massacrar",
    "massacre": "massacrar",
    "massacrei": "massacrar",
    "massacreis": "massacrar",
    "massacrem": "massacrar",
    "massacremo": "massacrar",
    "massacremos": "massacrar",
    "massacres": "massacre",
    "massacro": "massacrar",
    "massacrou": "massacrar",
    "massacrá": "massacrar",
    "massacrámo": "massacrar",
    "massacrámos": "massacrar",
    "massacráramo": "massacrar",
    "massacráramos": "massacrar",
    "massacrárei": "massacrar",
    "massacráreis": "massacrar",
    "massacrásseis": "massacrar",
    "massacrássemos": "massacrar",
    "massacrávamo": "massacrar",
    "massacrávamos": "massacrar",
    "massacrávei": "massacrar",
    "massacráveis": "massacrar",
    "massagadas": "massagada",
    "massageamentos": "massageamento",
    "massagens": "massagem",
    "massagistas": "massagista",
    "massambalas": "massambala",
    "massambarás": "massambará",
    "massames": "massame",
    "massamordas": "massamorda",
    "massangos": "massango",
    "massapés": "massapé",
    "massarocas": "massaroca",
    "massarocos": "massaroco",
    "massas": "massa",
    "masseiras": "masseira",
    "masseirões": "masseirão",
    "masseterina": "masseterino",
    "masseterinas": "masseterino",
    "masseterinos": "masseterino",
    "massetérica": "massetérico",
    "massetéricas": "massetérico",
    "massetéricos": "massetérico",
    "massicotes": "massicote",
    "massifica": "massificar",
    "massificada": "massificar",
    "massificadas": "massificar",
    "massificado": "massificar",
    "massificados": "massificar",
    "massificai": "massificar",
    "massificais": "massificar",
    "massificam": "massificar",
    "massificamo": "massificar",
    "massificamos": "massificar",
    "massificando": "massificar",
    "massificara": "massificar",
    "massificaram": "massificar",
    "massificaras": "massificar",
    "massificarde": "massificar",
    "massificardes": "massificar",
    "massificare": "massificar",
    "massificarei": "massificar",
    "massificareis": "massificar",
    "massificarem": "massificar",
    "massificaremos": "massificar",
    "massificares": "massificar",
    "massificaria": "massificar",
    "massificariam": "massificar",
    "massificarias": "massificar",
    "massificarmo": "massificar",
    "massificarmos": "massificar",
    "massificará": "massificar",
    "massificarás": "massificar",
    "massificarão": "massificar",
    "massificaríamos": "massificar",
    "massificaríeis": "massificar",
    "massificas": "massificar",
    "massificasse": "massificar",
    "massificassem": "massificar",
    "massificasses": "massificar",
    "massificaste": "massificar",
    "massificastes": "massificar",
    "massificava": "massificar",
    "massificavam": "massificar",
    "massificavas": "massificar",
    "massificações": "massificação",
    "massifico": "massificar",
    "massificou": "massificar",
    "massificá": "massificar",
    "massificámo": "massificar",
    "massificámos": "massificar",
    "massificáramo": "massificar",
    "massificáramos": "massificar",
    "massificárei": "massificar",
    "massificáreis": "massificar",
    "massificásseis": "massificar",
    "massificássemos": "massificar",
    "massificávamo": "massificar",
    "massificávamos": "massificar",
    "massificávei": "massificar",
    "massificáveis": "massificar",
    "massifique": "massificar",
    "massifiquei": "massificar",
    "massifiqueis": "massificar",
    "massifiquem": "massificar",
    "massifiquemo": "massificar",
    "massifiquemos": "massificar",
    "massifiques": "massificar",
    "massilhas": "massilha",
    "massinha": "massa",
    "massinhas": "massinha",
    "massita": "massa",
    "massitas": "massa",
    "massiva": "massivo",
    "massivas": "massivo",
    "massivos": "massivo",
    "massoterapias": "massoterapia",
    "massuda": "massudo",
    "massudas": "massudo",
    "massudos": "massudo",
    "massulipatões": "massulipatão",
    "masséteres": "masséter",
    "mastabas": "mastaba",
    "mastalgias": "mastalgia",
    "mastaréus": "mastaréu",
    "mastectomias": "mastectomia",
    "masticatória": "masticatório",
    "masticatórias": "masticatório",
    "masticatórios": "masticatório",
    "mastiga": "mastigar",
    "mastigada": "mastigar",
    "mastigadas": "mastigar",
    "mastigadinha": "mastigado",
    "mastigadinhas": "mastigado",
    "mastigadinho": "mastigado",
    "mastigadinhos": "mastigado",
    "mastigadita": "mastigado",
    "mastigaditas": "mastigado",
    "mastigadito": "mastigado",
    "mastigaditos": "mastigado",
    "mastigado": "mastigar",
    "mastigadoiros": "mastigadoiro",
    "mastigadora": "mastigador",
    "mastigadoras": "mastigador",
    "mastigadores": "mastigador",
    "mastigados": "mastigar",
    "mastigadouros": "mastigadouro",
    "mastigadíssima": "mastigado",
    "mastigadíssimas": "mastigado",
    "mastigadíssimo": "mastigado",
    "mastigadíssimos": "mastigado",
    "mastigai": "mastigar",
    "mastigais": "mastigar",
    "mastigam": "mastigar",
    "mastigamo": "mastigar",
    "mastigamos": "mastigar",
    "mastigando": "mastigar",
    "mastigara": "mastigar",
    "mastigaram": "mastigar",
    "mastigaras": "mastigar",
    "mastigarde": "mastigar",
    "mastigardes": "mastigar",
    "mastigare": "mastigar",
    "mastigarei": "mastigar",
    "mastigareis": "mastigar",
    "mastigarem": "mastigar",
    "mastigaremos": "mastigar",
    "mastigares": "mastigar",
    "mastigaria": "mastigar",
    "mastigariam": "mastigar",
    "mastigarias": "mastigar",
    "mastigarmo": "mastigar",
    "mastigarmos": "mastigar",
    "mastigará": "mastigar",
    "mastigarás": "mastigar",
    "mastigarão": "mastigar",
    "mastigaríamos": "mastigar",
    "mastigaríeis": "mastigar",
    "mastigas": "mastigar",
    "mastigasse": "mastigar",
    "mastigassem": "mastigar",
    "mastigasses": "mastigar",
    "mastigaste": "mastigar",
    "mastigastes": "mastigar",
    "mastigatória": "mastigatório",
    "mastigatórias": "mastigatório",
    "mastigatórios": "mastigatório",
    "mastigava": "mastigar",
    "mastigavam": "mastigar",
    "mastigavas": "mastigar",
    "mastigações": "mastigação",
    "mastigo": "mastigar",
    "mastigou": "mastigar",
    "mastigue": "mastigar",
    "mastiguei": "mastigar",
    "mastigueis": "mastigar",
    "mastiguem": "mastigar",
    "mastiguemo": "mastigar",
    "mastiguemos": "mastigar",
    "mastigues": "mastigar",
    "mastigá": "mastigar",
    "mastigámo": "mastigar",
    "mastigámos": "mastigar",
    "mastigáramo": "mastigar",
    "mastigáramos": "mastigar",
    "mastigárei": "mastigar",
    "mastigáreis": "mastigar",
    "mastigásseis": "mastigar",
    "mastigássemos": "mastigar",
    "mastigávamo": "mastigar",
    "mastigávamos": "mastigar",
    "mastigávei": "mastigar",
    "mastigáveis": "mastigável",
    "mastins": "mastim",
    "mastites": "mastite",
    "mastodinias": "mastodinia",
    "mastodonta": "mastodonte",
    "mastodontas": "mastodonte",
    "mastodontes": "mastodonte",
    "mastodontídeos": "mastodontídeo",
    "mastodôntica": "mastodôntico",
    "mastodônticas": "mastodôntico",
    "mastodônticos": "mastodôntico",
    "mastodôntidas": "mastodôntida",
    "mastoidites": "mastoidite",
    "mastologias": "mastologia",
    "mastoquinos": "mastoquino",
    "mastotomias": "mastotomia",
    "mastozoologias": "mastozoologia",
    "mastozoários": "mastozoário",
    "mastozoótica": "mastozoótico",
    "mastozoóticas": "mastozoótico",
    "mastozoóticos": "mastozoótico",
    "mastreada": "mastrear",
    "mastreadas": "mastrear",
    "mastreado": "mastrear",
    "mastreados": "mastrear",
    "mastreai": "mastrear",
    "mastreais": "mastrear",
    "mastreamo": "mastrear",
    "mastreamos": "mastrear",
    "mastreando": "mastrear",
    "mastreara": "mastrear",
    "mastrearam": "mastrear",
    "mastrearas": "mastrear",
    "mastrearde": "mastrear",
    "mastreardes": "mastrear",
    "mastreare": "mastrear",
    "mastrearei": "mastrear",
    "mastreareis": "mastrear",
    "mastrearem": "mastrear",
    "mastrearemos": "mastrear",
    "mastreares": "mastrear",
    "mastrearia": "mastrear",
    "mastreariam": "mastrear",
    "mastrearias": "mastrear",
    "mastrearmo": "mastrear",
    "mastrearmos": "mastrear",
    "mastreará": "mastrear",
    "mastrearás": "mastrear",
    "mastrearão": "mastrear",
    "mastrearíamos": "mastrear",
    "mastrearíeis": "mastrear",
    "mastreasse": "mastrear",
    "mastreassem": "mastrear",
    "mastreasses": "mastrear",
    "mastreaste": "mastrear",
    "mastreastes": "mastrear",
    "mastreava": "mastrear",
    "mastreavam": "mastrear",
    "mastreavas": "mastrear",
    "mastreações": "mastreação",
    "mastreei": "mastrear",
    "mastreeis": "mastrear",
    "mastreemo": "mastrear",
    "mastreemos": "mastrear",
    "mastreia": "mastrear",
    "mastreiam": "mastrear",
    "mastreias": "mastrear",
    "mastreie": "mastrear",
    "mastreiem": "mastrear",
    "mastreies": "mastrear",
    "mastreio": "mastrear",
    "mastreou": "mastrear",
    "mastreá": "mastrear",
    "mastreámo": "mastrear",
    "mastreámos": "mastrear",
    "mastreáramo": "mastrear",
    "mastreáramos": "mastrear",
    "mastreárei": "mastrear",
    "mastreáreis": "mastrear",
    "mastreásseis": "mastrear",
    "mastreássemos": "mastrear",
    "mastreávamo": "mastrear",
    "mastreávamos": "mastrear",
    "mastreávei": "mastrear",
    "mastreáveis": "mastrear",
    "mastros": "mastro",
    "mastruços": "mastruço",
    "masturba": "masturbar",
    "masturbada": "masturbar",
    "masturbadas": "masturbar",
    "masturbado": "masturbar",
    "masturbados": "masturbar",
    "masturbai": "masturbar",
    "masturbais": "masturbar",
    "masturbam": "masturbar",
    "masturbamo": "masturbar",
    "masturbamos": "masturbar",
    "masturbando": "masturbar",
    "masturbara": "masturbar",
    "masturbaram": "masturbar",
    "masturbaras": "masturbar",
    "masturbarde": "masturbar",
    "masturbardes": "masturbar",
    "masturbare": "masturbar",
    "masturbarei": "masturbar",
    "masturbareis": "masturbar",
    "masturbarem": "masturbar",
    "masturbaremos": "masturbar",
    "masturbares": "masturbar",
    "masturbaria": "masturbar",
    "masturbariam": "masturbar",
    "masturbarias": "masturbar",
    "masturbarmo": "masturbar",
    "masturbarmos": "masturbar",
    "masturbará": "masturbar",
    "masturbarás": "masturbar",
    "masturbarão": "masturbar",
    "masturbaríamos": "masturbar",
    "masturbaríeis": "masturbar",
    "masturbas": "masturbar",
    "masturbasse": "masturbar",
    "masturbassem": "masturbar",
    "masturbasses": "masturbar",
    "masturbaste": "masturbar",
    "masturbastes": "masturbar",
    "masturbava": "masturbar",
    "masturbavam": "masturbar",
    "masturbavas": "masturbar",
    "masturbações": "masturbação",
    "masturbe": "masturbar",
    "masturbei": "masturbar",
    "masturbeis": "masturbar",
    "masturbem": "masturbar",
    "masturbemo": "masturbar",
    "masturbemos": "masturbar",
    "masturbes": "masturbar",
    "masturbo": "masturbar",
    "masturbou": "masturbar",
    "masturbá": "masturbar",
    "masturbámo": "masturbar",
    "masturbámos": "masturbar",
    "masturbáramo": "masturbar",
    "masturbáramos": "masturbar",
    "masturbárei": "masturbar",
    "masturbáreis": "masturbar",
    "masturbásseis": "masturbar",
    "masturbássemos": "masturbar",
    "masturbávamo": "masturbar",
    "masturbávamos": "masturbar",
    "masturbávei": "masturbar",
    "masturbáveis": "masturbar",
    "mastóides": "mastóide",
    "mata": "matar",
    "matacanhas": "matacanha",
    "matacões": "matacão",
    "matada": "matar",
    "matadas": "matar",
    "matadelas": "matadela",
    "matado": "matar",
    "matadoiros": "matadoiro",
    "matadora": "matador",
    "matadoras": "matador",
    "matadores": "matador",
    "matados": "matar",
    "matadouros": "matadouro",
    "mataduras": "matadura",
    "matagais": "matagal",
    "matagosa": "matagoso",
    "matagosas": "matagoso",
    "matagosos": "matagoso",
    "matai": "matar",
    "matais": "matar",
    "matalota": "matalote",
    "matalotada": "matalotar",
    "matalotadas": "matalotar",
    "matalotado": "matalotar",
    "matalotados": "matalotar",
    "matalotagens": "matalotagem",
    "matalotai": "matalotar",
    "matalotais": "matalotar",
    "matalotam": "matalotar",
    "matalotamo": "matalotar",
    "matalotamos": "matalotar",
    "matalotando": "matalotar",
    "matalotara": "matalotar",
    "matalotaram": "matalotar",
    "matalotaras": "matalotar",
    "matalotarde": "matalotar",
    "matalotardes": "matalotar",
    "matalotare": "matalotar",
    "matalotarei": "matalotar",
    "matalotareis": "matalotar",
    "matalotarem": "matalotar",
    "matalotaremos": "matalotar",
    "matalotares": "matalotar",
    "matalotaria": "matalotar",
    "matalotariam": "matalotar",
    "matalotarias": "matalotar",
    "matalotarmo": "matalotar",
    "matalotarmos": "matalotar",
    "matalotará": "matalotar",
    "matalotarás": "matalotar",
    "matalotarão": "matalotar",
    "matalotaríamos": "matalotar",
    "matalotaríeis": "matalotar",
    "matalotas": "matalote",
    "matalotasse": "matalotar",
    "matalotassem": "matalotar",
    "matalotasses": "matalotar",
    "matalotaste": "matalotar",
    "matalotastes": "matalotar",
    "matalotava": "matalotar",
    "matalotavam": "matalotar",
    "matalotavas": "matalotar",
    "matalote": "matalotar",
    "matalotei": "matalotar",
    "mataloteis": "matalotar",
    "matalotem": "matalotar",
    "matalotemo": "matalotar",
    "matalotemos": "matalotar",
    "matalotes": "matalote",
    "mataloto": "matalotar",
    "matalotou": "matalotar",
    "matalotá": "matalotar",
    "matalotámo": "matalotar",
    "matalotámos": "matalotar",
    "matalotáramo": "matalotar",
    "matalotáramos": "matalotar",
    "matalotárei": "matalotar",
    "matalotáreis": "matalotar",
    "matalotásseis": "matalotar",
    "matalotássemos": "matalotar",
    "matalotávamo": "matalotar",
    "matalotávamos": "matalotar",
    "matalotávei": "matalotar",
    "matalotáveis": "matalotar",
    "matam": "matar",
    "matamatás": "matamatá",
    "matambus": "matambu",
    "matamo": "matar",
    "matamos": "matar",
    "matando": "matar",
    "matantes": "matante",
    "matanças": "matança",
    "matara": "matar",
    "mataram": "matar",
    "mataranas": "matarana",
    "mataras": "matar",
    "matarde": "matar",
    "matardes": "matar",
    "matare": "matar",
    "matarei": "matar",
    "matareis": "matar",
    "matarem": "matar",
    "mataremos": "matar",
    "matares": "matar",
    "mataria": "matar",
    "matariam": "matar",
    "matarias": "matar",
    "matarmo": "matar",
    "matarmos": "matar",
    "matará": "matar",
    "matarás": "matar",
    "matarão": "matar",
    "mataríamos": "matar",
    "mataríeis": "matar",
    "matas": "matar",
    "matasse": "matar",
    "matassem": "matar",
    "matasses": "matar",
    "mataste": "matar",
    "matastes": "matar",
    "matataúbas": "matataúba",
    "matava": "matar",
    "matavam": "matar",
    "matavas": "matar",
    "matações": "matação",
    "matches": "match",
    "mate": "matar",
    "mateada": "matear",
    "mateadas": "matear",
    "mateado": "matear",
    "mateados": "matear",
    "mateai": "matear",
    "mateais": "matear",
    "mateamo": "matear",
    "mateamos": "matear",
    "mateando": "matear",
    "mateara": "matear",
    "matearam": "matear",
    "matearas": "matear",
    "mateardes": "matear",
    "matearei": "matear",
    "mateareis": "matear",
    "matearem": "matear",
    "matearemos": "matear",
    "mateares": "matear",
    "matearia": "matear",
    "mateariam": "matear",
    "matearias": "matear",
    "matearmo": "matear",
    "matearmos": "matear",
    "mateará": "matear",
    "matearás": "matear",
    "matearão": "matear",
    "matearíamos": "matear",
    "matearíeis": "matear",
    "mateasse": "matear",
    "mateassem": "matear",
    "mateasses": "matear",
    "mateaste": "matear",
    "mateastes": "matear",
    "mateava": "matear",
    "mateavam": "matear",
    "mateavas": "matear",
    "matebeles": "matebele",
    "mateei": "matear",
    "mateeis": "matear",
    "mateemo": "matear",
    "mateemos": "matear",
    "matei": "matar",
    "mateia": "matear",
    "mateiam": "matear",
    "mateias": "matear",
    "mateie": "matear",
    "mateiem": "matear",
    "mateies": "matear",
    "mateio": "matear",
    "mateira": "mateiro",
    "mateiras": "mateiro",
    "mateiros": "mateiro",
    "mateis": "matar",
    "mateja": "matejar",
    "matejada": "matejar",
    "matejadas": "matejar",
    "matejado": "matejar",
    "matejados": "matejar",
    "matejai": "matejar",
    "matejais": "matejar",
    "matejam": "matejar",
    "matejamo": "matejar",
    "matejamos": "matejar",
    "matejando": "matejar",
    "matejara": "matejar",
    "matejaram": "matejar",
    "matejaras": "matejar",
    "matejardes": "matejar",
    "matejarei": "matejar",
    "matejareis": "matejar",
    "matejarem": "matejar",
    "matejaremos": "matejar",
    "matejares": "matejar",
    "matejaria": "matejar",
    "matejariam": "matejar",
    "matejarias": "matejar",
    "matejarmo": "matejar",
    "matejarmos": "matejar",
    "matejará": "matejar",
    "matejarás": "matejar",
    "matejarão": "matejar",
    "matejaríamos": "matejar",
    "matejaríeis": "matejar",
    "matejas": "matejar",
    "matejasse": "matejar",
    "matejassem": "matejar",
    "matejasses": "matejar",
    "matejaste": "matejar",
    "matejastes": "matejar",
    "matejava": "matejar",
    "matejavam": "matejar",
    "matejavas": "matejar",
    "mateje": "matejar",
    "matejei": "matejar",
    "matejeis": "matejar",
    "matejem": "matejar",
    "matejemo": "matejar",
    "matejemos": "matejar",
    "matejes": "matejar",
    "matejo": "matejar",
    "matejou": "matejar",
    "matejámo": "matejar",
    "matejámos": "matejar",
    "matejáramo": "matejar",
    "matejáramos": "matejar",
    "matejáreis": "matejar",
    "matejásseis": "matejar",
    "matejássemos": "matejar",
    "matejávamo": "matejar",
    "matejávamos": "matejar",
    "matejáveis": "matejar",
    "matem": "matar",
    "matematicidades": "matematicidade",
    "matematismos": "matematismo",
    "matematizações": "matematização",
    "matemo": "matar",
    "matemos": "matar",
    "matemática": "matemático",
    "matemáticas": "matemático",
    "matemáticos": "matemático",
    "mateologias": "mateologia",
    "mateologistas": "mateologista",
    "mateológica": "mateológico",
    "mateológicas": "mateológico",
    "mateológicos": "mateológico",
    "mateotecnias": "mateotecnia",
    "mateou": "matear",
    "materiais": "material",
    "materialeiras": "materialeira",
    "materialidades": "materialidade",
    "materialismos": "materialismo",
    "materialistas": "materialista",
    "materializa": "materializar",
    "materializada": "materializar",
    "materializadas": "materializar",
    "materializado": "materializar",
    "materializadora": "materializador",
    "materializadoras": "materializador",
    "materializadores": "materializador",
    "materializados": "materializar",
    "materializai": "materializar",
    "materializais": "materializar",
    "materializam": "materializar",
    "materializamo": "materializar",
    "materializamos": "materializar",
    "materializando": "materializar",
    "materializantes": "materializante",
    "materializara": "materializar",
    "materializaram": "materializar",
    "materializaras": "materializar",
    "materializarde": "materializar",
    "materializardes": "materializar",
    "materializare": "materializar",
    "materializarei": "materializar",
    "materializareis": "materializar",
    "materializarem": "materializar",
    "materializaremos": "materializar",
    "materializares": "materializar",
    "materializaria": "materializar",
    "materializariam": "materializar",
    "materializarias": "materializar",
    "materializarmo": "materializar",
    "materializarmos": "materializar",
    "materializará": "materializar",
    "materializarás": "materializar",
    "materializarão": "materializar",
    "materializaríamos": "materializar",
    "materializaríeis": "materializar",
    "materializas": "materializar",
    "materializasse": "materializar",
    "materializassem": "materializar",
    "materializasses": "materializar",
    "materializaste": "materializar",
    "materializastes": "materializar",
    "materializava": "materializar",
    "materializavam": "materializar",
    "materializavas": "materializar",
    "materializações": "materialização",
    "materialize": "materializar",
    "materializei": "materializar",
    "materializeis": "materializar",
    "materializem": "materializar",
    "materializemo": "materializar",
    "materializemos": "materializar",
    "materializes": "materializar",
    "materializo": "materializar",
    "materializou": "materializar",
    "materializá": "materializar",
    "materializámo": "materializar",
    "materializámos": "materializar",
    "materializáramo": "materializar",
    "materializáramos": "materializar",
    "materializárei": "materializar",
    "materializáreis": "materializar",
    "materializásseis": "materializar",
    "materializássemos": "materializar",
    "materializávamo": "materializar",
    "materializávamos": "materializar",
    "materializávei": "materializar",
    "materializáveis": "materializável",
    "materialona": "materialão",
    "materialonas": "materialão",
    "materialões": "materialão",
    "materna": "materno",
    "maternais": "maternal",
    "maternalíssima": "maternal",
    "maternalíssimas": "maternal",
    "maternalíssimo": "maternal",
    "maternalíssimos": "maternal",
    "maternas": "materno",
    "maternidades": "maternidade",
    "maternos": "materno",
    "mates": "mate",
    "mateámo": "matear",
    "mateámos": "matear",
    "mateáramo": "matear",
    "mateáramos": "matear",
    "mateáreis": "matear",
    "mateásseis": "matear",
    "mateássemos": "matear",
    "mateávamo": "matear",
    "mateávamos": "matear",
    "mateáveis": "matear",
    "mateóloga": "mateólogo",
    "mateólogas": "mateólogo",
    "mateólogos": "mateólogo",
    "matica": "maticar",
    "maticada": "maticar",
    "maticadas": "maticar",
    "maticado": "maticar",
    "maticados": "maticar",
    "maticai": "maticar",
    "maticais": "maticar",
    "maticam": "maticar",
    "maticamo": "maticar",
    "maticamos": "maticar",
    "maticando": "maticar",
    "maticara": "maticar",
    "maticaram": "maticar",
    "maticaras": "maticar",
    "maticarde": "maticar",
    "maticardes": "maticar",
    "maticare": "maticar",
    "maticarei": "maticar",
    "maticareis": "maticar",
    "maticarem": "maticar",
    "maticaremos": "maticar",
    "maticares": "maticar",
    "maticaria": "maticar",
    "maticariam": "maticar",
    "maticarias": "maticar",
    "maticarmo": "maticar",
    "maticarmos": "maticar",
    "maticará": "maticar",
    "maticarás": "maticar",
    "maticarão": "maticar",
    "maticaríamos": "maticar",
    "maticaríeis": "maticar",
    "maticas": "maticar",
    "maticasse": "maticar",
    "maticassem": "maticar",
    "maticasses": "maticar",
    "maticaste": "maticar",
    "maticastes": "maticar",
    "maticava": "maticar",
    "maticavam": "maticar",
    "maticavas": "maticar",
    "maticinas": "maticina",
    "matico": "maticar",
    "maticou": "maticar",
    "maticá": "maticar",
    "maticámo": "maticar",
    "maticámos": "maticar",
    "maticáramo": "maticar",
    "maticáramos": "maticar",
    "maticárei": "maticar",
    "maticáreis": "maticar",
    "maticásseis": "maticar",
    "maticássemos": "maticar",
    "maticávamo": "maticar",
    "maticávamos": "maticar",
    "maticávei": "maticar",
    "maticáveis": "maticar",
    "matilhas": "matilha",
    "matilheira": "matilheiro",
    "matilheiras": "matilheiro",
    "matilheiros": "matilheiro",
    "matina": "matinar",
    "matinada": "matinar",
    "matinadas": "matinar",
    "matinado": "matinar",
    "matinados": "matinar",
    "matinai": "matinar",
    "matinais": "matinar",
    "matinam": "matinar",
    "matinamo": "matinar",
    "matinamos": "matinar",
    "matinando": "matinar",
    "matinara": "matinar",
    "matinaram": "matinar",
    "matinaras": "matinar",
    "matinarde": "matinar",
    "matinardes": "matinar",
    "matinare": "matinar",
    "matinarei": "matinar",
    "matinareis": "matinar",
    "matinarem": "matinar",
    "matinaremos": "matinar",
    "matinares": "matinar",
    "matinaria": "matinar",
    "matinariam": "matinar",
    "matinarias": "matinar",
    "matinarmo": "matinar",
    "matinarmos": "matinar",
    "matinará": "matinar",
    "matinarás": "matinar",
    "matinarão": "matinar",
    "matinaríamos": "matinar",
    "matinaríeis": "matinar",
    "matinas": "matinar",
    "matinasse": "matinar",
    "matinassem": "matinar",
    "matinasses": "matinar",
    "matinaste": "matinar",
    "matinastes": "matinar",
    "matinava": "matinar",
    "matinavam": "matinar",
    "matinavas": "matinar",
    "matine": "matinar",
    "matinei": "matinar",
    "matineira": "matineiro",
    "matineiras": "matineiro",
    "matineiros": "matineiro",
    "matineis": "matinar",
    "matinem": "matinar",
    "matinemo": "matinar",
    "matinemos": "matinar",
    "matines": "matinar",
    "matino": "matinar",
    "matinou": "matinar",
    "matiná": "matinar",
    "matinámo": "matinar",
    "matinámos": "matinar",
    "matináramo": "matinar",
    "matináramos": "matinar",
    "matinárei": "matinar",
    "matináreis": "matinar",
    "matinária": "matinário",
    "matinárias": "matinário",
    "matinários": "matinário",
    "matinásseis": "matinar",
    "matinássemos": "matinar",
    "matinávamo": "matinar",
    "matinávamos": "matinar",
    "matinávei": "matinar",
    "matináveis": "matinar",
    "matinés": "matiné",
    "matique": "maticar",
    "matiquei": "maticar",
    "matiqueis": "maticar",
    "matiquem": "maticar",
    "matiquemo": "maticar",
    "matiquemos": "maticar",
    "matiques": "maticar",
    "matiza": "matizar",
    "matizada": "matizar",
    "matizadas": "matizar",
    "matizado": "matizar",
    "matizados": "matizar",
    "matizai": "matizar",
    "matizais": "matizar",
    "matizam": "matizar",
    "matizamo": "matizar",
    "matizamos": "matizar",
    "matizando": "matizar",
    "matizara": "matizar",
    "matizaram": "matizar",
    "matizaras": "matizar",
    "matizarde": "matizar",
    "matizardes": "matizar",
    "matizare": "matizar",
    "matizarei": "matizar",
    "matizareis": "matizar",
    "matizarem": "matizar",
    "matizaremos": "matizar",
    "matizares": "matizar",
    "matizaria": "matizar",
    "matizariam": "matizar",
    "matizarias": "matizar",
    "matizarmo": "matizar",
    "matizarmos": "matizar",
    "matizará": "matizar",
    "matizarás": "matizar",
    "matizarão": "matizar",
    "matizaríamos": "matizar",
    "matizaríeis": "matizar",
    "matizas": "matizar",
    "matizasse": "matizar",
    "matizassem": "matizar",
    "matizasses": "matizar",
    "matizaste": "matizar",
    "matizastes": "matizar",
    "matizava": "matizar",
    "matizavam": "matizar",
    "matizavas": "matizar",
    "matizações": "matização",
    "matize": "matizar",
    "matizei": "matizar",
    "matizeis": "matizar",
    "matizem": "matizar",
    "matizemo": "matizar",
    "matizemos": "matizar",
    "matizes": "matizar",
    "matizo": "matizar",
    "matizou": "matizar",
    "matizá": "matizar",
    "matizámo": "matizar",
    "matizámos": "matizar",
    "matizáramo": "matizar",
    "matizáramos": "matizar",
    "matizárei": "matizar",
    "matizáreis": "matizar",
    "matizásseis": "matizar",
    "matizássemos": "matizar",
    "matizávamo": "matizar",
    "matizávamos": "matizar",
    "matizávei": "matizar",
    "matizáveis": "matizável",
    "mato": "matar",
    "matolas": "matola",
    "matolões": "matolão",
    "matomba": "matombo",
    "matombas": "matombo",
    "matombos": "matombo",
    "matonices": "matonice",
    "matoninhas": "matoninha",
    "matorrais": "matorral",
    "matos": "mato",
    "matosa": "matoso",
    "matosas": "matoso",
    "matosinheira": "matosinheiro",
    "matosinheiras": "matosinheiro",
    "matosinheiros": "matosinheiro",
    "matosinhenses": "matosinhense",
    "matosos": "matoso",
    "matou": "matar",
    "matraca": "matracar",
    "matracada": "matracar",
    "matracadas": "matracar",
    "matracado": "matracar",
    "matracados": "matracar",
    "matracai": "matracar",
    "matracais": "matracar",
    "matracam": "matracar",
    "matracamo": "matracar",
    "matracamos": "matracar",
    "matracando": "matracar",
    "matracara": "matracar",
    "matracaram": "matracar",
    "matracaras": "matracar",
    "matracarde": "matracar",
    "matracardes": "matracar",
    "matracare": "matracar",
    "matracarei": "matracar",
    "matracareis": "matracar",
    "matracarem": "matracar",
    "matracaremos": "matracar",
    "matracares": "matracar",
    "matracaria": "matracar",
    "matracariam": "matracar",
    "matracarias": "matracar",
    "matracarmo": "matracar",
    "matracarmos": "matracar",
    "matracará": "matracar",
    "matracarás": "matracar",
    "matracarão": "matracar",
    "matracaríamos": "matracar",
    "matracaríeis": "matracar",
    "matracas": "matracar",
    "matracasse": "matracar",
    "matracassem": "matracar",
    "matracasses": "matracar",
    "matracaste": "matracar",
    "matracastes": "matracar",
    "matracava": "matracar",
    "matracavam": "matracar",
    "matracavas": "matracar",
    "matraco": "matracar",
    "matracou": "matracar",
    "matracá": "matracar",
    "matracámo": "matracar",
    "matracámos": "matracar",
    "matracáramo": "matracar",
    "matracáramos": "matracar",
    "matracárei": "matracar",
    "matracáreis": "matracar",
    "matracásseis": "matracar",
    "matracássemos": "matracar",
    "matracávamo": "matracar",
    "matracávamos": "matracar",
    "matracávei": "matracar",
    "matracáveis": "matracar",
    "matraque": "matracar",
    "matraqueada": "matraquear",
    "matraqueadas": "matraquear",
    "matraqueado": "matraquear",
    "matraqueadora": "matraqueador",
    "matraqueadoras": "matraqueador",
    "matraqueadores": "matraqueador",
    "matraqueados": "matraquear",
    "matraqueai": "matraquear",
    "matraqueais": "matraquear",
    "matraqueamo": "matraquear",
    "matraqueamos": "matraquear",
    "matraqueando": "matraquear",
    "matraqueara": "matraquear",
    "matraquearam": "matraquear",
    "matraquearas": "matraquear",
    "matraquearde": "matraquear",
    "matraqueardes": "matraquear",
    "matraqueare": "matraquear",
    "matraquearei": "matraquear",
    "matraqueareis": "matraquear",
    "matraquearem": "matraquear",
    "matraquearemos": "matraquear",
    "matraqueares": "matraquear",
    "matraquearia": "matraquear",
    "matraqueariam": "matraquear",
    "matraquearias": "matraquear",
    "matraquearmo": "matraquear",
    "matraquearmos": "matraquear",
    "matraqueará": "matraquear",
    "matraquearás": "matraquear",
    "matraquearão": "matraquear",
    "matraquearíamos": "matraquear",
    "matraquearíeis": "matraquear",
    "matraqueasse": "matraquear",
    "matraqueassem": "matraquear",
    "matraqueasses": "matraquear",
    "matraqueaste": "matraquear",
    "matraqueastes": "matraquear",
    "matraqueava": "matraquear",
    "matraqueavam": "matraquear",
    "matraqueavas": "matraquear",
    "matraqueei": "matraquear",
    "matraqueeis": "matraquear",
    "matraqueemo": "matraquear",
    "matraqueemos": "matraquear",
    "matraquei": "matracar",
    "matraqueia": "matraquear",
    "matraqueiam": "matraquear",
    "matraqueias": "matraquear",
    "matraqueie": "matraquear",
    "matraqueiem": "matraquear",
    "matraqueies": "matraquear",
    "matraqueio": "matraquear",
    "matraqueis": "matracar",
    "matraqueja": "matraquejar",
    "matraquejada": "matraquejar",
    "matraquejadas": "matraquejar",
    "matraquejado": "matraquejar",
    "matraquejados": "matraquejar",
    "matraquejai": "matraquejar",
    "matraquejais": "matraquejar",
    "matraquejam": "matraquejar",
    "matraquejamo": "matraquejar",
    "matraquejamos": "matraquejar",
    "matraquejando": "matraquejar",
    "matraquejara": "matraquejar",
    "matraquejaram": "matraquejar",
    "matraquejaras": "matraquejar",
    "matraquejarde": "matraquejar",
    "matraquejardes": "matraquejar",
    "matraquejare": "matraquejar",
    "matraquejarei": "matraquejar",
    "matraquejareis": "matraquejar",
    "matraquejarem": "matraquejar",
    "matraquejaremos": "matraquejar",
    "matraquejares": "matraquejar",
    "matraquejaria": "matraquejar",
    "matraquejariam": "matraquejar",
    "matraquejarias": "matraquejar",
    "matraquejarmo": "matraquejar",
    "matraquejarmos": "matraquejar",
    "matraquejará": "matraquejar",
    "matraquejarás": "matraquejar",
    "matraquejarão": "matraquejar",
    "matraquejaríamos": "matraquejar",
    "matraquejaríeis": "matraquejar",
    "matraquejas": "matraquejar",
    "matraquejasse": "matraquejar",
    "matraquejassem": "matraquejar",
    "matraquejasses": "matraquejar",
    "matraquejaste": "matraquejar",
    "matraquejastes": "matraquejar",
    "matraquejava": "matraquejar",
    "matraquejavam": "matraquejar",
    "matraquejavas": "matraquejar",
    "matraqueje": "matraquejar",
    "matraquejei": "matraquejar",
    "matraquejeis": "matraquejar",
    "matraquejem": "matraquejar",
    "matraquejemo": "matraquejar",
    "matraquejemos": "matraquejar",
    "matraquejes": "matraquejar",
    "matraquejo": "matraquejar",
    "matraquejou": "matraquejar",
    "matraquejá": "matraquejar",
    "matraquejámo": "matraquejar",
    "matraquejámos": "matraquejar",
    "matraquejáramo": "matraquejar",
    "matraquejáramos": "matraquejar",
    "matraquejárei": "matraquejar",
    "matraquejáreis": "matraquejar",
    "matraquejásseis": "matraquejar",
    "matraquejássemos": "matraquejar",
    "matraquejávamo": "matraquejar",
    "matraquejávamos": "matraquejar",
    "matraquejávei": "matraquejar",
    "matraquejáveis": "matraquejar",
    "matraquem": "matracar",
    "matraquemo": "matracar",
    "matraquemos": "matracar",
    "matraqueou": "matraquear",
    "matraques": "matracar",
    "matraqueá": "matraquear",
    "matraqueámo": "matraquear",
    "matraqueámos": "matraquear",
    "matraqueáramo": "matraquear",
    "matraqueáramos": "matraquear",
    "matraqueárei": "matraquear",
    "matraqueáreis": "matraquear",
    "matraqueásseis": "matraquear",
    "matraqueássemos": "matraquear",
    "matraqueávamo": "matraquear",
    "matraqueávamos": "matraquear",
    "matraqueávei": "matraquear",
    "matraqueáveis": "matraquear",
    "matraquilhos": "matraquilho",
    "matrazes": "matraz",
    "matreira": "matreiro",
    "matreiras": "matreiro",
    "matreirices": "matreirice",
    "matreirinha": "matreiro",
    "matreirinhas": "matreiro",
    "matreirinho": "matreiro",
    "matreirinhos": "matreiro",
    "matreirita": "matreiro",
    "matreiritas": "matreiro",
    "matreirito": "matreiro",
    "matreiritos": "matreiro",
    "matreiros": "matreiro",
    "matreiríssima": "matreiro",
    "matreiríssimas": "matreiro",
    "matreiríssimo": "matreiro",
    "matreiríssimos": "matreiro",
    "matriarcados": "matriarcado",
    "matriarcais": "matriarcal",
    "matriarcas": "matriarca",
    "matriciais": "matricial",
    "matricidas": "matricida",
    "matricula": "matricular",
    "matriculada": "matricular",
    "matriculadas": "matricular",
    "matriculado": "matricular",
    "matriculados": "matricular",
    "matriculai": "matricular",
    "matriculais": "matricular",
    "matriculam": "matricular",
    "matriculamo": "matricular",
    "matriculamos": "matricular",
    "matriculanda": "matriculando",
    "matriculandas": "matriculando",
    "matriculando": "matricular",
    "matriculandos": "matriculando",
    "matriculara": "matricular",
    "matricularam": "matricular",
    "matricularas": "matricular",
    "matricularde": "matricular",
    "matriculardes": "matricular",
    "matriculare": "matricular",
    "matricularei": "matricular",
    "matriculareis": "matricular",
    "matricularem": "matricular",
    "matricularemos": "matricular",
    "matriculares": "matricular",
    "matricularia": "matricular",
    "matriculariam": "matricular",
    "matricularias": "matricular",
    "matricularmo": "matricular",
    "matricularmos": "matricular",
    "matriculará": "matricular",
    "matricularás": "matricular",
    "matricularão": "matricular",
    "matricularíamos": "matricular",
    "matricularíeis": "matricular",
    "matriculas": "matricular",
    "matriculasse": "matricular",
    "matriculassem": "matricular",
    "matriculasses": "matricular",
    "matriculaste": "matricular",
    "matriculastes": "matricular",
    "matriculava": "matricular",
    "matriculavam": "matricular",
    "matriculavas": "matricular",
    "matricule": "matricular",
    "matriculei": "matricular",
    "matriculeis": "matricular",
    "matriculem": "matricular",
    "matriculemo": "matricular",
    "matriculemos": "matricular",
    "matricules": "matricular",
    "matriculo": "matricular",
    "matriculou": "matricular",
    "matriculá": "matricular",
    "matriculámo": "matricular",
    "matriculámos": "matricular",
    "matriculáramo": "matricular",
    "matriculáramos": "matricular",
    "matriculárei": "matricular",
    "matriculáreis": "matricular",
    "matriculásseis": "matricular",
    "matriculássemos": "matricular",
    "matriculávamo": "matricular",
    "matriculávamos": "matricular",
    "matriculávei": "matricular",
    "matriculáveis": "matriculável",
    "matricárias": "matricária",
    "matricídios": "matricídio",
    "matrimonia": "matrimoniar",
    "matrimoniada": "matrimoniar",
    "matrimoniadas": "matrimoniar",
    "matrimoniado": "matrimoniar",
    "matrimoniados": "matrimoniar",
    "matrimoniai": "matrimoniar",
    "matrimoniais": "matrimoniar",
    "matrimoniam": "matrimoniar",
    "matrimoniamo": "matrimoniar",
    "matrimoniamos": "matrimoniar",
    "matrimoniando": "matrimoniar",
    "matrimoniara": "matrimoniar",
    "matrimoniaram": "matrimoniar",
    "matrimoniaras": "matrimoniar",
    "matrimoniarde": "matrimoniar",
    "matrimoniardes": "matrimoniar",
    "matrimoniare": "matrimoniar",
    "matrimoniarei": "matrimoniar",
    "matrimoniareis": "matrimoniar",
    "matrimoniarem": "matrimoniar",
    "matrimoniaremos": "matrimoniar",
    "matrimoniares": "matrimoniar",
    "matrimoniaria": "matrimoniar",
    "matrimoniariam": "matrimoniar",
    "matrimoniarias": "matrimoniar",
    "matrimoniarmo": "matrimoniar",
    "matrimoniarmos": "matrimoniar",
    "matrimoniará": "matrimoniar",
    "matrimoniarás": "matrimoniar",
    "matrimoniarão": "matrimoniar",
    "matrimoniaríamos": "matrimoniar",
    "matrimoniaríeis": "matrimoniar",
    "matrimonias": "matrimoniar",
    "matrimoniasse": "matrimoniar",
    "matrimoniassem": "matrimoniar",
    "matrimoniasses": "matrimoniar",
    "matrimoniaste": "matrimoniar",
    "matrimoniastes": "matrimoniar",
    "matrimoniava": "matrimoniar",
    "matrimoniavam": "matrimoniar",
    "matrimoniavas": "matrimoniar",
    "matrimonie": "matrimoniar",
    "matrimoniei": "matrimoniar",
    "matrimonieis": "matrimoniar",
    "matrimoniem": "matrimoniar",
    "matrimoniemo": "matrimoniar",
    "matrimoniemos": "matrimoniar",
    "matrimonies": "matrimoniar",
    "matrimonio": "matrimoniar",
    "matrimoniou": "matrimoniar",
    "matrimoniá": "matrimoniar",
    "matrimoniámo": "matrimoniar",
    "matrimoniámos": "matrimoniar",
    "matrimoniáramo": "matrimoniar",
    "matrimoniáramos": "matrimoniar",
    "matrimoniárei": "matrimoniar",
    "matrimoniáreis": "matrimoniar",
    "matrimoniásseis": "matrimoniar",
    "matrimoniássemos": "matrimoniar",
    "matrimoniávamo": "matrimoniar",
    "matrimoniávamos": "matrimoniar",
    "matrimoniávei": "matrimoniar",
    "matrimoniáveis": "matrimoniar",
    "matrimónios": "matrimónio",
    "matrioskas": "matrioska",
    "matritenses": "matritense",
    "matrizes": "matriz",
    "matrocas": "matroca",
    "matrolas": "matrola",
    "matronais": "matronal",
    "matronarias": "matronaria",
    "matronas": "matrona",
    "matronaças": "matronaça",
    "matruca": "matrucar",
    "matrucada": "matrucar",
    "matrucadas": "matrucar",
    "matrucado": "matrucar",
    "matrucados": "matrucar",
    "matrucai": "matrucar",
    "matrucais": "matrucar",
    "matrucam": "matrucar",
    "matrucamo": "matrucar",
    "matrucamos": "matrucar",
    "matrucando": "matrucar",
    "matrucara": "matrucar",
    "matrucaram": "matrucar",
    "matrucaras": "matrucar",
    "matrucarde": "matrucar",
    "matrucardes": "matrucar",
    "matrucare": "matrucar",
    "matrucarei": "matrucar",
    "matrucareis": "matrucar",
    "matrucarem": "matrucar",
    "matrucaremos": "matrucar",
    "matrucares": "matrucar",
    "matrucaria": "matrucar",
    "matrucariam": "matrucar",
    "matrucarias": "matrucar",
    "matrucarmo": "matrucar",
    "matrucarmos": "matrucar",
    "matrucará": "matrucar",
    "matrucarás": "matrucar",
    "matrucarão": "matrucar",
    "matrucaríamos": "matrucar",
    "matrucaríeis": "matrucar",
    "matrucas": "matrucar",
    "matrucasse": "matrucar",
    "matrucassem": "matrucar",
    "matrucasses": "matrucar",
    "matrucaste": "matrucar",
    "matrucastes": "matrucar",
    "matrucava": "matrucar",
    "matrucavam": "matrucar",
    "matrucavas": "matrucar",
    "matruco": "matrucar",
    "matrucos": "matruco",
    "matrucou": "matrucar",
    "matrucá": "matrucar",
    "matrucámo": "matrucar",
    "matrucámos": "matrucar",
    "matrucáramo": "matrucar",
    "matrucáramos": "matrucar",
    "matrucárei": "matrucar",
    "matrucáreis": "matrucar",
    "matrucásseis": "matrucar",
    "matrucássemos": "matrucar",
    "matrucávamo": "matrucar",
    "matrucávamos": "matrucar",
    "matrucávei": "matrucar",
    "matrucáveis": "matrucar",
    "matruque": "matrucar",
    "matruquei": "matrucar",
    "matruqueis": "matrucar",
    "matruquem": "matrucar",
    "matruquemo": "matrucar",
    "matruquemos": "matrucar",
    "matruques": "matrucar",
    "matráculas": "matrácula",
    "matrículas": "matrícula",
    "matróclina": "matróclino",
    "matróclinas": "matróclino",
    "matróclinos": "matróclino",
    "matula": "matulo",
    "matulagens": "matulagem",
    "matulas": "matulo",
    "matulona": "matulão",
    "matulonas": "matulão",
    "matulos": "matulo",
    "matulões": "matulão",
    "matumba": "matumbo",
    "matumbas": "matumbo",
    "matumbinha": "matumbo",
    "matumbinhas": "matumbo",
    "matumbinho": "matumbo",
    "matumbinhos": "matumbo",
    "matumbita": "matumbo",
    "matumbitas": "matumbo",
    "matumbito": "matumbo",
    "matumbitos": "matumbo",
    "matumbos": "matumbo",
    "matundos": "matundo",
    "matunga": "matungo",
    "matungadas": "matungada",
    "matungas": "matungo",
    "matungos": "matungo",
    "matura": "maturo",
    "maturada": "maturar",
    "maturadas": "maturar",
    "maturado": "maturar",
    "maturadora": "maturador",
    "maturadoras": "maturador",
    "maturadores": "maturador",
    "maturados": "maturar",
    "maturai": "maturar",
    "maturais": "maturar",
    "maturam": "maturar",
    "maturamo": "maturar",
    "maturamos": "maturar",
    "maturando": "maturar",
    "maturara": "maturar",
    "maturaram": "maturar",
    "maturaras": "maturar",
    "maturarde": "maturar",
    "maturardes": "maturar",
    "maturare": "maturar",
    "maturarei": "maturar",
    "maturareis": "maturar",
    "maturarem": "maturar",
    "maturaremos": "maturar",
    "maturares": "maturar",
    "maturaria": "maturar",
    "maturariam": "maturar",
    "maturarias": "maturar",
    "maturarmo": "maturar",
    "maturarmos": "maturar",
    "maturará": "maturar",
    "maturarás": "maturar",
    "maturarão": "maturar",
    "maturaríamos": "maturar",
    "maturaríeis": "maturar",
    "maturas": "maturo",
    "maturasse": "maturar",
    "maturassem": "maturar",
    "maturasses": "maturar",
    "maturaste": "maturar",
    "maturastes": "maturar",
    "maturativa": "maturativo",
    "maturativas": "maturativo",
    "maturativos": "maturativo",
    "maturava": "maturar",
    "maturavam": "maturar",
    "maturavas": "maturar",
    "maturações": "maturação",
    "mature": "maturar",
    "maturei": "maturar",
    "matureis": "maturar",
    "maturem": "maturar",
    "maturemo": "maturar",
    "maturemos": "maturar",
    "matures": "maturar",
    "maturescentes": "maturescente",
    "maturescências": "maturescência",
    "maturidades": "maturidade",
    "maturo": "maturar",
    "maturos": "maturo",
    "maturou": "maturar",
    "maturranga": "maturrango",
    "maturrangas": "maturrango",
    "maturrangos": "maturrango",
    "maturá": "maturar",
    "maturámo": "maturar",
    "maturámos": "maturar",
    "maturáramo": "maturar",
    "maturáramos": "maturar",
    "maturárei": "maturar",
    "maturáreis": "maturar",
    "maturásseis": "maturar",
    "maturássemos": "maturar",
    "maturávamo": "maturar",
    "maturávamos": "maturar",
    "maturávei": "maturar",
    "maturáveis": "maturar",
    "matuta": "matuto",
    "matutada": "matutar",
    "matutadas": "matutar",
    "matutado": "matutar",
    "matutados": "matutar",
    "matutai": "matutar",
    "matutais": "matutar",
    "matutam": "matutar",
    "matutamo": "matutar",
    "matutamos": "matutar",
    "matutando": "matutar",
    "matutara": "matutar",
    "matutaram": "matutar",
    "matutaras": "matutar",
    "matutardes": "matutar",
    "matutarei": "matutar",
    "matutareis": "matutar",
    "matutarem": "matutar",
    "matutaremos": "matutar",
    "matutares": "matutar",
    "matutaria": "matutar",
    "matutariam": "matutar",
    "matutarias": "matutar",
    "matutarmo": "matutar",
    "matutarmos": "matutar",
    "matutará": "matutar",
    "matutarás": "matutar",
    "matutarão": "matutar",
    "matutaríamos": "matutar",
    "matutaríeis": "matutar",
    "matutas": "matuto",
    "matutasse": "matutar",
    "matutassem": "matutar",
    "matutasses": "matutar",
    "matutaste": "matutar",
    "matutastes": "matutar",
    "matutava": "matutar",
    "matutavam": "matutar",
    "matutavas": "matutar",
    "matutações": "matutação",
    "matute": "matutar",
    "matutei": "matutar",
    "matuteis": "matutar",
    "matutem": "matutar",
    "matutemo": "matutar",
    "matutemos": "matutar",
    "matutes": "matutar",
    "matutices": "matutice",
    "matutina": "matutino",
    "matutinas": "matutino",
    "matutinos": "matutino",
    "matutinários": "matutinário",
    "matuto": "matutar",
    "matutos": "matuto",
    "matutou": "matutar",
    "matutámo": "matutar",
    "matutámos": "matutar",
    "matutáramo": "matutar",
    "matutáramos": "matutar",
    "matutáreis": "matutar",
    "matutásseis": "matutar",
    "matutássemos": "matutar",
    "matutávamo": "matutar",
    "matutávamos": "matutar",
    "matutáveis": "matutar",
    "matá": "matar",
    "matámo": "matar",
    "matámos": "matar",
    "matáramo": "matar",
    "matáramos": "matar",
    "matárei": "matar",
    "matáreis": "matar",
    "matásseis": "matar",
    "matássemos": "matar",
    "matávamo": "matar",
    "matávamos": "matar",
    "matávei": "matar",
    "matáveis": "matar",
    "matérias": "matéria",
    "maunças": "maunça",
    "maura": "mauro",
    "mauras": "mauro",
    "mauresca": "mauresco",
    "maurescas": "mauresco",
    "maurescos": "mauresco",
    "mauriana": "mauriano",
    "maurianas": "mauriano",
    "maurianos": "mauriano",
    "maurienses": "mauriense",
    "maurina": "maurino",
    "maurinas": "maurino",
    "maurinos": "maurino",
    "mauritana": "mauritano",
    "mauritanas": "mauritano",
    "mauritanos": "mauritano",
    "mauritânias": "mauritânia",
    "mauros": "mauro",
    "maurrasismos": "maurrasismo",
    "maurás": "maurá",
    "maus": "mau",
    "mausoléus": "mausoléu",
    "mausólea": "mausóleo",
    "mausóleas": "mausóleo",
    "mausóleos": "mausóleo",
    "mauzinho": "mau",
    "mauzinhos": "mau",
    "mauzito": "mau",
    "mauzitos": "mau",
    "mauzona": "mauzão",
    "mauzonas": "mauzão",
    "mauzotes": "mauzote",
    "mauzões": "mauzão",
    "maviosa": "mavioso",
    "maviosas": "mavioso",
    "maviosidades": "maviosidade",
    "maviosos": "mavioso",
    "mavorcismos": "mavorcismo",
    "mavorcistas": "mavorcista",
    "mavórcia": "mavórcio",
    "mavórcias": "mavórcio",
    "mavórcios": "mavórcio",
    "mavórtica": "mavórtico",
    "mavórticas": "mavórtico",
    "mavórticos": "mavórtico",
    "maxicasacos": "maxicasaco",
    "maxidesvalorizações": "maxidesvalorização",
    "maxilares": "maxilar",
    "maxilas": "maxila",
    "maxiliformes": "maxiliforme",
    "maxilodentais": "maxilodental",
    "maxilosa": "maxiloso",
    "maxilosas": "maxiloso",
    "maxilosos": "maxiloso",
    "maximalismos": "maximalismo",
    "maximalistas": "maximalista",
    "maximantes": "maximante",
    "maximiza": "maximizar",
    "maximizada": "maximizar",
    "maximizadas": "maximizar",
    "maximizado": "maximizar",
    "maximizados": "maximizar",
    "maximizai": "maximizar",
    "maximizais": "maximizar",
    "maximizam": "maximizar",
    "maximizamo": "maximizar",
    "maximizamos": "maximizar",
    "maximizando": "maximizar",
    "maximizara": "maximizar",
    "maximizaram": "maximizar",
    "maximizaras": "maximizar",
    "maximizarde": "maximizar",
    "maximizardes": "maximizar",
    "maximizare": "maximizar",
    "maximizarei": "maximizar",
    "maximizareis": "maximizar",
    "maximizarem": "maximizar",
    "maximizaremos": "maximizar",
    "maximizares": "maximizar",
    "maximizaria": "maximizar",
    "maximizariam": "maximizar",
    "maximizarias": "maximizar",
    "maximizarmo": "maximizar",
    "maximizarmos": "maximizar",
    "maximizará": "maximizar",
    "maximizarás": "maximizar",
    "maximizarão": "maximizar",
    "maximizaríamos": "maximizar",
    "maximizaríeis": "maximizar",
    "maximizas": "maximizar",
    "maximizasse": "maximizar",
    "maximizassem": "maximizar",
    "maximizasses": "maximizar",
    "maximizaste": "maximizar",
    "maximizastes": "maximizar",
    "maximizava": "maximizar",
    "maximizavam": "maximizar",
    "maximizavas": "maximizar",
    "maximizações": "maximização",
    "maximize": "maximizar",
    "maximizei": "maximizar",
    "maximizeis": "maximizar",
    "maximizem": "maximizar",
    "maximizemo": "maximizar",
    "maximizemos": "maximizar",
    "maximizes": "maximizar",
    "maximizo": "maximizar",
    "maximizou": "maximizar",
    "maximizá": "maximizar",
    "maximizámo": "maximizar",
    "maximizámos": "maximizar",
    "maximizáramo": "maximizar",
    "maximizáramos": "maximizar",
    "maximizárei": "maximizar",
    "maximizáreis": "maximizar",
    "maximizásseis": "maximizar",
    "maximizássemos": "maximizar",
    "maximizávamo": "maximizar",
    "maximizávamos": "maximizar",
    "maximizávei": "maximizar",
    "maximizáveis": "maximizar",
    "maxins": "maxim",
    "maxissaias": "maxissaia",
    "maxivestidos": "maxivestido",
    "maxixeira": "maxixeiro",
    "maxixeiras": "maxixeiro",
    "maxixeiros": "maxixeiro",
    "maxixes": "maxixe",
    "maxwells": "maxwell",
    "mazagrãs": "mazagrã",
    "mazamas": "mazama",
    "mazamorras": "mazamorra",
    "mazanarias": "mazanaria",
    "mazanes": "mazane",
    "mazanias": "mazania",
    "mazarizes": "mazarize",
    "mazarulha": "mazarulho",
    "mazarulhas": "mazarulho",
    "mazarulhos": "mazarulho",
    "mazdeísmos": "mazdeísmo",
    "mazdeístas": "mazdeísta",
    "mazela": "mazelar",
    "mazelada": "mazelar",
    "mazeladas": "mazelar",
    "mazelado": "mazelar",
    "mazelados": "mazelar",
    "mazelai": "mazelar",
    "mazelais": "mazelar",
    "mazelam": "mazelar",
    "mazelamo": "mazelar",
    "mazelamos": "mazelar",
    "mazelando": "mazelar",
    "mazelara": "mazelar",
    "mazelaram": "mazelar",
    "mazelaras": "mazelar",
    "mazelarde": "mazelar",
    "mazelardes": "mazelar",
    "mazelare": "mazelar",
    "mazelarei": "mazelar",
    "mazelareis": "mazelar",
    "mazelarem": "mazelar",
    "mazelaremos": "mazelar",
    "mazelares": "mazelar",
    "mazelaria": "mazelar",
    "mazelariam": "mazelar",
    "mazelarias": "mazelar",
    "mazelarmo": "mazelar",
    "mazelarmos": "mazelar",
    "mazelará": "mazelar",
    "mazelarás": "mazelar",
    "mazelarão": "mazelar",
    "mazelaríamos": "mazelar",
    "mazelaríeis": "mazelar",
    "mazelas": "mazelar",
    "mazelasse": "mazelar",
    "mazelassem": "mazelar",
    "mazelasses": "mazelar",
    "mazelaste": "mazelar",
    "mazelastes": "mazelar",
    "mazelava": "mazelar",
    "mazelavam": "mazelar",
    "mazelavas": "mazelar",
    "mazele": "mazelar",
    "mazelei": "mazelar",
    "mazeleis": "mazelar",
    "mazelem": "mazelar",
    "mazelemo": "mazelar",
    "mazelemos": "mazelar",
    "mazelenta": "mazelento",
    "mazelentas": "mazelento",
    "mazelentos": "mazelento",
    "mazeles": "mazelar",
    "mazelo": "mazelar",
    "mazelou": "mazelar",
    "mazelá": "mazelar",
    "mazelámo": "mazelar",
    "mazelámos": "mazelar",
    "mazeláramo": "mazelar",
    "mazeláramos": "mazelar",
    "mazelárei": "mazelar",
    "mazeláreis": "mazelar",
    "mazelásseis": "mazelar",
    "mazelássemos": "mazelar",
    "mazelávamo": "mazelar",
    "mazelávamos": "mazelar",
    "mazelávei": "mazelar",
    "mazeláveis": "mazelar",
    "mazes": "maz",
    "mazinha": "mau",
    "mazinhas": "mau",
    "mazita": "mau",
    "mazitas": "mau",
    "mazomba": "mazombo",
    "mazombas": "mazombo",
    "mazombices": "mazombice",
    "mazombos": "mazombo",
    "mazorra": "mazorro",
    "mazorrais": "mazorral",
    "mazorras": "mazorro",
    "mazorros": "mazorro",
    "mazurca": "mazurcar",
    "mazurcada": "mazurcar",
    "mazurcadas": "mazurcar",
    "mazurcado": "mazurcar",
    "mazurcados": "mazurcar",
    "mazurcais": "mazurcar",
    "mazurcam": "mazurcar",
    "mazurcamo": "mazurcar",
    "mazurcamos": "mazurcar",
    "mazurcando": "mazurcar",
    "mazurcara": "mazurcar",
    "mazurcaram": "mazurcar",
    "mazurcaras": "mazurcar",
    "mazurcardes": "mazurcar",
    "mazurcarei": "mazurcar",
    "mazurcareis": "mazurcar",
    "mazurcarem": "mazurcar",
    "mazurcaremos": "mazurcar",
    "mazurcares": "mazurcar",
    "mazurcaria": "mazurcar",
    "mazurcariam": "mazurcar",
    "mazurcarias": "mazurcar",
    "mazurcarmo": "mazurcar",
    "mazurcarmos": "mazurcar",
    "mazurcará": "mazurcar",
    "mazurcarás": "mazurcar",
    "mazurcarão": "mazurcar",
    "mazurcaríamos": "mazurcar",
    "mazurcaríeis": "mazurcar",
    "mazurcas": "mazurcar",
    "mazurcasse": "mazurcar",
    "mazurcassem": "mazurcar",
    "mazurcasses": "mazurcar",
    "mazurcaste": "mazurcar",
    "mazurcastes": "mazurcar",
    "mazurcava": "mazurcar",
    "mazurcavam": "mazurcar",
    "mazurcavas": "mazurcar",
    "mazurco": "mazurcar",
    "mazurcou": "mazurcar",
    "mazurcámo": "mazurcar",
    "mazurcámos": "mazurcar",
    "mazurcáramo": "mazurcar",
    "mazurcáramos": "mazurcar",
    "mazurcáreis": "mazurcar",
    "mazurcásseis": "mazurcar",
    "mazurcássemos": "mazurcar",
    "mazurcávamo": "mazurcar",
    "mazurcávamos": "mazurcar",
    "mazurcáveis": "mazurcar",
    "mazurque": "mazurcar",
    "mazurquei": "mazurcar",
    "mazurqueis": "mazurcar",
    "mazurquem": "mazurcar",
    "mazurquemos": "mazurcar",
    "mazurques": "mazurcar",
    "maça": "maçar",
    "maçacotos": "maçacoto",
    "maçacucas": "maçacuca",
    "maçada": "maçar",
    "maçadas": "maçar",
    "maçadeiros": "maçadeiro",
    "maçadiça": "maçadiço",
    "maçadiças": "maçadiço",
    "maçadiços": "maçadiço",
    "maçado": "maçar",
    "maçadoiros": "maçadoiro",
    "maçadora": "maçador",
    "maçadoras": "maçador",
    "maçadores": "maçador",
    "maçadorias": "maçadoria",
    "maçados": "maçar",
    "maçadouros": "maçadouro",
    "maçadíssima": "maçado",
    "maçadíssimas": "maçado",
    "maçadíssimo": "maçado",
    "maçadíssimos": "maçado",
    "maçagens": "maçagem",
    "maçaguãs": "maçaguã",
    "maçai": "maçar",
    "maçais": "maçar",
    "maçam": "maçar",
    "maçamo": "maçar",
    "maçamos": "maçar",
    "maçando": "maçar",
    "maçanetas": "maçaneta",
    "maçanilhas": "maçanilha",
    "maçantes": "maçante",
    "maçapões": "maçapão",
    "maçaquetas": "maçaqueta",
    "maçara": "maçar",
    "maçaram": "maçar",
    "maçarandibas": "maçarandiba",
    "maçarandubas": "maçaranduba",
    "maçarandubeiras": "maçarandubeira",
    "maçaras": "maçar",
    "maçarde": "maçar",
    "maçardes": "maçar",
    "maçare": "maçar",
    "maçarei": "maçar",
    "maçareis": "maçar",
    "maçarem": "maçar",
    "maçaremos": "maçar",
    "maçares": "maçar",
    "maçaria": "maçar",
    "maçariam": "maçar",
    "maçarias": "maçar",
    "maçaricas": "maçarica",
    "maçaricos": "maçarico",
    "maçarmo": "maçar",
    "maçarmos": "maçar",
    "maçarocas": "maçaroca",
    "maçarocos": "maçaroco",
    "maçaroqueiras": "maçaroqueira",
    "maçaroquilhos": "maçaroquilho",
    "maçaruca": "maçaruco",
    "maçarucas": "maçaruco",
    "maçarucos": "maçaruco",
    "maçará": "maçar",
    "maçarás": "maçar",
    "maçarão": "maçar",
    "maçaríamos": "maçar",
    "maçaríeis": "maçar",
    "maças": "maçar",
    "maçasse": "maçar",
    "maçassem": "maçar",
    "maçasses": "maçar",
    "maçaste": "maçar",
    "maçastes": "maçar",
    "maçava": "maçar",
    "maçavam": "maçar",
    "maçavas": "maçar",
    "maço": "maçar",
    "maçoms": "maçom",
    "maçonarias": "maçonaria",
    "maçonismos": "maçonismo",
    "maçoniza": "onizar",
    "maçonizada": "maçonizar",
    "maçonizadas": "maçonizar",
    "maçonizado": "maçonizar",
    "maçonizados": "maçonizar",
    "maçonizai": "maçonizar",
    "maçonizais": "maçonizar",
    "maçonizam": "maçonizar",
    "maçonizamo": "maçonizar",
    "maçonizamos": "maçonizar",
    "maçonizando": "maçonizar",
    "maçonizar": "onizar",
    "maçonizara": "onizar",
    "maçonizaram": "onizar",
    "maçonizaras": "maçonizar",
    "maçonizarde": "maçonizar",
    "maçonizardes": "maçonizar",
    "maçonizare": "maçonizar",
    "maçonizarei": "maçonizar",
    "maçonizareis": "maçonizar",
    "maçonizarem": "onizar",
    "maçonizaremos": "maçonizar",
    "maçonizares": "maçonizar",
    "maçonizaria": "onizar",
    "maçonizariam": "maçonizar",
    "maçonizarias": "maçonizar",
    "maçonizarmo": "maçonizar",
    "maçonizarmos": "maçonizar",
    "maçonizará": "maçonizar",
    "maçonizarás": "maçonizar",
    "maçonizarão": "maçonizar",
    "maçonizaríamos": "maçonizar",
    "maçonizaríeis": "maçonizar",
    "maçonizas": "maçonizar",
    "maçonizasse": "onizar",
    "maçonizassem": "maçonizar",
    "maçonizasses": "maçonizar",
    "maçonizaste": "maçonizar",
    "maçonizastes": "maçonizar",
    "maçonizava": "onizar",
    "maçonizavam": "maçonizar",
    "maçonizavas": "maçonizar",
    "maçonize": "onizar",
    "maçonizei": "maçonizar",
    "maçonizeis": "maçonizar",
    "maçonizem": "onizar",
    "maçonizemo": "maçonizar",
    "maçonizemos": "maçonizar",
    "maçonizes": "maçonizar",
    "maçonizo": "maçonizar",
    "maçonizou": "maçonizar",
    "maçonizá": "onizar",
    "maçonizámo": "maçonizar",
    "maçonizámos": "maçonizar",
    "maçonizáramo": "maçonizar",
    "maçonizáramos": "maçonizar",
    "maçonizárei": "maçonizar",
    "maçonizáreis": "maçonizar",
    "maçonizásseis": "maçonizar",
    "maçonizássemos": "maçonizar",
    "maçonizávamo": "maçonizar",
    "maçonizávamos": "maçonizar",
    "maçonizávei": "maçonizar",
    "maçonizáveis": "maçonizável",
    "maços": "maço",
    "maçotes": "maçote",
    "maçou": "maçar",
    "maçuda": "maçudo",
    "maçudas": "maçudo",
    "maçudos": "maçudo",
    "maçá": "maçar",
    "maçámo": "maçar",
    "maçámos": "maçar",
    "maçáramo": "maçar",
    "maçáramos": "maçar",
    "maçárei": "maçar",
    "maçáreis": "maçar",
    "maçásseis": "maçar",
    "maçássemos": "maçar",
    "maçávamo": "maçar",
    "maçávamos": "maçar",
    "maçávei": "maçar",
    "maçáveis": "maçar",
    "maçãs": "maçã",
    "maçãzeiras": "maçãzeira",
    "maçónica": "maçónico",
    "maçónicas": "maçónico",
    "maçónicos": "maçónico",
    "mações": "mação",
    "maíses": "maís",
    "maúbas": "maúba",
    "maúças": "maúça",
    "meada": "mear",
    "meadas": "mear",
    "meadeiras": "meadeira",
    "meado": "mear",
    "meados": "mear",
    "meai": "mear",
    "meais": "mear",
    "mealhas": "mealha",
    "mealheira": "mealheiro",
    "mealheiras": "mealheiro",
    "mealheiros": "mealheiro",
    "mealhos": "mealho",
    "meamo": "mear",
    "meamos": "mear",
    "meando": "mear",
    "meandra": "meandrar",
    "meandrada": "meandrar",
    "meandradas": "meandrar",
    "meandrado": "meandrar",
    "meandrados": "meandrar",
    "meandrai": "meandrar",
    "meandrais": "meandrar",
    "meandram": "meandrar",
    "meandramo": "meandrar",
    "meandramos": "meandrar",
    "meandrando": "meandrar",
    "meandrara": "meandrar",
    "meandraram": "meandrar",
    "meandraras": "meandrar",
    "meandrardes": "meandrar",
    "meandrarei": "meandrar",
    "meandrareis": "meandrar",
    "meandrarem": "meandrar",
    "meandraremos": "meandrar",
    "meandrares": "meandrar",
    "meandraria": "meandrar",
    "meandrariam": "meandrar",
    "meandrarias": "meandrar",
    "meandrarmo": "meandrar",
    "meandrarmos": "meandrar",
    "meandrará": "meandrar",
    "meandrarás": "meandrar",
    "meandrarão": "meandrar",
    "meandraríamos": "meandrar",
    "meandraríeis": "meandrar",
    "meandras": "meandrar",
    "meandrasse": "meandrar",
    "meandrassem": "meandrar",
    "meandrasses": "meandrar",
    "meandraste": "meandrar",
    "meandrastes": "meandrar",
    "meandrava": "meandrar",
    "meandravam": "meandrar",
    "meandravas": "meandrar",
    "meandre": "meandrar",
    "meandrei": "meandrar",
    "meandreis": "meandrar",
    "meandrem": "meandrar",
    "meandremo": "meandrar",
    "meandremos": "meandrar",
    "meandres": "meandrar",
    "meandro": "meandrar",
    "meandros": "meandro",
    "meandrosa": "meandroso",
    "meandrosas": "meandroso",
    "meandrosos": "meandroso",
    "meandrou": "meandrar",
    "meandrámo": "meandrar",
    "meandrámos": "meandrar",
    "meandráramo": "meandrar",
    "meandráramos": "meandrar",
    "meandráreis": "meandrar",
    "meandrásseis": "meandrar",
    "meandrássemos": "meandrar",
    "meandrávamo": "meandrar",
    "meandrávamos": "meandrar",
    "meandráveis": "meandrar",
    "meantes": "meante",
    "meara": "mear",
    "mearam": "mear",
    "mearas": "mear",
    "mearde": "mear",
    "meardes": "mear",
    "meare": "mear",
    "mearei": "mear",
    "meareis": "mear",
    "mearem": "mear",
    "mearemos": "mear",
    "meares": "mear",
    "mearia": "mear",
    "meariam": "mear",
    "mearias": "mear",
    "mearmo": "mear",
    "mearmos": "mear",
    "meará": "mear",
    "mearás": "mear",
    "mearão": "mear",
    "mearíamos": "mear",
    "mearíeis": "mear",
    "measse": "mear",
    "meassem": "mear",
    "measses": "mear",
    "measte": "mear",
    "meastes": "mear",
    "meatos": "meato",
    "meava": "mear",
    "meavam": "mear",
    "meavas": "mear",
    "meaços": "meaço",
    "meações": "meação",
    "meca": "meco",
    "mecanicidades": "mecanicidade",
    "mecanicismos": "mecanicismo",
    "mecanicistas": "mecanicista",
    "mecanismos": "mecanismo",
    "mecaniza": "mecanizar",
    "mecanizada": "mecanizar",
    "mecanizadas": "mecanizar",
    "mecanizado": "mecanizar",
    "mecanizados": "mecanizar",
    "mecanizai": "mecanizar",
    "mecanizais": "mecanizar",
    "mecanizam": "mecanizar",
    "mecanizamo": "mecanizar",
    "mecanizamos": "mecanizar",
    "mecanizando": "mecanizar",
    "mecanizara": "mecanizar",
    "mecanizaram": "mecanizar",
    "mecanizaras": "mecanizar",
    "mecanizarde": "mecanizar",
    "mecanizardes": "mecanizar",
    "mecanizare": "mecanizar",
    "mecanizarei": "mecanizar",
    "mecanizareis": "mecanizar",
    "mecanizarem": "mecanizar",
    "mecanizaremos": "mecanizar",
    "mecanizares": "mecanizar",
    "mecanizaria": "mecanizar",
    "mecanizariam": "mecanizar",
    "mecanizarias": "mecanizar",
    "mecanizarmo": "mecanizar",
    "mecanizarmos": "mecanizar",
    "mecanizará": "mecanizar",
    "mecanizarás": "mecanizar",
    "mecanizarão": "mecanizar",
    "mecanizaríamos": "mecanizar",
    "mecanizaríeis": "mecanizar",
    "mecanizas": "mecanizar",
    "mecanizasse": "mecanizar",
    "mecanizassem": "mecanizar",
    "mecanizasses": "mecanizar",
    "mecanizaste": "mecanizar",
    "mecanizastes": "mecanizar",
    "mecanizava": "mecanizar",
    "mecanizavam": "mecanizar",
    "mecanizavas": "mecanizar",
    "mecanizações": "mecanização",
    "mecanize": "mecanizar",
    "mecanizei": "mecanizar",
    "mecanizeis": "mecanizar",
    "mecanizem": "mecanizar",
    "mecanizemo": "mecanizar",
    "mecanizemos": "mecanizar",
    "mecanizes": "mecanizar",
    "mecanizo": "mecanizar",
    "mecanizou": "mecanizar",
    "mecanizá": "mecanizar",
    "mecanizámo": "mecanizar",
    "mecanizámos": "mecanizar",
    "mecanizáramo": "mecanizar",
    "mecanizáramos": "mecanizar",
    "mecanizárei": "mecanizar",
    "mecanizáreis": "mecanizar",
    "mecanizásseis": "mecanizar",
    "mecanizássemos": "mecanizar",
    "mecanizávamo": "mecanizar",
    "mecanizávamos": "mecanizar",
    "mecanizávei": "mecanizar",
    "mecanizáveis": "mecanizável",
    "mecanografias": "mecanografia",
    "mecanográfica": "mecanográfico",
    "mecanográficas": "mecanográfico",
    "mecanográficos": "mecanográfico",
    "mecanoscritos": "mecanoscrito",
    "mecanoterapias": "mecanoterapia",
    "mecanoterápica": "mecanoterápico",
    "mecanoterápicas": "mecanoterápico",
    "mecanoterápicos": "mecanoterápico",
    "mecanógrafa": "mecanógrafo",
    "mecanógrafas": "mecanógrafo",
    "mecanógrafos": "mecanógrafo",
    "mecas": "meco",
    "mecenatos": "mecenato",
    "mecha": "mechar",
    "mechada": "mechar",
    "mechadas": "mechar",
    "mechado": "mechar",
    "mechados": "mechar",
    "mechagens": "mechagem",
    "mechai": "mechar",
    "mechais": "mechar",
    "mecham": "mechar",
    "mechamo": "mechar",
    "mechamos": "mechar",
    "mechando": "mechar",
    "mechara": "mechar",
    "mecharam": "mechar",
    "mecharas": "mechar",
    "mecharde": "mechar",
    "mechardes": "mechar",
    "mechare": "mechar",
    "mecharei": "mechar",
    "mechareis": "mechar",
    "mecharem": "mechar",
    "mecharemos": "mechar",
    "mechares": "mechar",
    "mecharia": "mechar",
    "mechariam": "mechar",
    "mecharias": "mechar",
    "mecharmo": "mechar",
    "mecharmos": "mechar",
    "mechará": "mechar",
    "mecharás": "mechar",
    "mecharão": "mechar",
    "mecharíamos": "mechar",
    "mecharíeis": "mechar",
    "mechas": "mechar",
    "mechasse": "mechar",
    "mechassem": "mechar",
    "mechasses": "mechar",
    "mechaste": "mechar",
    "mechastes": "mechar",
    "mechava": "mechar",
    "mechavam": "mechar",
    "mechavas": "mechar",
    "meche": "mechar",
    "mechei": "mechar",
    "mecheiros": "mecheiro",
    "mecheis": "mechar",
    "mechem": "mechar",
    "mechemo": "mechar",
    "mechemos": "mechar",
    "meches": "mechar",
    "mecho": "mechar",
    "mechoações": "mechoação",
    "mechou": "mechar",
    "mechá": "mechar",
    "mechámo": "mechar",
    "mechámos": "mechar",
    "mecháramo": "mechar",
    "mecháramos": "mechar",
    "mechárei": "mechar",
    "mecháreis": "mechar",
    "mechásseis": "mechar",
    "mechássemos": "mechar",
    "mechávamo": "mechar",
    "mechávamos": "mechar",
    "mechávei": "mechar",
    "mecháveis": "mechar",
    "meconofagias": "meconofagia",
    "meconófaga": "meconófago",
    "meconófagas": "meconófago",
    "meconófagos": "meconófago",
    "mecos": "meco",
    "mecrus": "mecru",
    "mecânica": "mecânico",
    "mecânicas": "mecânico",
    "mecânicos": "mecânico",
    "mecómetros": "mecómetro",
    "mecónios": "mecónio",
    "mecópodes": "mecópode",
    "meda": "medo",
    "medalha": "medalhar",
    "medalhada": "medalhar",
    "medalhadas": "medalhar",
    "medalhado": "medalhar",
    "medalhados": "medalhar",
    "medalhai": "medalhar",
    "medalhais": "medalhar",
    "medalham": "medalhar",
    "medalhamo": "medalhar",
    "medalhamos": "medalhar",
    "medalhando": "medalhar",
    "medalhara": "medalhar",
    "medalharam": "medalhar",
    "medalharas": "medalhar",
    "medalharde": "medalhar",
    "medalhardes": "medalhar",
    "medalhare": "medalhar",
    "medalharei": "medalhar",
    "medalhareis": "medalhar",
    "medalharem": "medalhar",
    "medalharemos": "medalhar",
    "medalhares": "medalhar",
    "medalharia": "medalhar",
    "medalhariam": "medalhar",
    "medalharias": "medalhar",
    "medalharmo": "medalhar",
    "medalharmos": "medalhar",
    "medalhará": "medalhar",
    "medalharás": "medalhar",
    "medalharão": "medalhar",
    "medalharíamos": "medalhar",
    "medalharíeis": "medalhar",
    "medalhas": "medalhar",
    "medalhasse": "medalhar",
    "medalhassem": "medalhar",
    "medalhasses": "medalhar",
    "medalhaste": "medalhar",
    "medalhastes": "medalhar",
    "medalhava": "medalhar",
    "medalhavam": "medalhar",
    "medalhavas": "medalhar",
    "medalhe": "medalhar",
    "medalhei": "medalhar",
    "medalheiros": "medalheiro",
    "medalheis": "medalhar",
    "medalhem": "medalhar",
    "medalhemo": "medalhar",
    "medalhemos": "medalhar",
    "medalhes": "medalhar",
    "medalhinha": "medalha",
    "medalhinhas": "medalha",
    "medalhistas": "medalhista",
    "medalhita": "medalha",
    "medalhitas": "medalha",
    "medalho": "medalhar",
    "medalhou": "medalhar",
    "medalhá": "medalhar",
    "medalhámo": "medalhar",
    "medalhámos": "medalhar",
    "medalháramo": "medalhar",
    "medalháramos": "medalhar",
    "medalhárei": "medalhar",
    "medalháreis": "medalhar",
    "medalhários": "medalhário",
    "medalhásseis": "medalhar",
    "medalhássemos": "medalhar",
    "medalhávamo": "medalhar",
    "medalhávamos": "medalhar",
    "medalhávei": "medalhar",
    "medalháveis": "medalhável",
    "medalhísticas": "medalhística",
    "medalhões": "medalhão",
    "medas": "medo",
    "mede": "medir",
    "medeia": "mediar",
    "medeiam": "mediar",
    "medeias": "mediar",
    "medeie": "mediar",
    "medeiem": "mediar",
    "medeies": "mediar",
    "medeio": "mediar",
    "medeiros": "medeiro",
    "medem": "medir",
    "medes": "medir",
    "medi": "medir",
    "media": "medir",
    "mediada": "mediar",
    "mediadas": "mediar",
    "mediado": "mediar",
    "mediadora": "mediador",
    "mediadoras": "mediador",
    "mediadores": "mediador",
    "mediados": "mediar",
    "mediai": "mediar",
    "mediais": "mediar",
    "mediam": "medir",
    "mediamo": "mediar",
    "mediamos": "mediar",
    "mediana": "mediano",
    "medianas": "mediano",
    "mediando": "mediar",
    "medianeira": "medianeiro",
    "medianeiras": "medianeiro",
    "medianeiros": "medianeiro",
    "medianias": "mediania",
    "medianimidades": "medianimidade",
    "medianismos": "medianismo",
    "medianiza": "medianizar",
    "medianizada": "medianizar",
    "medianizadas": "medianizar",
    "medianizado": "medianizar",
    "medianizados": "medianizar",
    "medianizai": "medianizar",
    "medianizais": "medianizar",
    "medianizam": "medianizar",
    "medianizamo": "medianizar",
    "medianizamos": "medianizar",
    "medianizando": "medianizar",
    "medianizara": "medianizar",
    "medianizaram": "medianizar",
    "medianizaras": "medianizar",
    "medianizarde": "medianizar",
    "medianizardes": "medianizar",
    "medianizare": "medianizar",
    "medianizarei": "medianizar",
    "medianizareis": "medianizar",
    "medianizarem": "medianizar",
    "medianizaremos": "medianizar",
    "medianizares": "medianizar",
    "medianizaria": "medianizar",
    "medianizariam": "medianizar",
    "medianizarias": "medianizar",
    "medianizarmo": "medianizar",
    "medianizarmos": "medianizar",
    "medianizará": "medianizar",
    "medianizarás": "medianizar",
    "medianizarão": "medianizar",
    "medianizaríamos": "medianizar",
    "medianizaríeis": "medianizar",
    "medianizas": "medianizar",
    "medianizasse": "medianizar",
    "medianizassem": "medianizar",
    "medianizasses": "medianizar",
    "medianizaste": "medianizar",
    "medianizastes": "medianizar",
    "medianizava": "medianizar",
    "medianizavam": "medianizar",
    "medianizavas": "medianizar",
    "medianize": "medianizar",
    "medianizei": "medianizar",
    "medianizeis": "medianizar",
    "medianizem": "medianizar",
    "medianizemo": "medianizar",
    "medianizemos": "medianizar",
    "medianizes": "medianizar",
    "medianizo": "medianizar",
    "medianizou": "medianizar",
    "medianizá": "medianizar",
    "medianizámo": "medianizar",
    "medianizámos": "medianizar",
    "medianizáramo": "medianizar",
    "medianizáramos": "medianizar",
    "medianizárei": "medianizar",
    "medianizáreis": "medianizar",
    "medianizásseis": "medianizar",
    "medianizássemos": "medianizar",
    "medianizávamo": "medianizar",
    "medianizávamos": "medianizar",
    "medianizávei": "medianizar",
    "medianizáveis": "medianizar",
    "medianos": "mediano",
    "mediantes": "mediante",
    "medianímica": "medianímico",
    "medianímicas": "medianímico",
    "medianímicos": "medianímico",
    "mediara": "mediar",
    "mediaram": "mediar",
    "mediaras": "mediar",
    "mediarde": "mediar",
    "mediardes": "mediar",
    "mediare": "mediar",
    "mediarei": "mediar",
    "mediareis": "mediar",
    "mediarem": "mediar",
    "mediaremos": "mediar",
    "mediares": "mediar",
    "mediaria": "mediar",
    "mediariam": "mediar",
    "mediarias": "mediar",
    "mediarmo": "mediar",
    "mediarmos": "mediar",
    "mediará": "mediar",
    "mediarás": "mediar",
    "mediarão": "mediar",
    "mediaríamos": "mediar",
    "mediaríeis": "mediar",
    "medias": "medir",
    "mediasse": "mediar",
    "mediassem": "mediar",
    "mediasses": "mediar",
    "mediaste": "mediar",
    "mediastes": "mediar",
    "mediastinites": "mediastinite",
    "mediastinos": "mediastino",
    "mediata": "mediato",
    "mediatas": "mediato",
    "mediatecas": "mediateca",
    "mediatismos": "mediatismo",
    "mediatiza": "mediatizar",
    "mediatizada": "mediatizar",
    "mediatizadas": "mediatizar",
    "mediatizado": "mediatizar",
    "mediatizados": "mediatizar",
    "mediatizai": "mediatizar",
    "mediatizais": "mediatizar",
    "mediatizam": "mediatizar",
    "mediatizamo": "mediatizar",
    "mediatizamos": "mediatizar",
    "mediatizando": "mediatizar",
    "mediatizara": "mediatizar",
    "mediatizaram": "mediatizar",
    "mediatizaras": "mediatizar",
    "mediatizarde": "mediatizar",
    "mediatizardes": "mediatizar",
    "mediatizare": "mediatizar",
    "mediatizarei": "mediatizar",
    "mediatizareis": "mediatizar",
    "mediatizarem": "mediatizar",
    "mediatizaremos": "mediatizar",
    "mediatizares": "mediatizar",
    "mediatizaria": "mediatizar",
    "mediatizariam": "mediatizar",
    "mediatizarias": "mediatizar",
    "mediatizarmo": "mediatizar",
    "mediatizarmos": "mediatizar",
    "mediatizará": "mediatizar",
    "mediatizarás": "mediatizar",
    "mediatizarão": "mediatizar",
    "mediatizaríamos": "mediatizar",
    "mediatizaríeis": "mediatizar",
    "mediatizas": "mediatizar",
    "mediatizasse": "mediatizar",
    "mediatizassem": "mediatizar",
    "mediatizasses": "mediatizar",
    "mediatizaste": "mediatizar",
    "mediatizastes": "mediatizar",
    "mediatizava": "mediatizar",
    "mediatizavam": "mediatizar",
    "mediatizavas": "mediatizar",
    "mediatizações": "mediatização",
    "mediatize": "mediatizar",
    "mediatizei": "mediatizar",
    "mediatizeis": "mediatizar",
    "mediatizem": "mediatizar",
    "mediatizemo": "mediatizar",
    "mediatizemos": "mediatizar",
    "mediatizes": "mediatizar",
    "mediatizo": "mediatizar",
    "mediatizou": "mediatizar",
    "mediatizá": "mediatizar",
    "mediatizámo": "mediatizar",
    "mediatizámos": "mediatizar",
    "mediatizáramo": "mediatizar",
    "mediatizáramos": "mediatizar",
    "mediatizárei": "mediatizar",
    "mediatizáreis": "mediatizar",
    "mediatizásseis": "mediatizar",
    "mediatizássemos": "mediatizar",
    "mediatizávamo": "mediatizar",
    "mediatizávamos": "mediatizar",
    "mediatizávei": "mediatizar",
    "mediatizáveis": "mediatizar",
    "mediatos": "mediato",
    "mediatrizes": "mediatriz",
    "mediatária": "mediatário",
    "mediatárias": "mediatário",
    "mediatários": "mediatário",
    "mediava": "mediar",
    "mediavam": "mediar",
    "mediavas": "mediar",
    "mediações": "mediação",
    "medica": "medicar",
    "medicada": "medicar",
    "medicadas": "medicar",
    "medicado": "medicar",
    "medicados": "medicar",
    "medicai": "medicar",
    "medicais": "medicar",
    "medicam": "medicar",
    "medicamenta": "medicamentar",
    "medicamentada": "medicamentar",
    "medicamentadas": "medicamentar",
    "medicamentado": "medicamentar",
    "medicamentados": "medicamentar",
    "medicamentai": "medicamentar",
    "medicamentais": "medicamentar",
    "medicamentam": "medicamentar",
    "medicamentamo": "medicamentar",
    "medicamentamos": "medicamentar",
    "medicamentando": "medicamentar",
    "medicamentara": "medicamentar",
    "medicamentaram": "medicamentar",
    "medicamentaras": "medicamentar",
    "medicamentarde": "medicamentar",
    "medicamentardes": "medicamentar",
    "medicamentare": "medicamentar",
    "medicamentarei": "medicamentar",
    "medicamentareis": "medicamentar",
    "medicamentarem": "medicamentar",
    "medicamentaremos": "medicamentar",
    "medicamentares": "medicamentar",
    "medicamentaria": "medicamentar",
    "medicamentariam": "medicamentar",
    "medicamentarias": "medicamentar",
    "medicamentarmo": "medicamentar",
    "medicamentarmos": "medicamentar",
    "medicamentará": "medicamentar",
    "medicamentarás": "medicamentar",
    "medicamentarão": "medicamentar",
    "medicamentaríamos": "medicamentar",
    "medicamentaríeis": "medicamentar",
    "medicamentas": "medicamentar",
    "medicamentasse": "medicamentar",
    "medicamentassem": "medicamentar",
    "medicamentasses": "medicamentar",
    "medicamentaste": "medicamentar",
    "medicamentastes": "medicamentar",
    "medicamentava": "medicamentar",
    "medicamentavam": "medicamentar",
    "medicamentavas": "medicamentar",
    "medicamentações": "medicamentação",
    "medicamente": "medicamentar",
    "medicamentei": "medicamentar",
    "medicamenteis": "medicamentar",
    "medicamentem": "medicamentar",
    "medicamentemo": "medicamentar",
    "medicamentemos": "medicamentar",
    "medicamentes": "medicamentar",
    "medicamento": "medicamentar",
    "medicamentos": "medicamento",
    "medicamentosa": "medicamentoso",
    "medicamentosas": "medicamentoso",
    "medicamentosos": "medicamentoso",
    "medicamentou": "medicamentar",
    "medicamentá": "medicamentar",
    "medicamentámo": "medicamentar",
    "medicamentámos": "medicamentar",
    "medicamentáramo": "medicamentar",
    "medicamentáramos": "medicamentar",
    "medicamentárei": "medicamentar",
    "medicamentáreis": "medicamentar",
    "medicamentásseis": "medicamentar",
    "medicamentássemos": "medicamentar",
    "medicamentávamo": "medicamentar",
    "medicamentávamos": "medicamentar",
    "medicamentávei": "medicamentar",
    "medicamentáveis": "medicamentar",
    "medicamo": "medicar",
    "medicamos": "medicar",
    "medicanda": "medicando",
    "medicandas": "medicando",
    "medicando": "medicar",
    "medicandos": "medicando",
    "medicantes": "medicante",
    "medicanças": "medicança",
    "medicara": "medicar",
    "medicaram": "medicar",
    "medicaras": "medicar",
    "medicarde": "medicar",
    "medicardes": "medicar",
    "medicare": "medicar",
    "medicarei": "medicar",
    "medicareis": "medicar",
    "medicarem": "medicar",
    "medicaremos": "medicar",
    "medicares": "medicar",
    "medicaria": "medicar",
    "medicariam": "medicar",
    "medicarias": "medicar",
    "medicarmo": "medicar",
    "medicarmos": "medicar",
    "medicará": "medicar",
    "medicarás": "medicar",
    "medicarão": "medicar",
    "medicaríamos": "medicar",
    "medicaríeis": "medicar",
    "medicas": "medicar",
    "medicasse": "medicar",
    "medicassem": "medicar",
    "medicasses": "medicar",
    "medicaste": "medicar",
    "medicastes": "medicar",
    "medicastra": "medicastro",
    "medicastras": "medicastro",
    "medicastros": "medicastro",
    "medicativa": "medicativo",
    "medicativas": "medicativo",
    "medicativos": "medicativo",
    "medicatrizes": "medicatriz",
    "medicava": "medicar",
    "medicavam": "medicar",
    "medicavas": "medicar",
    "medicações": "medicação",
    "medicina": "medicinar",
    "medicinada": "medicinar",
    "medicinadas": "medicinar",
    "medicinado": "medicinar",
    "medicinados": "medicinar",
    "medicinai": "medicinar",
    "medicinais": "medicinar",
    "medicinam": "medicinar",
    "medicinamo": "medicinar",
    "medicinamos": "medicinar",
    "medicinando": "medicinar",
    "medicinara": "medicinar",
    "medicinaram": "medicinar",
    "medicinaras": "medicinar",
    "medicinarde": "medicinar",
    "medicinardes": "medicinar",
    "medicinare": "medicinar",
    "medicinarei": "medicinar",
    "medicinareis": "medicinar",
    "medicinarem": "medicinar",
    "medicinaremos": "medicinar",
    "medicinares": "medicinar",
    "medicinaria": "medicinar",
    "medicinariam": "medicinar",
    "medicinarias": "medicinar",
    "medicinarmo": "medicinar",
    "medicinarmos": "medicinar",
    "medicinará": "medicinar",
    "medicinarás": "medicinar",
    "medicinarão": "medicinar",
    "medicinaríamos": "medicinar",
    "medicinaríeis": "medicinar",
    "medicinas": "medicinar",
    "medicinasse": "medicinar",
    "medicinassem": "medicinar",
    "medicinasses": "medicinar",
    "medicinaste": "medicinar",
    "medicinastes": "medicinar",
    "medicinava": "medicinar",
    "medicinavam": "medicinar",
    "medicinavas": "medicinar",
    "medicine": "medicinar",
    "medicinei": "medicinar",
    "medicineiros": "medicineiro",
    "medicineis": "medicinar",
    "medicinem": "medicinar",
    "medicinemo": "medicinar",
    "medicinemos": "medicinar",
    "medicines": "medicinar",
    "medicino": "medicinar",
    "medicinou": "medicinar",
    "mediciná": "medicinar",
    "medicinámo": "medicinar",
    "medicinámos": "medicinar",
    "medicináramo": "medicinar",
    "medicináramos": "medicinar",
    "medicinárei": "medicinar",
    "medicináreis": "medicinar",
    "medicinásseis": "medicinar",
    "medicinássemos": "medicinar",
    "medicinávamo": "medicinar",
    "medicinávamos": "medicinar",
    "medicinávei": "medicinar",
    "medicináveis": "medicinar",
    "medico": "medicar",
    "medicomanias": "medicomania",
    "medicomaníaca": "medicomaníaco",
    "medicomaníacas": "medicomaníaco",
    "medicomaníacos": "medicomaníaco",
    "medicou": "medicar",
    "medicá": "medicar",
    "medicámo": "medicar",
    "medicámos": "medicar",
    "medicáramo": "medicar",
    "medicáramos": "medicar",
    "medicárei": "medicar",
    "medicáreis": "medicar",
    "medicásseis": "medicar",
    "medicássemos": "medicar",
    "medicávamo": "medicar",
    "medicávamos": "medicar",
    "medicávei": "medicar",
    "medicáveis": "medicável",
    "medida": "medir",
    "medidagens": "medidagem",
    "medidas": "medir",
    "medido": "medir",
    "medidora": "medidor",
    "medidoras": "medidor",
    "medidores": "medidor",
    "medidos": "medir",
    "mediei": "mediar",
    "medieis": "mediar",
    "mediemo": "mediar",
    "mediemos": "mediar",
    "medieva": "medievo",
    "medievais": "medieval",
    "medievalidades": "medievalidade",
    "medievalismos": "medievalismo",
    "medievalistas": "medievalista",
    "medievas": "medievo",
    "medievismos": "medievismo",
    "medievistas": "medievista",
    "medievos": "medievo",
    "medimarímetros": "medimarímetro",
    "medimo": "medir",
    "medimos": "medir",
    "medindo": "medir",
    "medinho": "medo",
    "medinhos": "medo",
    "mediocracias": "mediocracia",
    "mediocridades": "mediocridade",
    "mediocriza": "mediocrizar",
    "mediocrizada": "mediocrizar",
    "mediocrizadas": "mediocrizar",
    "mediocrizado": "mediocrizar",
    "mediocrizados": "mediocrizar",
    "mediocrizai": "mediocrizar",
    "mediocrizais": "mediocrizar",
    "mediocrizam": "mediocrizar",
    "mediocrizamo": "mediocrizar",
    "mediocrizamos": "mediocrizar",
    "mediocrizando": "mediocrizar",
    "mediocrizara": "mediocrizar",
    "mediocrizaram": "mediocrizar",
    "mediocrizaras": "mediocrizar",
    "mediocrizarde": "mediocrizar",
    "mediocrizardes": "mediocrizar",
    "mediocrizare": "mediocrizar",
    "mediocrizarei": "mediocrizar",
    "mediocrizareis": "mediocrizar",
    "mediocrizarem": "mediocrizar",
    "mediocrizaremos": "mediocrizar",
    "mediocrizares": "mediocrizar",
    "mediocrizaria": "mediocrizar",
    "mediocrizariam": "mediocrizar",
    "mediocrizarias": "mediocrizar",
    "mediocrizarmo": "mediocrizar",
    "mediocrizarmos": "mediocrizar",
    "mediocrizará": "mediocrizar",
    "mediocrizarás": "mediocrizar",
    "mediocrizarão": "mediocrizar",
    "mediocrizaríamos": "mediocrizar",
    "mediocrizaríeis": "mediocrizar",
    "mediocrizas": "mediocrizar",
    "mediocrizasse": "mediocrizar",
    "mediocrizassem": "mediocrizar",
    "mediocrizasses": "mediocrizar",
    "mediocrizaste": "mediocrizar",
    "mediocrizastes": "mediocrizar",
    "mediocrizava": "mediocrizar",
    "mediocrizavam": "mediocrizar",
    "mediocrizavas": "mediocrizar",
    "mediocrize": "mediocrizar",
    "mediocrizei": "mediocrizar",
    "mediocrizeis": "mediocrizar",
    "mediocrizem": "mediocrizar",
    "mediocrizemo": "mediocrizar",
    "mediocrizemos": "mediocrizar",
    "mediocrizes": "mediocrizar",
    "mediocrizo": "mediocrizar",
    "mediocrizou": "mediocrizar",
    "mediocrizá": "mediocrizar",
    "mediocrizámo": "mediocrizar",
    "mediocrizámos": "mediocrizar",
    "mediocrizáramo": "mediocrizar",
    "mediocrizáramos": "mediocrizar",
    "mediocrizárei": "mediocrizar",
    "mediocrizáreis": "mediocrizar",
    "mediocrizásseis": "mediocrizar",
    "mediocrizássemos": "mediocrizar",
    "mediocrizávamo": "mediocrizar",
    "mediocrizávamos": "mediocrizar",
    "mediocrizávei": "mediocrizar",
    "mediocrizáveis": "mediocrizável",
    "mediou": "mediar",
    "medique": "medicar",
    "mediquei": "medicar",
    "mediqueis": "medicar",
    "mediquem": "medicar",
    "mediquemo": "medicar",
    "mediquemos": "medicar",
    "mediques": "medicar",
    "medira": "medir",
    "mediram": "medir",
    "mediras": "medir",
    "medirde": "medir",
    "medirdes": "medir",
    "medire": "medir",
    "medirei": "medir",
    "medireis": "medir",
    "medirem": "medir",
    "mediremos": "medir",
    "medires": "medir",
    "mediria": "medir",
    "mediriam": "medir",
    "medirias": "medir",
    "medirmo": "medir",
    "medirmos": "medir",
    "medirá": "medir",
    "medirás": "medir",
    "medirão": "medir",
    "mediríamos": "medir",
    "mediríeis": "medir",
    "medis": "medir",
    "medisse": "medir",
    "medissem": "medir",
    "medisses": "medir",
    "mediste": "medir",
    "medistes": "medir",
    "medita": "meditar",
    "meditabunda": "meditabundo",
    "meditabundas": "meditabundo",
    "meditabundos": "meditabundo",
    "meditada": "meditar",
    "meditadas": "meditar",
    "meditado": "meditar",
    "meditadora": "meditador",
    "meditadoras": "meditador",
    "meditadores": "meditador",
    "meditados": "meditar",
    "meditai": "meditar",
    "meditais": "meditar",
    "meditam": "meditar",
    "meditamo": "meditar",
    "meditamos": "meditar",
    "meditando": "meditar",
    "meditara": "meditar",
    "meditaram": "meditar",
    "meditaras": "meditar",
    "meditarde": "meditar",
    "meditardes": "meditar",
    "meditare": "meditar",
    "meditarei": "meditar",
    "meditareis": "meditar",
    "meditarem": "meditar",
    "meditaremos": "meditar",
    "meditares": "meditar",
    "meditaria": "meditar",
    "meditariam": "meditar",
    "meditarias": "meditar",
    "meditarmo": "meditar",
    "meditarmos": "meditar",
    "meditará": "meditar",
    "meditarás": "meditar",
    "meditarão": "meditar",
    "meditaríamos": "meditar",
    "meditaríeis": "meditar",
    "meditas": "meditar",
    "meditasse": "meditar",
    "meditassem": "meditar",
    "meditasses": "meditar",
    "meditaste": "meditar",
    "meditastes": "meditar",
    "meditativa": "meditativo",
    "meditativas": "meditativo",
    "meditativos": "meditativo",
    "meditava": "meditar",
    "meditavam": "meditar",
    "meditavas": "meditar",
    "meditações": "meditação",
    "medite": "meditar",
    "meditei": "meditar",
    "mediteis": "meditar",
    "meditem": "meditar",
    "meditemo": "meditar",
    "meditemos": "meditar",
    "mediterrânea": "mediterrâneo",
    "mediterrâneas": "mediterrâneo",
    "mediterrâneos": "mediterrâneo",
    "mediterrânica": "mediterrânico",
    "mediterrânicas": "mediterrânico",
    "mediterrânicos": "mediterrânico",
    "medites": "meditar",
    "medito": "medo",
    "meditos": "medo",
    "meditou": "meditar",
    "meditá": "meditar",
    "meditámo": "meditar",
    "meditámos": "meditar",
    "meditáramo": "meditar",
    "meditáramos": "meditar",
    "meditárei": "meditar",
    "meditáreis": "meditar",
    "meditásseis": "meditar",
    "meditássemos": "meditar",
    "meditávamo": "meditar",
    "meditávamos": "meditar",
    "meditávei": "meditar",
    "meditáveis": "meditável",
    "mediu": "medir",
    "mediá": "mediar",
    "mediámo": "mediar",
    "mediámos": "mediar",
    "mediáramo": "mediar",
    "mediáramos": "mediar",
    "mediárei": "mediar",
    "mediáreis": "mediar",
    "mediásseis": "mediar",
    "mediássemos": "mediar",
    "mediática": "mediático",
    "mediáticas": "mediático",
    "mediáticos": "mediático",
    "mediávamo": "mediar",
    "mediávamos": "mediar",
    "mediávei": "mediar",
    "mediáveis": "mediar",
    "medições": "medição",
    "mediévica": "mediévico",
    "mediévicas": "mediévico",
    "mediévicos": "mediévico",
    "mediúnica": "mediúnico",
    "mediúnicas": "mediúnico",
    "mediúnicos": "mediúnico",
    "medonha": "medonho",
    "medonhas": "medonho",
    "medonhos": "medonho",
    "medorreias": "medorreia",
    "medos": "medo",
    "medouços": "medouço",
    "medra": "medrar",
    "medrada": "medrar",
    "medradas": "medrar",
    "medrado": "medrar",
    "medrados": "medrar",
    "medrai": "medrar",
    "medrais": "medrar",
    "medram": "medrar",
    "medramo": "medrar",
    "medramos": "medrar",
    "medrando": "medrar",
    "medranças": "medrança",
    "medrançosa": "medrançoso",
    "medrançosas": "medrançoso",
    "medrançosos": "medrançoso",
    "medrara": "medrar",
    "medraram": "medrar",
    "medraras": "medrar",
    "medrarde": "medrar",
    "medrardes": "medrar",
    "medrare": "medrar",
    "medrarei": "medrar",
    "medrareis": "medrar",
    "medrarem": "medrar",
    "medraremos": "medrar",
    "medrares": "medrar",
    "medraria": "medrar",
    "medrariam": "medrar",
    "medrarias": "medrar",
    "medrarmo": "medrar",
    "medrarmos": "medrar",
    "medrará": "medrar",
    "medrarás": "medrar",
    "medrarão": "medrar",
    "medraríamos": "medrar",
    "medraríeis": "medrar",
    "medras": "medrar",
    "medrasse": "medrar",
    "medrassem": "medrar",
    "medrasses": "medrar",
    "medraste": "medrar",
    "medrastes": "medrar",
    "medrava": "medrar",
    "medravam": "medrar",
    "medravas": "medrar",
    "medre": "medrar",
    "medrei": "medrar",
    "medreis": "medrar",
    "medrem": "medrar",
    "medremo": "medrar",
    "medremos": "medrar",
    "medres": "medrar",
    "medricas": "medrica",
    "medrios": "medrio",
    "medro": "medrar",
    "medronhais": "medronhal",
    "medronheiros": "medronheiro",
    "medronhos": "medronho",
    "medrosa": "medroso",
    "medrosas": "medroso",
    "medrosos": "medroso",
    "medrou": "medrar",
    "medrá": "medrar",
    "medrámo": "medrar",
    "medrámos": "medrar",
    "medráramo": "medrar",
    "medráramos": "medrar",
    "medrárei": "medrar",
    "medráreis": "medrar",
    "medrásseis": "medrar",
    "medrássemos": "medrar",
    "medrávamo": "medrar",
    "medrávamos": "medrar",
    "medrávei": "medrar",
    "medráveis": "medrar",
    "medula": "medular",
    "medulada": "medular",
    "meduladas": "medular",
    "medulado": "medular",
    "medulados": "medular",
    "medulai": "medular",
    "medulais": "medular",
    "medulam": "medular",
    "medulamo": "medular",
    "medulamos": "medular",
    "medulando": "medular",
    "medulara": "medular",
    "medularam": "medular",
    "medularas": "medular",
    "medulardes": "medular",
    "medularei": "medular",
    "medulareis": "medular",
    "medularem": "medular",
    "medularemos": "medular",
    "medulares": "medular",
    "medularia": "medular",
    "medulariam": "medular",
    "medularias": "medular",
    "medularmo": "medular",
    "medularmos": "medular",
    "medulará": "medular",
    "medularás": "medular",
    "medularão": "medular",
    "medularíamos": "medular",
    "medularíeis": "medular",
    "medulas": "medular",
    "medulasse": "medular",
    "medulassem": "medular",
    "medulasses": "medular",
    "medulaste": "medular",
    "medulastes": "medular",
    "medulava": "medular",
    "medulavam": "medular",
    "medulavas": "medular",
    "medule": "medular",
    "medulei": "medular",
    "meduleis": "medular",
    "medulem": "medular",
    "medulemo": "medular",
    "medulemos": "medular",
    "medules": "medular",
    "medulinas": "medulina",
    "medulites": "medulite",
    "medulo": "medular",
    "meduloblastomas": "meduloblastoma",
    "medulosa": "meduloso",
    "medulosas": "meduloso",
    "medulosos": "meduloso",
    "medulou": "medular",
    "medulámo": "medular",
    "medulámos": "medular",
    "meduláramo": "medular",
    "meduláramos": "medular",
    "meduláreis": "medular",
    "medulásseis": "medular",
    "medulássemos": "medular",
    "medulávamo": "medular",
    "medulávamos": "medular",
    "meduláveis": "medular",
    "medusas": "medusa",
    "meduseia": "meduseu",
    "meduseias": "meduseu",
    "meduseus": "meduseu",
    "medusária": "medusário",
    "medusárias": "medusário",
    "medusários": "medusário",
    "medusóides": "medusóide",
    "medíamo": "medir",
    "medíamos": "medir",
    "medíei": "medir",
    "medíeis": "medir",
    "medíocres": "medíocre",
    "medíramo": "medir",
    "medíramos": "medir",
    "medírei": "medir",
    "medíreis": "medir",
    "medísseis": "medir",
    "medíssemos": "medir",
    "medíveis": "medível",
    "medúsica": "medúsico",
    "medúsicas": "medúsico",
    "medúsicos": "medúsico",
    "meei": "mear",
    "meeira": "meeiro",
    "meeiras": "meeiro",
    "meeiros": "meeiro",
    "meeis": "mear",
    "meemo": "mear",
    "meemos": "mear",
    "meetings": "meeting",
    "mefistofélica": "mefistofélico",
    "mefistofélicas": "mefistofélico",
    "mefistofélicos": "mefistofélico",
    "mefitismos": "mefitismo",
    "mefítica": "mefítico",
    "mefíticas": "mefítico",
    "mefíticos": "mefítico",
    "megacariócitos": "megacariócito",
    "megaciclos": "megaciclo",
    "megadines": "megadine",
    "megafones": "megafone",
    "megajoules": "megajoule",
    "megalanta": "megalanto",
    "megalantas": "megalanto",
    "megalantos": "megalanto",
    "megalegorias": "megalegoria",
    "megalepatias": "megalepatia",
    "megalitismos": "megalitismo",
    "megalitos": "megalito",
    "megalocardias": "megalocardia",
    "megalocefalias": "megalocefalia",
    "megaloceles": "megalocele",
    "megalocéfala": "megalocéfalo",
    "megalocéfalas": "megalocéfalo",
    "megalocéfalos": "megalocéfalo",
    "megalocélios": "megalocélio",
    "megalodactilias": "megalodactilia",
    "megalodáctila": "megalodáctilo",
    "megalodáctilas": "megalodáctilo",
    "megalodáctilos": "megalodáctilo",
    "megalografias": "megalografia",
    "megalomanias": "megalomania",
    "megalomaníaca": "megalomaníaco",
    "megalomaníacas": "megalomaníaco",
    "megalomaníacos": "megalomaníaco",
    "megalossauros": "megalossauro",
    "megalítica": "megalítico",
    "megalíticas": "megalítico",
    "megalíticos": "megalítico",
    "megalómana": "megalómano",
    "megalómanas": "megalómano",
    "megalómanos": "megalómano",
    "megalópodes": "megalópode",
    "megalóstoma": "megalóstomo",
    "megalóstomas": "megalóstomo",
    "megalóstomos": "megalóstomo",
    "megaohms": "megaohm",
    "megaprocessos": "megaprocesso",
    "megaprojectos": "megaprojecto",
    "megas": "mega",
    "megascópios": "megascópio",
    "megasférica": "megasférico",
    "megasféricas": "megasférico",
    "megasféricos": "megasférico",
    "megassismos": "megassismo",
    "megatérios": "megatério",
    "megeras": "megera",
    "megálios": "megálio",
    "megálitos": "megálito",
    "megâmetros": "megâmetro",
    "meia": "meio",
    "meiam": "mear",
    "meias": "meio",
    "meiazinha": "meia",
    "meiazinhas": "meia",
    "meiazita": "meia",
    "meiazitas": "meia",
    "meie": "mear",
    "meieira": "meieiro",
    "meieiras": "meieiro",
    "meieiros": "meieiro",
    "meiem": "mear",
    "meies": "mear",
    "meiga": "meigo",
    "meigas": "meigo",
    "meigos": "meigo",
    "meiguiceira": "meiguiceiro",
    "meiguiceiras": "meiguiceiro",
    "meiguiceiros": "meiguiceiro",
    "meiguices": "meiguice",
    "meiguinha": "meigo",
    "meiguinhas": "meigo",
    "meiguinho": "meigo",
    "meiguinhos": "meigo",
    "meiguita": "meigo",
    "meiguitas": "meigo",
    "meiguito": "meigo",
    "meiguitos": "meigo",
    "meiguíssima": "meigo",
    "meiguíssimas": "meigo",
    "meiguíssimo": "meigo",
    "meiguíssimos": "meigo",
    "meiinha": "meia",
    "meiinhas": "meia",
    "meiita": "meia",
    "meiitas": "meia",
    "meijengra": "meijengro",
    "meijengras": "meijengro",
    "meijengros": "meijengro",
    "meijoadas": "meijoada",
    "meimendros": "meimendro",
    "meiminha": "meiminho",
    "meiminhas": "meiminho",
    "meiminhos": "meiminho",
    "meio": "mear",
    "meios": "meio",
    "meioses": "meiose",
    "meiotas": "meiota",
    "meiotes": "meiote",
    "meirinha": "meirinho",
    "meirinhada": "meirinhar",
    "meirinhadas": "meirinhar",
    "meirinhado": "meirinhar",
    "meirinhados": "meirinhar",
    "meirinhai": "meirinhar",
    "meirinhais": "meirinhar",
    "meirinham": "meirinhar",
    "meirinhamo": "meirinhar",
    "meirinhamos": "meirinhar",
    "meirinhando": "meirinhar",
    "meirinhara": "meirinhar",
    "meirinharam": "meirinhar",
    "meirinharas": "meirinhar",
    "meirinhardes": "meirinhar",
    "meirinharei": "meirinhar",
    "meirinhareis": "meirinhar",
    "meirinharem": "meirinhar",
    "meirinharemos": "meirinhar",
    "meirinhares": "meirinhar",
    "meirinharia": "meirinhar",
    "meirinhariam": "meirinhar",
    "meirinharias": "meirinhar",
    "meirinharmo": "meirinhar",
    "meirinharmos": "meirinhar",
    "meirinhará": "meirinhar",
    "meirinharás": "meirinhar",
    "meirinharão": "meirinhar",
    "meirinharíamos": "meirinhar",
    "meirinharíeis": "meirinhar",
    "meirinhas": "meirinho",
    "meirinhasse": "meirinhar",
    "meirinhassem": "meirinhar",
    "meirinhasses": "meirinhar",
    "meirinhaste": "meirinhar",
    "meirinhastes": "meirinhar",
    "meirinhava": "meirinhar",
    "meirinhavam": "meirinhar",
    "meirinhavas": "meirinhar",
    "meirinhe": "meirinhar",
    "meirinhei": "meirinhar",
    "meirinheis": "meirinhar",
    "meirinhem": "meirinhar",
    "meirinhemo": "meirinhar",
    "meirinhemos": "meirinhar",
    "meirinhes": "meirinhar",
    "meirinho": "meirinhar",
    "meirinhos": "meirinho",
    "meirinhou": "meirinhar",
    "meirinhámo": "meirinhar",
    "meirinhámos": "meirinhar",
    "meirinháramo": "meirinhar",
    "meirinháramos": "meirinhar",
    "meirinháreis": "meirinhar",
    "meirinhásseis": "meirinhar",
    "meirinhássemos": "meirinhar",
    "meirinhávamo": "meirinhar",
    "meirinhávamos": "meirinhar",
    "meirinháveis": "meirinhar",
    "mejengras": "mejengra",
    "mela": "melar",
    "melaceira": "melaceiro",
    "melaceiras": "melaceiro",
    "melaceiros": "melaceiro",
    "melacotões": "melacotão",
    "melada": "melar",
    "meladas": "melar",
    "meladinhas": "meladinha",
    "melado": "melar",
    "melados": "melar",
    "meladuras": "meladura",
    "meladíssima": "melado",
    "meladíssimas": "melado",
    "meladíssimo": "melado",
    "meladíssimos": "melado",
    "melai": "melar",
    "melais": "melar",
    "melam": "melar",
    "melambeiras": "melambeira",
    "melambos": "melambo",
    "melamo": "melar",
    "melamos": "melar",
    "melampiros": "melampiro",
    "melananta": "melananto",
    "melanantas": "melananto",
    "melanantos": "melananto",
    "melanciais": "melancial",
    "melancias": "melancia",
    "melancieira": "melancieiro",
    "melancieiras": "melancieiro",
    "melancieiros": "melancieiro",
    "melancolias": "melancolia",
    "melancoliza": "melancolizar",
    "melancolizada": "melancolizar",
    "melancolizadas": "melancolizar",
    "melancolizado": "melancolizar",
    "melancolizadora": "melancolizador",
    "melancolizadoras": "melancolizador",
    "melancolizadores": "melancolizador",
    "melancolizados": "melancolizar",
    "melancolizai": "melancolizar",
    "melancolizais": "melancolizar",
    "melancolizam": "melancolizar",
    "melancolizamo": "melancolizar",
    "melancolizamos": "melancolizar",
    "melancolizando": "melancolizar",
    "melancolizara": "melancolizar",
    "melancolizaram": "melancolizar",
    "melancolizaras": "melancolizar",
    "melancolizarde": "melancolizar",
    "melancolizardes": "melancolizar",
    "melancolizare": "melancolizar",
    "melancolizarei": "melancolizar",
    "melancolizareis": "melancolizar",
    "melancolizarem": "melancolizar",
    "melancolizaremos": "melancolizar",
    "melancolizares": "melancolizar",
    "melancolizaria": "melancolizar",
    "melancolizariam": "melancolizar",
    "melancolizarias": "melancolizar",
    "melancolizarmo": "melancolizar",
    "melancolizarmos": "melancolizar",
    "melancolizará": "melancolizar",
    "melancolizarás": "melancolizar",
    "melancolizarão": "melancolizar",
    "melancolizaríamos": "melancolizar",
    "melancolizaríeis": "melancolizar",
    "melancolizas": "melancolizar",
    "melancolizasse": "melancolizar",
    "melancolizassem": "melancolizar",
    "melancolizasses": "melancolizar",
    "melancolizaste": "melancolizar",
    "melancolizastes": "melancolizar",
    "melancolizava": "melancolizar",
    "melancolizavam": "melancolizar",
    "melancolizavas": "melancolizar",
    "melancolize": "melancolizar",
    "melancolizei": "melancolizar",
    "melancolizeis": "melancolizar",
    "melancolizem": "melancolizar",
    "melancolizemo": "melancolizar",
    "melancolizemos": "melancolizar",
    "melancolizes": "melancolizar",
    "melancolizo": "melancolizar",
    "melancolizou": "melancolizar",
    "melancolizá": "melancolizar",
    "melancolizámo": "melancolizar",
    "melancolizámos": "melancolizar",
    "melancolizáramo": "melancolizar",
    "melancolizáramos": "melancolizar",
    "melancolizárei": "melancolizar",
    "melancolizáreis": "melancolizar",
    "melancolizásseis": "melancolizar",
    "melancolizássemos": "melancolizar",
    "melancolizávamo": "melancolizar",
    "melancolizávamos": "melancolizar",
    "melancolizávei": "melancolizar",
    "melancolizáveis": "melancolizar",
    "melancólica": "melancólico",
    "melancólicas": "melancólico",
    "melancólicos": "melancólico",
    "melando": "melar",
    "melanias": "melania",
    "melaninas": "melanina",
    "melanismos": "melanismo",
    "melanites": "melanite",
    "melaniza": "melanizar",
    "melanizada": "melanizar",
    "melanizadas": "melanizar",
    "melanizado": "melanizar",
    "melanizados": "melanizar",
    "melanizai": "melanizar",
    "melanizais": "melanizar",
    "melanizam": "melanizar",
    "melanizamo": "melanizar",
    "melanizamos": "melanizar",
    "melanizando": "melanizar",
    "melanizara": "melanizar",
    "melanizaram": "melanizar",
    "melanizaras": "melanizar",
    "melanizarde": "melanizar",
    "melanizardes": "melanizar",
    "melanizare": "melanizar",
    "melanizarei": "melanizar",
    "melanizareis": "melanizar",
    "melanizarem": "melanizar",
    "melanizaremos": "melanizar",
    "melanizares": "melanizar",
    "melanizaria": "melanizar",
    "melanizariam": "melanizar",
    "melanizarias": "melanizar",
    "melanizarmo": "melanizar",
    "melanizarmos": "melanizar",
    "melanizará": "melanizar",
    "melanizarás": "melanizar",
    "melanizarão": "melanizar",
    "melanizaríamos": "melanizar",
    "melanizaríeis": "melanizar",
    "melanizas": "melanizar",
    "melanizasse": "melanizar",
    "melanizassem": "melanizar",
    "melanizasses": "melanizar",
    "melanizaste": "melanizar",
    "melanizastes": "melanizar",
    "melanizava": "melanizar",
    "melanizavam": "melanizar",
    "melanizavas": "melanizar",
    "melanize": "melanizar",
    "melanizei": "melanizar",
    "melanizeis": "melanizar",
    "melanizem": "melanizar",
    "melanizemo": "melanizar",
    "melanizemos": "melanizar",
    "melanizes": "melanizar",
    "melanizo": "melanizar",
    "melanizou": "melanizar",
    "melanizá": "melanizar",
    "melanizámo": "melanizar",
    "melanizámos": "melanizar",
    "melanizáramo": "melanizar",
    "melanizáramos": "melanizar",
    "melanizárei": "melanizar",
    "melanizáreis": "melanizar",
    "melanizásseis": "melanizar",
    "melanizássemos": "melanizar",
    "melanizávamo": "melanizar",
    "melanizávamos": "melanizar",
    "melanizávei": "melanizar",
    "melanizáveis": "melanizar",
    "melanocarpa": "melanocarpo",
    "melanocarpas": "melanocarpo",
    "melanocarpos": "melanocarpo",
    "melanocrática": "melanocrático",
    "melanocráticas": "melanocrático",
    "melanocráticos": "melanocrático",
    "melanocéfala": "melanocéfalo",
    "melanocéfalas": "melanocéfalo",
    "melanocéfalos": "melanocéfalo",
    "melanodermes": "melanoderme",
    "melanodermias": "melanodermia",
    "melanodoncias": "melanodoncia",
    "melanodontes": "melanodonte",
    "melanoftalma": "melanoftalmo",
    "melanoftalmas": "melanoftalmo",
    "melanoftalmos": "melanoftalmo",
    "melanomas": "melanoma",
    "melanopes": "melanope",
    "melanorragias": "melanorragia",
    "melanorreias": "melanorreia",
    "melanoses": "melanose",
    "melanura": "melanuro",
    "melanuras": "melanuro",
    "melanurias": "melanuria",
    "melanuros": "melanuro",
    "melanésia": "melanésio",
    "melanésias": "melanésio",
    "melanésios": "melanésio",
    "melanócera": "melanócero",
    "melanóceras": "melanócero",
    "melanóceros": "melanócero",
    "melanócoma": "melanócomo",
    "melanócomas": "melanócomo",
    "melanócomos": "melanócomo",
    "melanóptera": "melanóptero",
    "melanópteras": "melanóptero",
    "melanópteros": "melanóptero",
    "melanóstoma": "melanóstomo",
    "melanóstomas": "melanóstomo",
    "melanóstomos": "melanóstomo",
    "melanótica": "melanótico",
    "melanóticas": "melanótico",
    "melanóticos": "melanótico",
    "melanúrias": "melanúria",
    "melara": "melar",
    "melaram": "melar",
    "melaras": "melar",
    "melarde": "melar",
    "melardes": "melar",
    "melare": "melar",
    "melarei": "melar",
    "melareis": "melar",
    "melarem": "melar",
    "melaremos": "melar",
    "melares": "melar",
    "melaria": "melar",
    "melariam": "melar",
    "melarias": "melar",
    "melarmo": "melar",
    "melarmos": "melar",
    "melará": "melar",
    "melarás": "melar",
    "melarão": "melar",
    "melaríamos": "melar",
    "melaríeis": "melar",
    "melas": "melar",
    "melasmas": "melasma",
    "melasmos": "melasmo",
    "melasse": "melar",
    "melassem": "melar",
    "melasses": "melar",
    "melaste": "melar",
    "melastes": "melar",
    "melastomáceas": "melastomácea",
    "melatrofias": "melatrofia",
    "melava": "melar",
    "melavam": "melar",
    "melavas": "melar",
    "melaxanta": "melaxanto",
    "melaxantas": "melaxanto",
    "melaxantos": "melaxanto",
    "melaços": "melaço",
    "melcas": "melca",
    "mele": "melar",
    "melei": "melar",
    "meleira": "meleiro",
    "meleiras": "meleiro",
    "meleiros": "meleiro",
    "meleis": "melar",
    "melem": "melar",
    "melemo": "melar",
    "melemos": "melar",
    "melenas": "melena",
    "meles": "melar",
    "melgas": "melga",
    "melgoteiros": "melgoteiro",
    "melgotões": "melgotão",
    "melgueiras": "melgueira",
    "melharucos": "melharuco",
    "melheiróses": "melheirós",
    "melhora": "melhorar",
    "melhorada": "melhorar",
    "melhoradas": "melhorar",
    "melhorado": "melhorar",
    "melhoradora": "melhorador",
    "melhoradoras": "melhorador",
    "melhoradores": "melhorador",
    "melhorados": "melhorar",
    "melhorai": "melhorar",
    "melhorais": "melhorar",
    "melhoram": "melhorar",
    "melhoramentos": "melhoramento",
    "melhoramo": "melhorar",
    "melhoramos": "melhorar",
    "melhorando": "melhorar",
    "melhorara": "melhorar",
    "melhoraram": "melhorar",
    "melhoraras": "melhorar",
    "melhorarde": "melhorar",
    "melhorardes": "melhorar",
    "melhorare": "melhorar",
    "melhorarei": "melhorar",
    "melhorareis": "melhorar",
    "melhorarem": "melhorar",
    "melhoraremos": "melhorar",
    "melhorares": "melhorar",
    "melhoraria": "melhorar",
    "melhorariam": "melhorar",
    "melhorarias": "melhorar",
    "melhorarmo": "melhorar",
    "melhorarmos": "melhorar",
    "melhorará": "melhorar",
    "melhorarás": "melhorar",
    "melhorarão": "melhorar",
    "melhoraríamos": "melhorar",
    "melhoraríeis": "melhorar",
    "melhoras": "melhorar",
    "melhorasse": "melhorar",
    "melhorassem": "melhorar",
    "melhorasses": "melhorar",
    "melhoraste": "melhorar",
    "melhorastes": "melhorar",
    "melhorativa": "melhorativo",
    "melhorativas": "melhorativo",
    "melhorativos": "melhorativo",
    "melhorava": "melhorar",
    "melhoravam": "melhorar",
    "melhoravas": "melhorar",
    "melhore": "melhorar",
    "melhorei": "melhorar",
    "melhoreis": "melhorar",
    "melhorem": "melhorar",
    "melhoremo": "melhorar",
    "melhoremos": "melhorar",
    "melhores": "melhorar",
    "melhorias": "melhoria",
    "melhoro": "melhorar",
    "melhorou": "melhorar",
    "melhorá": "melhorar",
    "melhorámo": "melhorar",
    "melhorámos": "melhorar",
    "melhoráramo": "melhorar",
    "melhoráramos": "melhorar",
    "melhorárei": "melhorar",
    "melhoráreis": "melhorar",
    "melhorásseis": "melhorar",
    "melhorássemos": "melhorar",
    "melhorávamo": "melhorar",
    "melhorávamos": "melhorar",
    "melhorávei": "melhorar",
    "melhoráveis": "melhorável",
    "meliana": "meliano",
    "melianas": "meliano",
    "melianos": "meliano",
    "meliantes": "meliante",
    "melidas": "melida",
    "melidos": "melido",
    "melieira": "melieiro",
    "melieiras": "melieiro",
    "melieiros": "melieiro",
    "melifica": "melificar",
    "melificada": "melificar",
    "melificadas": "melificar",
    "melificado": "melificar",
    "melificadores": "melificador",
    "melificados": "melificar",
    "melificai": "melificar",
    "melificais": "melificar",
    "melificam": "melificar",
    "melificamo": "melificar",
    "melificamos": "melificar",
    "melificando": "melificar",
    "melificara": "melificar",
    "melificaram": "melificar",
    "melificaras": "melificar",
    "melificarde": "melificar",
    "melificardes": "melificar",
    "melificare": "melificar",
    "melificarei": "melificar",
    "melificareis": "melificar",
    "melificarem": "melificar",
    "melificaremos": "melificar",
    "melificares": "melificar",
    "melificaria": "melificar",
    "melificariam": "melificar",
    "melificarias": "melificar",
    "melificarmo": "melificar",
    "melificarmos": "melificar",
    "melificará": "melificar",
    "melificarás": "melificar",
    "melificarão": "melificar",
    "melificaríamos": "melificar",
    "melificaríeis": "melificar",
    "melificas": "melificar",
    "melificasse": "melificar",
    "melificassem": "melificar",
    "melificasses": "melificar",
    "melificaste": "melificar",
    "melificastes": "melificar",
    "melificava": "melificar",
    "melificavam": "melificar",
    "melificavas": "melificar",
    "melificações": "melificação",
    "melifico": "melificar",
    "melificou": "melificar",
    "melificá": "melificar",
    "melificámo": "melificar",
    "melificámos": "melificar",
    "melificáramo": "melificar",
    "melificáramos": "melificar",
    "melificárei": "melificar",
    "melificáreis": "melificar",
    "melificásseis": "melificar",
    "melificássemos": "melificar",
    "melificávamo": "melificar",
    "melificávamos": "melificar",
    "melificávei": "melificar",
    "melificáveis": "melificar",
    "melifique": "melificar",
    "melifiquei": "melificar",
    "melifiqueis": "melificar",
    "melifiquem": "melificar",
    "melifiquemo": "melificar",
    "melifiquemos": "melificar",
    "melifiques": "melificar",
    "melifluenta": "melifluentar",
    "melifluentada": "melifluentar",
    "melifluentadas": "melifluentar",
    "melifluentado": "melifluentar",
    "melifluentados": "melifluentar",
    "melifluentai": "melifluentar",
    "melifluentais": "melifluentar",
    "melifluentam": "melifluentar",
    "melifluentamo": "melifluentar",
    "melifluentamos": "melifluentar",
    "melifluentando": "melifluentar",
    "melifluentara": "melifluentar",
    "melifluentaram": "melifluentar",
    "melifluentaras": "melifluentar",
    "melifluentarde": "melifluentar",
    "melifluentardes": "melifluentar",
    "melifluentare": "melifluentar",
    "melifluentarei": "melifluentar",
    "melifluentareis": "melifluentar",
    "melifluentarem": "melifluentar",
    "melifluentaremos": "melifluentar",
    "melifluentares": "melifluentar",
    "melifluentaria": "melifluentar",
    "melifluentariam": "melifluentar",
    "melifluentarias": "melifluentar",
    "melifluentarmo": "melifluentar",
    "melifluentarmos": "melifluentar",
    "melifluentará": "melifluentar",
    "melifluentarás": "melifluentar",
    "melifluentarão": "melifluentar",
    "melifluentaríamos": "melifluentar",
    "melifluentaríeis": "melifluentar",
    "melifluentas": "melifluentar",
    "melifluentasse": "melifluentar",
    "melifluentassem": "melifluentar",
    "melifluentasses": "melifluentar",
    "melifluentaste": "melifluentar",
    "melifluentastes": "melifluentar",
    "melifluentava": "melifluentar",
    "melifluentavam": "melifluentar",
    "melifluentavas": "melifluentar",
    "melifluente": "melifluentar",
    "melifluentei": "melifluentar",
    "melifluenteis": "melifluentar",
    "melifluentem": "melifluentar",
    "melifluentemo": "melifluentar",
    "melifluentemos": "melifluentar",
    "melifluentes": "melifluentar",
    "melifluento": "melifluentar",
    "melifluentou": "melifluentar",
    "melifluentá": "melifluentar",
    "melifluentámo": "melifluentar",
    "melifluentámos": "melifluentar",
    "melifluentáramo": "melifluentar",
    "melifluentáramos": "melifluentar",
    "melifluentárei": "melifluentar",
    "melifluentáreis": "melifluentar",
    "melifluentásseis": "melifluentar",
    "melifluentássemos": "melifluentar",
    "melifluentávamo": "melifluentar",
    "melifluentávamos": "melifluentar",
    "melifluentávei": "melifluentar",
    "melifluentáveis": "melifluentar",
    "melifluidades": "melifluidade",
    "melilotos": "meliloto",
    "melindana": "melindano",
    "melindanas": "melindano",
    "melindanos": "melindano",
    "melindra": "melindrar",
    "melindrabilidades": "melindrabilidade",
    "melindrada": "melindrar",
    "melindradas": "melindrar",
    "melindrado": "melindrar",
    "melindrados": "melindrar",
    "melindradíssima": "melindrado",
    "melindradíssimas": "melindrado",
    "melindradíssimo": "melindrado",
    "melindradíssimos": "melindrado",
    "melindrai": "melindrar",
    "melindrais": "melindrar",
    "melindram": "melindrar",
    "melindramo": "melindrar",
    "melindramos": "melindrar",
    "melindrando": "melindrar",
    "melindrara": "melindrar",
    "melindraram": "melindrar",
    "melindraras": "melindrar",
    "melindrarde": "melindrar",
    "melindrardes": "melindrar",
    "melindrare": "melindrar",
    "melindrarei": "melindrar",
    "melindrareis": "melindrar",
    "melindrarem": "melindrar",
    "melindraremos": "melindrar",
    "melindrares": "melindrar",
    "melindraria": "melindrar",
    "melindrariam": "melindrar",
    "melindrarias": "melindrar",
    "melindrarmo": "melindrar",
    "melindrarmos": "melindrar",
    "melindrará": "melindrar",
    "melindrarás": "melindrar",
    "melindrarão": "melindrar",
    "melindraríamos": "melindrar",
    "melindraríeis": "melindrar",
    "melindras": "melindrar",
    "melindrasse": "melindrar",
    "melindrassem": "melindrar",
    "melindrasses": "melindrar",
    "melindraste": "melindrar",
    "melindrastes": "melindrar",
    "melindrava": "melindrar",
    "melindravam": "melindrar",
    "melindravas": "melindrar",
    "melindre": "melindrar",
    "melindrei": "melindrar",
    "melindreis": "melindrar",
    "melindrem": "melindrar",
    "melindremo": "melindrar",
    "melindremos": "melindrar",
    "melindres": "melindre",
    "melindro": "melindrar",
    "melindros": "melindro",
    "melindrosa": "melindroso",
    "melindrosas": "melindroso",
    "melindrosos": "melindroso",
    "melindrou": "melindrar",
    "melindrá": "melindrar",
    "melindrámo": "melindrar",
    "melindrámos": "melindrar",
    "melindráramo": "melindrar",
    "melindráramos": "melindrar",
    "melindrárei": "melindrar",
    "melindráreis": "melindrar",
    "melindrásseis": "melindrar",
    "melindrássemos": "melindrar",
    "melindrávamo": "melindrar",
    "melindrávamos": "melindrar",
    "melindrávei": "melindrar",
    "melindráveis": "melindrável",
    "melinites": "melinite",
    "meliorismos": "meliorismo",
    "melioristas": "meliorista",
    "melissas": "melissa",
    "melissografias": "melissografia",
    "melitofilias": "melitofilia",
    "melitos": "melito",
    "meliturgias": "meliturgia",
    "melitófila": "melitófilo",
    "melitófilas": "melitófilo",
    "melitófilos": "melitófilo",
    "melitúrias": "melitúria",
    "meliáceas": "meliácea",
    "melo": "melar",
    "meloais": "meloal",
    "meloas": "meloa",
    "melocotões": "melocotão",
    "melodia": "melodiar",
    "melodiada": "melodiar",
    "melodiadas": "melodiar",
    "melodiado": "melodiar",
    "melodiados": "melodiar",
    "melodiai": "melodiar",
    "melodiais": "melodiar",
    "melodiam": "melodiar",
    "melodiamo": "melodiar",
    "melodiamos": "melodiar",
    "melodiando": "melodiar",
    "melodiara": "melodiar",
    "melodiaram": "melodiar",
    "melodiaras": "melodiar",
    "melodiarde": "melodiar",
    "melodiardes": "melodiar",
    "melodiare": "melodiar",
    "melodiarei": "melodiar",
    "melodiareis": "melodiar",
    "melodiarem": "melodiar",
    "melodiaremos": "melodiar",
    "melodiares": "melodiar",
    "melodiaria": "melodiar",
    "melodiariam": "melodiar",
    "melodiarias": "melodiar",
    "melodiarmo": "melodiar",
    "melodiarmos": "melodiar",
    "melodiará": "melodiar",
    "melodiarás": "melodiar",
    "melodiarão": "melodiar",
    "melodiaríamos": "melodiar",
    "melodiaríeis": "melodiar",
    "melodias": "melodiar",
    "melodiasse": "melodiar",
    "melodiassem": "melodiar",
    "melodiasses": "melodiar",
    "melodiaste": "melodiar",
    "melodiastes": "melodiar",
    "melodiava": "melodiar",
    "melodiavam": "melodiar",
    "melodiavas": "melodiar",
    "melodie": "melodiar",
    "melodiei": "melodiar",
    "melodieis": "melodiar",
    "melodiem": "melodiar",
    "melodiemo": "melodiar",
    "melodiemos": "melodiar",
    "melodies": "melodiar",
    "melodina": "melodino",
    "melodinas": "melodino",
    "melodinos": "melodino",
    "melodio": "melodiar",
    "melodiosa": "melodioso",
    "melodiosas": "melodioso",
    "melodiosos": "melodioso",
    "melodiou": "melodiar",
    "melodistas": "melodista",
    "melodiza": "melodizar",
    "melodizada": "melodizar",
    "melodizadas": "melodizar",
    "melodizado": "melodizar",
    "melodizados": "melodizar",
    "melodizai": "melodizar",
    "melodizais": "melodizar",
    "melodizam": "melodizar",
    "melodizamo": "melodizar",
    "melodizamos": "melodizar",
    "melodizando": "melodizar",
    "melodizara": "melodizar",
    "melodizaram": "melodizar",
    "melodizaras": "melodizar",
    "melodizarde": "melodizar",
    "melodizardes": "melodizar",
    "melodizare": "melodizar",
    "melodizarei": "melodizar",
    "melodizareis": "melodizar",
    "melodizarem": "melodizar",
    "melodizaremos": "melodizar",
    "melodizares": "melodizar",
    "melodizaria": "melodizar",
    "melodizariam": "melodizar",
    "melodizarias": "melodizar",
    "melodizarmo": "melodizar",
    "melodizarmos": "melodizar",
    "melodizará": "melodizar",
    "melodizarás": "melodizar",
    "melodizarão": "melodizar",
    "melodizaríamos": "melodizar",
    "melodizaríeis": "melodizar",
    "melodizas": "melodizar",
    "melodizasse": "melodizar",
    "melodizassem": "melodizar",
    "melodizasses": "melodizar",
    "melodizaste": "melodizar",
    "melodizastes": "melodizar",
    "melodizava": "melodizar",
    "melodizavam": "melodizar",
    "melodizavas": "melodizar",
    "melodize": "melodizar",
    "melodizei": "melodizar",
    "melodizeis": "melodizar",
    "melodizem": "melodizar",
    "melodizemo": "melodizar",
    "melodizemos": "melodizar",
    "melodizes": "melodizar",
    "melodizo": "melodizar",
    "melodizou": "melodizar",
    "melodizá": "melodizar",
    "melodizámo": "melodizar",
    "melodizámos": "melodizar",
    "melodizáramo": "melodizar",
    "melodizáramos": "melodizar",
    "melodizárei": "melodizar",
    "melodizáreis": "melodizar",
    "melodizásseis": "melodizar",
    "melodizássemos": "melodizar",
    "melodizávamo": "melodizar",
    "melodizávamos": "melodizar",
    "melodizávei": "melodizar",
    "melodizáveis": "melodizar",
    "melodiá": "melodiar",
    "melodiámo": "melodiar",
    "melodiámos": "melodiar",
    "melodiáramo": "melodiar",
    "melodiáramos": "melodiar",
    "melodiárei": "melodiar",
    "melodiáreis": "melodiar",
    "melodiásseis": "melodiar",
    "melodiássemos": "melodiar",
    "melodiávamo": "melodiar",
    "melodiávamos": "melodiar",
    "melodiávei": "melodiar",
    "melodiáveis": "melodiar",
    "melodramas": "melodrama",
    "melodramatiza": "melodramatizar",
    "melodramatizada": "melodramatizar",
    "melodramatizadas": "melodramatizar",
    "melodramatizado": "melodramatizar",
    "melodramatizados": "melodramatizar",
    "melodramatizai": "melodramatizar",
    "melodramatizais": "melodramatizar",
    "melodramatizam": "melodramatizar",
    "melodramatizamo": "melodramatizar",
    "melodramatizamos": "melodramatizar",
    "melodramatizando": "melodramatizar",
    "melodramatizara": "melodramatizar",
    "melodramatizaram": "melodramatizar",
    "melodramatizaras": "melodramatizar",
    "melodramatizarde": "melodramatizar",
    "melodramatizardes": "melodramatizar",
    "melodramatizare": "melodramatizar",
    "melodramatizarei": "melodramatizar",
    "melodramatizareis": "melodramatizar",
    "melodramatizarem": "melodramatizar",
    "melodramatizaremos": "melodramatizar",
    "melodramatizares": "melodramatizar",
    "melodramatizaria": "melodramatizar",
    "melodramatizariam": "melodramatizar",
    "melodramatizarias": "melodramatizar",
    "melodramatizarmo": "melodramatizar",
    "melodramatizarmos": "melodramatizar",
    "melodramatizará": "melodramatizar",
    "melodramatizarás": "melodramatizar",
    "melodramatizarão": "melodramatizar",
    "melodramatizaríamos": "melodramatizar",
    "melodramatizaríeis": "melodramatizar",
    "melodramatizas": "melodramatizar",
    "melodramatizasse": "melodramatizar",
    "melodramatizassem": "melodramatizar",
    "melodramatizasses": "melodramatizar",
    "melodramatizaste": "melodramatizar",
    "melodramatizastes": "melodramatizar",
    "melodramatizava": "melodramatizar",
    "melodramatizavam": "melodramatizar",
    "melodramatizavas": "melodramatizar",
    "melodramatize": "melodramatizar",
    "melodramatizei": "melodramatizar",
    "melodramatizeis": "melodramatizar",
    "melodramatizem": "melodramatizar",
    "melodramatizemo": "melodramatizar",
    "melodramatizemos": "melodramatizar",
    "melodramatizes": "melodramatizar",
    "melodramatizo": "melodramatizar",
    "melodramatizou": "melodramatizar",
    "melodramatizá": "melodramatizar",
    "melodramatizámo": "melodramatizar",
    "melodramatizámos": "melodramatizar",
    "melodramatizáramo": "melodramatizar",
    "melodramatizáramos": "melodramatizar",
    "melodramatizárei": "melodramatizar",
    "melodramatizáreis": "melodramatizar",
    "melodramatizásseis": "melodramatizar",
    "melodramatizássemos": "melodramatizar",
    "melodramatizávamo": "melodramatizar",
    "melodramatizávamos": "melodramatizar",
    "melodramatizávei": "melodramatizar",
    "melodramatizáveis": "melodramatizar",
    "melodramaturga": "melodramaturgo",
    "melodramaturgas": "melodramaturgo",
    "melodramaturgos": "melodramaturgo",
    "melodramática": "melodramático",
    "melodramáticas": "melodramático",
    "melodramáticos": "melodramático",
    "meloeiros": "meloeiro",
    "melofones": "melofone",
    "melografias": "melografia",
    "melográfica": "melográfico",
    "melográficas": "melográfico",
    "melográficos": "melográfico",
    "melolontas": "melolonta",
    "melomanias": "melomania",
    "melomaníana": "melomaníano",
    "melomaníanas": "melomaníano",
    "melomaníanos": "melomaníano",
    "melomelias": "melomelia",
    "meloniformes": "meloniforme",
    "melonites": "melonite",
    "melopeias": "melopeia",
    "melopes": "melope",
    "meloplastias": "meloplastia",
    "melos": "melo",
    "melosa": "meloso",
    "melosas": "meloso",
    "melosos": "meloso",
    "melotas": "melota",
    "meloterapias": "meloterapia",
    "melotes": "melote",
    "melou": "melar",
    "melquetrefes": "melquetrefe",
    "melra": "melro",
    "melras": "melro",
    "melriachos": "melriacho",
    "melroada": "melroado",
    "melroadas": "melroado",
    "melroados": "melroado",
    "melros": "melro",
    "melusinas": "melusina",
    "melá": "melar",
    "meláfiros": "meláfiro",
    "melámo": "melar",
    "melámos": "melar",
    "melápios": "melápio",
    "meláramo": "melar",
    "meláramos": "melar",
    "melárei": "melar",
    "meláreis": "melar",
    "melásseis": "melar",
    "melássemos": "melar",
    "melávamo": "melar",
    "melávamos": "melar",
    "melávei": "melar",
    "meláveis": "melar",
    "melânias": "melânia",
    "melânica": "melânico",
    "melânicas": "melânico",
    "melânicos": "melânico",
    "melícias": "melícia",
    "melífaga": "melífago",
    "melífagas": "melífago",
    "melífagos": "melífago",
    "melífera": "melífero",
    "melíferas": "melífero",
    "melíferos": "melífero",
    "melífica": "melífico",
    "melíficas": "melífico",
    "melíficos": "melífico",
    "melíflua": "melífluo",
    "melífluas": "melífluo",
    "melífluos": "melífluo",
    "melívora": "melívoro",
    "melívoras": "melívoro",
    "melívoros": "melívoro",
    "melódica": "melódico",
    "melódicas": "melódico",
    "melódicos": "melódico",
    "melófagos": "melófago",
    "melófila": "melófilo",
    "melófilas": "melófilo",
    "melófilos": "melófilo",
    "melógrafa": "melógrafo",
    "melógrafas": "melógrafo",
    "melógrafos": "melógrafo",
    "melómana": "melómano",
    "melómanas": "melómano",
    "melómanos": "melómano",
    "melómela": "melómelo",
    "melómelas": "melómelo",
    "melómelos": "melómelo",
    "melónama": "melónamo",
    "melónamas": "melónamo",
    "melónamos": "melónamo",
    "melótropos": "melótropo",
    "melões": "melão",
    "melúrias": "melúria",
    "memactérions": "memactérion",
    "membrada": "membrado",
    "membradas": "membrado",
    "membrados": "membrado",
    "membranas": "membrana",
    "membranelas": "membranela",
    "membraniformes": "membraniforme",
    "membranosa": "membranoso",
    "membranosas": "membranoso",
    "membranosos": "membranoso",
    "membranácea": "membranáceo",
    "membranáceas": "membranáceo",
    "membranáceos": "membranáceo",
    "membros": "membro",
    "membruda": "membrudo",
    "membrudas": "membrudo",
    "membrudos": "membrudo",
    "membruras": "membrura",
    "membrânulas": "membrânula",
    "mementos": "memento",
    "memora": "memorar",
    "memorada": "memorar",
    "memoradas": "memorar",
    "memorado": "memorar",
    "memorados": "memorar",
    "memorai": "memorar",
    "memorais": "memorar",
    "memoram": "memorar",
    "memoramo": "memorar",
    "memoramos": "memorar",
    "memoranda": "memorando",
    "memorandas": "memorando",
    "memorando": "memorar",
    "memorandos": "memorando",
    "memorara": "memorar",
    "memoraram": "memorar",
    "memoraras": "memorar",
    "memorarde": "memorar",
    "memorardes": "memorar",
    "memorare": "memorar",
    "memorarei": "memorar",
    "memorareis": "memorar",
    "memorarem": "memorar",
    "memoraremos": "memorar",
    "memorares": "memorar",
    "memoraria": "memorar",
    "memorariam": "memorar",
    "memorarias": "memorar",
    "memorarmo": "memorar",
    "memorarmos": "memorar",
    "memorará": "memorar",
    "memorarás": "memorar",
    "memorarão": "memorar",
    "memoraríamos": "memorar",
    "memoraríeis": "memorar",
    "memoras": "memorar",
    "memorasse": "memorar",
    "memorassem": "memorar",
    "memorasses": "memorar",
    "memoraste": "memorar",
    "memorastes": "memorar",
    "memorativa": "memorativo",
    "memorativas": "memorativo",
    "memorativos": "memorativo",
    "memorava": "memorar",
    "memoravam": "memorar",
    "memoravas": "memorar",
    "memorações": "memoração",
    "memore": "memorar",
    "memorei": "memorar",
    "memoreis": "memorar",
    "memorem": "memorar",
    "memoremo": "memorar",
    "memoremos": "memorar",
    "memores": "memorar",
    "memoria": "memoriar",
    "memoriada": "memoriar",
    "memoriadas": "memoriar",
    "memoriado": "memoriar",
    "memoriados": "memoriar",
    "memoriai": "memoriar",
    "memoriais": "memoriar",
    "memorialistas": "memorialista",
    "memorialísticas": "memorialística",
    "memoriam": "memoriar",
    "memoriamo": "memoriar",
    "memoriamos": "memoriar",
    "memoriando": "memoriar",
    "memoriara": "memoriar",
    "memoriaram": "memoriar",
    "memoriaras": "memoriar",
    "memoriarde": "memoriar",
    "memoriardes": "memoriar",
    "memoriare": "memoriar",
    "memoriarei": "memoriar",
    "memoriareis": "memoriar",
    "memoriarem": "memoriar",
    "memoriaremos": "memoriar",
    "memoriares": "memoriar",
    "memoriaria": "memoriar",
    "memoriariam": "memoriar",
    "memoriarias": "memoriar",
    "memoriarmo": "memoriar",
    "memoriarmos": "memoriar",
    "memoriará": "memoriar",
    "memoriarás": "memoriar",
    "memoriarão": "memoriar",
    "memoriaríamos": "memoriar",
    "memoriaríeis": "memoriar",
    "memorias": "memoriar",
    "memoriasse": "memoriar",
    "memoriassem": "memoriar",
    "memoriasses": "memoriar",
    "memoriaste": "memoriar",
    "memoriastes": "memoriar",
    "memoriava": "memoriar",
    "memoriavam": "memoriar",
    "memoriavas": "memoriar",
    "memorie": "memoriar",
    "memoriei": "memoriar",
    "memorieis": "memoriar",
    "memoriem": "memoriar",
    "memoriemo": "memoriar",
    "memoriemos": "memoriar",
    "memories": "memoriar",
    "memorio": "memoriar",
    "memoriosa": "memorioso",
    "memoriosas": "memorioso",
    "memoriosos": "memorioso",
    "memoriou": "memoriar",
    "memoristas": "memorista",
    "memoriza": "memorizar",
    "memorizada": "memorizar",
    "memorizadas": "memorizar",
    "memorizado": "memorizar",
    "memorizados": "memorizar",
    "memorizai": "memorizar",
    "memorizais": "memorizar",
    "memorizam": "memorizar",
    "memorizamo": "memorizar",
    "memorizamos": "memorizar",
    "memorizando": "memorizar",
    "memorizara": "memorizar",
    "memorizaram": "memorizar",
    "memorizaras": "memorizar",
    "memorizarde": "memorizar",
    "memorizardes": "memorizar",
    "memorizare": "memorizar",
    "memorizarei": "memorizar",
    "memorizareis": "memorizar",
    "memorizarem": "memorizar",
    "memorizaremos": "memorizar",
    "memorizares": "memorizar",
    "memorizaria": "memorizar",
    "memorizariam": "memorizar",
    "memorizarias": "memorizar",
    "memorizarmo": "memorizar",
    "memorizarmos": "memorizar",
    "memorizará": "memorizar",
    "memorizarás": "memorizar",
    "memorizarão": "memorizar",
    "memorizaríamos": "memorizar",
    "memorizaríeis": "memorizar",
    "memorizas": "memorizar",
    "memorizasse": "memorizar",
    "memorizassem": "memorizar",
    "memorizasses": "memorizar",
    "memorizaste": "memorizar",
    "memorizastes": "memorizar",
    "memorizava": "memorizar",
    "memorizavam": "memorizar",
    "memorizavas": "memorizar",
    "memorizações": "memorização",
    "memorize": "memorizar",
    "memorizei": "memorizar",
    "memorizeis": "memorizar",
    "memorizem": "memorizar",
    "memorizemo": "memorizar",
    "memorizemos": "memorizar",
    "memorizes": "memorizar",
    "memorizo": "memorizar",
    "memorizou": "memorizar",
    "memorizá": "memorizar",
    "memorizámo": "memorizar",
    "memorizámos": "memorizar",
    "memorizáramo": "memorizar",
    "memorizáramos": "memorizar",
    "memorizárei": "memorizar",
    "memorizáreis": "memorizar",
    "memorizásseis": "memorizar",
    "memorizássemos": "memorizar",
    "memorizávamo": "memorizar",
    "memorizávamos": "memorizar",
    "memorizávei": "memorizar",
    "memorizáveis": "memorizável",
    "memoriá": "memoriar",
    "memoriámo": "memoriar",
    "memoriámos": "memoriar",
    "memoriáramo": "memoriar",
    "memoriáramos": "memoriar",
    "memoriárei": "memoriar",
    "memoriáreis": "memoriar",
    "memoriásseis": "memoriar",
    "memoriássemos": "memoriar",
    "memoriávamo": "memoriar",
    "memoriávamos": "memoriar",
    "memoriávei": "memoriar",
    "memoriáveis": "memoriável",
    "memoriões": "memorião",
    "memoro": "memorar",
    "memorosa": "memoroso",
    "memorosas": "memoroso",
    "memorosos": "memoroso",
    "memorou": "memorar",
    "memorá": "memorar",
    "memorámo": "memorar",
    "memorámos": "memorar",
    "memoráramo": "memorar",
    "memoráramos": "memorar",
    "memorárei": "memorar",
    "memoráreis": "memorar",
    "memorásseis": "memorar",
    "memorássemos": "memorar",
    "memorávamo": "memorar",
    "memorávamos": "memorar",
    "memorávei": "memorar",
    "memoráveis": "memorável",
    "memórias": "memória",
    "menacmas": "menacma",
    "menagens": "menagem",
    "menarcas": "menarca",
    "menarquias": "menarquia",
    "mencheviques": "menchevique",
    "mencheviquismos": "mencheviquismo",
    "menchevismos": "menchevismo",
    "menchevistas": "menchevista",
    "menciona": "mencionar",
    "mencionada": "mencionar",
    "mencionadas": "mencionar",
    "mencionado": "mencionar",
    "mencionados": "mencionar",
    "mencionai": "mencionar",
    "mencionais": "mencionar",
    "mencionam": "mencionar",
    "mencionamo": "mencionar",
    "mencionamos": "mencionar",
    "mencionando": "mencionar",
    "mencionara": "mencionar",
    "mencionaram": "mencionar",
    "mencionaras": "mencionar",
    "mencionarde": "mencionar",
    "mencionardes": "mencionar",
    "mencionare": "mencionar",
    "mencionarei": "mencionar",
    "mencionareis": "mencionar",
    "mencionarem": "mencionar",
    "mencionaremos": "mencionar",
    "mencionares": "mencionar",
    "mencionaria": "mencionar",
    "mencionariam": "mencionar",
    "mencionarias": "mencionar",
    "mencionarmo": "mencionar",
    "mencionarmos": "mencionar",
    "mencionará": "mencionar",
    "mencionarás": "mencionar",
    "mencionarão": "mencionar",
    "mencionaríamos": "mencionar",
    "mencionaríeis": "mencionar",
    "mencionas": "mencionar",
    "mencionasse": "mencionar",
    "mencionassem": "mencionar",
    "mencionasses": "mencionar",
    "mencionaste": "mencionar",
    "mencionastes": "mencionar",
    "mencionava": "mencionar",
    "mencionavam": "mencionar",
    "mencionavas": "mencionar",
    "mencione": "mencionar",
    "mencionei": "mencionar",
    "mencioneis": "mencionar",
    "mencionem": "mencionar",
    "mencionemo": "mencionar",
    "mencionemos": "mencionar",
    "menciones": "mencionar",
    "menciono": "mencionar",
    "mencionou": "mencionar",
    "mencioná": "mencionar",
    "mencionámo": "mencionar",
    "mencionámos": "mencionar",
    "mencionáramo": "mencionar",
    "mencionáramos": "mencionar",
    "mencionárei": "mencionar",
    "mencionáreis": "mencionar",
    "mencionásseis": "mencionar",
    "mencionássemos": "mencionar",
    "mencionávamo": "mencionar",
    "mencionávamos": "mencionar",
    "mencionávei": "mencionar",
    "mencionáveis": "mencionável",
    "mendaces": "mendace",
    "mendacidades": "mendacidade",
    "mendazes": "mendaz",
    "mendeliana": "mendeliano",
    "mendelianas": "mendeliano",
    "mendelianos": "mendeliano",
    "mendelismos": "mendelismo",
    "mendelévios": "mendelévio",
    "mendicantes": "mendicante",
    "mendicidades": "mendicidade",
    "mendicâncias": "mendicância",
    "mendiga": "mendigo",
    "mendigada": "mendigar",
    "mendigadas": "mendigar",
    "mendigado": "mendigar",
    "mendigados": "mendigar",
    "mendigagens": "mendigagem",
    "mendigai": "mendigar",
    "mendigais": "mendigar",
    "mendigam": "mendigar",
    "mendigamo": "mendigar",
    "mendigamos": "mendigar",
    "mendigando": "mendigar",
    "mendigara": "mendigar",
    "mendigaram": "mendigar",
    "mendigaras": "mendigar",
    "mendigarde": "mendigar",
    "mendigardes": "mendigar",
    "mendigare": "mendigar",
    "mendigarei": "mendigar",
    "mendigareis": "mendigar",
    "mendigarem": "mendigar",
    "mendigaremos": "mendigar",
    "mendigares": "mendigar",
    "mendigaria": "mendigar",
    "mendigariam": "mendigar",
    "mendigarias": "mendigar",
    "mendigarmo": "mendigar",
    "mendigarmos": "mendigar",
    "mendigará": "mendigar",
    "mendigarás": "mendigar",
    "mendigarão": "mendigar",
    "mendigaríamos": "mendigar",
    "mendigaríeis": "mendigar",
    "mendigas": "mendigo",
    "mendigasse": "mendigar",
    "mendigassem": "mendigar",
    "mendigasses": "mendigar",
    "mendigaste": "mendigar",
    "mendigastes": "mendigar",
    "mendigava": "mendigar",
    "mendigavam": "mendigar",
    "mendigavas": "mendigar",
    "mendigações": "mendigação",
    "mendigo": "mendigar",
    "mendigos": "mendigo",
    "mendigou": "mendigar",
    "mendigue": "mendigar",
    "mendiguei": "mendigar",
    "mendigueis": "mendigar",
    "mendiguem": "mendigar",
    "mendiguemo": "mendigar",
    "mendiguemos": "mendigar",
    "mendigues": "mendigar",
    "mendigá": "mendigar",
    "mendigámo": "mendigar",
    "mendigámos": "mendigar",
    "mendigáramo": "mendigar",
    "mendigáramos": "mendigar",
    "mendigárei": "mendigar",
    "mendigáreis": "mendigar",
    "mendigásseis": "mendigar",
    "mendigássemos": "mendigar",
    "mendigávamo": "mendigar",
    "mendigávamos": "mendigar",
    "mendigávei": "mendigar",
    "mendigáveis": "mendigar",
    "mendinha": "mendinho",
    "mendinhas": "mendinho",
    "mendinhos": "mendinho",
    "mendubins": "mendubim",
    "mendubis": "mendubi",
    "mendáculos": "mendáculo",
    "mendálias": "mendália",
    "meneada": "menear",
    "meneadas": "menear",
    "meneado": "menear",
    "meneadora": "meneador",
    "meneadoras": "meneador",
    "meneadores": "meneador",
    "meneados": "menear",
    "meneai": "menear",
    "meneais": "menear",
    "meneamentos": "meneamento",
    "meneamo": "menear",
    "meneamos": "menear",
    "meneando": "menear",
    "meneara": "menear",
    "menearam": "menear",
    "menearas": "menear",
    "menearde": "menear",
    "meneardes": "menear",
    "meneare": "menear",
    "menearei": "menear",
    "meneareis": "menear",
    "menearem": "menear",
    "menearemos": "menear",
    "meneares": "menear",
    "menearia": "menear",
    "meneariam": "menear",
    "menearias": "menear",
    "menearmo": "menear",
    "menearmos": "menear",
    "meneará": "menear",
    "menearás": "menear",
    "menearão": "menear",
    "menearíamos": "menear",
    "menearíeis": "menear",
    "meneasse": "menear",
    "meneassem": "menear",
    "meneasses": "menear",
    "meneaste": "menear",
    "meneastes": "menear",
    "meneava": "menear",
    "meneavam": "menear",
    "meneavas": "menear",
    "menecmas": "menecma",
    "meneei": "menear",
    "meneeis": "menear",
    "meneemo": "menear",
    "meneemos": "menear",
    "meneia": "menear",
    "meneiam": "menear",
    "meneias": "menear",
    "meneie": "menear",
    "meneiem": "menear",
    "meneies": "menear",
    "meneio": "menear",
    "meneios": "meneio",
    "meneou": "menear",
    "menestréis": "menestrel",
    "meneá": "menear",
    "meneámo": "menear",
    "meneámos": "menear",
    "meneáramo": "menear",
    "meneáramos": "menear",
    "meneárei": "menear",
    "meneáreis": "menear",
    "meneásseis": "menear",
    "meneássemos": "menear",
    "meneávamo": "menear",
    "meneávamos": "menear",
    "meneávei": "menear",
    "meneáveis": "meneável",
    "menfitas": "menfita",
    "menfítica": "menfítico",
    "menfíticas": "menfítico",
    "menfíticos": "menfítico",
    "mengos": "mengo",
    "menhires": "menhir",
    "menianos": "meniano",
    "menierismos": "menierismo",
    "menina": "menino",
    "meninadas": "meninada",
    "meninas": "menino",
    "meninatas": "meninata",
    "meninazinha": "menino",
    "meninazinhas": "menino",
    "meninazita": "menino",
    "meninazitas": "menino",
    "menineira": "menineiro",
    "menineiras": "menineiro",
    "menineiros": "menineiro",
    "meninezes": "meninez",
    "meninges": "meninge",
    "meningites": "meningite",
    "meningítica": "meningítico",
    "meningíticas": "meningítico",
    "meningíticos": "meningítico",
    "meninices": "meninice",
    "menininha": "menino",
    "menininhas": "menino",
    "menininho": "menino",
    "menininhos": "menino",
    "meninita": "menino",
    "meninitas": "menino",
    "meninito": "menino",
    "meninitos": "menino",
    "meninos": "menino",
    "meninozinho": "menino",
    "meninozinhos": "menino",
    "meninozito": "menino",
    "meninozitos": "menino",
    "meninós": "meninó",
    "menires": "menir",
    "meniscos": "menisco",
    "meniscóides": "meniscóide",
    "menispermos": "menispermo",
    "menispermácea": "menispermáceo",
    "menispermáceas": "menispermáceo",
    "menispermáceos": "menispermáceo",
    "menjengras": "menjengra",
    "menológica": "menológico",
    "menológicas": "menológico",
    "menológicos": "menológico",
    "menológios": "menológio",
    "menopausas": "menopausa",
    "menopáusica": "menopáusico",
    "menopáusicas": "menopáusico",
    "menopáusicos": "menopáusico",
    "menores": "menor",
    "menoridades": "menoridade",
    "menoristas": "menorista",
    "menoritas": "menorita",
    "menorragias": "menorragia",
    "menorreias": "menorreia",
    "menorrágica": "menorrágico",
    "menorrágicas": "menorrágico",
    "menorrágicos": "menorrágico",
    "menorréica": "menorréico",
    "menorréicas": "menorréico",
    "menorréicos": "menorréico",
    "menorítica": "menorítico",
    "menoríticas": "menorítico",
    "menoríticos": "menorítico",
    "menoscaba": "menoscabar",
    "menoscabada": "menoscabar",
    "menoscabadas": "menoscabar",
    "menoscabado": "menoscabar",
    "menoscabadora": "menoscabador",
    "menoscabadoras": "menoscabador",
    "menoscabadores": "menoscabador",
    "menoscabados": "menoscabar",
    "menoscabai": "menoscabar",
    "menoscabais": "menoscabar",
    "menoscabam": "menoscabar",
    "menoscabamo": "menoscabar",
    "menoscabamos": "menoscabar",
    "menoscabando": "menoscabar",
    "menoscabara": "menoscabar",
    "menoscabaram": "menoscabar",
    "menoscabaras": "menoscabar",
    "menoscabarde": "menoscabar",
    "menoscabardes": "menoscabar",
    "menoscabare": "menoscabar",
    "menoscabarei": "menoscabar",
    "menoscabareis": "menoscabar",
    "menoscabarem": "menoscabar",
    "menoscabaremos": "menoscabar",
    "menoscabares": "menoscabar",
    "menoscabaria": "menoscabar",
    "menoscabariam": "menoscabar",
    "menoscabarias": "menoscabar",
    "menoscabarmo": "menoscabar",
    "menoscabarmos": "menoscabar",
    "menoscabará": "menoscabar",
    "menoscabarás": "menoscabar",
    "menoscabarão": "menoscabar",
    "menoscabaríamos": "menoscabar",
    "menoscabaríeis": "menoscabar",
    "menoscabas": "menoscabar",
    "menoscabasse": "menoscabar",
    "menoscabassem": "menoscabar",
    "menoscabasses": "menoscabar",
    "menoscabaste": "menoscabar",
    "menoscabastes": "menoscabar",
    "menoscabava": "menoscabar",
    "menoscabavam": "menoscabar",
    "menoscabavas": "menoscabar",
    "menoscabe": "menoscabar",
    "menoscabei": "menoscabar",
    "menoscabeis": "menoscabar",
    "menoscabem": "menoscabar",
    "menoscabemo": "menoscabar",
    "menoscabemos": "menoscabar",
    "menoscabes": "menoscabar",
    "menoscabo": "menoscabar",
    "menoscabos": "menoscabo",
    "menoscabou": "menoscabar",
    "menoscabá": "menoscabar",
    "menoscabámo": "menoscabar",
    "menoscabámos": "menoscabar",
    "menoscabáramo": "menoscabar",
    "menoscabáramos": "menoscabar",
    "menoscabárei": "menoscabar",
    "menoscabáreis": "menoscabar",
    "menoscabásseis": "menoscabar",
    "menoscabássemos": "menoscabar",
    "menoscabávamo": "menoscabar",
    "menoscabávamos": "menoscabar",
    "menoscabávei": "menoscabar",
    "menoscabáveis": "menoscabar",
    "menospreza": "menosprezar",
    "menosprezada": "menosprezar",
    "menosprezadas": "menosprezar",
    "menosprezado": "menosprezar",
    "menosprezadora": "menosprezador",
    "menosprezadoras": "menosprezador",
    "menosprezadores": "menosprezador",
    "menosprezados": "menosprezar",
    "menosprezadíssima": "menosprezado",
    "menosprezadíssimas": "menosprezado",
    "menosprezadíssimo": "menosprezado",
    "menosprezadíssimos": "menosprezado",
    "menosprezai": "menosprezar",
    "menosprezais": "menosprezar",
    "menosprezam": "menosprezar",
    "menosprezamo": "menosprezar",
    "menosprezamos": "menosprezar",
    "menosprezando": "menosprezar",
    "menosprezara": "menosprezar",
    "menosprezaram": "menosprezar",
    "menosprezaras": "menosprezar",
    "menosprezarde": "menosprezar",
    "menosprezardes": "menosprezar",
    "menosprezare": "menosprezar",
    "menosprezarei": "menosprezar",
    "menosprezareis": "menosprezar",
    "menosprezarem": "menosprezar",
    "menosprezaremos": "menosprezar",
    "menosprezares": "menosprezar",
    "menosprezaria": "menosprezar",
    "menosprezariam": "menosprezar",
    "menosprezarias": "menosprezar",
    "menosprezarmo": "menosprezar",
    "menosprezarmos": "menosprezar",
    "menosprezará": "menosprezar",
    "menosprezarás": "menosprezar",
    "menosprezarão": "menosprezar",
    "menosprezaríamos": "menosprezar",
    "menosprezaríeis": "menosprezar",
    "menosprezas": "menosprezar",
    "menosprezasse": "menosprezar",
    "menosprezassem": "menosprezar",
    "menosprezasses": "menosprezar",
    "menosprezaste": "menosprezar",
    "menosprezastes": "menosprezar",
    "menosprezativa": "menosprezativo",
    "menosprezativas": "menosprezativo",
    "menosprezativos": "menosprezativo",
    "menosprezava": "menosprezar",
    "menosprezavam": "menosprezar",
    "menosprezavas": "menosprezar",
    "menospreze": "menosprezar",
    "menosprezei": "menosprezar",
    "menosprezeis": "menosprezar",
    "menosprezem": "menosprezar",
    "menosprezemo": "menosprezar",
    "menosprezemos": "menosprezar",
    "menosprezes": "menosprezar",
    "menosprezo": "menosprezar",
    "menosprezos": "menosprezo",
    "menosprezou": "menosprezar",
    "menosprezvíeis": "menosprezvíel",
    "menosprezá": "menosprezar",
    "menosprezámo": "menosprezar",
    "menosprezámos": "menosprezar",
    "menosprezáramo": "menosprezar",
    "menosprezáramos": "menosprezar",
    "menosprezárei": "menosprezar",
    "menosprezáreis": "menosprezar",
    "menosprezásseis": "menosprezar",
    "menosprezássemos": "menosprezar",
    "menosprezávamo": "menosprezar",
    "menosprezávamos": "menosprezar",
    "menosprezávei": "menosprezar",
    "menosprezáveis": "menosprezável",
    "menospreços": "menospreço",
    "menostasias": "menostasia",
    "mensageira": "mensageiro",
    "mensageiras": "mensageiro",
    "mensageiros": "mensageiro",
    "mensagens": "mensagem",
    "mensais": "mensal",
    "mensalidades": "mensalidade",
    "mensalistas": "mensalista",
    "menstrua": "menstruar",
    "menstruada": "menstruar",
    "menstruadas": "menstruar",
    "menstruado": "menstruar",
    "menstruados": "menstruar",
    "menstruai": "menstruar",
    "menstruais": "menstruar",
    "menstruam": "menstruar",
    "menstruamo": "menstruar",
    "menstruamos": "menstruar",
    "menstruando": "menstruar",
    "menstruara": "menstruar",
    "menstruaram": "menstruar",
    "menstruaras": "menstruar",
    "menstruardes": "menstruar",
    "menstruarei": "menstruar",
    "menstruareis": "menstruar",
    "menstruarem": "menstruar",
    "menstruaremos": "menstruar",
    "menstruares": "menstruar",
    "menstruaria": "menstruar",
    "menstruariam": "menstruar",
    "menstruarias": "menstruar",
    "menstruarmo": "menstruar",
    "menstruarmos": "menstruar",
    "menstruará": "menstruar",
    "menstruarás": "menstruar",
    "menstruarão": "menstruar",
    "menstruaríamos": "menstruar",
    "menstruaríeis": "menstruar",
    "menstruas": "menstruar",
    "menstruasse": "menstruar",
    "menstruassem": "menstruar",
    "menstruasses": "menstruar",
    "menstruaste": "menstruar",
    "menstruastes": "menstruar",
    "menstruava": "menstruar",
    "menstruavam": "menstruar",
    "menstruavas": "menstruar",
    "menstruações": "menstruação",
    "menstrue": "menstruar",
    "menstruei": "menstruar",
    "menstrueis": "menstruar",
    "menstruem": "menstruar",
    "menstruemo": "menstruar",
    "menstruemos": "menstruar",
    "menstrues": "menstruar",
    "menstruo": "menstruar",
    "menstruou": "menstruar",
    "menstruámo": "menstruar",
    "menstruámos": "menstruar",
    "menstruáramo": "menstruar",
    "menstruáramos": "menstruar",
    "menstruáreis": "menstruar",
    "menstruásseis": "menstruar",
    "menstruássemos": "menstruar",
    "menstruávamo": "menstruar",
    "menstruávamos": "menstruar",
    "menstruáveis": "menstruar",
    "mensura": "mensurar",
    "mensurabilidades": "mensurabilidade",
    "mensurada": "mensurar",
    "mensuradas": "mensurar",
    "mensurado": "mensurar",
    "mensuradora": "mensurador",
    "mensuradoras": "mensurador",
    "mensuradores": "mensurador",
    "mensurados": "mensurar",
    "mensurai": "mensurar",
    "mensurais": "mensurar",
    "mensuralistas": "mensuralista",
    "mensuram": "mensurar",
    "mensuramo": "mensurar",
    "mensuramos": "mensurar",
    "mensurando": "mensurar",
    "mensurara": "mensurar",
    "mensuraram": "mensurar",
    "mensuraras": "mensurar",
    "mensurarde": "mensurar",
    "mensurardes": "mensurar",
    "mensurare": "mensurar",
    "mensurarei": "mensurar",
    "mensurareis": "mensurar",
    "mensurarem": "mensurar",
    "mensuraremos": "mensurar",
    "mensurares": "mensurar",
    "mensuraria": "mensurar",
    "mensurariam": "mensurar",
    "mensurarias": "mensurar",
    "mensurarmo": "mensurar",
    "mensurarmos": "mensurar",
    "mensurará": "mensurar",
    "mensurarás": "mensurar",
    "mensurarão": "mensurar",
    "mensuraríamos": "mensurar",
    "mensuraríeis": "mensurar",
    "mensuras": "mensurar",
    "mensurasse": "mensurar",
    "mensurassem": "mensurar",
    "mensurasses": "mensurar",
    "mensuraste": "mensurar",
    "mensurastes": "mensurar",
    "mensurava": "mensurar",
    "mensuravam": "mensurar",
    "mensuravas": "mensurar",
    "mensurações": "mensuração",
    "mensure": "mensurar",
    "mensurei": "mensurar",
    "mensureis": "mensurar",
    "mensurem": "mensurar",
    "mensuremo": "mensurar",
    "mensuremos": "mensurar",
    "mensures": "mensurar",
    "mensuro": "mensurar",
    "mensurou": "mensurar",
    "mensurá": "mensurar",
    "mensurámo": "mensurar",
    "mensurámos": "mensurar",
    "mensuráramo": "mensurar",
    "mensuráramos": "mensurar",
    "mensurárei": "mensurar",
    "mensuráreis": "mensurar",
    "mensurásseis": "mensurar",
    "mensurássemos": "mensurar",
    "mensurávamo": "mensurar",
    "mensurávamos": "mensurar",
    "mensurávei": "mensurar",
    "mensuráveis": "mensurável",
    "mensária": "mensário",
    "mensárias": "mensário",
    "mensários": "mensário",
    "mentagras": "mentagra",
    "mentais": "mental",
    "mentalidades": "mentalidade",
    "mentalismos": "mentalismo",
    "mentalistas": "mentalista",
    "mentaliza": "mentalizar",
    "mentalizada": "mentalizar",
    "mentalizadas": "mentalizar",
    "mentalizado": "mentalizar",
    "mentalizados": "mentalizar",
    "mentalizai": "mentalizar",
    "mentalizais": "mentalizar",
    "mentalizam": "mentalizar",
    "mentalizamo": "mentalizar",
    "mentalizamos": "mentalizar",
    "mentalizando": "mentalizar",
    "mentalizara": "mentalizar",
    "mentalizaram": "mentalizar",
    "mentalizaras": "mentalizar",
    "mentalizarde": "mentalizar",
    "mentalizardes": "mentalizar",
    "mentalizare": "mentalizar",
    "mentalizarei": "mentalizar",
    "mentalizareis": "mentalizar",
    "mentalizarem": "mentalizar",
    "mentalizaremos": "mentalizar",
    "mentalizares": "mentalizar",
    "mentalizaria": "mentalizar",
    "mentalizariam": "mentalizar",
    "mentalizarias": "mentalizar",
    "mentalizarmo": "mentalizar",
    "mentalizarmos": "mentalizar",
    "mentalizará": "mentalizar",
    "mentalizarás": "mentalizar",
    "mentalizarão": "mentalizar",
    "mentalizaríamos": "mentalizar",
    "mentalizaríeis": "mentalizar",
    "mentalizas": "mentalizar",
    "mentalizasse": "mentalizar",
    "mentalizassem": "mentalizar",
    "mentalizasses": "mentalizar",
    "mentalizaste": "mentalizar",
    "mentalizastes": "mentalizar",
    "mentalizava": "mentalizar",
    "mentalizavam": "mentalizar",
    "mentalizavas": "mentalizar",
    "mentalize": "mentalizar",
    "mentalizei": "mentalizar",
    "mentalizeis": "mentalizar",
    "mentalizem": "mentalizar",
    "mentalizemo": "mentalizar",
    "mentalizemos": "mentalizar",
    "mentalizes": "mentalizar",
    "mentalizo": "mentalizar",
    "mentalizou": "mentalizar",
    "mentalizá": "mentalizar",
    "mentalizámo": "mentalizar",
    "mentalizámos": "mentalizar",
    "mentalizáramo": "mentalizar",
    "mentalizáramos": "mentalizar",
    "mentalizárei": "mentalizar",
    "mentalizáreis": "mentalizar",
    "mentalizásseis": "mentalizar",
    "mentalizássemos": "mentalizar",
    "mentalizávamo": "mentalizar",
    "mentalizávamos": "mentalizar",
    "mentalizávei": "mentalizar",
    "mentalizáveis": "mentalizável",
    "mentas": "menta",
    "mentastres": "mentastre",
    "mentastros": "mentastro",
    "mente": "mentir",
    "mentecapta": "mentecapto",
    "mentecaptas": "mentecapto",
    "mentecaptos": "mentecapto",
    "mentem": "mentir",
    "mentes": "mentir",
    "menti": "mentir",
    "mentia": "mentir",
    "mentiam": "mentir",
    "mentias": "mentir",
    "mentida": "mentir",
    "mentidas": "mentir",
    "mentideiros": "mentideiro",
    "mentido": "mentir",
    "mentidos": "mentir",
    "mentigens": "mentigem",
    "mentigos": "mentigo",
    "mentimo": "mentir",
    "mentimos": "mentir",
    "mentindo": "mentir",
    "mentira": "mentir",
    "mentiram": "mentir",
    "mentiras": "mentira",
    "mentirde": "mentir",
    "mentirdes": "mentir",
    "mentire": "mentir",
    "mentirei": "mentir",
    "mentireira": "mentireiro",
    "mentireiras": "mentireiro",
    "mentireiros": "mentireiro",
    "mentireis": "mentir",
    "mentirem": "mentir",
    "mentiremos": "mentir",
    "mentires": "mentir",
    "mentiria": "mentir",
    "mentiriam": "mentir",
    "mentirias": "mentir",
    "mentirinha": "mentira",
    "mentirinhas": "mentira",
    "mentirita": "mentira",
    "mentiritas": "mentira",
    "mentirmo": "mentir",
    "mentirmos": "mentir",
    "mentirolas": "mentirola",
    "mentirosa": "mentiroso",
    "mentirosas": "mentiroso",
    "mentirosos": "mentiroso",
    "mentirá": "mentir",
    "mentirás": "mentir",
    "mentirão": "mentir",
    "mentiríamos": "mentir",
    "mentiríeis": "mentir",
    "mentis": "mentir",
    "mentismos": "mentismo",
    "mentisse": "mentir",
    "mentissem": "mentir",
    "mentisses": "mentir",
    "mentiste": "mentir",
    "mentistes": "mentir",
    "mentiu": "mentir",
    "mentolabiais": "mentolabial",
    "mentolada": "mentolado",
    "mentoladas": "mentolado",
    "mentolados": "mentolado",
    "mentora": "mentor",
    "mentoras": "mentor",
    "mentores": "mentor",
    "mentos": "mento",
    "mentrastes": "mentraste",
    "mentrastos": "mentrasto",
    "mentíamo": "mentir",
    "mentíamos": "mentir",
    "mentíei": "mentir",
    "mentíeis": "mentir",
    "mentíramo": "mentir",
    "mentíramos": "mentir",
    "mentírei": "mentir",
    "mentíreis": "mentir",
    "mentísseis": "mentir",
    "mentíssemos": "mentir",
    "mentóis": "mentol",
    "mentólica": "mentólico",
    "mentólicas": "mentólico",
    "mentólicos": "mentólico",
    "menurídeos": "menurídeo",
    "menus": "menu",
    "menália": "menálio",
    "menálias": "menálio",
    "menálios": "menálio",
    "menções": "menção",
    "menídeos": "menídeo",
    "meníngea": "meníngeo",
    "meníngeas": "meníngeo",
    "meníngeos": "meníngeo",
    "menúridas": "menúrida",
    "meotes": "meote",
    "meou": "mear",
    "mequetrefes": "mequetrefe",
    "mera": "mero",
    "meras": "mero",
    "merca": "mercar",
    "mercada": "mercar",
    "mercadas": "mercar",
    "mercadeja": "mercadejar",
    "mercadejada": "mercadejar",
    "mercadejadas": "mercadejar",
    "mercadejado": "mercadejar",
    "mercadejados": "mercadejar",
    "mercadejai": "mercadejar",
    "mercadejais": "mercadejar",
    "mercadejam": "mercadejar",
    "mercadejamo": "mercadejar",
    "mercadejamos": "mercadejar",
    "mercadejando": "mercadejar",
    "mercadejara": "mercadejar",
    "mercadejaram": "mercadejar",
    "mercadejaras": "mercadejar",
    "mercadejardes": "mercadejar",
    "mercadejarei": "mercadejar",
    "mercadejareis": "mercadejar",
    "mercadejarem": "mercadejar",
    "mercadejaremos": "mercadejar",
    "mercadejares": "mercadejar",
    "mercadejaria": "mercadejar",
    "mercadejariam": "mercadejar",
    "mercadejarias": "mercadejar",
    "mercadejarmo": "mercadejar",
    "mercadejarmos": "mercadejar",
    "mercadejará": "mercadejar",
    "mercadejarás": "mercadejar",
    "mercadejarão": "mercadejar",
    "mercadejaríamos": "mercadejar",
    "mercadejaríeis": "mercadejar",
    "mercadejas": "mercadejar",
    "mercadejasse": "mercadejar",
    "mercadejassem": "mercadejar",
    "mercadejasses": "mercadejar",
    "mercadejaste": "mercadejar",
    "mercadejastes": "mercadejar",
    "mercadejava": "mercadejar",
    "mercadejavam": "mercadejar",
    "mercadejavas": "mercadejar",
    "mercadeje": "mercadejar",
    "mercadejei": "mercadejar",
    "mercadejeis": "mercadejar",
    "mercadejem": "mercadejar",
    "mercadejemo": "mercadejar",
    "mercadejemos": "mercadejar",
    "mercadejes": "mercadejar",
    "mercadejo": "mercadejar",
    "mercadejou": "mercadejar",
    "mercadejámo": "mercadejar",
    "mercadejámos": "mercadejar",
    "mercadejáramo": "mercadejar",
    "mercadejáramos": "mercadejar",
    "mercadejáreis": "mercadejar",
    "mercadejásseis": "mercadejar",
    "mercadejássemos": "mercadejar",
    "mercadejávamo": "mercadejar",
    "mercadejávamos": "mercadejar",
    "mercadejáveis": "mercadejável",
    "mercado": "mercar",
    "mercadologias": "mercadologia",
    "mercadológica": "mercadológico",
    "mercadológicas": "mercadológico",
    "mercadológicos": "mercadológico",
    "mercadora": "mercador",
    "mercadoras": "mercador",
    "mercadores": "mercador",
    "mercadorias": "mercadoria",
    "mercados": "mercar",
    "mercai": "mercar",
    "mercais": "mercar",
    "mercam": "mercar",
    "mercamo": "mercar",
    "mercamos": "mercar",
    "mercancia": "mercanciar",
    "mercanciada": "mercanciar",
    "mercanciadas": "mercanciar",
    "mercanciado": "mercanciar",
    "mercanciados": "mercanciar",
    "mercanciai": "mercanciar",
    "mercanciais": "mercanciar",
    "mercanciam": "mercanciar",
    "mercanciamo": "mercanciar",
    "mercanciamos": "mercanciar",
    "mercanciando": "mercanciar",
    "mercanciara": "mercanciar",
    "mercanciaram": "mercanciar",
    "mercanciaras": "mercanciar",
    "mercanciarde": "mercanciar",
    "mercanciardes": "mercanciar",
    "mercanciare": "mercanciar",
    "mercanciarei": "mercanciar",
    "mercanciareis": "mercanciar",
    "mercanciarem": "mercanciar",
    "mercanciaremos": "mercanciar",
    "mercanciares": "mercanciar",
    "mercanciaria": "mercanciar",
    "mercanciariam": "mercanciar",
    "mercanciarias": "mercanciar",
    "mercanciarmo": "mercanciar",
    "mercanciarmos": "mercanciar",
    "mercanciará": "mercanciar",
    "mercanciarás": "mercanciar",
    "mercanciarão": "mercanciar",
    "mercanciaríamos": "mercanciar",
    "mercanciaríeis": "mercanciar",
    "mercancias": "mercanciar",
    "mercanciasse": "mercanciar",
    "mercanciassem": "mercanciar",
    "mercanciasses": "mercanciar",
    "mercanciaste": "mercanciar",
    "mercanciastes": "mercanciar",
    "mercanciava": "mercanciar",
    "mercanciavam": "mercanciar",
    "mercanciavas": "mercanciar",
    "mercancie": "mercanciar",
    "mercanciei": "mercanciar",
    "mercancieis": "mercanciar",
    "mercanciem": "mercanciar",
    "mercanciemo": "mercanciar",
    "mercanciemos": "mercanciar",
    "mercancies": "mercanciar",
    "mercancio": "mercanciar",
    "mercanciou": "mercanciar",
    "mercanciá": "mercanciar",
    "mercanciámo": "mercanciar",
    "mercanciámos": "mercanciar",
    "mercanciáramo": "mercanciar",
    "mercanciáramos": "mercanciar",
    "mercanciárei": "mercanciar",
    "mercanciáreis": "mercanciar",
    "mercanciásseis": "mercanciar",
    "mercanciássemos": "mercanciar",
    "mercanciávamo": "mercanciar",
    "mercanciávamos": "mercanciar",
    "mercanciávei": "mercanciar",
    "mercanciáveis": "mercanciar",
    "mercando": "mercar",
    "mercantes": "mercante",
    "mercantilices": "mercantilice",
    "mercantilismos": "mercantilismo",
    "mercantilistas": "mercantilista",
    "mercantiliza": "mercantilizar",
    "mercantilizada": "mercantilizar",
    "mercantilizadas": "mercantilizar",
    "mercantilizado": "mercantilizar",
    "mercantilizados": "mercantilizar",
    "mercantilizai": "mercantilizar",
    "mercantilizais": "mercantilizar",
    "mercantilizam": "mercantilizar",
    "mercantilizamo": "mercantilizar",
    "mercantilizamos": "mercantilizar",
    "mercantilizando": "mercantilizar",
    "mercantilizara": "mercantilizar",
    "mercantilizaram": "mercantilizar",
    "mercantilizaras": "mercantilizar",
    "mercantilizarde": "mercantilizar",
    "mercantilizardes": "mercantilizar",
    "mercantilizare": "mercantilizar",
    "mercantilizarei": "mercantilizar",
    "mercantilizareis": "mercantilizar",
    "mercantilizarem": "mercantilizar",
    "mercantilizaremos": "mercantilizar",
    "mercantilizares": "mercantilizar",
    "mercantilizaria": "mercantilizar",
    "mercantilizariam": "mercantilizar",
    "mercantilizarias": "mercantilizar",
    "mercantilizarmo": "mercantilizar",
    "mercantilizarmos": "mercantilizar",
    "mercantilizará": "mercantilizar",
    "mercantilizarás": "mercantilizar",
    "mercantilizarão": "mercantilizar",
    "mercantilizaríamos": "mercantilizar",
    "mercantilizaríeis": "mercantilizar",
    "mercantilizas": "mercantilizar",
    "mercantilizasse": "mercantilizar",
    "mercantilizassem": "mercantilizar",
    "mercantilizasses": "mercantilizar",
    "mercantilizaste": "mercantilizar",
    "mercantilizastes": "mercantilizar",
    "mercantilizava": "mercantilizar",
    "mercantilizavam": "mercantilizar",
    "mercantilizavas": "mercantilizar",
    "mercantilize": "mercantilizar",
    "mercantilizei": "mercantilizar",
    "mercantilizeis": "mercantilizar",
    "mercantilizem": "mercantilizar",
    "mercantilizemo": "mercantilizar",
    "mercantilizemos": "mercantilizar",
    "mercantilizes": "mercantilizar",
    "mercantilizo": "mercantilizar",
    "mercantilizou": "mercantilizar",
    "mercantilizá": "mercantilizar",
    "mercantilizámo": "mercantilizar",
    "mercantilizámos": "mercantilizar",
    "mercantilizáramo": "mercantilizar",
    "mercantilizáramos": "mercantilizar",
    "mercantilizárei": "mercantilizar",
    "mercantilizáreis": "mercantilizar",
    "mercantilizásseis": "mercantilizar",
    "mercantilizássemos": "mercantilizar",
    "mercantilizávamo": "mercantilizar",
    "mercantilizávamos": "mercantilizar",
    "mercantilizávei": "mercantilizar",
    "mercantilizáveis": "mercantilizar",
    "mercantis": "mercantil",
    "mercaptais": "mercaptal",
    "mercara": "mercar",
    "mercaram": "mercar",
    "mercaras": "mercar",
    "mercarde": "mercar",
    "mercardes": "mercar",
    "mercare": "mercar",
    "mercarei": "mercar",
    "mercareis": "mercar",
    "mercarem": "mercar",
    "mercaremos": "mercar",
    "mercares": "mercar",
    "mercaria": "mercar",
    "mercariam": "mercar",
    "mercarias": "mercaria",
    "mercarmo": "mercar",
    "mercarmos": "mercar",
    "mercará": "mercar",
    "mercarás": "mercar",
    "mercarão": "mercar",
    "mercaríamos": "mercar",
    "mercaríeis": "mercar",
    "mercas": "mercar",
    "mercasse": "mercar",
    "mercassem": "mercar",
    "mercasses": "mercar",
    "mercaste": "mercar",
    "mercastes": "mercar",
    "mercatória": "mercatório",
    "mercatórias": "mercatório",
    "mercatórios": "mercatório",
    "mercava": "mercar",
    "mercavam": "mercar",
    "mercavas": "mercar",
    "mercearias": "mercearia",
    "merceeira": "merceeiro",
    "merceeiras": "merceeiro",
    "merceeiros": "merceeiro",
    "mercenarismos": "mercenarismo",
    "mercenária": "mercenário",
    "mercenárias": "mercenário",
    "mercenários": "mercenário",
    "merceologias": "merceologia",
    "merceológica": "merceológico",
    "merceológicas": "merceológico",
    "merceológicos": "merceológico",
    "merceriza": "mercerizar",
    "mercerizada": "mercerizar",
    "mercerizadas": "mercerizar",
    "mercerizado": "mercerizar",
    "mercerizados": "mercerizar",
    "mercerizai": "mercerizar",
    "mercerizais": "mercerizar",
    "mercerizam": "mercerizar",
    "mercerizamo": "mercerizar",
    "mercerizamos": "mercerizar",
    "mercerizando": "mercerizar",
    "mercerizara": "mercerizar",
    "mercerizaram": "mercerizar",
    "mercerizaras": "mercerizar",
    "mercerizarde": "mercerizar",
    "mercerizardes": "mercerizar",
    "mercerizare": "mercerizar",
    "mercerizarei": "mercerizar",
    "mercerizareis": "mercerizar",
    "mercerizarem": "mercerizar",
    "mercerizaremos": "mercerizar",
    "mercerizares": "mercerizar",
    "mercerizaria": "mercerizar",
    "mercerizariam": "mercerizar",
    "mercerizarias": "mercerizar",
    "mercerizarmo": "mercerizar",
    "mercerizarmos": "mercerizar",
    "mercerizará": "mercerizar",
    "mercerizarás": "mercerizar",
    "mercerizarão": "mercerizar",
    "mercerizaríamos": "mercerizar",
    "mercerizaríeis": "mercerizar",
    "mercerizas": "mercerizar",
    "mercerizasse": "mercerizar",
    "mercerizassem": "mercerizar",
    "mercerizasses": "mercerizar",
    "mercerizaste": "mercerizar",
    "mercerizastes": "mercerizar",
    "mercerizava": "mercerizar",
    "mercerizavam": "mercerizar",
    "mercerizavas": "mercerizar",
    "mercerizações": "mercerização",
    "mercerize": "mercerizar",
    "mercerizei": "mercerizar",
    "mercerizeis": "mercerizar",
    "mercerizem": "mercerizar",
    "mercerizemo": "mercerizar",
    "mercerizemos": "mercerizar",
    "mercerizes": "mercerizar",
    "mercerizo": "mercerizar",
    "mercerizou": "mercerizar",
    "mercerizá": "mercerizar",
    "mercerizámo": "mercerizar",
    "mercerizámos": "mercerizar",
    "mercerizáramo": "mercerizar",
    "mercerizáramos": "mercerizar",
    "mercerizárei": "mercerizar",
    "mercerizáreis": "mercerizar",
    "mercerizásseis": "mercerizar",
    "mercerizássemos": "mercerizar",
    "mercerizávamo": "mercerizar",
    "mercerizávamos": "mercerizar",
    "mercerizávei": "mercerizar",
    "mercerizáveis": "mercerizar",
    "merces": "merce",
    "merchandisings": "merchandising",
    "merco": "mercar",
    "mercou": "mercar",
    "mercuriais": "mercurial",
    "mercurialismos": "mercurialismo",
    "mercurializa": "mercurializar",
    "mercurializada": "mercurializar",
    "mercurializadas": "mercurializar",
    "mercurializado": "mercurializar",
    "mercurializados": "mercurializar",
    "mercurializai": "mercurializar",
    "mercurializais": "mercurializar",
    "mercurializam": "mercurializar",
    "mercurializamo": "mercurializar",
    "mercurializamos": "mercurializar",
    "mercurializando": "mercurializar",
    "mercurializara": "mercurializar",
    "mercurializaram": "mercurializar",
    "mercurializaras": "mercurializar",
    "mercurializarde": "mercurializar",
    "mercurializardes": "mercurializar",
    "mercurializare": "mercurializar",
    "mercurializarei": "mercurializar",
    "mercurializareis": "mercurializar",
    "mercurializarem": "mercurializar",
    "mercurializaremos": "mercurializar",
    "mercurializares": "mercurializar",
    "mercurializaria": "mercurializar",
    "mercurializariam": "mercurializar",
    "mercurializarias": "mercurializar",
    "mercurializarmo": "mercurializar",
    "mercurializarmos": "mercurializar",
    "mercurializará": "mercurializar",
    "mercurializarás": "mercurializar",
    "mercurializarão": "mercurializar",
    "mercurializaríamos": "mercurializar",
    "mercurializaríeis": "mercurializar",
    "mercurializas": "mercurializar",
    "mercurializasse": "mercurializar",
    "mercurializassem": "mercurializar",
    "mercurializasses": "mercurializar",
    "mercurializaste": "mercurializar",
    "mercurializastes": "mercurializar",
    "mercurializava": "mercurializar",
    "mercurializavam": "mercurializar",
    "mercurializavas": "mercurializar",
    "mercurializações": "mercurialização",
    "mercurialize": "mercurializar",
    "mercurializei": "mercurializar",
    "mercurializeis": "mercurializar",
    "mercurializem": "mercurializar",
    "mercurializemo": "mercurializar",
    "mercurializemos": "mercurializar",
    "mercurializes": "mercurializar",
    "mercurializo": "mercurializar",
    "mercurializou": "mercurializar",
    "mercurializá": "mercurializar",
    "mercurializámo": "mercurializar",
    "mercurializámos": "mercurializar",
    "mercurializáramo": "mercurializar",
    "mercurializáramos": "mercurializar",
    "mercurializárei": "mercurializar",
    "mercurializáreis": "mercurializar",
    "mercurializásseis": "mercurializar",
    "mercurializássemos": "mercurializar",
    "mercurializávamo": "mercurializar",
    "mercurializávamos": "mercurializar",
    "mercurializávei": "mercurializar",
    "mercurializáveis": "mercurializar",
    "mercurocromos": "mercurocromo",
    "mercurosa": "mercuroso",
    "mercurosas": "mercuroso",
    "mercurosos": "mercuroso",
    "mercá": "mercar",
    "mercámo": "mercar",
    "mercámos": "mercar",
    "mercáramo": "mercar",
    "mercáramos": "mercar",
    "mercárei": "mercar",
    "mercáreis": "mercar",
    "mercásseis": "mercar",
    "mercássemos": "mercar",
    "mercávamo": "mercar",
    "mercávamos": "mercar",
    "mercávei": "mercar",
    "mercáveis": "mercável",
    "mercês": "mercê",
    "mercúrica": "mercúrico",
    "mercúricas": "mercúrico",
    "mercúricos": "mercúrico",
    "mercúrios": "mercúrio",
    "merdas": "merda",
    "merdices": "merdice",
    "merdinha": "merda",
    "merdinhas": "merda",
    "merdita": "merda",
    "merditas": "merda",
    "merdosa": "merdoso",
    "merdosas": "merdoso",
    "merdosos": "merdoso",
    "merdícolas": "merdícola",
    "merdívora": "merdívoro",
    "merdívoras": "merdívoro",
    "merdívoros": "merdívoro",
    "merece": "merecer",
    "merecedora": "merecedor",
    "merecedoras": "merecedor",
    "merecedores": "merecedor",
    "merecei": "merecer",
    "mereceis": "merecer",
    "merecem": "merecer",
    "merecemo": "merecer",
    "merecemos": "merecer",
    "merecendo": "merecer",
    "merecera": "merecer",
    "mereceram": "merecer",
    "mereceras": "merecer",
    "merecerde": "merecer",
    "merecerdes": "merecer",
    "merecere": "merecer",
    "merecerei": "merecer",
    "merecereis": "merecer",
    "merecerem": "merecer",
    "mereceremos": "merecer",
    "mereceres": "merecer",
    "mereceria": "merecer",
    "mereceriam": "merecer",
    "merecerias": "merecer",
    "merecermo": "merecer",
    "merecermos": "merecer",
    "merecerá": "merecer",
    "merecerás": "merecer",
    "merecerão": "merecer",
    "mereceríamos": "merecer",
    "mereceríeis": "merecer",
    "mereces": "merecer",
    "merecesse": "merecer",
    "merecessem": "merecer",
    "merecesses": "merecer",
    "mereceste": "merecer",
    "merecestes": "merecer",
    "mereceu": "merecer",
    "mereci": "merecer",
    "merecia": "merecer",
    "mereciam": "merecer",
    "merecias": "merecer",
    "merecida": "merecido",
    "merecidas": "merecido",
    "merecido": "merecer",
    "merecidos": "merecido",
    "merecidíssima": "merecido",
    "merecidíssimas": "merecido",
    "merecidíssimo": "merecido",
    "merecidíssimos": "merecido",
    "merecimentos": "merecimento",
    "merecê": "merecer",
    "merecêramo": "merecer",
    "merecêramos": "merecer",
    "merecêrei": "merecer",
    "merecêreis": "merecer",
    "merecêsseis": "merecer",
    "merecêssemos": "merecer",
    "merecíamo": "merecer",
    "merecíamos": "merecer",
    "merecíei": "merecer",
    "merecíeis": "merecer",
    "merecíveis": "merecível",
    "merencória": "merencório",
    "merencórias": "merencório",
    "merencórios": "merencório",
    "merenda": "merendar",
    "merendada": "merendar",
    "merendadas": "merendar",
    "merendado": "merendar",
    "merendados": "merendar",
    "merendai": "merendar",
    "merendais": "merendar",
    "merendam": "merendar",
    "merendamo": "merendar",
    "merendamos": "merendar",
    "merendando": "merendar",
    "merendara": "merendar",
    "merendaram": "merendar",
    "merendaras": "merendar",
    "merendarde": "merendar",
    "merendardes": "merendar",
    "merendare": "merendar",
    "merendarei": "merendar",
    "merendareis": "merendar",
    "merendarem": "merendar",
    "merendaremos": "merendar",
    "merendares": "merendar",
    "merendaria": "merendar",
    "merendariam": "merendar",
    "merendarias": "merendar",
    "merendarmo": "merendar",
    "merendarmos": "merendar",
    "merendará": "merendar",
    "merendarás": "merendar",
    "merendarão": "merendar",
    "merendaríamos": "merendar",
    "merendaríeis": "merendar",
    "merendas": "merendar",
    "merendasse": "merendar",
    "merendassem": "merendar",
    "merendasses": "merendar",
    "merendaste": "merendar",
    "merendastes": "merendar",
    "merendava": "merendar",
    "merendavam": "merendar",
    "merendavas": "merendar",
    "merende": "merendar",
    "merendei": "merendar",
    "merendeira": "merendeiro",
    "merendeiras": "merendeiro",
    "merendeiros": "merendeiro",
    "merendeis": "merendar",
    "merendem": "merendar",
    "merendemo": "merendar",
    "merendemos": "merendar",
    "merendes": "merendar",
    "merendicos": "merendico",
    "merendinha": "merenda",
    "merendinhas": "merenda",
    "merendita": "merenda",
    "merenditas": "merenda",
    "merendo": "merendar",
    "merendolas": "merendola",
    "merendonas": "merendona",
    "merendou": "merendar",
    "merendá": "merendar",
    "merendámo": "merendar",
    "merendámos": "merendar",
    "merendáramo": "merendar",
    "merendáramos": "merendar",
    "merendárei": "merendar",
    "merendáreis": "merendar",
    "merendásseis": "merendar",
    "merendássemos": "merendar",
    "merendávamo": "merendar",
    "merendávamos": "merendar",
    "merendávei": "merendar",
    "merendáveis": "merendar",
    "merengues": "merengue",
    "meretrices": "meretrice",
    "meretrizes": "meretriz",
    "meretrícia": "meretrício",
    "meretrícias": "meretrício",
    "meretrícios": "meretrício",
    "mereça": "merecer",
    "mereçais": "merecer",
    "mereçam": "merecer",
    "mereçamo": "merecer",
    "mereçamos": "merecer",
    "mereças": "merecer",
    "mereço": "merecer",
    "mergansos": "merganso",
    "mergulha": "mergulhar",
    "mergulhada": "mergulhar",
    "mergulhadas": "mergulhar",
    "mergulhado": "mergulhar",
    "mergulhadora": "mergulhador",
    "mergulhadoras": "mergulhador",
    "mergulhadores": "mergulhador",
    "mergulhados": "mergulhar",
    "mergulhai": "mergulhar",
    "mergulhais": "mergulhar",
    "mergulham": "mergulhar",
    "mergulhamo": "mergulhar",
    "mergulhamos": "mergulhar",
    "mergulhando": "mergulhar",
    "mergulhantes": "mergulhante",
    "mergulhara": "mergulhar",
    "mergulharam": "mergulhar",
    "mergulharas": "mergulhar",
    "mergulharde": "mergulhar",
    "mergulhardes": "mergulhar",
    "mergulhare": "mergulhar",
    "mergulharei": "mergulhar",
    "mergulhareis": "mergulhar",
    "mergulharem": "mergulhar",
    "mergulharemos": "mergulhar",
    "mergulhares": "mergulhar",
    "mergulharia": "mergulhar",
    "mergulhariam": "mergulhar",
    "mergulharias": "mergulhar",
    "mergulharmo": "mergulhar",
    "mergulharmos": "mergulhar",
    "mergulhará": "mergulhar",
    "mergulharás": "mergulhar",
    "mergulharão": "mergulhar",
    "mergulharíamos": "mergulhar",
    "mergulharíeis": "mergulhar",
    "mergulhas": "mergulhar",
    "mergulhasse": "mergulhar",
    "mergulhassem": "mergulhar",
    "mergulhasses": "mergulhar",
    "mergulhaste": "mergulhar",
    "mergulhastes": "mergulhar",
    "mergulhava": "mergulhar",
    "mergulhavam": "mergulhar",
    "mergulhavas": "mergulhar",
    "mergulhe": "mergulhar",
    "mergulhei": "mergulhar",
    "mergulheira": "mergulheiro",
    "mergulheiras": "mergulheiro",
    "mergulheiros": "mergulheiro",
    "mergulheis": "mergulhar",
    "mergulhem": "mergulhar",
    "mergulhemo": "mergulhar",
    "mergulhemos": "mergulhar",
    "mergulhes": "mergulhar",
    "mergulhias": "mergulhia",
    "mergulhinho": "mergulho",
    "mergulhinhos": "mergulho",
    "mergulhito": "mergulho",
    "mergulhitos": "mergulho",
    "mergulho": "mergulhar",
    "mergulhos": "mergulho",
    "mergulhou": "mergulhar",
    "mergulhá": "mergulhar",
    "mergulhámo": "mergulhar",
    "mergulhámos": "mergulhar",
    "mergulháramo": "mergulhar",
    "mergulháramos": "mergulhar",
    "mergulhárei": "mergulhar",
    "mergulháreis": "mergulhar",
    "mergulhásseis": "mergulhar",
    "mergulhássemos": "mergulhar",
    "mergulhávamo": "mergulhar",
    "mergulhávamos": "mergulhar",
    "mergulhávei": "mergulhar",
    "mergulháveis": "mergulhar",
    "mergulhões": "mergulhão",
    "mericarpos": "mericarpo",
    "mericismos": "mericismo",
    "meridiana": "meridiano",
    "meridianas": "meridiano",
    "meridianos": "meridiano",
    "meridionais": "meridional",
    "meridotalos": "meridotalo",
    "meriedrias": "meriedria",
    "merifelas": "merifela",
    "merina": "merino",
    "merinaques": "merinaque",
    "merinas": "merino",
    "merinos": "merino",
    "merinós": "merinó",
    "merismas": "merisma",
    "merismática": "merismático",
    "merismáticas": "merismático",
    "merismáticos": "merismático",
    "meristemas": "meristema",
    "meritalos": "meritalo",
    "meritíssima": "meritíssimo",
    "meritíssimas": "meritíssimo",
    "meritíssimos": "meritíssimo",
    "meritória": "meritório",
    "meritórias": "meritório",
    "meritórios": "meritório",
    "merlantes": "merlante",
    "merlins": "merlim",
    "merlões": "merlão",
    "merma": "mermar",
    "mermada": "mermar",
    "mermadas": "mermar",
    "mermado": "mermar",
    "mermados": "mermar",
    "mermai": "mermar",
    "mermais": "mermar",
    "mermam": "mermar",
    "mermamo": "mermar",
    "mermamos": "mermar",
    "mermando": "mermar",
    "mermara": "mermar",
    "mermaram": "mermar",
    "mermaras": "mermar",
    "mermarde": "mermar",
    "mermardes": "mermar",
    "mermare": "mermar",
    "mermarei": "mermar",
    "mermareis": "mermar",
    "mermarem": "mermar",
    "mermaremos": "mermar",
    "mermares": "mermar",
    "mermaria": "mermar",
    "mermariam": "mermar",
    "mermarias": "mermar",
    "mermarmo": "mermar",
    "mermarmos": "mermar",
    "mermará": "mermar",
    "mermarás": "mermar",
    "mermarão": "mermar",
    "mermaríamos": "mermar",
    "mermaríeis": "mermar",
    "mermas": "mermar",
    "mermasse": "mermar",
    "mermassem": "mermar",
    "mermasses": "mermar",
    "mermaste": "mermar",
    "mermastes": "mermar",
    "mermava": "mermar",
    "mermavam": "mermar",
    "mermavas": "mermar",
    "merme": "mermar",
    "mermei": "mermar",
    "mermeis": "mermar",
    "mermem": "mermar",
    "mermemo": "mermar",
    "mermemos": "mermar",
    "mermes": "mermar",
    "mermo": "mermar",
    "mermou": "mermar",
    "mermá": "mermar",
    "mermámo": "mermar",
    "mermámos": "mermar",
    "mermáramo": "mermar",
    "mermáramos": "mermar",
    "mermárei": "mermar",
    "mermáreis": "mermar",
    "mermásseis": "mermar",
    "mermássemos": "mermar",
    "mermávamo": "mermar",
    "mermávamos": "mermar",
    "mermávei": "mermar",
    "mermáveis": "mermar",
    "meroblástica": "meroblástico",
    "meroblásticas": "meroblástico",
    "meroblásticos": "meroblástico",
    "meroceles": "merocele",
    "meroedrias": "meroedria",
    "merologias": "merologia",
    "merológica": "merológico",
    "merológicas": "merológico",
    "merológicos": "merológico",
    "meropídeos": "meropídeo",
    "meros": "mero",
    "merostomáceos": "merostomáceo",
    "merouços": "merouço",
    "merovíngia": "merovíngio",
    "merovíngias": "merovíngio",
    "merovíngios": "merovíngio",
    "merozoários": "merozoário",
    "merozóitos": "merozóito",
    "meroédrica": "meroédrico",
    "meroédricas": "meroédrico",
    "meroédricos": "meroédrico",
    "merque": "mercar",
    "merquei": "mercar",
    "merqueis": "mercar",
    "merquem": "mercar",
    "merquemo": "mercar",
    "merquemos": "mercar",
    "merques": "mercar",
    "mertolenga": "mertolengo",
    "mertolengas": "mertolengo",
    "mertolengos": "mertolengo",
    "mertolenses": "mertolense",
    "merufos": "merufo",
    "merugens": "merugem",
    "meruges": "meruge",
    "meruginhas": "meruginha",
    "meruja": "merujar",
    "merujada": "merujar",
    "merujadas": "merujar",
    "merujado": "merujar",
    "merujados": "merujar",
    "merujai": "merujar",
    "merujais": "merujar",
    "merujam": "merujar",
    "merujamo": "merujar",
    "merujamos": "merujar",
    "merujando": "merujar",
    "merujara": "merujar",
    "merujaram": "merujar",
    "merujaras": "merujar",
    "merujarde": "merujar",
    "merujardes": "merujar",
    "merujare": "merujar",
    "merujarei": "merujar",
    "merujareis": "merujar",
    "merujarem": "merujar",
    "merujaremos": "merujar",
    "merujares": "merujar",
    "merujaria": "merujar",
    "merujariam": "merujar",
    "merujarias": "merujar",
    "merujarmo": "merujar",
    "merujarmos": "merujar",
    "merujará": "merujar",
    "merujarás": "merujar",
    "merujarão": "merujar",
    "merujaríamos": "merujar",
    "merujaríeis": "merujar",
    "merujas": "merujar",
    "merujasse": "merujar",
    "merujassem": "merujar",
    "merujasses": "merujar",
    "merujaste": "merujar",
    "merujastes": "merujar",
    "merujava": "merujar",
    "merujavam": "merujar",
    "merujavas": "merujar",
    "meruje": "merujar",
    "merujei": "merujar",
    "merujeis": "merujar",
    "merujem": "merujar",
    "merujemo": "merujar",
    "merujemos": "merujar",
    "merujes": "merujar",
    "merujo": "merujar",
    "merujou": "merujar",
    "merujá": "merujar",
    "merujámo": "merujar",
    "merujámos": "merujar",
    "merujáramo": "merujar",
    "merujáramos": "merujar",
    "merujárei": "merujar",
    "merujáreis": "merujar",
    "merujásseis": "merujar",
    "merujássemos": "merujar",
    "merujávamo": "merujar",
    "merujávamos": "merujar",
    "merujávei": "merujar",
    "merujáveis": "merujar",
    "merus": "meru",
    "merídia": "merídio",
    "merídias": "merídio",
    "merídios": "merídio",
    "merópidas": "merópida",
    "mesadas": "mesada",
    "mesas": "mesa",
    "mesatocefalias": "mesatocefalia",
    "mesatocéfala": "mesatocéfalo",
    "mesatocéfalas": "mesatocéfalo",
    "mesatocéfalos": "mesatocéfalo",
    "mescais": "mescal",
    "mescalinas": "mescalina",
    "mescla": "mesclar",
    "mesclada": "mesclar",
    "mescladas": "mesclar",
    "mesclado": "mesclar",
    "mesclados": "mesclar",
    "mesclai": "mesclar",
    "mesclais": "mesclar",
    "mesclam": "mesclar",
    "mesclamo": "mesclar",
    "mesclamos": "mesclar",
    "mesclando": "mesclar",
    "mesclara": "mesclar",
    "mesclaram": "mesclar",
    "mesclaras": "mesclar",
    "mesclarde": "mesclar",
    "mesclardes": "mesclar",
    "mesclare": "mesclar",
    "mesclarei": "mesclar",
    "mesclareis": "mesclar",
    "mesclarem": "mesclar",
    "mesclaremos": "mesclar",
    "mesclares": "mesclar",
    "mesclaria": "mesclar",
    "mesclariam": "mesclar",
    "mesclarias": "mesclar",
    "mesclarmo": "mesclar",
    "mesclarmos": "mesclar",
    "mesclará": "mesclar",
    "mesclarás": "mesclar",
    "mesclarão": "mesclar",
    "mesclaríamos": "mesclar",
    "mesclaríeis": "mesclar",
    "mesclas": "mesclar",
    "mesclasse": "mesclar",
    "mesclassem": "mesclar",
    "mesclasses": "mesclar",
    "mesclaste": "mesclar",
    "mesclastes": "mesclar",
    "mesclava": "mesclar",
    "mesclavam": "mesclar",
    "mesclavas": "mesclar",
    "mescle": "mesclar",
    "mesclei": "mesclar",
    "mescleis": "mesclar",
    "mesclem": "mesclar",
    "mesclemo": "mesclar",
    "mesclemos": "mesclar",
    "mescles": "mesclar",
    "mesclo": "mesclar",
    "mesclou": "mesclar",
    "mesclá": "mesclar",
    "mesclámo": "mesclar",
    "mesclámos": "mesclar",
    "mescláramo": "mesclar",
    "mescláramos": "mesclar",
    "mesclárei": "mesclar",
    "mescláreis": "mesclar",
    "mesclásseis": "mesclar",
    "mesclássemos": "mesclar",
    "mesclávamo": "mesclar",
    "mesclávamos": "mesclar",
    "mesclávei": "mesclar",
    "mescláveis": "mesclável",
    "mesencéfalos": "mesencéfalo",
    "mesenterites": "mesenterite",
    "mesentérica": "mesentérico",
    "mesentéricas": "mesentérico",
    "mesentéricos": "mesentérico",
    "mesentérios": "mesentério",
    "meses": "mês",
    "mesetas": "meseta",
    "mesinha": "mesa",
    "mesinhas": "mesa",
    "mesita": "mesa",
    "mesitas": "mesa",
    "mesma": "mesmo",
    "mesmas": "mesmo",
    "mesmeriana": "mesmeriano",
    "mesmerianas": "mesmeriano",
    "mesmerianos": "mesmeriano",
    "mesmerismos": "mesmerismo",
    "mesmeristas": "mesmerista",
    "mesmices": "mesmice",
    "mesmidades": "mesmidade",
    "mesmos": "mesmo",
    "mesmíssima": "mesmo",
    "mesmíssimas": "mesmo",
    "mesmíssimo": "mesmo",
    "mesmíssimos": "mesmo",
    "mesnadarias": "mesnadaria",
    "mesnadas": "mesnada",
    "mesnadeiros": "mesnadeiro",
    "mesoblastos": "mesoblasto",
    "mesocarpos": "mesocarpo",
    "mesocefalias": "mesocefalia",
    "mesocefalites": "mesocefalite",
    "mesocistos": "mesocisto",
    "mesoclítica": "mesoclítico",
    "mesoclíticas": "mesoclítico",
    "mesoclíticos": "mesoclítico",
    "mesocolos": "mesocolo",
    "mesocracias": "mesocracia",
    "mesocrática": "mesocrático",
    "mesocráticas": "mesocrático",
    "mesocráticos": "mesocrático",
    "mesocárpica": "mesocárpico",
    "mesocárpicas": "mesocárpico",
    "mesocárpicos": "mesocárpico",
    "mesocárpios": "mesocárpio",
    "mesocéfala": "mesocéfalo",
    "mesocéfalas": "mesocéfalo",
    "mesocéfalos": "mesocéfalo",
    "mesocólons": "mesocólon",
    "mesodermas": "mesoderma",
    "mesodermes": "mesoderme",
    "mesofalanges": "mesofalange",
    "mesofilos": "mesofilo",
    "mesogástrica": "mesogástrico",
    "mesogástricas": "mesogástrico",
    "mesogástricos": "mesogástrico",
    "mesogástrios": "mesogástrio",
    "mesologias": "mesologia",
    "mesolítica": "mesolítico",
    "mesolíticas": "mesolítico",
    "mesolíticos": "mesolítico",
    "mesológica": "mesológico",
    "mesológicas": "mesológico",
    "mesológicos": "mesológico",
    "mesomerismos": "mesomerismo",
    "mesomorfismos": "mesomorfismo",
    "mesométrica": "mesométrico",
    "mesométricas": "mesométrico",
    "mesométricos": "mesométrico",
    "mesopotâmias": "mesopotâmia",
    "mesopotâmica": "mesopotâmico",
    "mesopotâmicas": "mesopotâmico",
    "mesopotâmicos": "mesopotâmico",
    "mesorrectos": "mesorrecto",
    "mesos": "meso",
    "mesosferas": "mesosfera",
    "mesosférica": "mesosférico",
    "mesosféricas": "mesosférico",
    "mesosféricos": "mesosférico",
    "mesospermos": "mesospermo",
    "mesotenares": "mesotenar",
    "mesotimpânica": "mesotimpânico",
    "mesotimpânicas": "mesotimpânico",
    "mesotimpânicos": "mesotimpânico",
    "mesotóraxes": "mesotórax",
    "mesozeugmas": "mesozeugma",
    "mesozonas": "mesozona",
    "mesozoários": "mesozoário",
    "mesozóica": "mesozóico",
    "mesozóicas": "mesozóico",
    "mesozóicos": "mesozóico",
    "mesquinha": "mesquinho",
    "mesquinhada": "mesquinhar",
    "mesquinhadas": "mesquinhar",
    "mesquinhado": "mesquinhar",
    "mesquinhados": "mesquinhar",
    "mesquinhai": "mesquinhar",
    "mesquinhais": "mesquinhar",
    "mesquinham": "mesquinhar",
    "mesquinhamo": "mesquinhar",
    "mesquinhamos": "mesquinhar",
    "mesquinhando": "mesquinhar",
    "mesquinhara": "mesquinhar",
    "mesquinharam": "mesquinhar",
    "mesquinharas": "mesquinhar",
    "mesquinharde": "mesquinhar",
    "mesquinhardes": "mesquinhar",
    "mesquinhare": "mesquinhar",
    "mesquinharei": "mesquinhar",
    "mesquinhareis": "mesquinhar",
    "mesquinharem": "mesquinhar",
    "mesquinharemos": "mesquinhar",
    "mesquinhares": "mesquinhar",
    "mesquinharia": "mesquinhar",
    "mesquinhariam": "mesquinhar",
    "mesquinharias": "mesquinharia",
    "mesquinharmo": "mesquinhar",
    "mesquinharmos": "mesquinhar",
    "mesquinhará": "mesquinhar",
    "mesquinharás": "mesquinhar",
    "mesquinharão": "mesquinhar",
    "mesquinharíamos": "mesquinhar",
    "mesquinharíeis": "mesquinhar",
    "mesquinhas": "mesquinho",
    "mesquinhasse": "mesquinhar",
    "mesquinhassem": "mesquinhar",
    "mesquinhasses": "mesquinhar",
    "mesquinhaste": "mesquinhar",
    "mesquinhastes": "mesquinhar",
    "mesquinhava": "mesquinhar",
    "mesquinhavam": "mesquinhar",
    "mesquinhavas": "mesquinhar",
    "mesquinhe": "mesquinhar",
    "mesquinhei": "mesquinhar",
    "mesquinheis": "mesquinhar",
    "mesquinhem": "mesquinhar",
    "mesquinhemo": "mesquinhar",
    "mesquinhemos": "mesquinhar",
    "mesquinhes": "mesquinhar",
    "mesquinhezas": "mesquinheza",
    "mesquinhices": "mesquinhice",
    "mesquinho": "mesquinhar",
    "mesquinhos": "mesquinho",
    "mesquinhou": "mesquinhar",
    "mesquinhá": "mesquinhar",
    "mesquinhámo": "mesquinhar",
    "mesquinhámos": "mesquinhar",
    "mesquinháramo": "mesquinhar",
    "mesquinháramos": "mesquinhar",
    "mesquinhárei": "mesquinhar",
    "mesquinháreis": "mesquinhar",
    "mesquinhásseis": "mesquinhar",
    "mesquinhássemos": "mesquinhar",
    "mesquinhávamo": "mesquinhar",
    "mesquinhávamos": "mesquinhar",
    "mesquinhávei": "mesquinhar",
    "mesquinháveis": "mesquinhar",
    "mesquinhíssima": "mesquinho",
    "mesquinhíssimas": "mesquinho",
    "mesquinhíssimo": "mesquinho",
    "mesquinhíssimos": "mesquinho",
    "mesquitas": "mesquita",
    "messa": "messar",
    "messada": "messar",
    "messadas": "messar",
    "messado": "messar",
    "messados": "messar",
    "messai": "messar",
    "messais": "messar",
    "messalinas": "messalina",
    "messam": "messar",
    "messamo": "messar",
    "messamos": "messar",
    "messando": "messar",
    "messara": "messar",
    "messaram": "messar",
    "messaras": "messar",
    "messardes": "messar",
    "messarei": "messar",
    "messareis": "messar",
    "messarem": "messar",
    "messaremos": "messar",
    "messares": "messar",
    "messaria": "messar",
    "messariam": "messar",
    "messarias": "messar",
    "messarmo": "messar",
    "messarmos": "messar",
    "messará": "messar",
    "messarás": "messar",
    "messarão": "messar",
    "messaríamos": "messar",
    "messaríeis": "messar",
    "messas": "messar",
    "messasse": "messar",
    "messassem": "messar",
    "messasses": "messar",
    "messaste": "messar",
    "messastes": "messar",
    "messava": "messar",
    "messavam": "messar",
    "messavas": "messar",
    "messe": "messar",
    "messei": "messar",
    "messeis": "messar",
    "messem": "messar",
    "messemo": "messar",
    "messemos": "messar",
    "messes": "messe",
    "messiados": "messiado",
    "messianismos": "messianismo",
    "messianistas": "messianista",
    "messidores": "messidor",
    "messieurs": "messieur",
    "messiânica": "messiânico",
    "messiânicas": "messiânico",
    "messiânicos": "messiânico",
    "messo": "messar",
    "messou": "messar",
    "messámo": "messar",
    "messámos": "messar",
    "messáramo": "messar",
    "messáramos": "messar",
    "messáreis": "messar",
    "messásseis": "messar",
    "messássemos": "messar",
    "messávamo": "messar",
    "messávamos": "messar",
    "messáveis": "messar",
    "messória": "messório",
    "messórias": "messório",
    "messórios": "messório",
    "mesta": "mesto",
    "mestas": "mesto",
    "mesteirais": "mesteiral",
    "mesteres": "mester",
    "mestice": "mestiçar",
    "mesticei": "mestiçar",
    "mesticeis": "mestiçar",
    "mesticem": "mestiçar",
    "mesticemo": "mestiçar",
    "mesticemos": "mestiçar",
    "mestices": "mestiçar",
    "mestiça": "mestiço",
    "mestiçada": "mestiçar",
    "mestiçadas": "mestiçar",
    "mestiçado": "mestiçar",
    "mestiçados": "mestiçar",
    "mestiçagens": "mestiçagem",
    "mestiçai": "mestiçar",
    "mestiçais": "mestiçar",
    "mestiçam": "mestiçar",
    "mestiçamentos": "mestiçamento",
    "mestiçamo": "mestiçar",
    "mestiçamos": "mestiçar",
    "mestiçando": "mestiçar",
    "mestiçara": "mestiçar",
    "mestiçaram": "mestiçar",
    "mestiçaras": "mestiçar",
    "mestiçarde": "mestiçar",
    "mestiçardes": "mestiçar",
    "mestiçare": "mestiçar",
    "mestiçarei": "mestiçar",
    "mestiçareis": "mestiçar",
    "mestiçarem": "mestiçar",
    "mestiçaremos": "mestiçar",
    "mestiçares": "mestiçar",
    "mestiçaria": "mestiçar",
    "mestiçariam": "mestiçar",
    "mestiçarias": "mestiçar",
    "mestiçarmo": "mestiçar",
    "mestiçarmos": "mestiçar",
    "mestiçará": "mestiçar",
    "mestiçarás": "mestiçar",
    "mestiçarão": "mestiçar",
    "mestiçaríamos": "mestiçar",
    "mestiçaríeis": "mestiçar",
    "mestiças": "mestiço",
    "mestiçasse": "mestiçar",
    "mestiçassem": "mestiçar",
    "mestiçasses": "mestiçar",
    "mestiçaste": "mestiçar",
    "mestiçastes": "mestiçar",
    "mestiçava": "mestiçar",
    "mestiçavam": "mestiçar",
    "mestiçavas": "mestiçar",
    "mestiço": "mestiçar",
    "mestiços": "mestiço",
    "mestiçou": "mestiçar",
    "mestiçá": "mestiçar",
    "mestiçámo": "mestiçar",
    "mestiçámos": "mestiçar",
    "mestiçáramo": "mestiçar",
    "mestiçáramos": "mestiçar",
    "mestiçárei": "mestiçar",
    "mestiçáreis": "mestiçar",
    "mestiçásseis": "mestiçar",
    "mestiçássemos": "mestiçar",
    "mestiçávamo": "mestiçar",
    "mestiçávamos": "mestiçar",
    "mestiçávei": "mestiçar",
    "mestiçáveis": "mestiçável",
    "mestos": "mesto",
    "mestra": "mestre",
    "mestrados": "mestrado",
    "mestrais": "mestral",
    "mestranda": "mestrando",
    "mestrandas": "mestrando",
    "mestrandos": "mestrando",
    "mestranças": "mestrança",
    "mestras": "mestre",
    "mestraça": "mestraço",
    "mestraças": "mestraço",
    "mestraços": "mestraço",
    "mestres": "mestre",
    "mestrias": "mestria",
    "mestrona": "mestrão",
    "mestronas": "mestrão",
    "mestrões": "mestrão",
    "mesura": "mesurar",
    "mesurada": "mesurar",
    "mesuradas": "mesurar",
    "mesurado": "mesurar",
    "mesurados": "mesurar",
    "mesurai": "mesurar",
    "mesurais": "mesurar",
    "mesuram": "mesurar",
    "mesuramo": "mesurar",
    "mesuramos": "mesurar",
    "mesurando": "mesurar",
    "mesurara": "mesurar",
    "mesuraram": "mesurar",
    "mesuraras": "mesurar",
    "mesurardes": "mesurar",
    "mesurarei": "mesurar",
    "mesurareis": "mesurar",
    "mesurarem": "mesurar",
    "mesuraremos": "mesurar",
    "mesurares": "mesurar",
    "mesuraria": "mesurar",
    "mesurariam": "mesurar",
    "mesurarias": "mesurar",
    "mesurarmo": "mesurar",
    "mesurarmos": "mesurar",
    "mesurará": "mesurar",
    "mesurarás": "mesurar",
    "mesurarão": "mesurar",
    "mesuraríamos": "mesurar",
    "mesuraríeis": "mesurar",
    "mesuras": "mesurar",
    "mesurasse": "mesurar",
    "mesurassem": "mesurar",
    "mesurasses": "mesurar",
    "mesuraste": "mesurar",
    "mesurastes": "mesurar",
    "mesurava": "mesurar",
    "mesuravam": "mesurar",
    "mesuravas": "mesurar",
    "mesure": "mesurar",
    "mesurei": "mesurar",
    "mesureira": "mesureiro",
    "mesureiras": "mesureiro",
    "mesureiros": "mesureiro",
    "mesureis": "mesurar",
    "mesurem": "mesurar",
    "mesuremo": "mesurar",
    "mesuremos": "mesurar",
    "mesures": "mesurar",
    "mesurices": "mesurice",
    "mesuro": "mesurar",
    "mesurou": "mesurar",
    "mesurámo": "mesurar",
    "mesurámos": "mesurar",
    "mesuráramo": "mesurar",
    "mesuráramos": "mesurar",
    "mesuráreis": "mesurar",
    "mesurásseis": "mesurar",
    "mesurássemos": "mesurar",
    "mesurávamo": "mesurar",
    "mesurávamos": "mesurar",
    "mesuráveis": "mesurar",
    "mesária": "mesário",
    "mesárias": "mesário",
    "mesários": "mesário",
    "mesóclises": "mesóclise",
    "mesófitos": "mesófito",
    "mesófrios": "mesófrio",
    "mesómera": "mesómero",
    "mesómeras": "mesómero",
    "mesómeros": "mesómero",
    "mesónefros": "mesónefro",
    "mesões": "mesão",
    "meta": "meter",
    "metaboles": "metabole",
    "metabolismos": "metabolismo",
    "metabologias": "metabologia",
    "metabologistas": "metabologista",
    "metabólica": "metabólico",
    "metabólicas": "metabólico",
    "metabólicos": "metabólico",
    "metacarpiana": "metacarpiano",
    "metacarpianas": "metacarpiano",
    "metacarpianos": "metacarpiano",
    "metacarpos": "metacarpo",
    "metacentros": "metacentro",
    "metacismos": "metacismo",
    "metacromasias": "metacromasia",
    "metacromatismos": "metacromatismo",
    "metacromática": "metacromático",
    "metacromáticas": "metacromático",
    "metacromáticos": "metacromático",
    "metacronismos": "metacronismo",
    "metacárpica": "metacárpico",
    "metacárpicas": "metacárpico",
    "metacárpicos": "metacárpico",
    "metacárpios": "metacárpio",
    "metade": "dois",
    "metades": "metade",
    "metadonas": "metadona",
    "metafalanges": "metafalange",
    "metafisica": "metafisicar",
    "metafisicada": "metafisicar",
    "metafisicadas": "metafisicar",
    "metafisicado": "metafisicar",
    "metafisicados": "metafisicar",
    "metafisicai": "metafisicar",
    "metafisicais": "metafisicar",
    "metafisicam": "metafisicar",
    "metafisicamo": "metafisicar",
    "metafisicamos": "metafisicar",
    "metafisicando": "metafisicar",
    "metafisicara": "metafisicar",
    "metafisicaram": "metafisicar",
    "metafisicaras": "metafisicar",
    "metafisicarde": "metafisicar",
    "metafisicardes": "metafisicar",
    "metafisicare": "metafisicar",
    "metafisicarei": "metafisicar",
    "metafisicareis": "metafisicar",
    "metafisicarem": "metafisicar",
    "metafisicaremos": "metafisicar",
    "metafisicares": "metafisicar",
    "metafisicaria": "metafisicar",
    "metafisicariam": "metafisicar",
    "metafisicarias": "metafisicar",
    "metafisicarmo": "metafisicar",
    "metafisicarmos": "metafisicar",
    "metafisicará": "metafisicar",
    "metafisicarás": "metafisicar",
    "metafisicarão": "metafisicar",
    "metafisicaríamos": "metafisicar",
    "metafisicaríeis": "metafisicar",
    "metafisicas": "metafisicar",
    "metafisicasse": "metafisicar",
    "metafisicassem": "metafisicar",
    "metafisicasses": "metafisicar",
    "metafisicaste": "metafisicar",
    "metafisicastes": "metafisicar",
    "metafisicava": "metafisicar",
    "metafisicavam": "metafisicar",
    "metafisicavas": "metafisicar",
    "metafisicismos": "metafisicismo",
    "metafisico": "metafisicar",
    "metafisicou": "metafisicar",
    "metafisicá": "metafisicar",
    "metafisicámo": "metafisicar",
    "metafisicámos": "metafisicar",
    "metafisicáramo": "metafisicar",
    "metafisicáramos": "metafisicar",
    "metafisicárei": "metafisicar",
    "metafisicáreis": "metafisicar",
    "metafisicásseis": "metafisicar",
    "metafisicássemos": "metafisicar",
    "metafisicávamo": "metafisicar",
    "metafisicávamos": "metafisicar",
    "metafisicávei": "metafisicar",
    "metafisicáveis": "metafisicar",
    "metafisique": "metafisicar",
    "metafisiquei": "metafisicar",
    "metafisiqueis": "metafisicar",
    "metafisiquem": "metafisicar",
    "metafisiquemo": "metafisicar",
    "metafisiquemos": "metafisicar",
    "metafisiques": "metafisicar",
    "metafonias": "metafonia",
    "metaforismos": "metaforismo",
    "metaforiza": "metaforizar",
    "metaforizada": "metaforizar",
    "metaforizadas": "metaforizar",
    "metaforizado": "metaforizar",
    "metaforizados": "metaforizar",
    "metaforizai": "metaforizar",
    "metaforizais": "metaforizar",
    "metaforizam": "metaforizar",
    "metaforizamo": "metaforizar",
    "metaforizamos": "metaforizar",
    "metaforizando": "metaforizar",
    "metaforizara": "metaforizar",
    "metaforizaram": "metaforizar",
    "metaforizaras": "metaforizar",
    "metaforizarde": "metaforizar",
    "metaforizardes": "metaforizar",
    "metaforizare": "metaforizar",
    "metaforizarei": "metaforizar",
    "metaforizareis": "metaforizar",
    "metaforizarem": "metaforizar",
    "metaforizaremos": "metaforizar",
    "metaforizares": "metaforizar",
    "metaforizaria": "metaforizar",
    "metaforizariam": "metaforizar",
    "metaforizarias": "metaforizar",
    "metaforizarmo": "metaforizar",
    "metaforizarmos": "metaforizar",
    "metaforizará": "metaforizar",
    "metaforizarás": "metaforizar",
    "metaforizarão": "metaforizar",
    "metaforizaríamos": "metaforizar",
    "metaforizaríeis": "metaforizar",
    "metaforizas": "metaforizar",
    "metaforizasse": "metaforizar",
    "metaforizassem": "metaforizar",
    "metaforizasses": "metaforizar",
    "metaforizaste": "metaforizar",
    "metaforizastes": "metaforizar",
    "metaforizava": "metaforizar",
    "metaforizavam": "metaforizar",
    "metaforizavas": "metaforizar",
    "metaforize": "metaforizar",
    "metaforizei": "metaforizar",
    "metaforizeis": "metaforizar",
    "metaforizem": "metaforizar",
    "metaforizemo": "metaforizar",
    "metaforizemos": "metaforizar",
    "metaforizes": "metaforizar",
    "metaforizo": "metaforizar",
    "metaforizou": "metaforizar",
    "metaforizá": "metaforizar",
    "metaforizámo": "metaforizar",
    "metaforizámos": "metaforizar",
    "metaforizáramo": "metaforizar",
    "metaforizáramos": "metaforizar",
    "metaforizárei": "metaforizar",
    "metaforizáreis": "metaforizar",
    "metaforizásseis": "metaforizar",
    "metaforizássemos": "metaforizar",
    "metaforizávamo": "metaforizar",
    "metaforizávamos": "metaforizar",
    "metaforizávei": "metaforizar",
    "metaforizáveis": "metaforizável",
    "metafrastas": "metafrasta",
    "metafrástica": "metafrástico",
    "metafrásticas": "metafrástico",
    "metafrásticos": "metafrástico",
    "metafísica": "metafísico",
    "metafísicas": "metafísico",
    "metafísicos": "metafísico",
    "metafónica": "metafónico",
    "metafónicas": "metafónico",
    "metafónicos": "metafónico",
    "metafórica": "metafórico",
    "metafóricas": "metafórico",
    "metafóricos": "metafórico",
    "metagaláxias": "metagaláxia",
    "metageometrias": "metageometria",
    "metagoges": "metagoge",
    "metagramas": "metagrama",
    "metagéneses": "metagénese",
    "metagógica": "metagógico",
    "metagógicas": "metagógico",
    "metagógicos": "metagógico",
    "metais": "meter",
    "metaldeídos": "metaldeído",
    "metalepses": "metalepse",
    "metalescentes": "metalescente",
    "metalescências": "metalescência",
    "metalicidades": "metalicidade",
    "metalificações": "metalificação",
    "metaliformes": "metaliforme",
    "metalina": "metalino",
    "metalinas": "metalino",
    "metalinguagens": "metalinguagem",
    "metalinguística": "metalinguístico",
    "metalinguísticas": "metalinguístico",
    "metalinguísticos": "metalinguístico",
    "metalinos": "metalino",
    "metalismos": "metalismo",
    "metalistas": "metalista",
    "metaliza": "metalizar",
    "metalizada": "metalizar",
    "metalizadas": "metalizar",
    "metalizado": "metalizar",
    "metalizados": "metalizar",
    "metalizai": "metalizar",
    "metalizais": "metalizar",
    "metalizam": "metalizar",
    "metalizamo": "metalizar",
    "metalizamos": "metalizar",
    "metalizando": "metalizar",
    "metalizara": "metalizar",
    "metalizaram": "metalizar",
    "metalizaras": "metalizar",
    "metalizarde": "metalizar",
    "metalizardes": "metalizar",
    "metalizare": "metalizar",
    "metalizarei": "metalizar",
    "metalizareis": "metalizar",
    "metalizarem": "metalizar",
    "metalizaremos": "metalizar",
    "metalizares": "metalizar",
    "metalizaria": "metalizar",
    "metalizariam": "metalizar",
    "metalizarias": "metalizar",
    "metalizarmo": "metalizar",
    "metalizarmos": "metalizar",
    "metalizará": "metalizar",
    "metalizarás": "metalizar",
    "metalizarão": "metalizar",
    "metalizaríamos": "metalizar",
    "metalizaríeis": "metalizar",
    "metalizas": "metalizar",
    "metalizasse": "metalizar",
    "metalizassem": "metalizar",
    "metalizasses": "metalizar",
    "metalizaste": "metalizar",
    "metalizastes": "metalizar",
    "metalizava": "metalizar",
    "metalizavam": "metalizar",
    "metalizavas": "metalizar",
    "metalizações": "metalização",
    "metalize": "metalizar",
    "metalizei": "metalizar",
    "metalizeis": "metalizar",
    "metalizem": "metalizar",
    "metalizemo": "metalizar",
    "metalizemos": "metalizar",
    "metalizes": "metalizar",
    "metalizo": "metalizar",
    "metalizou": "metalizar",
    "metalizá": "metalizar",
    "metalizámo": "metalizar",
    "metalizámos": "metalizar",
    "metalizáramo": "metalizar",
    "metalizáramos": "metalizar",
    "metalizárei": "metalizar",
    "metalizáreis": "metalizar",
    "metalizásseis": "metalizar",
    "metalizássemos": "metalizar",
    "metalizávamo": "metalizar",
    "metalizávamos": "metalizar",
    "metalizávei": "metalizar",
    "metalizáveis": "metalizável",
    "metalocromias": "metalocromia",
    "metalogenias": "metalogenia",
    "metalografias": "metalografia",
    "metalográfica": "metalográfico",
    "metalográficas": "metalográfico",
    "metalográficos": "metalográfico",
    "metalologias": "metalologia",
    "metalologistas": "metalologista",
    "metalológica": "metalológico",
    "metalológicas": "metalológico",
    "metalológicos": "metalológico",
    "metalomecânica": "metalomecânico",
    "metalomecânicas": "metalomecânico",
    "metalomecânicos": "metalomecânico",
    "metaloplastias": "metaloplastia",
    "metaloquímica": "metaloquímico",
    "metaloquímicas": "metaloquímico",
    "metaloquímicos": "metaloquímico",
    "metaloterapias": "metaloterapia",
    "metalurgias": "metalurgia",
    "metalurgistas": "metalurgista",
    "metaléptica": "metaléptico",
    "metalépticas": "metaléptico",
    "metalépticos": "metaléptico",
    "metalífera": "metalífero",
    "metalíferas": "metalífero",
    "metalíferos": "metalífero",
    "metalógicas": "metalógica",
    "metalógrafa": "metalógrafo",
    "metalógrafas": "metalógrafo",
    "metalógrafos": "metalógrafo",
    "metalóides": "metalóide",
    "metalúrgica": "metalúrgico",
    "metalúrgicas": "metalúrgico",
    "metalúrgicos": "metalúrgico",
    "metam": "meter",
    "metamatemáticas": "metamatemática",
    "metamerias": "metameria",
    "metamerizações": "metamerização",
    "metamo": "meter",
    "metamorfismos": "metamorfismo",
    "metamorfopsias": "metamorfopsia",
    "metamorfoseada": "metamorfosear",
    "metamorfoseadas": "metamorfosear",
    "metamorfoseado": "metamorfosear",
    "metamorfoseados": "metamorfosear",
    "metamorfoseai": "metamorfosear",
    "metamorfoseais": "metamorfosear",
    "metamorfoseamo": "metamorfosear",
    "metamorfoseamos": "metamorfosear",
    "metamorfoseando": "metamorfosear",
    "metamorfoseara": "metamorfosear",
    "metamorfosearam": "metamorfosear",
    "metamorfosearas": "metamorfosear",
    "metamorfosearde": "metamorfosear",
    "metamorfoseardes": "metamorfosear",
    "metamorfoseare": "metamorfosear",
    "metamorfosearei": "metamorfosear",
    "metamorfoseareis": "metamorfosear",
    "metamorfosearem": "metamorfosear",
    "metamorfosearemos": "metamorfosear",
    "metamorfoseares": "metamorfosear",
    "metamorfosearia": "metamorfosear",
    "metamorfoseariam": "metamorfosear",
    "metamorfosearias": "metamorfosear",
    "metamorfosearmo": "metamorfosear",
    "metamorfosearmos": "metamorfosear",
    "metamorfoseará": "metamorfosear",
    "metamorfosearás": "metamorfosear",
    "metamorfosearão": "metamorfosear",
    "metamorfosearíamos": "metamorfosear",
    "metamorfosearíeis": "metamorfosear",
    "metamorfoseasse": "metamorfosear",
    "metamorfoseassem": "metamorfosear",
    "metamorfoseasses": "metamorfosear",
    "metamorfoseaste": "metamorfosear",
    "metamorfoseastes": "metamorfosear",
    "metamorfoseava": "metamorfosear",
    "metamorfoseavam": "metamorfosear",
    "metamorfoseavas": "metamorfosear",
    "metamorfoseei": "metamorfosear",
    "metamorfoseeis": "metamorfosear",
    "metamorfoseemo": "metamorfosear",
    "metamorfoseemos": "metamorfosear",
    "metamorfoseia": "metamorfosear",
    "metamorfoseiam": "metamorfosear",
    "metamorfoseias": "metamorfosear",
    "metamorfoseie": "metamorfosear",
    "metamorfoseiem": "metamorfosear",
    "metamorfoseies": "metamorfosear",
    "metamorfoseio": "metamorfosear",
    "metamorfoseou": "metamorfosear",
    "metamorfoses": "metamorfose",
    "metamorfoseá": "metamorfosear",
    "metamorfoseámo": "metamorfosear",
    "metamorfoseámos": "metamorfosear",
    "metamorfoseáramo": "metamorfosear",
    "metamorfoseáramos": "metamorfosear",
    "metamorfoseárei": "metamorfosear",
    "metamorfoseáreis": "metamorfosear",
    "metamorfoseásseis": "metamorfosear",
    "metamorfoseássemos": "metamorfosear",
    "metamorfoseávamo": "metamorfosear",
    "metamorfoseávamos": "metamorfosear",
    "metamorfoseávei": "metamorfosear",
    "metamorfoseáveis": "metamorfosear",
    "metamos": "meter",
    "metamérica": "metamérico",
    "metaméricas": "metamérico",
    "metaméricos": "metamérico",
    "metamórfica": "metamórfico",
    "metamórficas": "metamórfico",
    "metamórficos": "metamórfico",
    "metanas": "metana",
    "metanefros": "metanefro",
    "metanefrídios": "metanefrídio",
    "metanos": "metano",
    "metanóias": "metanóia",
    "metanóis": "metanol",
    "metapagias": "metapagia",
    "metaplasias": "metaplasia",
    "metaplasmas": "metaplasma",
    "metaplasmos": "metaplasmo",
    "metaplástica": "metaplástico",
    "metaplásticas": "metaplástico",
    "metaplásticos": "metaplástico",
    "metapsicologias": "metapsicologia",
    "metapsíquicas": "metapsíquica",
    "metas": "meter",
    "metassedimentos": "metassedimento",
    "metassomatismos": "metassomatismo",
    "metassomatoses": "metassomatose",
    "metassíncrises": "metassíncrise",
    "metastática": "metastático",
    "metastáticas": "metastático",
    "metastáticos": "metastático",
    "metastáveis": "metastável",
    "metastómios": "metastómio",
    "metatarsos": "metatarso",
    "metatipias": "metatipia",
    "metatársica": "metatársico",
    "metatársicas": "metatársico",
    "metatársicos": "metatársico",
    "metatérios": "metatério",
    "metazoários": "metazoário",
    "metazóica": "metazóico",
    "metazóicas": "metazóico",
    "metazóicos": "metazóico",
    "mete": "meter",
    "metecos": "meteco",
    "metediça": "metediço",
    "metediças": "metediço",
    "metediços": "metediço",
    "metedora": "metedor",
    "metedoras": "metedor",
    "metedores": "metedor",
    "metei": "meter",
    "meteis": "meter",
    "metem": "meter",
    "metemo": "meter",
    "metemos": "meter",
    "metempsicoses": "metempsicose",
    "metencéfalos": "metencéfalo",
    "metendo": "meter",
    "meteorismos": "meteorismo",
    "meteoritos": "meteorito",
    "meteoriza": "meteorizar",
    "meteorizada": "meteorizar",
    "meteorizadas": "meteorizar",
    "meteorizado": "meteorizar",
    "meteorizados": "meteorizar",
    "meteorizai": "meteorizar",
    "meteorizais": "meteorizar",
    "meteorizam": "meteorizar",
    "meteorizamo": "meteorizar",
    "meteorizamos": "meteorizar",
    "meteorizando": "meteorizar",
    "meteorizara": "meteorizar",
    "meteorizaram": "meteorizar",
    "meteorizaras": "meteorizar",
    "meteorizarde": "meteorizar",
    "meteorizardes": "meteorizar",
    "meteorizare": "meteorizar",
    "meteorizarei": "meteorizar",
    "meteorizareis": "meteorizar",
    "meteorizarem": "meteorizar",
    "meteorizaremos": "meteorizar",
    "meteorizares": "meteorizar",
    "meteorizaria": "meteorizar",
    "meteorizariam": "meteorizar",
    "meteorizarias": "meteorizar",
    "meteorizarmo": "meteorizar",
    "meteorizarmos": "meteorizar",
    "meteorizará": "meteorizar",
    "meteorizarás": "meteorizar",
    "meteorizarão": "meteorizar",
    "meteorizaríamos": "meteorizar",
    "meteorizaríeis": "meteorizar",
    "meteorizas": "meteorizar",
    "meteorizasse": "meteorizar",
    "meteorizassem": "meteorizar",
    "meteorizasses": "meteorizar",
    "meteorizaste": "meteorizar",
    "meteorizastes": "meteorizar",
    "meteorizava": "meteorizar",
    "meteorizavam": "meteorizar",
    "meteorizavas": "meteorizar",
    "meteorizações": "meteorização",
    "meteorize": "meteorizar",
    "meteorizei": "meteorizar",
    "meteorizeis": "meteorizar",
    "meteorizem": "meteorizar",
    "meteorizemo": "meteorizar",
    "meteorizemos": "meteorizar",
    "meteorizes": "meteorizar",
    "meteorizo": "meteorizar",
    "meteorizou": "meteorizar",
    "meteorizá": "meteorizar",
    "meteorizámo": "meteorizar",
    "meteorizámos": "meteorizar",
    "meteorizáramo": "meteorizar",
    "meteorizáramos": "meteorizar",
    "meteorizárei": "meteorizar",
    "meteorizáreis": "meteorizar",
    "meteorizásseis": "meteorizar",
    "meteorizássemos": "meteorizar",
    "meteorizávamo": "meteorizar",
    "meteorizávamos": "meteorizar",
    "meteorizávei": "meteorizar",
    "meteorizáveis": "meteorizar",
    "meteorografias": "meteorografia",
    "meteorográfica": "meteorográfico",
    "meteorográficas": "meteorográfico",
    "meteorográficos": "meteorográfico",
    "meteorologias": "meteorologia",
    "meteorologistas": "meteorologista",
    "meteorológica": "meteorológico",
    "meteorológicas": "meteorológico",
    "meteorológicos": "meteorológico",
    "meteoromancias": "meteoromancia",
    "meteoromantes": "meteoromante",
    "meteoromântica": "meteoromântico",
    "meteoromânticas": "meteoromântico",
    "meteoromânticos": "meteoromântico",
    "meteoronomias": "meteoronomia",
    "meteoronómica": "meteoronómico",
    "meteoronómicas": "meteoronómico",
    "meteoronómicos": "meteoronómico",
    "meteoros": "meteoro",
    "meteoroscópios": "meteoroscópio",
    "meteorosópica": "meteorosópico",
    "meteorosópicas": "meteorosópico",
    "meteorosópicos": "meteorosópico",
    "meteorólitos": "meteorólito",
    "metera": "meter",
    "meteram": "meter",
    "meteras": "meter",
    "meterde": "meter",
    "meterdes": "meter",
    "metere": "meter",
    "meterei": "meter",
    "metereis": "meter",
    "meterem": "meter",
    "meteremos": "meter",
    "meteres": "meter",
    "meteria": "meter",
    "meteriam": "meter",
    "meterias": "meter",
    "metermo": "meter",
    "metermos": "meter",
    "meterá": "meter",
    "meterás": "meter",
    "meterão": "meter",
    "meteríamos": "meter",
    "meteríeis": "meter",
    "metes": "meter",
    "metesse": "meter",
    "metessem": "meter",
    "metesses": "meter",
    "meteste": "meter",
    "metestes": "meter",
    "meteu": "meter",
    "meteórica": "meteórico",
    "meteóricas": "meteórico",
    "meteóricos": "meteórico",
    "meti": "meter",
    "metia": "meter",
    "metiam": "meter",
    "metias": "meter",
    "meticais": "metical",
    "meticulosa": "meticuloso",
    "meticulosas": "meticuloso",
    "meticulosidades": "meticulosidade",
    "meticulosos": "meticuloso",
    "metida": "metido",
    "metidas": "metido",
    "metido": "meter",
    "metidos": "metido",
    "metilenos": "metileno",
    "metilos": "metilo",
    "metins": "metim",
    "meto": "meter",
    "metodismos": "metodismo",
    "metodistas": "metodista",
    "metodiza": "metodizar",
    "metodizada": "metodizar",
    "metodizadas": "metodizar",
    "metodizado": "metodizar",
    "metodizados": "metodizar",
    "metodizai": "metodizar",
    "metodizais": "metodizar",
    "metodizam": "metodizar",
    "metodizamo": "metodizar",
    "metodizamos": "metodizar",
    "metodizando": "metodizar",
    "metodizara": "metodizar",
    "metodizaram": "metodizar",
    "metodizaras": "metodizar",
    "metodizarde": "metodizar",
    "metodizardes": "metodizar",
    "metodizare": "metodizar",
    "metodizarei": "metodizar",
    "metodizareis": "metodizar",
    "metodizarem": "metodizar",
    "metodizaremos": "metodizar",
    "metodizares": "metodizar",
    "metodizaria": "metodizar",
    "metodizariam": "metodizar",
    "metodizarias": "metodizar",
    "metodizarmo": "metodizar",
    "metodizarmos": "metodizar",
    "metodizará": "metodizar",
    "metodizarás": "metodizar",
    "metodizarão": "metodizar",
    "metodizaríamos": "metodizar",
    "metodizaríeis": "metodizar",
    "metodizas": "metodizar",
    "metodizasse": "metodizar",
    "metodizassem": "metodizar",
    "metodizasses": "metodizar",
    "metodizaste": "metodizar",
    "metodizastes": "metodizar",
    "metodizava": "metodizar",
    "metodizavam": "metodizar",
    "metodizavas": "metodizar",
    "metodizações": "metodização",
    "metodize": "metodizar",
    "metodizei": "metodizar",
    "metodizeis": "metodizar",
    "metodizem": "metodizar",
    "metodizemo": "metodizar",
    "metodizemos": "metodizar",
    "metodizes": "metodizar",
    "metodizo": "metodizar",
    "metodizou": "metodizar",
    "metodizá": "metodizar",
    "metodizámo": "metodizar",
    "metodizámos": "metodizar",
    "metodizáramo": "metodizar",
    "metodizáramos": "metodizar",
    "metodizárei": "metodizar",
    "metodizáreis": "metodizar",
    "metodizásseis": "metodizar",
    "metodizássemos": "metodizar",
    "metodizávamo": "metodizar",
    "metodizávamos": "metodizar",
    "metodizávei": "metodizar",
    "metodizáveis": "metodizar",
    "metodologias": "metodologia",
    "metodologistas": "metodologista",
    "metodológica": "metodológico",
    "metodológicas": "metodológico",
    "metodológicos": "metodológico",
    "metodóloga": "metodólogo",
    "metodólogas": "metodólogo",
    "metodólogos": "metodólogo",
    "metomanias": "metomania",
    "metomaníaca": "metomaníaco",
    "metomaníacas": "metomaníaco",
    "metomaníacos": "metomaníaco",
    "metonomásias": "metonomásia",
    "metonomásica": "metonomásico",
    "metonomásicas": "metonomásico",
    "metonomásicos": "metonomásico",
    "metonímias": "metonímia",
    "metonímica": "metonímico",
    "metonímicas": "metonímico",
    "metonímicos": "metonímico",
    "metoposcopias": "metoposcopia",
    "metopóscopos": "metopóscopo",
    "metragens": "metragem",
    "metralgias": "metralgia",
    "metralha": "metralhar",
    "metralhada": "metralhar",
    "metralhadas": "metralhar",
    "metralhado": "metralhar",
    "metralhadora": "metralhador",
    "metralhadoras": "metralhadora",
    "metralhadores": "metralhador",
    "metralhados": "metralhar",
    "metralhai": "metralhar",
    "metralhais": "metralhar",
    "metralham": "metralhar",
    "metralhamo": "metralhar",
    "metralhamos": "metralhar",
    "metralhando": "metralhar",
    "metralhara": "metralhar",
    "metralharam": "metralhar",
    "metralharas": "metralhar",
    "metralharde": "metralhar",
    "metralhardes": "metralhar",
    "metralhare": "metralhar",
    "metralharei": "metralhar",
    "metralhareis": "metralhar",
    "metralharem": "metralhar",
    "metralharemos": "metralhar",
    "metralhares": "metralhar",
    "metralharia": "metralhar",
    "metralhariam": "metralhar",
    "metralharias": "metralhar",
    "metralharmo": "metralhar",
    "metralharmos": "metralhar",
    "metralhará": "metralhar",
    "metralharás": "metralhar",
    "metralharão": "metralhar",
    "metralharíamos": "metralhar",
    "metralharíeis": "metralhar",
    "metralhas": "metralhar",
    "metralhasse": "metralhar",
    "metralhassem": "metralhar",
    "metralhasses": "metralhar",
    "metralhaste": "metralhar",
    "metralhastes": "metralhar",
    "metralhava": "metralhar",
    "metralhavam": "metralhar",
    "metralhavas": "metralhar",
    "metralhe": "metralhar",
    "metralhei": "metralhar",
    "metralheis": "metralhar",
    "metralhem": "metralhar",
    "metralhemo": "metralhar",
    "metralhemos": "metralhar",
    "metralhes": "metralhar",
    "metralho": "metralhar",
    "metralhou": "metralhar",
    "metralhá": "metralhar",
    "metralhámo": "metralhar",
    "metralhámos": "metralhar",
    "metralháramo": "metralhar",
    "metralháramos": "metralhar",
    "metralhárei": "metralhar",
    "metralháreis": "metralhar",
    "metralhásseis": "metralhar",
    "metralhássemos": "metralhar",
    "metralhávamo": "metralhar",
    "metralhávamos": "metralhar",
    "metralhávei": "metralhar",
    "metralháveis": "metralhar",
    "metrifica": "metrificar",
    "metrificada": "metrificar",
    "metrificadas": "metrificar",
    "metrificado": "metrificar",
    "metrificadora": "metrificador",
    "metrificadoras": "metrificador",
    "metrificadores": "metrificador",
    "metrificados": "metrificar",
    "metrificai": "metrificar",
    "metrificais": "metrificar",
    "metrificam": "metrificar",
    "metrificamo": "metrificar",
    "metrificamos": "metrificar",
    "metrificando": "metrificar",
    "metrificara": "metrificar",
    "metrificaram": "metrificar",
    "metrificaras": "metrificar",
    "metrificarde": "metrificar",
    "metrificardes": "metrificar",
    "metrificare": "metrificar",
    "metrificarei": "metrificar",
    "metrificareis": "metrificar",
    "metrificarem": "metrificar",
    "metrificaremos": "metrificar",
    "metrificares": "metrificar",
    "metrificaria": "metrificar",
    "metrificariam": "metrificar",
    "metrificarias": "metrificar",
    "metrificarmo": "metrificar",
    "metrificarmos": "metrificar",
    "metrificará": "metrificar",
    "metrificarás": "metrificar",
    "metrificarão": "metrificar",
    "metrificaríamos": "metrificar",
    "metrificaríeis": "metrificar",
    "metrificas": "metrificar",
    "metrificasse": "metrificar",
    "metrificassem": "metrificar",
    "metrificasses": "metrificar",
    "metrificaste": "metrificar",
    "metrificastes": "metrificar",
    "metrificava": "metrificar",
    "metrificavam": "metrificar",
    "metrificavas": "metrificar",
    "metrificações": "metrificação",
    "metrifico": "metrificar",
    "metrificou": "metrificar",
    "metrificá": "metrificar",
    "metrificámo": "metrificar",
    "metrificámos": "metrificar",
    "metrificáramo": "metrificar",
    "metrificáramos": "metrificar",
    "metrificárei": "metrificar",
    "metrificáreis": "metrificar",
    "metrificásseis": "metrificar",
    "metrificássemos": "metrificar",
    "metrificávamo": "metrificar",
    "metrificávamos": "metrificar",
    "metrificávei": "metrificar",
    "metrificáveis": "metrificar",
    "metrifique": "metrificar",
    "metrifiquei": "metrificar",
    "metrifiqueis": "metrificar",
    "metrifiquem": "metrificar",
    "metrifiquemo": "metrificar",
    "metrifiquemos": "metrificar",
    "metrifiques": "metrificar",
    "metrites": "metrite",
    "metroceles": "metrocele",
    "metrografias": "metrografia",
    "metrográfica": "metrográfico",
    "metrográficas": "metrográfico",
    "metrográficos": "metrográfico",
    "metrologias": "metrologia",
    "metrologistas": "metrologista",
    "metrológica": "metrológico",
    "metrológicas": "metrológico",
    "metrológicos": "metrológico",
    "metromanias": "metromania",
    "metromaníaca": "metromaníaco",
    "metromaníacas": "metromaníaco",
    "metromaníacos": "metromaníaco",
    "metronómica": "metronómico",
    "metronómicas": "metronómico",
    "metronómicos": "metronómico",
    "metropatias": "metropatia",
    "metropolitana": "metropolitano",
    "metropolitanas": "metropolitano",
    "metropolitanos": "metropolitano",
    "metropolitas": "metropolita",
    "metropolítica": "metropolítico",
    "metropolíticas": "metropolítico",
    "metropolíticos": "metropolítico",
    "metrorragias": "metrorragia",
    "metrorreias": "metrorreia",
    "metrorrágica": "metrorrágico",
    "metrorrágicas": "metrorrágico",
    "metrorrágicos": "metrorrágico",
    "metros": "metro",
    "metrotomias": "metrotomia",
    "metrálgica": "metrálgico",
    "metrálgicas": "metrálgico",
    "metrálgicos": "metrálgico",
    "metrógrafa": "metrógrafo",
    "metrógrafas": "metrógrafo",
    "metrógrafos": "metrógrafo",
    "metrómana": "metrómano",
    "metrómanas": "metrómano",
    "metrómanos": "metrómano",
    "metrómetros": "metrómetro",
    "metrónomos": "metrónomo",
    "metrópoles": "metrópole",
    "metuenda": "metuendo",
    "metuendas": "metuendo",
    "metuendos": "metuendo",
    "metáfases": "metáfase",
    "metáfises": "metáfise",
    "metáforas": "metáfora",
    "metáfrases": "metáfrase",
    "metálica": "metálico",
    "metálicas": "metálico",
    "metálicos": "metálico",
    "metástases": "metástase",
    "metáteses": "metátese",
    "metátomos": "metátomo",
    "metâmera": "metâmero",
    "metâmeras": "metâmero",
    "metâmeros": "metâmero",
    "metê": "meter",
    "metêramo": "meter",
    "metêramos": "meter",
    "metêrei": "meter",
    "metêreis": "meter",
    "metêsseis": "meter",
    "metêssemos": "meter",
    "metíamo": "meter",
    "metíamos": "meter",
    "metíei": "meter",
    "metíeis": "meter",
    "metílica": "metílico",
    "metílicas": "metílico",
    "metílicos": "metílico",
    "metódica": "metódico",
    "metódicas": "metódico",
    "metódicos": "metódico",
    "metónica": "metónico",
    "metónicas": "metónico",
    "metónicos": "metónico",
    "meus": "meu",
    "mexa": "mexer",
    "mexais": "mexer",
    "mexam": "mexer",
    "mexamo": "mexer",
    "mexamos": "mexer",
    "mexas": "mexer",
    "mexe": "mexer",
    "mexedelas": "mexedela",
    "mexediça": "mexediço",
    "mexediças": "mexediço",
    "mexediços": "mexediço",
    "mexedora": "mexedor",
    "mexedoras": "mexedor",
    "mexedores": "mexedor",
    "mexeduras": "mexedura",
    "mexei": "mexer",
    "mexeis": "mexer",
    "mexelha": "mexelhar",
    "mexelhada": "mexelhar",
    "mexelhadas": "mexelhar",
    "mexelhado": "mexelhar",
    "mexelhados": "mexelhar",
    "mexelhai": "mexelhar",
    "mexelhais": "mexelhar",
    "mexelham": "mexelhar",
    "mexelhamo": "mexelhar",
    "mexelhamos": "mexelhar",
    "mexelhando": "mexelhar",
    "mexelhara": "mexelhar",
    "mexelharam": "mexelhar",
    "mexelharas": "mexelhar",
    "mexelhardes": "mexelhar",
    "mexelharei": "mexelhar",
    "mexelhareis": "mexelhar",
    "mexelharem": "mexelhar",
    "mexelharemos": "mexelhar",
    "mexelhares": "mexelhar",
    "mexelharia": "mexelhar",
    "mexelhariam": "mexelhar",
    "mexelharias": "mexelhar",
    "mexelharmo": "mexelhar",
    "mexelharmos": "mexelhar",
    "mexelhará": "mexelhar",
    "mexelharás": "mexelhar",
    "mexelharão": "mexelhar",
    "mexelharíamos": "mexelhar",
    "mexelharíeis": "mexelhar",
    "mexelhas": "mexelhar",
    "mexelhasse": "mexelhar",
    "mexelhassem": "mexelhar",
    "mexelhasses": "mexelhar",
    "mexelhaste": "mexelhar",
    "mexelhastes": "mexelhar",
    "mexelhava": "mexelhar",
    "mexelhavam": "mexelhar",
    "mexelhavas": "mexelhar",
    "mexelhe": "mexelhar",
    "mexelhei": "mexelhar",
    "mexelheis": "mexelhar",
    "mexelhem": "mexelhar",
    "mexelhemo": "mexelhar",
    "mexelhemos": "mexelhar",
    "mexelhes": "mexelhar",
    "mexelho": "mexelhar",
    "mexelhona": "mexelhão",
    "mexelhonas": "mexelhão",
    "mexelhou": "mexelhar",
    "mexelhámo": "mexelhar",
    "mexelhámos": "mexelhar",
    "mexelháramo": "mexelhar",
    "mexelháramos": "mexelhar",
    "mexelháreis": "mexelhar",
    "mexelhásseis": "mexelhar",
    "mexelhássemos": "mexelhar",
    "mexelhávamo": "mexelhar",
    "mexelhávamos": "mexelhar",
    "mexelháveis": "mexelhar",
    "mexelhões": "mexelhão",
    "mexem": "mexer",
    "mexemo": "mexer",
    "mexemos": "mexer",
    "mexendo": "mexer",
    "mexera": "mexer",
    "mexeram": "mexer",
    "mexeras": "mexer",
    "mexerde": "mexer",
    "mexerdes": "mexer",
    "mexere": "mexer",
    "mexerei": "mexer",
    "mexereis": "mexer",
    "mexerem": "mexer",
    "mexeremos": "mexer",
    "mexeres": "mexer",
    "mexeria": "mexer",
    "mexeriam": "mexer",
    "mexerias": "mexer",
    "mexerica": "mexericar",
    "mexericada": "mexericar",
    "mexericadas": "mexericar",
    "mexericado": "mexericar",
    "mexericados": "mexericar",
    "mexericai": "mexericar",
    "mexericais": "mexericar",
    "mexericam": "mexericar",
    "mexericamo": "mexericar",
    "mexericamos": "mexericar",
    "mexericando": "mexericar",
    "mexericara": "mexericar",
    "mexericaram": "mexericar",
    "mexericaras": "mexericar",
    "mexericarde": "mexericar",
    "mexericardes": "mexericar",
    "mexericare": "mexericar",
    "mexericarei": "mexericar",
    "mexericareis": "mexericar",
    "mexericarem": "mexericar",
    "mexericaremos": "mexericar",
    "mexericares": "mexericar",
    "mexericaria": "mexericar",
    "mexericariam": "mexericar",
    "mexericarias": "mexericar",
    "mexericarmo": "mexericar",
    "mexericarmos": "mexericar",
    "mexericará": "mexericar",
    "mexericarás": "mexericar",
    "mexericarão": "mexericar",
    "mexericaríamos": "mexericar",
    "mexericaríeis": "mexericar",
    "mexericas": "mexericar",
    "mexericasse": "mexericar",
    "mexericassem": "mexericar",
    "mexericasses": "mexericar",
    "mexericaste": "mexericar",
    "mexericastes": "mexericar",
    "mexericava": "mexericar",
    "mexericavam": "mexericar",
    "mexericavas": "mexericar",
    "mexerico": "mexericar",
    "mexericos": "mexerico",
    "mexericou": "mexericar",
    "mexericá": "mexericar",
    "mexericámo": "mexericar",
    "mexericámos": "mexericar",
    "mexericáramo": "mexericar",
    "mexericáramos": "mexericar",
    "mexericárei": "mexericar",
    "mexericáreis": "mexericar",
    "mexericásseis": "mexericar",
    "mexericássemos": "mexericar",
    "mexericávamo": "mexericar",
    "mexericávamos": "mexericar",
    "mexericávei": "mexericar",
    "mexericáveis": "mexericar",
    "mexerique": "mexericar",
    "mexeriquei": "mexericar",
    "mexeriqueira": "mexeriqueiro",
    "mexeriqueiras": "mexeriqueiro",
    "mexeriqueiros": "mexeriqueiro",
    "mexeriqueis": "mexericar",
    "mexeriquem": "mexericar",
    "mexeriquemo": "mexericar",
    "mexeriquemos": "mexericar",
    "mexeriques": "mexericar",
    "mexermo": "mexer",
    "mexermos": "mexer",
    "mexeruca": "mexerucar",
    "mexerucada": "mexerucar",
    "mexerucadas": "mexerucar",
    "mexerucado": "mexerucar",
    "mexerucados": "mexerucar",
    "mexerucai": "mexerucar",
    "mexerucais": "mexerucar",
    "mexerucam": "mexerucar",
    "mexerucamo": "mexerucar",
    "mexerucamos": "mexerucar",
    "mexerucando": "mexerucar",
    "mexerucara": "mexerucar",
    "mexerucaram": "mexerucar",
    "mexerucaras": "mexerucar",
    "mexerucarde": "mexerucar",
    "mexerucardes": "mexerucar",
    "mexerucare": "mexerucar",
    "mexerucarei": "mexerucar",
    "mexerucareis": "mexerucar",
    "mexerucarem": "mexerucar",
    "mexerucaremos": "mexerucar",
    "mexerucares": "mexerucar",
    "mexerucaria": "mexerucar",
    "mexerucariam": "mexerucar",
    "mexerucarias": "mexerucar",
    "mexerucarmo": "mexerucar",
    "mexerucarmos": "mexerucar",
    "mexerucará": "mexerucar",
    "mexerucarás": "mexerucar",
    "mexerucarão": "mexerucar",
    "mexerucaríamos": "mexerucar",
    "mexerucaríeis": "mexerucar",
    "mexerucas": "mexerucar",
    "mexerucasse": "mexerucar",
    "mexerucassem": "mexerucar",
    "mexerucasses": "mexerucar",
    "mexerucaste": "mexerucar",
    "mexerucastes": "mexerucar",
    "mexerucava": "mexerucar",
    "mexerucavam": "mexerucar",
    "mexerucavas": "mexerucar",
    "mexeruco": "mexerucar",
    "mexerucou": "mexerucar",
    "mexerucá": "mexerucar",
    "mexerucámo": "mexerucar",
    "mexerucámos": "mexerucar",
    "mexerucáramo": "mexerucar",
    "mexerucáramos": "mexerucar",
    "mexerucárei": "mexerucar",
    "mexerucáreis": "mexerucar",
    "mexerucásseis": "mexerucar",
    "mexerucássemos": "mexerucar",
    "mexerucávamo": "mexerucar",
    "mexerucávamos": "mexerucar",
    "mexerucávei": "mexerucar",
    "mexerucáveis": "mexerucar",
    "mexerufadas": "mexerufada",
    "mexeruque": "mexerucar",
    "mexeruquei": "mexerucar",
    "mexeruqueis": "mexerucar",
    "mexeruquem": "mexerucar",
    "mexeruquemo": "mexerucar",
    "mexeruquemos": "mexerucar",
    "mexeruques": "mexerucar",
    "mexerá": "mexer",
    "mexerás": "mexer",
    "mexerão": "mexer",
    "mexeríamos": "mexer",
    "mexeríeis": "mexer",
    "mexes": "mexer",
    "mexesse": "mexer",
    "mexessem": "mexer",
    "mexesses": "mexer",
    "mexeste": "mexer",
    "mexestes": "mexer",
    "mexeu": "mexer",
    "mexi": "mexer",
    "mexia": "mexer",
    "mexiam": "mexer",
    "mexias": "mexer",
    "mexicana": "mexicano",
    "mexicanas": "mexicano",
    "mexicanos": "mexicano",
    "mexida": "mexido",
    "mexidas": "mexido",
    "mexidelas": "mexidela",
    "mexido": "mexer",
    "mexidos": "mexido",
    "mexidíssima": "mexido",
    "mexidíssimas": "mexido",
    "mexidíssimo": "mexido",
    "mexidíssimos": "mexido",
    "mexilhoeiras": "mexilhoeira",
    "mexilhões": "mexilhão",
    "mexo": "mexer",
    "mexoalhos": "mexoalho",
    "mexoeiras": "mexoeira",
    "mexonadas": "mexonada",
    "mexê": "mexer",
    "mexêramo": "mexer",
    "mexêramos": "mexer",
    "mexêrei": "mexer",
    "mexêreis": "mexer",
    "mexêsseis": "mexer",
    "mexêssemos": "mexer",
    "mexíamo": "mexer",
    "mexíamos": "mexer",
    "mexíei": "mexer",
    "mexíeis": "mexer",
    "mexões": "mexão",
    "mezenas": "mezena",
    "mezinha": "mezinhar",
    "mezinhada": "mezinhar",
    "mezinhadas": "mezinhar",
    "mezinhado": "mezinhar",
    "mezinhados": "mezinhar",
    "mezinhai": "mezinhar",
    "mezinhais": "mezinhar",
    "mezinham": "mezinhar",
    "mezinhamo": "mezinhar",
    "mezinhamos": "mezinhar",
    "mezinhando": "mezinhar",
    "mezinhara": "mezinhar",
    "mezinharam": "mezinhar",
    "mezinharas": "mezinhar",
    "mezinharde": "mezinhar",
    "mezinhardes": "mezinhar",
    "mezinhare": "mezinhar",
    "mezinharei": "mezinhar",
    "mezinhareis": "mezinhar",
    "mezinharem": "mezinhar",
    "mezinharemos": "mezinhar",
    "mezinhares": "mezinhar",
    "mezinharia": "mezinhar",
    "mezinhariam": "mezinhar",
    "mezinharias": "mezinhar",
    "mezinharmo": "mezinhar",
    "mezinharmos": "mezinhar",
    "mezinhará": "mezinhar",
    "mezinharás": "mezinhar",
    "mezinharão": "mezinhar",
    "mezinharíamos": "mezinhar",
    "mezinharíeis": "mezinhar",
    "mezinhas": "mezinhar",
    "mezinhasse": "mezinhar",
    "mezinhassem": "mezinhar",
    "mezinhasses": "mezinhar",
    "mezinhaste": "mezinhar",
    "mezinhastes": "mezinhar",
    "mezinhava": "mezinhar",
    "mezinhavam": "mezinhar",
    "mezinhavas": "mezinhar",
    "mezinhe": "mezinhar",
    "mezinhei": "mezinhar",
    "mezinheira": "mezinheiro",
    "mezinheiras": "mezinheiro",
    "mezinheiros": "mezinheiro",
    "mezinheis": "mezinhar",
    "mezinhem": "mezinhar",
    "mezinhemo": "mezinhar",
    "mezinhemos": "mezinhar",
    "mezinhes": "mezinhar",
    "mezinhices": "mezinhice",
    "mezinho": "mezinhar",
    "mezinhou": "mezinhar",
    "mezinhá": "mezinhar",
    "mezinhámo": "mezinhar",
    "mezinhámos": "mezinhar",
    "mezinháramo": "mezinhar",
    "mezinháramos": "mezinhar",
    "mezinhárei": "mezinhar",
    "mezinháreis": "mezinhar",
    "mezinhásseis": "mezinhar",
    "mezinhássemos": "mezinhar",
    "mezinhávamo": "mezinhar",
    "mezinhávamos": "mezinhar",
    "mezinhávei": "mezinhar",
    "mezinháveis": "mezinhar",
    "meá": "mear",
    "meámo": "mear",
    "meámos": "mear",
    "meáramo": "mear",
    "meáramos": "mear",
    "meárei": "mear",
    "meáreis": "mear",
    "meásseis": "mear",
    "meássemos": "mear",
    "meávamo": "mear",
    "meávamos": "mear",
    "meávei": "mear",
    "meáveis": "mear",
    "meândrica": "meândrico",
    "meândricas": "meândrico",
    "meândricos": "meândrico",
    "meã": "meão",
    "meãos": "meão",
    "meãs": "meão",
    "meça": "medir",
    "meçais": "medir",
    "meçam": "medir",
    "meçamo": "medir",
    "meçamos": "medir",
    "meças": "medir",
    "meço": "medir",
    "mhos": "mho",
    "mia": "miar",
    "miada": "miar",
    "miadas": "miar",
    "miadelas": "miadela",
    "miado": "miar",
    "miadora": "miador",
    "miadoras": "miador",
    "miadores": "miador",
    "miados": "miar",
    "miaduras": "miadura",
    "miai": "miar",
    "miais": "miar",
    "mialgias": "mialgia",
    "mialhares": "mialhar",
    "miam": "miar",
    "miamo": "miar",
    "miamos": "miar",
    "miando": "miar",
    "miara": "miar",
    "miaram": "miar",
    "miaras": "miar",
    "miarde": "miar",
    "miardes": "miar",
    "miare": "miar",
    "miarei": "miar",
    "miareis": "miar",
    "miarem": "miar",
    "miaremos": "miar",
    "miares": "miar",
    "miaria": "miar",
    "miariam": "miar",
    "miarias": "miar",
    "miarmo": "miar",
    "miarmos": "miar",
    "miará": "miar",
    "miarás": "miar",
    "miarão": "miar",
    "miaríamos": "miar",
    "miaríeis": "miar",
    "mias": "miar",
    "miasma": "miasmar",
    "miasmada": "miasmar",
    "miasmadas": "miasmar",
    "miasmado": "miasmar",
    "miasmados": "miasmar",
    "miasmai": "miasmar",
    "miasmais": "miasmar",
    "miasmam": "miasmar",
    "miasmamo": "miasmar",
    "miasmamos": "miasmar",
    "miasmando": "miasmar",
    "miasmara": "miasmar",
    "miasmaram": "miasmar",
    "miasmaras": "miasmar",
    "miasmarde": "miasmar",
    "miasmardes": "miasmar",
    "miasmare": "miasmar",
    "miasmarei": "miasmar",
    "miasmareis": "miasmar",
    "miasmarem": "miasmar",
    "miasmaremos": "miasmar",
    "miasmares": "miasmar",
    "miasmaria": "miasmar",
    "miasmariam": "miasmar",
    "miasmarias": "miasmar",
    "miasmarmo": "miasmar",
    "miasmarmos": "miasmar",
    "miasmará": "miasmar",
    "miasmarás": "miasmar",
    "miasmarão": "miasmar",
    "miasmaríamos": "miasmar",
    "miasmaríeis": "miasmar",
    "miasmas": "miasmar",
    "miasmasse": "miasmar",
    "miasmassem": "miasmar",
    "miasmasses": "miasmar",
    "miasmaste": "miasmar",
    "miasmastes": "miasmar",
    "miasmava": "miasmar",
    "miasmavam": "miasmar",
    "miasmavas": "miasmar",
    "miasme": "miasmar",
    "miasmei": "miasmar",
    "miasmeis": "miasmar",
    "miasmem": "miasmar",
    "miasmemo": "miasmar",
    "miasmemos": "miasmar",
    "miasmes": "miasmar",
    "miasmo": "miasmar",
    "miasmou": "miasmar",
    "miasmá": "miasmar",
    "miasmámo": "miasmar",
    "miasmámos": "miasmar",
    "miasmáramo": "miasmar",
    "miasmáramos": "miasmar",
    "miasmárei": "miasmar",
    "miasmáreis": "miasmar",
    "miasmásseis": "miasmar",
    "miasmássemos": "miasmar",
    "miasmática": "miasmático",
    "miasmáticas": "miasmático",
    "miasmáticos": "miasmático",
    "miasmávamo": "miasmar",
    "miasmávamos": "miasmar",
    "miasmávei": "miasmar",
    "miasmáveis": "miasmar",
    "miasse": "miar",
    "miassem": "miar",
    "miasses": "miar",
    "miaste": "miar",
    "miastenias": "miastenia",
    "miastes": "miar",
    "miasténica": "miasténico",
    "miasténicas": "miasténico",
    "miasténicos": "miasténico",
    "miaus": "miau",
    "miava": "miar",
    "miavam": "miar",
    "miavas": "miar",
    "micados": "micado",
    "micaelenses": "micaelense",
    "micantes": "micante",
    "micas": "mica",
    "micaxistos": "micaxisto",
    "micelas": "micela",
    "micetografias": "micetografia",
    "micetologias": "micetologia",
    "micetologistas": "micetologista",
    "micetozoários": "micetozoário",
    "micetófaga": "micetófago",
    "micetófagas": "micetófago",
    "micetófagos": "micetófago",
    "micha": "micho",
    "michas": "micho",
    "michelas": "michela",
    "michelos": "michelo",
    "michos": "micho",
    "micodermas": "micoderma",
    "micogenias": "micogenia",
    "micografias": "micografia",
    "micogénica": "micogénico",
    "micogénicas": "micogénico",
    "micogénicos": "micogénico",
    "micologias": "micologia",
    "micologistas": "micologista",
    "micorrizos": "micorrizo",
    "micos": "mico",
    "micoses": "micose",
    "micracústica": "micracústico",
    "micracústicas": "micracústico",
    "micracústicos": "micracústico",
    "micras": "micra",
    "microbalanças": "microbalança",
    "microbiais": "microbial",
    "microbiana": "microbiano",
    "microbianas": "microbiano",
    "microbianos": "microbiano",
    "microbicidas": "microbicida",
    "microbiologias": "microbiologia",
    "microbiologistas": "microbiologista",
    "microbiológica": "microbiológico",
    "microbiológicas": "microbiológico",
    "microbiológicos": "microbiológico",
    "microbismos": "microbismo",
    "microbióloga": "microbiólogo",
    "microbiólogas": "microbiólogo",
    "microbiólogos": "microbiólogo",
    "microcalcificações": "microcalcificação",
    "microcefalias": "microcefalia",
    "microcentros": "microcentro",
    "microciclos": "microciclo",
    "microcinematografias": "microcinematografia",
    "microcinematográfica": "microcinematográfico",
    "microcinematográficas": "microcinematográfico",
    "microcinematográficos": "microcinematográfico",
    "microcirurgias": "microcirurgia",
    "microclimas": "microclima",
    "microclimática": "microclimático",
    "microclimáticas": "microclimático",
    "microclimáticos": "microclimático",
    "microclinas": "microclina",
    "microcomputadores": "microcomputador",
    "microcosmologias": "microcosmologia",
    "microcosmologistas": "microcosmologista",
    "microcosmológica": "microcosmológico",
    "microcosmológicas": "microcosmológico",
    "microcosmológicos": "microcosmológico",
    "microcosmos": "microcosmo",
    "microcosmóloga": "microcosmólogo",
    "microcosmólogas": "microcosmólogo",
    "microcosmólogos": "microcosmólogo",
    "microcristais": "microcristal",
    "microcristalina": "microcristalino",
    "microcristalinas": "microcristalino",
    "microcristalinos": "microcristalino",
    "microcronómetros": "microcronómetro",
    "microcâmaras": "microcâmara",
    "microcéfala": "microcéfalo",
    "microcéfalas": "microcéfalo",
    "microcéfalos": "microcéfalo",
    "microcósmica": "microcósmico",
    "microcósmicas": "microcósmico",
    "microcósmicos": "microcósmico",
    "microdensitometrias": "microdensitometria",
    "microdioritos": "microdiorito",
    "microdissecções": "microdissecção",
    "microdontes": "microdonte",
    "microdontismos": "microdontismo",
    "microdáctila": "microdáctilo",
    "microdáctilas": "microdáctilo",
    "microdáctilos": "microdáctilo",
    "microeconomias": "microeconomia",
    "microeconómica": "microeconómico",
    "microeconómicas": "microeconómico",
    "microeconómicos": "microeconómico",
    "microelectrónicas": "microelectrónica",
    "microempresas": "microempresa",
    "microestruturas": "microestrutura",
    "microfarads": "microfarad",
    "microfichas": "microficha",
    "microfila": "microfilo",
    "microfilas": "microfilo",
    "microfilmagens": "microfilmagem",
    "microfilmes": "microfilme",
    "microfilos": "microfilo",
    "microfloras": "microflora",
    "microfones": "microfone",
    "microfonias": "microfonia",
    "microfonos": "microfono",
    "microfonógrafos": "microfonógrafo",
    "microfotografias": "microfotografia",
    "microfísicas": "microfísica",
    "microfónica": "microfónico",
    "microfónicas": "microfónico",
    "microfónicos": "microfónico",
    "microgabros": "microgabro",
    "microglossa": "microglosso",
    "microglossas": "microglosso",
    "microglossos": "microglosso",
    "micrografias": "micrografia",
    "microgramas": "micrograma",
    "micrograva": "microgravar",
    "microgravada": "microgravar",
    "microgravadas": "microgravar",
    "microgravado": "microgravar",
    "microgravados": "microgravar",
    "microgravai": "microgravar",
    "microgravais": "microgravar",
    "microgravam": "microgravar",
    "microgravamo": "microgravar",
    "microgravamos": "microgravar",
    "microgravando": "microgravar",
    "microgravara": "microgravar",
    "microgravaram": "microgravar",
    "microgravaras": "microgravar",
    "microgravarde": "microgravar",
    "microgravardes": "microgravar",
    "microgravare": "microgravar",
    "microgravarei": "microgravar",
    "microgravareis": "microgravar",
    "microgravarem": "microgravar",
    "microgravaremos": "microgravar",
    "microgravares": "microgravar",
    "microgravaria": "microgravar",
    "microgravariam": "microgravar",
    "microgravarias": "microgravar",
    "microgravarmo": "microgravar",
    "microgravarmos": "microgravar",
    "microgravará": "microgravar",
    "microgravarás": "microgravar",
    "microgravarão": "microgravar",
    "microgravaríamos": "microgravar",
    "microgravaríeis": "microgravar",
    "microgravas": "microgravar",
    "microgravasse": "microgravar",
    "microgravassem": "microgravar",
    "microgravasses": "microgravar",
    "microgravaste": "microgravar",
    "microgravastes": "microgravar",
    "microgravava": "microgravar",
    "microgravavam": "microgravar",
    "microgravavas": "microgravar",
    "microgravações": "microgravação",
    "micrograve": "microgravar",
    "microgravei": "microgravar",
    "micrograveis": "microgravar",
    "microgravem": "microgravar",
    "microgravemo": "microgravar",
    "microgravemos": "microgravar",
    "micrograves": "microgravar",
    "microgravo": "microgravar",
    "microgravou": "microgravar",
    "microgravá": "microgravar",
    "microgravámo": "microgravar",
    "microgravámos": "microgravar",
    "micrograváramo": "microgravar",
    "micrograváramos": "microgravar",
    "microgravárei": "microgravar",
    "micrograváreis": "microgravar",
    "microgravásseis": "microgravar",
    "microgravássemos": "microgravar",
    "microgravávamo": "microgravar",
    "microgravávamos": "microgravar",
    "microgravávei": "microgravar",
    "micrograváveis": "microgravar",
    "micrográfica": "micrográfico",
    "micrográficas": "micrográfico",
    "micrográficos": "micrográfico",
    "microgâmetas": "microgâmeta",
    "microindústrias": "microindústria",
    "microinformáticas": "microinformática",
    "microinstrumentos": "microinstrumento",
    "microlites": "microlite",
    "microlitros": "microlitro",
    "micrologias": "micrologia",
    "microlítica": "microlítico",
    "microlíticas": "microlítico",
    "microlíticos": "microlítico",
    "micrológica": "micrológico",
    "micrológicas": "micrológico",
    "micrológicos": "micrológico",
    "micromanipuladores": "micromanipulador",
    "micromanómetros": "micromanómetro",
    "micromelias": "micromelia",
    "micrometrias": "micrometria",
    "micrometros": "micrometro",
    "micrométrica": "micrométrico",
    "micrométricas": "micrométrico",
    "micrométricos": "micrométrico",
    "microondas": "microonda",
    "microorganismos": "microorganismo",
    "micropaleontologias": "micropaleontologia",
    "micropertites": "micropertite",
    "micropilares": "micropilar",
    "micropolegadas": "micropolegada",
    "microprocessadores": "microprocessador",
    "micropsias": "micropsia",
    "micropsiquias": "micropsiquia",
    "micropétala": "micropétalo",
    "micropétalas": "micropétalo",
    "micropétalos": "micropétalo",
    "microreproduções": "microreprodução",
    "microrradiografias": "microrradiografia",
    "microrregiões": "microrregião",
    "microrriza": "microrrizo",
    "microrrizas": "microrrizo",
    "microrrizos": "microrrizo",
    "micros": "micro",
    "microscopias": "microscopia",
    "microscopistas": "microscopista",
    "microscópica": "microscópico",
    "microscópicas": "microscópico",
    "microscópicos": "microscópico",
    "microscópios": "microscópio",
    "microsférica": "microsférico",
    "microsféricas": "microsférico",
    "microsféricos": "microsférico",
    "microsporofilos": "microsporofilo",
    "microsporângios": "microsporângio",
    "microssegundos": "microssegundo",
    "microssismos": "microssismo",
    "microssismógrafos": "microssismógrafo",
    "microssociologias": "microssociologia",
    "microstomídeos": "microstomídeo",
    "microstómidas": "microstómida",
    "microzoários": "microzoário",
    "micróbios": "micróbio",
    "micrófita": "micrófito",
    "micrófitas": "micrófito",
    "micrófitos": "micrófito",
    "micrófona": "micrófono",
    "micrófonas": "micrófono",
    "micrófonos": "micrófono",
    "micrógnata": "micrógnato",
    "micrógnatas": "micrógnato",
    "micrógnatos": "micrógnato",
    "micrógrafa": "micrógrafo",
    "micrógrafas": "micrógrafo",
    "micrógrafos": "micrógrafo",
    "micrólitos": "micrólito",
    "micróloga": "micrólogo",
    "micrólogas": "micrólogo",
    "micrólogos": "micrólogo",
    "micrómera": "micrómero",
    "micrómeras": "micrómero",
    "micrómeros": "micrómero",
    "micrómetros": "micrómetro",
    "micrópilas": "micrópila",
    "micrópilos": "micrópilo",
    "micrósporos": "micrósporo",
    "micróstoma": "micróstomo",
    "micróstomas": "micróstomo",
    "micróstomos": "micróstomo",
    "micrótomos": "micrótomo",
    "micterismos": "micterismo",
    "micturições": "micturição",
    "mictória": "mictório",
    "mictórias": "mictório",
    "mictórios": "mictório",
    "micácea": "micáceo",
    "micáceas": "micáceo",
    "micáceos": "micáceo",
    "micções": "micção",
    "micélios": "micélio",
    "micóloga": "micólogo",
    "micólogas": "micólogo",
    "micólogos": "micólogo",
    "micótica": "micótico",
    "micóticas": "micótico",
    "micóticos": "micótico",
    "mie": "miar",
    "miei": "miar",
    "mieis": "miar",
    "mielencéfalos": "mielencéfalo",
    "mielinas": "mielina",
    "mielites": "mielite",
    "mielografias": "mielografia",
    "mielomas": "mieloma",
    "mielopatias": "mielopatia",
    "mieloplaxes": "mieloplaxe",
    "mielossarcomas": "mielossarcoma",
    "mielínica": "mielínico",
    "mielínicas": "mielínico",
    "mielínicos": "mielínico",
    "mielóides": "mielóide",
    "mielóplaces": "mielóplace",
    "miem": "miar",
    "miemo": "miar",
    "miemos": "miar",
    "mies": "miar",
    "miga": "migar",
    "migada": "migar",
    "migadas": "migar",
    "migadinha": "migado",
    "migadinhas": "migado",
    "migadinho": "migado",
    "migadinhos": "migado",
    "migadita": "migado",
    "migaditas": "migado",
    "migadito": "migado",
    "migaditos": "migado",
    "migado": "migar",
    "migados": "migar",
    "migai": "migar",
    "migais": "migar",
    "migalha": "migalhar",
    "migalhada": "migalhar",
    "migalhadas": "migalhar",
    "migalhado": "migalhar",
    "migalhados": "migalhar",
    "migalhai": "migalhar",
    "migalhais": "migalhar",
    "migalham": "migalhar",
    "migalhamo": "migalhar",
    "migalhamos": "migalhar",
    "migalhando": "migalhar",
    "migalhara": "migalhar",
    "migalharam": "migalhar",
    "migalharas": "migalhar",
    "migalharde": "migalhar",
    "migalhardes": "migalhar",
    "migalhare": "migalhar",
    "migalharei": "migalhar",
    "migalhareis": "migalhar",
    "migalharem": "migalhar",
    "migalharemos": "migalhar",
    "migalhares": "migalhar",
    "migalharia": "migalhar",
    "migalhariam": "migalhar",
    "migalharias": "migalharia",
    "migalharmo": "migalhar",
    "migalharmos": "migalhar",
    "migalhará": "migalhar",
    "migalharás": "migalhar",
    "migalharão": "migalhar",
    "migalharíamos": "migalhar",
    "migalharíeis": "migalhar",
    "migalhas": "migalhar",
    "migalhasse": "migalhar",
    "migalhassem": "migalhar",
    "migalhasses": "migalhar",
    "migalhaste": "migalhar",
    "migalhastes": "migalhar",
    "migalhava": "migalhar",
    "migalhavam": "migalhar",
    "migalhavas": "migalhar",
    "migalhe": "migalhar",
    "migalhei": "migalhar",
    "migalheira": "migalheiro",
    "migalheiras": "migalheiro",
    "migalheiros": "migalheiro",
    "migalheis": "migalhar",
    "migalhem": "migalhar",
    "migalhemo": "migalhar",
    "migalhemos": "migalhar",
    "migalhes": "migalhar",
    "migalhices": "migalhice",
    "migalhinha": "migalha",
    "migalhinhas": "migalha",
    "migalhita": "migalha",
    "migalhitas": "migalha",
    "migalho": "migalhar",
    "migalhos": "migalho",
    "migalhou": "migalhar",
    "migalhá": "migalhar",
    "migalhámo": "migalhar",
    "migalhámos": "migalhar",
    "migalháramo": "migalhar",
    "migalháramos": "migalhar",
    "migalhárei": "migalhar",
    "migalháreis": "migalhar",
    "migalhásseis": "migalhar",
    "migalhássemos": "migalhar",
    "migalhávamo": "migalhar",
    "migalhávamos": "migalhar",
    "migalhávei": "migalhar",
    "migalháveis": "migalhar",
    "migalos": "migalo",
    "migam": "migar",
    "migamo": "migar",
    "migamos": "migar",
    "migando": "migar",
    "migara": "migar",
    "migaram": "migar",
    "migaras": "migar",
    "migarde": "migar",
    "migardes": "migar",
    "migare": "migar",
    "migarei": "migar",
    "migareis": "migar",
    "migarem": "migar",
    "migaremos": "migar",
    "migares": "migar",
    "migaria": "migar",
    "migariam": "migar",
    "migarias": "migar",
    "migarmo": "migar",
    "migarmos": "migar",
    "migará": "migar",
    "migarás": "migar",
    "migarão": "migar",
    "migaríamos": "migar",
    "migaríeis": "migar",
    "migas": "migar",
    "migasse": "migar",
    "migassem": "migar",
    "migasses": "migar",
    "migaste": "migar",
    "migastes": "migar",
    "migava": "migar",
    "migavam": "migar",
    "migavas": "migar",
    "migmatitos": "migmatito",
    "migo": "migar",
    "migou": "migar",
    "migra": "migrar",
    "migrada": "migrar",
    "migradas": "migrar",
    "migrado": "migrar",
    "migradora": "migrador",
    "migradoras": "migrador",
    "migradores": "migrador",
    "migrados": "migrar",
    "migrai": "migrar",
    "migrais": "migrar",
    "migram": "migrar",
    "migramo": "migrar",
    "migramos": "migrar",
    "migrando": "migrar",
    "migrantes": "migrante",
    "migrara": "migrar",
    "migraram": "migrar",
    "migraras": "migrar",
    "migrardes": "migrar",
    "migrarei": "migrar",
    "migrareis": "migrar",
    "migrarem": "migrar",
    "migraremos": "migrar",
    "migrares": "migrar",
    "migraria": "migrar",
    "migrariam": "migrar",
    "migrarias": "migrar",
    "migrarmo": "migrar",
    "migrarmos": "migrar",
    "migrará": "migrar",
    "migrarás": "migrar",
    "migrarão": "migrar",
    "migraríamos": "migrar",
    "migraríeis": "migrar",
    "migras": "migrar",
    "migrasse": "migrar",
    "migrassem": "migrar",
    "migrasses": "migrar",
    "migraste": "migrar",
    "migrastes": "migrar",
    "migratória": "migratório",
    "migratórias": "migratório",
    "migratórios": "migratório",
    "migrava": "migrar",
    "migravam": "migrar",
    "migravas": "migrar",
    "migrações": "migração",
    "migre": "migrar",
    "migrei": "migrar",
    "migreis": "migrar",
    "migrem": "migrar",
    "migremo": "migrar",
    "migremos": "migrar",
    "migres": "migrar",
    "migro": "migrar",
    "migrou": "migrar",
    "migrámo": "migrar",
    "migrámos": "migrar",
    "migráramo": "migrar",
    "migráramos": "migrar",
    "migráreis": "migrar",
    "migrásseis": "migrar",
    "migrássemos": "migrar",
    "migrávamo": "migrar",
    "migrávamos": "migrar",
    "migráveis": "migrar",
    "migue": "migar",
    "miguei": "migar",
    "migueis": "migar",
    "miguelismos": "miguelismo",
    "miguelistas": "miguelista",
    "miguem": "migar",
    "miguemo": "migar",
    "miguemos": "migar",
    "migues": "migar",
    "migá": "migar",
    "migámo": "migar",
    "migámos": "migar",
    "migáramo": "migar",
    "migáramos": "migar",
    "migárei": "migar",
    "migáreis": "migar",
    "migásseis": "migar",
    "migássemos": "migar",
    "migávamo": "migar",
    "migávamos": "migar",
    "migávei": "migar",
    "migáveis": "migar",
    "miiocéfala": "miiocéfalo",
    "miiocéfalas": "miiocéfalo",
    "miiocéfalos": "miiocéfalo",
    "miiodopsias": "miiodopsia",
    "miites": "miite",
    "mija": "mijar",
    "mijaburros": "mijaburro",
    "mijaceiras": "mijaceira",
    "mijada": "mijar",
    "mijadas": "mijar",
    "mijadeiras": "mijadeira",
    "mijadeiros": "mijadeiro",
    "mijadelas": "mijadela",
    "mijado": "mijar",
    "mijadoiros": "mijadoiro",
    "mijados": "mijar",
    "mijadouros": "mijadouro",
    "mijai": "mijar",
    "mijais": "mijar",
    "mijam": "mijar",
    "mijamo": "mijar",
    "mijamos": "mijar",
    "mijanceiras": "mijanceira",
    "mijando": "mijar",
    "mijara": "mijar",
    "mijaram": "mijar",
    "mijaras": "mijar",
    "mijarde": "mijar",
    "mijardes": "mijar",
    "mijare": "mijar",
    "mijarei": "mijar",
    "mijareis": "mijar",
    "mijarem": "mijar",
    "mijaremos": "mijar",
    "mijares": "mijar",
    "mijaria": "mijar",
    "mijariam": "mijar",
    "mijarias": "mijar",
    "mijarmo": "mijar",
    "mijarmos": "mijar",
    "mijará": "mijar",
    "mijarás": "mijar",
    "mijarão": "mijar",
    "mijaríamos": "mijar",
    "mijaríeis": "mijar",
    "mijas": "mijar",
    "mijasse": "mijar",
    "mijassem": "mijar",
    "mijasses": "mijar",
    "mijaste": "mijar",
    "mijastes": "mijar",
    "mijava": "mijar",
    "mijavam": "mijar",
    "mijavas": "mijar",
    "mijazinha": "mija",
    "mijazinhas": "mija",
    "mijazita": "mija",
    "mijazitas": "mija",
    "mije": "mijar",
    "mijei": "mijar",
    "mijeis": "mijar",
    "mijem": "mijar",
    "mijemo": "mijar",
    "mijemos": "mijar",
    "mijes": "mijar",
    "mijinas": "mijina",
    "mijinha": "mija",
    "mijinhas": "mija",
    "mijita": "mija",
    "mijitas": "mija",
    "mijo": "mijar",
    "mijocas": "mijoca",
    "mijona": "mijão",
    "mijonas": "mijão",
    "mijonazinha": "mijão",
    "mijonazinhas": "mijão",
    "mijonazita": "mijão",
    "mijonazitas": "mijão",
    "mijos": "mijo",
    "mijou": "mijar",
    "mijá": "mijar",
    "mijámo": "mijar",
    "mijámos": "mijar",
    "mijáramo": "mijar",
    "mijáramos": "mijar",
    "mijárei": "mijar",
    "mijáreis": "mijar",
    "mijásseis": "mijar",
    "mijássemos": "mijar",
    "mijávamo": "mijar",
    "mijávamos": "mijar",
    "mijávei": "mijar",
    "mijáveis": "mijar",
    "mijãozinho": "mijão",
    "mijãozito": "mijão",
    "mijões": "mijão",
    "mijõezinhos": "mijão",
    "mijõezitos": "mijão",
    "milagrarias": "milagraria",
    "milagreira": "milagreiro",
    "milagreiras": "milagreiro",
    "milagreiros": "milagreiro",
    "milagrenta": "milagrento",
    "milagrentas": "milagrento",
    "milagrentos": "milagrento",
    "milagres": "milagre",
    "milagrosa": "milagroso",
    "milagrosas": "milagroso",
    "milagrosos": "milagroso",
    "milagrórios": "milagrório",
    "milandos": "milando",
    "milanesa": "milanês",
    "milanesas": "milanesa",
    "milaneses": "milanês",
    "milanos": "milano",
    "milavos": "milavo",
    "mildes": "milde",
    "milefólios": "milefólio",
    "milenares": "milenar",
    "milenarismos": "milenarismo",
    "milenaristas": "milenarista",
    "milenária": "milenário",
    "milenárias": "milenário",
    "milenários": "milenário",
    "milfolhadas": "milfolhada",
    "milfurada": "milfurado",
    "milfuradas": "milfurado",
    "milfurados": "milfurado",
    "milgradas": "milgrada",
    "milgranadas": "milgranada",
    "milhada": "milhado",
    "milhadas": "milhado",
    "milhados": "milhado",
    "milhafos": "milhafo",
    "milhafres": "milhafre",
    "milhagens": "milhagem",
    "milhais": "milhal",
    "milhaneira": "milhaneiro",
    "milhaneiras": "milhaneiro",
    "milhaneiros": "milhaneiro",
    "milhanos": "milhano",
    "milhar": "mil",
    "milharadas": "milharada",
    "milharais": "milharal",
    "milharengos": "milharengo",
    "milhares": "milhar",
    "milharoses": "milharós",
    "milhas": "milha",
    "milhaças": "milhaça",
    "milheirais": "milheiral",
    "milheiras": "milheira",
    "milheirinhas": "milheirinha",
    "milheiriças": "milheiriça",
    "milheiros": "milheiro",
    "milheiroses": "milheirós",
    "milheirós": "milheiró",
    "milheirões": "milheirão",
    "milhentas": "milhentos",
    "milherangos": "milherango",
    "milhereus": "milhereu",
    "milhetes": "milhete",
    "milhos": "milho",
    "milhãs": "milhã",
    "milhões": "milhão",
    "miliamperímetros": "miliamperímetro",
    "miliampères": "miliampère",
    "miliares": "miliare",
    "milibares": "milibar",
    "miliciana": "miliciano",
    "milicianas": "miliciano",
    "milicianos": "miliciano",
    "milicuries": "milicurie",
    "miligramas": "miligrama",
    "miligrãs": "miligrã",
    "mililitros": "mililitro",
    "milimicros": "milimicro",
    "milimétrica": "milimétrico",
    "milimétricas": "milimétrico",
    "milimétricos": "milimétrico",
    "miliolídeos": "miliolídeo",
    "milionária": "milionário",
    "milionárias": "milionário",
    "milionários": "milionário",
    "milionésima": "milionésimo",
    "milionésimas": "milionésimo",
    "milionésimos": "milionésimo",
    "milissegundos": "milissegundo",
    "milisteres": "milistere",
    "milistéreos": "milistéreo",
    "milita": "militar",
    "militada": "militar",
    "militadas": "militar",
    "militado": "militar",
    "militados": "militar",
    "militai": "militar",
    "militais": "militar",
    "militam": "militar",
    "militamo": "militar",
    "militamos": "militar",
    "militando": "militar",
    "militantes": "militante",
    "militantismos": "militantismo",
    "militanças": "militança",
    "militara": "militar",
    "militaram": "militar",
    "militaras": "militar",
    "militardes": "militar",
    "militarei": "militar",
    "militareis": "militar",
    "militarem": "militar",
    "militaremos": "militar",
    "militares": "militar",
    "militaria": "militar",
    "militariam": "militar",
    "militarias": "militar",
    "militarismos": "militarismo",
    "militaristas": "militarista",
    "militarites": "militarite",
    "militariza": "militarizar",
    "militarizada": "militarizar",
    "militarizadas": "militarizar",
    "militarizado": "militarizar",
    "militarizados": "militarizar",
    "militarizai": "militarizar",
    "militarizais": "militarizar",
    "militarizam": "militarizar",
    "militarizamo": "militarizar",
    "militarizamos": "militarizar",
    "militarizando": "militarizar",
    "militarizara": "militarizar",
    "militarizaram": "militarizar",
    "militarizaras": "militarizar",
    "militarizarde": "militarizar",
    "militarizardes": "militarizar",
    "militarizare": "militarizar",
    "militarizarei": "militarizar",
    "militarizareis": "militarizar",
    "militarizarem": "militarizar",
    "militarizaremos": "militarizar",
    "militarizares": "militarizar",
    "militarizaria": "militarizar",
    "militarizariam": "militarizar",
    "militarizarias": "militarizar",
    "militarizarmo": "militarizar",
    "militarizarmos": "militarizar",
    "militarizará": "militarizar",
    "militarizarás": "militarizar",
    "militarizarão": "militarizar",
    "militarizaríamos": "militarizar",
    "militarizaríeis": "militarizar",
    "militarizas": "militarizar",
    "militarizasse": "militarizar",
    "militarizassem": "militarizar",
    "militarizasses": "militarizar",
    "militarizaste": "militarizar",
    "militarizastes": "militarizar",
    "militarizava": "militarizar",
    "militarizavam": "militarizar",
    "militarizavas": "militarizar",
    "militarizações": "militarização",
    "militarize": "militarizar",
    "militarizei": "militarizar",
    "militarizeis": "militarizar",
    "militarizem": "militarizar",
    "militarizemo": "militarizar",
    "militarizemos": "militarizar",
    "militarizes": "militarizar",
    "militarizo": "militarizar",
    "militarizou": "militarizar",
    "militarizá": "militarizar",
    "militarizámo": "militarizar",
    "militarizámos": "militarizar",
    "militarizáramo": "militarizar",
    "militarizáramos": "militarizar",
    "militarizárei": "militarizar",
    "militarizáreis": "militarizar",
    "militarizásseis": "militarizar",
    "militarizássemos": "militarizar",
    "militarizávamo": "militarizar",
    "militarizávamos": "militarizar",
    "militarizávei": "militarizar",
    "militarizáveis": "militarizável",
    "militarmo": "militar",
    "militarmos": "militar",
    "militarona": "militarão",
    "militaronas": "militarão",
    "militará": "militar",
    "militarás": "militar",
    "militarão": "militar",
    "militaríamos": "militar",
    "militaríeis": "militar",
    "militarões": "militarão",
    "militas": "militar",
    "militasse": "militar",
    "militassem": "militar",
    "militasses": "militar",
    "militaste": "militar",
    "militastes": "militar",
    "militava": "militar",
    "militavam": "militar",
    "militavas": "militar",
    "milite": "militar",
    "militei": "militar",
    "militeis": "militar",
    "militem": "militar",
    "militemo": "militar",
    "militemos": "militar",
    "milites": "militar",
    "milito": "militar",
    "militofobias": "militofobia",
    "militou": "militar",
    "militámo": "militar",
    "militámos": "militar",
    "militáramo": "militar",
    "militáramos": "militar",
    "militáreis": "militar",
    "militásseis": "militar",
    "militássemos": "militar",
    "militávamo": "militar",
    "militávamos": "militar",
    "militáveis": "militar",
    "militâncias": "militância",
    "miliácea": "miliáceo",
    "miliáceas": "miliáceo",
    "miliáceos": "miliáceo",
    "miliária": "miliário",
    "miliárias": "miliário",
    "miliários": "miliário",
    "miliólidas": "miliólida",
    "millerites": "millerite",
    "milongueira": "milongueiro",
    "milongueiras": "milongueiro",
    "milongueiros": "milongueiro",
    "milordes": "milorde",
    "miltoniana": "miltoniano",
    "miltonianas": "miltoniano",
    "miltonianos": "miltoniano",
    "milénios": "milénio",
    "milésima": "milésimo",
    "milésimas": "milésimo",
    "milésimos": "milésimo",
    "milícias": "milícia",
    "milímetros": "milímetro",
    "milímoda": "milímodo",
    "milímodas": "milímodo",
    "milímodos": "milímodo",
    "milípedes": "milípede",
    "milões": "milão",
    "mima": "mimo",
    "mimada": "mimar",
    "mimadas": "mimar",
    "mimado": "mimar",
    "mimadores": "mimador",
    "mimados": "mimar",
    "mimadíssima": "mimado",
    "mimadíssimas": "mimado",
    "mimadíssimo": "mimado",
    "mimadíssimos": "mimado",
    "mimai": "mimar",
    "mimais": "mimar",
    "mimalha": "mimalho",
    "mimalhas": "mimalho",
    "mimalheira": "mimalheiro",
    "mimalheiras": "mimalheiro",
    "mimalheiros": "mimalheiro",
    "mimalhices": "mimalhice",
    "mimalhos": "mimalho",
    "mimam": "mimar",
    "mimamo": "mimar",
    "mimamos": "mimar",
    "mimando": "mimar",
    "mimança": "mimanço",
    "mimanças": "mimanço",
    "mimanços": "mimanço",
    "mimara": "mimar",
    "mimaram": "mimar",
    "mimaras": "mimar",
    "mimarde": "mimar",
    "mimardes": "mimar",
    "mimare": "mimar",
    "mimarei": "mimar",
    "mimareis": "mimar",
    "mimarem": "mimar",
    "mimaremos": "mimar",
    "mimares": "mimar",
    "mimaria": "mimar",
    "mimariam": "mimar",
    "mimarias": "mimar",
    "mimarmo": "mimar",
    "mimarmos": "mimar",
    "mimará": "mimar",
    "mimarás": "mimar",
    "mimarão": "mimar",
    "mimaríamos": "mimar",
    "mimaríeis": "mimar",
    "mimas": "mimo",
    "mimasse": "mimar",
    "mimassem": "mimar",
    "mimasses": "mimar",
    "mimaste": "mimar",
    "mimastes": "mimar",
    "mimava": "mimar",
    "mimavam": "mimar",
    "mimavas": "mimar",
    "mime": "mimar",
    "mimecos": "mimeco",
    "mimei": "mimar",
    "mimeis": "mimar",
    "mimem": "mimar",
    "mimemo": "mimar",
    "mimemos": "mimar",
    "mimeografagens": "mimeografagem",
    "mimeografias": "mimeografia",
    "mimes": "mimar",
    "mimeses": "mimese",
    "mimetismos": "mimetismo",
    "mimetistas": "mimetista",
    "mimetomanias": "mimetomania",
    "mimeógrafos": "mimeógrafo",
    "mimiambos": "mimiambo",
    "mimica": "mimicar",
    "mimicada": "mimicar",
    "mimicadas": "mimicar",
    "mimicado": "mimicar",
    "mimicados": "mimicar",
    "mimicai": "mimicar",
    "mimicais": "mimicar",
    "mimicam": "mimicar",
    "mimicamo": "mimicar",
    "mimicamos": "mimicar",
    "mimicando": "mimicar",
    "mimicara": "mimicar",
    "mimicaram": "mimicar",
    "mimicaras": "mimicar",
    "mimicarde": "mimicar",
    "mimicardes": "mimicar",
    "mimicare": "mimicar",
    "mimicarei": "mimicar",
    "mimicareis": "mimicar",
    "mimicarem": "mimicar",
    "mimicaremos": "mimicar",
    "mimicares": "mimicar",
    "mimicaria": "mimicar",
    "mimicariam": "mimicar",
    "mimicarias": "mimicar",
    "mimicarmo": "mimicar",
    "mimicarmos": "mimicar",
    "mimicará": "mimicar",
    "mimicarás": "mimicar",
    "mimicarão": "mimicar",
    "mimicaríamos": "mimicar",
    "mimicaríeis": "mimicar",
    "mimicas": "mimicar",
    "mimicasse": "mimicar",
    "mimicassem": "mimicar",
    "mimicasses": "mimicar",
    "mimicaste": "mimicar",
    "mimicastes": "mimicar",
    "mimicava": "mimicar",
    "mimicavam": "mimicar",
    "mimicavas": "mimicar",
    "mimices": "mimice",
    "mimico": "mimicar",
    "mimicou": "mimicar",
    "mimicá": "mimicar",
    "mimicámo": "mimicar",
    "mimicámos": "mimicar",
    "mimicáramo": "mimicar",
    "mimicáramos": "mimicar",
    "mimicárei": "mimicar",
    "mimicáreis": "mimicar",
    "mimicásseis": "mimicar",
    "mimicássemos": "mimicar",
    "mimicávamo": "mimicar",
    "mimicávamos": "mimicar",
    "mimicávei": "mimicar",
    "mimicáveis": "mimicar",
    "miminho": "mimo",
    "miminhos": "mimo",
    "mimique": "mimicar",
    "mimiquei": "mimicar",
    "mimiqueis": "mimicar",
    "mimiquem": "mimicar",
    "mimiquemo": "mimicar",
    "mimiquemos": "mimicar",
    "mimiques": "mimicar",
    "mimito": "mimo",
    "mimitos": "mimo",
    "mimo": "mimar",
    "mimodramas": "mimodrama",
    "mimografias": "mimografia",
    "mimologias": "mimologia",
    "mimologismos": "mimologismo",
    "mimos": "mimo",
    "mimosa": "mimoso",
    "mimosas": "mimoso",
    "mimoseada": "mimosear",
    "mimoseadas": "mimosear",
    "mimoseado": "mimosear",
    "mimoseados": "mimosear",
    "mimoseai": "mimosear",
    "mimoseais": "mimosear",
    "mimoseamo": "mimosear",
    "mimoseamos": "mimosear",
    "mimoseando": "mimosear",
    "mimoseara": "mimosear",
    "mimosearam": "mimosear",
    "mimosearas": "mimosear",
    "mimosearde": "mimosear",
    "mimoseardes": "mimosear",
    "mimoseare": "mimosear",
    "mimosearei": "mimosear",
    "mimoseareis": "mimosear",
    "mimosearem": "mimosear",
    "mimosearemos": "mimosear",
    "mimoseares": "mimosear",
    "mimosearia": "mimosear",
    "mimoseariam": "mimosear",
    "mimosearias": "mimosear",
    "mimosearmo": "mimosear",
    "mimosearmos": "mimosear",
    "mimoseará": "mimosear",
    "mimosearás": "mimosear",
    "mimosearão": "mimosear",
    "mimosearíamos": "mimosear",
    "mimosearíeis": "mimosear",
    "mimoseasse": "mimosear",
    "mimoseassem": "mimosear",
    "mimoseasses": "mimosear",
    "mimoseaste": "mimosear",
    "mimoseastes": "mimosear",
    "mimoseava": "mimosear",
    "mimoseavam": "mimosear",
    "mimoseavas": "mimosear",
    "mimoseei": "mimosear",
    "mimoseeis": "mimosear",
    "mimoseemo": "mimosear",
    "mimoseemos": "mimosear",
    "mimoseia": "mimosear",
    "mimoseiam": "mimosear",
    "mimoseias": "mimosear",
    "mimoseie": "mimosear",
    "mimoseiem": "mimosear",
    "mimoseies": "mimosear",
    "mimoseio": "mimosear",
    "mimoseou": "mimosear",
    "mimoseá": "mimosear",
    "mimoseámo": "mimosear",
    "mimoseámos": "mimosear",
    "mimoseáramo": "mimosear",
    "mimoseáramos": "mimosear",
    "mimoseárei": "mimosear",
    "mimoseáreis": "mimosear",
    "mimoseásseis": "mimosear",
    "mimoseássemos": "mimosear",
    "mimoseávamo": "mimosear",
    "mimoseávamos": "mimosear",
    "mimoseávei": "mimosear",
    "mimoseáveis": "mimosear",
    "mimosos": "mimoso",
    "mimosáceas": "mimosácea",
    "mimou": "mimar",
    "mimá": "mimar",
    "mimámo": "mimar",
    "mimámos": "mimar",
    "mimáramo": "mimar",
    "mimáramos": "mimar",
    "mimárei": "mimar",
    "mimáreis": "mimar",
    "mimásseis": "mimar",
    "mimássemos": "mimar",
    "mimávamo": "mimar",
    "mimávamos": "mimar",
    "mimávei": "mimar",
    "mimáveis": "mimável",
    "mimética": "mimético",
    "miméticas": "mimético",
    "miméticos": "mimético",
    "mimídeos": "mimídeo",
    "mimógrafa": "mimógrafo",
    "mimógrafas": "mimógrafo",
    "mimógrafos": "mimógrafo",
    "mimóloga": "mimólogo",
    "mimólogas": "mimólogo",
    "mimólogos": "mimólogo",
    "mimósea": "mimóseo",
    "mimóseas": "mimóseo",
    "mimóseos": "mimóseo",
    "mina": "minar",
    "minacíssima": "minaz",
    "minacíssimas": "minaz",
    "minacíssimo": "minaz",
    "minacíssimos": "minaz",
    "minada": "minar",
    "minadas": "minar",
    "minado": "minar",
    "minadoiros": "minadoiro",
    "minadora": "minador",
    "minadoras": "minador",
    "minadores": "minador",
    "minados": "minar",
    "minadouros": "minadouro",
    "minai": "minar",
    "minais": "minar",
    "minam": "minar",
    "minamo": "minar",
    "minamos": "minar",
    "minando": "minar",
    "minara": "minar",
    "minaram": "minar",
    "minaras": "minar",
    "minarde": "minar",
    "minardes": "minar",
    "minare": "minar",
    "minarei": "minar",
    "minareis": "minar",
    "minarem": "minar",
    "minaremos": "minar",
    "minares": "minar",
    "minaretes": "minarete",
    "minaria": "minar",
    "minariam": "minar",
    "minarias": "minar",
    "minarmo": "minar",
    "minarmos": "minar",
    "minará": "minar",
    "minarás": "minar",
    "minarão": "minar",
    "minaríamos": "minar",
    "minaríeis": "minar",
    "minas": "minar",
    "minasse": "minar",
    "minassem": "minar",
    "minasses": "minar",
    "minaste": "minar",
    "minastes": "minar",
    "minava": "minar",
    "minavam": "minar",
    "minavas": "minar",
    "minazes": "minaz",
    "mincções": "mincção",
    "mindinha": "mindinho",
    "mindinhas": "mindinho",
    "mindinhos": "mindinho",
    "mindubas": "minduba",
    "mine": "minar",
    "minei": "minar",
    "mineira": "mineiro",
    "mineiras": "mineiro",
    "mineiros": "mineiro",
    "mineis": "minar",
    "minem": "minar",
    "minemo": "minar",
    "minemos": "minar",
    "minenses": "minense",
    "minera": "minerar",
    "minerada": "minerar",
    "mineradas": "minerar",
    "minerado": "minerar",
    "minerados": "minerar",
    "minerai": "minerar",
    "minerais": "minerar",
    "mineraliza": "mineralizar",
    "mineralizada": "mineralizar",
    "mineralizadas": "mineralizar",
    "mineralizado": "mineralizar",
    "mineralizadora": "mineralizador",
    "mineralizadoras": "mineralizador",
    "mineralizadores": "mineralizador",
    "mineralizados": "mineralizar",
    "mineralizai": "mineralizar",
    "mineralizais": "mineralizar",
    "mineralizam": "mineralizar",
    "mineralizamo": "mineralizar",
    "mineralizamos": "mineralizar",
    "mineralizando": "mineralizar",
    "mineralizara": "mineralizar",
    "mineralizaram": "mineralizar",
    "mineralizaras": "mineralizar",
    "mineralizarde": "mineralizar",
    "mineralizardes": "mineralizar",
    "mineralizare": "mineralizar",
    "mineralizarei": "mineralizar",
    "mineralizareis": "mineralizar",
    "mineralizarem": "mineralizar",
    "mineralizaremos": "mineralizar",
    "mineralizares": "mineralizar",
    "mineralizaria": "mineralizar",
    "mineralizariam": "mineralizar",
    "mineralizarias": "mineralizar",
    "mineralizarmo": "mineralizar",
    "mineralizarmos": "mineralizar",
    "mineralizará": "mineralizar",
    "mineralizarás": "mineralizar",
    "mineralizarão": "mineralizar",
    "mineralizaríamos": "mineralizar",
    "mineralizaríeis": "mineralizar",
    "mineralizas": "mineralizar",
    "mineralizasse": "mineralizar",
    "mineralizassem": "mineralizar",
    "mineralizasses": "mineralizar",
    "mineralizaste": "mineralizar",
    "mineralizastes": "mineralizar",
    "mineralizava": "mineralizar",
    "mineralizavam": "mineralizar",
    "mineralizavas": "mineralizar",
    "mineralizações": "mineralização",
    "mineralize": "mineralizar",
    "mineralizei": "mineralizar",
    "mineralizeis": "mineralizar",
    "mineralizem": "mineralizar",
    "mineralizemo": "mineralizar",
    "mineralizemos": "mineralizar",
    "mineralizes": "mineralizar",
    "mineralizo": "mineralizar",
    "mineralizou": "mineralizar",
    "mineralizá": "mineralizar",
    "mineralizámo": "mineralizar",
    "mineralizámos": "mineralizar",
    "mineralizáramo": "mineralizar",
    "mineralizáramos": "mineralizar",
    "mineralizárei": "mineralizar",
    "mineralizáreis": "mineralizar",
    "mineralizásseis": "mineralizar",
    "mineralizássemos": "mineralizar",
    "mineralizávamo": "mineralizar",
    "mineralizávamos": "mineralizar",
    "mineralizávei": "mineralizar",
    "mineralizáveis": "mineralizável",
    "mineralogias": "mineralogia",
    "mineralogistas": "mineralogista",
    "mineralurgias": "mineralurgia",
    "mineralógica": "mineralógico",
    "mineralógicas": "mineralógico",
    "mineralógicos": "mineralógico",
    "mineralúrgica": "mineralúrgico",
    "mineralúrgicas": "mineralúrgico",
    "mineralúrgicos": "mineralúrgico",
    "mineram": "minerar",
    "mineramo": "minerar",
    "mineramos": "minerar",
    "minerando": "minerar",
    "minerara": "minerar",
    "mineraram": "minerar",
    "mineraras": "minerar",
    "minerarde": "minerar",
    "minerardes": "minerar",
    "minerare": "minerar",
    "minerarei": "minerar",
    "minerareis": "minerar",
    "minerarem": "minerar",
    "mineraremos": "minerar",
    "minerares": "minerar",
    "mineraria": "minerar",
    "minerariam": "minerar",
    "minerarias": "minerar",
    "minerarmo": "minerar",
    "minerarmos": "minerar",
    "minerará": "minerar",
    "minerarás": "minerar",
    "minerarão": "minerar",
    "mineraríamos": "minerar",
    "mineraríeis": "minerar",
    "mineras": "minerar",
    "minerasse": "minerar",
    "minerassem": "minerar",
    "minerasses": "minerar",
    "mineraste": "minerar",
    "minerastes": "minerar",
    "minerava": "minerar",
    "mineravam": "minerar",
    "mineravas": "minerar",
    "minerações": "mineração",
    "minere": "minerar",
    "minerei": "minerar",
    "minereis": "minerar",
    "minerem": "minerar",
    "mineremo": "minerar",
    "mineremos": "minerar",
    "mineres": "minerar",
    "minero": "minerar",
    "minerodutos": "mineroduto",
    "minerogenias": "minerogenia",
    "minerografias": "minerografia",
    "minerográfica": "minerográfico",
    "minerográficas": "minerográfico",
    "minerográficos": "minerográfico",
    "minerou": "minerar",
    "minervais": "minerval",
    "minervas": "minerva",
    "minerá": "minerar",
    "minerámo": "minerar",
    "minerámos": "minerar",
    "mineráramo": "minerar",
    "mineráramos": "minerar",
    "minerárei": "minerar",
    "mineráreis": "minerar",
    "minerásseis": "minerar",
    "minerássemos": "minerar",
    "minerávamo": "minerar",
    "minerávamos": "minerar",
    "minerávei": "minerar",
    "mineráveis": "minerar",
    "minerógrafa": "minerógrafo",
    "minerógrafas": "minerógrafo",
    "minerógrafos": "minerógrafo",
    "mines": "minar",
    "minga": "mingar",
    "mingachos": "mingacho",
    "mingada": "mingar",
    "mingadas": "mingar",
    "mingado": "mingar",
    "mingados": "mingar",
    "mingai": "mingar",
    "mingais": "mingar",
    "mingam": "mingar",
    "mingamo": "mingar",
    "mingamos": "mingar",
    "mingando": "mingar",
    "minganças": "mingança",
    "mingara": "mingar",
    "mingaram": "mingar",
    "mingaras": "mingar",
    "mingarde": "mingar",
    "mingardes": "mingar",
    "mingare": "mingar",
    "mingarei": "mingar",
    "mingareis": "mingar",
    "mingarem": "mingar",
    "mingaremos": "mingar",
    "mingares": "mingar",
    "mingaria": "mingar",
    "mingariam": "mingar",
    "mingarias": "mingar",
    "mingarmo": "mingar",
    "mingarmos": "mingar",
    "mingará": "mingar",
    "mingarás": "mingar",
    "mingarão": "mingar",
    "mingaríamos": "mingar",
    "mingaríeis": "mingar",
    "mingas": "mingar",
    "mingasse": "mingar",
    "mingassem": "mingar",
    "mingasses": "mingar",
    "mingaste": "mingar",
    "mingastes": "mingar",
    "mingaus": "mingau",
    "mingava": "mingar",
    "mingavam": "mingar",
    "mingavas": "mingar",
    "mingo": "mingar",
    "mingou": "mingar",
    "mingua": "minguar",
    "minguada": "minguar",
    "minguadas": "minguar",
    "minguado": "minguar",
    "minguados": "minguar",
    "minguai": "minguar",
    "minguais": "minguar",
    "minguam": "minguar",
    "minguamo": "minguar",
    "minguamos": "minguar",
    "minguando": "minguar",
    "minguantes": "minguante",
    "minguara": "minguar",
    "minguaram": "minguar",
    "minguaras": "minguar",
    "minguardes": "minguar",
    "minguarei": "minguar",
    "minguareis": "minguar",
    "minguarem": "minguar",
    "minguaremos": "minguar",
    "minguares": "minguar",
    "minguaria": "minguar",
    "minguariam": "minguar",
    "minguarias": "minguar",
    "minguarmo": "minguar",
    "minguarmos": "minguar",
    "minguará": "minguar",
    "minguarás": "minguar",
    "minguarão": "minguar",
    "minguaríamos": "minguar",
    "minguaríeis": "minguar",
    "minguas": "minguar",
    "minguasse": "minguar",
    "minguassem": "minguar",
    "minguasses": "minguar",
    "minguaste": "minguar",
    "minguastes": "minguar",
    "minguava": "minguar",
    "minguavam": "minguar",
    "minguavas": "minguar",
    "mingue": "mingar",
    "minguei": "minguar",
    "mingueis": "minguar",
    "minguem": "mingar",
    "minguemo": "minguar",
    "minguemos": "minguar",
    "mingues": "minguar",
    "minguo": "minguar",
    "minguou": "minguar",
    "minguámo": "minguar",
    "minguámos": "minguar",
    "minguáramo": "minguar",
    "minguáramos": "minguar",
    "minguáreis": "minguar",
    "minguásseis": "minguar",
    "minguássemos": "minguar",
    "minguávamo": "minguar",
    "minguávamos": "minguar",
    "minguáveis": "minguar",
    "mingá": "mingar",
    "mingámo": "mingar",
    "mingámos": "mingar",
    "mingáramo": "mingar",
    "mingáramos": "mingar",
    "mingárei": "mingar",
    "mingáreis": "mingar",
    "mingásseis": "mingar",
    "mingássemos": "mingar",
    "mingávamo": "mingar",
    "mingávamos": "mingar",
    "mingávei": "mingar",
    "mingáveis": "mingar",
    "mingúe": "minguar",
    "mingúem": "minguar",
    "mingúes": "minguar",
    "minha": "meu",
    "minhafres": "minhafre",
    "minhas": "meu",
    "minhocas": "minhoca",
    "minhocass": "minhocas",
    "minhocões": "minhocão",
    "minhonetas": "minhoneta",
    "minhoquices": "minhoquice",
    "minhota": "minhoto",
    "minhotas": "minhoto",
    "minhoteira": "minhoteiro",
    "minhoteiras": "minhoteiro",
    "minhoteiros": "minhoteiro",
    "minhotismos": "minhotismo",
    "minhotos": "minhoto",
    "miniatura": "miniaturar",
    "miniaturada": "miniaturar",
    "miniaturadas": "miniaturar",
    "miniaturado": "miniaturar",
    "miniaturados": "miniaturar",
    "miniaturai": "miniaturar",
    "miniaturais": "miniaturar",
    "miniaturam": "miniaturar",
    "miniaturamo": "miniaturar",
    "miniaturamos": "miniaturar",
    "miniaturando": "miniaturar",
    "miniaturara": "miniaturar",
    "miniaturaram": "miniaturar",
    "miniaturaras": "miniaturar",
    "miniaturarde": "miniaturar",
    "miniaturardes": "miniaturar",
    "miniaturare": "miniaturar",
    "miniaturarei": "miniaturar",
    "miniaturareis": "miniaturar",
    "miniaturarem": "miniaturar",
    "miniaturaremos": "miniaturar",
    "miniaturares": "miniaturar",
    "miniaturaria": "miniaturar",
    "miniaturariam": "miniaturar",
    "miniaturarias": "miniaturar",
    "miniaturarmo": "miniaturar",
    "miniaturarmos": "miniaturar",
    "miniaturará": "miniaturar",
    "miniaturarás": "miniaturar",
    "miniaturarão": "miniaturar",
    "miniaturaríamos": "miniaturar",
    "miniaturaríeis": "miniaturar",
    "miniaturas": "miniaturar",
    "miniaturasse": "miniaturar",
    "miniaturassem": "miniaturar",
    "miniaturasses": "miniaturar",
    "miniaturaste": "miniaturar",
    "miniaturastes": "miniaturar",
    "miniaturava": "miniaturar",
    "miniaturavam": "miniaturar",
    "miniaturavas": "miniaturar",
    "miniature": "miniaturar",
    "miniaturei": "miniaturar",
    "miniatureis": "miniaturar",
    "miniaturem": "miniaturar",
    "miniaturemo": "miniaturar",
    "miniaturemos": "miniaturar",
    "miniatures": "miniaturar",
    "miniaturismos": "miniaturismo",
    "miniaturistas": "miniaturista",
    "miniaturiza": "miniaturizar",
    "miniaturizada": "miniaturizar",
    "miniaturizadas": "miniaturizar",
    "miniaturizado": "miniaturizar",
    "miniaturizados": "miniaturizar",
    "miniaturizai": "miniaturizar",
    "miniaturizais": "miniaturizar",
    "miniaturizam": "miniaturizar",
    "miniaturizamo": "miniaturizar",
    "miniaturizamos": "miniaturizar",
    "miniaturizando": "miniaturizar",
    "miniaturizara": "miniaturizar",
    "miniaturizaram": "miniaturizar",
    "miniaturizaras": "miniaturizar",
    "miniaturizarde": "miniaturizar",
    "miniaturizardes": "miniaturizar",
    "miniaturizare": "miniaturizar",
    "miniaturizarei": "miniaturizar",
    "miniaturizareis": "miniaturizar",
    "miniaturizarem": "miniaturizar",
    "miniaturizaremos": "miniaturizar",
    "miniaturizares": "miniaturizar",
    "miniaturizaria": "miniaturizar",
    "miniaturizariam": "miniaturizar",
    "miniaturizarias": "miniaturizar",
    "miniaturizarmo": "miniaturizar",
    "miniaturizarmos": "miniaturizar",
    "miniaturizará": "miniaturizar",
    "miniaturizarás": "miniaturizar",
    "miniaturizarão": "miniaturizar",
    "miniaturizaríamos": "miniaturizar",
    "miniaturizaríeis": "miniaturizar",
    "miniaturizas": "miniaturizar",
    "miniaturizasse": "miniaturizar",
    "miniaturizassem": "miniaturizar",
    "miniaturizasses": "miniaturizar",
    "miniaturizaste": "miniaturizar",
    "miniaturizastes": "miniaturizar",
    "miniaturizava": "miniaturizar",
    "miniaturizavam": "miniaturizar",
    "miniaturizavas": "miniaturizar",
    "miniaturizações": "miniaturização",
    "miniaturize": "miniaturizar",
    "miniaturizei": "miniaturizar",
    "miniaturizeis": "miniaturizar",
    "miniaturizem": "miniaturizar",
    "miniaturizemo": "miniaturizar",
    "miniaturizemos": "miniaturizar",
    "miniaturizes": "miniaturizar",
    "miniaturizo": "miniaturizar",
    "miniaturizou": "miniaturizar",
    "miniaturizá": "miniaturizar",
    "miniaturizámo": "miniaturizar",
    "miniaturizámos": "miniaturizar",
    "miniaturizáramo": "miniaturizar",
    "miniaturizáramos": "miniaturizar",
    "miniaturizárei": "miniaturizar",
    "miniaturizáreis": "miniaturizar",
    "miniaturizásseis": "miniaturizar",
    "miniaturizássemos": "miniaturizar",
    "miniaturizávamo": "miniaturizar",
    "miniaturizávamos": "miniaturizar",
    "miniaturizávei": "miniaturizar",
    "miniaturizáveis": "miniaturizável",
    "miniaturo": "miniaturar",
    "miniaturou": "miniaturar",
    "miniaturá": "miniaturar",
    "miniaturámo": "miniaturar",
    "miniaturámos": "miniaturar",
    "miniaturáramo": "miniaturar",
    "miniaturáramos": "miniaturar",
    "miniaturárei": "miniaturar",
    "miniaturáreis": "miniaturar",
    "miniaturásseis": "miniaturar",
    "miniaturássemos": "miniaturar",
    "miniaturávamo": "miniaturar",
    "miniaturávamos": "miniaturar",
    "miniaturávei": "miniaturar",
    "miniaturáveis": "miniaturar",
    "minibibliotecas": "minibiblioteca",
    "minicalculadoras": "minicalculadora",
    "minicaminhões": "minicaminhão",
    "minicampeonatos": "minicampeonato",
    "minicasacos": "minicasaco",
    "minicimeiras": "minicimeira",
    "minicomputadores": "minicomputador",
    "minicomícios": "minicomício",
    "miniconcertos": "miniconcerto",
    "miniconcursos": "miniconcurso",
    "miniconferências": "miniconferência",
    "minicontos": "miniconto",
    "minicursos": "minicurso",
    "minidesvalorizações": "minidesvalorização",
    "minifundiária": "minifundiário",
    "minifundiárias": "minifundiário",
    "minifundiários": "minifundiário",
    "minifúndios": "minifúndio",
    "minijardins": "minijardim",
    "minimais": "minimal",
    "minimalismos": "minimalismo",
    "minimalistas": "minimalista",
    "minimantes": "minimante",
    "minimaratonas": "minimaratona",
    "minimatistas": "minimatista",
    "minimercados": "minimercado",
    "minimidades": "minimidade",
    "minimiza": "minimizar",
    "minimizada": "minimizar",
    "minimizadas": "minimizar",
    "minimizado": "minimizar",
    "minimizados": "minimizar",
    "minimizai": "minimizar",
    "minimizais": "minimizar",
    "minimizam": "minimizar",
    "minimizamo": "minimizar",
    "minimizamos": "minimizar",
    "minimizando": "minimizar",
    "minimizara": "minimizar",
    "minimizaram": "minimizar",
    "minimizaras": "minimizar",
    "minimizarde": "minimizar",
    "minimizardes": "minimizar",
    "minimizare": "minimizar",
    "minimizarei": "minimizar",
    "minimizareis": "minimizar",
    "minimizarem": "minimizar",
    "minimizaremos": "minimizar",
    "minimizares": "minimizar",
    "minimizaria": "minimizar",
    "minimizariam": "minimizar",
    "minimizarias": "minimizar",
    "minimizarmo": "minimizar",
    "minimizarmos": "minimizar",
    "minimizará": "minimizar",
    "minimizarás": "minimizar",
    "minimizarão": "minimizar",
    "minimizaríamos": "minimizar",
    "minimizaríeis": "minimizar",
    "minimizas": "minimizar",
    "minimizasse": "minimizar",
    "minimizassem": "minimizar",
    "minimizasses": "minimizar",
    "minimizaste": "minimizar",
    "minimizastes": "minimizar",
    "minimizava": "minimizar",
    "minimizavam": "minimizar",
    "minimizavas": "minimizar",
    "minimizações": "minimização",
    "minimize": "minimizar",
    "minimizei": "minimizar",
    "minimizeis": "minimizar",
    "minimizem": "minimizar",
    "minimizemo": "minimizar",
    "minimizemos": "minimizar",
    "minimizes": "minimizar",
    "minimizo": "minimizar",
    "minimizou": "minimizar",
    "minimizá": "minimizar",
    "minimizámo": "minimizar",
    "minimizámos": "minimizar",
    "minimizáramo": "minimizar",
    "minimizáramos": "minimizar",
    "minimizárei": "minimizar",
    "minimizáreis": "minimizar",
    "minimizásseis": "minimizar",
    "minimizássemos": "minimizar",
    "minimizávamo": "minimizar",
    "minimizávamos": "minimizar",
    "minimizávei": "minimizar",
    "minimizáveis": "minimizável",
    "minissaias": "minissaia",
    "minissubmarinos": "minissubmarino",
    "ministeriais": "ministerial",
    "ministerialismos": "ministerialismo",
    "ministerialistas": "ministerialista",
    "ministeriáveis": "ministeriável",
    "ministra": "ministro",
    "ministrada": "ministrar",
    "ministradas": "ministrar",
    "ministrado": "ministrar",
    "ministradora": "ministrador",
    "ministradoras": "ministrador",
    "ministradores": "ministrador",
    "ministrados": "ministrar",
    "ministrai": "ministrar",
    "ministrais": "ministrar",
    "ministram": "ministrar",
    "ministramo": "ministrar",
    "ministramos": "ministrar",
    "ministrando": "ministrar",
    "ministrantes": "ministrante",
    "ministrara": "ministrar",
    "ministraram": "ministrar",
    "ministraras": "ministrar",
    "ministrarde": "ministrar",
    "ministrardes": "ministrar",
    "ministrare": "ministrar",
    "ministrarei": "ministrar",
    "ministrareis": "ministrar",
    "ministrarem": "ministrar",
    "ministraremos": "ministrar",
    "ministrares": "ministrar",
    "ministraria": "ministrar",
    "ministrariam": "ministrar",
    "ministrarias": "ministraria",
    "ministrarmo": "ministrar",
    "ministrarmos": "ministrar",
    "ministrará": "ministrar",
    "ministrarás": "ministrar",
    "ministrarão": "ministrar",
    "ministraríamos": "ministrar",
    "ministraríeis": "ministrar",
    "ministras": "ministro",
    "ministrasse": "ministrar",
    "ministrassem": "ministrar",
    "ministrasses": "ministrar",
    "ministraste": "ministrar",
    "ministrastes": "ministrar",
    "ministrava": "ministrar",
    "ministravam": "ministrar",
    "ministravas": "ministrar",
    "ministre": "ministrar",
    "ministrei": "ministrar",
    "ministreis": "ministrar",
    "ministrem": "ministrar",
    "ministremo": "ministrar",
    "ministremos": "ministrar",
    "ministres": "ministrar",
    "ministrificações": "ministrificação",
    "ministro": "ministrar",
    "ministros": "ministro",
    "ministrou": "ministrar",
    "ministrá": "ministrar",
    "ministrámo": "ministrar",
    "ministrámos": "ministrar",
    "ministráramo": "ministrar",
    "ministráramos": "ministrar",
    "ministrárei": "ministrar",
    "ministráreis": "ministrar",
    "ministrásseis": "ministrar",
    "ministrássemos": "ministrar",
    "ministrávamo": "ministrar",
    "ministrávamos": "ministrar",
    "ministrávei": "ministrar",
    "ministráveis": "ministrável",
    "ministérios": "ministério",
    "minivestidos": "minivestido",
    "mino": "minar",
    "minora": "minorar",
    "minorada": "minorar",
    "minoradas": "minorar",
    "minorado": "minorar",
    "minorados": "minorar",
    "minorai": "minorar",
    "minorais": "minorar",
    "minoram": "minorar",
    "minoramo": "minorar",
    "minoramos": "minorar",
    "minorando": "minorar",
    "minorantes": "minorante",
    "minorara": "minorar",
    "minoraram": "minorar",
    "minoraras": "minorar",
    "minorarde": "minorar",
    "minorardes": "minorar",
    "minorare": "minorar",
    "minorarei": "minorar",
    "minorareis": "minorar",
    "minorarem": "minorar",
    "minoraremos": "minorar",
    "minorares": "minorar",
    "minoraria": "minorar",
    "minorariam": "minorar",
    "minorarias": "minorar",
    "minorarmo": "minorar",
    "minorarmos": "minorar",
    "minorará": "minorar",
    "minorarás": "minorar",
    "minorarão": "minorar",
    "minoraríamos": "minorar",
    "minoraríeis": "minorar",
    "minoras": "minorar",
    "minorasse": "minorar",
    "minorassem": "minorar",
    "minorasses": "minorar",
    "minoraste": "minorar",
    "minorastes": "minorar",
    "minorativa": "minorativo",
    "minorativas": "minorativo",
    "minorativos": "minorativo",
    "minorava": "minorar",
    "minoravam": "minorar",
    "minoravas": "minorar",
    "minorações": "minoração",
    "minorcas": "minorca",
    "minore": "minorar",
    "minorei": "minorar",
    "minoreis": "minorar",
    "minorem": "minorar",
    "minoremo": "minorar",
    "minoremos": "minorar",
    "minores": "minorar",
    "minorias": "minoria",
    "minoriazinha": "minoria",
    "minoriazinhas": "minoria",
    "minoriazita": "minoria",
    "minoriazitas": "minoria",
    "minoristas": "minorista",
    "minoritas": "minorita",
    "minoritária": "minoritário",
    "minoritárias": "minoritário",
    "minoritários": "minoritário",
    "minoro": "minorar",
    "minorou": "minorar",
    "minorquina": "minorquino",
    "minorquinas": "minorquino",
    "minorquinos": "minorquino",
    "minorá": "minorar",
    "minorámo": "minorar",
    "minorámos": "minorar",
    "minoráramo": "minorar",
    "minoráramos": "minorar",
    "minorárei": "minorar",
    "minoráreis": "minorar",
    "minorásseis": "minorar",
    "minorássemos": "minorar",
    "minorávamo": "minorar",
    "minorávamos": "minorar",
    "minorávei": "minorar",
    "minoráveis": "minorável",
    "minotauriza": "minotaurizar",
    "minotaurizada": "minotaurizar",
    "minotaurizadas": "minotaurizar",
    "minotaurizado": "minotaurizar",
    "minotaurizados": "minotaurizar",
    "minotaurizai": "minotaurizar",
    "minotaurizais": "minotaurizar",
    "minotaurizam": "minotaurizar",
    "minotaurizamo": "minotaurizar",
    "minotaurizamos": "minotaurizar",
    "minotaurizando": "minotaurizar",
    "minotaurizara": "minotaurizar",
    "minotaurizaram": "minotaurizar",
    "minotaurizaras": "minotaurizar",
    "minotaurizarde": "minotaurizar",
    "minotaurizardes": "minotaurizar",
    "minotaurizare": "minotaurizar",
    "minotaurizarei": "minotaurizar",
    "minotaurizareis": "minotaurizar",
    "minotaurizarem": "minotaurizar",
    "minotaurizaremos": "minotaurizar",
    "minotaurizares": "minotaurizar",
    "minotaurizaria": "minotaurizar",
    "minotaurizariam": "minotaurizar",
    "minotaurizarias": "minotaurizar",
    "minotaurizarmo": "minotaurizar",
    "minotaurizarmos": "minotaurizar",
    "minotaurizará": "minotaurizar",
    "minotaurizarás": "minotaurizar",
    "minotaurizarão": "minotaurizar",
    "minotaurizaríamos": "minotaurizar",
    "minotaurizaríeis": "minotaurizar",
    "minotaurizas": "minotaurizar",
    "minotaurizasse": "minotaurizar",
    "minotaurizassem": "minotaurizar",
    "minotaurizasses": "minotaurizar",
    "minotaurizaste": "minotaurizar",
    "minotaurizastes": "minotaurizar",
    "minotaurizava": "minotaurizar",
    "minotaurizavam": "minotaurizar",
    "minotaurizavas": "minotaurizar",
    "minotaurize": "minotaurizar",
    "minotaurizei": "minotaurizar",
    "minotaurizeis": "minotaurizar",
    "minotaurizem": "minotaurizar",
    "minotaurizemo": "minotaurizar",
    "minotaurizemos": "minotaurizar",
    "minotaurizes": "minotaurizar",
    "minotaurizo": "minotaurizar",
    "minotaurizou": "minotaurizar",
    "minotaurizá": "minotaurizar",
    "minotaurizámo": "minotaurizar",
    "minotaurizámos": "minotaurizar",
    "minotaurizáramo": "minotaurizar",
    "minotaurizáramos": "minotaurizar",
    "minotaurizárei": "minotaurizar",
    "minotaurizáreis": "minotaurizar",
    "minotaurizásseis": "minotaurizar",
    "minotaurizássemos": "minotaurizar",
    "minotaurizávamo": "minotaurizar",
    "minotaurizávamos": "minotaurizar",
    "minotaurizávei": "minotaurizar",
    "minotaurizáveis": "minotaurizar",
    "minotauros": "minotauro",
    "minou": "minar",
    "minta": "mentir",
    "mintais": "mentir",
    "mintam": "mentir",
    "mintamo": "mentir",
    "mintamos": "mentir",
    "mintas": "mentir",
    "minto": "mentir",
    "minua": "minuir",
    "minuais": "minuir",
    "minuam": "minuir",
    "minuamo": "minuir",
    "minuamos": "minuir",
    "minuas": "minuir",
    "minuciosa": "minucioso",
    "minuciosas": "minucioso",
    "minuciosidades": "minuciosidade",
    "minuciosos": "minucioso",
    "minuciosíssima": "minucioso",
    "minuciosíssimas": "minucioso",
    "minuciosíssimo": "minucioso",
    "minuciosíssimos": "minucioso",
    "minuda": "minudar",
    "minudada": "minudar",
    "minudadas": "minudar",
    "minudado": "minudar",
    "minudados": "minudar",
    "minudai": "minudar",
    "minudais": "minudar",
    "minudam": "minudar",
    "minudamo": "minudar",
    "minudamos": "minudar",
    "minudando": "minudar",
    "minudara": "minudar",
    "minudaram": "minudar",
    "minudaras": "minudar",
    "minudarde": "minudar",
    "minudardes": "minudar",
    "minudare": "minudar",
    "minudarei": "minudar",
    "minudareis": "minudar",
    "minudarem": "minudar",
    "minudaremos": "minudar",
    "minudares": "minudar",
    "minudaria": "minudar",
    "minudariam": "minudar",
    "minudarias": "minudar",
    "minudarmo": "minudar",
    "minudarmos": "minudar",
    "minudará": "minudar",
    "minudarás": "minudar",
    "minudarão": "minudar",
    "minudaríamos": "minudar",
    "minudaríeis": "minudar",
    "minudas": "minudar",
    "minudasse": "minudar",
    "minudassem": "minudar",
    "minudasses": "minudar",
    "minudaste": "minudar",
    "minudastes": "minudar",
    "minudava": "minudar",
    "minudavam": "minudar",
    "minudavas": "minudar",
    "minude": "minudar",
    "minudeada": "minudear",
    "minudeadas": "minudear",
    "minudeado": "minudear",
    "minudeados": "minudear",
    "minudeai": "minudear",
    "minudeais": "minudear",
    "minudeamo": "minudear",
    "minudeamos": "minudear",
    "minudeando": "minudear",
    "minudeara": "minudear",
    "minudearam": "minudear",
    "minudearas": "minudear",
    "minudearde": "minudear",
    "minudeardes": "minudear",
    "minudeare": "minudear",
    "minudearei": "minudear",
    "minudeareis": "minudear",
    "minudearem": "minudear",
    "minudearemos": "minudear",
    "minudeares": "minudear",
    "minudearia": "minudear",
    "minudeariam": "minudear",
    "minudearias": "minudear",
    "minudearmo": "minudear",
    "minudearmos": "minudear",
    "minudeará": "minudear",
    "minudearás": "minudear",
    "minudearão": "minudear",
    "minudearíamos": "minudear",
    "minudearíeis": "minudear",
    "minudeasse": "minudear",
    "minudeassem": "minudear",
    "minudeasses": "minudear",
    "minudeaste": "minudear",
    "minudeastes": "minudear",
    "minudeava": "minudear",
    "minudeavam": "minudear",
    "minudeavas": "minudear",
    "minudeei": "minudear",
    "minudeeis": "minudear",
    "minudeemo": "minudear",
    "minudeemos": "minudear",
    "minudei": "minudar",
    "minudeia": "minudear",
    "minudeiam": "minudear",
    "minudeias": "minudear",
    "minudeie": "minudear",
    "minudeiem": "minudear",
    "minudeies": "minudear",
    "minudeio": "minudear",
    "minudeis": "minudar",
    "minudem": "minudar",
    "minudemo": "minudar",
    "minudemos": "minudar",
    "minudencia": "minudenciar",
    "minudenciada": "minudenciar",
    "minudenciadas": "minudenciar",
    "minudenciado": "minudenciar",
    "minudenciados": "minudenciar",
    "minudenciai": "minudenciar",
    "minudenciais": "minudenciar",
    "minudenciam": "minudenciar",
    "minudenciamo": "minudenciar",
    "minudenciamos": "minudenciar",
    "minudenciando": "minudenciar",
    "minudenciara": "minudenciar",
    "minudenciaram": "minudenciar",
    "minudenciaras": "minudenciar",
    "minudenciarde": "minudenciar",
    "minudenciardes": "minudenciar",
    "minudenciare": "minudenciar",
    "minudenciarei": "minudenciar",
    "minudenciareis": "minudenciar",
    "minudenciarem": "minudenciar",
    "minudenciaremos": "minudenciar",
    "minudenciares": "minudenciar",
    "minudenciaria": "minudenciar",
    "minudenciariam": "minudenciar",
    "minudenciarias": "minudenciar",
    "minudenciarmo": "minudenciar",
    "minudenciarmos": "minudenciar",
    "minudenciará": "minudenciar",
    "minudenciarás": "minudenciar",
    "minudenciarão": "minudenciar",
    "minudenciaríamos": "minudenciar",
    "minudenciaríeis": "minudenciar",
    "minudencias": "minudenciar",
    "minudenciasse": "minudenciar",
    "minudenciassem": "minudenciar",
    "minudenciasses": "minudenciar",
    "minudenciaste": "minudenciar",
    "minudenciastes": "minudenciar",
    "minudenciava": "minudenciar",
    "minudenciavam": "minudenciar",
    "minudenciavas": "minudenciar",
    "minudencie": "minudenciar",
    "minudenciei": "minudenciar",
    "minudencieis": "minudenciar",
    "minudenciem": "minudenciar",
    "minudenciemo": "minudenciar",
    "minudenciemos": "minudenciar",
    "minudencies": "minudenciar",
    "minudencio": "minudenciar",
    "minudenciosa": "minudencioso",
    "minudenciosas": "minudencioso",
    "minudenciosos": "minudencioso",
    "minudenciou": "minudenciar",
    "minudenciá": "minudenciar",
    "minudenciámo": "minudenciar",
    "minudenciámos": "minudenciar",
    "minudenciáramo": "minudenciar",
    "minudenciáramos": "minudenciar",
    "minudenciárei": "minudenciar",
    "minudenciáreis": "minudenciar",
    "minudenciásseis": "minudenciar",
    "minudenciássemos": "minudenciar",
    "minudenciávamo": "minudenciar",
    "minudenciávamos": "minudenciar",
    "minudenciávei": "minudenciar",
    "minudenciáveis": "minudenciar",
    "minudentes": "minudente",
    "minudeou": "minudear",
    "minudes": "minudar",
    "minudeá": "minudear",
    "minudeámo": "minudear",
    "minudeámos": "minudear",
    "minudeáramo": "minudear",
    "minudeáramos": "minudear",
    "minudeárei": "minudear",
    "minudeáreis": "minudear",
    "minudeásseis": "minudear",
    "minudeássemos": "minudear",
    "minudeávamo": "minudear",
    "minudeávamos": "minudear",
    "minudeávei": "minudear",
    "minudeáveis": "minudear",
    "minudo": "minudar",
    "minudou": "minudar",
    "minudá": "minudar",
    "minudámo": "minudar",
    "minudámos": "minudar",
    "minudáramo": "minudar",
    "minudáramos": "minudar",
    "minudárei": "minudar",
    "minudáreis": "minudar",
    "minudásseis": "minudar",
    "minudássemos": "minudar",
    "minudávamo": "minudar",
    "minudávamos": "minudar",
    "minudávei": "minudar",
    "minudáveis": "minudar",
    "minudências": "minudência",
    "minuem": "minuir",
    "minuetes": "minuete",
    "minuetos": "minueto",
    "minui": "minuir",
    "minuindo": "minuir",
    "minuirde": "minuir",
    "minuirdes": "minuir",
    "minuirei": "minuir",
    "minuireis": "minuir",
    "minuiremos": "minuir",
    "minuiria": "minuir",
    "minuiriam": "minuir",
    "minuirias": "minuir",
    "minuirmo": "minuir",
    "minuirmos": "minuir",
    "minuirá": "minuir",
    "minuirás": "minuir",
    "minuirão": "minuir",
    "minuiríamos": "minuir",
    "minuiríeis": "minuir",
    "minuis": "minuir",
    "minuiu": "minuir",
    "minuo": "minuir",
    "minuta": "minutar",
    "minutada": "minutar",
    "minutadas": "minutar",
    "minutado": "minutar",
    "minutadora": "minutador",
    "minutadoras": "minutador",
    "minutadores": "minutador",
    "minutados": "minutar",
    "minutai": "minutar",
    "minutais": "minutar",
    "minutam": "minutar",
    "minutamo": "minutar",
    "minutamos": "minutar",
    "minutando": "minutar",
    "minutara": "minutar",
    "minutaram": "minutar",
    "minutaras": "minutar",
    "minutarde": "minutar",
    "minutardes": "minutar",
    "minutare": "minutar",
    "minutarei": "minutar",
    "minutareis": "minutar",
    "minutarem": "minutar",
    "minutaremos": "minutar",
    "minutares": "minutar",
    "minutaria": "minutar",
    "minutariam": "minutar",
    "minutarias": "minutar",
    "minutarmo": "minutar",
    "minutarmos": "minutar",
    "minutará": "minutar",
    "minutarás": "minutar",
    "minutarão": "minutar",
    "minutaríamos": "minutar",
    "minutaríeis": "minutar",
    "minutas": "minutar",
    "minutasse": "minutar",
    "minutassem": "minutar",
    "minutasses": "minutar",
    "minutaste": "minutar",
    "minutastes": "minutar",
    "minutava": "minutar",
    "minutavam": "minutar",
    "minutavas": "minutar",
    "minute": "minutar",
    "minutei": "minutar",
    "minuteis": "minutar",
    "minutem": "minutar",
    "minutemo": "minutar",
    "minutemos": "minutar",
    "minutes": "minutar",
    "minutinho": "minuto",
    "minutinhos": "minuto",
    "minutito": "minuto",
    "minutitos": "minuto",
    "minuto": "minutar",
    "minutora": "minutor",
    "minutoras": "minutor",
    "minutores": "minutor",
    "minutos": "minuto",
    "minutou": "minutar",
    "minutá": "minutar",
    "minutámo": "minutar",
    "minutámos": "minutar",
    "minutáramo": "minutar",
    "minutáramos": "minutar",
    "minutárei": "minutar",
    "minutáreis": "minutar",
    "minutásseis": "minutar",
    "minutássemos": "minutar",
    "minutávamo": "minutar",
    "minutávamos": "minutar",
    "minutávei": "minutar",
    "minutáveis": "minutar",
    "minuí": "minuir",
    "minuía": "minuir",
    "minuíam": "minuir",
    "minuíamo": "minuir",
    "minuíamos": "minuir",
    "minuías": "minuir",
    "minuída": "minuir",
    "minuídas": "minuir",
    "minuído": "minuir",
    "minuídos": "minuir",
    "minuíei": "minuir",
    "minuíeis": "minuir",
    "minuímo": "minuir",
    "minuímos": "minuir",
    "minuíra": "minuir",
    "minuíram": "minuir",
    "minuíramo": "minuir",
    "minuíramos": "minuir",
    "minuíras": "minuir",
    "minuíre": "minuir",
    "minuírei": "minuir",
    "minuíreis": "minuir",
    "minuírem": "minuir",
    "minuíres": "minuir",
    "minuís": "minuir",
    "minuísse": "minuir",
    "minuísseis": "minuir",
    "minuíssem": "minuir",
    "minuíssemos": "minuir",
    "minuísses": "minuir",
    "minuíste": "minuir",
    "minuístes": "minuir",
    "miná": "minar",
    "minámo": "minar",
    "minámos": "minar",
    "mináramo": "minar",
    "mináramos": "minar",
    "minárei": "minar",
    "mináreis": "minar",
    "minásseis": "minar",
    "minássemos": "minar",
    "minávamo": "minar",
    "minávamos": "minar",
    "minávei": "minar",
    "mináveis": "minável",
    "minérios": "minério",
    "minúcias": "minúcia",
    "minúscula": "minúsculo",
    "minúsculas": "minúsculo",
    "minúsculos": "minúsculo",
    "mio": "miar",
    "miocardites": "miocardite",
    "miocena": "mioceno",
    "miocenas": "mioceno",
    "miocenos": "mioceno",
    "mioclonias": "mioclonia",
    "miocárdios": "miocárdio",
    "miocénica": "miocénico",
    "miocénicas": "miocénico",
    "miocénicos": "miocénico",
    "miodinias": "miodinia",
    "miodopsias": "miodopsia",
    "mioepiteliais": "mioepitelial",
    "miografias": "miografia",
    "miogramas": "miograma",
    "mioladas": "miolada",
    "mioleiras": "mioleira",
    "miolemas": "miolema",
    "miolinho": "miolo",
    "miolinhos": "miolo",
    "miolito": "miolo",
    "miolitos": "miolo",
    "miologias": "miologia",
    "miolos": "miolo",
    "miolosa": "mioloso",
    "miolosas": "mioloso",
    "miolosos": "mioloso",
    "mioluda": "mioludo",
    "mioludas": "mioludo",
    "mioludos": "mioludo",
    "miomalacias": "miomalacia",
    "miomas": "mioma",
    "miometrites": "miometrite",
    "miomorfos": "miomorfo",
    "miométrios": "miométrio",
    "miopatias": "miopatia",
    "miopezinha": "míope",
    "miopezinhas": "míope",
    "miopezinho": "míope",
    "miopezinhos": "míope",
    "miopezita": "míope",
    "miopezitas": "míope",
    "miopezito": "míope",
    "miopezitos": "míope",
    "miopias": "miopia",
    "mioplasmas": "mioplasma",
    "mioplastias": "mioplastia",
    "mioplegias": "mioplegia",
    "mioporáceas": "mioporácea",
    "mioporínea": "mioporíneo",
    "mioporíneas": "mioporíneo",
    "mioporíneos": "mioporíneo",
    "miopresbitas": "miopresbita",
    "miopótamos": "miopótamo",
    "miorragias": "miorragia",
    "mios": "mio",
    "miosalgias": "miosalgia",
    "mioses": "miose",
    "miosinas": "miosina",
    "miosites": "miosite",
    "miosotas": "miosota",
    "miosótides": "miosótide",
    "miotomias": "miotomia",
    "miotos": "mioto",
    "miou": "miar",
    "miqueletes": "miquelete",
    "mira": "mirar",
    "mirabolantes": "mirabolante",
    "mirabolâncias": "mirabolância",
    "miracula": "miracular",
    "miraculada": "miracular",
    "miraculadas": "miracular",
    "miraculado": "miracular",
    "miraculados": "miracular",
    "miraculai": "miracular",
    "miraculais": "miracular",
    "miraculam": "miracular",
    "miraculamo": "miracular",
    "miraculamos": "miracular",
    "miraculando": "miracular",
    "miraculara": "miracular",
    "miracularam": "miracular",
    "miracularas": "miracular",
    "miracularde": "miracular",
    "miraculardes": "miracular",
    "miraculare": "miracular",
    "miracularei": "miracular",
    "miraculareis": "miracular",
    "miracularem": "miracular",
    "miracularemos": "miracular",
    "miraculares": "miracular",
    "miracularia": "miracular",
    "miraculariam": "miracular",
    "miracularias": "miracular",
    "miracularmo": "miracular",
    "miracularmos": "miracular",
    "miraculará": "miracular",
    "miracularás": "miracular",
    "miracularão": "miracular",
    "miracularíamos": "miracular",
    "miracularíeis": "miracular",
    "miraculas": "miracular",
    "miraculasse": "miracular",
    "miraculassem": "miracular",
    "miraculasses": "miracular",
    "miraculaste": "miracular",
    "miraculastes": "miracular",
    "miraculava": "miracular",
    "miraculavam": "miracular",
    "miraculavas": "miracular",
    "miracule": "miracular",
    "miraculei": "miracular",
    "miraculeis": "miracular",
    "miraculem": "miracular",
    "miraculemo": "miracular",
    "miraculemos": "miracular",
    "miracules": "miracular",
    "miraculo": "miracular",
    "miraculosa": "miraculoso",
    "miraculosas": "miraculoso",
    "miraculosos": "miraculoso",
    "miraculou": "miracular",
    "miraculá": "miracular",
    "miraculámo": "miracular",
    "miraculámos": "miracular",
    "miraculáramo": "miracular",
    "miraculáramos": "miracular",
    "miraculárei": "miracular",
    "miraculáreis": "miracular",
    "miraculásseis": "miracular",
    "miraculássemos": "miracular",
    "miraculávamo": "miracular",
    "miraculávamos": "miracular",
    "miraculávei": "miracular",
    "miraculáveis": "miracular",
    "mirada": "mirar",
    "miradas": "mirar",
    "mirado": "mirar",
    "miradoiros": "miradoiro",
    "mirados": "mirar",
    "miradouros": "miradouro",
    "miragens": "miragem",
    "mirai": "mirar",
    "mirais": "mirar",
    "miralmunimins": "miralmunimim",
    "miram": "mirar",
    "miramo": "mirar",
    "miramolins": "miramolim",
    "miramos": "mirar",
    "mirandelenses": "mirandelense",
    "mirandenses": "mirandense",
    "mirandesa": "mirandês",
    "mirandesas": "mirandês",
    "mirandeses": "mirandês",
    "mirando": "mirar",
    "mirantes": "mirante",
    "mirara": "mirar",
    "miraram": "mirar",
    "miraras": "mirar",
    "mirarde": "mirar",
    "mirardes": "mirar",
    "mirare": "mirar",
    "mirarei": "mirar",
    "mirareis": "mirar",
    "mirarem": "mirar",
    "miraremos": "mirar",
    "mirares": "mirar",
    "miraria": "mirar",
    "mirariam": "mirar",
    "mirarias": "mirar",
    "mirarmo": "mirar",
    "mirarmos": "mirar",
    "mirará": "mirar",
    "mirarás": "mirar",
    "mirarão": "mirar",
    "miraríamos": "mirar",
    "miraríeis": "mirar",
    "miras": "mirar",
    "mirasse": "mirar",
    "mirassem": "mirar",
    "mirasses": "mirar",
    "miraste": "mirar",
    "mirastes": "mirar",
    "mirava": "mirar",
    "miravam": "mirar",
    "miravas": "mirar",
    "mire": "mirar",
    "mirei": "mirar",
    "mireis": "mirar",
    "mirem": "mirar",
    "miremo": "mirar",
    "miremos": "mirar",
    "mires": "mirar",
    "miriagramas": "miriagrama",
    "mirialitros": "mirialitro",
    "miriares": "miriare",
    "miriasteres": "miriastere",
    "miriastéreos": "miriastéreo",
    "miricáceas": "miricácea",
    "mirifica": "mirificar",
    "mirificada": "mirificar",
    "mirificadas": "mirificar",
    "mirificado": "mirificar",
    "mirificados": "mirificar",
    "mirificai": "mirificar",
    "mirificais": "mirificar",
    "mirificam": "mirificar",
    "mirificamo": "mirificar",
    "mirificamos": "mirificar",
    "mirificando": "mirificar",
    "mirificara": "mirificar",
    "mirificaram": "mirificar",
    "mirificaras": "mirificar",
    "mirificarde": "mirificar",
    "mirificardes": "mirificar",
    "mirificare": "mirificar",
    "mirificarei": "mirificar",
    "mirificareis": "mirificar",
    "mirificarem": "mirificar",
    "mirificaremos": "mirificar",
    "mirificares": "mirificar",
    "mirificaria": "mirificar",
    "mirificariam": "mirificar",
    "mirificarias": "mirificar",
    "mirificarmo": "mirificar",
    "mirificarmos": "mirificar",
    "mirificará": "mirificar",
    "mirificarás": "mirificar",
    "mirificarão": "mirificar",
    "mirificaríamos": "mirificar",
    "mirificaríeis": "mirificar",
    "mirificas": "mirificar",
    "mirificasse": "mirificar",
    "mirificassem": "mirificar",
    "mirificasses": "mirificar",
    "mirificaste": "mirificar",
    "mirificastes": "mirificar",
    "mirificava": "mirificar",
    "mirificavam": "mirificar",
    "mirificavas": "mirificar",
    "mirifico": "mirificar",
    "mirificou": "mirificar",
    "mirificá": "mirificar",
    "mirificámo": "mirificar",
    "mirificámos": "mirificar",
    "mirificáramo": "mirificar",
    "mirificáramos": "mirificar",
    "mirificárei": "mirificar",
    "mirificáreis": "mirificar",
    "mirificásseis": "mirificar",
    "mirificássemos": "mirificar",
    "mirificávamo": "mirificar",
    "mirificávamos": "mirificar",
    "mirificávei": "mirificar",
    "mirificáveis": "mirificar",
    "mirifique": "mirificar",
    "mirifiquei": "mirificar",
    "mirifiqueis": "mirificar",
    "mirifiquem": "mirificar",
    "mirifiquemo": "mirificar",
    "mirifiquemos": "mirificar",
    "mirifiques": "mirificar",
    "mirinas": "mirina",
    "mirindibas": "mirindiba",
    "miringes": "miringe",
    "miringites": "miringite",
    "mirins": "mirim",
    "miris": "miri",
    "miristicáceas": "miristicácea",
    "miriápodes": "miriápode",
    "miriâmetros": "miriâmetro",
    "miriópodes": "miriópode",
    "mirmecologias": "mirmecologia",
    "mirmecófaga": "mirmecófago",
    "mirmecófagas": "mirmecófago",
    "mirmecófagos": "mirmecófago",
    "mirmequices": "mirmequice",
    "mirmidões": "mirmidão",
    "mirmilões": "mirmilão",
    "mirmídones": "mirmídone",
    "miro": "mirar",
    "mirolha": "mirolho",
    "mirolhas": "mirolho",
    "mirolhos": "mirolho",
    "mirones": "mirone",
    "mirosinas": "mirosina",
    "mirou": "mirar",
    "miroxilinas": "miroxilina",
    "mirra": "mirrar",
    "mirrada": "mirrar",
    "mirradas": "mirrar",
    "mirradinha": "mirrado",
    "mirradinhas": "mirrado",
    "mirradinho": "mirrado",
    "mirradinhos": "mirrado",
    "mirradita": "mirrado",
    "mirraditas": "mirrado",
    "mirradito": "mirrado",
    "mirraditos": "mirrado",
    "mirrado": "mirrar",
    "mirradora": "mirrador",
    "mirradoras": "mirrador",
    "mirradores": "mirrador",
    "mirrados": "mirrar",
    "mirradíssima": "mirrado",
    "mirradíssimas": "mirrado",
    "mirradíssimo": "mirrado",
    "mirradíssimos": "mirrado",
    "mirrai": "mirrar",
    "mirrais": "mirrar",
    "mirram": "mirrar",
    "mirramo": "mirrar",
    "mirramos": "mirrar",
    "mirrando": "mirrar",
    "mirrara": "mirrar",
    "mirraram": "mirrar",
    "mirraras": "mirrar",
    "mirrarde": "mirrar",
    "mirrardes": "mirrar",
    "mirrare": "mirrar",
    "mirrarei": "mirrar",
    "mirrareis": "mirrar",
    "mirrarem": "mirrar",
    "mirraremos": "mirrar",
    "mirrares": "mirrar",
    "mirraria": "mirrar",
    "mirrariam": "mirrar",
    "mirrarias": "mirrar",
    "mirrarmo": "mirrar",
    "mirrarmos": "mirrar",
    "mirrará": "mirrar",
    "mirrarás": "mirrar",
    "mirrarão": "mirrar",
    "mirraríamos": "mirrar",
    "mirraríeis": "mirrar",
    "mirras": "mirrar",
    "mirrasse": "mirrar",
    "mirrassem": "mirrar",
    "mirrasses": "mirrar",
    "mirraste": "mirrar",
    "mirrastes": "mirrar",
    "mirrava": "mirrar",
    "mirravam": "mirrar",
    "mirravas": "mirrar",
    "mirrações": "mirração",
    "mirre": "mirrar",
    "mirrei": "mirrar",
    "mirreis": "mirrar",
    "mirrem": "mirrar",
    "mirremo": "mirrar",
    "mirremos": "mirrar",
    "mirres": "mirrar",
    "mirro": "mirrar",
    "mirrou": "mirrar",
    "mirrá": "mirrar",
    "mirrámo": "mirrar",
    "mirrámos": "mirrar",
    "mirráramo": "mirrar",
    "mirráramos": "mirrar",
    "mirrárei": "mirrar",
    "mirráreis": "mirrar",
    "mirrásseis": "mirrar",
    "mirrássemos": "mirrar",
    "mirrávamo": "mirrar",
    "mirrávamos": "mirrar",
    "mirrávei": "mirrar",
    "mirráveis": "mirrar",
    "mirsináceas": "mirsinácea",
    "mirtedos": "mirtedo",
    "mirtiformes": "mirtiforme",
    "mirtos": "mirto",
    "mirtosa": "mirtoso",
    "mirtosas": "mirtoso",
    "mirtosos": "mirtoso",
    "mirtáceas": "mirtácea",
    "mirtóides": "mirtóide",
    "mirzás": "mirzá",
    "mirá": "mirar",
    "mirámo": "mirar",
    "mirámos": "mirar",
    "miráramo": "mirar",
    "miráramos": "mirar",
    "mirárei": "mirar",
    "miráreis": "mirar",
    "mirásseis": "mirar",
    "mirássemos": "mirar",
    "mirávamo": "mirar",
    "mirávamos": "mirar",
    "mirávei": "mirar",
    "miráveis": "mirar",
    "miríada": "miríade",
    "miríadas": "miríade",
    "miríades": "miríade",
    "mirífica": "mirífico",
    "miríficas": "mirífico",
    "miríficos": "mirífico",
    "mirões": "mirão",
    "mis": "mi",
    "misa": "miso",
    "misantropa": "misantropo",
    "misantropas": "misantropo",
    "misantropias": "misantropia",
    "misantropismos": "misantropismo",
    "misantropos": "misantropo",
    "misantrópica": "misantrópico",
    "misantrópicas": "misantrópico",
    "misantrópicos": "misantrópico",
    "misas": "miso",
    "misca": "miscar",
    "miscada": "miscar",
    "miscadas": "miscar",
    "miscado": "miscar",
    "miscados": "miscar",
    "miscai": "miscar",
    "miscais": "miscar",
    "miscam": "miscar",
    "miscamo": "miscar",
    "miscamos": "miscar",
    "miscando": "miscar",
    "miscara": "miscar",
    "miscaram": "miscar",
    "miscaras": "miscar",
    "miscarde": "miscar",
    "miscardes": "miscar",
    "miscare": "miscar",
    "miscarei": "miscar",
    "miscareis": "miscar",
    "miscarem": "miscar",
    "miscaremos": "miscar",
    "miscares": "miscar",
    "miscaria": "miscar",
    "miscariam": "miscar",
    "miscarias": "miscar",
    "miscarmo": "miscar",
    "miscarmos": "miscar",
    "miscará": "miscar",
    "miscarás": "miscar",
    "miscarão": "miscar",
    "miscaríamos": "miscar",
    "miscaríeis": "miscar",
    "miscas": "miscar",
    "miscasse": "miscar",
    "miscassem": "miscar",
    "miscasses": "miscar",
    "miscaste": "miscar",
    "miscastes": "miscar",
    "miscava": "miscar",
    "miscavam": "miscar",
    "miscavas": "miscar",
    "miscelânea": "miscelâneo",
    "miscelâneas": "miscelâneo",
    "miscelâneos": "miscelâneo",
    "miscibilidades": "miscibilidade",
    "miscigenada": "miscigenado",
    "miscigenadas": "miscigenado",
    "miscigenados": "miscigenado",
    "miscigenações": "miscigenação",
    "misco": "miscar",
    "miscou": "miscar",
    "miscra": "miscrar",
    "miscrada": "miscrar",
    "miscradas": "miscrar",
    "miscrado": "miscrar",
    "miscrados": "miscrar",
    "miscrai": "miscrar",
    "miscrais": "miscrar",
    "miscram": "miscrar",
    "miscramo": "miscrar",
    "miscramos": "miscrar",
    "miscrando": "miscrar",
    "miscrara": "miscrar",
    "miscraram": "miscrar",
    "miscraras": "miscrar",
    "miscrarde": "miscrar",
    "miscrardes": "miscrar",
    "miscrare": "miscrar",
    "miscrarei": "miscrar",
    "miscrareis": "miscrar",
    "miscrarem": "miscrar",
    "miscraremos": "miscrar",
    "miscrares": "miscrar",
    "miscraria": "miscrar",
    "miscrariam": "miscrar",
    "miscrarias": "miscrar",
    "miscrarmo": "miscrar",
    "miscrarmos": "miscrar",
    "miscrará": "miscrar",
    "miscrarás": "miscrar",
    "miscrarão": "miscrar",
    "miscraríamos": "miscrar",
    "miscraríeis": "miscrar",
    "miscras": "miscrar",
    "miscrasse": "miscrar",
    "miscrassem": "miscrar",
    "miscrasses": "miscrar",
    "miscraste": "miscrar",
    "miscrastes": "miscrar",
    "miscrava": "miscrar",
    "miscravam": "miscrar",
    "miscravas": "miscrar",
    "miscre": "miscrar",
    "miscrei": "miscrar",
    "miscreis": "miscrar",
    "miscrem": "miscrar",
    "miscremo": "miscrar",
    "miscremos": "miscrar",
    "miscres": "miscrar",
    "miscro": "miscrar",
    "miscrou": "miscrar",
    "miscrá": "miscrar",
    "miscrámo": "miscrar",
    "miscrámos": "miscrar",
    "miscráramo": "miscrar",
    "miscráramos": "miscrar",
    "miscrárei": "miscrar",
    "miscráreis": "miscrar",
    "miscrásseis": "miscrar",
    "miscrássemos": "miscrar",
    "miscrávamo": "miscrar",
    "miscrávamos": "miscrar",
    "miscrávei": "miscrar",
    "miscráveis": "miscrar",
    "miscá": "miscar",
    "miscámo": "miscar",
    "miscámos": "miscar",
    "miscáramo": "miscar",
    "miscáramos": "miscar",
    "miscárei": "miscar",
    "miscáreis": "miscar",
    "miscásseis": "miscar",
    "miscássemos": "miscar",
    "miscávamo": "miscar",
    "miscávamos": "miscar",
    "miscávei": "miscar",
    "miscáveis": "miscar",
    "miscíveis": "miscível",
    "misera": "miserar",
    "miserabilidades": "miserabilidade",
    "miserabilismos": "miserabilismo",
    "miserabilistas": "miserabilista",
    "miserada": "miserar",
    "miseradas": "miserar",
    "miserado": "miserar",
    "miserados": "miserar",
    "miserai": "miserar",
    "miserais": "miserar",
    "miseram": "miserar",
    "miseramo": "miserar",
    "miseramos": "miserar",
    "miseranda": "miserando",
    "miserandas": "miserando",
    "miserando": "miserar",
    "miserandos": "miserando",
    "miserara": "miserar",
    "miseraram": "miserar",
    "miseraras": "miserar",
    "miserarde": "miserar",
    "miserardes": "miserar",
    "miserare": "miserar",
    "miserarei": "miserar",
    "miserareis": "miserar",
    "miserarem": "miserar",
    "miseraremos": "miserar",
    "miserares": "miserar",
    "miseraria": "miserar",
    "miserariam": "miserar",
    "miserarias": "miserar",
    "miserarmo": "miserar",
    "miserarmos": "miserar",
    "miserará": "miserar",
    "miserarás": "miserar",
    "miserarão": "miserar",
    "miseraríamos": "miserar",
    "miseraríeis": "miserar",
    "miseras": "miserar",
    "miserasse": "miserar",
    "miserassem": "miserar",
    "miserasses": "miserar",
    "miseraste": "miserar",
    "miserastes": "miserar",
    "miserava": "miserar",
    "miseravam": "miserar",
    "miseravas": "miserar",
    "miserações": "miseração",
    "misere": "miserar",
    "miserei": "miserar",
    "misereis": "miserar",
    "miserem": "miserar",
    "miseremo": "miserar",
    "miseremos": "miserar",
    "misereres": "miserere",
    "miseres": "miserar",
    "misericordiosa": "misericordioso",
    "misericordiosas": "misericordioso",
    "misericordiosos": "misericordioso",
    "misericórdias": "misericórdia",
    "misero": "miserar",
    "miserou": "miserar",
    "miserá": "miserar",
    "miserámo": "miserar",
    "miserámos": "miserar",
    "miseráramo": "miserar",
    "miseráramos": "miserar",
    "miserárei": "miserar",
    "miseráreis": "miserar",
    "miserásseis": "miserar",
    "miserássemos": "miserar",
    "miserávamo": "miserar",
    "miserávamos": "miserar",
    "miserávei": "miserar",
    "miseráveis": "miserável",
    "misia": "misio",
    "misias": "misio",
    "misios": "misio",
    "misofobias": "misofobia",
    "misogamias": "misogamia",
    "misoginias": "misoginia",
    "misologias": "misologia",
    "misoneísmos": "misoneísmo",
    "misoneístas": "misoneísta",
    "misopedias": "misopedia",
    "misos": "miso",
    "mispíquéis": "mispíquel",
    "misque": "miscar",
    "misquei": "miscar",
    "misqueis": "miscar",
    "misquem": "miscar",
    "misquemo": "miscar",
    "misquemos": "miscar",
    "misques": "miscar",
    "missa": "missar",
    "missada": "missar",
    "missadas": "missar",
    "missado": "missar",
    "missados": "missar",
    "missagras": "missagra",
    "missai": "missar",
    "missais": "missar",
    "missam": "missar",
    "missamo": "missar",
    "missamos": "missar",
    "missando": "missar",
    "missangas": "missanga",
    "missara": "missar",
    "missaram": "missar",
    "missaras": "missar",
    "missarde": "missar",
    "missardes": "missar",
    "missare": "missar",
    "missarei": "missar",
    "missareis": "missar",
    "missarem": "missar",
    "missaremos": "missar",
    "missares": "missar",
    "missaria": "missar",
    "missariam": "missar",
    "missarias": "missar",
    "missarmo": "missar",
    "missarmos": "missar",
    "missará": "missar",
    "missarás": "missar",
    "missarão": "missar",
    "missaríamos": "missar",
    "missaríeis": "missar",
    "missas": "missar",
    "missasse": "missar",
    "missassem": "missar",
    "missasses": "missar",
    "missaste": "missar",
    "missastes": "missar",
    "missava": "missar",
    "missavam": "missar",
    "missavas": "missar",
    "misse": "missar",
    "missei": "missar",
    "misseira": "misseiro",
    "misseiras": "misseiro",
    "misseiros": "misseiro",
    "misseis": "missar",
    "missem": "missar",
    "missemo": "missar",
    "missemos": "missar",
    "misses": "missar",
    "missinha": "missa",
    "missinhas": "missa",
    "missiona": "missionar",
    "missionada": "missionar",
    "missionadas": "missionar",
    "missionado": "missionar",
    "missionados": "missionar",
    "missionai": "missionar",
    "missionais": "missionar",
    "missionam": "missionar",
    "missionamo": "missionar",
    "missionamos": "missionar",
    "missionando": "missionar",
    "missionara": "missionar",
    "missionaram": "missionar",
    "missionaras": "missionar",
    "missionarde": "missionar",
    "missionardes": "missionar",
    "missionare": "missionar",
    "missionarei": "missionar",
    "missionareis": "missionar",
    "missionarem": "missionar",
    "missionaremos": "missionar",
    "missionares": "missionar",
    "missionaria": "missionar",
    "missionariam": "missionar",
    "missionarias": "missionar",
    "missionarismos": "missionarismo",
    "missionaristas": "missionarista",
    "missionarmo": "missionar",
    "missionarmos": "missionar",
    "missionará": "missionar",
    "missionarás": "missionar",
    "missionarão": "missionar",
    "missionaríamos": "missionar",
    "missionaríeis": "missionar",
    "missionas": "missionar",
    "missionasse": "missionar",
    "missionassem": "missionar",
    "missionasses": "missionar",
    "missionaste": "missionar",
    "missionastes": "missionar",
    "missionava": "missionar",
    "missionavam": "missionar",
    "missionavas": "missionar",
    "missionações": "missionação",
    "missione": "missionar",
    "missionei": "missionar",
    "missioneis": "missionar",
    "missionem": "missionar",
    "missionemo": "missionar",
    "missionemos": "missionar",
    "missiones": "missionar",
    "missiono": "missionar",
    "missionou": "missionar",
    "missioná": "missionar",
    "missionámo": "missionar",
    "missionámos": "missionar",
    "missionáramo": "missionar",
    "missionáramos": "missionar",
    "missionárei": "missionar",
    "missionáreis": "missionar",
    "missionária": "missionário",
    "missionárias": "missionário",
    "missionários": "missionário",
    "missionásseis": "missionar",
    "missionássemos": "missionar",
    "missionávamo": "missionar",
    "missionávamos": "missionar",
    "missionávei": "missionar",
    "missionáveis": "missionar",
    "mississipianos": "mississipiano",
    "missita": "missa",
    "missitas": "missa",
    "missiva": "missivo",
    "missivas": "missivo",
    "missivos": "missivo",
    "misso": "missar",
    "missonga": "missongo",
    "missongas": "missongo",
    "missongos": "missongo",
    "missou": "missar",
    "missá": "missar",
    "missámo": "missar",
    "missámos": "missar",
    "missáramo": "missar",
    "missáramos": "missar",
    "missárei": "missar",
    "missáreis": "missar",
    "missásseis": "missar",
    "missássemos": "missar",
    "missávamo": "missar",
    "missávamos": "missar",
    "missávei": "missar",
    "missáveis": "missar",
    "missória": "missório",
    "missórias": "missório",
    "missórios": "missório",
    "missões": "missão",
    "mista": "misto",
    "mistagoga": "mistagogo",
    "mistagogas": "mistagogo",
    "mistagogias": "mistagogia",
    "mistagogos": "mistagogo",
    "mistagógica": "mistagógico",
    "mistagógicas": "mistagógico",
    "mistagógicos": "mistagógico",
    "mistas": "misto",
    "mistelas": "mistela",
    "misteres": "mister",
    "misteriosa": "misterioso",
    "misteriosas": "misterioso",
    "misteriosos": "misterioso",
    "misticelos": "misticelo",
    "misticidades": "misticidade",
    "misticismos": "misticismo",
    "mistifica": "mistificar",
    "mistificada": "mistificar",
    "mistificadas": "mistificar",
    "mistificado": "mistificar",
    "mistificadora": "mistificador",
    "mistificadoras": "mistificador",
    "mistificadores": "mistificador",
    "mistificados": "mistificar",
    "mistificai": "mistificar",
    "mistificais": "mistificar",
    "mistificam": "mistificar",
    "mistificamo": "mistificar",
    "mistificamos": "mistificar",
    "mistificando": "mistificar",
    "mistificara": "mistificar",
    "mistificaram": "mistificar",
    "mistificaras": "mistificar",
    "mistificarde": "mistificar",
    "mistificardes": "mistificar",
    "mistificare": "mistificar",
    "mistificarei": "mistificar",
    "mistificareis": "mistificar",
    "mistificarem": "mistificar",
    "mistificaremos": "mistificar",
    "mistificares": "mistificar",
    "mistificaria": "mistificar",
    "mistificariam": "mistificar",
    "mistificarias": "mistificar",
    "mistificarmo": "mistificar",
    "mistificarmos": "mistificar",
    "mistificará": "mistificar",
    "mistificarás": "mistificar",
    "mistificarão": "mistificar",
    "mistificaríamos": "mistificar",
    "mistificaríeis": "mistificar",
    "mistificas": "mistificar",
    "mistificasse": "mistificar",
    "mistificassem": "mistificar",
    "mistificasses": "mistificar",
    "mistificaste": "mistificar",
    "mistificastes": "mistificar",
    "mistificava": "mistificar",
    "mistificavam": "mistificar",
    "mistificavas": "mistificar",
    "mistificações": "mistificação",
    "mistifico": "mistificar",
    "mistificou": "mistificar",
    "mistificá": "mistificar",
    "mistificámo": "mistificar",
    "mistificámos": "mistificar",
    "mistificáramo": "mistificar",
    "mistificáramos": "mistificar",
    "mistificárei": "mistificar",
    "mistificáreis": "mistificar",
    "mistificásseis": "mistificar",
    "mistificássemos": "mistificar",
    "mistificávamo": "mistificar",
    "mistificávamos": "mistificar",
    "mistificávei": "mistificar",
    "mistificáveis": "mistificável",
    "mistifique": "mistificar",
    "mistifiquei": "mistificar",
    "mistifiqueis": "mistificar",
    "mistifiquem": "mistificar",
    "mistifiquemo": "mistificar",
    "mistifiquemos": "mistificar",
    "mistifiques": "mistificar",
    "mistifórios": "mistifório",
    "mistilingue": "mistilíngue",
    "mistilingues": "mistilíngue",
    "mistilínea": "mistilíneo",
    "mistilíneas": "mistilíneo",
    "mistilíneos": "mistilíneo",
    "mistilíngues": "mistilíngue",
    "mistinérvea": "mistinérveo",
    "mistinérveas": "mistinérveo",
    "mistinérveos": "mistinérveo",
    "mistos": "misto",
    "mistrais": "mistral",
    "mistura": "misturar",
    "misturada": "misturar",
    "misturadas": "misturar",
    "misturadeiras": "misturadeira",
    "misturado": "misturar",
    "misturadora": "misturador",
    "misturadoras": "misturadora",
    "misturadores": "misturador",
    "misturados": "misturar",
    "misturadíssima": "misturado",
    "misturadíssimas": "misturado",
    "misturadíssimo": "misturado",
    "misturadíssimos": "misturado",
    "misturai": "misturar",
    "misturais": "misturar",
    "misturam": "misturar",
    "misturamo": "misturar",
    "misturamos": "misturar",
    "misturando": "misturar",
    "misturara": "misturar",
    "misturaram": "misturar",
    "misturaras": "misturar",
    "misturarde": "misturar",
    "misturardes": "misturar",
    "misturare": "misturar",
    "misturarei": "misturar",
    "misturareis": "misturar",
    "misturarem": "misturar",
    "misturaremos": "misturar",
    "misturares": "misturar",
    "misturaria": "misturar",
    "misturariam": "misturar",
    "misturarias": "misturar",
    "misturarmo": "misturar",
    "misturarmos": "misturar",
    "misturará": "misturar",
    "misturarás": "misturar",
    "misturarão": "misturar",
    "misturaríamos": "misturar",
    "misturaríeis": "misturar",
    "misturas": "misturar",
    "misturasse": "misturar",
    "misturassem": "misturar",
    "misturasses": "misturar",
    "misturaste": "misturar",
    "misturastes": "misturar",
    "misturava": "misturar",
    "misturavam": "misturar",
    "misturavas": "misturar",
    "misture": "misturar",
    "misturei": "misturar",
    "mistureira": "mistureiro",
    "mistureiras": "mistureiro",
    "mistureiros": "mistureiro",
    "mistureis": "misturar",
    "misturem": "misturar",
    "misturemo": "misturar",
    "misturemos": "misturar",
    "mistures": "misturar",
    "misturo": "misturar",
    "misturou": "misturar",
    "misturá": "misturar",
    "misturámo": "misturar",
    "misturámos": "misturar",
    "misturáramo": "misturar",
    "misturáramos": "misturar",
    "misturárei": "misturar",
    "misturáreis": "misturar",
    "misturásseis": "misturar",
    "misturássemos": "misturar",
    "misturávamo": "misturar",
    "misturávamos": "misturar",
    "misturávei": "misturar",
    "misturáveis": "misturável",
    "mistérios": "mistério",
    "mistões": "mistão",
    "misérias": "miséria",
    "misérrima": "mísero",
    "misérrimas": "mísero",
    "misérrimo": "mísero",
    "misérrimos": "mísero",
    "misófoba": "misófobo",
    "misófobas": "misófobo",
    "misófobos": "misófobo",
    "misógama": "misógamo",
    "misógamas": "misógamo",
    "misógamos": "misógamo",
    "misógina": "misógino",
    "misóginas": "misógino",
    "misóginos": "misógino",
    "misóloga": "misólogo",
    "misólogas": "misólogo",
    "misólogos": "misólogo",
    "mitacismos": "mitacismo",
    "mitenes": "mitene",
    "mitifica": "mitificar",
    "mitificada": "mitificar",
    "mitificadas": "mitificar",
    "mitificado": "mitificar",
    "mitificados": "mitificar",
    "mitificai": "mitificar",
    "mitificais": "mitificar",
    "mitificam": "mitificar",
    "mitificamo": "mitificar",
    "mitificamos": "mitificar",
    "mitificando": "mitificar",
    "mitificara": "mitificar",
    "mitificaram": "mitificar",
    "mitificaras": "mitificar",
    "mitificarde": "mitificar",
    "mitificardes": "mitificar",
    "mitificare": "mitificar",
    "mitificarei": "mitificar",
    "mitificareis": "mitificar",
    "mitificarem": "mitificar",
    "mitificaremos": "mitificar",
    "mitificares": "mitificar",
    "mitificaria": "mitificar",
    "mitificariam": "mitificar",
    "mitificarias": "mitificar",
    "mitificarmo": "mitificar",
    "mitificarmos": "mitificar",
    "mitificará": "mitificar",
    "mitificarás": "mitificar",
    "mitificarão": "mitificar",
    "mitificaríamos": "mitificar",
    "mitificaríeis": "mitificar",
    "mitificas": "mitificar",
    "mitificasse": "mitificar",
    "mitificassem": "mitificar",
    "mitificasses": "mitificar",
    "mitificaste": "mitificar",
    "mitificastes": "mitificar",
    "mitificava": "mitificar",
    "mitificavam": "mitificar",
    "mitificavas": "mitificar",
    "mitificações": "mitificação",
    "mitifico": "mitificar",
    "mitificou": "mitificar",
    "mitificá": "mitificar",
    "mitificámo": "mitificar",
    "mitificámos": "mitificar",
    "mitificáramo": "mitificar",
    "mitificáramos": "mitificar",
    "mitificárei": "mitificar",
    "mitificáreis": "mitificar",
    "mitificásseis": "mitificar",
    "mitificássemos": "mitificar",
    "mitificávamo": "mitificar",
    "mitificávamos": "mitificar",
    "mitificávei": "mitificar",
    "mitificáveis": "mitificável",
    "mitifique": "mitificar",
    "mitifiquei": "mitificar",
    "mitifiqueis": "mitificar",
    "mitifiquem": "mitificar",
    "mitifiquemo": "mitificar",
    "mitifiquemos": "mitificar",
    "mitifiques": "mitificar",
    "mitiga": "mitigar",
    "mitigada": "mitigar",
    "mitigadas": "mitigar",
    "mitigado": "mitigar",
    "mitigadora": "mitigador",
    "mitigadoras": "mitigador",
    "mitigadores": "mitigador",
    "mitigados": "mitigar",
    "mitigai": "mitigar",
    "mitigais": "mitigar",
    "mitigam": "mitigar",
    "mitigamo": "mitigar",
    "mitigamos": "mitigar",
    "mitigando": "mitigar",
    "mitigara": "mitigar",
    "mitigaram": "mitigar",
    "mitigaras": "mitigar",
    "mitigarde": "mitigar",
    "mitigardes": "mitigar",
    "mitigare": "mitigar",
    "mitigarei": "mitigar",
    "mitigareis": "mitigar",
    "mitigarem": "mitigar",
    "mitigaremos": "mitigar",
    "mitigares": "mitigar",
    "mitigaria": "mitigar",
    "mitigariam": "mitigar",
    "mitigarias": "mitigar",
    "mitigarmo": "mitigar",
    "mitigarmos": "mitigar",
    "mitigará": "mitigar",
    "mitigarás": "mitigar",
    "mitigarão": "mitigar",
    "mitigaríamos": "mitigar",
    "mitigaríeis": "mitigar",
    "mitigas": "mitigar",
    "mitigasse": "mitigar",
    "mitigassem": "mitigar",
    "mitigasses": "mitigar",
    "mitigaste": "mitigar",
    "mitigastes": "mitigar",
    "mitigativa": "mitigativo",
    "mitigativas": "mitigativo",
    "mitigativos": "mitigativo",
    "mitigatória": "mitigatório",
    "mitigatórias": "mitigatório",
    "mitigatórios": "mitigatório",
    "mitigava": "mitigar",
    "mitigavam": "mitigar",
    "mitigavas": "mitigar",
    "mitigações": "mitigação",
    "mitigo": "mitigar",
    "mitigou": "mitigar",
    "mitigue": "mitigar",
    "mitiguei": "mitigar",
    "mitigueis": "mitigar",
    "mitiguem": "mitigar",
    "mitiguemo": "mitigar",
    "mitiguemos": "mitigar",
    "mitigues": "mitigar",
    "mitigá": "mitigar",
    "mitigámo": "mitigar",
    "mitigámos": "mitigar",
    "mitigáramo": "mitigar",
    "mitigáramos": "mitigar",
    "mitigárei": "mitigar",
    "mitigáreis": "mitigar",
    "mitigásseis": "mitigar",
    "mitigássemos": "mitigar",
    "mitigávamo": "mitigar",
    "mitigávamos": "mitigar",
    "mitigávei": "mitigar",
    "mitigáveis": "mitigável",
    "mitiliculturas": "mitilicultura",
    "mitilídeos": "mitilídeo",
    "mitismos": "mitismo",
    "mitografias": "mitografia",
    "mitográfica": "mitográfico",
    "mitográficas": "mitográfico",
    "mitográficos": "mitográfico",
    "mitologias": "mitologia",
    "mitologistas": "mitologista",
    "mitológica": "mitológico",
    "mitológicas": "mitológico",
    "mitológicos": "mitológico",
    "mitomanias": "mitomania",
    "mitomaníaca": "mitomaníaco",
    "mitomaníacas": "mitomaníaco",
    "mitomaníacos": "mitomaníaco",
    "mitonímias": "mitonímia",
    "mitos": "mito",
    "mitoses": "mitose",
    "mitra": "mitrar",
    "mitrada": "mitrar",
    "mitradas": "mitrar",
    "mitrado": "mitrar",
    "mitrados": "mitrar",
    "mitrai": "mitrar",
    "mitrais": "mitrar",
    "mitram": "mitrar",
    "mitramo": "mitrar",
    "mitramos": "mitrar",
    "mitrando": "mitrar",
    "mitrara": "mitrar",
    "mitraram": "mitrar",
    "mitraras": "mitrar",
    "mitrarde": "mitrar",
    "mitrardes": "mitrar",
    "mitrare": "mitrar",
    "mitrarei": "mitrar",
    "mitrareis": "mitrar",
    "mitrarem": "mitrar",
    "mitraremos": "mitrar",
    "mitrares": "mitrar",
    "mitraria": "mitrar",
    "mitrariam": "mitrar",
    "mitrarias": "mitrar",
    "mitrarmo": "mitrar",
    "mitrarmos": "mitrar",
    "mitrará": "mitrar",
    "mitrarás": "mitrar",
    "mitrarão": "mitrar",
    "mitraríamos": "mitrar",
    "mitraríeis": "mitrar",
    "mitras": "mitrar",
    "mitrasse": "mitrar",
    "mitrassem": "mitrar",
    "mitrasses": "mitrar",
    "mitraste": "mitrar",
    "mitrastes": "mitrar",
    "mitrava": "mitrar",
    "mitravam": "mitrar",
    "mitravas": "mitrar",
    "mitrazinha": "mitra",
    "mitrazinhas": "mitra",
    "mitrazita": "mitra",
    "mitrazitas": "mitra",
    "mitre": "mitrar",
    "mitrei": "mitrar",
    "mitreis": "mitrar",
    "mitrem": "mitrar",
    "mitremo": "mitrar",
    "mitremos": "mitrar",
    "mitres": "mitrar",
    "mitridatismos": "mitridatismo",
    "mitridatiza": "mitridatizar",
    "mitridatizada": "mitridatizar",
    "mitridatizadas": "mitridatizar",
    "mitridatizado": "mitridatizar",
    "mitridatizados": "mitridatizar",
    "mitridatizai": "mitridatizar",
    "mitridatizais": "mitridatizar",
    "mitridatizam": "mitridatizar",
    "mitridatizamo": "mitridatizar",
    "mitridatizamos": "mitridatizar",
    "mitridatizando": "mitridatizar",
    "mitridatizara": "mitridatizar",
    "mitridatizaram": "mitridatizar",
    "mitridatizaras": "mitridatizar",
    "mitridatizarde": "mitridatizar",
    "mitridatizardes": "mitridatizar",
    "mitridatizare": "mitridatizar",
    "mitridatizarei": "mitridatizar",
    "mitridatizareis": "mitridatizar",
    "mitridatizarem": "mitridatizar",
    "mitridatizaremos": "mitridatizar",
    "mitridatizares": "mitridatizar",
    "mitridatizaria": "mitridatizar",
    "mitridatizariam": "mitridatizar",
    "mitridatizarias": "mitridatizar",
    "mitridatizarmo": "mitridatizar",
    "mitridatizarmos": "mitridatizar",
    "mitridatizará": "mitridatizar",
    "mitridatizarás": "mitridatizar",
    "mitridatizarão": "mitridatizar",
    "mitridatizaríamos": "mitridatizar",
    "mitridatizaríeis": "mitridatizar",
    "mitridatizas": "mitridatizar",
    "mitridatizasse": "mitridatizar",
    "mitridatizassem": "mitridatizar",
    "mitridatizasses": "mitridatizar",
    "mitridatizaste": "mitridatizar",
    "mitridatizastes": "mitridatizar",
    "mitridatizava": "mitridatizar",
    "mitridatizavam": "mitridatizar",
    "mitridatizavas": "mitridatizar",
    "mitridatize": "mitridatizar",
    "mitridatizei": "mitridatizar",
    "mitridatizeis": "mitridatizar",
    "mitridatizem": "mitridatizar",
    "mitridatizemo": "mitridatizar",
    "mitridatizemos": "mitridatizar",
    "mitridatizes": "mitridatizar",
    "mitridatizo": "mitridatizar",
    "mitridatizou": "mitridatizar",
    "mitridatizá": "mitridatizar",
    "mitridatizámo": "mitridatizar",
    "mitridatizámos": "mitridatizar",
    "mitridatizáramo": "mitridatizar",
    "mitridatizáramos": "mitridatizar",
    "mitridatizárei": "mitridatizar",
    "mitridatizáreis": "mitridatizar",
    "mitridatizásseis": "mitridatizar",
    "mitridatizássemos": "mitridatizar",
    "mitridatizávamo": "mitridatizar",
    "mitridatizávamos": "mitridatizar",
    "mitridatizávei": "mitridatizar",
    "mitridatizáveis": "mitridatizar",
    "mitridatos": "mitridato",
    "mitriformes": "mitriforme",
    "mitro": "mitrar",
    "mitrou": "mitrar",
    "mitrá": "mitrar",
    "mitrámo": "mitrar",
    "mitrámos": "mitrar",
    "mitráramo": "mitrar",
    "mitráramos": "mitrar",
    "mitrárei": "mitrar",
    "mitráreis": "mitrar",
    "mitrásseis": "mitrar",
    "mitrássemos": "mitrar",
    "mitrávamo": "mitrar",
    "mitrávamos": "mitrar",
    "mitrávei": "mitrar",
    "mitráveis": "mitrar",
    "mitrídeos": "mitrídeo",
    "mitílidas": "mitílida",
    "mitógrafa": "mitógrafo",
    "mitógrafas": "mitógrafo",
    "mitógrafos": "mitógrafo",
    "mitóloga": "mitólogo",
    "mitólogas": "mitólogo",
    "mitólogos": "mitólogo",
    "mitómana": "mitómano",
    "mitómanas": "mitómano",
    "mitómanos": "mitómano",
    "mitónina": "mitónino",
    "mitóninas": "mitónino",
    "mitóninos": "mitónino",
    "mitótica": "mitótico",
    "mitóticas": "mitótico",
    "mitóticos": "mitótico",
    "miudada": "miudar",
    "miudadas": "miudar",
    "miudado": "miudar",
    "miudados": "miudar",
    "miudagens": "miudagem",
    "miudai": "miudar",
    "miudais": "miudar",
    "miudamo": "miudar",
    "miudamos": "miudar",
    "miudando": "miudar",
    "miudara": "miudar",
    "miudaram": "miudar",
    "miudaras": "miudar",
    "miudarde": "miudar",
    "miudardes": "miudar",
    "miudare": "miudar",
    "miudarei": "miudar",
    "miudareis": "miudar",
    "miudarem": "miudar",
    "miudaremos": "miudar",
    "miudares": "miudar",
    "miudaria": "miudar",
    "miudariam": "miudar",
    "miudarias": "miudar",
    "miudarmo": "miudar",
    "miudarmos": "miudar",
    "miudará": "miudar",
    "miudarás": "miudar",
    "miudarão": "miudar",
    "miudaríamos": "miudar",
    "miudaríeis": "miudar",
    "miudasse": "miudar",
    "miudassem": "miudar",
    "miudasses": "miudar",
    "miudaste": "miudar",
    "miudastes": "miudar",
    "miudava": "miudar",
    "miudavam": "miudar",
    "miudavas": "miudar",
    "miudazinha": "miúdo",
    "miudazinhas": "miúdo",
    "miudazita": "miúdo",
    "miudazitas": "miúdo",
    "miudeada": "miudear",
    "miudeadas": "miudear",
    "miudeado": "miudear",
    "miudeados": "miudear",
    "miudeai": "miudear",
    "miudeais": "miudear",
    "miudeamo": "miudear",
    "miudeamos": "miudear",
    "miudeando": "miudear",
    "miudeara": "miudear",
    "miudearam": "miudear",
    "miudearas": "miudear",
    "miudearde": "miudear",
    "miudeardes": "miudear",
    "miudeare": "miudear",
    "miudearei": "miudear",
    "miudeareis": "miudear",
    "miudearem": "miudear",
    "miudearemos": "miudear",
    "miudeares": "miudear",
    "miudearia": "miudear",
    "miudeariam": "miudear",
    "miudearias": "miudear",
    "miudearmo": "miudear",
    "miudearmos": "miudear",
    "miudeará": "miudear",
    "miudearás": "miudear",
    "miudearão": "miudear",
    "miudearíamos": "miudear",
    "miudearíeis": "miudear",
    "miudeasse": "miudear",
    "miudeassem": "miudear",
    "miudeasses": "miudear",
    "miudeaste": "miudear",
    "miudeastes": "miudear",
    "miudeava": "miudear",
    "miudeavam": "miudear",
    "miudeavas": "miudear",
    "miudeei": "miudear",
    "miudeeis": "miudear",
    "miudeemo": "miudear",
    "miudeemos": "miudear",
    "miudei": "miudar",
    "miudeia": "miudear",
    "miudeiam": "miudear",
    "miudeias": "miudear",
    "miudeie": "miudear",
    "miudeiem": "miudear",
    "miudeies": "miudear",
    "miudeio": "miudear",
    "miudeira": "miudeiro",
    "miudeiras": "miudeiro",
    "miudeiros": "miudeiro",
    "miudeis": "miudar",
    "miudemo": "miudar",
    "miudemos": "miudar",
    "miudeou": "miudear",
    "miudezas": "miudeza",
    "miudeá": "miudear",
    "miudeámo": "miudear",
    "miudeámos": "miudear",
    "miudeáramo": "miudear",
    "miudeáramos": "miudear",
    "miudeárei": "miudear",
    "miudeáreis": "miudear",
    "miudeásseis": "miudear",
    "miudeássemos": "miudear",
    "miudeávamo": "miudear",
    "miudeávamos": "miudear",
    "miudeávei": "miudear",
    "miudeáveis": "miudear",
    "miudinha": "miúdo",
    "miudinhas": "miúdo",
    "miudinho": "miúdo",
    "miudinhos": "miúdo",
    "miudita": "miúdo",
    "miuditas": "miúdo",
    "miudito": "miúdo",
    "miuditos": "miúdo",
    "miudou": "miudar",
    "miudozinho": "miúdo",
    "miudozinhos": "miúdo",
    "miudozito": "miúdo",
    "miudozitos": "miúdo",
    "miudá": "miudar",
    "miudámo": "miudar",
    "miudámos": "miudar",
    "miudáramo": "miudar",
    "miudáramos": "miudar",
    "miudárei": "miudar",
    "miudáreis": "miudar",
    "miudásseis": "miudar",
    "miudássemos": "miudar",
    "miudávamo": "miudar",
    "miudávamos": "miudar",
    "miudávei": "miudar",
    "miudáveis": "miudar",
    "miudíssima": "miúdo",
    "miudíssimas": "miúdo",
    "miudíssimo": "miúdo",
    "miudíssimos": "miúdo",
    "miunçalhas": "miunçalha",
    "miunças": "miunça",
    "miuçalhas": "miuçalha",
    "miuçalhos": "miuçalho",
    "mixamebas": "mixameba",
    "mixedemas": "mixedema",
    "mixedematosa": "mixedematoso",
    "mixedematosas": "mixedematoso",
    "mixedematosos": "mixedematoso",
    "mixogastros": "mixogastro",
    "mixomas": "mixoma",
    "mixomatoses": "mixomatose",
    "mixomicetes": "mixomicete",
    "mixordeira": "mixordeiro",
    "mixordeiras": "mixordeiro",
    "mixordeiros": "mixordeiro",
    "mixoscopias": "mixoscopia",
    "mixófitas": "mixófita",
    "mixórdias": "mixórdia",
    "mizenas": "mizena",
    "mizocéfala": "mizocéfalo",
    "mizocéfalas": "mizocéfalo",
    "mizocéfalos": "mizocéfalo",
    "miá": "miar",
    "miámo": "miar",
    "miámos": "miar",
    "miáramo": "miar",
    "miáramos": "miar",
    "miárei": "miar",
    "miáreis": "miar",
    "miásseis": "miar",
    "miássemos": "miar",
    "miávamo": "miar",
    "miávamos": "miar",
    "miávei": "miar",
    "miáveis": "miar",
    "miíases": "miíase",
    "miógrafos": "miógrafo",
    "mióporos": "mióporo",
    "miótica": "miótico",
    "mióticas": "miótico",
    "mióticos": "miótico",
    "miúda": "miúdo",
    "miúdam": "miudar",
    "miúdas": "miúdo",
    "miúde": "miudar",
    "miúdem": "miudar",
    "miúdes": "miudar",
    "miúdo": "miudar",
    "miúdos": "miúdo",
    "miúlos": "miúlo",
    "miúra": "miúro",
    "miúras": "miúro",
    "miúros": "miúro",
    "miúças": "miúça",
    "mm": "m",
    "mnemoniza": "mnemonizar",
    "mnemonizada": "mnemonizar",
    "mnemonizadas": "mnemonizar",
    "mnemonizado": "mnemonizar",
    "mnemonizados": "mnemonizar",
    "mnemonizai": "mnemonizar",
    "mnemonizais": "mnemonizar",
    "mnemonizam": "mnemonizar",
    "mnemonizamo": "mnemonizar",
    "mnemonizamos": "mnemonizar",
    "mnemonizando": "mnemonizar",
    "mnemonizara": "mnemonizar",
    "mnemonizaram": "mnemonizar",
    "mnemonizaras": "mnemonizar",
    "mnemonizarde": "mnemonizar",
    "mnemonizardes": "mnemonizar",
    "mnemonizare": "mnemonizar",
    "mnemonizarei": "mnemonizar",
    "mnemonizareis": "mnemonizar",
    "mnemonizarem": "mnemonizar",
    "mnemonizaremos": "mnemonizar",
    "mnemonizares": "mnemonizar",
    "mnemonizaria": "mnemonizar",
    "mnemonizariam": "mnemonizar",
    "mnemonizarias": "mnemonizar",
    "mnemonizarmo": "mnemonizar",
    "mnemonizarmos": "mnemonizar",
    "mnemonizará": "mnemonizar",
    "mnemonizarás": "mnemonizar",
    "mnemonizarão": "mnemonizar",
    "mnemonizaríamos": "mnemonizar",
    "mnemonizaríeis": "mnemonizar",
    "mnemonizas": "mnemonizar",
    "mnemonizasse": "mnemonizar",
    "mnemonizassem": "mnemonizar",
    "mnemonizasses": "mnemonizar",
    "mnemonizaste": "mnemonizar",
    "mnemonizastes": "mnemonizar",
    "mnemonizava": "mnemonizar",
    "mnemonizavam": "mnemonizar",
    "mnemonizavas": "mnemonizar",
    "mnemonizações": "mnemonização",
    "mnemonize": "mnemonizar",
    "mnemonizei": "mnemonizar",
    "mnemonizeis": "mnemonizar",
    "mnemonizem": "mnemonizar",
    "mnemonizemo": "mnemonizar",
    "mnemonizemos": "mnemonizar",
    "mnemonizes": "mnemonizar",
    "mnemonizo": "mnemonizar",
    "mnemonizou": "mnemonizar",
    "mnemonizá": "mnemonizar",
    "mnemonizámo": "mnemonizar",
    "mnemonizámos": "mnemonizar",
    "mnemonizáramo": "mnemonizar",
    "mnemonizáramos": "mnemonizar",
    "mnemonizárei": "mnemonizar",
    "mnemonizáreis": "mnemonizar",
    "mnemonizásseis": "mnemonizar",
    "mnemonizássemos": "mnemonizar",
    "mnemonizávamo": "mnemonizar",
    "mnemonizávamos": "mnemonizar",
    "mnemonizávei": "mnemonizar",
    "mnemonizáveis": "mnemonizável",
    "mnemotecnias": "mnemotecnia",
    "mnemotestes": "mnemoteste",
    "mnemotécnica": "mnemotécnico",
    "mnemotécnicas": "mnemotécnico",
    "mnemotécnicos": "mnemotécnico",
    "mnemónica": "mnemónico",
    "mnemónicas": "mnemónico",
    "mnemónicos": "mnemónico",
    "mnésica": "mnésico",
    "mnésicas": "mnésico",
    "mnésicos": "mnésico",
    "moa": "moer",
    "moabitas": "moabita",
    "moados": "moado",
    "moageira": "moageiro",
    "moageiras": "moageiro",
    "moageiros": "moageiro",
    "moagens": "moagem",
    "moais": "moer",
    "moam": "moer",
    "moamo": "moer",
    "moamos": "moer",
    "moas": "moer",
    "mobelhas": "mobelha",
    "mobila": "mobilar",
    "mobilada": "mobilar",
    "mobiladas": "mobilar",
    "mobilado": "mobilar",
    "mobiladora": "mobilador",
    "mobiladoras": "mobilador",
    "mobiladores": "mobilador",
    "mobilados": "mobilar",
    "mobilai": "mobilar",
    "mobilais": "mobilar",
    "mobilam": "mobilar",
    "mobilamo": "mobilar",
    "mobilamos": "mobilar",
    "mobilando": "mobilar",
    "mobilara": "mobilar",
    "mobilaram": "mobilar",
    "mobilaras": "mobilar",
    "mobilarde": "mobilar",
    "mobilardes": "mobilar",
    "mobilare": "mobilar",
    "mobilarei": "mobilar",
    "mobilareis": "mobilar",
    "mobilarem": "mobilar",
    "mobilaremos": "mobilar",
    "mobilares": "mobilar",
    "mobilaria": "mobilar",
    "mobilariam": "mobilar",
    "mobilarias": "mobilar",
    "mobilarmo": "mobilar",
    "mobilarmos": "mobilar",
    "mobilará": "mobilar",
    "mobilarás": "mobilar",
    "mobilarão": "mobilar",
    "mobilaríamos": "mobilar",
    "mobilaríeis": "mobilar",
    "mobilas": "mobilar",
    "mobilasse": "mobilar",
    "mobilassem": "mobilar",
    "mobilasses": "mobilar",
    "mobilaste": "mobilar",
    "mobilastes": "mobilar",
    "mobilava": "mobilar",
    "mobilavam": "mobilar",
    "mobilavas": "mobilar",
    "mobile": "mobilar",
    "mobilei": "mobilar",
    "mobileis": "mobilar",
    "mobilem": "mobilar",
    "mobilemo": "mobilar",
    "mobilemos": "mobilar",
    "mobiles": "mobilar",
    "mobilidades": "mobilidade",
    "mobilismos": "mobilismo",
    "mobilistas": "mobilista",
    "mobiliza": "mobilizar",
    "mobilizada": "mobilizar",
    "mobilizadas": "mobilizar",
    "mobilizado": "mobilizar",
    "mobilizadora": "mobilizador",
    "mobilizadoras": "mobilizador",
    "mobilizadores": "mobilizador",
    "mobilizados": "mobilizar",
    "mobilizai": "mobilizar",
    "mobilizais": "mobilizar",
    "mobilizam": "mobilizar",
    "mobilizamo": "mobilizar",
    "mobilizamos": "mobilizar",
    "mobilizando": "mobilizar",
    "mobilizara": "mobilizar",
    "mobilizaram": "mobilizar",
    "mobilizaras": "mobilizar",
    "mobilizarde": "mobilizar",
    "mobilizardes": "mobilizar",
    "mobilizare": "mobilizar",
    "mobilizarei": "mobilizar",
    "mobilizareis": "mobilizar",
    "mobilizarem": "mobilizar",
    "mobilizaremos": "mobilizar",
    "mobilizares": "mobilizar",
    "mobilizaria": "mobilizar",
    "mobilizariam": "mobilizar",
    "mobilizarias": "mobilizar",
    "mobilizarmo": "mobilizar",
    "mobilizarmos": "mobilizar",
    "mobilizará": "mobilizar",
    "mobilizarás": "mobilizar",
    "mobilizarão": "mobilizar",
    "mobilizaríamos": "mobilizar",
    "mobilizaríeis": "mobilizar",
    "mobilizas": "mobilizar",
    "mobilizasse": "mobilizar",
    "mobilizassem": "mobilizar",
    "mobilizasses": "mobilizar",
    "mobilizaste": "mobilizar",
    "mobilizastes": "mobilizar",
    "mobilizava": "mobilizar",
    "mobilizavam": "mobilizar",
    "mobilizavas": "mobilizar",
    "mobilizações": "mobilização",
    "mobilize": "mobilizar",
    "mobilizei": "mobilizar",
    "mobilizeis": "mobilizar",
    "mobilizem": "mobilizar",
    "mobilizemo": "mobilizar",
    "mobilizemos": "mobilizar",
    "mobilizes": "mobilizar",
    "mobilizo": "mobilizar",
    "mobilizou": "mobilizar",
    "mobilizá": "mobilizar",
    "mobilizámo": "mobilizar",
    "mobilizámos": "mobilizar",
    "mobilizáramo": "mobilizar",
    "mobilizáramos": "mobilizar",
    "mobilizárei": "mobilizar",
    "mobilizáreis": "mobilizar",
    "mobilizásseis": "mobilizar",
    "mobilizássemos": "mobilizar",
    "mobilizávamo": "mobilizar",
    "mobilizávamos": "mobilizar",
    "mobilizávei": "mobilizar",
    "mobilizáveis": "mobilizável",
    "mobiliária": "mobiliário",
    "mobiliárias": "mobiliário",
    "mobiliários": "mobiliário",
    "mobilo": "mobilar",
    "mobilou": "mobilar",
    "mobilá": "mobilar",
    "mobilámo": "mobilar",
    "mobilámos": "mobilar",
    "mobiláramo": "mobilar",
    "mobiláramos": "mobilar",
    "mobilárei": "mobilar",
    "mobiláreis": "mobilar",
    "mobilásseis": "mobilar",
    "mobilássemos": "mobilar",
    "mobilávamo": "mobilar",
    "mobilávamos": "mobilar",
    "mobilávei": "mobilar",
    "mobiláveis": "mobilável",
    "mobílias": "mobília",
    "mocadas": "mocada",
    "mocambos": "mocambo",
    "mocanca": "mocanco",
    "mocancas": "mocanco",
    "mocancos": "mocanco",
    "mocanqueira": "mocanqueiro",
    "mocanqueiras": "mocanqueiro",
    "mocanqueiros": "mocanqueiro",
    "mocanquices": "mocanquice",
    "mocas": "moca",
    "mocedos": "mocedo",
    "mocelas": "mocela",
    "mocetona": "mocetão",
    "mocetonas": "mocetão",
    "mocetões": "mocetão",
    "mocha": "mocho",
    "mochada": "mochar",
    "mochadas": "mochar",
    "mochado": "mochar",
    "mochados": "mochar",
    "mochaduras": "mochadura",
    "mochai": "mochar",
    "mochais": "mochar",
    "mocham": "mochar",
    "mochamo": "mochar",
    "mochamos": "mochar",
    "mochando": "mochar",
    "mochara": "mochar",
    "mocharam": "mochar",
    "mocharas": "mochar",
    "mocharde": "mochar",
    "mochardes": "mochar",
    "mochare": "mochar",
    "mocharei": "mochar",
    "mochareis": "mochar",
    "mocharem": "mochar",
    "mocharemos": "mochar",
    "mochares": "mochar",
    "mocharia": "mochar",
    "mochariam": "mochar",
    "mocharias": "mochar",
    "mocharmo": "mochar",
    "mocharmos": "mochar",
    "mochará": "mochar",
    "mocharás": "mochar",
    "mocharão": "mochar",
    "mocharíamos": "mochar",
    "mocharíeis": "mochar",
    "mochas": "mocho",
    "mochasse": "mochar",
    "mochassem": "mochar",
    "mochasses": "mochar",
    "mochaste": "mochar",
    "mochastes": "mochar",
    "mochava": "mochar",
    "mochavam": "mochar",
    "mochavas": "mochar",
    "moche": "mochar",
    "mochei": "mochar",
    "mocheis": "mochar",
    "mochelas": "mochela",
    "mochem": "mochar",
    "mochemo": "mochar",
    "mochemos": "mochar",
    "moches": "mochar",
    "mochetas": "mocheta",
    "mochilas": "mochila",
    "mochilinha": "mochila",
    "mochilinhas": "mochila",
    "mochilita": "mochila",
    "mochilitas": "mochila",
    "mocho": "mochar",
    "mochos": "mocho",
    "mochou": "mochar",
    "mochá": "mochar",
    "mochámo": "mochar",
    "mochámos": "mochar",
    "mocháramo": "mochar",
    "mocháramos": "mochar",
    "mochárei": "mochar",
    "mocháreis": "mochar",
    "mochásseis": "mochar",
    "mochássemos": "mochar",
    "mochávamo": "mochar",
    "mochávamos": "mochar",
    "mochávei": "mochar",
    "mocháveis": "mochar",
    "mocidades": "mocidade",
    "mocinha": "moço",
    "mocinhas": "moço",
    "mocinho": "moço",
    "mocinhos": "moço",
    "mocita": "moço",
    "mocitas": "moço",
    "mocito": "moço",
    "mocitos": "moço",
    "mociça": "mociço",
    "mociças": "mociço",
    "mociços": "mociço",
    "mocoas": "mocoa",
    "mocotós": "mocotó",
    "mocsas": "mocsa",
    "modais": "modal",
    "modalidades": "modalidade",
    "modalismos": "modalismo",
    "modaliza": "modalizar",
    "modalizada": "modalizar",
    "modalizadas": "modalizar",
    "modalizado": "modalizar",
    "modalizados": "modalizar",
    "modalizai": "modalizar",
    "modalizais": "modalizar",
    "modalizam": "modalizar",
    "modalizamo": "modalizar",
    "modalizamos": "modalizar",
    "modalizando": "modalizar",
    "modalizara": "modalizar",
    "modalizaram": "modalizar",
    "modalizaras": "modalizar",
    "modalizarde": "modalizar",
    "modalizardes": "modalizar",
    "modalizare": "modalizar",
    "modalizarei": "modalizar",
    "modalizareis": "modalizar",
    "modalizarem": "modalizar",
    "modalizaremos": "modalizar",
    "modalizares": "modalizar",
    "modalizaria": "modalizar",
    "modalizariam": "modalizar",
    "modalizarias": "modalizar",
    "modalizarmo": "modalizar",
    "modalizarmos": "modalizar",
    "modalizará": "modalizar",
    "modalizarás": "modalizar",
    "modalizarão": "modalizar",
    "modalizaríamos": "modalizar",
    "modalizaríeis": "modalizar",
    "modalizas": "modalizar",
    "modalizasse": "modalizar",
    "modalizassem": "modalizar",
    "modalizasses": "modalizar",
    "modalizaste": "modalizar",
    "modalizastes": "modalizar",
    "modalizava": "modalizar",
    "modalizavam": "modalizar",
    "modalizavas": "modalizar",
    "modalize": "modalizar",
    "modalizei": "modalizar",
    "modalizeis": "modalizar",
    "modalizem": "modalizar",
    "modalizemo": "modalizar",
    "modalizemos": "modalizar",
    "modalizes": "modalizar",
    "modalizo": "modalizar",
    "modalizou": "modalizar",
    "modalizá": "modalizar",
    "modalizámo": "modalizar",
    "modalizámos": "modalizar",
    "modalizáramo": "modalizar",
    "modalizáramos": "modalizar",
    "modalizárei": "modalizar",
    "modalizáreis": "modalizar",
    "modalizásseis": "modalizar",
    "modalizássemos": "modalizar",
    "modalizávamo": "modalizar",
    "modalizávamos": "modalizar",
    "modalizávei": "modalizar",
    "modalizáveis": "modalizável",
    "modas": "moda",
    "modela": "modelar",
    "modelada": "modelar",
    "modeladas": "modelar",
    "modelado": "modelar",
    "modeladora": "modelador",
    "modeladoras": "modelador",
    "modeladores": "modelador",
    "modelados": "modelar",
    "modelagens": "modelagem",
    "modelai": "modelar",
    "modelais": "modelar",
    "modelam": "modelar",
    "modelamo": "modelar",
    "modelamos": "modelar",
    "modelando": "modelar",
    "modelara": "modelar",
    "modelaram": "modelar",
    "modelaras": "modelar",
    "modelarde": "modelar",
    "modelardes": "modelar",
    "modelare": "modelar",
    "modelarei": "modelar",
    "modelareis": "modelar",
    "modelarem": "modelar",
    "modelaremos": "modelar",
    "modelares": "modelar",
    "modelaria": "modelar",
    "modelariam": "modelar",
    "modelarias": "modelar",
    "modelarmo": "modelar",
    "modelarmos": "modelar",
    "modelará": "modelar",
    "modelarás": "modelar",
    "modelarão": "modelar",
    "modelaríamos": "modelar",
    "modelaríeis": "modelar",
    "modelas": "modelar",
    "modelasse": "modelar",
    "modelassem": "modelar",
    "modelasses": "modelar",
    "modelaste": "modelar",
    "modelastes": "modelar",
    "modelava": "modelar",
    "modelavam": "modelar",
    "modelavas": "modelar",
    "modelações": "modelação",
    "modele": "modelar",
    "modelei": "modelar",
    "modeleis": "modelar",
    "modelem": "modelar",
    "modelemo": "modelar",
    "modelemos": "modelar",
    "modeles": "modelar",
    "modelismos": "modelismo",
    "modelistas": "modelista",
    "modelo": "modelar",
    "modelos": "modelo",
    "modelou": "modelar",
    "modelá": "modelar",
    "modelámo": "modelar",
    "modelámos": "modelar",
    "modeláramo": "modelar",
    "modeláramos": "modelar",
    "modelárei": "modelar",
    "modeláreis": "modelar",
    "modelásseis": "modelar",
    "modelássemos": "modelar",
    "modelávamo": "modelar",
    "modelávamos": "modelar",
    "modelávei": "modelar",
    "modeláveis": "modelável",
    "modemes": "modem",
    "modenaturas": "modenatura",
    "modera": "moderar",
    "moderada": "moderar",
    "moderadas": "moderar",
    "moderadinha": "moderado",
    "moderadinhas": "moderado",
    "moderadinho": "moderado",
    "moderadinhos": "moderado",
    "moderadita": "moderado",
    "moderaditas": "moderado",
    "moderadito": "moderado",
    "moderaditos": "moderado",
    "moderado": "moderar",
    "moderadora": "moderador",
    "moderadoras": "moderador",
    "moderadores": "moderador",
    "moderados": "moderar",
    "moderadíssima": "moderado",
    "moderadíssimas": "moderado",
    "moderadíssimo": "moderado",
    "moderadíssimos": "moderado",
    "moderai": "moderar",
    "moderais": "moderar",
    "moderam": "moderar",
    "moderamo": "moderar",
    "moderamos": "moderar",
    "moderando": "moderar",
    "moderantes": "moderante",
    "moderantismos": "moderantismo",
    "moderara": "moderar",
    "moderaram": "moderar",
    "moderaras": "moderar",
    "moderarde": "moderar",
    "moderardes": "moderar",
    "moderare": "moderar",
    "moderarei": "moderar",
    "moderareis": "moderar",
    "moderarem": "moderar",
    "moderaremos": "moderar",
    "moderares": "moderar",
    "moderaria": "moderar",
    "moderariam": "moderar",
    "moderarias": "moderar",
    "moderarmo": "moderar",
    "moderarmos": "moderar",
    "moderará": "moderar",
    "moderarás": "moderar",
    "moderarão": "moderar",
    "moderaríamos": "moderar",
    "moderaríeis": "moderar",
    "moderas": "moderar",
    "moderasse": "moderar",
    "moderassem": "moderar",
    "moderasses": "moderar",
    "moderaste": "moderar",
    "moderastes": "moderar",
    "moderativa": "moderativo",
    "moderativas": "moderativo",
    "moderativos": "moderativo",
    "moderatos": "moderato",
    "moderava": "moderar",
    "moderavam": "moderar",
    "moderavas": "moderar",
    "moderações": "moderação",
    "modere": "moderar",
    "moderei": "moderar",
    "modereis": "moderar",
    "moderem": "moderar",
    "moderemo": "moderar",
    "moderemos": "moderar",
    "moderes": "moderar",
    "moderna": "moderno",
    "modernas": "moderno",
    "modernaça": "modernaço",
    "modernaças": "modernaço",
    "modernaços": "modernaço",
    "modernices": "modernice",
    "modernidades": "modernidade",
    "modernismos": "modernismo",
    "modernistas": "modernista",
    "moderniza": "modernizar",
    "modernizada": "modernizar",
    "modernizadas": "modernizar",
    "modernizado": "modernizar",
    "modernizadora": "modernizador",
    "modernizadoras": "modernizador",
    "modernizadores": "modernizador",
    "modernizados": "modernizar",
    "modernizai": "modernizar",
    "modernizais": "modernizar",
    "modernizam": "modernizar",
    "modernizamo": "modernizar",
    "modernizamos": "modernizar",
    "modernizando": "modernizar",
    "modernizara": "modernizar",
    "modernizaram": "modernizar",
    "modernizaras": "modernizar",
    "modernizarde": "modernizar",
    "modernizardes": "modernizar",
    "modernizare": "modernizar",
    "modernizarei": "modernizar",
    "modernizareis": "modernizar",
    "modernizarem": "modernizar",
    "modernizaremos": "modernizar",
    "modernizares": "modernizar",
    "modernizaria": "modernizar",
    "modernizariam": "modernizar",
    "modernizarias": "modernizar",
    "modernizarmo": "modernizar",
    "modernizarmos": "modernizar",
    "modernizará": "modernizar",
    "modernizarás": "modernizar",
    "modernizarão": "modernizar",
    "modernizaríamos": "modernizar",
    "modernizaríeis": "modernizar",
    "modernizas": "modernizar",
    "modernizasse": "modernizar",
    "modernizassem": "modernizar",
    "modernizasses": "modernizar",
    "modernizaste": "modernizar",
    "modernizastes": "modernizar",
    "modernizava": "modernizar",
    "modernizavam": "modernizar",
    "modernizavas": "modernizar",
    "modernizações": "modernização",
    "modernize": "modernizar",
    "modernizei": "modernizar",
    "modernizeis": "modernizar",
    "modernizem": "modernizar",
    "modernizemo": "modernizar",
    "modernizemos": "modernizar",
    "modernizes": "modernizar",
    "modernizo": "modernizar",
    "modernizou": "modernizar",
    "modernizá": "modernizar",
    "modernizámo": "modernizar",
    "modernizámos": "modernizar",
    "modernizáramo": "modernizar",
    "modernizáramos": "modernizar",
    "modernizárei": "modernizar",
    "modernizáreis": "modernizar",
    "modernizásseis": "modernizar",
    "modernizássemos": "modernizar",
    "modernizávamo": "modernizar",
    "modernizávamos": "modernizar",
    "modernizávei": "modernizar",
    "modernizáveis": "modernizável",
    "modernos": "moderno",
    "moderníssima": "moderno",
    "moderníssimas": "moderno",
    "moderníssimo": "moderno",
    "moderníssimos": "moderno",
    "modero": "moderar",
    "moderou": "moderar",
    "moderá": "moderar",
    "moderámo": "moderar",
    "moderámos": "moderar",
    "moderáramo": "moderar",
    "moderáramos": "moderar",
    "moderárei": "moderar",
    "moderáreis": "moderar",
    "moderásseis": "moderar",
    "moderássemos": "moderar",
    "moderávamo": "moderar",
    "moderávamos": "moderar",
    "moderávei": "moderar",
    "moderáveis": "moderável",
    "modesta": "modesto",
    "modestas": "modesto",
    "modestazinha": "modesto",
    "modestazinhas": "modesto",
    "modestazita": "modesto",
    "modestazitas": "modesto",
    "modestaça": "modestaço",
    "modestaças": "modestaço",
    "modestaços": "modestaço",
    "modestinha": "modesto",
    "modestinhas": "modesto",
    "modestinho": "modesto",
    "modestinhos": "modesto",
    "modestita": "modesto",
    "modestitas": "modesto",
    "modestito": "modesto",
    "modestitos": "modesto",
    "modestos": "modesto",
    "modestozinho": "modesto",
    "modestozinhos": "modesto",
    "modestozito": "modesto",
    "modestozitos": "modesto",
    "modestíssima": "modesto",
    "modestíssimas": "modesto",
    "modestíssimo": "modesto",
    "modestíssimos": "modesto",
    "modica": "modicar",
    "modicada": "modicar",
    "modicadas": "modicar",
    "modicado": "modicar",
    "modicados": "modicar",
    "modicai": "modicar",
    "modicais": "modicar",
    "modicam": "modicar",
    "modicamo": "modicar",
    "modicamos": "modicar",
    "modicando": "modicar",
    "modicara": "modicar",
    "modicaram": "modicar",
    "modicaras": "modicar",
    "modicarde": "modicar",
    "modicardes": "modicar",
    "modicare": "modicar",
    "modicarei": "modicar",
    "modicareis": "modicar",
    "modicarem": "modicar",
    "modicaremos": "modicar",
    "modicares": "modicar",
    "modicaria": "modicar",
    "modicariam": "modicar",
    "modicarias": "modicar",
    "modicarmo": "modicar",
    "modicarmos": "modicar",
    "modicará": "modicar",
    "modicarás": "modicar",
    "modicarão": "modicar",
    "modicaríamos": "modicar",
    "modicaríeis": "modicar",
    "modicas": "modicar",
    "modicasse": "modicar",
    "modicassem": "modicar",
    "modicasses": "modicar",
    "modicaste": "modicar",
    "modicastes": "modicar",
    "modicava": "modicar",
    "modicavam": "modicar",
    "modicavas": "modicar",
    "modicidades": "modicidade",
    "modico": "modicar",
    "modicou": "modicar",
    "modicá": "modicar",
    "modicámo": "modicar",
    "modicámos": "modicar",
    "modicáramo": "modicar",
    "modicáramos": "modicar",
    "modicárei": "modicar",
    "modicáreis": "modicar",
    "modicásseis": "modicar",
    "modicássemos": "modicar",
    "modicávamo": "modicar",
    "modicávamos": "modicar",
    "modicávei": "modicar",
    "modicáveis": "modicar",
    "modifica": "modificar",
    "modificada": "modificar",
    "modificadas": "modificar",
    "modificado": "modificar",
    "modificadora": "modificador",
    "modificadoras": "modificador",
    "modificadores": "modificador",
    "modificados": "modificar",
    "modificadíssima": "modificado",
    "modificadíssimas": "modificado",
    "modificadíssimo": "modificado",
    "modificadíssimos": "modificado",
    "modificai": "modificar",
    "modificais": "modificar",
    "modificam": "modificar",
    "modificamo": "modificar",
    "modificamos": "modificar",
    "modificando": "modificar",
    "modificara": "modificar",
    "modificaram": "modificar",
    "modificaras": "modificar",
    "modificarde": "modificar",
    "modificardes": "modificar",
    "modificare": "modificar",
    "modificarei": "modificar",
    "modificareis": "modificar",
    "modificarem": "modificar",
    "modificaremos": "modificar",
    "modificares": "modificar",
    "modificaria": "modificar",
    "modificariam": "modificar",
    "modificarias": "modificar",
    "modificarmo": "modificar",
    "modificarmos": "modificar",
    "modificará": "modificar",
    "modificarás": "modificar",
    "modificarão": "modificar",
    "modificaríamos": "modificar",
    "modificaríeis": "modificar",
    "modificas": "modificar",
    "modificasse": "modificar",
    "modificassem": "modificar",
    "modificasses": "modificar",
    "modificaste": "modificar",
    "modificastes": "modificar",
    "modificativa": "modificativo",
    "modificativas": "modificativo",
    "modificativos": "modificativo",
    "modificava": "modificar",
    "modificavam": "modificar",
    "modificavas": "modificar",
    "modificações": "modificação",
    "modifico": "modificar",
    "modificou": "modificar",
    "modificá": "modificar",
    "modificámo": "modificar",
    "modificámos": "modificar",
    "modificáramo": "modificar",
    "modificáramos": "modificar",
    "modificárei": "modificar",
    "modificáreis": "modificar",
    "modificásseis": "modificar",
    "modificássemos": "modificar",
    "modificávamo": "modificar",
    "modificávamos": "modificar",
    "modificávei": "modificar",
    "modificáveis": "modificável",
    "modifique": "modificar",
    "modifiquei": "modificar",
    "modifiqueis": "modificar",
    "modifiquem": "modificar",
    "modifiquemo": "modificar",
    "modifiquemos": "modificar",
    "modifiques": "modificar",
    "modilha": "modilho",
    "modilhada": "modilhar",
    "modilhadas": "modilhar",
    "modilhado": "modilhar",
    "modilhados": "modilhar",
    "modilhai": "modilhar",
    "modilhais": "modilhar",
    "modilham": "modilhar",
    "modilhamo": "modilhar",
    "modilhamos": "modilhar",
    "modilhando": "modilhar",
    "modilhara": "modilhar",
    "modilharam": "modilhar",
    "modilharas": "modilhar",
    "modilharde": "modilhar",
    "modilhardes": "modilhar",
    "modilhare": "modilhar",
    "modilharei": "modilhar",
    "modilhareis": "modilhar",
    "modilharem": "modilhar",
    "modilharemos": "modilhar",
    "modilhares": "modilhar",
    "modilharia": "modilhar",
    "modilhariam": "modilhar",
    "modilharias": "modilhar",
    "modilharmo": "modilhar",
    "modilharmos": "modilhar",
    "modilhará": "modilhar",
    "modilharás": "modilhar",
    "modilharão": "modilhar",
    "modilharíamos": "modilhar",
    "modilharíeis": "modilhar",
    "modilhas": "modilho",
    "modilhasse": "modilhar",
    "modilhassem": "modilhar",
    "modilhasses": "modilhar",
    "modilhaste": "modilhar",
    "modilhastes": "modilhar",
    "modilhava": "modilhar",
    "modilhavam": "modilhar",
    "modilhavas": "modilhar",
    "modilhe": "modilhar",
    "modilhei": "modilhar",
    "modilheis": "modilhar",
    "modilhem": "modilhar",
    "modilhemo": "modilhar",
    "modilhemos": "modilhar",
    "modilhes": "modilhar",
    "modilho": "modilhar",
    "modilhos": "modilho",
    "modilhou": "modilhar",
    "modilhá": "modilhar",
    "modilhámo": "modilhar",
    "modilhámos": "modilhar",
    "modilháramo": "modilhar",
    "modilháramos": "modilhar",
    "modilhárei": "modilhar",
    "modilháreis": "modilhar",
    "modilhásseis": "modilhar",
    "modilhássemos": "modilhar",
    "modilhávamo": "modilhar",
    "modilhávamos": "modilhar",
    "modilhávei": "modilhar",
    "modilháveis": "modilhar",
    "modilhões": "modilhão",
    "modinaturas": "modinatura",
    "modinha": "moda",
    "modinhas": "modinha",
    "modinhos": "modinho",
    "modique": "modicar",
    "modiquei": "modicar",
    "modiqueis": "modicar",
    "modiquem": "modicar",
    "modiquemo": "modicar",
    "modiquemos": "modicar",
    "modiques": "modicar",
    "modismos": "modismo",
    "modistas": "modista",
    "modita": "moda",
    "moditas": "moda",
    "modorra": "modorro",
    "modorrada": "modorrar",
    "modorradas": "modorrar",
    "modorrado": "modorrar",
    "modorrados": "modorrar",
    "modorrai": "modorrar",
    "modorrais": "modorrar",
    "modorram": "modorrar",
    "modorramo": "modorrar",
    "modorramos": "modorrar",
    "modorrando": "modorrar",
    "modorrara": "modorrar",
    "modorraram": "modorrar",
    "modorraras": "modorrar",
    "modorrarde": "modorrar",
    "modorrardes": "modorrar",
    "modorrare": "modorrar",
    "modorrarei": "modorrar",
    "modorrareis": "modorrar",
    "modorrarem": "modorrar",
    "modorraremos": "modorrar",
    "modorrares": "modorrar",
    "modorraria": "modorrar",
    "modorrariam": "modorrar",
    "modorrarias": "modorrar",
    "modorrarmo": "modorrar",
    "modorrarmos": "modorrar",
    "modorrará": "modorrar",
    "modorrarás": "modorrar",
    "modorrarão": "modorrar",
    "modorraríamos": "modorrar",
    "modorraríeis": "modorrar",
    "modorras": "modorro",
    "modorrasse": "modorrar",
    "modorrassem": "modorrar",
    "modorrasses": "modorrar",
    "modorraste": "modorrar",
    "modorrastes": "modorrar",
    "modorrava": "modorrar",
    "modorravam": "modorrar",
    "modorravas": "modorrar",
    "modorre": "modorrar",
    "modorrei": "modorrar",
    "modorreis": "modorrar",
    "modorrem": "modorrar",
    "modorremo": "modorrar",
    "modorremos": "modorrar",
    "modorrenta": "modorrento",
    "modorrentas": "modorrento",
    "modorrentos": "modorrento",
    "modorres": "modorrar",
    "modorro": "modorrar",
    "modorros": "modorro",
    "modorrou": "modorrar",
    "modorrá": "modorrar",
    "modorrámo": "modorrar",
    "modorrámos": "modorrar",
    "modorráramo": "modorrar",
    "modorráramos": "modorrar",
    "modorrárei": "modorrar",
    "modorráreis": "modorrar",
    "modorrásseis": "modorrar",
    "modorrássemos": "modorrar",
    "modorrávamo": "modorrar",
    "modorrávamos": "modorrar",
    "modorrávei": "modorrar",
    "modorráveis": "modorrar",
    "modos": "modo",
    "modula": "modular",
    "modulada": "modular",
    "moduladas": "modular",
    "modulado": "modular",
    "moduladora": "modulador",
    "moduladoras": "modulador",
    "moduladores": "modulador",
    "modulados": "modular",
    "modulagens": "modulagem",
    "modulai": "modular",
    "modulais": "modular",
    "modulam": "modular",
    "modulamo": "modular",
    "modulamos": "modular",
    "modulando": "modular",
    "modulara": "modular",
    "modularam": "modular",
    "modularas": "modular",
    "modularde": "modular",
    "modulardes": "modular",
    "modulare": "modular",
    "modularei": "modular",
    "modulareis": "modular",
    "modularem": "modular",
    "modularemos": "modular",
    "modulares": "modular",
    "modularia": "modular",
    "modulariam": "modular",
    "modularias": "modular",
    "modularmo": "modular",
    "modularmos": "modular",
    "modulará": "modular",
    "modularás": "modular",
    "modularão": "modular",
    "modularíamos": "modular",
    "modularíeis": "modular",
    "modulas": "modular",
    "modulasse": "modular",
    "modulassem": "modular",
    "modulasses": "modular",
    "modulaste": "modular",
    "modulastes": "modular",
    "modulava": "modular",
    "modulavam": "modular",
    "modulavas": "modular",
    "modulações": "modulação",
    "module": "modular",
    "modulei": "modular",
    "moduleis": "modular",
    "modulem": "modular",
    "modulemo": "modular",
    "modulemos": "modular",
    "modules": "modular",
    "modulo": "modular",
    "modulou": "modular",
    "modulá": "modular",
    "modulámo": "modular",
    "modulámos": "modular",
    "moduláramo": "modular",
    "moduláramos": "modular",
    "modulárei": "modular",
    "moduláreis": "modular",
    "modulásseis": "modular",
    "modulássemos": "modular",
    "modulávamo": "modular",
    "modulávamos": "modular",
    "modulávei": "modular",
    "moduláveis": "modulável",
    "modéstias": "modéstia",
    "modíolas": "modíola",
    "modíolos": "modíolo",
    "moedagens": "moedagem",
    "moedas": "moeda",
    "moedazinha": "moeda",
    "moedazinhas": "moeda",
    "moedazita": "moeda",
    "moedazitas": "moeda",
    "moedeira": "moedeiro",
    "moedeiras": "moedeiro",
    "moedeiros": "moedeiro",
    "moedelas": "moedela",
    "moedinha": "moeda",
    "moedinhas": "moeda",
    "moedita": "moeda",
    "moeditas": "moeda",
    "moedora": "moedor",
    "moedoras": "moedor",
    "moedores": "moedor",
    "moedouros": "moedouro",
    "moeduras": "moedura",
    "moegas": "moega",
    "moei": "moer",
    "moeiras": "moeira",
    "moeis": "moer",
    "moelas": "moela",
    "moem": "moer",
    "moemo": "moer",
    "moemos": "moer",
    "moendas": "moenda",
    "moendeira": "moendeiro",
    "moendeiras": "moendeiro",
    "moendeiros": "moendeiro",
    "moendo": "moer",
    "moengas": "moenga",
    "moentes": "moente",
    "moera": "moer",
    "moeram": "moer",
    "moeras": "moer",
    "moerde": "moer",
    "moerdes": "moer",
    "moere": "moer",
    "moerei": "moer",
    "moereis": "moer",
    "moerem": "moer",
    "moeremos": "moer",
    "moeres": "moer",
    "moeria": "moer",
    "moeriam": "moer",
    "moerias": "moer",
    "moermo": "moer",
    "moermos": "moer",
    "moerá": "moer",
    "moerás": "moer",
    "moerão": "moer",
    "moeríamos": "moer",
    "moeríeis": "moer",
    "moesse": "moer",
    "moessem": "moer",
    "moesses": "moer",
    "moeste": "moer",
    "moestes": "moer",
    "moeu": "moer",
    "mofa": "mofar",
    "mofaceira": "mofaceiro",
    "mofaceiras": "mofaceiro",
    "mofaceiros": "mofaceiro",
    "mofada": "mofar",
    "mofadas": "mofar",
    "mofado": "mofar",
    "mofadora": "mofador",
    "mofadoras": "mofador",
    "mofadores": "mofador",
    "mofados": "mofar",
    "mofai": "mofar",
    "mofais": "mofar",
    "mofam": "mofar",
    "mofamo": "mofar",
    "mofamos": "mofar",
    "mofando": "mofar",
    "mofara": "mofar",
    "mofaram": "mofar",
    "mofaras": "mofar",
    "mofarde": "mofar",
    "mofardes": "mofar",
    "mofare": "mofar",
    "mofarei": "mofar",
    "mofareira": "mofareiro",
    "mofareiras": "mofareiro",
    "mofareiros": "mofareiro",
    "mofareis": "mofar",
    "mofarem": "mofar",
    "mofaremos": "mofar",
    "mofares": "mofar",
    "mofaria": "mofar",
    "mofariam": "mofar",
    "mofarias": "mofar",
    "mofarmo": "mofar",
    "mofarmos": "mofar",
    "mofará": "mofar",
    "mofarás": "mofar",
    "mofarão": "mofar",
    "mofaríamos": "mofar",
    "mofaríeis": "mofar",
    "mofas": "mofar",
    "mofasse": "mofar",
    "mofassem": "mofar",
    "mofasses": "mofar",
    "mofaste": "mofar",
    "mofastes": "mofar",
    "mofatras": "mofatra",
    "mofatrona": "mofatrão",
    "mofatronas": "mofatrão",
    "mofatrões": "mofatrão",
    "mofava": "mofar",
    "mofavam": "mofar",
    "mofavas": "mofar",
    "mofe": "mofar",
    "mofei": "mofar",
    "mofeis": "mofar",
    "mofem": "mofar",
    "mofemo": "mofar",
    "mofemos": "mofar",
    "mofenta": "mofento",
    "mofentas": "mofento",
    "mofentos": "mofento",
    "mofes": "mofar",
    "mofetas": "mofeta",
    "mofina": "mofino",
    "mofinas": "mofino",
    "mofinenta": "mofinento",
    "mofinentas": "mofinento",
    "mofinentos": "mofinento",
    "mofinos": "mofino",
    "mofo": "mofar",
    "mofos": "mofo",
    "mofosa": "mofoso",
    "mofosas": "mofoso",
    "mofosos": "mofoso",
    "mofou": "mofar",
    "mofumbos": "mofumbo",
    "mofungos": "mofungo",
    "mofá": "mofar",
    "mofámo": "mofar",
    "mofámos": "mofar",
    "mofáramo": "mofar",
    "mofáramos": "mofar",
    "mofárei": "mofar",
    "mofáreis": "mofar",
    "mofásseis": "mofar",
    "mofássemos": "mofar",
    "mofávamo": "mofar",
    "mofávamos": "mofar",
    "mofávei": "mofar",
    "mofáveis": "mofar",
    "moganga": "mogango",
    "mogangas": "mogango",
    "mogangos": "mogango",
    "mogangueira": "mogangueiro",
    "mogangueiras": "mogangueiro",
    "mogangueiros": "mogangueiro",
    "moganguices": "moganguice",
    "moge": "mugir",
    "mogem": "mugir",
    "moges": "mugir",
    "mogigangas": "mogiganga",
    "mogigrafias": "mogigrafia",
    "mogilalias": "mogilalia",
    "mogilalismos": "mogilalismo",
    "mognos": "mogno",
    "mogóis": "mogol",
    "mogões": "mogão",
    "moiações": "moiação",
    "moicana": "moicano",
    "moicanas": "moicano",
    "moicanos": "moicano",
    "moida": "moido",
    "moidas": "moido",
    "moidazinha": "moído",
    "moidazinhas": "moído",
    "moidazita": "moído",
    "moidazitas": "moído",
    "moidos": "moido",
    "moidozinho": "moído",
    "moidozinhos": "moído",
    "moidozito": "moído",
    "moidozitos": "moído",
    "moidíssima": "moído",
    "moidíssimas": "moído",
    "moidíssimo": "moído",
    "moidíssimos": "moído",
    "moimentos": "moimento",
    "moina": "moinar",
    "moinada": "moinar",
    "moinadas": "moinar",
    "moinado": "moinar",
    "moinados": "moinar",
    "moinai": "moinar",
    "moinais": "moinar",
    "moinam": "moinar",
    "moinamo": "moinar",
    "moinamos": "moinar",
    "moinando": "moinar",
    "moinantes": "moinante",
    "moinara": "moinar",
    "moinaram": "moinar",
    "moinaras": "moinar",
    "moinarde": "moinar",
    "moinardes": "moinar",
    "moinare": "moinar",
    "moinarei": "moinar",
    "moinareis": "moinar",
    "moinarem": "moinar",
    "moinaremos": "moinar",
    "moinares": "moinar",
    "moinaria": "moinar",
    "moinariam": "moinar",
    "moinarias": "moinar",
    "moinarmo": "moinar",
    "moinarmos": "moinar",
    "moinará": "moinar",
    "moinarás": "moinar",
    "moinarão": "moinar",
    "moinaríamos": "moinar",
    "moinaríeis": "moinar",
    "moinas": "moinar",
    "moinasse": "moinar",
    "moinassem": "moinar",
    "moinasses": "moinar",
    "moinaste": "moinar",
    "moinastes": "moinar",
    "moinava": "moinar",
    "moinavam": "moinar",
    "moinavas": "moinar",
    "moine": "moinar",
    "moinei": "moinar",
    "moineis": "moinar",
    "moinem": "moinar",
    "moinemo": "moinar",
    "moinemos": "moinar",
    "moines": "moinar",
    "moinha": "moinhar",
    "moinhada": "moinhar",
    "moinhadas": "moinhar",
    "moinhado": "moinhar",
    "moinhados": "moinhar",
    "moinhai": "moinhar",
    "moinhais": "moinhar",
    "moinham": "moinhar",
    "moinhamo": "moinhar",
    "moinhamos": "moinhar",
    "moinhando": "moinhar",
    "moinhara": "moinhar",
    "moinharam": "moinhar",
    "moinharas": "moinhar",
    "moinharde": "moinhar",
    "moinhardes": "moinhar",
    "moinhare": "moinhar",
    "moinharei": "moinhar",
    "moinhareis": "moinhar",
    "moinharem": "moinhar",
    "moinharemos": "moinhar",
    "moinhares": "moinhar",
    "moinharia": "moinhar",
    "moinhariam": "moinhar",
    "moinharias": "moinhar",
    "moinharmo": "moinhar",
    "moinharmos": "moinhar",
    "moinhará": "moinhar",
    "moinharás": "moinhar",
    "moinharão": "moinhar",
    "moinharíamos": "moinhar",
    "moinharíeis": "moinhar",
    "moinhas": "moinhar",
    "moinhasse": "moinhar",
    "moinhassem": "moinhar",
    "moinhasses": "moinhar",
    "moinhaste": "moinhar",
    "moinhastes": "moinhar",
    "moinhava": "moinhar",
    "moinhavam": "moinhar",
    "moinhavas": "moinhar",
    "moinhe": "moinhar",
    "moinhei": "moinhar",
    "moinheis": "moinhar",
    "moinhem": "moinhar",
    "moinhemo": "moinhar",
    "moinhemos": "moinhar",
    "moinhes": "moinhar",
    "moinho": "moinhar",
    "moinhos": "moinho",
    "moinhou": "moinhar",
    "moinhá": "moinhar",
    "moinhámo": "moinhar",
    "moinhámos": "moinhar",
    "moinháramo": "moinhar",
    "moinháramos": "moinhar",
    "moinhárei": "moinhar",
    "moinháreis": "moinhar",
    "moinhásseis": "moinhar",
    "moinhássemos": "moinhar",
    "moinhávamo": "moinhar",
    "moinhávamos": "moinhar",
    "moinhávei": "moinhar",
    "moinháveis": "moinhar",
    "moino": "moinar",
    "moinou": "moinar",
    "moiná": "moinar",
    "moinámo": "moinar",
    "moinámos": "moinar",
    "moináramo": "moinar",
    "moináramos": "moinar",
    "moinárei": "moinar",
    "moináreis": "moinar",
    "moinásseis": "moinar",
    "moinássemos": "moinar",
    "moinávamo": "moinar",
    "moinávamos": "moinar",
    "moinávei": "moinar",
    "moináveis": "moinar",
    "moios": "moio",
    "moira": "moiro",
    "moirada": "moirar",
    "moiradas": "moirar",
    "moirado": "moirar",
    "moirados": "moirar",
    "moirai": "moirar",
    "moirais": "moirar",
    "moiram": "moirar",
    "moiramas": "moirama",
    "moiramo": "moirar",
    "moiramos": "moirar",
    "moirando": "moirar",
    "moirara": "moirar",
    "moiraram": "moirar",
    "moiraras": "moirar",
    "moirardes": "moirar",
    "moirarei": "moirar",
    "moirareis": "moirar",
    "moirarem": "moirar",
    "moiraremos": "moirar",
    "moirares": "moirar",
    "moiraria": "moirar",
    "moirariam": "moirar",
    "moirarias": "moiraria",
    "moirarmo": "moirar",
    "moirarmos": "moirar",
    "moirará": "moirar",
    "moirarás": "moirar",
    "moirarão": "moirar",
    "moiraríamos": "moirar",
    "moiraríeis": "moirar",
    "moiras": "moiro",
    "moirasse": "moirar",
    "moirassem": "moirar",
    "moirasses": "moirar",
    "moiraste": "moirar",
    "moirastes": "moirar",
    "moirava": "moirar",
    "moiravam": "moirar",
    "moiravas": "moirar",
    "moirazinha": "moiro",
    "moirazinhas": "moiro",
    "moirazita": "moiro",
    "moirazitas": "moiro",
    "moire": "moirar",
    "moirei": "moirar",
    "moireis": "moirar",
    "moireja": "moirejar",
    "moirejada": "moirejar",
    "moirejadas": "moirejar",
    "moirejado": "moirejar",
    "moirejados": "moirejar",
    "moirejai": "moirejar",
    "moirejais": "moirejar",
    "moirejam": "moirejar",
    "moirejamo": "moirejar",
    "moirejamos": "moirejar",
    "moirejando": "moirejar",
    "moirejara": "moirejar",
    "moirejaram": "moirejar",
    "moirejaras": "moirejar",
    "moirejarde": "moirejar",
    "moirejardes": "moirejar",
    "moirejare": "moirejar",
    "moirejarei": "moirejar",
    "moirejareis": "moirejar",
    "moirejarem": "moirejar",
    "moirejaremos": "moirejar",
    "moirejares": "moirejar",
    "moirejaria": "moirejar",
    "moirejariam": "moirejar",
    "moirejarias": "moirejar",
    "moirejarmo": "moirejar",
    "moirejarmos": "moirejar",
    "moirejará": "moirejar",
    "moirejarás": "moirejar",
    "moirejarão": "moirejar",
    "moirejaríamos": "moirejar",
    "moirejaríeis": "moirejar",
    "moirejas": "moirejar",
    "moirejasse": "moirejar",
    "moirejassem": "moirejar",
    "moirejasses": "moirejar",
    "moirejaste": "moirejar",
    "moirejastes": "moirejar",
    "moirejava": "moirejar",
    "moirejavam": "moirejar",
    "moirejavas": "moirejar",
    "moireje": "moirejar",
    "moirejei": "moirejar",
    "moirejeis": "moirejar",
    "moirejem": "moirejar",
    "moirejemo": "moirejar",
    "moirejemos": "moirejar",
    "moirejes": "moirejar",
    "moirejo": "moirejar",
    "moirejou": "moirejar",
    "moirejá": "moirejar",
    "moirejámo": "moirejar",
    "moirejámos": "moirejar",
    "moirejáramo": "moirejar",
    "moirejáramos": "moirejar",
    "moirejárei": "moirejar",
    "moirejáreis": "moirejar",
    "moirejásseis": "moirejar",
    "moirejássemos": "moirejar",
    "moirejávamo": "moirejar",
    "moirejávamos": "moirejar",
    "moirejávei": "moirejar",
    "moirejáveis": "moirejar",
    "moirem": "moirar",
    "moiremo": "moirar",
    "moiremos": "moirar",
    "moires": "moirar",
    "moiresca": "moiresco",
    "moirescas": "moiresco",
    "moirescos": "moiresco",
    "moirinha": "moiro",
    "moirinhas": "moiro",
    "moirinho": "moiro",
    "moirinhos": "moiro",
    "moirisca": "moirisco",
    "moiriscada": "moiriscado",
    "moiriscadas": "moiriscado",
    "moiriscados": "moiriscado",
    "moiriscas": "moirisco",
    "moiriscos": "moirisco",
    "moirismas": "moirisma",
    "moirismos": "moirismo",
    "moirita": "moiro",
    "moiritas": "moiro",
    "moirito": "moiro",
    "moiritos": "moiro",
    "moiro": "moirar",
    "moiros": "moiro",
    "moirou": "moirar",
    "moirozinho": "moiro",
    "moirozinhos": "moiro",
    "moirozito": "moiro",
    "moirozitos": "moiro",
    "moirámo": "moirar",
    "moirámos": "moirar",
    "moiráramo": "moirar",
    "moiráramos": "moirar",
    "moiráreis": "moirar",
    "moirásseis": "moirar",
    "moirássemos": "moirar",
    "moirávamo": "moirar",
    "moirávamos": "moirar",
    "moiráveis": "moirar",
    "moirés": "moiré",
    "moirões": "moirão",
    "moisaica": "moisaico",
    "moisaicas": "moisaico",
    "moisaicos": "moisaico",
    "moiseísmos": "moiseísmo",
    "moiseístas": "moiseísta",
    "moitais": "moital",
    "moitas": "moita",
    "moitedos": "moitedo",
    "moiteiras": "moiteira",
    "moitenses": "moitense",
    "moitões": "moitão",
    "moições": "moição",
    "moladas": "molada",
    "molagens": "molagem",
    "molalidades": "molalidade",
    "molancona": "molancão",
    "molanconas": "molancão",
    "molancões": "molancão",
    "molangueirona": "molangueirão",
    "molangueironas": "molangueirão",
    "molangueirões": "molangueirão",
    "molanqueira": "molanqueiro",
    "molanqueiras": "molanqueiro",
    "molanqueirices": "molanqueirice",
    "molanqueirona": "molanqueirão",
    "molanqueironas": "molanqueirão",
    "molanqueiros": "molanqueiro",
    "molanqueirões": "molanqueirão",
    "molares": "molar",
    "molaridades": "molaridade",
    "molariformes": "molariforme",
    "molarinha": "molarinho",
    "molarinhas": "molarinho",
    "molarinhos": "molarinho",
    "molas": "mola",
    "molda": "moldar",
    "moldada": "moldar",
    "moldadas": "moldar",
    "moldado": "moldar",
    "moldadora": "moldador",
    "moldadoras": "moldador",
    "moldadores": "moldador",
    "moldados": "moldar",
    "moldagens": "moldagem",
    "moldai": "moldar",
    "moldais": "moldar",
    "moldam": "moldar",
    "moldamo": "moldar",
    "moldamos": "moldar",
    "moldandeiras": "moldandeira",
    "moldando": "moldar",
    "moldara": "moldar",
    "moldaram": "moldar",
    "moldaras": "moldar",
    "moldarde": "moldar",
    "moldardes": "moldar",
    "moldare": "moldar",
    "moldarei": "moldar",
    "moldareis": "moldar",
    "moldarem": "moldar",
    "moldaremos": "moldar",
    "moldares": "moldar",
    "moldaria": "moldar",
    "moldariam": "moldar",
    "moldarias": "moldar",
    "moldarmo": "moldar",
    "moldarmos": "moldar",
    "moldará": "moldar",
    "moldarás": "moldar",
    "moldarão": "moldar",
    "moldaríamos": "moldar",
    "moldaríeis": "moldar",
    "moldas": "moldar",
    "moldasse": "moldar",
    "moldassem": "moldar",
    "moldasses": "moldar",
    "moldaste": "moldar",
    "moldastes": "moldar",
    "moldava": "moldar",
    "moldavam": "moldar",
    "moldavas": "moldar",
    "moldações": "moldação",
    "molde": "moldar",
    "moldei": "moldar",
    "moldeis": "moldar",
    "moldem": "moldar",
    "moldemo": "moldar",
    "moldemos": "moldar",
    "moldes": "molde",
    "moldo": "moldar",
    "moldou": "moldar",
    "moldura": "moldurar",
    "moldurada": "moldurar",
    "molduradas": "moldurar",
    "moldurado": "moldurar",
    "moldurados": "moldurar",
    "molduragens": "molduragem",
    "moldurai": "moldurar",
    "moldurais": "moldurar",
    "molduram": "moldurar",
    "molduramo": "moldurar",
    "molduramos": "moldurar",
    "moldurando": "moldurar",
    "moldurara": "moldurar",
    "molduraram": "moldurar",
    "molduraras": "moldurar",
    "moldurarde": "moldurar",
    "moldurardes": "moldurar",
    "moldurare": "moldurar",
    "moldurarei": "moldurar",
    "moldurareis": "moldurar",
    "moldurarem": "moldurar",
    "molduraremos": "moldurar",
    "moldurares": "moldurar",
    "molduraria": "moldurar",
    "moldurariam": "moldurar",
    "moldurarias": "moldurar",
    "moldurarmo": "moldurar",
    "moldurarmos": "moldurar",
    "moldurará": "moldurar",
    "moldurarás": "moldurar",
    "moldurarão": "moldurar",
    "molduraríamos": "moldurar",
    "molduraríeis": "moldurar",
    "molduras": "moldurar",
    "moldurasse": "moldurar",
    "moldurassem": "moldurar",
    "moldurasses": "moldurar",
    "molduraste": "moldurar",
    "moldurastes": "moldurar",
    "moldurava": "moldurar",
    "molduravam": "moldurar",
    "molduravas": "moldurar",
    "moldure": "moldurar",
    "moldurei": "moldurar",
    "moldureira": "moldureiro",
    "moldureiras": "moldureiro",
    "moldureiros": "moldureiro",
    "moldureis": "moldurar",
    "moldurem": "moldurar",
    "molduremo": "moldurar",
    "molduremos": "moldurar",
    "moldures": "moldurar",
    "moldurinha": "moldura",
    "moldurinhas": "moldura",
    "moldurita": "moldura",
    "molduritas": "moldura",
    "molduro": "moldurar",
    "moldurou": "moldurar",
    "moldurá": "moldurar",
    "moldurámo": "moldurar",
    "moldurámos": "moldurar",
    "molduráramo": "moldurar",
    "molduráramos": "moldurar",
    "moldurárei": "moldurar",
    "molduráreis": "moldurar",
    "moldurásseis": "moldurar",
    "moldurássemos": "moldurar",
    "moldurávamo": "moldurar",
    "moldurávamos": "moldurar",
    "moldurávei": "moldurar",
    "molduráveis": "moldurar",
    "moldá": "moldar",
    "moldámo": "moldar",
    "moldámos": "moldar",
    "moldáramo": "moldar",
    "moldáramos": "moldar",
    "moldárei": "moldar",
    "moldáreis": "moldar",
    "moldásseis": "moldar",
    "moldássemos": "moldar",
    "moldávamo": "moldar",
    "moldávamos": "moldar",
    "moldávei": "moldar",
    "moldáveis": "moldável",
    "moleca": "moleque",
    "molecadas": "molecada",
    "molecas": "moleque",
    "moleculares": "molecular",
    "molecularidades": "molecularidade",
    "moleculazinha": "molécula",
    "moleculazinhas": "molécula",
    "moleculazita": "molécula",
    "moleculazitas": "molécula",
    "moledos": "moledo",
    "moleira": "moleiro",
    "moleiras": "moleiro",
    "moleirinhas": "moleirinha",
    "moleiros": "moleiro",
    "molejas": "moleja",
    "molejos": "molejo",
    "molendária": "molendário",
    "molendárias": "molendário",
    "molendários": "molendário",
    "molenga": "molengar",
    "molengada": "molengar",
    "molengadas": "molengar",
    "molengado": "molengar",
    "molengados": "molengar",
    "molengai": "molengar",
    "molengais": "molengar",
    "molengam": "molengar",
    "molengamo": "molengar",
    "molengamos": "molengar",
    "molengando": "molengar",
    "molengara": "molengar",
    "molengaram": "molengar",
    "molengaras": "molengar",
    "molengarde": "molengar",
    "molengardes": "molengar",
    "molengare": "molengar",
    "molengarei": "molengar",
    "molengareis": "molengar",
    "molengarem": "molengar",
    "molengaremos": "molengar",
    "molengares": "molengar",
    "molengaria": "molengar",
    "molengariam": "molengar",
    "molengarias": "molengar",
    "molengarmo": "molengar",
    "molengarmos": "molengar",
    "molengará": "molengar",
    "molengarás": "molengar",
    "molengarão": "molengar",
    "molengaríamos": "molengar",
    "molengaríeis": "molengar",
    "molengas": "molengar",
    "molengasse": "molengar",
    "molengassem": "molengar",
    "molengasses": "molengar",
    "molengaste": "molengar",
    "molengastes": "molengar",
    "molengava": "molengar",
    "molengavam": "molengar",
    "molengavas": "molengar",
    "molengo": "molengar",
    "molengona": "molengão",
    "molengonas": "molengão",
    "molengou": "molengar",
    "molengu": "molenga",
    "molengue": "molengar",
    "molenguei": "molengar",
    "molengueira": "molengueiro",
    "molengueiras": "molengueiro",
    "molengueiros": "molengueiro",
    "molengueis": "molengar",
    "molenguem": "molengar",
    "molenguemo": "molengar",
    "molenguemos": "molengar",
    "molengues": "molengar",
    "molengus": "molenga",
    "molengá": "molengar",
    "molengámo": "molengar",
    "molengámos": "molengar",
    "molengáramo": "molengar",
    "molengáramos": "molengar",
    "molengárei": "molengar",
    "molengáreis": "molengar",
    "molengásseis": "molengar",
    "molengássemos": "molengar",
    "molengávamo": "molengar",
    "molengávamos": "molengar",
    "molengávei": "molengar",
    "molengáveis": "molengar",
    "molengão": "molenga",
    "molengões": "molengão",
    "moleques": "moleque",
    "moles": "mole",
    "molesta": "molesto",
    "molestada": "molestar",
    "molestadas": "molestar",
    "molestado": "molestar",
    "molestadora": "molestador",
    "molestadoras": "molestador",
    "molestadores": "molestador",
    "molestados": "molestar",
    "molestai": "molestar",
    "molestais": "molestar",
    "molestam": "molestar",
    "molestamo": "molestar",
    "molestamos": "molestar",
    "molestando": "molestar",
    "molestara": "molestar",
    "molestaram": "molestar",
    "molestaras": "molestar",
    "molestarde": "molestar",
    "molestardes": "molestar",
    "molestare": "molestar",
    "molestarei": "molestar",
    "molestareis": "molestar",
    "molestarem": "molestar",
    "molestaremos": "molestar",
    "molestares": "molestar",
    "molestaria": "molestar",
    "molestariam": "molestar",
    "molestarias": "molestar",
    "molestarmo": "molestar",
    "molestarmos": "molestar",
    "molestará": "molestar",
    "molestarás": "molestar",
    "molestarão": "molestar",
    "molestaríamos": "molestar",
    "molestaríeis": "molestar",
    "molestas": "molesto",
    "molestasse": "molestar",
    "molestassem": "molestar",
    "molestasses": "molestar",
    "molestaste": "molestar",
    "molestastes": "molestar",
    "molestava": "molestar",
    "molestavam": "molestar",
    "molestavas": "molestar",
    "moleste": "molestar",
    "molestei": "molestar",
    "molesteis": "molestar",
    "molestem": "molestar",
    "molestemo": "molestar",
    "molestemos": "molestar",
    "molestes": "molestar",
    "molesto": "molestar",
    "molestos": "molesto",
    "molestou": "molestar",
    "molestradora": "molestrador",
    "molestradoras": "molestrador",
    "molestradores": "molestrador",
    "molestá": "molestar",
    "molestámo": "molestar",
    "molestámos": "molestar",
    "molestáramo": "molestar",
    "molestáramos": "molestar",
    "molestárei": "molestar",
    "molestáreis": "molestar",
    "molestásseis": "molestar",
    "molestássemos": "molestar",
    "molestávamo": "molestar",
    "molestávamos": "molestar",
    "molestávei": "molestar",
    "molestáveis": "molestar",
    "moletas": "moleta",
    "moletes": "molete",
    "moletões": "moletão",
    "molezas": "moleza",
    "molezinha": "mole",
    "molezinhas": "mole",
    "molezinho": "mole",
    "molezinhos": "mole",
    "molezita": "mole",
    "molezitas": "mole",
    "molezito": "mole",
    "molezitos": "mole",
    "moleçadas": "moleçada",
    "molha": "molhar",
    "molhada": "molhar",
    "molhadas": "molhar",
    "molhadelas": "molhadela",
    "molhadinha": "molhado",
    "molhadinhas": "molhado",
    "molhadinho": "molhado",
    "molhadinhos": "molhado",
    "molhadita": "molhado",
    "molhaditas": "molhado",
    "molhadito": "molhado",
    "molhaditos": "molhado",
    "molhado": "molhar",
    "molhados": "molhar",
    "molhaduras": "molhadura",
    "molhadíssima": "molhado",
    "molhadíssimas": "molhado",
    "molhadíssimo": "molhado",
    "molhadíssimos": "molhado",
    "molhagens": "molhagem",
    "molhai": "molhar",
    "molhais": "molhar",
    "molham": "molhar",
    "molhamo": "molhar",
    "molhamos": "molhar",
    "molhando": "molhar",
    "molhangas": "molhanga",
    "molhanças": "molhança",
    "molhara": "molhar",
    "molharam": "molhar",
    "molharas": "molhar",
    "molharde": "molhar",
    "molhardes": "molhar",
    "molhare": "molhar",
    "molharei": "molhar",
    "molhareis": "molhar",
    "molharem": "molhar",
    "molharemos": "molhar",
    "molhares": "molhar",
    "molharia": "molhar",
    "molhariam": "molhar",
    "molharias": "molhar",
    "molharmo": "molhar",
    "molharmos": "molhar",
    "molhará": "molhar",
    "molharás": "molhar",
    "molharão": "molhar",
    "molharíamos": "molhar",
    "molharíeis": "molhar",
    "molhas": "molhar",
    "molhasse": "molhar",
    "molhassem": "molhar",
    "molhasses": "molhar",
    "molhaste": "molhar",
    "molhastes": "molhar",
    "molhava": "molhar",
    "molhavam": "molhar",
    "molhavas": "molhar",
    "molhe": "molhar",
    "molhei": "molhar",
    "molheiras": "molheira",
    "molheis": "molhar",
    "molhelhas": "molhelha",
    "molhelheira": "molhelheiro",
    "molhelheiras": "molhelheiro",
    "molhelheiros": "molhelheiro",
    "molhem": "molhar",
    "molhemo": "molhar",
    "molhemos": "molhar",
    "molhes": "molhe",
    "molhinho": "molho",
    "molhinhos": "molho",
    "molhito": "molho",
    "molhitos": "molho",
    "molho": "molhar",
    "molhos": "molho",
    "molhou": "molhar",
    "molhá": "molhar",
    "molhámo": "molhar",
    "molhámos": "molhar",
    "molháramo": "molhar",
    "molháramos": "molhar",
    "molhárei": "molhar",
    "molháreis": "molhar",
    "molhásseis": "molhar",
    "molhássemos": "molhar",
    "molhávamo": "molhar",
    "molhávamos": "molhar",
    "molhávei": "molhar",
    "molháveis": "molhar",
    "molianas": "moliana",
    "molibdenites": "molibdenite",
    "molibdenos": "molibdeno",
    "molibdénios": "molibdénio",
    "moliceira": "moliceiro",
    "moliceiras": "moliceiro",
    "moliceiros": "moliceiro",
    "molieresca": "molieresco",
    "molierescas": "molieresco",
    "molierescos": "molieresco",
    "molifica": "molificar",
    "molificada": "molificar",
    "molificadas": "molificar",
    "molificado": "molificar",
    "molificados": "molificar",
    "molificai": "molificar",
    "molificais": "molificar",
    "molificam": "molificar",
    "molificamo": "molificar",
    "molificamos": "molificar",
    "molificando": "molificar",
    "molificantes": "molificante",
    "molificara": "molificar",
    "molificaram": "molificar",
    "molificaras": "molificar",
    "molificarde": "molificar",
    "molificardes": "molificar",
    "molificare": "molificar",
    "molificarei": "molificar",
    "molificareis": "molificar",
    "molificarem": "molificar",
    "molificaremos": "molificar",
    "molificares": "molificar",
    "molificaria": "molificar",
    "molificariam": "molificar",
    "molificarias": "molificar",
    "molificarmo": "molificar",
    "molificarmos": "molificar",
    "molificará": "molificar",
    "molificarás": "molificar",
    "molificarão": "molificar",
    "molificaríamos": "molificar",
    "molificaríeis": "molificar",
    "molificas": "molificar",
    "molificasse": "molificar",
    "molificassem": "molificar",
    "molificasses": "molificar",
    "molificaste": "molificar",
    "molificastes": "molificar",
    "molificativa": "molificativo",
    "molificativas": "molificativo",
    "molificativos": "molificativo",
    "molificava": "molificar",
    "molificavam": "molificar",
    "molificavas": "molificar",
    "molificações": "molificação",
    "molifico": "molificar",
    "molificou": "molificar",
    "molificá": "molificar",
    "molificámo": "molificar",
    "molificámos": "molificar",
    "molificáramo": "molificar",
    "molificáramos": "molificar",
    "molificárei": "molificar",
    "molificáreis": "molificar",
    "molificásseis": "molificar",
    "molificássemos": "molificar",
    "molificávamo": "molificar",
    "molificávamos": "molificar",
    "molificávei": "molificar",
    "molificáveis": "molificável",
    "molifique": "molificar",
    "molifiquei": "molificar",
    "molifiqueis": "molificar",
    "molifiquem": "molificar",
    "molifiquemo": "molificar",
    "molifiquemos": "molificar",
    "molifiques": "molificar",
    "molimes": "molime",
    "molina": "molinar",
    "molinada": "molinar",
    "molinadas": "molinar",
    "molinado": "molinar",
    "molinados": "molinar",
    "molinai": "molinar",
    "molinais": "molinar",
    "molinam": "molinar",
    "molinamo": "molinar",
    "molinamos": "molinar",
    "molinando": "molinar",
    "molinara": "molinar",
    "molinaram": "molinar",
    "molinaras": "molinar",
    "molinarde": "molinar",
    "molinardes": "molinar",
    "molinare": "molinar",
    "molinarei": "molinar",
    "molinareis": "molinar",
    "molinarem": "molinar",
    "molinaremos": "molinar",
    "molinares": "molinar",
    "molinaria": "molinar",
    "molinariam": "molinar",
    "molinarias": "molinar",
    "molinarmo": "molinar",
    "molinarmos": "molinar",
    "molinará": "molinar",
    "molinarás": "molinar",
    "molinarão": "molinar",
    "molinaríamos": "molinar",
    "molinaríeis": "molinar",
    "molinas": "molinar",
    "molinasse": "molinar",
    "molinassem": "molinar",
    "molinasses": "molinar",
    "molinaste": "molinar",
    "molinastes": "molinar",
    "molinava": "molinar",
    "molinavam": "molinar",
    "molinavas": "molinar",
    "moline": "molinar",
    "molinei": "molinar",
    "molineis": "molinar",
    "molinem": "molinar",
    "molinemo": "molinar",
    "molinemos": "molinar",
    "molines": "molinar",
    "molinetas": "molineta",
    "molinetes": "molinete",
    "molinha": "molinhar",
    "molinhada": "molinhar",
    "molinhadas": "molinhar",
    "molinhado": "molinhar",
    "molinhados": "molinhar",
    "molinhai": "molinhar",
    "molinhais": "molinhar",
    "molinham": "molinhar",
    "molinhamo": "molinhar",
    "molinhamos": "molinhar",
    "molinhando": "molinhar",
    "molinhara": "molinhar",
    "molinharam": "molinhar",
    "molinharas": "molinhar",
    "molinharde": "molinhar",
    "molinhardes": "molinhar",
    "molinhare": "molinhar",
    "molinharei": "molinhar",
    "molinhareis": "molinhar",
    "molinharem": "molinhar",
    "molinharemos": "molinhar",
    "molinhares": "molinhar",
    "molinharia": "molinhar",
    "molinhariam": "molinhar",
    "molinharias": "molinhar",
    "molinharmo": "molinhar",
    "molinharmos": "molinhar",
    "molinhará": "molinhar",
    "molinharás": "molinhar",
    "molinharão": "molinhar",
    "molinharíamos": "molinhar",
    "molinharíeis": "molinhar",
    "molinhas": "molinhar",
    "molinhasse": "molinhar",
    "molinhassem": "molinhar",
    "molinhasses": "molinhar",
    "molinhaste": "molinhar",
    "molinhastes": "molinhar",
    "molinhava": "molinhar",
    "molinhavam": "molinhar",
    "molinhavas": "molinhar",
    "molinhe": "molinhar",
    "molinhei": "molinhar",
    "molinheiras": "molinheira",
    "molinheiros": "molinheiro",
    "molinheis": "molinhar",
    "molinhem": "molinhar",
    "molinhemo": "molinhar",
    "molinhemos": "molinhar",
    "molinhes": "molinhar",
    "molinho": "molinhar",
    "molinhos": "mole",
    "molinhosa": "molinhoso",
    "molinhosas": "molinhoso",
    "molinhosos": "molinhoso",
    "molinhou": "molinhar",
    "molinhá": "molinhar",
    "molinhámo": "molinhar",
    "molinhámos": "molinhar",
    "molinháramo": "molinhar",
    "molinháramos": "molinhar",
    "molinhárei": "molinhar",
    "molinháreis": "molinhar",
    "molinhásseis": "molinhar",
    "molinhássemos": "molinhar",
    "molinhávamo": "molinhar",
    "molinhávamos": "molinhar",
    "molinhávei": "molinhar",
    "molinháveis": "molinhar",
    "molinhãs": "molinhã",
    "molinilhos": "molinilho",
    "molinismos": "molinismo",
    "molinistas": "molinista",
    "molino": "molinar",
    "molinosismos": "molinosismo",
    "molinotes": "molinote",
    "molinou": "molinar",
    "moliná": "molinar",
    "molinámo": "molinar",
    "molinámos": "molinar",
    "molináramo": "molinar",
    "molináramos": "molinar",
    "molinárei": "molinar",
    "molináreis": "molinar",
    "molinásseis": "molinar",
    "molinássemos": "molinar",
    "molinávamo": "molinar",
    "molinávamos": "molinar",
    "molinávei": "molinar",
    "molináveis": "molinar",
    "molis": "moli",
    "molita": "mole",
    "molitas": "mole",
    "molito": "mole",
    "molitos": "mole",
    "moliços": "moliço",
    "molições": "molição",
    "molossos": "molosso",
    "molossídeos": "molossídeo",
    "mols": "mol",
    "molucana": "molucano",
    "molucanas": "molucano",
    "molucanos": "molucano",
    "molugens": "molugem",
    "moluras": "molura",
    "moluscos": "molusco",
    "moluscóides": "moluscóide",
    "moléculas": "molécula",
    "moléstias": "moléstia",
    "molícias": "molícia",
    "molícies": "molície",
    "molídeos": "molídeo",
    "molídias": "molídia",
    "molímens": "molímen",
    "molípedes": "molípede",
    "molíssima": "mole",
    "molíssimas": "mole",
    "molíssimo": "mole",
    "molíssimos": "mole",
    "molúrias": "molúria",
    "momboiaxiós": "momboiaxió",
    "momenta": "momentum",
    "momentinho": "momento",
    "momentinhos": "momento",
    "momentito": "momento",
    "momentitos": "momento",
    "momentos": "momento",
    "momentosa": "momentoso",
    "momentosas": "momentoso",
    "momentosos": "momentoso",
    "momentânea": "momentâneo",
    "momentâneas": "momentâneo",
    "momentâneos": "momentâneo",
    "momices": "momice",
    "momos": "momo",
    "mona": "mono",
    "monaca": "monacar",
    "monacada": "monacar",
    "monacadas": "monacar",
    "monacado": "monacar",
    "monacados": "monacar",
    "monacai": "monacar",
    "monacais": "monacar",
    "monacam": "monacar",
    "monacamo": "monacar",
    "monacamos": "monacar",
    "monacando": "monacar",
    "monacara": "monacar",
    "monacaram": "monacar",
    "monacaras": "monacar",
    "monacarde": "monacar",
    "monacardes": "monacar",
    "monacare": "monacar",
    "monacarei": "monacar",
    "monacareis": "monacar",
    "monacarem": "monacar",
    "monacaremos": "monacar",
    "monacares": "monacar",
    "monacaria": "monacar",
    "monacariam": "monacar",
    "monacarias": "monacar",
    "monacarmo": "monacar",
    "monacarmos": "monacar",
    "monacará": "monacar",
    "monacarás": "monacar",
    "monacarão": "monacar",
    "monacaríamos": "monacar",
    "monacaríeis": "monacar",
    "monacas": "monacar",
    "monacasse": "monacar",
    "monacassem": "monacar",
    "monacasses": "monacar",
    "monacaste": "monacar",
    "monacastes": "monacar",
    "monacatos": "monacato",
    "monacava": "monacar",
    "monacavam": "monacar",
    "monacavas": "monacar",
    "monaco": "monacar",
    "monacou": "monacar",
    "monacá": "monacar",
    "monacámo": "monacar",
    "monacámos": "monacar",
    "monacáramo": "monacar",
    "monacáramos": "monacar",
    "monacárei": "monacar",
    "monacáreis": "monacar",
    "monacásseis": "monacar",
    "monacássemos": "monacar",
    "monacávamo": "monacar",
    "monacávamos": "monacar",
    "monacávei": "monacar",
    "monacáveis": "monacar",
    "monadas": "monada",
    "monadelfa": "monadelfo",
    "monadelfas": "monadelfo",
    "monadelfias": "monadelfia",
    "monadelfos": "monadelfo",
    "monadismos": "monadismo",
    "monadistas": "monadista",
    "monadologias": "monadologia",
    "monandra": "monandro",
    "monandras": "monandro",
    "monandrias": "monandria",
    "monandros": "monandro",
    "monanta": "monanto",
    "monantas": "monanto",
    "monantos": "monanto",
    "monantropias": "monantropia",
    "monaque": "monacar",
    "monaquei": "monacar",
    "monaqueis": "monacar",
    "monaquem": "monacar",
    "monaquemo": "monacar",
    "monaquemos": "monacar",
    "monaques": "monacar",
    "monaquismos": "monaquismo",
    "monarcas": "monarca",
    "monarcolatrias": "monarcolatria",
    "monarcomanias": "monarcomania",
    "monarcólatras": "monarcólatra",
    "monarcómaca": "monarcómaco",
    "monarcómacas": "monarcómaco",
    "monarcómacos": "monarcómaco",
    "monarcómana": "monarcómano",
    "monarcómanas": "monarcómano",
    "monarcómanos": "monarcómano",
    "monarias": "monaria",
    "monarquianismos": "monarquianismo",
    "monarquias": "monarquia",
    "monarquismos": "monarquismo",
    "monarquistas": "monarquista",
    "monarquiza": "monarquizar",
    "monarquizada": "monarquizar",
    "monarquizadas": "monarquizar",
    "monarquizado": "monarquizar",
    "monarquizados": "monarquizar",
    "monarquizai": "monarquizar",
    "monarquizais": "monarquizar",
    "monarquizam": "monarquizar",
    "monarquizamo": "monarquizar",
    "monarquizamos": "monarquizar",
    "monarquizando": "monarquizar",
    "monarquizara": "monarquizar",
    "monarquizaram": "monarquizar",
    "monarquizaras": "monarquizar",
    "monarquizarde": "monarquizar",
    "monarquizardes": "monarquizar",
    "monarquizare": "monarquizar",
    "monarquizarei": "monarquizar",
    "monarquizareis": "monarquizar",
    "monarquizarem": "monarquizar",
    "monarquizaremos": "monarquizar",
    "monarquizares": "monarquizar",
    "monarquizaria": "monarquizar",
    "monarquizariam": "monarquizar",
    "monarquizarias": "monarquizar",
    "monarquizarmo": "monarquizar",
    "monarquizarmos": "monarquizar",
    "monarquizará": "monarquizar",
    "monarquizarás": "monarquizar",
    "monarquizarão": "monarquizar",
    "monarquizaríamos": "monarquizar",
    "monarquizaríeis": "monarquizar",
    "monarquizas": "monarquizar",
    "monarquizasse": "monarquizar",
    "monarquizassem": "monarquizar",
    "monarquizasses": "monarquizar",
    "monarquizaste": "monarquizar",
    "monarquizastes": "monarquizar",
    "monarquizava": "monarquizar",
    "monarquizavam": "monarquizar",
    "monarquizavas": "monarquizar",
    "monarquizações": "monarquização",
    "monarquize": "monarquizar",
    "monarquizei": "monarquizar",
    "monarquizeis": "monarquizar",
    "monarquizem": "monarquizar",
    "monarquizemo": "monarquizar",
    "monarquizemos": "monarquizar",
    "monarquizes": "monarquizar",
    "monarquizo": "monarquizar",
    "monarquizou": "monarquizar",
    "monarquizá": "monarquizar",
    "monarquizámo": "monarquizar",
    "monarquizámos": "monarquizar",
    "monarquizáramo": "monarquizar",
    "monarquizáramos": "monarquizar",
    "monarquizárei": "monarquizar",
    "monarquizáreis": "monarquizar",
    "monarquizásseis": "monarquizar",
    "monarquizássemos": "monarquizar",
    "monarquizávamo": "monarquizar",
    "monarquizávamos": "monarquizar",
    "monarquizávei": "monarquizar",
    "monarquizáveis": "monarquizar",
    "monas": "mono",
    "monasteriais": "monasterial",
    "monasticais": "monastical",
    "monasticismos": "monasticismo",
    "monastérios": "monastério",
    "monatómica": "monatómico",
    "monatómicas": "monatómico",
    "monatómicos": "monatómico",
    "monauriculares": "monauricular",
    "monazites": "monazite",
    "moncarpos": "moncarpo",
    "monchiquites": "monchiquite",
    "monchiquitos": "monchiquito",
    "moncos": "monco",
    "moncosa": "moncoso",
    "moncosas": "moncoso",
    "moncosos": "moncoso",
    "monda": "mondar",
    "mondada": "mondar",
    "mondadas": "mondar",
    "mondadeira": "mondadeiro",
    "mondadeiras": "mondadeiro",
    "mondadeiros": "mondadeiro",
    "mondado": "mondar",
    "mondadora": "mondador",
    "mondadoras": "mondador",
    "mondadores": "mondador",
    "mondados": "mondar",
    "mondai": "mondar",
    "mondais": "mondar",
    "mondam": "mondar",
    "mondamo": "mondar",
    "mondamos": "mondar",
    "mondando": "mondar",
    "mondara": "mondar",
    "mondaram": "mondar",
    "mondaras": "mondar",
    "mondarde": "mondar",
    "mondardes": "mondar",
    "mondare": "mondar",
    "mondarei": "mondar",
    "mondareis": "mondar",
    "mondarem": "mondar",
    "mondaremos": "mondar",
    "mondares": "mondar",
    "mondaria": "mondar",
    "mondariam": "mondar",
    "mondarias": "mondar",
    "mondarmo": "mondar",
    "mondarmos": "mondar",
    "mondará": "mondar",
    "mondarás": "mondar",
    "mondarão": "mondar",
    "mondaríamos": "mondar",
    "mondaríeis": "mondar",
    "mondas": "mondar",
    "mondasse": "mondar",
    "mondassem": "mondar",
    "mondasses": "mondar",
    "mondaste": "mondar",
    "mondastes": "mondar",
    "mondava": "mondar",
    "mondavam": "mondar",
    "mondavas": "mondar",
    "monde": "mondar",
    "mondei": "mondar",
    "mondeis": "mondar",
    "mondem": "mondar",
    "mondemo": "mondar",
    "mondemos": "mondar",
    "mondes": "mondar",
    "mondilhos": "mondilho",
    "mondina": "mondino",
    "mondinas": "mondino",
    "mondinenses": "mondinense",
    "mondinos": "mondino",
    "mondo": "mondar",
    "mondonga": "mondongo",
    "mondongas": "mondongo",
    "mondongos": "mondongo",
    "mondongueira": "mondongueiro",
    "mondongueiras": "mondongueiro",
    "mondongueiros": "mondongueiro",
    "mondou": "mondar",
    "mondá": "mondar",
    "mondámo": "mondar",
    "mondámos": "mondar",
    "mondáramo": "mondar",
    "mondáramos": "mondar",
    "mondárei": "mondar",
    "mondáreis": "mondar",
    "mondásseis": "mondar",
    "mondássemos": "mondar",
    "mondávamo": "mondar",
    "mondávamos": "mondar",
    "mondávei": "mondar",
    "mondáveis": "mondar",
    "moneca": "moneco",
    "monecas": "moneco",
    "monecias": "monecia",
    "monecos": "moneco",
    "monegasca": "monegasco",
    "monegascas": "monegasco",
    "monegascos": "monegasco",
    "monelhas": "monelha",
    "monemas": "monema",
    "monenergistas": "monenergista",
    "monenergistos": "monenergisto",
    "moneras": "monera",
    "moneres": "monere",
    "monetarismos": "monetarismo",
    "monetaristas": "monetarista",
    "monetas": "moneta",
    "monetes": "monete",
    "monetiformes": "monetiforme",
    "monetiza": "monetizar",
    "monetizada": "monetizar",
    "monetizadas": "monetizar",
    "monetizado": "monetizar",
    "monetizados": "monetizar",
    "monetizai": "monetizar",
    "monetizais": "monetizar",
    "monetizam": "monetizar",
    "monetizamo": "monetizar",
    "monetizamos": "monetizar",
    "monetizando": "monetizar",
    "monetizara": "monetizar",
    "monetizaram": "monetizar",
    "monetizaras": "monetizar",
    "monetizarde": "monetizar",
    "monetizardes": "monetizar",
    "monetizare": "monetizar",
    "monetizarei": "monetizar",
    "monetizareis": "monetizar",
    "monetizarem": "monetizar",
    "monetizaremos": "monetizar",
    "monetizares": "monetizar",
    "monetizaria": "monetizar",
    "monetizariam": "monetizar",
    "monetizarias": "monetizar",
    "monetizarmo": "monetizar",
    "monetizarmos": "monetizar",
    "monetizará": "monetizar",
    "monetizarás": "monetizar",
    "monetizarão": "monetizar",
    "monetizaríamos": "monetizar",
    "monetizaríeis": "monetizar",
    "monetizas": "monetizar",
    "monetizasse": "monetizar",
    "monetizassem": "monetizar",
    "monetizasses": "monetizar",
    "monetizaste": "monetizar",
    "monetizastes": "monetizar",
    "monetizava": "monetizar",
    "monetizavam": "monetizar",
    "monetizavas": "monetizar",
    "monetize": "monetizar",
    "monetizei": "monetizar",
    "monetizeis": "monetizar",
    "monetizem": "monetizar",
    "monetizemo": "monetizar",
    "monetizemos": "monetizar",
    "monetizes": "monetizar",
    "monetizo": "monetizar",
    "monetizou": "monetizar",
    "monetizá": "monetizar",
    "monetizámo": "monetizar",
    "monetizámos": "monetizar",
    "monetizáramo": "monetizar",
    "monetizáramos": "monetizar",
    "monetizárei": "monetizar",
    "monetizáreis": "monetizar",
    "monetizásseis": "monetizar",
    "monetizássemos": "monetizar",
    "monetizávamo": "monetizar",
    "monetizávamos": "monetizar",
    "monetizávei": "monetizar",
    "monetizáveis": "monetizar",
    "monetária": "monetário",
    "monetárias": "monetário",
    "monetários": "monetário",
    "mongariças": "mongariça",
    "monges": "monge",
    "mongezinho": "monge",
    "mongezinhos": "monge",
    "mongezito": "monge",
    "mongezitos": "monge",
    "mongis": "mongil",
    "mongolismos": "mongolismo",
    "mongolóides": "mongolóide",
    "mongóis": "mongol",
    "mongólica": "mongólico",
    "mongólicas": "mongólico",
    "mongólicos": "mongólico",
    "monhas": "monha",
    "monhos": "monho",
    "monhés": "monhé",
    "monices": "monice",
    "moniliformes": "moniliforme",
    "monimiáceas": "monimiácea",
    "monismos": "monismo",
    "monistas": "monista",
    "monitora": "monitor",
    "monitoras": "monitor",
    "monitores": "monitor",
    "monitoriais": "monitorial",
    "monitorias": "monitoria",
    "monitoriza": "monitorizar",
    "monitorizada": "monitorizar",
    "monitorizadas": "monitorizar",
    "monitorizado": "monitorizar",
    "monitorizados": "monitorizar",
    "monitorizai": "monitorizar",
    "monitorizais": "monitorizar",
    "monitorizam": "monitorizar",
    "monitorizamo": "monitorizar",
    "monitorizamos": "monitorizar",
    "monitorizando": "monitorizar",
    "monitorizara": "monitorizar",
    "monitorizaram": "monitorizar",
    "monitorizaras": "monitorizar",
    "monitorizarde": "monitorizar",
    "monitorizardes": "monitorizar",
    "monitorizare": "monitorizar",
    "monitorizarei": "monitorizar",
    "monitorizareis": "monitorizar",
    "monitorizarem": "monitorizar",
    "monitorizaremos": "monitorizar",
    "monitorizares": "monitorizar",
    "monitorizaria": "monitorizar",
    "monitorizariam": "monitorizar",
    "monitorizarias": "monitorizar",
    "monitorizarmo": "monitorizar",
    "monitorizarmos": "monitorizar",
    "monitorizará": "monitorizar",
    "monitorizarás": "monitorizar",
    "monitorizarão": "monitorizar",
    "monitorizaríamos": "monitorizar",
    "monitorizaríeis": "monitorizar",
    "monitorizas": "monitorizar",
    "monitorizasse": "monitorizar",
    "monitorizassem": "monitorizar",
    "monitorizasses": "monitorizar",
    "monitorizaste": "monitorizar",
    "monitorizastes": "monitorizar",
    "monitorizava": "monitorizar",
    "monitorizavam": "monitorizar",
    "monitorizavas": "monitorizar",
    "monitorizações": "monitorização",
    "monitorize": "monitorizar",
    "monitorizei": "monitorizar",
    "monitorizeis": "monitorizar",
    "monitorizem": "monitorizar",
    "monitorizemo": "monitorizar",
    "monitorizemos": "monitorizar",
    "monitorizes": "monitorizar",
    "monitorizo": "monitorizar",
    "monitorizou": "monitorizar",
    "monitorizá": "monitorizar",
    "monitorizámo": "monitorizar",
    "monitorizámos": "monitorizar",
    "monitorizáramo": "monitorizar",
    "monitorizáramos": "monitorizar",
    "monitorizárei": "monitorizar",
    "monitorizáreis": "monitorizar",
    "monitorizásseis": "monitorizar",
    "monitorizássemos": "monitorizar",
    "monitorizávamo": "monitorizar",
    "monitorizávamos": "monitorizar",
    "monitorizávei": "monitorizar",
    "monitorizáveis": "monitorizar",
    "monitors": "monitor",
    "monitórias": "monitória",
    "moniçãozinha": "monição",
    "moniçãozita": "monição",
    "monições": "monição",
    "moniçõezinhas": "monição",
    "moniçõezitas": "monição",
    "monja": "monge",
    "monjais": "monjal",
    "monjas": "monge",
    "monjazinha": "monge",
    "monjazinhas": "monge",
    "monjazita": "monge",
    "monjazitas": "monge",
    "monoatómica": "monoatómico",
    "monoatómicas": "monoatómico",
    "monoatómicos": "monoatómico",
    "monoblocos": "monobloco",
    "monocabos": "monocabo",
    "monocarpa": "monocarpo",
    "monocarpas": "monocarpo",
    "monocarpelares": "monocarpelar",
    "monocarpos": "monocarpo",
    "monocarris": "monocarril",
    "monocefalias": "monocefalia",
    "monocelulares": "monocelular",
    "monocerontes": "monoceronte",
    "monociclistas": "monociclista",
    "monociclos": "monociclo",
    "monocilíndrica": "monocilíndrico",
    "monocilíndricas": "monocilíndrico",
    "monocilíndricos": "monocilíndrico",
    "monoclina": "monoclino",
    "monoclinais": "monoclinal",
    "monoclinas": "monoclino",
    "monoclinos": "monoclino",
    "monoclínica": "monoclínico",
    "monoclínicas": "monoclínico",
    "monoclínicos": "monoclínico",
    "monocordos": "monocordo",
    "monocotiledónea": "monocotiledóneo",
    "monocotiledóneas": "monocotiledóneo",
    "monocotiledóneos": "monocotiledóneo",
    "monocristais": "monocristal",
    "monocroma": "monocromo",
    "monocromadors": "monocromador",
    "monocromas": "monocromo",
    "monocromatas": "monocromata",
    "monocromatismos": "monocromatismo",
    "monocromias": "monocromia",
    "monocromos": "monocromo",
    "monocromática": "monocromático",
    "monocromáticas": "monocromático",
    "monocromáticos": "monocromático",
    "monocrómica": "monocrómico",
    "monocrómicas": "monocrómico",
    "monocrómicos": "monocrómico",
    "monoculares": "monocular",
    "monoculiza": "monoculizar",
    "monoculizada": "monoculizar",
    "monoculizadas": "monoculizar",
    "monoculizado": "monoculizar",
    "monoculizados": "monoculizar",
    "monoculizai": "monoculizar",
    "monoculizais": "monoculizar",
    "monoculizam": "monoculizar",
    "monoculizamo": "monoculizar",
    "monoculizamos": "monoculizar",
    "monoculizando": "monoculizar",
    "monoculizara": "monoculizar",
    "monoculizaram": "monoculizar",
    "monoculizaras": "monoculizar",
    "monoculizarde": "monoculizar",
    "monoculizardes": "monoculizar",
    "monoculizare": "monoculizar",
    "monoculizarei": "monoculizar",
    "monoculizareis": "monoculizar",
    "monoculizarem": "monoculizar",
    "monoculizaremos": "monoculizar",
    "monoculizares": "monoculizar",
    "monoculizaria": "monoculizar",
    "monoculizariam": "monoculizar",
    "monoculizarias": "monoculizar",
    "monoculizarmo": "monoculizar",
    "monoculizarmos": "monoculizar",
    "monoculizará": "monoculizar",
    "monoculizarás": "monoculizar",
    "monoculizarão": "monoculizar",
    "monoculizaríamos": "monoculizar",
    "monoculizaríeis": "monoculizar",
    "monoculizas": "monoculizar",
    "monoculizasse": "monoculizar",
    "monoculizassem": "monoculizar",
    "monoculizasses": "monoculizar",
    "monoculizaste": "monoculizar",
    "monoculizastes": "monoculizar",
    "monoculizava": "monoculizar",
    "monoculizavam": "monoculizar",
    "monoculizavas": "monoculizar",
    "monoculize": "monoculizar",
    "monoculizei": "monoculizar",
    "monoculizeis": "monoculizar",
    "monoculizem": "monoculizar",
    "monoculizemo": "monoculizar",
    "monoculizemos": "monoculizar",
    "monoculizes": "monoculizar",
    "monoculizo": "monoculizar",
    "monoculizou": "monoculizar",
    "monoculizá": "monoculizar",
    "monoculizámo": "monoculizar",
    "monoculizámos": "monoculizar",
    "monoculizáramo": "monoculizar",
    "monoculizáramos": "monoculizar",
    "monoculizárei": "monoculizar",
    "monoculizáreis": "monoculizar",
    "monoculizásseis": "monoculizar",
    "monoculizássemos": "monoculizar",
    "monoculizávamo": "monoculizar",
    "monoculizávamos": "monoculizar",
    "monoculizávei": "monoculizar",
    "monoculizáveis": "monoculizar",
    "monocultora": "monocultor",
    "monocultoras": "monocultor",
    "monocultores": "monocultor",
    "monoculturas": "monocultura",
    "monocárpica": "monocárpico",
    "monocárpicas": "monocárpico",
    "monocárpicos": "monocárpico",
    "monocéfala": "monocéfalo",
    "monocéfalas": "monocéfalo",
    "monocéfalos": "monocéfalo",
    "monocórdica": "monocórdico",
    "monocórdicas": "monocórdico",
    "monocórdicos": "monocórdico",
    "monocórdios": "monocórdio",
    "monodia": "monodiar",
    "monodiada": "monodiar",
    "monodiadas": "monodiar",
    "monodiado": "monodiar",
    "monodiados": "monodiar",
    "monodiai": "monodiar",
    "monodiais": "monodiar",
    "monodiam": "monodiar",
    "monodiamo": "monodiar",
    "monodiamos": "monodiar",
    "monodiando": "monodiar",
    "monodiara": "monodiar",
    "monodiaram": "monodiar",
    "monodiaras": "monodiar",
    "monodiardes": "monodiar",
    "monodiarei": "monodiar",
    "monodiareis": "monodiar",
    "monodiarem": "monodiar",
    "monodiaremos": "monodiar",
    "monodiares": "monodiar",
    "monodiaria": "monodiar",
    "monodiariam": "monodiar",
    "monodiarias": "monodiar",
    "monodiarmo": "monodiar",
    "monodiarmos": "monodiar",
    "monodiará": "monodiar",
    "monodiarás": "monodiar",
    "monodiarão": "monodiar",
    "monodiaríamos": "monodiar",
    "monodiaríeis": "monodiar",
    "monodias": "monodiar",
    "monodiasse": "monodiar",
    "monodiassem": "monodiar",
    "monodiasses": "monodiar",
    "monodiaste": "monodiar",
    "monodiastes": "monodiar",
    "monodiava": "monodiar",
    "monodiavam": "monodiar",
    "monodiavas": "monodiar",
    "monodie": "monodiar",
    "monodiei": "monodiar",
    "monodieis": "monodiar",
    "monodiem": "monodiar",
    "monodiemo": "monodiar",
    "monodiemos": "monodiar",
    "monodies": "monodiar",
    "monodinamismos": "monodinamismo",
    "monodio": "monodiar",
    "monodiou": "monodiar",
    "monodispersa": "monodisperso",
    "monodispersas": "monodisperso",
    "monodispersos": "monodisperso",
    "monodiámo": "monodiar",
    "monodiámos": "monodiar",
    "monodiáramo": "monodiar",
    "monodiáramos": "monodiar",
    "monodiáreis": "monodiar",
    "monodiásseis": "monodiar",
    "monodiássemos": "monodiar",
    "monodiávamo": "monodiar",
    "monodiávamos": "monodiar",
    "monodiáveis": "monodiar",
    "monodontes": "monodonte",
    "monodramas": "monodrama",
    "monodáctila": "monodáctilo",
    "monodáctilas": "monodáctilo",
    "monodáctilos": "monodáctilo",
    "monofila": "monofilo",
    "monofilas": "monofilo",
    "monofilos": "monofilo",
    "monofilética": "monofilético",
    "monofiléticas": "monofilético",
    "monofiléticos": "monofilético",
    "monofiodontes": "monofiodonte",
    "monofisismos": "monofisismo",
    "monofisistas": "monofisista",
    "monofisitas": "monofisita",
    "monofobias": "monofobia",
    "monofonias": "monofonia",
    "monofotos": "monofoto",
    "monoftalma": "monoftalmo",
    "monoftalmas": "monoftalmo",
    "monoftalmos": "monoftalmo",
    "monofásica": "monofásico",
    "monofásicas": "monofásico",
    "monofásicos": "monofásico",
    "monogamias": "monogamia",
    "monogamistas": "monogamista",
    "monogenias": "monogenia",
    "monogenismos": "monogenismo",
    "monogenistas": "monogenista",
    "monogenética": "monogenético",
    "monogenéticas": "monogenético",
    "monogenéticos": "monogenético",
    "monoginias": "monoginia",
    "monoglótica": "monoglótico",
    "monoglóticas": "monoglótico",
    "monoglóticos": "monoglótico",
    "monografa": "monografar",
    "monografada": "monografar",
    "monografadas": "monografar",
    "monografado": "monografar",
    "monografados": "monografar",
    "monografai": "monografar",
    "monografais": "monografar",
    "monografam": "monografar",
    "monografamo": "monografar",
    "monografamos": "monografar",
    "monografando": "monografar",
    "monografara": "monografar",
    "monografaram": "monografar",
    "monografaras": "monografar",
    "monografarde": "monografar",
    "monografardes": "monografar",
    "monografare": "monografar",
    "monografarei": "monografar",
    "monografareis": "monografar",
    "monografarem": "monografar",
    "monografaremos": "monografar",
    "monografares": "monografar",
    "monografaria": "monografar",
    "monografariam": "monografar",
    "monografarias": "monografar",
    "monografarmo": "monografar",
    "monografarmos": "monografar",
    "monografará": "monografar",
    "monografarás": "monografar",
    "monografarão": "monografar",
    "monografaríamos": "monografar",
    "monografaríeis": "monografar",
    "monografas": "monografar",
    "monografasse": "monografar",
    "monografassem": "monografar",
    "monografasses": "monografar",
    "monografaste": "monografar",
    "monografastes": "monografar",
    "monografava": "monografar",
    "monografavam": "monografar",
    "monografavas": "monografar",
    "monografe": "monografar",
    "monografei": "monografar",
    "monografeis": "monografar",
    "monografem": "monografar",
    "monografemo": "monografar",
    "monografemos": "monografar",
    "monografes": "monografar",
    "monografias": "monografia",
    "monografistas": "monografista",
    "monografo": "monografar",
    "monografou": "monografar",
    "monografá": "monografar",
    "monografámo": "monografar",
    "monografámos": "monografar",
    "monografáramo": "monografar",
    "monografáramos": "monografar",
    "monografárei": "monografar",
    "monografáreis": "monografar",
    "monografásseis": "monografar",
    "monografássemos": "monografar",
    "monografávamo": "monografar",
    "monografávamos": "monografar",
    "monografávei": "monografar",
    "monografáveis": "monografar",
    "monograma": "monogramo",
    "monogramas": "monogramo",
    "monogramistas": "monogramista",
    "monogramos": "monogramo",
    "monogramática": "monogramático",
    "monogramáticas": "monogramático",
    "monogramáticos": "monogramático",
    "monográfica": "monográfico",
    "monográficas": "monográfico",
    "monográficos": "monográfico",
    "monogástrica": "monogástrico",
    "monogástricas": "monogástrico",
    "monogástricos": "monogástrico",
    "monogâmica": "monogâmico",
    "monogâmicas": "monogâmico",
    "monogâmicos": "monogâmico",
    "monogéneses": "monogénese",
    "monogénica": "monogénico",
    "monogénicas": "monogénico",
    "monogénicos": "monogénico",
    "monogénios": "monogénio",
    "monoibridismos": "monoibridismo",
    "monoicias": "monoicia",
    "monoideísmos": "monoideísmo",
    "monolatrias": "monolatria",
    "monolitismos": "monolitismo",
    "monologa": "monologar",
    "monologada": "monologar",
    "monologadas": "monologar",
    "monologado": "monologar",
    "monologados": "monologar",
    "monologai": "monologar",
    "monologais": "monologar",
    "monologam": "monologar",
    "monologamo": "monologar",
    "monologamos": "monologar",
    "monologando": "monologar",
    "monologara": "monologar",
    "monologaram": "monologar",
    "monologaras": "monologar",
    "monologarde": "monologar",
    "monologardes": "monologar",
    "monologare": "monologar",
    "monologarei": "monologar",
    "monologareis": "monologar",
    "monologarem": "monologar",
    "monologaremos": "monologar",
    "monologares": "monologar",
    "monologaria": "monologar",
    "monologariam": "monologar",
    "monologarias": "monologar",
    "monologarmo": "monologar",
    "monologarmos": "monologar",
    "monologará": "monologar",
    "monologarás": "monologar",
    "monologarão": "monologar",
    "monologaríamos": "monologar",
    "monologaríeis": "monologar",
    "monologas": "monologar",
    "monologasse": "monologar",
    "monologassem": "monologar",
    "monologasses": "monologar",
    "monologaste": "monologar",
    "monologastes": "monologar",
    "monologava": "monologar",
    "monologavam": "monologar",
    "monologavas": "monologar",
    "monologias": "monologia",
    "monologo": "monologar",
    "monologou": "monologar",
    "monologue": "monologar",
    "monologuei": "monologar",
    "monologueis": "monologar",
    "monologuem": "monologar",
    "monologuemo": "monologar",
    "monologuemos": "monologar",
    "monologues": "monologar",
    "monologuistas": "monologuista",
    "monologá": "monologar",
    "monologámo": "monologar",
    "monologámos": "monologar",
    "monologáramo": "monologar",
    "monologáramos": "monologar",
    "monologárei": "monologar",
    "monologáreis": "monologar",
    "monologásseis": "monologar",
    "monologássemos": "monologar",
    "monologávamo": "monologar",
    "monologávamos": "monologar",
    "monologávei": "monologar",
    "monologáveis": "monologar",
    "monolugares": "monolugar",
    "monolépida": "monolépido",
    "monolépidas": "monolépido",
    "monolépides": "monolépide",
    "monolépidos": "monolépido",
    "monolítica": "monolítico",
    "monolíticas": "monolítico",
    "monolíticos": "monolítico",
    "monológica": "monológico",
    "monológicas": "monológico",
    "monológicos": "monológico",
    "monomanias": "monomania",
    "monomaníaca": "monomaníaco",
    "monomaníacas": "monomaníaco",
    "monomaníacos": "monomaníaco",
    "monomaquias": "monomaquia",
    "monometalismos": "monometalismo",
    "monometalistas": "monometalista",
    "monomorfismos": "monomorfismo",
    "monomotora": "monomotor",
    "monomotoras": "monomotor",
    "monomotores": "monomotor",
    "monomérica": "monomérico",
    "monoméricas": "monomérico",
    "monoméricos": "monomérico",
    "monométrica": "monométrico",
    "monométricas": "monométrico",
    "monométricos": "monométrico",
    "monomórfica": "monomórfico",
    "monomórficas": "monomórfico",
    "monomórficos": "monomórfico",
    "mononfalias": "mononfalia",
    "mononucleoses": "mononucleose",
    "monoparentais": "monoparental",
    "monopes": "monope",
    "monoplanos": "monoplano",
    "monoplegias": "monoplegia",
    "monoplástica": "monoplástico",
    "monoplásticas": "monoplástico",
    "monoplásticos": "monoplástico",
    "monopneumones": "monopneumone",
    "monopnêumones": "monopnêumone",
    "monopodiais": "monopodial",
    "monopodias": "monopodia",
    "monopolistas": "monopolista",
    "monopoliza": "monopolizar",
    "monopolizada": "monopolizar",
    "monopolizadas": "monopolizar",
    "monopolizado": "monopolizar",
    "monopolizadora": "monopolizador",
    "monopolizadoras": "monopolizador",
    "monopolizadores": "monopolizador",
    "monopolizados": "monopolizar",
    "monopolizai": "monopolizar",
    "monopolizais": "monopolizar",
    "monopolizam": "monopolizar",
    "monopolizamo": "monopolizar",
    "monopolizamos": "monopolizar",
    "monopolizando": "monopolizar",
    "monopolizara": "monopolizar",
    "monopolizaram": "monopolizar",
    "monopolizaras": "monopolizar",
    "monopolizarde": "monopolizar",
    "monopolizardes": "monopolizar",
    "monopolizare": "monopolizar",
    "monopolizarei": "monopolizar",
    "monopolizareis": "monopolizar",
    "monopolizarem": "monopolizar",
    "monopolizaremos": "monopolizar",
    "monopolizares": "monopolizar",
    "monopolizaria": "monopolizar",
    "monopolizariam": "monopolizar",
    "monopolizarias": "monopolizar",
    "monopolizarmo": "monopolizar",
    "monopolizarmos": "monopolizar",
    "monopolizará": "monopolizar",
    "monopolizarás": "monopolizar",
    "monopolizarão": "monopolizar",
    "monopolizaríamos": "monopolizar",
    "monopolizaríeis": "monopolizar",
    "monopolizas": "monopolizar",
    "monopolizasse": "monopolizar",
    "monopolizassem": "monopolizar",
    "monopolizasses": "monopolizar",
    "monopolizaste": "monopolizar",
    "monopolizastes": "monopolizar",
    "monopolizava": "monopolizar",
    "monopolizavam": "monopolizar",
    "monopolizavas": "monopolizar",
    "monopolizações": "monopolização",
    "monopolize": "monopolizar",
    "monopolizei": "monopolizar",
    "monopolizeis": "monopolizar",
    "monopolizem": "monopolizar",
    "monopolizemo": "monopolizar",
    "monopolizemos": "monopolizar",
    "monopolizes": "monopolizar",
    "monopolizo": "monopolizar",
    "monopolizou": "monopolizar",
    "monopolizá": "monopolizar",
    "monopolizámo": "monopolizar",
    "monopolizámos": "monopolizar",
    "monopolizáramo": "monopolizar",
    "monopolizáramos": "monopolizar",
    "monopolizárei": "monopolizar",
    "monopolizáreis": "monopolizar",
    "monopolizásseis": "monopolizar",
    "monopolizássemos": "monopolizar",
    "monopolizávamo": "monopolizar",
    "monopolizávamos": "monopolizar",
    "monopolizávei": "monopolizar",
    "monopolizáveis": "monopolizável",
    "monopsónios": "monopsónio",
    "monopétala": "monopétalo",
    "monopétalas": "monopétalo",
    "monopétalos": "monopétalo",
    "monopódia": "monopódio",
    "monopódias": "monopódio",
    "monopódica": "monopódico",
    "monopódicas": "monopódico",
    "monopódicos": "monopódico",
    "monopódios": "monopódio",
    "monopólios": "monopólio",
    "monoquinis": "monoquini",
    "monorrima": "monorrimo",
    "monorrimas": "monorrimo",
    "monorrimos": "monorrimo",
    "monorrinos": "monorrino",
    "monorrítmica": "monorrítmico",
    "monorrítmicas": "monorrítmico",
    "monorrítmicos": "monorrítmico",
    "monos": "mono",
    "monosperma": "monospermo",
    "monospermas": "monospermo",
    "monospermias": "monospermia",
    "monospermos": "monospermo",
    "monospérmica": "monospérmico",
    "monospérmicas": "monospérmico",
    "monospérmicos": "monospérmico",
    "monossacarídeos": "monossacarídeo",
    "monossemias": "monossemia",
    "monosseriada": "monosseriado",
    "monosseriadas": "monosseriado",
    "monosseriados": "monosseriado",
    "monossilabismos": "monossilabismo",
    "monossilábica": "monossilábico",
    "monossilábicas": "monossilábico",
    "monossilábicos": "monossilábico",
    "monossintonias": "monossintonia",
    "monossitias": "monossitia",
    "monossémica": "monossémico",
    "monossémicas": "monossémico",
    "monossémicos": "monossémico",
    "monossépala": "monossépalo",
    "monossépalas": "monossépalo",
    "monossépalos": "monossépalo",
    "monossílaba": "monossílabo",
    "monossílabas": "monossílabo",
    "monossílabos": "monossílabo",
    "monostelas": "monostela",
    "monostila": "monostilo",
    "monostilas": "monostilo",
    "monostilos": "monostilo",
    "monostélica": "monostélico",
    "monostélicas": "monostélico",
    "monostélicos": "monostélico",
    "monotalâmica": "monotalâmico",
    "monotalâmicas": "monotalâmico",
    "monotalâmicos": "monotalâmico",
    "monoteica": "monoteico",
    "monoteicas": "monoteico",
    "monoteicos": "monoteico",
    "monotelismos": "monotelismo",
    "monotelitas": "monotelita",
    "monotelitismos": "monotelitismo",
    "monoteísmos": "monoteísmo",
    "monoteístas": "monoteísta",
    "monotipias": "monotipia",
    "monotipistas": "monotipista",
    "monotipos": "monotipo",
    "monotongos": "monotongo",
    "monotonias": "monotonia",
    "monotrema": "monotremo",
    "monotremas": "monotremo",
    "monotremos": "monotremo",
    "monotrilhos": "monotrilho",
    "monotropias": "monotropia",
    "monotrémata": "monotrémato",
    "monotrématas": "monotrémato",
    "monotrématos": "monotrémato",
    "monotrópica": "monotrópico",
    "monotrópicas": "monotrópico",
    "monotrópicos": "monotrópico",
    "monotálama": "monotálamo",
    "monotálamas": "monotálamo",
    "monotálamos": "monotálamo",
    "monotípica": "monotípico",
    "monotípicas": "monotípico",
    "monotípicos": "monotípico",
    "monovalentes": "monovalente",
    "monovolumes": "monovolume",
    "monoxós": "monoxó",
    "monozigótica": "monozigótico",
    "monozigóticas": "monozigótico",
    "monozigóticos": "monozigótico",
    "monozoicidades": "monozoicidade",
    "monozoários": "monozoário",
    "monozóica": "monozóico",
    "monozóicas": "monozóico",
    "monozóicos": "monozóico",
    "monoácidos": "monoácido",
    "monoécias": "monoécia",
    "monquilhos": "monquilho",
    "monroísmos": "monroísmo",
    "monroístas": "monroísta",
    "monsenhorados": "monsenhorado",
    "monsenhores": "monsenhor",
    "monsenhorias": "monsenhoria",
    "monsieurs": "monsieur",
    "monstra": "monstro",
    "monstras": "monstro",
    "monstrengos": "monstrengo",
    "monstros": "monstro",
    "monstruosa": "monstruoso",
    "monstruosas": "monstruoso",
    "monstruosidades": "monstruosidade",
    "monstruosos": "monstruoso",
    "monstruosíssima": "monstruoso",
    "monstruosíssimas": "monstruoso",
    "monstruosíssimo": "monstruoso",
    "monstruosíssimos": "monstruoso",
    "monta": "montar",
    "montada": "montar",
    "montadas": "montar",
    "montado": "montar",
    "montadora": "montador",
    "montadoras": "montador",
    "montadores": "montador",
    "montados": "montar",
    "montagens": "montagem",
    "montai": "montar",
    "montais": "montar",
    "montam": "montar",
    "montamo": "montar",
    "montamos": "montar",
    "montana": "montano",
    "montanas": "montano",
    "montando": "montar",
    "montanhaques": "montanhaque",
    "montanhas": "montanha",
    "montanheira": "montanheiro",
    "montanheiras": "montanheiro",
    "montanheiros": "montanheiro",
    "montanhesa": "montanhês",
    "montanhesas": "montanhês",
    "montanhesca": "montanhesco",
    "montanhescas": "montanhesco",
    "montanhescos": "montanhesco",
    "montanheses": "montanhês",
    "montanhismos": "montanhismo",
    "montanhistas": "montanhista",
    "montanhona": "montanhão",
    "montanhonas": "montanhão",
    "montanhosa": "montanhoso",
    "montanhosas": "montanhoso",
    "montanhosos": "montanhoso",
    "montanhões": "montanhão",
    "montanismos": "montanismo",
    "montanistas": "montanista",
    "montanos": "montano",
    "montantes": "montante",
    "montanística": "montanístico",
    "montanísticas": "montanístico",
    "montanísticos": "montanístico",
    "montara": "montar",
    "montaram": "montar",
    "montaras": "montar",
    "montarazes": "montaraz",
    "montarde": "montar",
    "montardes": "montar",
    "montare": "montar",
    "montarei": "montar",
    "montareis": "montar",
    "montarem": "montar",
    "montaremos": "montar",
    "montares": "montar",
    "montaria": "montar",
    "montariam": "montar",
    "montarias": "montaria",
    "montarmo": "montar",
    "montarmos": "montar",
    "montará": "montar",
    "montarás": "montar",
    "montarão": "montar",
    "montaríamos": "montar",
    "montaríeis": "montar",
    "montas": "montar",
    "montasse": "montar",
    "montassem": "montar",
    "montasses": "montar",
    "montaste": "montar",
    "montastes": "montar",
    "montava": "montar",
    "montavam": "montar",
    "montavas": "montar",
    "monte": "montar",
    "monteada": "montear",
    "monteadas": "montear",
    "monteado": "montear",
    "monteadora": "monteador",
    "monteadoras": "monteador",
    "monteadores": "monteador",
    "monteados": "montear",
    "monteai": "montear",
    "monteais": "montear",
    "monteamo": "montear",
    "monteamos": "montear",
    "monteando": "montear",
    "monteara": "montear",
    "montearam": "montear",
    "montearas": "montear",
    "montearde": "montear",
    "monteardes": "montear",
    "monteare": "montear",
    "montearei": "montear",
    "monteareis": "montear",
    "montearem": "montear",
    "montearemos": "montear",
    "monteares": "montear",
    "montearia": "montear",
    "monteariam": "montear",
    "montearias": "montear",
    "montearmo": "montear",
    "montearmos": "montear",
    "monteará": "montear",
    "montearás": "montear",
    "montearão": "montear",
    "montearíamos": "montear",
    "montearíeis": "montear",
    "monteasse": "montear",
    "monteassem": "montear",
    "monteasses": "montear",
    "monteaste": "montear",
    "monteastes": "montear",
    "monteava": "montear",
    "monteavam": "montear",
    "monteavas": "montear",
    "monteei": "montear",
    "monteeis": "montear",
    "monteemo": "montear",
    "monteemos": "montear",
    "montei": "montar",
    "monteia": "montear",
    "monteiam": "montear",
    "monteias": "monteia",
    "monteie": "montear",
    "monteiem": "montear",
    "monteies": "montear",
    "monteio": "montear",
    "monteira": "monteiro",
    "monteiras": "monteiro",
    "monteirias": "monteiria",
    "monteiros": "monteiro",
    "monteis": "montar",
    "montem": "montar",
    "montemo": "montar",
    "montemorenses": "montemorense",
    "montemos": "montar",
    "montenegrina": "montenegrino",
    "montenegrinas": "montenegrino",
    "montenegrinos": "montenegrino",
    "monteou": "montear",
    "montepios": "montepio",
    "montes": "monte",
    "montesa": "montês",
    "montesas": "montês",
    "monteses": "montês",
    "montesina": "montesino",
    "montesinas": "montesino",
    "montesinha": "montesinho",
    "montesinhas": "montesinho",
    "montesinhos": "montesinho",
    "montesinos": "montesino",
    "montevideana": "montevideano",
    "montevideanas": "montevideano",
    "montevideanos": "montevideano",
    "monteá": "montear",
    "monteámo": "montear",
    "monteámos": "montear",
    "monteáramo": "montear",
    "monteáramos": "montear",
    "monteárei": "montear",
    "monteáreis": "montear",
    "monteásseis": "montear",
    "monteássemos": "montear",
    "monteávamo": "montear",
    "monteávamos": "montear",
    "monteávei": "montear",
    "monteáveis": "montear",
    "montijenses": "montijense",
    "montijos": "montijo",
    "montinho": "monte",
    "montinhos": "monte",
    "montito": "monte",
    "montitos": "monte",
    "montmorilonites": "montmorilonite",
    "monto": "montar",
    "montoeiras": "montoeira",
    "montou": "montar",
    "montras": "montra",
    "montuosa": "montuoso",
    "montuosas": "montuoso",
    "montuosos": "montuoso",
    "montureira": "montureiro",
    "montureiras": "montureiro",
    "montureiros": "montureiro",
    "monturos": "monturo",
    "montá": "montar",
    "montádegos": "montádego",
    "montádigos": "montádigo",
    "montámo": "montar",
    "montámos": "montar",
    "montáramo": "montar",
    "montáramos": "montar",
    "montárei": "montar",
    "montáreis": "montar",
    "montásseis": "montar",
    "montássemos": "montar",
    "montávamo": "montar",
    "montávamos": "montar",
    "montávei": "montar",
    "montáveis": "montável",
    "montícolas": "montícola",
    "montículos": "montículo",
    "montígena": "montígeno",
    "montígenas": "montígeno",
    "montígenos": "montígeno",
    "montívaga": "montívago",
    "montívagas": "montívago",
    "montívagos": "montívago",
    "montões": "montão",
    "monumentais": "monumental",
    "monumentalidades": "monumentalidade",
    "monumentaliza": "monumentalizar",
    "monumentalizada": "monumentalizar",
    "monumentalizadas": "monumentalizar",
    "monumentalizado": "monumentalizar",
    "monumentalizados": "monumentalizar",
    "monumentalizai": "monumentalizar",
    "monumentalizais": "monumentalizar",
    "monumentalizam": "monumentalizar",
    "monumentalizamo": "monumentalizar",
    "monumentalizamos": "monumentalizar",
    "monumentalizando": "monumentalizar",
    "monumentalizara": "monumentalizar",
    "monumentalizaram": "monumentalizar",
    "monumentalizaras": "monumentalizar",
    "monumentalizarde": "monumentalizar",
    "monumentalizardes": "monumentalizar",
    "monumentalizare": "monumentalizar",
    "monumentalizarei": "monumentalizar",
    "monumentalizareis": "monumentalizar",
    "monumentalizarem": "monumentalizar",
    "monumentalizaremos": "monumentalizar",
    "monumentalizares": "monumentalizar",
    "monumentalizaria": "monumentalizar",
    "monumentalizariam": "monumentalizar",
    "monumentalizarias": "monumentalizar",
    "monumentalizarmo": "monumentalizar",
    "monumentalizarmos": "monumentalizar",
    "monumentalizará": "monumentalizar",
    "monumentalizarás": "monumentalizar",
    "monumentalizarão": "monumentalizar",
    "monumentalizaríamos": "monumentalizar",
    "monumentalizaríeis": "monumentalizar",
    "monumentalizas": "monumentalizar",
    "monumentalizasse": "monumentalizar",
    "monumentalizassem": "monumentalizar",
    "monumentalizasses": "monumentalizar",
    "monumentalizaste": "monumentalizar",
    "monumentalizastes": "monumentalizar",
    "monumentalizava": "monumentalizar",
    "monumentalizavam": "monumentalizar",
    "monumentalizavas": "monumentalizar",
    "monumentalize": "monumentalizar",
    "monumentalizei": "monumentalizar",
    "monumentalizeis": "monumentalizar",
    "monumentalizem": "monumentalizar",
    "monumentalizemo": "monumentalizar",
    "monumentalizemos": "monumentalizar",
    "monumentalizes": "monumentalizar",
    "monumentalizo": "monumentalizar",
    "monumentalizou": "monumentalizar",
    "monumentalizá": "monumentalizar",
    "monumentalizámo": "monumentalizar",
    "monumentalizámos": "monumentalizar",
    "monumentalizáramo": "monumentalizar",
    "monumentalizáramos": "monumentalizar",
    "monumentalizárei": "monumentalizar",
    "monumentalizáreis": "monumentalizar",
    "monumentalizásseis": "monumentalizar",
    "monumentalizássemos": "monumentalizar",
    "monumentalizávamo": "monumentalizar",
    "monumentalizávamos": "monumentalizar",
    "monumentalizávei": "monumentalizar",
    "monumentalizáveis": "monumentalizar",
    "monumentos": "monumento",
    "monumentosa": "monumentoso",
    "monumentosas": "monumentoso",
    "monumentosos": "monumentoso",
    "monvedros": "monvedro",
    "monzonites": "monzonite",
    "monzonitos": "monzonito",
    "monácidos": "monácido",
    "monárquica": "monárquico",
    "monárquicas": "monárquico",
    "monárquicos": "monárquico",
    "monástica": "monástico",
    "monásticas": "monástico",
    "monásticos": "monástico",
    "monândrias": "monândria",
    "monândrica": "monândrico",
    "monândricas": "monândrico",
    "monândricos": "monândrico",
    "monções": "monção",
    "monécias": "monécia",
    "monécica": "monécico",
    "monécicas": "monécico",
    "monécicos": "monécico",
    "monística": "monístico",
    "monísticas": "monístico",
    "monísticos": "monístico",
    "monócera": "monócero",
    "monóceras": "monócero",
    "monóceros": "monócero",
    "monócitos": "monócito",
    "monócula": "monóculo",
    "monóculas": "monóculo",
    "monóculos": "monóculo",
    "monódias": "monódia",
    "monófita": "monófito",
    "monófitas": "monófito",
    "monófitos": "monófito",
    "monófoba": "monófobo",
    "monófobas": "monófobo",
    "monófobos": "monófobo",
    "monófona": "monófono",
    "monófonas": "monófono",
    "monófonos": "monófono",
    "monógama": "monógamo",
    "monógamas": "monógamo",
    "monógamos": "monógamo",
    "monógena": "monógeno",
    "monógenas": "monógeno",
    "monógenos": "monógeno",
    "monógina": "monógino",
    "monóginas": "monógino",
    "monóginos": "monógino",
    "monógnatos": "monógnato",
    "monógrafa": "monógrafo",
    "monógrafas": "monógrafo",
    "monógrafos": "monógrafo",
    "monóica": "monóico",
    "monóicas": "monóico",
    "monóicos": "monóico",
    "monóides": "monóide",
    "monólitos": "monólito",
    "monólogos": "monólogo",
    "monómera": "monómero",
    "monómeras": "monómero",
    "monómeros": "monómero",
    "monómetra": "monómetro",
    "monómetras": "monómetro",
    "monómetros": "monómetro",
    "monómios": "monómio",
    "monópodes": "monópode",
    "monóptera": "monóptero",
    "monópteras": "monóptero",
    "monópteros": "monóptero",
    "monóspora": "monósporo",
    "monósporas": "monósporo",
    "monósporos": "monósporo",
    "monóstica": "monóstico",
    "monósticas": "monóstico",
    "monósticos": "monóstico",
    "monóstrofa": "monóstrofo",
    "monóstrofas": "monóstrofo",
    "monóstrofes": "monóstrofe",
    "monóstrofos": "monóstrofo",
    "monótipos": "monótipo",
    "monótona": "monótono",
    "monótonas": "monótono",
    "monótonos": "monótono",
    "monóxena": "monóxeno",
    "monóxenas": "monóxeno",
    "monóxenos": "monóxeno",
    "monóxidos": "monóxido",
    "monóxila": "monóxilo",
    "monóxilas": "monóxilo",
    "monóxilos": "monóxilo",
    "moo": "moer",
    "moqueada": "moquear",
    "moqueadas": "moquear",
    "moqueado": "moquear",
    "moqueados": "moquear",
    "moqueai": "moquear",
    "moqueais": "moquear",
    "moqueamo": "moquear",
    "moqueamos": "moquear",
    "moqueando": "moquear",
    "moqueara": "moquear",
    "moquearam": "moquear",
    "moquearas": "moquear",
    "moquearde": "moquear",
    "moqueardes": "moquear",
    "moqueare": "moquear",
    "moquearei": "moquear",
    "moqueareis": "moquear",
    "moquearem": "moquear",
    "moquearemos": "moquear",
    "moqueares": "moquear",
    "moquearia": "moquear",
    "moqueariam": "moquear",
    "moquearias": "moquear",
    "moquearmo": "moquear",
    "moquearmos": "moquear",
    "moqueará": "moquear",
    "moquearás": "moquear",
    "moquearão": "moquear",
    "moquearíamos": "moquear",
    "moquearíeis": "moquear",
    "moqueasse": "moquear",
    "moqueassem": "moquear",
    "moqueasses": "moquear",
    "moqueaste": "moquear",
    "moqueastes": "moquear",
    "moqueava": "moquear",
    "moqueavam": "moquear",
    "moqueavas": "moquear",
    "moqueações": "moqueação",
    "moquecas": "moqueca",
    "moqueei": "moquear",
    "moqueeis": "moquear",
    "moqueemo": "moquear",
    "moqueemos": "moquear",
    "moqueia": "moquear",
    "moqueiam": "moquear",
    "moqueias": "moquear",
    "moqueie": "moquear",
    "moqueiem": "moquear",
    "moqueies": "moquear",
    "moqueio": "moquear",
    "moquenca": "moquenco",
    "moquencas": "moquenco",
    "moquencos": "moquenco",
    "moquenqueira": "moquenqueiro",
    "moquenqueiras": "moquenqueiro",
    "moquenqueiros": "moquenqueiro",
    "moquenquices": "moquenquice",
    "moqueou": "moquear",
    "moquetas": "moqueta",
    "moqueá": "moquear",
    "moqueámo": "moquear",
    "moqueámos": "moquear",
    "moqueáramo": "moquear",
    "moqueáramos": "moquear",
    "moqueárei": "moquear",
    "moqueáreis": "moquear",
    "moqueásseis": "moquear",
    "moqueássemos": "moquear",
    "moqueávamo": "moquear",
    "moqueávamos": "moquear",
    "moqueávei": "moquear",
    "moqueáveis": "moquear",
    "moquéns": "moquém",
    "mora": "morar",
    "morabita": "morabito",
    "morabitas": "morabito",
    "morabitinadas": "morabitinada",
    "morabitinos": "morabitino",
    "morabitos": "morabito",
    "morada": "morar",
    "moradas": "morar",
    "moradias": "moradia",
    "moradilhos": "moradilho",
    "moradios": "moradio",
    "morado": "morar",
    "moradora": "morador",
    "moradoras": "morador",
    "moradores": "morador",
    "morados": "morar",
    "morai": "morar",
    "morainas": "moraina",
    "morais": "morar",
    "moraises": "moraís",
    "moralidades": "moralidade",
    "moralismos": "moralismo",
    "moralistas": "moralista",
    "moraliza": "moralizar",
    "moralizada": "moralizar",
    "moralizadas": "moralizar",
    "moralizado": "moralizar",
    "moralizadora": "moralizador",
    "moralizadoras": "moralizador",
    "moralizadores": "moralizador",
    "moralizados": "moralizar",
    "moralizai": "moralizar",
    "moralizais": "moralizar",
    "moralizam": "moralizar",
    "moralizamo": "moralizar",
    "moralizamos": "moralizar",
    "moralizando": "moralizar",
    "moralizantes": "moralizante",
    "moralizara": "moralizar",
    "moralizaram": "moralizar",
    "moralizaras": "moralizar",
    "moralizarde": "moralizar",
    "moralizardes": "moralizar",
    "moralizare": "moralizar",
    "moralizarei": "moralizar",
    "moralizareis": "moralizar",
    "moralizarem": "moralizar",
    "moralizaremos": "moralizar",
    "moralizares": "moralizar",
    "moralizaria": "moralizar",
    "moralizariam": "moralizar",
    "moralizarias": "moralizar",
    "moralizarmo": "moralizar",
    "moralizarmos": "moralizar",
    "moralizará": "moralizar",
    "moralizarás": "moralizar",
    "moralizarão": "moralizar",
    "moralizaríamos": "moralizar",
    "moralizaríeis": "moralizar",
    "moralizas": "moralizar",
    "moralizasse": "moralizar",
    "moralizassem": "moralizar",
    "moralizasses": "moralizar",
    "moralizaste": "moralizar",
    "moralizastes": "moralizar",
    "moralizava": "moralizar",
    "moralizavam": "moralizar",
    "moralizavas": "moralizar",
    "moralizações": "moralização",
    "moralize": "moralizar",
    "moralizei": "moralizar",
    "moralizeis": "moralizar",
    "moralizem": "moralizar",
    "moralizemo": "moralizar",
    "moralizemos": "moralizar",
    "moralizes": "moralizar",
    "moralizo": "moralizar",
    "moralizou": "moralizar",
    "moralizá": "moralizar",
    "moralizámo": "moralizar",
    "moralizámos": "moralizar",
    "moralizáramo": "moralizar",
    "moralizáramos": "moralizar",
    "moralizárei": "moralizar",
    "moralizáreis": "moralizar",
    "moralizásseis": "moralizar",
    "moralizássemos": "moralizar",
    "moralizávamo": "moralizar",
    "moralizávamos": "moralizar",
    "moralizávei": "moralizar",
    "moralizáveis": "moralizável",
    "moram": "morar",
    "moramo": "morar",
    "moramos": "morar",
    "morando": "morar",
    "moranga": "morangar",
    "morangada": "morangar",
    "morangadas": "morangar",
    "morangado": "morangar",
    "morangados": "morangar",
    "morangai": "morangar",
    "morangais": "morangar",
    "morangam": "morangar",
    "morangamo": "morangar",
    "morangamos": "morangar",
    "morangando": "morangar",
    "morangara": "morangar",
    "morangaram": "morangar",
    "morangaras": "morangar",
    "morangardes": "morangar",
    "morangarei": "morangar",
    "morangareis": "morangar",
    "morangarem": "morangar",
    "morangaremos": "morangar",
    "morangares": "morangar",
    "morangaria": "morangar",
    "morangariam": "morangar",
    "morangarias": "morangar",
    "morangarmo": "morangar",
    "morangarmos": "morangar",
    "morangará": "morangar",
    "morangarás": "morangar",
    "morangarão": "morangar",
    "morangaríamos": "morangar",
    "morangaríeis": "morangar",
    "morangas": "morangar",
    "morangasse": "morangar",
    "morangassem": "morangar",
    "morangasses": "morangar",
    "morangaste": "morangar",
    "morangastes": "morangar",
    "morangava": "morangar",
    "morangavam": "morangar",
    "morangavas": "morangar",
    "morango": "morangar",
    "morangos": "morango",
    "morangou": "morangar",
    "morangue": "morangar",
    "moranguei": "morangar",
    "morangueira": "morangueiro",
    "morangueiras": "morangueiro",
    "morangueiros": "morangueiro",
    "morangueis": "morangar",
    "moranguem": "morangar",
    "moranguemo": "morangar",
    "moranguemos": "morangar",
    "morangues": "morangar",
    "moranguinho": "morango",
    "moranguinhos": "morango",
    "moranguito": "morango",
    "moranguitos": "morango",
    "morangámo": "morangar",
    "morangámos": "morangar",
    "morangáramo": "morangar",
    "morangáramos": "morangar",
    "morangáreis": "morangar",
    "morangásseis": "morangar",
    "morangássemos": "morangar",
    "morangávamo": "morangar",
    "morangávamos": "morangar",
    "morangáveis": "morangar",
    "moranças": "morança",
    "morara": "morar",
    "moraram": "morar",
    "moraras": "morar",
    "morardes": "morar",
    "morarei": "morar",
    "morareis": "morar",
    "morarem": "morar",
    "moraremos": "morar",
    "morares": "morar",
    "moraria": "morar",
    "morariam": "morar",
    "morarias": "morar",
    "morarmo": "morar",
    "morarmos": "morar",
    "morará": "morar",
    "morarás": "morar",
    "morarão": "morar",
    "moraríamos": "morar",
    "moraríeis": "morar",
    "moras": "morar",
    "morasse": "morar",
    "morassem": "morar",
    "morasses": "morar",
    "moraste": "morar",
    "morastes": "morar",
    "morata": "morato",
    "moratas": "morato",
    "morateiras": "morateira",
    "moratos": "morato",
    "moratória": "moratório",
    "moratórias": "moratório",
    "moratórios": "moratório",
    "morava": "morar",
    "moravam": "morar",
    "moravas": "morar",
    "morbidades": "morbidade",
    "morbidazinha": "mórbido",
    "morbidazinhas": "mórbido",
    "morbidazita": "mórbido",
    "morbidazitas": "mórbido",
    "morbidezas": "morbideza",
    "morbidezes": "morbidez",
    "morbidozinho": "mórbido",
    "morbidozinhos": "mórbido",
    "morbidozito": "mórbido",
    "morbidozitos": "mórbido",
    "morbidíssima": "mórbido",
    "morbidíssimas": "mórbido",
    "morbidíssimo": "mórbido",
    "morbidíssimos": "mórbido",
    "morbilidades": "morbilidade",
    "morbos": "morbo",
    "morbosa": "morboso",
    "morbosas": "morboso",
    "morbosidades": "morbosidade",
    "morbosos": "morboso",
    "morbífica": "morbífico",
    "morbíficas": "morbífico",
    "morbíficos": "morbífico",
    "morbígena": "morbígeno",
    "morbígenas": "morbígeno",
    "morbígenos": "morbígeno",
    "morbígera": "morbígero",
    "morbígeras": "morbígero",
    "morbígeros": "morbígero",
    "morbípara": "morbíparo",
    "morbíparas": "morbíparo",
    "morbíparos": "morbíparo",
    "morcas": "morca",
    "morcega": "morcegar",
    "morcegada": "morcegar",
    "morcegadas": "morcegar",
    "morcegado": "morcegar",
    "morcegados": "morcegar",
    "morcegai": "morcegar",
    "morcegais": "morcegar",
    "morcegam": "morcegar",
    "morcegamo": "morcegar",
    "morcegamos": "morcegar",
    "morcegando": "morcegar",
    "morcegara": "morcegar",
    "morcegaram": "morcegar",
    "morcegaras": "morcegar",
    "morcegarde": "morcegar",
    "morcegardes": "morcegar",
    "morcegare": "morcegar",
    "morcegarei": "morcegar",
    "morcegareis": "morcegar",
    "morcegarem": "morcegar",
    "morcegaremos": "morcegar",
    "morcegares": "morcegar",
    "morcegaria": "morcegar",
    "morcegariam": "morcegar",
    "morcegarias": "morcegar",
    "morcegarmo": "morcegar",
    "morcegarmos": "morcegar",
    "morcegará": "morcegar",
    "morcegarás": "morcegar",
    "morcegarão": "morcegar",
    "morcegaríamos": "morcegar",
    "morcegaríeis": "morcegar",
    "morcegas": "morcegar",
    "morcegasse": "morcegar",
    "morcegassem": "morcegar",
    "morcegasses": "morcegar",
    "morcegaste": "morcegar",
    "morcegastes": "morcegar",
    "morcegava": "morcegar",
    "morcegavam": "morcegar",
    "morcegavas": "morcegar",
    "morcego": "morcegar",
    "morcegos": "morcego",
    "morcegou": "morcegar",
    "morcegue": "morcegar",
    "morceguei": "morcegar",
    "morcegueis": "morcegar",
    "morceguem": "morcegar",
    "morceguemo": "morcegar",
    "morceguemos": "morcegar",
    "morcegues": "morcegar",
    "morcegá": "morcegar",
    "morcegámo": "morcegar",
    "morcegámos": "morcegar",
    "morcegáramo": "morcegar",
    "morcegáramos": "morcegar",
    "morcegárei": "morcegar",
    "morcegáreis": "morcegar",
    "morcegásseis": "morcegar",
    "morcegássemos": "morcegar",
    "morcegávamo": "morcegar",
    "morcegávamos": "morcegar",
    "morcegávei": "morcegar",
    "morcegáveis": "morcegar",
    "morcegões": "morcegão",
    "morcelas": "morcela",
    "morcona": "morcão",
    "morconas": "morcão",
    "morcões": "morcão",
    "morda": "morder",
    "mordacidades": "mordacidade",
    "mordacíssima": "mordaz",
    "mordacíssimas": "mordaz",
    "mordacíssimo": "mordaz",
    "mordacíssimos": "mordaz",
    "mordais": "morder",
    "mordam": "morder",
    "mordamo": "morder",
    "mordamos": "morder",
    "mordas": "morder",
    "mordazes": "mordaz",
    "mordaças": "mordaça",
    "morde": "morder",
    "mordedelas": "mordedela",
    "mordedora": "mordedor",
    "mordedoras": "mordedor",
    "mordedores": "mordedor",
    "mordedouros": "mordedouro",
    "mordeduras": "mordedura",
    "mordei": "morder",
    "mordeis": "morder",
    "mordem": "morder",
    "mordemo": "morder",
    "mordemos": "morder",
    "mordendo": "morder",
    "mordentes": "mordente",
    "mordera": "morder",
    "morderam": "morder",
    "morderas": "morder",
    "morderde": "morder",
    "morderdes": "morder",
    "mordere": "morder",
    "morderei": "morder",
    "mordereis": "morder",
    "morderem": "morder",
    "morderemos": "morder",
    "morderes": "morder",
    "morderia": "morder",
    "morderiam": "morder",
    "morderias": "morder",
    "mordermo": "morder",
    "mordermos": "morder",
    "morderá": "morder",
    "morderás": "morder",
    "morderão": "morder",
    "morderíamos": "morder",
    "morderíeis": "morder",
    "mordes": "morder",
    "mordesse": "morder",
    "mordessem": "morder",
    "mordesses": "morder",
    "mordeste": "morder",
    "mordestes": "morder",
    "mordeu": "morder",
    "mordexins": "mordexim",
    "mordi": "morder",
    "mordia": "morder",
    "mordiam": "morder",
    "mordias": "morder",
    "mordica": "mordicar",
    "mordicada": "mordicar",
    "mordicadas": "mordicar",
    "mordicado": "mordicar",
    "mordicados": "mordicar",
    "mordicai": "mordicar",
    "mordicais": "mordicar",
    "mordicam": "mordicar",
    "mordicamo": "mordicar",
    "mordicamos": "mordicar",
    "mordicando": "mordicar",
    "mordicantes": "mordicante",
    "mordicara": "mordicar",
    "mordicaram": "mordicar",
    "mordicaras": "mordicar",
    "mordicarde": "mordicar",
    "mordicardes": "mordicar",
    "mordicare": "mordicar",
    "mordicarei": "mordicar",
    "mordicareis": "mordicar",
    "mordicarem": "mordicar",
    "mordicaremos": "mordicar",
    "mordicares": "mordicar",
    "mordicaria": "mordicar",
    "mordicariam": "mordicar",
    "mordicarias": "mordicar",
    "mordicarmo": "mordicar",
    "mordicarmos": "mordicar",
    "mordicará": "mordicar",
    "mordicarás": "mordicar",
    "mordicarão": "mordicar",
    "mordicaríamos": "mordicar",
    "mordicaríeis": "mordicar",
    "mordicas": "mordicar",
    "mordicasse": "mordicar",
    "mordicassem": "mordicar",
    "mordicasses": "mordicar",
    "mordicaste": "mordicar",
    "mordicastes": "mordicar",
    "mordicativa": "mordicativo",
    "mordicativas": "mordicativo",
    "mordicativos": "mordicativo",
    "mordicava": "mordicar",
    "mordicavam": "mordicar",
    "mordicavas": "mordicar",
    "mordicações": "mordicação",
    "mordico": "mordicar",
    "mordicos": "mordico",
    "mordicou": "mordicar",
    "mordicá": "mordicar",
    "mordicámo": "mordicar",
    "mordicámos": "mordicar",
    "mordicáramo": "mordicar",
    "mordicáramos": "mordicar",
    "mordicárei": "mordicar",
    "mordicáreis": "mordicar",
    "mordicásseis": "mordicar",
    "mordicássemos": "mordicar",
    "mordicávamo": "mordicar",
    "mordicávamos": "mordicar",
    "mordicávei": "mordicar",
    "mordicáveis": "mordicar",
    "mordida": "mordido",
    "mordidas": "mordido",
    "mordidelas": "mordidela",
    "mordido": "morder",
    "mordidos": "mordido",
    "mordimentos": "mordimento",
    "mordique": "mordicar",
    "mordiquei": "mordicar",
    "mordiqueis": "mordicar",
    "mordiquem": "mordicar",
    "mordiquemo": "mordicar",
    "mordiquemos": "mordicar",
    "mordiques": "mordicar",
    "mordisca": "mordiscar",
    "mordiscada": "mordiscar",
    "mordiscadas": "mordiscar",
    "mordiscado": "mordiscar",
    "mordiscados": "mordiscar",
    "mordiscai": "mordiscar",
    "mordiscais": "mordiscar",
    "mordiscam": "mordiscar",
    "mordiscamo": "mordiscar",
    "mordiscamos": "mordiscar",
    "mordiscando": "mordiscar",
    "mordiscara": "mordiscar",
    "mordiscaram": "mordiscar",
    "mordiscaras": "mordiscar",
    "mordiscarde": "mordiscar",
    "mordiscardes": "mordiscar",
    "mordiscare": "mordiscar",
    "mordiscarei": "mordiscar",
    "mordiscareis": "mordiscar",
    "mordiscarem": "mordiscar",
    "mordiscaremos": "mordiscar",
    "mordiscares": "mordiscar",
    "mordiscaria": "mordiscar",
    "mordiscariam": "mordiscar",
    "mordiscarias": "mordiscar",
    "mordiscarmo": "mordiscar",
    "mordiscarmos": "mordiscar",
    "mordiscará": "mordiscar",
    "mordiscarás": "mordiscar",
    "mordiscarão": "mordiscar",
    "mordiscaríamos": "mordiscar",
    "mordiscaríeis": "mordiscar",
    "mordiscas": "mordiscar",
    "mordiscasse": "mordiscar",
    "mordiscassem": "mordiscar",
    "mordiscasses": "mordiscar",
    "mordiscaste": "mordiscar",
    "mordiscastes": "mordiscar",
    "mordiscava": "mordiscar",
    "mordiscavam": "mordiscar",
    "mordiscavas": "mordiscar",
    "mordisco": "mordiscar",
    "mordiscou": "mordiscar",
    "mordiscá": "mordiscar",
    "mordiscámo": "mordiscar",
    "mordiscámos": "mordiscar",
    "mordiscáramo": "mordiscar",
    "mordiscáramos": "mordiscar",
    "mordiscárei": "mordiscar",
    "mordiscáreis": "mordiscar",
    "mordiscásseis": "mordiscar",
    "mordiscássemos": "mordiscar",
    "mordiscávamo": "mordiscar",
    "mordiscávamos": "mordiscar",
    "mordiscávei": "mordiscar",
    "mordiscáveis": "mordiscar",
    "mordisque": "mordiscar",
    "mordisquei": "mordiscar",
    "mordisqueis": "mordiscar",
    "mordisquem": "mordiscar",
    "mordisquemo": "mordiscar",
    "mordisquemos": "mordiscar",
    "mordisques": "mordiscar",
    "mordixins": "mordixim",
    "mordo": "morder",
    "mordoma": "mordomar",
    "mordomada": "mordomar",
    "mordomadas": "mordomar",
    "mordomado": "mordomar",
    "mordomados": "mordomar",
    "mordomai": "mordomar",
    "mordomais": "mordomar",
    "mordomam": "mordomar",
    "mordomamo": "mordomar",
    "mordomamos": "mordomar",
    "mordomando": "mordomar",
    "mordomara": "mordomar",
    "mordomaram": "mordomar",
    "mordomaras": "mordomar",
    "mordomarde": "mordomar",
    "mordomardes": "mordomar",
    "mordomare": "mordomar",
    "mordomarei": "mordomar",
    "mordomareis": "mordomar",
    "mordomarem": "mordomar",
    "mordomaremos": "mordomar",
    "mordomares": "mordomar",
    "mordomaria": "mordomar",
    "mordomariam": "mordomar",
    "mordomarias": "mordomar",
    "mordomarmo": "mordomar",
    "mordomarmos": "mordomar",
    "mordomará": "mordomar",
    "mordomarás": "mordomar",
    "mordomarão": "mordomar",
    "mordomaríamos": "mordomar",
    "mordomaríeis": "mordomar",
    "mordomas": "mordomar",
    "mordomasse": "mordomar",
    "mordomassem": "mordomar",
    "mordomasses": "mordomar",
    "mordomaste": "mordomar",
    "mordomastes": "mordomar",
    "mordomava": "mordomar",
    "mordomavam": "mordomar",
    "mordomavas": "mordomar",
    "mordome": "mordomar",
    "mordomei": "mordomar",
    "mordomeira": "mordomeiro",
    "mordomeiras": "mordomeiro",
    "mordomeiros": "mordomeiro",
    "mordomeis": "mordomar",
    "mordomem": "mordomar",
    "mordomemo": "mordomar",
    "mordomemos": "mordomar",
    "mordomes": "mordomar",
    "mordomias": "mordomia",
    "mordomices": "mordomice",
    "mordomo": "mordomar",
    "mordomos": "mordomo",
    "mordomou": "mordomar",
    "mordomá": "mordomar",
    "mordomámo": "mordomar",
    "mordomámos": "mordomar",
    "mordomáramo": "mordomar",
    "mordomáramos": "mordomar",
    "mordomárei": "mordomar",
    "mordomáreis": "mordomar",
    "mordomásseis": "mordomar",
    "mordomássemos": "mordomar",
    "mordomávamo": "mordomar",
    "mordomávamos": "mordomar",
    "mordomávei": "mordomar",
    "mordomáveis": "mordomar",
    "mordos": "mordo",
    "mordê": "morder",
    "mordêramo": "morder",
    "mordêramos": "morder",
    "mordêrei": "morder",
    "mordêreis": "morder",
    "mordêsseis": "morder",
    "mordêssemos": "morder",
    "mordíamo": "morder",
    "mordíamos": "morder",
    "mordíei": "morder",
    "mordíeis": "morder",
    "more": "morar",
    "morei": "morar",
    "moreias": "moreia",
    "moreiras": "moreira",
    "moreiredos": "moreiredo",
    "moreis": "morar",
    "morem": "morar",
    "moremo": "morar",
    "moremos": "morar",
    "morena": "moreno",
    "morenada": "morenado",
    "morenadas": "morenado",
    "morenados": "morenado",
    "morenas": "moreno",
    "morenaça": "morenaço",
    "morenaças": "morenaço",
    "morenaços": "morenaço",
    "moreninha": "moreno",
    "moreninhas": "moreno",
    "moreninho": "moreno",
    "moreninhos": "moreno",
    "morenita": "moreno",
    "morenitas": "moreno",
    "morenito": "moreno",
    "morenitos": "moreno",
    "morenos": "moreno",
    "mores": "morar",
    "moretos": "moreto",
    "moreácea": "moreáceo",
    "moreáceas": "moreáceo",
    "moreáceos": "moreáceo",
    "moreões": "moreão",
    "morfanha": "morfanho",
    "morfanhas": "morfanho",
    "morfanhos": "morfanho",
    "morfeias": "morfeia",
    "morfeica": "morfeico",
    "morfeicas": "morfeico",
    "morfeicos": "morfeico",
    "morfemas": "morfema",
    "morfes": "morfe",
    "morfinas": "morfina",
    "morfinismos": "morfinismo",
    "morfiniza": "morfinizar",
    "morfinizada": "morfinizar",
    "morfinizadas": "morfinizar",
    "morfinizado": "morfinizar",
    "morfinizados": "morfinizar",
    "morfinizai": "morfinizar",
    "morfinizais": "morfinizar",
    "morfinizam": "morfinizar",
    "morfinizamo": "morfinizar",
    "morfinizamos": "morfinizar",
    "morfinizando": "morfinizar",
    "morfinizara": "morfinizar",
    "morfinizaram": "morfinizar",
    "morfinizaras": "morfinizar",
    "morfinizarde": "morfinizar",
    "morfinizardes": "morfinizar",
    "morfinizare": "morfinizar",
    "morfinizarei": "morfinizar",
    "morfinizareis": "morfinizar",
    "morfinizarem": "morfinizar",
    "morfinizaremos": "morfinizar",
    "morfinizares": "morfinizar",
    "morfinizaria": "morfinizar",
    "morfinizariam": "morfinizar",
    "morfinizarias": "morfinizar",
    "morfinizarmo": "morfinizar",
    "morfinizarmos": "morfinizar",
    "morfinizará": "morfinizar",
    "morfinizarás": "morfinizar",
    "morfinizarão": "morfinizar",
    "morfinizaríamos": "morfinizar",
    "morfinizaríeis": "morfinizar",
    "morfinizas": "morfinizar",
    "morfinizasse": "morfinizar",
    "morfinizassem": "morfinizar",
    "morfinizasses": "morfinizar",
    "morfinizaste": "morfinizar",
    "morfinizastes": "morfinizar",
    "morfinizava": "morfinizar",
    "morfinizavam": "morfinizar",
    "morfinizavas": "morfinizar",
    "morfinizações": "morfinização",
    "morfinize": "morfinizar",
    "morfinizei": "morfinizar",
    "morfinizeis": "morfinizar",
    "morfinizem": "morfinizar",
    "morfinizemo": "morfinizar",
    "morfinizemos": "morfinizar",
    "morfinizes": "morfinizar",
    "morfinizo": "morfinizar",
    "morfinizou": "morfinizar",
    "morfinizá": "morfinizar",
    "morfinizámo": "morfinizar",
    "morfinizámos": "morfinizar",
    "morfinizáramo": "morfinizar",
    "morfinizáramos": "morfinizar",
    "morfinizárei": "morfinizar",
    "morfinizáreis": "morfinizar",
    "morfinizásseis": "morfinizar",
    "morfinizássemos": "morfinizar",
    "morfinizávamo": "morfinizar",
    "morfinizávamos": "morfinizar",
    "morfinizávei": "morfinizar",
    "morfinizáveis": "morfinizar",
    "morfinomanias": "morfinomania",
    "morfinomaníaca": "morfinomaníaco",
    "morfinomaníacas": "morfinomaníaco",
    "morfinomaníacos": "morfinomaníaco",
    "morfinómana": "morfinómano",
    "morfinómanas": "morfinómano",
    "morfinómanos": "morfinómano",
    "morfismos": "morfismo",
    "morfogenias": "morfogenia",
    "morfografias": "morfografia",
    "morfográfica": "morfográfico",
    "morfográficas": "morfográfico",
    "morfográficos": "morfográfico",
    "morfogénica": "morfogénico",
    "morfogénicas": "morfogénico",
    "morfogénicos": "morfogénico",
    "morfologias": "morfologia",
    "morfologistas": "morfologista",
    "morfológica": "morfológico",
    "morfológicas": "morfológico",
    "morfológicos": "morfológico",
    "morfopsicologias": "morfopsicologia",
    "morfoscopias": "morfoscopia",
    "morfoscópica": "morfoscópico",
    "morfoscópicas": "morfoscópico",
    "morfoscópicos": "morfoscópico",
    "morfoses": "morfose",
    "morfossintaxes": "morfossintaxe",
    "morfotropias": "morfotropia",
    "morfozoários": "morfozoário",
    "morfémica": "morfémico",
    "morfémicas": "morfémico",
    "morfémicos": "morfémico",
    "morfética": "morfético",
    "morféticas": "morfético",
    "morféticos": "morfético",
    "morfídeos": "morfídeo",
    "morfóloga": "morfólogo",
    "morfólogas": "morfólogo",
    "morfólogos": "morfólogo",
    "morgada": "morgado",
    "morgadas": "morgado",
    "morgadelha": "morgadelho",
    "morgadelhas": "morgadelho",
    "morgadelhos": "morgadelho",
    "morgadeta": "morgadete",
    "morgadetas": "morgadete",
    "morgadetes": "morgadete",
    "morgadias": "morgadia",
    "morgadinha": "morgado",
    "morgadinhas": "morgado",
    "morgadinho": "morgado",
    "morgadinhos": "morgado",
    "morgadios": "morgadio",
    "morgadita": "morgado",
    "morgaditas": "morgado",
    "morgadito": "morgado",
    "morgaditos": "morgado",
    "morgados": "morgado",
    "morganheiras": "morganheira",
    "morganhos": "morganho",
    "morganática": "morganático",
    "morganáticas": "morganático",
    "morganáticos": "morganático",
    "morgações": "morgação",
    "morgues": "morgue",
    "moribunda": "moribundo",
    "moribundas": "moribundo",
    "moribundazinha": "moribundo",
    "moribundazinhas": "moribundo",
    "moribundazita": "moribundo",
    "moribundazitas": "moribundo",
    "moribundos": "moribundo",
    "moribundozinho": "moribundo",
    "moribundozinhos": "moribundo",
    "moribundozito": "moribundo",
    "moribundozitos": "moribundo",
    "morigera": "morigerar",
    "morigerada": "morigerar",
    "morigeradas": "morigerar",
    "morigeradinha": "morigerado",
    "morigeradinhas": "morigerado",
    "morigeradinho": "morigerado",
    "morigeradinhos": "morigerado",
    "morigeradita": "morigerado",
    "morigeraditas": "morigerado",
    "morigeradito": "morigerado",
    "morigeraditos": "morigerado",
    "morigerado": "morigerar",
    "morigerados": "morigerar",
    "morigeradíssima": "morigerado",
    "morigeradíssimas": "morigerado",
    "morigeradíssimo": "morigerado",
    "morigeradíssimos": "morigerado",
    "morigerai": "morigerar",
    "morigerais": "morigerar",
    "morigeram": "morigerar",
    "morigeramo": "morigerar",
    "morigeramos": "morigerar",
    "morigerando": "morigerar",
    "morigerara": "morigerar",
    "morigeraram": "morigerar",
    "morigeraras": "morigerar",
    "morigerarde": "morigerar",
    "morigerardes": "morigerar",
    "morigerare": "morigerar",
    "morigerarei": "morigerar",
    "morigerareis": "morigerar",
    "morigerarem": "morigerar",
    "morigeraremos": "morigerar",
    "morigerares": "morigerar",
    "morigeraria": "morigerar",
    "morigerariam": "morigerar",
    "morigerarias": "morigerar",
    "morigerarmo": "morigerar",
    "morigerarmos": "morigerar",
    "morigerará": "morigerar",
    "morigerarás": "morigerar",
    "morigerarão": "morigerar",
    "morigeraríamos": "morigerar",
    "morigeraríeis": "morigerar",
    "morigeras": "morigerar",
    "morigerasse": "morigerar",
    "morigerassem": "morigerar",
    "morigerasses": "morigerar",
    "morigeraste": "morigerar",
    "morigerastes": "morigerar",
    "morigerava": "morigerar",
    "morigeravam": "morigerar",
    "morigeravas": "morigerar",
    "morigerações": "morigeração",
    "morigere": "morigerar",
    "morigerei": "morigerar",
    "morigereis": "morigerar",
    "morigerem": "morigerar",
    "morigeremo": "morigerar",
    "morigeremos": "morigerar",
    "morigeres": "morigerar",
    "morigero": "morigerar",
    "morigerou": "morigerar",
    "morigerá": "morigerar",
    "morigerámo": "morigerar",
    "morigerámos": "morigerar",
    "morigeráramo": "morigerar",
    "morigeráramos": "morigerar",
    "morigerárei": "morigerar",
    "morigeráreis": "morigerar",
    "morigerásseis": "morigerar",
    "morigerássemos": "morigerar",
    "morigerávamo": "morigerar",
    "morigerávamos": "morigerar",
    "morigerávei": "morigerar",
    "morigeráveis": "morigerar",
    "morilhos": "morilho",
    "morilhões": "morilhão",
    "morinas": "morina",
    "morindas": "morinda",
    "moringas": "moringa",
    "moringos": "moringo",
    "moringues": "moringue",
    "moringáceas": "moringácea",
    "morins": "morim",
    "morioplastias": "morioplastia",
    "moriscos": "morisco",
    "mormaceiras": "mormaceira",
    "mormacenta": "mormacento",
    "mormacentas": "mormacento",
    "mormacentos": "mormacento",
    "mormaços": "mormaço",
    "mormonismos": "mormonismo",
    "mormonistas": "mormonista",
    "mormons": "mormon",
    "mormos": "mormo",
    "mormosa": "mormoso",
    "mormosas": "mormoso",
    "mormosos": "mormoso",
    "morna": "morno",
    "mornada": "mornar",
    "mornadas": "mornar",
    "mornado": "mornar",
    "mornados": "mornar",
    "mornai": "mornar",
    "mornais": "mornar",
    "mornam": "mornar",
    "mornamo": "mornar",
    "mornamos": "mornar",
    "mornando": "mornar",
    "mornara": "mornar",
    "mornaram": "mornar",
    "mornaras": "mornar",
    "mornarde": "mornar",
    "mornardes": "mornar",
    "mornare": "mornar",
    "mornarei": "mornar",
    "mornareis": "mornar",
    "mornarem": "mornar",
    "mornaremos": "mornar",
    "mornares": "mornar",
    "mornaria": "mornar",
    "mornariam": "mornar",
    "mornarias": "mornar",
    "mornarmo": "mornar",
    "mornarmos": "mornar",
    "mornará": "mornar",
    "mornarás": "mornar",
    "mornarão": "mornar",
    "mornaríamos": "mornar",
    "mornaríeis": "mornar",
    "mornas": "morno",
    "mornasse": "mornar",
    "mornassem": "mornar",
    "mornasses": "mornar",
    "mornaste": "mornar",
    "mornastes": "mornar",
    "mornava": "mornar",
    "mornavam": "mornar",
    "mornavas": "mornar",
    "mornazinha": "morno",
    "mornazinhas": "morno",
    "mornazita": "morno",
    "mornazitas": "morno",
    "morne": "mornar",
    "mornei": "mornar",
    "morneiros": "morneiro",
    "morneis": "mornar",
    "mornem": "mornar",
    "mornemo": "mornar",
    "mornemos": "mornar",
    "mornes": "mornar",
    "mornidões": "mornidão",
    "morninha": "morno",
    "morninhas": "morno",
    "morninho": "morno",
    "morninhos": "morno",
    "mornita": "morno",
    "mornitas": "morno",
    "mornito": "morno",
    "mornitos": "morno",
    "morno": "mornar",
    "mornos": "morno",
    "mornou": "mornar",
    "mornozinho": "morno",
    "mornozinhos": "morno",
    "mornozito": "morno",
    "mornozitos": "morno",
    "morná": "mornar",
    "mornámo": "mornar",
    "mornámos": "mornar",
    "mornáramo": "mornar",
    "mornáramos": "mornar",
    "mornárei": "mornar",
    "mornáreis": "mornar",
    "mornásseis": "mornar",
    "mornássemos": "mornar",
    "mornávamo": "mornar",
    "mornávamos": "mornar",
    "mornávei": "mornar",
    "mornáveis": "mornar",
    "morníssima": "morno",
    "morníssimas": "morno",
    "morníssimo": "morno",
    "morníssimos": "morno",
    "moro": "morar",
    "moroiços": "moroiço",
    "morosa": "moroso",
    "morosas": "moroso",
    "morosidades": "morosidade",
    "morosos": "moroso",
    "morosíssima": "moroso",
    "morosíssimas": "moroso",
    "morosíssimo": "moroso",
    "morosíssimos": "moroso",
    "morou": "morar",
    "morouços": "morouço",
    "morra": "morrer",
    "morrace": "morraçar",
    "morracei": "morraçar",
    "morraceira": "morraceiro",
    "morraceiras": "morraceiro",
    "morraceiros": "morraceiro",
    "morraceis": "morraçar",
    "morracem": "morraçar",
    "morracemo": "morraçar",
    "morracemos": "morraçar",
    "morraces": "morraçar",
    "morracos": "morraco",
    "morrais": "morrer",
    "morram": "morrer",
    "morramo": "morrer",
    "morramos": "morrer",
    "morraques": "morraque",
    "morrarias": "morraria",
    "morras": "morrer",
    "morraça": "morraçar",
    "morraçada": "morraçar",
    "morraçadas": "morraçar",
    "morraçado": "morraçar",
    "morraçados": "morraçar",
    "morraçai": "morraçar",
    "morraçais": "morraçar",
    "morraçam": "morraçar",
    "morraçamo": "morraçar",
    "morraçamos": "morraçar",
    "morraçando": "morraçar",
    "morraçara": "morraçar",
    "morraçaram": "morraçar",
    "morraçaras": "morraçar",
    "morraçardes": "morraçar",
    "morraçarei": "morraçar",
    "morraçareis": "morraçar",
    "morraçarem": "morraçar",
    "morraçaremos": "morraçar",
    "morraçares": "morraçar",
    "morraçaria": "morraçar",
    "morraçariam": "morraçar",
    "morraçarias": "morraçar",
    "morraçarmo": "morraçar",
    "morraçarmos": "morraçar",
    "morraçará": "morraçar",
    "morraçarás": "morraçar",
    "morraçarão": "morraçar",
    "morraçaríamos": "morraçar",
    "morraçaríeis": "morraçar",
    "morraças": "morraçar",
    "morraçasse": "morraçar",
    "morraçassem": "morraçar",
    "morraçasses": "morraçar",
    "morraçaste": "morraçar",
    "morraçastes": "morraçar",
    "morraçava": "morraçar",
    "morraçavam": "morraçar",
    "morraçavas": "morraçar",
    "morraço": "morraçar",
    "morraçou": "morraçar",
    "morraçámo": "morraçar",
    "morraçámos": "morraçar",
    "morraçáramo": "morraçar",
    "morraçáramos": "morraçar",
    "morraçáreis": "morraçar",
    "morraçásseis": "morraçar",
    "morraçássemos": "morraçar",
    "morraçávamo": "morraçar",
    "morraçávamos": "morraçar",
    "morraçáveis": "morraçar",
    "morre": "morrer",
    "morrediça": "morrediço",
    "morrediças": "morrediço",
    "morrediços": "morrediço",
    "morredoira": "morredoiro",
    "morredoiras": "morredoiro",
    "morredoiros": "morredoiro",
    "morredoura": "morredouro",
    "morredouras": "morredouro",
    "morredouros": "morredouro",
    "morrei": "morrer",
    "morreis": "morrer",
    "morrem": "morrer",
    "morremo": "morrer",
    "morremorra": "morremorrer",
    "morremorrais": "morremorrer",
    "morremorram": "morremorrer",
    "morremorramo": "morremorrer",
    "morremorramos": "morremorrer",
    "morremorras": "morremorrer",
    "morremorre": "morremorrer",
    "morremorrei": "morremorrer",
    "morremorreis": "morremorrer",
    "morremorrem": "morremorrer",
    "morremorremo": "morremorrer",
    "morremorremos": "morremorrer",
    "morremorrendo": "morremorrer",
    "morremorrera": "morremorrer",
    "morremorreram": "morremorrer",
    "morremorreras": "morremorrer",
    "morremorrerdes": "morremorrer",
    "morremorrerei": "morremorrer",
    "morremorrereis": "morremorrer",
    "morremorrerem": "morremorrer",
    "morremorreremos": "morremorrer",
    "morremorreres": "morremorrer",
    "morremorreria": "morremorrer",
    "morremorreriam": "morremorrer",
    "morremorrerias": "morremorrer",
    "morremorrermo": "morremorrer",
    "morremorrermos": "morremorrer",
    "morremorrerá": "morremorrer",
    "morremorrerás": "morremorrer",
    "morremorrerão": "morremorrer",
    "morremorreríamos": "morremorrer",
    "morremorreríeis": "morremorrer",
    "morremorres": "morremorrer",
    "morremorresse": "morremorrer",
    "morremorressem": "morremorrer",
    "morremorresses": "morremorrer",
    "morremorreste": "morremorrer",
    "morremorrestes": "morremorrer",
    "morremorreu": "morremorrer",
    "morremorri": "morremorrer",
    "morremorria": "morremorrer",
    "morremorriam": "morremorrer",
    "morremorrias": "morremorrer",
    "morremorrida": "morremorrer",
    "morremorridas": "morremorrer",
    "morremorrido": "morremorrer",
    "morremorridos": "morremorrer",
    "morremorro": "morremorrer",
    "morremorrêramo": "morremorrer",
    "morremorrêramos": "morremorrer",
    "morremorrêreis": "morremorrer",
    "morremorrêsseis": "morremorrer",
    "morremorrêssemos": "morremorrer",
    "morremorríamo": "morremorrer",
    "morremorríamos": "morremorrer",
    "morremorríeis": "morremorrer",
    "morremos": "morrer",
    "morrendo": "morrer",
    "morrera": "morrer",
    "morreram": "morrer",
    "morreras": "morrer",
    "morrerdes": "morrer",
    "morrerei": "morrer",
    "morrereis": "morrer",
    "morrerem": "morrer",
    "morreremos": "morrer",
    "morreres": "morrer",
    "morreria": "morrer",
    "morreriam": "morrer",
    "morrerias": "morrer",
    "morrermo": "morrer",
    "morrermos": "morrer",
    "morrerá": "morrer",
    "morrerás": "morrer",
    "morrerão": "morrer",
    "morreríamos": "morrer",
    "morreríeis": "morrer",
    "morres": "morrer",
    "morresse": "morrer",
    "morressem": "morrer",
    "morresses": "morrer",
    "morreste": "morrer",
    "morrestes": "morrer",
    "morreu": "morrer",
    "morri": "morrer",
    "morria": "morrer",
    "morriam": "morrer",
    "morrias": "morrer",
    "morrida": "morrer",
    "morridas": "morrer",
    "morrido": "morrer",
    "morridos": "morrer",
    "morrinha": "morrinhar",
    "morrinhada": "morrinhar",
    "morrinhadas": "morrinhar",
    "morrinhado": "morrinhar",
    "morrinhados": "morrinhar",
    "morrinhai": "morrinhar",
    "morrinhais": "morrinhar",
    "morrinham": "morrinhar",
    "morrinhamo": "morrinhar",
    "morrinhamos": "morrinhar",
    "morrinhando": "morrinhar",
    "morrinhara": "morrinhar",
    "morrinharam": "morrinhar",
    "morrinharas": "morrinhar",
    "morrinhardes": "morrinhar",
    "morrinharei": "morrinhar",
    "morrinhareis": "morrinhar",
    "morrinharem": "morrinhar",
    "morrinharemos": "morrinhar",
    "morrinhares": "morrinhar",
    "morrinharia": "morrinhar",
    "morrinhariam": "morrinhar",
    "morrinharias": "morrinhar",
    "morrinharmo": "morrinhar",
    "morrinharmos": "morrinhar",
    "morrinhará": "morrinhar",
    "morrinharás": "morrinhar",
    "morrinharão": "morrinhar",
    "morrinharíamos": "morrinhar",
    "morrinharíeis": "morrinhar",
    "morrinhas": "morrinhar",
    "morrinhasse": "morrinhar",
    "morrinhassem": "morrinhar",
    "morrinhasses": "morrinhar",
    "morrinhaste": "morrinhar",
    "morrinhastes": "morrinhar",
    "morrinhava": "morrinhar",
    "morrinhavam": "morrinhar",
    "morrinhavas": "morrinhar",
    "morrinhe": "morrinhar",
    "morrinhei": "morrinhar",
    "morrinheis": "morrinhar",
    "morrinhem": "morrinhar",
    "morrinhemo": "morrinhar",
    "morrinhemos": "morrinhar",
    "morrinhenta": "morrinhento",
    "morrinhentas": "morrinhento",
    "morrinhentos": "morrinhento",
    "morrinhes": "morrinhar",
    "morrinhices": "morrinhice",
    "morrinho": "morrinhar",
    "morrinhosa": "morrinhoso",
    "morrinhosas": "morrinhoso",
    "morrinhosos": "morrinhoso",
    "morrinhou": "morrinhar",
    "morrinhámo": "morrinhar",
    "morrinhámos": "morrinhar",
    "morrinháramo": "morrinhar",
    "morrinháramos": "morrinhar",
    "morrinháreis": "morrinhar",
    "morrinhásseis": "morrinhar",
    "morrinhássemos": "morrinhar",
    "morrinhávamo": "morrinhar",
    "morrinhávamos": "morrinhar",
    "morrinháveis": "morrinhar",
    "morriões": "morrião",
    "morro": "morrer",
    "morros": "morro",
    "morrêramo": "morrer",
    "morrêramos": "morrer",
    "morrêreis": "morrer",
    "morrêsseis": "morrer",
    "morrêssemos": "morrer",
    "morríamo": "morrer",
    "morríamos": "morrer",
    "morríeis": "morrer",
    "morrões": "morrão",
    "morsas": "morsa",
    "morsega": "morsegar",
    "morsegada": "morsegar",
    "morsegadas": "morsegar",
    "morsegado": "morsegar",
    "morsegados": "morsegar",
    "morsegai": "morsegar",
    "morsegais": "morsegar",
    "morsegam": "morsegar",
    "morsegamo": "morsegar",
    "morsegamos": "morsegar",
    "morsegando": "morsegar",
    "morsegara": "morsegar",
    "morsegaram": "morsegar",
    "morsegaras": "morsegar",
    "morsegardes": "morsegar",
    "morsegarei": "morsegar",
    "morsegareis": "morsegar",
    "morsegarem": "morsegar",
    "morsegaremos": "morsegar",
    "morsegares": "morsegar",
    "morsegaria": "morsegar",
    "morsegariam": "morsegar",
    "morsegarias": "morsegar",
    "morsegarmo": "morsegar",
    "morsegarmos": "morsegar",
    "morsegará": "morsegar",
    "morsegarás": "morsegar",
    "morsegarão": "morsegar",
    "morsegaríamos": "morsegar",
    "morsegaríeis": "morsegar",
    "morsegas": "morsegar",
    "morsegasse": "morsegar",
    "morsegassem": "morsegar",
    "morsegasses": "morsegar",
    "morsegaste": "morsegar",
    "morsegastes": "morsegar",
    "morsegava": "morsegar",
    "morsegavam": "morsegar",
    "morsegavas": "morsegar",
    "morsego": "morsegar",
    "morsegou": "morsegar",
    "morsegue": "morsegar",
    "morseguei": "morsegar",
    "morsegueis": "morsegar",
    "morseguem": "morsegar",
    "morseguemo": "morsegar",
    "morseguemos": "morsegar",
    "morsegues": "morsegar",
    "morsegámo": "morsegar",
    "morsegámos": "morsegar",
    "morsegáramo": "morsegar",
    "morsegáramos": "morsegar",
    "morsegáreis": "morsegar",
    "morsegásseis": "morsegar",
    "morsegássemos": "morsegar",
    "morsegávamo": "morsegar",
    "morsegávamos": "morsegar",
    "morsegáveis": "morsegar",
    "morsegões": "morsegão",
    "morsos": "morso",
    "morta": "morto",
    "mortadelas": "mortadela",
    "mortagens": "mortagem",
    "mortais": "mortal",
    "mortalha": "mortalhar",
    "mortalhada": "mortalhar",
    "mortalhadas": "mortalhar",
    "mortalhado": "mortalhar",
    "mortalhados": "mortalhar",
    "mortalhai": "mortalhar",
    "mortalhais": "mortalhar",
    "mortalham": "mortalhar",
    "mortalhamo": "mortalhar",
    "mortalhamos": "mortalhar",
    "mortalhando": "mortalhar",
    "mortalhara": "mortalhar",
    "mortalharam": "mortalhar",
    "mortalharas": "mortalhar",
    "mortalharde": "mortalhar",
    "mortalhardes": "mortalhar",
    "mortalhare": "mortalhar",
    "mortalharei": "mortalhar",
    "mortalhareis": "mortalhar",
    "mortalharem": "mortalhar",
    "mortalharemos": "mortalhar",
    "mortalhares": "mortalhar",
    "mortalharia": "mortalhar",
    "mortalhariam": "mortalhar",
    "mortalharias": "mortalhar",
    "mortalharmo": "mortalhar",
    "mortalharmos": "mortalhar",
    "mortalhará": "mortalhar",
    "mortalharás": "mortalhar",
    "mortalharão": "mortalhar",
    "mortalharíamos": "mortalhar",
    "mortalharíeis": "mortalhar",
    "mortalhas": "mortalhar",
    "mortalhasse": "mortalhar",
    "mortalhassem": "mortalhar",
    "mortalhasses": "mortalhar",
    "mortalhaste": "mortalhar",
    "mortalhastes": "mortalhar",
    "mortalhava": "mortalhar",
    "mortalhavam": "mortalhar",
    "mortalhavas": "mortalhar",
    "mortalhe": "mortalhar",
    "mortalhei": "mortalhar",
    "mortalheis": "mortalhar",
    "mortalhem": "mortalhar",
    "mortalhemo": "mortalhar",
    "mortalhemos": "mortalhar",
    "mortalhes": "mortalhar",
    "mortalho": "mortalhar",
    "mortalhou": "mortalhar",
    "mortalhá": "mortalhar",
    "mortalhámo": "mortalhar",
    "mortalhámos": "mortalhar",
    "mortalháramo": "mortalhar",
    "mortalháramos": "mortalhar",
    "mortalhárei": "mortalhar",
    "mortalháreis": "mortalhar",
    "mortalhásseis": "mortalhar",
    "mortalhássemos": "mortalhar",
    "mortalhávamo": "mortalhar",
    "mortalhávamos": "mortalhar",
    "mortalhávei": "mortalhar",
    "mortalháveis": "mortalhar",
    "mortalidades": "mortalidade",
    "mortandades": "mortandade",
    "mortas": "morto",
    "morteiradas": "morteirada",
    "morteiretes": "morteirete",
    "morteiros": "morteiro",
    "mortes": "morte",
    "morticínios": "morticínio",
    "mortifica": "mortificar",
    "mortificada": "mortificar",
    "mortificadas": "mortificar",
    "mortificado": "mortificar",
    "mortificadora": "mortificador",
    "mortificadoras": "mortificador",
    "mortificadores": "mortificador",
    "mortificados": "mortificar",
    "mortificai": "mortificar",
    "mortificais": "mortificar",
    "mortificam": "mortificar",
    "mortificamo": "mortificar",
    "mortificamos": "mortificar",
    "mortificando": "mortificar",
    "mortificantes": "mortificante",
    "mortificara": "mortificar",
    "mortificaram": "mortificar",
    "mortificaras": "mortificar",
    "mortificarde": "mortificar",
    "mortificardes": "mortificar",
    "mortificare": "mortificar",
    "mortificarei": "mortificar",
    "mortificareis": "mortificar",
    "mortificarem": "mortificar",
    "mortificaremos": "mortificar",
    "mortificares": "mortificar",
    "mortificaria": "mortificar",
    "mortificariam": "mortificar",
    "mortificarias": "mortificar",
    "mortificarmo": "mortificar",
    "mortificarmos": "mortificar",
    "mortificará": "mortificar",
    "mortificarás": "mortificar",
    "mortificarão": "mortificar",
    "mortificaríamos": "mortificar",
    "mortificaríeis": "mortificar",
    "mortificas": "mortificar",
    "mortificasse": "mortificar",
    "mortificassem": "mortificar",
    "mortificasses": "mortificar",
    "mortificaste": "mortificar",
    "mortificastes": "mortificar",
    "mortificativa": "mortificativo",
    "mortificativas": "mortificativo",
    "mortificativos": "mortificativo",
    "mortificava": "mortificar",
    "mortificavam": "mortificar",
    "mortificavas": "mortificar",
    "mortificações": "mortificação",
    "mortifico": "mortificar",
    "mortificou": "mortificar",
    "mortificá": "mortificar",
    "mortificámo": "mortificar",
    "mortificámos": "mortificar",
    "mortificáramo": "mortificar",
    "mortificáramos": "mortificar",
    "mortificárei": "mortificar",
    "mortificáreis": "mortificar",
    "mortificásseis": "mortificar",
    "mortificássemos": "mortificar",
    "mortificávamo": "mortificar",
    "mortificávamos": "mortificar",
    "mortificávei": "mortificar",
    "mortificáveis": "mortificar",
    "mortifique": "mortificar",
    "mortifiquei": "mortificar",
    "mortifiqueis": "mortificar",
    "mortifiquem": "mortificar",
    "mortifiquemo": "mortificar",
    "mortifiquemos": "mortificar",
    "mortifiques": "mortificar",
    "mortinatalidades": "mortinatalidade",
    "mortinha": "morto",
    "mortinhas": "morto",
    "mortinho": "morto",
    "mortinhos": "morto",
    "mortita": "morto",
    "mortitas": "morto",
    "mortito": "morto",
    "mortitos": "morto",
    "mortiça": "mortiço",
    "mortiças": "mortiço",
    "mortiços": "mortiço",
    "mortos": "morto",
    "mortualhas": "mortualha",
    "mortulhos": "mortulho",
    "mortuosa": "mortuoso",
    "mortuosas": "mortuoso",
    "mortuosos": "mortuoso",
    "mortuária": "mortuário",
    "mortuárias": "mortuário",
    "mortuários": "mortuário",
    "mortuória": "mortuório",
    "mortuórias": "mortuório",
    "mortuórios": "mortuório",
    "mortífera": "mortífero",
    "mortíferas": "mortífero",
    "mortíferos": "mortífero",
    "mortória": "mortório",
    "mortórias": "mortório",
    "mortórios": "mortório",
    "morubixabas": "morubixaba",
    "morugens": "morugem",
    "morulas": "morula",
    "moráceas": "morácea",
    "morámo": "morar",
    "morámos": "morar",
    "moráramo": "morar",
    "moráramos": "morar",
    "moráreis": "morar",
    "morásseis": "morar",
    "morássemos": "morar",
    "morávamo": "morar",
    "morávamos": "morar",
    "moráveis": "morar",
    "morávia": "morávio",
    "morávias": "morávio",
    "morávios": "morávio",
    "morígera": "morígero",
    "morígeras": "morígero",
    "morígeros": "morígero",
    "mosaica": "mosaico",
    "mosaicas": "mosaico",
    "mosaicos": "mosaico",
    "mosas": "mosa",
    "mosassaurídeos": "mosassaurídeo",
    "mosassáurios": "mosassáurio",
    "mosaísmos": "mosaísmo",
    "mosaístas": "mosaísta",
    "mosca": "mosco",
    "moscada": "moscar",
    "moscadas": "moscar",
    "moscadeiras": "moscadeira",
    "moscadeiros": "moscadeiro",
    "moscadins": "moscadim",
    "moscado": "moscar",
    "moscados": "moscar",
    "moscais": "moscar",
    "moscam": "moscar",
    "moscamo": "moscar",
    "moscamos": "moscar",
    "moscando": "moscar",
    "moscanhos": "moscanho",
    "moscara": "moscar",
    "moscaram": "moscar",
    "moscaras": "moscar",
    "moscardes": "moscar",
    "moscardos": "moscardo",
    "moscarei": "moscar",
    "moscareis": "moscar",
    "moscarem": "moscar",
    "moscaremos": "moscar",
    "moscares": "moscar",
    "moscaria": "moscar",
    "moscariam": "moscar",
    "moscarias": "moscaria",
    "moscarmo": "moscar",
    "moscarmos": "moscar",
    "moscará": "moscar",
    "moscarás": "moscar",
    "moscarão": "moscar",
    "moscaríamos": "moscar",
    "moscaríeis": "moscar",
    "moscas": "mosco",
    "moscasse": "moscar",
    "moscassem": "moscar",
    "moscasses": "moscar",
    "moscaste": "moscar",
    "moscastes": "moscar",
    "moscatelinas": "moscatelina",
    "moscatéis": "moscatel",
    "moscava": "moscar",
    "moscavam": "moscar",
    "moscavas": "moscar",
    "mosco": "moscar",
    "moscos": "mosco",
    "moscou": "moscar",
    "moscous": "moscou",
    "moscovianos": "moscoviano",
    "moscovitas": "moscovita",
    "moscovites": "moscovite",
    "moscovítica": "moscovítico",
    "moscovíticas": "moscovítico",
    "moscovíticos": "moscovítico",
    "moscámo": "moscar",
    "moscámos": "moscar",
    "moscáramo": "moscar",
    "moscáramos": "moscar",
    "moscáreis": "moscar",
    "moscásseis": "moscar",
    "moscássemos": "moscar",
    "moscávamo": "moscar",
    "moscávamos": "moscar",
    "moscáveis": "moscar",
    "moscóvias": "moscóvia",
    "moscões": "moscão",
    "mosetas": "moseta",
    "moslemes": "mosleme",
    "moslemias": "moslemia",
    "moslemitas": "moslemita",
    "moslémes": "moslém",
    "moslémica": "moslémico",
    "moslémicas": "moslémico",
    "moslémicos": "moslémico",
    "mosléns": "moslém",
    "mosque": "moscar",
    "mosqueada": "mosquear",
    "mosqueadas": "mosquear",
    "mosqueado": "mosquear",
    "mosqueados": "mosquear",
    "mosqueai": "mosquear",
    "mosqueais": "mosquear",
    "mosqueamo": "mosquear",
    "mosqueamos": "mosquear",
    "mosqueando": "mosquear",
    "mosqueara": "mosquear",
    "mosquearam": "mosquear",
    "mosquearas": "mosquear",
    "mosquearde": "mosquear",
    "mosqueardes": "mosquear",
    "mosqueare": "mosquear",
    "mosquearei": "mosquear",
    "mosqueareis": "mosquear",
    "mosquearem": "mosquear",
    "mosquearemos": "mosquear",
    "mosqueares": "mosquear",
    "mosquearia": "mosquear",
    "mosqueariam": "mosquear",
    "mosquearias": "mosquear",
    "mosquearmo": "mosquear",
    "mosquearmos": "mosquear",
    "mosqueará": "mosquear",
    "mosquearás": "mosquear",
    "mosquearão": "mosquear",
    "mosquearíamos": "mosquear",
    "mosquearíeis": "mosquear",
    "mosqueasse": "mosquear",
    "mosqueassem": "mosquear",
    "mosqueasses": "mosquear",
    "mosqueaste": "mosquear",
    "mosqueastes": "mosquear",
    "mosqueava": "mosquear",
    "mosqueavam": "mosquear",
    "mosqueavas": "mosquear",
    "mosquedos": "mosquedo",
    "mosqueei": "mosquear",
    "mosqueeis": "mosquear",
    "mosqueemo": "mosquear",
    "mosqueemos": "mosquear",
    "mosquei": "moscar",
    "mosqueia": "mosquear",
    "mosqueiam": "mosquear",
    "mosqueias": "mosquear",
    "mosqueie": "mosquear",
    "mosqueiem": "mosquear",
    "mosqueies": "mosquear",
    "mosqueio": "mosquear",
    "mosqueira": "mosqueiro",
    "mosqueiras": "mosqueiro",
    "mosqueiros": "mosqueiro",
    "mosqueis": "moscar",
    "mosquem": "moscar",
    "mosquemos": "moscar",
    "mosqueou": "mosquear",
    "mosques": "moscar",
    "mosquetadas": "mosquetada",
    "mosquetarias": "mosquetaria",
    "mosquetas": "mosqueta",
    "mosquetaços": "mosquetaço",
    "mosqueteada": "mosquetear",
    "mosqueteadas": "mosquetear",
    "mosqueteado": "mosquetear",
    "mosqueteados": "mosquetear",
    "mosqueteai": "mosquetear",
    "mosqueteais": "mosquetear",
    "mosqueteamo": "mosquetear",
    "mosqueteamos": "mosquetear",
    "mosqueteando": "mosquetear",
    "mosqueteara": "mosquetear",
    "mosquetearam": "mosquetear",
    "mosquetearas": "mosquetear",
    "mosquetearde": "mosquetear",
    "mosqueteardes": "mosquetear",
    "mosqueteare": "mosquetear",
    "mosquetearei": "mosquetear",
    "mosqueteareis": "mosquetear",
    "mosquetearem": "mosquetear",
    "mosquetearemos": "mosquetear",
    "mosqueteares": "mosquetear",
    "mosquetearia": "mosquetear",
    "mosqueteariam": "mosquetear",
    "mosquetearias": "mosquetear",
    "mosquetearmo": "mosquetear",
    "mosquetearmos": "mosquetear",
    "mosqueteará": "mosquetear",
    "mosquetearás": "mosquetear",
    "mosquetearão": "mosquetear",
    "mosquetearíamos": "mosquetear",
    "mosquetearíeis": "mosquetear",
    "mosqueteasse": "mosquetear",
    "mosqueteassem": "mosquetear",
    "mosqueteasses": "mosquetear",
    "mosqueteaste": "mosquetear",
    "mosqueteastes": "mosquetear",
    "mosqueteava": "mosquetear",
    "mosqueteavam": "mosquetear",
    "mosqueteavas": "mosquetear",
    "mosqueteei": "mosquetear",
    "mosqueteeis": "mosquetear",
    "mosqueteemo": "mosquetear",
    "mosqueteemos": "mosquetear",
    "mosqueteia": "mosquetear",
    "mosqueteiam": "mosquetear",
    "mosqueteias": "mosquetear",
    "mosqueteie": "mosquetear",
    "mosqueteiem": "mosquetear",
    "mosqueteies": "mosquetear",
    "mosqueteio": "mosquetear",
    "mosqueteira": "mosqueteiro",
    "mosqueteiras": "mosqueteiro",
    "mosqueteiros": "mosqueteiro",
    "mosqueteou": "mosquetear",
    "mosquetes": "mosquete",
    "mosqueteá": "mosquetear",
    "mosqueteámo": "mosquetear",
    "mosqueteámos": "mosquetear",
    "mosqueteáramo": "mosquetear",
    "mosqueteáramos": "mosquetear",
    "mosqueteárei": "mosquetear",
    "mosqueteáreis": "mosquetear",
    "mosqueteásseis": "mosquetear",
    "mosqueteássemos": "mosquetear",
    "mosqueteávamo": "mosquetear",
    "mosqueteávamos": "mosquetear",
    "mosqueteávei": "mosquetear",
    "mosqueteáveis": "mosquetear",
    "mosquetões": "mosquetão",
    "mosqueá": "mosquear",
    "mosqueámo": "mosquear",
    "mosqueámos": "mosquear",
    "mosqueáramo": "mosquear",
    "mosqueáramos": "mosquear",
    "mosqueárei": "mosquear",
    "mosqueáreis": "mosquear",
    "mosqueásseis": "mosquear",
    "mosqueássemos": "mosquear",
    "mosqueávamo": "mosquear",
    "mosqueávamos": "mosquear",
    "mosqueávei": "mosquear",
    "mosqueáveis": "mosquear",
    "mosquinha": "mosca",
    "mosquinhas": "mosca",
    "mosquita": "mosca",
    "mosquitadas": "mosquitada",
    "mosquitas": "mosca",
    "mosquiteiros": "mosquiteiro",
    "mosquitinho": "mosquito",
    "mosquitinhos": "mosquito",
    "mosquitito": "mosquito",
    "mosquititos": "mosquito",
    "mosquitos": "mosquito",
    "mosquídeos": "mosquídeo",
    "mossa": "mossar",
    "mossada": "mossar",
    "mossadas": "mossar",
    "mossado": "mossar",
    "mossados": "mossar",
    "mossai": "mossar",
    "mossais": "mossar",
    "mossam": "mossar",
    "mossamo": "mossar",
    "mossamos": "mossar",
    "mossando": "mossar",
    "mossara": "mossar",
    "mossaram": "mossar",
    "mossaras": "mossar",
    "mossarde": "mossar",
    "mossardes": "mossar",
    "mossare": "mossar",
    "mossarei": "mossar",
    "mossareis": "mossar",
    "mossarem": "mossar",
    "mossaremos": "mossar",
    "mossares": "mossar",
    "mossaria": "mossar",
    "mossariam": "mossar",
    "mossarias": "mossar",
    "mossarmo": "mossar",
    "mossarmos": "mossar",
    "mossará": "mossar",
    "mossarás": "mossar",
    "mossarão": "mossar",
    "mossaríamos": "mossar",
    "mossaríeis": "mossar",
    "mossas": "mossar",
    "mossasse": "mossar",
    "mossassem": "mossar",
    "mossasses": "mossar",
    "mossaste": "mossar",
    "mossastes": "mossar",
    "mossava": "mossar",
    "mossavam": "mossar",
    "mossavas": "mossar",
    "mosse": "mossar",
    "mossega": "mossegar",
    "mossegada": "mossegar",
    "mossegadas": "mossegar",
    "mossegado": "mossegar",
    "mossegados": "mossegar",
    "mossegai": "mossegar",
    "mossegais": "mossegar",
    "mossegam": "mossegar",
    "mossegamo": "mossegar",
    "mossegamos": "mossegar",
    "mossegando": "mossegar",
    "mossegara": "mossegar",
    "mossegaram": "mossegar",
    "mossegaras": "mossegar",
    "mossegarde": "mossegar",
    "mossegardes": "mossegar",
    "mossegare": "mossegar",
    "mossegarei": "mossegar",
    "mossegareis": "mossegar",
    "mossegarem": "mossegar",
    "mossegaremos": "mossegar",
    "mossegares": "mossegar",
    "mossegaria": "mossegar",
    "mossegariam": "mossegar",
    "mossegarias": "mossegar",
    "mossegarmo": "mossegar",
    "mossegarmos": "mossegar",
    "mossegará": "mossegar",
    "mossegarás": "mossegar",
    "mossegarão": "mossegar",
    "mossegaríamos": "mossegar",
    "mossegaríeis": "mossegar",
    "mossegas": "mossegar",
    "mossegasse": "mossegar",
    "mossegassem": "mossegar",
    "mossegasses": "mossegar",
    "mossegaste": "mossegar",
    "mossegastes": "mossegar",
    "mossegava": "mossegar",
    "mossegavam": "mossegar",
    "mossegavas": "mossegar",
    "mossego": "mossegar",
    "mossegona": "mossegão",
    "mossegonas": "mossegão",
    "mossegou": "mossegar",
    "mossegue": "mossegar",
    "mosseguei": "mossegar",
    "mossegueis": "mossegar",
    "mosseguem": "mossegar",
    "mosseguemo": "mossegar",
    "mosseguemos": "mossegar",
    "mossegues": "mossegar",
    "mossegá": "mossegar",
    "mossegámo": "mossegar",
    "mossegámos": "mossegar",
    "mossegáramo": "mossegar",
    "mossegáramos": "mossegar",
    "mossegárei": "mossegar",
    "mossegáreis": "mossegar",
    "mossegásseis": "mossegar",
    "mossegássemos": "mossegar",
    "mossegávamo": "mossegar",
    "mossegávamos": "mossegar",
    "mossegávei": "mossegar",
    "mossegáveis": "mossegar",
    "mossegões": "mossegão",
    "mossei": "mossar",
    "mosseis": "mossar",
    "mossem": "mossar",
    "mossemo": "mossar",
    "mossemos": "mossar",
    "mosses": "mossar",
    "mosso": "mossar",
    "mossou": "mossar",
    "mossá": "mossar",
    "mossámo": "mossar",
    "mossámos": "mossar",
    "mossáramo": "mossar",
    "mossáramos": "mossar",
    "mossárei": "mossar",
    "mossáreis": "mossar",
    "mossásseis": "mossar",
    "mossássemos": "mossar",
    "mossávamo": "mossar",
    "mossávamos": "mossar",
    "mossávei": "mossar",
    "mossáveis": "mossar",
    "mostajeiros": "mostajeiro",
    "mostajos": "mostajo",
    "mostardais": "mostardal",
    "mostardas": "mostarda",
    "mostardeira": "mostardeiro",
    "mostardeiras": "mostardeiro",
    "mostardeiros": "mostardeiro",
    "mostaços": "mostaço",
    "mosteias": "mosteia",
    "mosteiros": "mosteiro",
    "mosteirós": "mosteiró",
    "mostos": "mosto",
    "mostra": "mostrar",
    "mostrada": "mostrar",
    "mostradas": "mostrar",
    "mostradelas": "mostradela",
    "mostrado": "mostrar",
    "mostradora": "mostrador",
    "mostradoras": "mostrador",
    "mostradores": "mostrador",
    "mostrados": "mostrar",
    "mostragens": "mostragem",
    "mostrai": "mostrar",
    "mostrais": "mostrar",
    "mostram": "mostrar",
    "mostramo": "mostrar",
    "mostramos": "mostrar",
    "mostrando": "mostrar",
    "mostranças": "mostrança",
    "mostrara": "mostrar",
    "mostraram": "mostrar",
    "mostraras": "mostrar",
    "mostrarde": "mostrar",
    "mostrardes": "mostrar",
    "mostrare": "mostrar",
    "mostrarei": "mostrar",
    "mostrareis": "mostrar",
    "mostrarem": "mostrar",
    "mostraremos": "mostrar",
    "mostrares": "mostrar",
    "mostraria": "mostrar",
    "mostrariam": "mostrar",
    "mostrarias": "mostrar",
    "mostrarmo": "mostrar",
    "mostrarmos": "mostrar",
    "mostrará": "mostrar",
    "mostrarás": "mostrar",
    "mostrarão": "mostrar",
    "mostraríamos": "mostrar",
    "mostraríeis": "mostrar",
    "mostras": "mostrar",
    "mostrasse": "mostrar",
    "mostrassem": "mostrar",
    "mostrasses": "mostrar",
    "mostraste": "mostrar",
    "mostrastes": "mostrar",
    "mostrava": "mostrar",
    "mostravam": "mostrar",
    "mostravas": "mostrar",
    "mostre": "mostrar",
    "mostrei": "mostrar",
    "mostreis": "mostrar",
    "mostrem": "mostrar",
    "mostremo": "mostrar",
    "mostremos": "mostrar",
    "mostrenga": "mostrengo",
    "mostrengada": "mostrengar",
    "mostrengadas": "mostrengar",
    "mostrengado": "mostrengar",
    "mostrengados": "mostrengar",
    "mostrengai": "mostrengar",
    "mostrengais": "mostrengar",
    "mostrengam": "mostrengar",
    "mostrengamo": "mostrengar",
    "mostrengamos": "mostrengar",
    "mostrengando": "mostrengar",
    "mostrengara": "mostrengar",
    "mostrengaram": "mostrengar",
    "mostrengaras": "mostrengar",
    "mostrengarde": "mostrengar",
    "mostrengardes": "mostrengar",
    "mostrengare": "mostrengar",
    "mostrengarei": "mostrengar",
    "mostrengareis": "mostrengar",
    "mostrengarem": "mostrengar",
    "mostrengaremos": "mostrengar",
    "mostrengares": "mostrengar",
    "mostrengaria": "mostrengar",
    "mostrengariam": "mostrengar",
    "mostrengarias": "mostrengar",
    "mostrengarmo": "mostrengar",
    "mostrengarmos": "mostrengar",
    "mostrengará": "mostrengar",
    "mostrengarás": "mostrengar",
    "mostrengarão": "mostrengar",
    "mostrengaríamos": "mostrengar",
    "mostrengaríeis": "mostrengar",
    "mostrengas": "mostrengo",
    "mostrengasse": "mostrengar",
    "mostrengassem": "mostrengar",
    "mostrengasses": "mostrengar",
    "mostrengaste": "mostrengar",
    "mostrengastes": "mostrengar",
    "mostrengava": "mostrengar",
    "mostrengavam": "mostrengar",
    "mostrengavas": "mostrengar",
    "mostrengo": "mostrengar",
    "mostrengos": "mostrengo",
    "mostrengou": "mostrengar",
    "mostrengue": "mostrengar",
    "mostrenguei": "mostrengar",
    "mostrengueis": "mostrengar",
    "mostrenguem": "mostrengar",
    "mostrenguemo": "mostrengar",
    "mostrenguemos": "mostrengar",
    "mostrengues": "mostrengar",
    "mostrengá": "mostrengar",
    "mostrengámo": "mostrengar",
    "mostrengámos": "mostrengar",
    "mostrengáramo": "mostrengar",
    "mostrengáramos": "mostrengar",
    "mostrengárei": "mostrengar",
    "mostrengáreis": "mostrengar",
    "mostrengásseis": "mostrengar",
    "mostrengássemos": "mostrengar",
    "mostrengávamo": "mostrengar",
    "mostrengávamos": "mostrengar",
    "mostrengávei": "mostrengar",
    "mostrengáveis": "mostrengar",
    "mostres": "mostrar",
    "mostro": "mostrar",
    "mostrou": "mostrar",
    "mostruários": "mostruário",
    "mostrá": "mostrar",
    "mostrámo": "mostrar",
    "mostrámos": "mostrar",
    "mostráramo": "mostrar",
    "mostráramos": "mostrar",
    "mostrárei": "mostrar",
    "mostráreis": "mostrar",
    "mostrásseis": "mostrar",
    "mostrássemos": "mostrar",
    "mostrávamo": "mostrar",
    "mostrávamos": "mostrar",
    "mostrávei": "mostrar",
    "mostráveis": "mostrável",
    "mostárabes": "mostárabe",
    "mostífera": "mostífero",
    "mostíferas": "mostífero",
    "mostíferos": "mostífero",
    "motacilídeos": "motacilídeo",
    "motacés": "motacé",
    "motacílidas": "motacílida",
    "motas": "mota",
    "motazés": "motazé",
    "moteja": "motejar",
    "motejada": "motejar",
    "motejadas": "motejar",
    "motejado": "motejar",
    "motejadora": "motejador",
    "motejadoras": "motejador",
    "motejadores": "motejador",
    "motejados": "motejar",
    "motejai": "motejar",
    "motejais": "motejar",
    "motejam": "motejar",
    "motejamo": "motejar",
    "motejamos": "motejar",
    "motejando": "motejar",
    "motejara": "motejar",
    "motejaram": "motejar",
    "motejaras": "motejar",
    "motejarde": "motejar",
    "motejardes": "motejar",
    "motejare": "motejar",
    "motejarei": "motejar",
    "motejareis": "motejar",
    "motejarem": "motejar",
    "motejaremos": "motejar",
    "motejares": "motejar",
    "motejaria": "motejar",
    "motejariam": "motejar",
    "motejarias": "motejar",
    "motejarmo": "motejar",
    "motejarmos": "motejar",
    "motejará": "motejar",
    "motejarás": "motejar",
    "motejarão": "motejar",
    "motejaríamos": "motejar",
    "motejaríeis": "motejar",
    "motejas": "motejar",
    "motejasse": "motejar",
    "motejassem": "motejar",
    "motejasses": "motejar",
    "motejaste": "motejar",
    "motejastes": "motejar",
    "motejava": "motejar",
    "motejavam": "motejar",
    "motejavas": "motejar",
    "moteje": "motejar",
    "motejei": "motejar",
    "motejeis": "motejar",
    "motejem": "motejar",
    "motejemo": "motejar",
    "motejemos": "motejar",
    "motejes": "motejar",
    "motejo": "motejar",
    "motejos": "motejo",
    "motejou": "motejar",
    "motejá": "motejar",
    "motejámo": "motejar",
    "motejámos": "motejar",
    "motejáramo": "motejar",
    "motejáramos": "motejar",
    "motejárei": "motejar",
    "motejáreis": "motejar",
    "motejásseis": "motejar",
    "motejássemos": "motejar",
    "motejávamo": "motejar",
    "motejávamos": "motejar",
    "motejávei": "motejar",
    "motejáveis": "motejar",
    "motes": "mote",
    "motetes": "motete",
    "motetos": "moteto",
    "motilidades": "motilidade",
    "motina": "motinar",
    "motinada": "motinar",
    "motinadas": "motinar",
    "motinado": "motinar",
    "motinados": "motinar",
    "motinai": "motinar",
    "motinais": "motinar",
    "motinam": "motinar",
    "motinamo": "motinar",
    "motinamos": "motinar",
    "motinando": "motinar",
    "motinara": "motinar",
    "motinaram": "motinar",
    "motinaras": "motinar",
    "motinarde": "motinar",
    "motinardes": "motinar",
    "motinare": "motinar",
    "motinarei": "motinar",
    "motinareis": "motinar",
    "motinarem": "motinar",
    "motinaremos": "motinar",
    "motinares": "motinar",
    "motinaria": "motinar",
    "motinariam": "motinar",
    "motinarias": "motinar",
    "motinarmo": "motinar",
    "motinarmos": "motinar",
    "motinará": "motinar",
    "motinarás": "motinar",
    "motinarão": "motinar",
    "motinaríamos": "motinar",
    "motinaríeis": "motinar",
    "motinas": "motinar",
    "motinasse": "motinar",
    "motinassem": "motinar",
    "motinasses": "motinar",
    "motinaste": "motinar",
    "motinastes": "motinar",
    "motinava": "motinar",
    "motinavam": "motinar",
    "motinavas": "motinar",
    "motine": "motinar",
    "motinei": "motinar",
    "motineira": "motineiro",
    "motineiras": "motineiro",
    "motineiros": "motineiro",
    "motineis": "motinar",
    "motinem": "motinar",
    "motinemo": "motinar",
    "motinemos": "motinar",
    "motines": "motinar",
    "motinha": "mota",
    "motinhas": "mota",
    "motino": "motinar",
    "motinosa": "motinoso",
    "motinosas": "motinoso",
    "motinosos": "motinoso",
    "motinou": "motinar",
    "motins": "motim",
    "motiná": "motinar",
    "motinámo": "motinar",
    "motinámos": "motinar",
    "motináramo": "motinar",
    "motináramos": "motinar",
    "motinárei": "motinar",
    "motináreis": "motinar",
    "motinásseis": "motinar",
    "motinássemos": "motinar",
    "motinávamo": "motinar",
    "motinávamos": "motinar",
    "motinávei": "motinar",
    "motináveis": "motinar",
    "motita": "mota",
    "motitas": "mota",
    "motiva": "motivar",
    "motivada": "motivar",
    "motivadas": "motivar",
    "motivadinha": "motivado",
    "motivadinhas": "motivado",
    "motivadinho": "motivado",
    "motivadinhos": "motivado",
    "motivadita": "motivado",
    "motivaditas": "motivado",
    "motivadito": "motivado",
    "motivaditos": "motivado",
    "motivado": "motivar",
    "motivadora": "motivador",
    "motivadoras": "motivador",
    "motivadores": "motivador",
    "motivados": "motivar",
    "motivadíssima": "motivado",
    "motivadíssimas": "motivado",
    "motivadíssimo": "motivado",
    "motivadíssimos": "motivado",
    "motivai": "motivar",
    "motivais": "motivar",
    "motivam": "motivar",
    "motivamo": "motivar",
    "motivamos": "motivar",
    "motivando": "motivar",
    "motivara": "motivar",
    "motivaram": "motivar",
    "motivaras": "motivar",
    "motivarde": "motivar",
    "motivardes": "motivar",
    "motivare": "motivar",
    "motivarei": "motivar",
    "motivareis": "motivar",
    "motivarem": "motivar",
    "motivaremos": "motivar",
    "motivares": "motivar",
    "motivaria": "motivar",
    "motivariam": "motivar",
    "motivarias": "motivar",
    "motivarmo": "motivar",
    "motivarmos": "motivar",
    "motivará": "motivar",
    "motivarás": "motivar",
    "motivarão": "motivar",
    "motivaríamos": "motivar",
    "motivaríeis": "motivar",
    "motivas": "motivar",
    "motivasse": "motivar",
    "motivassem": "motivar",
    "motivasses": "motivar",
    "motivaste": "motivar",
    "motivastes": "motivar",
    "motivava": "motivar",
    "motivavam": "motivar",
    "motivavas": "motivar",
    "motivações": "motivação",
    "motive": "motivar",
    "motivei": "motivar",
    "motiveis": "motivar",
    "motivem": "motivar",
    "motivemo": "motivar",
    "motivemos": "motivar",
    "motives": "motivar",
    "motivo": "motivar",
    "motivos": "motivo",
    "motivou": "motivar",
    "motivá": "motivar",
    "motivámo": "motivar",
    "motivámos": "motivar",
    "motiváramo": "motivar",
    "motiváramos": "motivar",
    "motivárei": "motivar",
    "motiváreis": "motivar",
    "motivásseis": "motivar",
    "motivássemos": "motivar",
    "motivávamo": "motivar",
    "motivávamos": "motivar",
    "motivávei": "motivar",
    "motiváveis": "motivável",
    "motocicletas": "motocicleta",
    "motociclismos": "motociclismo",
    "motociclistas": "motociclista",
    "motociclos": "motociclo",
    "motoclubes": "motoclube",
    "motocrosses": "motocross",
    "motomecanizações": "motomecanização",
    "motona": "mota",
    "motonas": "mota",
    "motonetas": "motoneta",
    "motoniveladoras": "motoniveladora",
    "motonáuticas": "motonáutica",
    "motoqueira": "motoqueiro",
    "motoqueiras": "motoqueiro",
    "motoqueiros": "motoqueiro",
    "motora": "motor",
    "motoras": "motor",
    "motores": "motor",
    "motoretas": "motoreta",
    "motoristas": "motorista",
    "motoriza": "motorizar",
    "motorizada": "motorizar",
    "motorizadas": "motorizar",
    "motorizado": "motorizar",
    "motorizados": "motorizar",
    "motorizai": "motorizar",
    "motorizais": "motorizar",
    "motorizam": "motorizar",
    "motorizamo": "motorizar",
    "motorizamos": "motorizar",
    "motorizando": "motorizar",
    "motorizara": "motorizar",
    "motorizaram": "motorizar",
    "motorizaras": "motorizar",
    "motorizarde": "motorizar",
    "motorizardes": "motorizar",
    "motorizare": "motorizar",
    "motorizarei": "motorizar",
    "motorizareis": "motorizar",
    "motorizarem": "motorizar",
    "motorizaremos": "motorizar",
    "motorizares": "motorizar",
    "motorizaria": "motorizar",
    "motorizariam": "motorizar",
    "motorizarias": "motorizar",
    "motorizarmo": "motorizar",
    "motorizarmos": "motorizar",
    "motorizará": "motorizar",
    "motorizarás": "motorizar",
    "motorizarão": "motorizar",
    "motorizaríamos": "motorizar",
    "motorizaríeis": "motorizar",
    "motorizas": "motorizar",
    "motorizasse": "motorizar",
    "motorizassem": "motorizar",
    "motorizasses": "motorizar",
    "motorizaste": "motorizar",
    "motorizastes": "motorizar",
    "motorizava": "motorizar",
    "motorizavam": "motorizar",
    "motorizavas": "motorizar",
    "motorizações": "motorização",
    "motorize": "motorizar",
    "motorizei": "motorizar",
    "motorizeis": "motorizar",
    "motorizem": "motorizar",
    "motorizemo": "motorizar",
    "motorizemos": "motorizar",
    "motorizes": "motorizar",
    "motorizo": "motorizar",
    "motorizou": "motorizar",
    "motorizá": "motorizar",
    "motorizámo": "motorizar",
    "motorizámos": "motorizar",
    "motorizáramo": "motorizar",
    "motorizáramos": "motorizar",
    "motorizárei": "motorizar",
    "motorizáreis": "motorizar",
    "motorizásseis": "motorizar",
    "motorizássemos": "motorizar",
    "motorizávamo": "motorizar",
    "motorizávamos": "motorizar",
    "motorizávei": "motorizar",
    "motorizáveis": "motorizável",
    "motorzinho": "motor",
    "motorzinhos": "motor",
    "motorzito": "motor",
    "motorzitos": "motor",
    "motos": "moto",
    "motricidades": "motricidade",
    "motrizes": "motriz",
    "motão": "mota",
    "motéis": "motel",
    "motódromos": "motódromo",
    "motões": "mota",
    "mouca": "mouco",
    "moucarrona": "mouco",
    "moucarronas": "mouco",
    "moucarrão": "mouco",
    "moucarrões": "mouco",
    "moucas": "mouco",
    "mouchões": "mouchão",
    "moucos": "mouco",
    "mouqueiras": "mouqueira",
    "mouquices": "mouquice",
    "mouquidões": "mouquidão",
    "mouquinha": "mouco",
    "mouquinhas": "mouco",
    "mouquinho": "mouco",
    "mouquinhos": "mouco",
    "mouquita": "mouco",
    "mouquitas": "mouco",
    "mouquito": "mouco",
    "mouquitos": "mouco",
    "moura": "mouro",
    "mourada": "mourar",
    "mouradas": "mourar",
    "mourado": "mourar",
    "mourados": "mourar",
    "mourai": "mourar",
    "mourais": "mourar",
    "mouram": "mourar",
    "mouramas": "mourama",
    "mouramo": "mourar",
    "mouramos": "mourar",
    "mourando": "mourar",
    "mourara": "mourar",
    "mouraram": "mourar",
    "mouraras": "mourar",
    "mourardes": "mourar",
    "mourarei": "mourar",
    "mourareis": "mourar",
    "mourarem": "mourar",
    "mouraremos": "mourar",
    "mourares": "mourar",
    "mouraria": "mourar",
    "mourariam": "mourar",
    "mourarias": "mouraria",
    "mourarmo": "mourar",
    "mourarmos": "mourar",
    "mourará": "mourar",
    "mourarás": "mourar",
    "mourarão": "mourar",
    "mouraríamos": "mourar",
    "mouraríeis": "mourar",
    "mouras": "mouro",
    "mourasse": "mourar",
    "mourassem": "mourar",
    "mourasses": "mourar",
    "mouraste": "mourar",
    "mourastes": "mourar",
    "mourava": "mourar",
    "mouravam": "mourar",
    "mouravas": "mourar",
    "moure": "mourar",
    "mourei": "mourar",
    "moureis": "mourar",
    "moureja": "mourejar",
    "mourejada": "mourejar",
    "mourejadas": "mourejar",
    "mourejado": "mourejar",
    "mourejados": "mourejar",
    "mourejai": "mourejar",
    "mourejais": "mourejar",
    "mourejam": "mourejar",
    "mourejamo": "mourejar",
    "mourejamos": "mourejar",
    "mourejando": "mourejar",
    "mourejara": "mourejar",
    "mourejaram": "mourejar",
    "mourejaras": "mourejar",
    "mourejarde": "mourejar",
    "mourejardes": "mourejar",
    "mourejare": "mourejar",
    "mourejarei": "mourejar",
    "mourejareis": "mourejar",
    "mourejarem": "mourejar",
    "mourejaremos": "mourejar",
    "mourejares": "mourejar",
    "mourejaria": "mourejar",
    "mourejariam": "mourejar",
    "mourejarias": "mourejar",
    "mourejarmo": "mourejar",
    "mourejarmos": "mourejar",
    "mourejará": "mourejar",
    "mourejarás": "mourejar",
    "mourejarão": "mourejar",
    "mourejaríamos": "mourejar",
    "mourejaríeis": "mourejar",
    "mourejas": "mourejar",
    "mourejasse": "mourejar",
    "mourejassem": "mourejar",
    "mourejasses": "mourejar",
    "mourejaste": "mourejar",
    "mourejastes": "mourejar",
    "mourejava": "mourejar",
    "mourejavam": "mourejar",
    "mourejavas": "mourejar",
    "moureje": "mourejar",
    "mourejei": "mourejar",
    "mourejeis": "mourejar",
    "mourejem": "mourejar",
    "mourejemo": "mourejar",
    "mourejemos": "mourejar",
    "mourejes": "mourejar",
    "mourejo": "mourejar",
    "mourejou": "mourejar",
    "mourejá": "mourejar",
    "mourejámo": "mourejar",
    "mourejámos": "mourejar",
    "mourejáramo": "mourejar",
    "mourejáramos": "mourejar",
    "mourejárei": "mourejar",
    "mourejáreis": "mourejar",
    "mourejásseis": "mourejar",
    "mourejássemos": "mourejar",
    "mourejávamo": "mourejar",
    "mourejávamos": "mourejar",
    "mourejávei": "mourejar",
    "mourejáveis": "mourejar",
    "mourem": "mourar",
    "mouremo": "mourar",
    "mouremos": "mourar",
    "moures": "mourar",
    "mouresca": "mouresco",
    "mourescas": "mouresco",
    "mourescos": "mouresco",
    "mourinha": "mouro",
    "mourinhas": "mouro",
    "mourinho": "mouro",
    "mourinhos": "mouro",
    "mourisca": "mourisco",
    "mouriscada": "mouriscado",
    "mouriscadas": "mouriscado",
    "mouriscados": "mouriscado",
    "mouriscas": "mourisco",
    "mouriscos": "mourisco",
    "mourismas": "mourisma",
    "mourismos": "mourismo",
    "mourita": "mouro",
    "mouritas": "mouro",
    "mourito": "mouro",
    "mouritos": "mouro",
    "mouro": "mourar",
    "mouros": "mouro",
    "mourou": "mourar",
    "mourámo": "mourar",
    "mourámos": "mourar",
    "mouráramo": "mourar",
    "mouráramos": "mourar",
    "mouráreis": "mourar",
    "mourásseis": "mourar",
    "mourássemos": "mourar",
    "mourávamo": "mourar",
    "mourávamos": "mourar",
    "mouráveis": "mourar",
    "mourões": "mourão",
    "mousses": "mousse",
    "moutas": "mouta",
    "moutazinha": "mouta",
    "moutazinhas": "mouta",
    "moutazita": "mouta",
    "moutazitas": "mouta",
    "moutedos": "moutedo",
    "mouteiras": "mouteira",
    "moutões": "moutão",
    "mova": "mover",
    "movais": "mover",
    "movam": "mover",
    "movamo": "mover",
    "movamos": "mover",
    "movas": "mover",
    "move": "mover",
    "movediça": "movediço",
    "movediças": "movediço",
    "movediços": "movediço",
    "movedora": "movedor",
    "movedoras": "movedor",
    "movedores": "movedor",
    "movei": "mover",
    "moveis": "mover",
    "movem": "mover",
    "movemo": "mover",
    "movemos": "mover",
    "movendo": "mover",
    "moventes": "movente",
    "movera": "mover",
    "moveram": "mover",
    "moveras": "mover",
    "moverde": "mover",
    "moverdes": "mover",
    "movere": "mover",
    "moverei": "mover",
    "movereis": "mover",
    "moverem": "mover",
    "moveremos": "mover",
    "moveres": "mover",
    "moveria": "mover",
    "moveriam": "mover",
    "moverias": "mover",
    "movermo": "mover",
    "movermos": "mover",
    "moverá": "mover",
    "moverás": "mover",
    "moverão": "mover",
    "moveríamos": "mover",
    "moveríeis": "mover",
    "moves": "mover",
    "movesse": "mover",
    "movessem": "mover",
    "movesses": "mover",
    "moveste": "mover",
    "movestes": "mover",
    "moveu": "mover",
    "movi": "mover",
    "movia": "mover",
    "moviam": "mover",
    "movias": "mover",
    "movida": "movido",
    "movidas": "movido",
    "movido": "mover",
    "movidos": "movido",
    "movimenta": "movimentar",
    "movimentada": "movimentar",
    "movimentadas": "movimentar",
    "movimentado": "movimentar",
    "movimentados": "movimentar",
    "movimentai": "movimentar",
    "movimentais": "movimentar",
    "movimentam": "movimentar",
    "movimentamo": "movimentar",
    "movimentamos": "movimentar",
    "movimentando": "movimentar",
    "movimentara": "movimentar",
    "movimentaram": "movimentar",
    "movimentaras": "movimentar",
    "movimentarde": "movimentar",
    "movimentardes": "movimentar",
    "movimentare": "movimentar",
    "movimentarei": "movimentar",
    "movimentareis": "movimentar",
    "movimentarem": "movimentar",
    "movimentaremos": "movimentar",
    "movimentares": "movimentar",
    "movimentaria": "movimentar",
    "movimentariam": "movimentar",
    "movimentarias": "movimentar",
    "movimentarmo": "movimentar",
    "movimentarmos": "movimentar",
    "movimentará": "movimentar",
    "movimentarás": "movimentar",
    "movimentarão": "movimentar",
    "movimentaríamos": "movimentar",
    "movimentaríeis": "movimentar",
    "movimentas": "movimentar",
    "movimentasse": "movimentar",
    "movimentassem": "movimentar",
    "movimentasses": "movimentar",
    "movimentaste": "movimentar",
    "movimentastes": "movimentar",
    "movimentava": "movimentar",
    "movimentavam": "movimentar",
    "movimentavas": "movimentar",
    "movimentações": "movimentação",
    "movimente": "movimentar",
    "movimentei": "movimentar",
    "movimenteis": "movimentar",
    "movimentem": "movimentar",
    "movimentemo": "movimentar",
    "movimentemos": "movimentar",
    "movimentes": "movimentar",
    "movimento": "movimentar",
    "movimentos": "movimento",
    "movimentou": "movimentar",
    "movimentá": "movimentar",
    "movimentámo": "movimentar",
    "movimentámos": "movimentar",
    "movimentáramo": "movimentar",
    "movimentáramos": "movimentar",
    "movimentárei": "movimentar",
    "movimentáreis": "movimentar",
    "movimentásseis": "movimentar",
    "movimentássemos": "movimentar",
    "movimentávamo": "movimentar",
    "movimentávamos": "movimentar",
    "movimentávei": "movimentar",
    "movimentáveis": "movimentar",
    "movo": "mover",
    "movê": "mover",
    "movêramo": "mover",
    "movêramos": "mover",
    "movêrei": "mover",
    "movêreis": "mover",
    "movêsseis": "mover",
    "movêssemos": "mover",
    "movíamo": "mover",
    "movíamos": "mover",
    "movíei": "mover",
    "movíeis": "mover",
    "movíveis": "movível",
    "moxama": "moxamar",
    "moxamada": "moxamar",
    "moxamadas": "moxamar",
    "moxamado": "moxamar",
    "moxamados": "moxamar",
    "moxamai": "moxamar",
    "moxamais": "moxamar",
    "moxamam": "moxamar",
    "moxamamo": "moxamar",
    "moxamamos": "moxamar",
    "moxamando": "moxamar",
    "moxamara": "moxamar",
    "moxamaram": "moxamar",
    "moxamaras": "moxamar",
    "moxamarde": "moxamar",
    "moxamardes": "moxamar",
    "moxamare": "moxamar",
    "moxamarei": "moxamar",
    "moxamareis": "moxamar",
    "moxamarem": "moxamar",
    "moxamaremos": "moxamar",
    "moxamares": "moxamar",
    "moxamaria": "moxamar",
    "moxamariam": "moxamar",
    "moxamarias": "moxamar",
    "moxamarmo": "moxamar",
    "moxamarmos": "moxamar",
    "moxamará": "moxamar",
    "moxamarás": "moxamar",
    "moxamarão": "moxamar",
    "moxamaríamos": "moxamar",
    "moxamaríeis": "moxamar",
    "moxamas": "moxamar",
    "moxamasse": "moxamar",
    "moxamassem": "moxamar",
    "moxamasses": "moxamar",
    "moxamaste": "moxamar",
    "moxamastes": "moxamar",
    "moxamava": "moxamar",
    "moxamavam": "moxamar",
    "moxamavas": "moxamar",
    "moxame": "moxamar",
    "moxamei": "moxamar",
    "moxameira": "moxameiro",
    "moxameiras": "moxameiro",
    "moxameiros": "moxameiro",
    "moxameis": "moxamar",
    "moxamem": "moxamar",
    "moxamemo": "moxamar",
    "moxamemos": "moxamar",
    "moxames": "moxamar",
    "moxamo": "moxamar",
    "moxamou": "moxamar",
    "moxamá": "moxamar",
    "moxamámo": "moxamar",
    "moxamámos": "moxamar",
    "moxamáramo": "moxamar",
    "moxamáramos": "moxamar",
    "moxamárei": "moxamar",
    "moxamáreis": "moxamar",
    "moxamásseis": "moxamar",
    "moxamássemos": "moxamar",
    "moxamávamo": "moxamar",
    "moxamávamos": "moxamar",
    "moxamávei": "moxamar",
    "moxamáveis": "moxamar",
    "moxaras": "moxara",
    "moxingas": "moxinga",
    "moxinifadas": "moxinifada",
    "mozarabismos": "mozarabismo",
    "mozartiana": "mozartiano",
    "mozartianas": "mozartiano",
    "mozartianos": "mozartiano",
    "mozarábica": "mozarábico",
    "mozarábicas": "mozarábico",
    "mozarábicos": "mozarábico",
    "mozetas": "mozeta",
    "mozárabes": "mozárabe",
    "moádis": "moádi",
    "moça": "moço",
    "moçadas": "moçada",
    "moçambicana": "moçambicano",
    "moçambicanas": "moçambicano",
    "moçambicanos": "moçambicano",
    "moçambiques": "moçambique",
    "moçarabismos": "moçarabismo",
    "moçarábica": "moçarábico",
    "moçarábicas": "moçarábico",
    "moçarábicos": "moçarábico",
    "moças": "moço",
    "moçazinha": "moço",
    "moçazinhas": "moço",
    "moçazita": "moço",
    "moçazitas": "moço",
    "moçoila": "moçoilo",
    "moçoilas": "moçoilo",
    "moçoilos": "moçoilo",
    "moços": "moço",
    "moçozinho": "moço",
    "moçozinhos": "moço",
    "moçozito": "moço",
    "moçozitos": "moço",
    "moçárabes": "moçárabe",
    "moções": "moção",
    "moê": "moer",
    "moêramo": "moer",
    "moêramos": "moer",
    "moêrei": "moer",
    "moêreis": "moer",
    "moêsseis": "moer",
    "moêssemos": "moer",
    "moí": "moer",
    "moía": "moer",
    "moíam": "moer",
    "moíamo": "moer",
    "moíamos": "moer",
    "moías": "moer",
    "moída": "moído",
    "moídas": "moído",
    "moído": "moer",
    "moídos": "moído",
    "moíei": "moer",
    "moíeis": "moer",
    "moíveis": "moível",
    "mua": "mu",
    "muambas": "muamba",
    "muambeira": "muambeiro",
    "muambeiras": "muambeiro",
    "muambeiros": "muambeiro",
    "muares": "muar",
    "muas": "mu",
    "muaves": "muave",
    "mucamas": "mucama",
    "mucedínea": "mucedíneo",
    "mucedíneas": "mucedíneo",
    "mucedíneos": "mucedíneo",
    "muchacha": "muchacho",
    "muchacharias": "muchacharia",
    "muchachas": "muchacho",
    "muchachos": "muchacho",
    "mucharras": "mucharra",
    "muchéns": "muchém",
    "muchões": "muchão",
    "muciformes": "muciforme",
    "mucilagens": "mucilagem",
    "mucilaginosa": "mucilaginoso",
    "mucilaginosas": "mucilaginoso",
    "mucilaginosos": "mucilaginoso",
    "mucinas": "mucina",
    "mucocos": "mucoco",
    "mucocutânea": "mucocutâneo",
    "mucocutâneas": "mucocutâneo",
    "mucocutâneos": "mucocutâneo",
    "mucocóis": "mucocol",
    "mucopurulenta": "mucopurulento",
    "mucopurulentas": "mucopurulento",
    "mucopurulentos": "mucopurulento",
    "mucoráceas": "mucorácea",
    "mucos": "muco",
    "mucosa": "mucoso",
    "mucosas": "mucoso",
    "mucosidades": "mucosidade",
    "mucosos": "mucoso",
    "mucosserosa": "mucosseroso",
    "mucosserosas": "mucosseroso",
    "mucosserosos": "mucosseroso",
    "mucronada": "mucronado",
    "mucronadas": "mucronado",
    "mucronados": "mucronado",
    "mucros": "mucro",
    "mucrões": "mucrão",
    "mucucos": "mucuco",
    "mucípara": "mucíparo",
    "mucíparas": "mucíparo",
    "mucíparos": "mucíparo",
    "mucívora": "mucívoro",
    "mucívoras": "mucívoro",
    "mucívoros": "mucívoro",
    "mucóides": "mucóide",
    "muda": "mudo",
    "mudada": "mudar",
    "mudadas": "mudar",
    "mudadiça": "mudadiço",
    "mudadiças": "mudadiço",
    "mudadiços": "mudadiço",
    "mudado": "mudar",
    "mudadora": "mudador",
    "mudadoras": "mudador",
    "mudadores": "mudador",
    "mudados": "mudar",
    "mudadíssima": "mudado",
    "mudadíssimas": "mudado",
    "mudadíssimo": "mudado",
    "mudadíssimos": "mudado",
    "mudai": "mudar",
    "mudais": "mudar",
    "mudam": "mudar",
    "mudamo": "mudar",
    "mudamos": "mudar",
    "mudando": "mudar",
    "mudanças": "mudança",
    "mudara": "mudar",
    "mudaram": "mudar",
    "mudaras": "mudar",
    "mudarde": "mudar",
    "mudardes": "mudar",
    "mudare": "mudar",
    "mudarei": "mudar",
    "mudareis": "mudar",
    "mudarem": "mudar",
    "mudaremos": "mudar",
    "mudares": "mudar",
    "mudaria": "mudar",
    "mudariam": "mudar",
    "mudarias": "mudar",
    "mudarmo": "mudar",
    "mudarmos": "mudar",
    "mudará": "mudar",
    "mudarás": "mudar",
    "mudarão": "mudar",
    "mudaríamos": "mudar",
    "mudaríeis": "mudar",
    "mudas": "mudo",
    "mudasse": "mudar",
    "mudassem": "mudar",
    "mudasses": "mudar",
    "mudaste": "mudar",
    "mudastes": "mudar",
    "mudava": "mudar",
    "mudavam": "mudar",
    "mudavas": "mudar",
    "mude": "mudar",
    "mudei": "mudar",
    "mudeis": "mudar",
    "mudejarismos": "mudejarismo",
    "mudem": "mudar",
    "mudemo": "mudar",
    "mudemos": "mudar",
    "mudes": "mudar",
    "mudezes": "mudez",
    "mudinha": "mudo",
    "mudinhas": "mudo",
    "mudinho": "mudo",
    "mudinhos": "mudo",
    "mudita": "mudo",
    "muditas": "mudo",
    "mudito": "mudo",
    "muditos": "mudo",
    "mudo": "mudar",
    "mudongueiras": "mudongueira",
    "mudos": "mudo",
    "mudou": "mudar",
    "mudá": "mudar",
    "mudámo": "mudar",
    "mudámos": "mudar",
    "mudáramo": "mudar",
    "mudáramos": "mudar",
    "mudárei": "mudar",
    "mudáreis": "mudar",
    "mudásseis": "mudar",
    "mudássemos": "mudar",
    "mudávamo": "mudar",
    "mudávamos": "mudar",
    "mudávei": "mudar",
    "mudáveis": "mudável",
    "mudéjares": "mudéjar",
    "mudíssima": "mudo",
    "mudíssimas": "mudo",
    "mudíssimo": "mudo",
    "mudíssimos": "mudo",
    "muelas": "muela",
    "muezins": "muezim",
    "muflas": "mufla",
    "muflos": "muflo",
    "muflões": "muflão",
    "muftis": "mufti",
    "mugeiros": "mugeiro",
    "mugens": "mugem",
    "muges": "muge",
    "mugi": "mugir",
    "mugia": "mugir",
    "mugiam": "mugir",
    "mugias": "mugir",
    "mugida": "mugir",
    "mugidas": "mugir",
    "mugido": "mugir",
    "mugidora": "mugidor",
    "mugidoras": "mugidor",
    "mugidores": "mugidor",
    "mugidos": "mugir",
    "mugilídeos": "mugilídeo",
    "mugimo": "mugir",
    "mugimos": "mugir",
    "mugindo": "mugir",
    "mugira": "mugir",
    "mugiram": "mugir",
    "mugiras": "mugir",
    "mugirdes": "mugir",
    "mugirei": "mugir",
    "mugireis": "mugir",
    "mugirem": "mugir",
    "mugiremos": "mugir",
    "mugires": "mugir",
    "mugiria": "mugir",
    "mugiriam": "mugir",
    "mugirias": "mugir",
    "mugirmo": "mugir",
    "mugirmos": "mugir",
    "mugirá": "mugir",
    "mugirás": "mugir",
    "mugirão": "mugir",
    "mugiríamos": "mugir",
    "mugiríeis": "mugir",
    "mugis": "mugir",
    "mugisse": "mugir",
    "mugissem": "mugir",
    "mugisses": "mugir",
    "mugiste": "mugir",
    "mugistes": "mugir",
    "mugiu": "mugir",
    "mugres": "mugre",
    "mugueiras": "mugueira",
    "mugíamo": "mugir",
    "mugíamos": "mugir",
    "mugíeis": "mugir",
    "mugílidas": "mugílida",
    "mugíramo": "mugir",
    "mugíramos": "mugir",
    "mugíreis": "mugir",
    "mugísseis": "mugir",
    "mugíssemos": "mugir",
    "muis": "mui",
    "muita": "muito",
    "muitas": "muito",
    "muitos": "muito",
    "muitíssima": "muito",
    "muitíssimas": "muito",
    "muitíssimo": "muito",
    "muitíssimos": "muito",
    "muja": "mugir",
    "mujais": "mugir",
    "mujam": "mugir",
    "mujamo": "mugir",
    "mujamos": "mugir",
    "mujas": "mugir",
    "mujiques": "mujique",
    "mujo": "mugir",
    "mula": "mulo",
    "muladares": "muladar",
    "muladas": "mulada",
    "mulas": "mulo",
    "mulata": "mulato",
    "mulatarias": "mulataria",
    "mulatas": "mulato",
    "mulatices": "mulatice",
    "mulatinha": "mulato",
    "mulatinhas": "mulato",
    "mulatinho": "mulato",
    "mulatinhos": "mulato",
    "mulatismos": "mulatismo",
    "mulatita": "mulato",
    "mulatitas": "mulato",
    "mulatito": "mulato",
    "mulatitos": "mulato",
    "mulatos": "mulato",
    "muletadas": "muletada",
    "muletas": "muleta",
    "muleteiros": "muleteiro",
    "muletins": "muletim",
    "mulheradas": "mulherada",
    "mulherames": "mulherame",
    "mulheraças": "mulheraça",
    "mulheraços": "mulheraço",
    "mulherenga": "mulherengo",
    "mulherengas": "mulherengo",
    "mulherengos": "mulherengo",
    "mulheres": "mulher",
    "mulherica": "mulherico",
    "mulhericas": "mulherico",
    "mulhericos": "mulherico",
    "mulherinas": "mulherina",
    "mulherios": "mulherio",
    "mulheris": "mulheril",
    "mulheronas": "mulherona",
    "mulheruns": "mulherum",
    "mulherzinha": "mulher",
    "mulherzinhas": "mulher",
    "mulherzita": "mulher",
    "mulherzitas": "mulher",
    "mulherões": "mulherão",
    "mulos": "mulo",
    "mulsos": "mulso",
    "multa": "multar",
    "multada": "multar",
    "multadas": "multar",
    "multado": "multar",
    "multados": "multar",
    "multai": "multar",
    "multais": "multar",
    "multam": "multar",
    "multamo": "multar",
    "multamos": "multar",
    "multando": "multar",
    "multangulares": "multangular",
    "multara": "multar",
    "multaram": "multar",
    "multaras": "multar",
    "multarde": "multar",
    "multardes": "multar",
    "multare": "multar",
    "multarei": "multar",
    "multareis": "multar",
    "multarem": "multar",
    "multaremos": "multar",
    "multares": "multar",
    "multaria": "multar",
    "multariam": "multar",
    "multarias": "multar",
    "multarmo": "multar",
    "multarmos": "multar",
    "multará": "multar",
    "multarás": "multar",
    "multarão": "multar",
    "multaríamos": "multar",
    "multaríeis": "multar",
    "multas": "multar",
    "multasse": "multar",
    "multassem": "multar",
    "multasses": "multar",
    "multaste": "multar",
    "multastes": "multar",
    "multava": "multar",
    "multavam": "multar",
    "multavas": "multar",
    "multe": "multar",
    "multei": "multar",
    "multeis": "multar",
    "multem": "multar",
    "multemo": "multar",
    "multemos": "multar",
    "multes": "multar",
    "multiactividades": "multiactividade",
    "multiangulares": "multiangular",
    "multiatómica": "multiatómico",
    "multiatómicas": "multiatómico",
    "multiatómicos": "multiatómico",
    "multiaxífera": "multiaxífero",
    "multiaxíferas": "multiaxífero",
    "multiaxíferos": "multiaxífero",
    "multibancos": "multibanco",
    "multicapsulares": "multicapsular",
    "multicarpelares": "multicarpelar",
    "multicaules": "multicaule",
    "multicelulares": "multicelular",
    "multicolore": "multicolorir",
    "multicolorem": "multicolorir",
    "multicolores": "multicolorir",
    "multicolori": "multicolorir",
    "multicoloria": "multicolorir",
    "multicoloriam": "multicolorir",
    "multicolorias": "multicolorir",
    "multicolorida": "multicolorir",
    "multicoloridas": "multicolorir",
    "multicolorido": "multicolorir",
    "multicoloridos": "multicolorir",
    "multicolorimo": "multicolorir",
    "multicolorimos": "multicolorir",
    "multicolorindo": "multicolorir",
    "multicolorira": "multicolorir",
    "multicoloriram": "multicolorir",
    "multicoloriras": "multicolorir",
    "multicolorirde": "multicolorir",
    "multicolorirdes": "multicolorir",
    "multicolorire": "multicolorir",
    "multicolorirei": "multicolorir",
    "multicolorireis": "multicolorir",
    "multicolorirem": "multicolorir",
    "multicoloriremos": "multicolorir",
    "multicolorires": "multicolorir",
    "multicoloriria": "multicolorir",
    "multicoloririam": "multicolorir",
    "multicoloririas": "multicolorir",
    "multicolorirmo": "multicolorir",
    "multicolorirmos": "multicolorir",
    "multicolorirá": "multicolorir",
    "multicolorirás": "multicolorir",
    "multicolorirão": "multicolorir",
    "multicoloriríamos": "multicolorir",
    "multicoloriríeis": "multicolorir",
    "multicoloris": "multicolorir",
    "multicolorisse": "multicolorir",
    "multicolorissem": "multicolorir",
    "multicolorisses": "multicolorir",
    "multicoloriste": "multicolorir",
    "multicoloristes": "multicolorir",
    "multicoloriu": "multicolorir",
    "multicoloríamo": "multicolorir",
    "multicoloríamos": "multicolorir",
    "multicoloríei": "multicolorir",
    "multicoloríeis": "multicolorir",
    "multicoloríramo": "multicolorir",
    "multicoloríramos": "multicolorir",
    "multicolorírei": "multicolorir",
    "multicoloríreis": "multicolorir",
    "multicolorísseis": "multicolorir",
    "multicoloríssemos": "multicolorir",
    "multicolura": "multicolorir",
    "multicolurais": "multicolorir",
    "multicoluram": "multicolorir",
    "multicoluramo": "multicolorir",
    "multicoluramos": "multicolorir",
    "multicoluras": "multicolorir",
    "multicoluro": "multicolorir",
    "multicores": "multicor",
    "multicultora": "multicultor",
    "multicultoras": "multicultor",
    "multicultores": "multicultor",
    "multiculturais": "multicultural",
    "multicúspides": "multicúspide",
    "multidiedros": "multidiedro",
    "multidificiências": "multidificiência",
    "multidigitada": "multidigitado",
    "multidigitadas": "multidigitado",
    "multidigitados": "multidigitado",
    "multidisciplinares": "multidisciplinar",
    "multidocências": "multidocência",
    "multidões": "multidão",
    "multifaces": "multiface",
    "multifacetada": "multifacetado",
    "multifacetadas": "multifacetado",
    "multifacetados": "multifacetado",
    "multiflora": "multifloro",
    "multifloras": "multifloro",
    "multifloros": "multifloro",
    "multifoliada": "multifoliado",
    "multifoliadas": "multifoliado",
    "multifoliados": "multifoliado",
    "multiformes": "multiforme",
    "multiformidades": "multiformidade",
    "multifuncionais": "multifuncional",
    "multifura": "multifuro",
    "multifuras": "multifuro",
    "multifuros": "multifuro",
    "multifária": "multifário",
    "multifárias": "multifário",
    "multifários": "multifário",
    "multilaterais": "multilateral",
    "multilingue": "multilíngue",
    "multilingues": "multilíngue",
    "multilinguismos": "multilinguismo",
    "multilites": "multilite",
    "multilobada": "multilobado",
    "multilobadas": "multilobado",
    "multilobados": "multilobado",
    "multiloculares": "multilocular",
    "multilátera": "multilátero",
    "multiláteras": "multilátero",
    "multiláteros": "multilátero",
    "multilíngues": "multilíngue",
    "multimilenária": "multimilenário",
    "multimilenárias": "multimilenário",
    "multimilenários": "multimilenário",
    "multimilionária": "multimilionário",
    "multimilionárias": "multimilionário",
    "multimilionários": "multimilionário",
    "multimédias": "multimédia",
    "multinacionais": "multinacional",
    "multinacionalismos": "multinacionalismo",
    "multinegativos": "multinegativo",
    "multinfecções": "multinfecção",
    "multinérvea": "multinérveo",
    "multinérveas": "multinérveo",
    "multinérveos": "multinérveo",
    "multiparidades": "multiparidade",
    "multipartida": "multipartido",
    "multipartidarismos": "multipartidarismo",
    "multipartidas": "multipartido",
    "multipartidos": "multipartido",
    "multipartidária": "multipartidário",
    "multipartidárias": "multipartidário",
    "multipartidários": "multipartidário",
    "multipartições": "multipartição",
    "multipistilada": "multipistilado",
    "multipistiladas": "multipistilado",
    "multipistilados": "multipistilado",
    "multiplanos": "multiplano",
    "multipletos": "multipleto",
    "multiplexadores": "multiplexador",
    "multiplica": "multiplicar",
    "multiplicada": "multiplicar",
    "multiplicadas": "multiplicar",
    "multiplicado": "multiplicar",
    "multiplicadora": "multiplicador",
    "multiplicadoras": "multiplicador",
    "multiplicadores": "multiplicador",
    "multiplicados": "multiplicar",
    "multiplicai": "multiplicar",
    "multiplicais": "multiplicar",
    "multiplicam": "multiplicar",
    "multiplicamo": "multiplicar",
    "multiplicamos": "multiplicar",
    "multiplicanda": "multiplicando",
    "multiplicandas": "multiplicando",
    "multiplicando": "multiplicar",
    "multiplicandos": "multiplicando",
    "multiplicara": "multiplicar",
    "multiplicaram": "multiplicar",
    "multiplicaras": "multiplicar",
    "multiplicarde": "multiplicar",
    "multiplicardes": "multiplicar",
    "multiplicare": "multiplicar",
    "multiplicarei": "multiplicar",
    "multiplicareis": "multiplicar",
    "multiplicarem": "multiplicar",
    "multiplicaremos": "multiplicar",
    "multiplicares": "multiplicar",
    "multiplicaria": "multiplicar",
    "multiplicariam": "multiplicar",
    "multiplicarias": "multiplicar",
    "multiplicarmo": "multiplicar",
    "multiplicarmos": "multiplicar",
    "multiplicará": "multiplicar",
    "multiplicarás": "multiplicar",
    "multiplicarão": "multiplicar",
    "multiplicaríamos": "multiplicar",
    "multiplicaríeis": "multiplicar",
    "multiplicas": "multiplicar",
    "multiplicasse": "multiplicar",
    "multiplicassem": "multiplicar",
    "multiplicasses": "multiplicar",
    "multiplicaste": "multiplicar",
    "multiplicastes": "multiplicar",
    "multiplicativa": "multiplicativo",
    "multiplicativas": "multiplicativo",
    "multiplicativos": "multiplicativo",
    "multiplicava": "multiplicar",
    "multiplicavam": "multiplicar",
    "multiplicavas": "multiplicar",
    "multiplicações": "multiplicação",
    "multiplicidades": "multiplicidade",
    "multiplico": "multiplicar",
    "multiplicou": "multiplicar",
    "multiplicá": "multiplicar",
    "multiplicámo": "multiplicar",
    "multiplicámos": "multiplicar",
    "multiplicáramo": "multiplicar",
    "multiplicáramos": "multiplicar",
    "multiplicárei": "multiplicar",
    "multiplicáreis": "multiplicar",
    "multiplicásseis": "multiplicar",
    "multiplicássemos": "multiplicar",
    "multiplicávamo": "multiplicar",
    "multiplicávamos": "multiplicar",
    "multiplicávei": "multiplicar",
    "multiplicáveis": "multiplicável",
    "multiplique": "multiplicar",
    "multipliquei": "multiplicar",
    "multipliqueis": "multiplicar",
    "multipliquem": "multiplicar",
    "multipliquemo": "multiplicar",
    "multipliquemos": "multiplicar",
    "multipliques": "multiplicar",
    "multipolares": "multipolar",
    "multipolos": "multipolo",
    "multipontos": "multiponto",
    "multipontuada": "multipontuado",
    "multipontuadas": "multipontuado",
    "multipontuados": "multipontuado",
    "multipotentes": "multipotente",
    "multipétala": "multipétalo",
    "multipétalas": "multipétalo",
    "multipétalos": "multipétalo",
    "multirraciais": "multirracial",
    "multirradiada": "multirradiado",
    "multirradiadas": "multirradiado",
    "multirradiados": "multirradiado",
    "multirradiculares": "multirradicular",
    "multirriscos": "multirrisco",
    "multiscientes": "multisciente",
    "multisseculares": "multissecular",
    "multitubulares": "multitubular",
    "multitudes": "multitude",
    "multitudinária": "multitudinário",
    "multitudinárias": "multitudinário",
    "multitudinários": "multitudinário",
    "multiungulada": "multiungulado",
    "multiunguladas": "multiungulado",
    "multiungulados": "multiungulado",
    "multivalves": "multivalve",
    "multivalvulares": "multivalvular",
    "multivibradores": "multivibrador",
    "multiétnica": "multiétnico",
    "multiétnicas": "multiétnico",
    "multiétnicos": "multiétnico",
    "multo": "multar",
    "multou": "multar",
    "multá": "multar",
    "multámo": "multar",
    "multámos": "multar",
    "multáramo": "multar",
    "multáramos": "multar",
    "multárei": "multar",
    "multáreis": "multar",
    "multásseis": "multar",
    "multássemos": "multar",
    "multávamo": "multar",
    "multávamos": "multar",
    "multávei": "multar",
    "multáveis": "multar",
    "multífera": "multífero",
    "multíferas": "multífero",
    "multíferos": "multífero",
    "multífida": "multífido",
    "multífidas": "multífido",
    "multífidos": "multífido",
    "multíflua": "multífluo",
    "multífluas": "multífluo",
    "multífluos": "multífluo",
    "multígena": "multígeno",
    "multígenas": "multígeno",
    "multígenos": "multígeno",
    "multíloqua": "multíloquo",
    "multíloquas": "multíloquo",
    "multíloquos": "multíloquo",
    "multímetros": "multímetro",
    "multímoda": "multímodo",
    "multímodas": "multímodo",
    "multímodos": "multímodo",
    "multípara": "multíparo",
    "multíparas": "multíparo",
    "multíparos": "multíparo",
    "multípedes": "multípede",
    "multíplices": "multíplice",
    "multíscia": "multíscio",
    "multíscias": "multíscio",
    "multíscios": "multíscio",
    "multíssona": "multíssono",
    "multíssonas": "multíssono",
    "multíssonos": "multíssono",
    "multívaga": "multívago",
    "multívagas": "multívago",
    "multívagos": "multívago",
    "multívia": "multívio",
    "multívias": "multívio",
    "multívios": "multívio",
    "multívola": "multívolo",
    "multívolas": "multívolo",
    "multívolos": "multívolo",
    "mulungos": "mulungo",
    "mulungus": "mulungu",
    "mumifica": "mumificar",
    "mumificada": "mumificar",
    "mumificadas": "mumificar",
    "mumificado": "mumificar",
    "mumificadora": "mumificador",
    "mumificadoras": "mumificador",
    "mumificadores": "mumificador",
    "mumificados": "mumificar",
    "mumificai": "mumificar",
    "mumificais": "mumificar",
    "mumificam": "mumificar",
    "mumificamo": "mumificar",
    "mumificamos": "mumificar",
    "mumificando": "mumificar",
    "mumificantes": "mumificante",
    "mumificara": "mumificar",
    "mumificaram": "mumificar",
    "mumificaras": "mumificar",
    "mumificarde": "mumificar",
    "mumificardes": "mumificar",
    "mumificare": "mumificar",
    "mumificarei": "mumificar",
    "mumificareis": "mumificar",
    "mumificarem": "mumificar",
    "mumificaremos": "mumificar",
    "mumificares": "mumificar",
    "mumificaria": "mumificar",
    "mumificariam": "mumificar",
    "mumificarias": "mumificar",
    "mumificarmo": "mumificar",
    "mumificarmos": "mumificar",
    "mumificará": "mumificar",
    "mumificarás": "mumificar",
    "mumificarão": "mumificar",
    "mumificaríamos": "mumificar",
    "mumificaríeis": "mumificar",
    "mumificas": "mumificar",
    "mumificasse": "mumificar",
    "mumificassem": "mumificar",
    "mumificasses": "mumificar",
    "mumificaste": "mumificar",
    "mumificastes": "mumificar",
    "mumificava": "mumificar",
    "mumificavam": "mumificar",
    "mumificavas": "mumificar",
    "mumificações": "mumificação",
    "mumifico": "mumificar",
    "mumificou": "mumificar",
    "mumificá": "mumificar",
    "mumificámo": "mumificar",
    "mumificámos": "mumificar",
    "mumificáramo": "mumificar",
    "mumificáramos": "mumificar",
    "mumificárei": "mumificar",
    "mumificáreis": "mumificar",
    "mumificásseis": "mumificar",
    "mumificássemos": "mumificar",
    "mumificávamo": "mumificar",
    "mumificávamos": "mumificar",
    "mumificávei": "mumificar",
    "mumificáveis": "mumificável",
    "mumifique": "mumificar",
    "mumifiquei": "mumificar",
    "mumifiqueis": "mumificar",
    "mumifiquem": "mumificar",
    "mumifiquemo": "mumificar",
    "mumifiquemos": "mumificar",
    "mumifiques": "mumificar",
    "muna": "munir",
    "munais": "munir",
    "munam": "munir",
    "munamo": "munir",
    "munamos": "munir",
    "munas": "munir",
    "mundana": "mundano",
    "mundanais": "mundanal",
    "mundanalidades": "mundanalidade",
    "mundanas": "mundano",
    "mundanidades": "mundanidade",
    "mundanismos": "mundanismo",
    "mundanos": "mundano",
    "mundanária": "mundanário",
    "mundanárias": "mundanário",
    "mundanários": "mundanário",
    "mundas": "munda",
    "mundiais": "mundial",
    "mundialistas": "mundialista",
    "mundializada": "mundializado",
    "mundializadas": "mundializado",
    "mundializados": "mundializado",
    "mundializações": "mundialização",
    "mundifica": "mundificar",
    "mundificada": "mundificar",
    "mundificadas": "mundificar",
    "mundificado": "mundificar",
    "mundificadora": "mundificador",
    "mundificadoras": "mundificador",
    "mundificadores": "mundificador",
    "mundificados": "mundificar",
    "mundificai": "mundificar",
    "mundificais": "mundificar",
    "mundificam": "mundificar",
    "mundificamo": "mundificar",
    "mundificamos": "mundificar",
    "mundificando": "mundificar",
    "mundificantes": "mundificante",
    "mundificara": "mundificar",
    "mundificaram": "mundificar",
    "mundificaras": "mundificar",
    "mundificarde": "mundificar",
    "mundificardes": "mundificar",
    "mundificare": "mundificar",
    "mundificarei": "mundificar",
    "mundificareis": "mundificar",
    "mundificarem": "mundificar",
    "mundificaremos": "mundificar",
    "mundificares": "mundificar",
    "mundificaria": "mundificar",
    "mundificariam": "mundificar",
    "mundificarias": "mundificar",
    "mundificarmo": "mundificar",
    "mundificarmos": "mundificar",
    "mundificará": "mundificar",
    "mundificarás": "mundificar",
    "mundificarão": "mundificar",
    "mundificaríamos": "mundificar",
    "mundificaríeis": "mundificar",
    "mundificas": "mundificar",
    "mundificasse": "mundificar",
    "mundificassem": "mundificar",
    "mundificasses": "mundificar",
    "mundificaste": "mundificar",
    "mundificastes": "mundificar",
    "mundificativa": "mundificativo",
    "mundificativas": "mundificativo",
    "mundificativos": "mundificativo",
    "mundificava": "mundificar",
    "mundificavam": "mundificar",
    "mundificavas": "mundificar",
    "mundificações": "mundificação",
    "mundifico": "mundificar",
    "mundificou": "mundificar",
    "mundificá": "mundificar",
    "mundificámo": "mundificar",
    "mundificámos": "mundificar",
    "mundificáramo": "mundificar",
    "mundificáramos": "mundificar",
    "mundificárei": "mundificar",
    "mundificáreis": "mundificar",
    "mundificásseis": "mundificar",
    "mundificássemos": "mundificar",
    "mundificávamo": "mundificar",
    "mundificávamos": "mundificar",
    "mundificávei": "mundificar",
    "mundificáveis": "mundificar",
    "mundifique": "mundificar",
    "mundifiquei": "mundificar",
    "mundifiqueis": "mundificar",
    "mundifiquem": "mundificar",
    "mundifiquemo": "mundificar",
    "mundifiquemos": "mundificar",
    "mundifiques": "mundificar",
    "mundinóvis": "mundinóvi",
    "mundistas": "mundista",
    "mundividências": "mundividência",
    "mundivisões": "mundivisão",
    "mundongos": "mundongo",
    "mundongueiros": "mundongueiro",
    "mundos": "mundo",
    "mundícias": "mundícia",
    "mundícies": "mundície",
    "mune": "munir",
    "munem": "munir",
    "munerária": "munerário",
    "munerárias": "munerário",
    "munerários": "munerário",
    "munes": "munir",
    "munge": "mungir",
    "mungem": "mungir",
    "munges": "mungir",
    "mungi": "mungir",
    "mungia": "mungir",
    "mungiam": "mungir",
    "mungias": "mungir",
    "mungida": "mungir",
    "mungidas": "mungir",
    "mungido": "mungir",
    "mungidora": "mungidor",
    "mungidoras": "mungidor",
    "mungidores": "mungidor",
    "mungidos": "mungir",
    "mungiduras": "mungidura",
    "mungimentos": "mungimento",
    "mungimo": "mungir",
    "mungimos": "mungir",
    "mungindo": "mungir",
    "mungira": "mungir",
    "mungiram": "mungir",
    "mungiras": "mungir",
    "mungirde": "mungir",
    "mungirdes": "mungir",
    "mungire": "mungir",
    "mungirei": "mungir",
    "mungireis": "mungir",
    "mungirem": "mungir",
    "mungiremos": "mungir",
    "mungires": "mungir",
    "mungiria": "mungir",
    "mungiriam": "mungir",
    "mungirias": "mungir",
    "mungirmo": "mungir",
    "mungirmos": "mungir",
    "mungirá": "mungir",
    "mungirás": "mungir",
    "mungirão": "mungir",
    "mungiríamos": "mungir",
    "mungiríeis": "mungir",
    "mungis": "mungir",
    "mungisse": "mungir",
    "mungissem": "mungir",
    "mungisses": "mungir",
    "mungiste": "mungir",
    "mungistes": "mungir",
    "mungiu": "mungir",
    "mungíamo": "mungir",
    "mungíamos": "mungir",
    "mungíei": "mungir",
    "mungíeis": "mungir",
    "mungíramo": "mungir",
    "mungíramos": "mungir",
    "mungírei": "mungir",
    "mungíreis": "mungir",
    "mungísseis": "mungir",
    "mungíssemos": "mungir",
    "munhas": "munha",
    "munhecas": "munheca",
    "munhoneiras": "munhoneira",
    "munhões": "munhão",
    "muni": "munir",
    "munia": "munir",
    "muniam": "munir",
    "munias": "munir",
    "municia": "municiar",
    "municiada": "municiar",
    "municiadas": "municiar",
    "municiado": "municiar",
    "municiadora": "municiador",
    "municiadoras": "municiador",
    "municiadores": "municiador",
    "municiados": "municiar",
    "municiai": "municiar",
    "municiais": "municiar",
    "municiam": "municiar",
    "municiamentos": "municiamento",
    "municiamo": "municiar",
    "municiamos": "municiar",
    "municiando": "municiar",
    "municiara": "municiar",
    "municiaram": "municiar",
    "municiaras": "municiar",
    "municiarde": "municiar",
    "municiardes": "municiar",
    "municiare": "municiar",
    "municiarei": "municiar",
    "municiareis": "municiar",
    "municiarem": "municiar",
    "municiaremos": "municiar",
    "municiares": "municiar",
    "municiaria": "municiar",
    "municiariam": "municiar",
    "municiarias": "municiar",
    "municiarmo": "municiar",
    "municiarmos": "municiar",
    "municiará": "municiar",
    "municiarás": "municiar",
    "municiarão": "municiar",
    "municiaríamos": "municiar",
    "municiaríeis": "municiar",
    "municias": "municiar",
    "municiasse": "municiar",
    "municiassem": "municiar",
    "municiasses": "municiar",
    "municiaste": "municiar",
    "municiastes": "municiar",
    "municiava": "municiar",
    "municiavam": "municiar",
    "municiavas": "municiar",
    "municie": "municiar",
    "municiei": "municiar",
    "municieis": "municiar",
    "municiem": "municiar",
    "municiemo": "municiar",
    "municiemos": "municiar",
    "municies": "municiar",
    "municio": "municiar",
    "municiona": "municionar",
    "municionada": "municionar",
    "municionadas": "municionar",
    "municionado": "municionar",
    "municionadora": "municionador",
    "municionadoras": "municionador",
    "municionadores": "municionador",
    "municionados": "municionar",
    "municionai": "municionar",
    "municionais": "municionar",
    "municionam": "municionar",
    "municionamentos": "municionamento",
    "municionamo": "municionar",
    "municionamos": "municionar",
    "municionando": "municionar",
    "municionara": "municionar",
    "municionaram": "municionar",
    "municionaras": "municionar",
    "municionarde": "municionar",
    "municionardes": "municionar",
    "municionare": "municionar",
    "municionarei": "municionar",
    "municionareis": "municionar",
    "municionarem": "municionar",
    "municionaremos": "municionar",
    "municionares": "municionar",
    "municionaria": "municionar",
    "municionariam": "municionar",
    "municionarias": "municionar",
    "municionarmo": "municionar",
    "municionarmos": "municionar",
    "municionará": "municionar",
    "municionarás": "municionar",
    "municionarão": "municionar",
    "municionaríamos": "municionar",
    "municionaríeis": "municionar",
    "municionas": "municionar",
    "municionasse": "municionar",
    "municionassem": "municionar",
    "municionasses": "municionar",
    "municionaste": "municionar",
    "municionastes": "municionar",
    "municionava": "municionar",
    "municionavam": "municionar",
    "municionavas": "municionar",
    "municione": "municionar",
    "municionei": "municionar",
    "municioneis": "municionar",
    "municionem": "municionar",
    "municionemo": "municionar",
    "municionemos": "municionar",
    "municiones": "municionar",
    "municiono": "municionar",
    "municionou": "municionar",
    "municioná": "municionar",
    "municionámo": "municionar",
    "municionámos": "municionar",
    "municionáramo": "municionar",
    "municionáramos": "municionar",
    "municionárei": "municionar",
    "municionáreis": "municionar",
    "municionária": "municionário",
    "municionárias": "municionário",
    "municionários": "municionário",
    "municionásseis": "municionar",
    "municionássemos": "municionar",
    "municionávamo": "municionar",
    "municionávamos": "municionar",
    "municionávei": "municionar",
    "municionáveis": "municionar",
    "municiou": "municiar",
    "municipais": "municipal",
    "municipalidades": "municipalidade",
    "municipalismos": "municipalismo",
    "municipalistas": "municipalista",
    "municipaliza": "municipalizar",
    "municipalizada": "municipalizar",
    "municipalizadas": "municipalizar",
    "municipalizado": "municipalizar",
    "municipalizados": "municipalizar",
    "municipalizai": "municipalizar",
    "municipalizais": "municipalizar",
    "municipalizam": "municipalizar",
    "municipalizamo": "municipalizar",
    "municipalizamos": "municipalizar",
    "municipalizando": "municipalizar",
    "municipalizara": "municipalizar",
    "municipalizaram": "municipalizar",
    "municipalizaras": "municipalizar",
    "municipalizarde": "municipalizar",
    "municipalizardes": "municipalizar",
    "municipalizare": "municipalizar",
    "municipalizarei": "municipalizar",
    "municipalizareis": "municipalizar",
    "municipalizarem": "municipalizar",
    "municipalizaremos": "municipalizar",
    "municipalizares": "municipalizar",
    "municipalizaria": "municipalizar",
    "municipalizariam": "municipalizar",
    "municipalizarias": "municipalizar",
    "municipalizarmo": "municipalizar",
    "municipalizarmos": "municipalizar",
    "municipalizará": "municipalizar",
    "municipalizarás": "municipalizar",
    "municipalizarão": "municipalizar",
    "municipalizaríamos": "municipalizar",
    "municipalizaríeis": "municipalizar",
    "municipalizas": "municipalizar",
    "municipalizasse": "municipalizar",
    "municipalizassem": "municipalizar",
    "municipalizasses": "municipalizar",
    "municipalizaste": "municipalizar",
    "municipalizastes": "municipalizar",
    "municipalizava": "municipalizar",
    "municipalizavam": "municipalizar",
    "municipalizavas": "municipalizar",
    "municipalizações": "municipalização",
    "municipalize": "municipalizar",
    "municipalizei": "municipalizar",
    "municipalizeis": "municipalizar",
    "municipalizem": "municipalizar",
    "municipalizemo": "municipalizar",
    "municipalizemos": "municipalizar",
    "municipalizes": "municipalizar",
    "municipalizo": "municipalizar",
    "municipalizou": "municipalizar",
    "municipalizá": "municipalizar",
    "municipalizámo": "municipalizar",
    "municipalizámos": "municipalizar",
    "municipalizáramo": "municipalizar",
    "municipalizáramos": "municipalizar",
    "municipalizárei": "municipalizar",
    "municipalizáreis": "municipalizar",
    "municipalizásseis": "municipalizar",
    "municipalizássemos": "municipalizar",
    "municipalizávamo": "municipalizar",
    "municipalizávamos": "municipalizar",
    "municipalizávei": "municipalizar",
    "municipalizáveis": "municipalizável",
    "municiá": "municiar",
    "municiámo": "municiar",
    "municiámos": "municiar",
    "municiáramo": "municiar",
    "municiáramos": "municiar",
    "municiárei": "municiar",
    "municiáreis": "municiar",
    "municiásseis": "municiar",
    "municiássemos": "municiar",
    "municiávamo": "municiar",
    "municiávamos": "municiar",
    "municiávei": "municiar",
    "municiáveis": "municiar",
    "municípios": "município",
    "munida": "munir",
    "munidas": "munir",
    "munido": "munir",
    "munidos": "munir",
    "munificentes": "munificente",
    "munificências": "munificência",
    "munimo": "munir",
    "munimos": "munir",
    "munindo": "munir",
    "munira": "munir",
    "muniram": "munir",
    "muniras": "munir",
    "munirde": "munir",
    "munirdes": "munir",
    "munire": "munir",
    "munirei": "munir",
    "munireis": "munir",
    "munirem": "munir",
    "muniremos": "munir",
    "munires": "munir",
    "muniria": "munir",
    "muniriam": "munir",
    "munirias": "munir",
    "munirmo": "munir",
    "munirmos": "munir",
    "munirá": "munir",
    "munirás": "munir",
    "munirão": "munir",
    "muniríamos": "munir",
    "muniríeis": "munir",
    "munis": "munir",
    "munisse": "munir",
    "munissem": "munir",
    "munisses": "munir",
    "muniste": "munir",
    "munistes": "munir",
    "muniu": "munir",
    "munições": "munição",
    "munja": "mungir",
    "munjais": "mungir",
    "munjam": "mungir",
    "munjamo": "mungir",
    "munjamos": "mungir",
    "munjas": "mungir",
    "munjo": "mungir",
    "muno": "munir",
    "munqua": "munquir",
    "munquais": "munquir",
    "munquam": "munquir",
    "munquamo": "munquir",
    "munquamos": "munquir",
    "munquas": "munquir",
    "munque": "munquir",
    "munquem": "munquir",
    "munques": "munquir",
    "munqui": "munquir",
    "munquia": "munquir",
    "munquiam": "munquir",
    "munquias": "munquir",
    "munquida": "munquir",
    "munquidas": "munquir",
    "munquido": "munquir",
    "munquidos": "munquir",
    "munquimo": "munquir",
    "munquimos": "munquir",
    "munquindo": "munquir",
    "munquira": "munquir",
    "munquiram": "munquir",
    "munquiras": "munquir",
    "munquirdes": "munquir",
    "munquirei": "munquir",
    "munquireis": "munquir",
    "munquirem": "munquir",
    "munquiremos": "munquir",
    "munquires": "munquir",
    "munquiria": "munquir",
    "munquiriam": "munquir",
    "munquirias": "munquir",
    "munquirmo": "munquir",
    "munquirmos": "munquir",
    "munquirá": "munquir",
    "munquirás": "munquir",
    "munquirão": "munquir",
    "munquiríamos": "munquir",
    "munquiríeis": "munquir",
    "munquis": "munquir",
    "munquisse": "munquir",
    "munquissem": "munquir",
    "munquisses": "munquir",
    "munquiste": "munquir",
    "munquistes": "munquir",
    "munquiu": "munquir",
    "munquo": "munquir",
    "munquíamo": "munquir",
    "munquíamos": "munquir",
    "munquíeis": "munquir",
    "munquíramo": "munquir",
    "munquíramos": "munquir",
    "munquíreis": "munquir",
    "munquísseis": "munquir",
    "munquíssemos": "munquir",
    "muníamo": "munir",
    "muníamos": "munir",
    "munícios": "munício",
    "munícipes": "munícipe",
    "muníei": "munir",
    "muníeis": "munir",
    "munífica": "munífico",
    "muníficas": "munífico",
    "muníficos": "munífico",
    "muníramo": "munir",
    "muníramos": "munir",
    "munírei": "munir",
    "muníreis": "munir",
    "munísseis": "munir",
    "muníssemos": "munir",
    "mupandas": "mupanda",
    "mupeques": "mupeque",
    "mupondos": "mupondo",
    "mura": "murar",
    "murada": "murar",
    "muradais": "muradal",
    "muradas": "murar",
    "murado": "murar",
    "muradora": "murador",
    "muradoras": "murador",
    "muradores": "murador",
    "murados": "murar",
    "muradouros": "muradouro",
    "murai": "murar",
    "murais": "murar",
    "muralha": "muralhar",
    "muralhada": "muralhar",
    "muralhadas": "muralhar",
    "muralhado": "muralhar",
    "muralhados": "muralhar",
    "muralhai": "muralhar",
    "muralhais": "muralhar",
    "muralham": "muralhar",
    "muralhamo": "muralhar",
    "muralhamos": "muralhar",
    "muralhando": "muralhar",
    "muralhara": "muralhar",
    "muralharam": "muralhar",
    "muralharas": "muralhar",
    "muralharde": "muralhar",
    "muralhardes": "muralhar",
    "muralhare": "muralhar",
    "muralharei": "muralhar",
    "muralhareis": "muralhar",
    "muralharem": "muralhar",
    "muralharemos": "muralhar",
    "muralhares": "muralhar",
    "muralharia": "muralhar",
    "muralhariam": "muralhar",
    "muralharias": "muralhar",
    "muralharmo": "muralhar",
    "muralharmos": "muralhar",
    "muralhará": "muralhar",
    "muralharás": "muralhar",
    "muralharão": "muralhar",
    "muralharíamos": "muralhar",
    "muralharíeis": "muralhar",
    "muralhas": "muralhar",
    "muralhasse": "muralhar",
    "muralhassem": "muralhar",
    "muralhasses": "muralhar",
    "muralhaste": "muralhar",
    "muralhastes": "muralhar",
    "muralhava": "muralhar",
    "muralhavam": "muralhar",
    "muralhavas": "muralhar",
    "muralhe": "muralhar",
    "muralhei": "muralhar",
    "muralheis": "muralhar",
    "muralhem": "muralhar",
    "muralhemo": "muralhar",
    "muralhemos": "muralhar",
    "muralhes": "muralhar",
    "muralho": "muralhar",
    "muralhou": "muralhar",
    "muralhá": "muralhar",
    "muralhámo": "muralhar",
    "muralhámos": "muralhar",
    "muralháramo": "muralhar",
    "muralháramos": "muralhar",
    "muralhárei": "muralhar",
    "muralháreis": "muralhar",
    "muralhásseis": "muralhar",
    "muralhássemos": "muralhar",
    "muralhávamo": "muralhar",
    "muralhávamos": "muralhar",
    "muralhávei": "muralhar",
    "muralháveis": "muralhável",
    "muralismos": "muralismo",
    "muram": "murar",
    "muramentos": "muramento",
    "muramo": "murar",
    "muramos": "murar",
    "murando": "murar",
    "murara": "murar",
    "muraram": "murar",
    "muraras": "murar",
    "murarde": "murar",
    "murardes": "murar",
    "murare": "murar",
    "murarei": "murar",
    "murareis": "murar",
    "murarem": "murar",
    "muraremos": "murar",
    "murares": "murar",
    "muraria": "murar",
    "murariam": "murar",
    "murarias": "murar",
    "murarmo": "murar",
    "murarmos": "murar",
    "murará": "murar",
    "murarás": "murar",
    "murarão": "murar",
    "muraríamos": "murar",
    "muraríeis": "murar",
    "muras": "murar",
    "murasse": "murar",
    "murassem": "murar",
    "murasses": "murar",
    "muraste": "murar",
    "murastes": "murar",
    "murava": "murar",
    "muravam": "murar",
    "muravas": "murar",
    "murceira": "murceiro",
    "murceiras": "murceiro",
    "murceiros": "murceiro",
    "murcha": "murcho",
    "murchada": "murchar",
    "murchadas": "murchar",
    "murchado": "murchar",
    "murchados": "murchar",
    "murchai": "murchar",
    "murchais": "murchar",
    "murcham": "murchar",
    "murchamentos": "murchamento",
    "murchamo": "murchar",
    "murchamos": "murchar",
    "murchando": "murchar",
    "murchara": "murchar",
    "murcharam": "murchar",
    "murcharas": "murchar",
    "murcharde": "murchar",
    "murchardes": "murchar",
    "murchare": "murchar",
    "murcharei": "murchar",
    "murchareis": "murchar",
    "murcharem": "murchar",
    "murcharemos": "murchar",
    "murchares": "murchar",
    "murcharia": "murchar",
    "murchariam": "murchar",
    "murcharias": "murchar",
    "murcharmo": "murchar",
    "murcharmos": "murchar",
    "murchará": "murchar",
    "murcharás": "murchar",
    "murcharão": "murchar",
    "murcharíamos": "murchar",
    "murcharíeis": "murchar",
    "murchas": "murcho",
    "murchasse": "murchar",
    "murchassem": "murchar",
    "murchasses": "murchar",
    "murchaste": "murchar",
    "murchastes": "murchar",
    "murchava": "murchar",
    "murchavam": "murchar",
    "murchavas": "murchar",
    "murche": "murchar",
    "murchece": "murchecer",
    "murchecei": "murchecer",
    "murcheceis": "murchecer",
    "murchecem": "murchecer",
    "murchecemo": "murchecer",
    "murchecemos": "murchecer",
    "murchecendo": "murchecer",
    "murchecera": "murchecer",
    "murcheceram": "murchecer",
    "murcheceras": "murchecer",
    "murchecerde": "murchecer",
    "murchecerdes": "murchecer",
    "murchecere": "murchecer",
    "murchecerei": "murchecer",
    "murchecereis": "murchecer",
    "murchecerem": "murchecer",
    "murcheceremos": "murchecer",
    "murcheceres": "murchecer",
    "murcheceria": "murchecer",
    "murcheceriam": "murchecer",
    "murchecerias": "murchecer",
    "murchecermo": "murchecer",
    "murchecermos": "murchecer",
    "murchecerá": "murchecer",
    "murchecerás": "murchecer",
    "murchecerão": "murchecer",
    "murcheceríamos": "murchecer",
    "murcheceríeis": "murchecer",
    "murcheces": "murchecer",
    "murchecesse": "murchecer",
    "murchecessem": "murchecer",
    "murchecesses": "murchecer",
    "murcheceste": "murchecer",
    "murchecestes": "murchecer",
    "murcheceu": "murchecer",
    "murcheci": "murchecer",
    "murchecia": "murchecer",
    "murcheciam": "murchecer",
    "murchecias": "murchecer",
    "murchecida": "murchecer",
    "murchecidas": "murchecer",
    "murchecido": "murchecer",
    "murchecidos": "murchecer",
    "murchecê": "murchecer",
    "murchecêramo": "murchecer",
    "murchecêramos": "murchecer",
    "murchecêrei": "murchecer",
    "murchecêreis": "murchecer",
    "murchecêsseis": "murchecer",
    "murchecêssemos": "murchecer",
    "murchecíamo": "murchecer",
    "murchecíamos": "murchecer",
    "murchecíei": "murchecer",
    "murchecíeis": "murchecer",
    "murchei": "murchar",
    "murcheis": "murchar",
    "murchem": "murchar",
    "murchemo": "murchar",
    "murchemos": "murchar",
    "murches": "murchar",
    "murcheça": "murchecer",
    "murcheçais": "murchecer",
    "murcheçam": "murchecer",
    "murcheçamo": "murchecer",
    "murcheçamos": "murchecer",
    "murcheças": "murchecer",
    "murcheço": "murchecer",
    "murchidões": "murchidão",
    "murchinha": "murcho",
    "murchinhas": "murcho",
    "murchinho": "murcho",
    "murchinhos": "murcho",
    "murchita": "murcho",
    "murchitas": "murcho",
    "murchito": "murcho",
    "murchitos": "murcho",
    "murcho": "murchar",
    "murchos": "murcho",
    "murchou": "murchar",
    "murchá": "murchar",
    "murchámo": "murchar",
    "murchámos": "murchar",
    "murcháramo": "murchar",
    "murcháramos": "murchar",
    "murchárei": "murchar",
    "murcháreis": "murchar",
    "murchásseis": "murchar",
    "murchássemos": "murchar",
    "murchávamo": "murchar",
    "murchávamos": "murchar",
    "murchávei": "murchar",
    "murcháveis": "murchar",
    "murchíssima": "murcho",
    "murchíssimas": "murcho",
    "murchíssimo": "murcho",
    "murchíssimos": "murcho",
    "murciana": "murciano",
    "murcianas": "murciano",
    "murcianos": "murciano",
    "mure": "murar",
    "murei": "murar",
    "mureiras": "mureira",
    "mureis": "murar",
    "murelos": "murelo",
    "murem": "murar",
    "muremo": "murar",
    "muremos": "murar",
    "murenídeos": "murenídeo",
    "mures": "murar",
    "mureza": "murezo",
    "murezas": "murezo",
    "murezos": "murezo",
    "murfelas": "murfela",
    "murganhos": "murganho",
    "muricidas": "muricida",
    "muricídeos": "muricídeo",
    "murifelas": "murifela",
    "murina": "murino",
    "murinas": "murino",
    "murinho": "muro",
    "murinhos": "muro",
    "murinos": "murino",
    "murito": "muro",
    "muritos": "muro",
    "muriática": "muriático",
    "muriáticas": "muriático",
    "muriáticos": "muriático",
    "murmulha": "murmulhar",
    "murmulhada": "murmulhar",
    "murmulhadas": "murmulhar",
    "murmulhado": "murmulhar",
    "murmulhados": "murmulhar",
    "murmulhai": "murmulhar",
    "murmulhais": "murmulhar",
    "murmulham": "murmulhar",
    "murmulhamo": "murmulhar",
    "murmulhamos": "murmulhar",
    "murmulhando": "murmulhar",
    "murmulhantes": "murmulhante",
    "murmulhara": "murmulhar",
    "murmulharam": "murmulhar",
    "murmulharas": "murmulhar",
    "murmulhardes": "murmulhar",
    "murmulharei": "murmulhar",
    "murmulhareis": "murmulhar",
    "murmulharem": "murmulhar",
    "murmulharemos": "murmulhar",
    "murmulhares": "murmulhar",
    "murmulharia": "murmulhar",
    "murmulhariam": "murmulhar",
    "murmulharias": "murmulhar",
    "murmulharmo": "murmulhar",
    "murmulharmos": "murmulhar",
    "murmulhará": "murmulhar",
    "murmulharás": "murmulhar",
    "murmulharão": "murmulhar",
    "murmulharíamos": "murmulhar",
    "murmulharíeis": "murmulhar",
    "murmulhas": "murmulhar",
    "murmulhasse": "murmulhar",
    "murmulhassem": "murmulhar",
    "murmulhasses": "murmulhar",
    "murmulhaste": "murmulhar",
    "murmulhastes": "murmulhar",
    "murmulhava": "murmulhar",
    "murmulhavam": "murmulhar",
    "murmulhavas": "murmulhar",
    "murmulhe": "murmulhar",
    "murmulhei": "murmulhar",
    "murmulheis": "murmulhar",
    "murmulhem": "murmulhar",
    "murmulhemo": "murmulhar",
    "murmulhemos": "murmulhar",
    "murmulhes": "murmulhar",
    "murmulho": "murmulhar",
    "murmulhos": "murmulho",
    "murmulhou": "murmulhar",
    "murmulhámo": "murmulhar",
    "murmulhámos": "murmulhar",
    "murmulháramo": "murmulhar",
    "murmulháramos": "murmulhar",
    "murmulháreis": "murmulhar",
    "murmulhásseis": "murmulhar",
    "murmulhássemos": "murmulhar",
    "murmulhávamo": "murmulhar",
    "murmulhávamos": "murmulhar",
    "murmulháveis": "murmulhar",
    "murmura": "murmurar",
    "murmurada": "murmurar",
    "murmuradas": "murmurar",
    "murmuradeiras": "murmuradeira",
    "murmurado": "murmurar",
    "murmuradora": "murmurador",
    "murmuradoras": "murmurador",
    "murmuradores": "murmurador",
    "murmurados": "murmurar",
    "murmurai": "murmurar",
    "murmurais": "murmurar",
    "murmuram": "murmurar",
    "murmuramo": "murmurar",
    "murmuramos": "murmurar",
    "murmurando": "murmurar",
    "murmurantes": "murmurante",
    "murmurara": "murmurar",
    "murmuraram": "murmurar",
    "murmuraras": "murmurar",
    "murmurarde": "murmurar",
    "murmurardes": "murmurar",
    "murmurare": "murmurar",
    "murmurarei": "murmurar",
    "murmurareis": "murmurar",
    "murmurarem": "murmurar",
    "murmuraremos": "murmurar",
    "murmurares": "murmurar",
    "murmuraria": "murmurar",
    "murmurariam": "murmurar",
    "murmurarias": "murmurar",
    "murmurarmo": "murmurar",
    "murmurarmos": "murmurar",
    "murmurará": "murmurar",
    "murmurarás": "murmurar",
    "murmurarão": "murmurar",
    "murmuraríamos": "murmurar",
    "murmuraríeis": "murmurar",
    "murmuras": "murmurar",
    "murmurasse": "murmurar",
    "murmurassem": "murmurar",
    "murmurasses": "murmurar",
    "murmuraste": "murmurar",
    "murmurastes": "murmurar",
    "murmurativa": "murmurativo",
    "murmurativas": "murmurativo",
    "murmurativos": "murmurativo",
    "murmurava": "murmurar",
    "murmuravam": "murmurar",
    "murmuravas": "murmurar",
    "murmurações": "murmuração",
    "murmure": "murmurar",
    "murmurei": "murmurar",
    "murmureis": "murmurar",
    "murmureja": "murmurejar",
    "murmurejada": "murmurejar",
    "murmurejadas": "murmurejar",
    "murmurejado": "murmurejar",
    "murmurejados": "murmurejar",
    "murmurejai": "murmurejar",
    "murmurejais": "murmurejar",
    "murmurejam": "murmurejar",
    "murmurejamo": "murmurejar",
    "murmurejamos": "murmurejar",
    "murmurejando": "murmurejar",
    "murmurejara": "murmurejar",
    "murmurejaram": "murmurejar",
    "murmurejaras": "murmurejar",
    "murmurejardes": "murmurejar",
    "murmurejarei": "murmurejar",
    "murmurejareis": "murmurejar",
    "murmurejarem": "murmurejar",
    "murmurejaremos": "murmurejar",
    "murmurejares": "murmurejar",
    "murmurejaria": "murmurejar",
    "murmurejariam": "murmurejar",
    "murmurejarias": "murmurejar",
    "murmurejarmo": "murmurejar",
    "murmurejarmos": "murmurejar",
    "murmurejará": "murmurejar",
    "murmurejarás": "murmurejar",
    "murmurejarão": "murmurejar",
    "murmurejaríamos": "murmurejar",
    "murmurejaríeis": "murmurejar",
    "murmurejas": "murmurejar",
    "murmurejasse": "murmurejar",
    "murmurejassem": "murmurejar",
    "murmurejasses": "murmurejar",
    "murmurejaste": "murmurejar",
    "murmurejastes": "murmurejar",
    "murmurejava": "murmurejar",
    "murmurejavam": "murmurejar",
    "murmurejavas": "murmurejar",
    "murmureje": "murmurejar",
    "murmurejei": "murmurejar",
    "murmurejeis": "murmurejar",
    "murmurejem": "murmurejar",
    "murmurejemo": "murmurejar",
    "murmurejemos": "murmurejar",
    "murmurejes": "murmurejar",
    "murmurejo": "murmurejar",
    "murmurejos": "murmurejo",
    "murmurejou": "murmurejar",
    "murmurejámo": "murmurejar",
    "murmurejámos": "murmurejar",
    "murmurejáramo": "murmurejar",
    "murmurejáramos": "murmurejar",
    "murmurejáreis": "murmurejar",
    "murmurejásseis": "murmurejar",
    "murmurejássemos": "murmurejar",
    "murmurejávamo": "murmurejar",
    "murmurejávamos": "murmurejar",
    "murmurejáveis": "murmurejar",
    "murmurem": "murmurar",
    "murmuremo": "murmurar",
    "murmuremos": "murmurar",
    "murmures": "murmurar",
    "murmurinha": "murmurinhar",
    "murmurinhada": "murmurinhar",
    "murmurinhadas": "murmurinhar",
    "murmurinhado": "murmurinhar",
    "murmurinhados": "murmurinhar",
    "murmurinhai": "murmurinhar",
    "murmurinhais": "murmurinhar",
    "murmurinham": "murmurinhar",
    "murmurinhamo": "murmurinhar",
    "murmurinhamos": "murmurinhar",
    "murmurinhando": "murmurinhar",
    "murmurinhara": "murmurinhar",
    "murmurinharam": "murmurinhar",
    "murmurinharas": "murmurinhar",
    "murmurinhardes": "murmurinhar",
    "murmurinharei": "murmurinhar",
    "murmurinhareis": "murmurinhar",
    "murmurinharem": "murmurinhar",
    "murmurinharemos": "murmurinhar",
    "murmurinhares": "murmurinhar",
    "murmurinharia": "murmurinhar",
    "murmurinhariam": "murmurinhar",
    "murmurinharias": "murmurinhar",
    "murmurinharmo": "murmurinhar",
    "murmurinharmos": "murmurinhar",
    "murmurinhará": "murmurinhar",
    "murmurinharás": "murmurinhar",
    "murmurinharão": "murmurinhar",
    "murmurinharíamos": "murmurinhar",
    "murmurinharíeis": "murmurinhar",
    "murmurinhas": "murmurinhar",
    "murmurinhasse": "murmurinhar",
    "murmurinhassem": "murmurinhar",
    "murmurinhasses": "murmurinhar",
    "murmurinhaste": "murmurinhar",
    "murmurinhastes": "murmurinhar",
    "murmurinhava": "murmurinhar",
    "murmurinhavam": "murmurinhar",
    "murmurinhavas": "murmurinhar",
    "murmurinhe": "murmurinhar",
    "murmurinhei": "murmurinhar",
    "murmurinheis": "murmurinhar",
    "murmurinhem": "murmurinhar",
    "murmurinhemo": "murmurinhar",
    "murmurinhemos": "murmurinhar",
    "murmurinhes": "murmurinhar",
    "murmurinho": "murmurinhar",
    "murmurinhos": "murmurinho",
    "murmurinhou": "murmurinhar",
    "murmurinhámo": "murmurinhar",
    "murmurinhámos": "murmurinhar",
    "murmurinháramo": "murmurinhar",
    "murmurinháramos": "murmurinhar",
    "murmurinháreis": "murmurinhar",
    "murmurinhásseis": "murmurinhar",
    "murmurinhássemos": "murmurinhar",
    "murmurinhávamo": "murmurinhar",
    "murmurinhávamos": "murmurinhar",
    "murmurinháveis": "murmurinhar",
    "murmuro": "murmurar",
    "murmurosa": "murmuroso",
    "murmurosas": "murmuroso",
    "murmurosos": "murmuroso",
    "murmurou": "murmurar",
    "murmurá": "murmurar",
    "murmurámo": "murmurar",
    "murmurámos": "murmurar",
    "murmuráramo": "murmurar",
    "murmuráramos": "murmurar",
    "murmurárei": "murmurar",
    "murmuráreis": "murmurar",
    "murmurásseis": "murmurar",
    "murmurássemos": "murmurar",
    "murmurávamo": "murmurar",
    "murmurávamos": "murmurar",
    "murmurávei": "murmurar",
    "murmuráveis": "murmurar",
    "murmúrios": "murmúrio",
    "muro": "murar",
    "muros": "muro",
    "murou": "murar",
    "murozinho": "muro",
    "murozinhos": "muro",
    "murozito": "muro",
    "murozitos": "muro",
    "murras": "murra",
    "murraças": "murraça",
    "murrinho": "murro",
    "murrinhos": "murro",
    "murrito": "murro",
    "murritos": "murro",
    "murros": "murro",
    "murrões": "murrão",
    "murtais": "murtal",
    "murtas": "murta",
    "murtefuges": "murtefuge",
    "murteiras": "murteira",
    "murteiros": "murteiro",
    "murtinheiras": "murtinheira",
    "murtinhos": "murtinho",
    "murtoseira": "murtoseiro",
    "murtoseiras": "murtoseiro",
    "murtoseiros": "murtoseiro",
    "murucutus": "murucutu",
    "mururus": "mururu",
    "murus": "muru",
    "murzela": "murzelo",
    "murzelas": "murzelo",
    "murzelos": "murzelo",
    "murzás": "murzá",
    "murá": "murar",
    "murámo": "murar",
    "murámos": "murar",
    "muráramo": "murar",
    "muráramos": "murar",
    "murárei": "murar",
    "muráreis": "murar",
    "murária": "murário",
    "murárias": "murário",
    "murários": "murário",
    "murásseis": "murar",
    "murássemos": "murar",
    "murávamo": "murar",
    "murávamos": "murar",
    "murávei": "murar",
    "muráveis": "murável",
    "murças": "murça",
    "murénidas": "murénida",
    "murícidas": "murícida",
    "murícolas": "murícola",
    "murídeos": "murídeo",
    "mus": "mu",
    "musais": "musal",
    "musaranhos": "musaranho",
    "musas": "musa",
    "muscardinas": "muscardina",
    "muscardínica": "muscardínico",
    "muscardínicas": "muscardínico",
    "muscardínicos": "muscardínico",
    "muscarinas": "muscarina",
    "muscicapídeos": "muscicapídeo",
    "muscicápidas": "muscicápida",
    "muscosa": "muscoso",
    "muscosas": "muscoso",
    "muscosos": "muscoso",
    "musculada": "musculado",
    "musculadas": "musculado",
    "musculadinha": "musculado",
    "musculadinhas": "musculado",
    "musculadinho": "musculado",
    "musculadinhos": "musculado",
    "musculadita": "musculado",
    "musculaditas": "musculado",
    "musculadito": "musculado",
    "musculaditos": "musculado",
    "musculados": "musculado",
    "musculadíssima": "musculado",
    "musculadíssimas": "musculado",
    "musculadíssimo": "musculado",
    "musculadíssimos": "musculado",
    "musculares": "muscular",
    "musculaturas": "musculatura",
    "musculações": "musculação",
    "musculinas": "musculina",
    "musculomembranosa": "musculomembranoso",
    "musculomembranosas": "musculomembranoso",
    "musculomembranosos": "musculomembranoso",
    "musculosa": "musculoso",
    "musculosas": "musculoso",
    "musculosidades": "musculosidade",
    "musculosos": "musculoso",
    "muscícolas": "muscícola",
    "muscídeos": "muscídeo",
    "muscínea": "muscíneo",
    "muscíneas": "muscíneo",
    "muscíneos": "muscíneo",
    "muscívora": "muscívoro",
    "muscívoras": "muscívoro",
    "muscívoros": "muscívoro",
    "muscóides": "muscóide",
    "museografias": "museografia",
    "museográfica": "museográfico",
    "museográficas": "museográfico",
    "museográficos": "museográfico",
    "museologias": "museologia",
    "museologistas": "museologista",
    "museológica": "museológico",
    "museológicas": "museológico",
    "museológicos": "museológico",
    "museotecnias": "museotecnia",
    "musetas": "museta",
    "museus": "museu",
    "museógrafa": "museógrafo",
    "museógrafas": "museógrafo",
    "museógrafos": "museógrafo",
    "museóloga": "museólogo",
    "museólogas": "museólogo",
    "museólogos": "museólogo",
    "musga": "musgo",
    "musgada": "musgar",
    "musgadas": "musgar",
    "musgado": "musgar",
    "musgados": "musgar",
    "musgai": "musgar",
    "musgais": "musgar",
    "musgam": "musgar",
    "musgamo": "musgar",
    "musgamos": "musgar",
    "musgando": "musgar",
    "musgara": "musgar",
    "musgaram": "musgar",
    "musgaras": "musgar",
    "musgarde": "musgar",
    "musgardes": "musgar",
    "musgare": "musgar",
    "musgarei": "musgar",
    "musgareis": "musgar",
    "musgarem": "musgar",
    "musgaremos": "musgar",
    "musgares": "musgar",
    "musgaria": "musgar",
    "musgariam": "musgar",
    "musgarias": "musgar",
    "musgarmo": "musgar",
    "musgarmos": "musgar",
    "musgará": "musgar",
    "musgarás": "musgar",
    "musgarão": "musgar",
    "musgaríamos": "musgar",
    "musgaríeis": "musgar",
    "musgas": "musgo",
    "musgasse": "musgar",
    "musgassem": "musgar",
    "musgasses": "musgar",
    "musgaste": "musgar",
    "musgastes": "musgar",
    "musgava": "musgar",
    "musgavam": "musgar",
    "musgavas": "musgar",
    "musgo": "musgar",
    "musgos": "musgo",
    "musgosa": "musgoso",
    "musgosas": "musgoso",
    "musgosos": "musgoso",
    "musgou": "musgar",
    "musgue": "musgar",
    "musguei": "musgar",
    "musgueis": "musgar",
    "musguem": "musgar",
    "musguemo": "musgar",
    "musguemos": "musgar",
    "musguenta": "musguento",
    "musguentas": "musguento",
    "musguentos": "musguento",
    "musgues": "musgar",
    "musgá": "musgar",
    "musgámo": "musgar",
    "musgámos": "musgar",
    "musgáramo": "musgar",
    "musgáramos": "musgar",
    "musgárei": "musgar",
    "musgáreis": "musgar",
    "musgásseis": "musgar",
    "musgássemos": "musgar",
    "musgávamo": "musgar",
    "musgávamos": "musgar",
    "musgávei": "musgar",
    "musgáveis": "musgar",
    "musica": "musicar",
    "musicada": "musicar",
    "musicadas": "musicar",
    "musicado": "musicar",
    "musicados": "musicar",
    "musicais": "musicar",
    "musicalidades": "musicalidade",
    "musicam": "musicar",
    "musicamo": "musicar",
    "musicamos": "musicar",
    "musicando": "musicar",
    "musicantes": "musicante",
    "musicara": "musicar",
    "musicaram": "musicar",
    "musicaras": "musicar",
    "musicardes": "musicar",
    "musicarei": "musicar",
    "musicareis": "musicar",
    "musicarem": "musicar",
    "musicaremos": "musicar",
    "musicares": "musicar",
    "musicaria": "musicar",
    "musicariam": "musicar",
    "musicarias": "musicar",
    "musicarmo": "musicar",
    "musicarmos": "musicar",
    "musicará": "musicar",
    "musicarás": "musicar",
    "musicarão": "musicar",
    "musicaríamos": "musicar",
    "musicaríeis": "musicar",
    "musicas": "musicar",
    "musicasse": "musicar",
    "musicassem": "musicar",
    "musicasses": "musicar",
    "musicaste": "musicar",
    "musicastes": "musicar",
    "musicastros": "musicastro",
    "musicatas": "musicata",
    "musicava": "musicar",
    "musicavam": "musicar",
    "musicavas": "musicar",
    "musicistas": "musicista",
    "musico": "musicar",
    "musicofilias": "musicofilia",
    "musicofobias": "musicofobia",
    "musicografias": "musicografia",
    "musicologias": "musicologia",
    "musicológica": "musicológico",
    "musicológicas": "musicológico",
    "musicológicos": "musicológico",
    "musicomanias": "musicomania",
    "musicomaníaca": "musicomaníaco",
    "musicomaníacas": "musicomaníaco",
    "musicomaníacos": "musicomaníaco",
    "musicoterapias": "musicoterapia",
    "musicoterapêutas": "musicoterapêuta",
    "musicou": "musicar",
    "musicámo": "musicar",
    "musicámos": "musicar",
    "musicáramo": "musicar",
    "musicáramos": "musicar",
    "musicáreis": "musicar",
    "musicásseis": "musicar",
    "musicássemos": "musicar",
    "musicávamo": "musicar",
    "musicávamos": "musicar",
    "musicáveis": "musicável",
    "musicófila": "musicófilo",
    "musicófilas": "musicófilo",
    "musicófilos": "musicófilo",
    "musicógrafa": "musicógrafo",
    "musicógrafas": "musicógrafo",
    "musicógrafos": "musicógrafo",
    "musicóloga": "musicólogo",
    "musicólogas": "musicólogo",
    "musicólogos": "musicólogo",
    "musicómana": "musicómano",
    "musicómanas": "musicómano",
    "musicómanos": "musicómano",
    "musique": "musicar",
    "musiquei": "musicar",
    "musiqueira": "musiqueiro",
    "musiqueiras": "musiqueiro",
    "musiqueiros": "musiqueiro",
    "musiqueis": "musicar",
    "musiquem": "musicar",
    "musiquemos": "musicar",
    "musiques": "musicar",
    "musiquetas": "musiqueta",
    "musiquinha": "música",
    "musiquinhas": "música",
    "musiquins": "musiquim",
    "musiquita": "música",
    "musiquitas": "música",
    "muslema": "muslemo",
    "muslemas": "muslemo",
    "muslemias": "muslemia",
    "muslemos": "muslemo",
    "muslins": "muslim",
    "muslímica": "muslímico",
    "muslímicas": "muslímico",
    "muslímicos": "muslímico",
    "musofagídeos": "musofagídeo",
    "musofágidas": "musofágida",
    "mussambas": "mussamba",
    "musselinas": "musselina",
    "musseques": "musseque",
    "musses": "musse",
    "mussita": "mussitar",
    "mussitada": "mussitar",
    "mussitadas": "mussitar",
    "mussitado": "mussitar",
    "mussitados": "mussitar",
    "mussitai": "mussitar",
    "mussitais": "mussitar",
    "mussitam": "mussitar",
    "mussitamo": "mussitar",
    "mussitamos": "mussitar",
    "mussitando": "mussitar",
    "mussitara": "mussitar",
    "mussitaram": "mussitar",
    "mussitaras": "mussitar",
    "mussitardes": "mussitar",
    "mussitarei": "mussitar",
    "mussitareis": "mussitar",
    "mussitarem": "mussitar",
    "mussitaremos": "mussitar",
    "mussitares": "mussitar",
    "mussitaria": "mussitar",
    "mussitariam": "mussitar",
    "mussitarias": "mussitar",
    "mussitarmo": "mussitar",
    "mussitarmos": "mussitar",
    "mussitará": "mussitar",
    "mussitarás": "mussitar",
    "mussitarão": "mussitar",
    "mussitaríamos": "mussitar",
    "mussitaríeis": "mussitar",
    "mussitas": "mussitar",
    "mussitasse": "mussitar",
    "mussitassem": "mussitar",
    "mussitasses": "mussitar",
    "mussitaste": "mussitar",
    "mussitastes": "mussitar",
    "mussitava": "mussitar",
    "mussitavam": "mussitar",
    "mussitavas": "mussitar",
    "mussitações": "mussitação",
    "mussite": "mussitar",
    "mussitei": "mussitar",
    "mussiteis": "mussitar",
    "mussitem": "mussitar",
    "mussitemo": "mussitar",
    "mussitemos": "mussitar",
    "mussites": "mussitar",
    "mussito": "mussitar",
    "mussitou": "mussitar",
    "mussitámo": "mussitar",
    "mussitámos": "mussitar",
    "mussitáramo": "mussitar",
    "mussitáramos": "mussitar",
    "mussitáreis": "mussitar",
    "mussitásseis": "mussitar",
    "mussitássemos": "mussitar",
    "mussitávamo": "mussitar",
    "mussitávamos": "mussitar",
    "mussitáveis": "mussitar",
    "mussurungos": "mussurungo",
    "mustelina": "mustelino",
    "mustelinas": "mustelino",
    "mustelinos": "mustelino",
    "mustelídea": "mustelídeo",
    "mustelídeas": "mustelídeo",
    "mustelídeos": "mustelídeo",
    "mustélidas": "mustélida",
    "mustímetros": "mustímetro",
    "musácea": "musáceo",
    "musáceas": "musáceo",
    "musáceos": "musáceo",
    "muságetas": "muságeta",
    "musófagos": "musófago",
    "mutabilidades": "mutabilidade",
    "mutacionismos": "mutacionismo",
    "mutacismos": "mutacismo",
    "mutagéneses": "mutagénese",
    "mutantes": "mutante",
    "mutatória": "mutatório",
    "mutatórias": "mutatório",
    "mutatórios": "mutatório",
    "mutações": "mutação",
    "mutelinas": "mutelina",
    "mutila": "mutilar",
    "mutilada": "mutilar",
    "mutiladas": "mutilar",
    "mutilado": "mutilar",
    "mutiladora": "mutilador",
    "mutiladoras": "mutilador",
    "mutiladores": "mutilador",
    "mutilados": "mutilar",
    "mutiladíssima": "mutilado",
    "mutiladíssimas": "mutilado",
    "mutiladíssimo": "mutilado",
    "mutiladíssimos": "mutilado",
    "mutilai": "mutilar",
    "mutilais": "mutilar",
    "mutilam": "mutilar",
    "mutilamo": "mutilar",
    "mutilamos": "mutilar",
    "mutilando": "mutilar",
    "mutilara": "mutilar",
    "mutilaram": "mutilar",
    "mutilaras": "mutilar",
    "mutilarde": "mutilar",
    "mutilardes": "mutilar",
    "mutilare": "mutilar",
    "mutilarei": "mutilar",
    "mutilareis": "mutilar",
    "mutilarem": "mutilar",
    "mutilaremos": "mutilar",
    "mutilares": "mutilar",
    "mutilaria": "mutilar",
    "mutilariam": "mutilar",
    "mutilarias": "mutilar",
    "mutilarmo": "mutilar",
    "mutilarmos": "mutilar",
    "mutilará": "mutilar",
    "mutilarás": "mutilar",
    "mutilarão": "mutilar",
    "mutilaríamos": "mutilar",
    "mutilaríeis": "mutilar",
    "mutilas": "mutilar",
    "mutilasse": "mutilar",
    "mutilassem": "mutilar",
    "mutilasses": "mutilar",
    "mutilaste": "mutilar",
    "mutilastes": "mutilar",
    "mutilava": "mutilar",
    "mutilavam": "mutilar",
    "mutilavas": "mutilar",
    "mutilações": "mutilação",
    "mutile": "mutilar",
    "mutilei": "mutilar",
    "mutileis": "mutilar",
    "mutilem": "mutilar",
    "mutilemo": "mutilar",
    "mutilemos": "mutilar",
    "mutiles": "mutilar",
    "mutilo": "mutilar",
    "mutilou": "mutilar",
    "mutilá": "mutilar",
    "mutilámo": "mutilar",
    "mutilámos": "mutilar",
    "mutiláramo": "mutilar",
    "mutiláramos": "mutilar",
    "mutilárei": "mutilar",
    "mutiláreis": "mutilar",
    "mutilásseis": "mutilar",
    "mutilássemos": "mutilar",
    "mutilávamo": "mutilar",
    "mutilávamos": "mutilar",
    "mutilávei": "mutilar",
    "mutiláveis": "mutilável",
    "mutismos": "mutismo",
    "mutua": "mutuar",
    "mutuada": "mutuar",
    "mutuadas": "mutuar",
    "mutuado": "mutuar",
    "mutuadora": "mutuador",
    "mutuadoras": "mutuador",
    "mutuadores": "mutuador",
    "mutuados": "mutuar",
    "mutuai": "mutuar",
    "mutuais": "mutuar",
    "mutualidades": "mutualidade",
    "mutualismos": "mutualismo",
    "mutualistas": "mutualista",
    "mutuam": "mutuar",
    "mutuamo": "mutuar",
    "mutuamos": "mutuar",
    "mutuando": "mutuar",
    "mutuantes": "mutuante",
    "mutuara": "mutuar",
    "mutuaram": "mutuar",
    "mutuaras": "mutuar",
    "mutuarde": "mutuar",
    "mutuardes": "mutuar",
    "mutuare": "mutuar",
    "mutuarei": "mutuar",
    "mutuareis": "mutuar",
    "mutuarem": "mutuar",
    "mutuaremos": "mutuar",
    "mutuares": "mutuar",
    "mutuaria": "mutuar",
    "mutuariam": "mutuar",
    "mutuarias": "mutuar",
    "mutuarmo": "mutuar",
    "mutuarmos": "mutuar",
    "mutuará": "mutuar",
    "mutuarás": "mutuar",
    "mutuarão": "mutuar",
    "mutuaríamos": "mutuar",
    "mutuaríeis": "mutuar",
    "mutuas": "mutuar",
    "mutuasse": "mutuar",
    "mutuassem": "mutuar",
    "mutuasses": "mutuar",
    "mutuaste": "mutuar",
    "mutuastes": "mutuar",
    "mutuatária": "mutuatário",
    "mutuatárias": "mutuatário",
    "mutuatários": "mutuatário",
    "mutuava": "mutuar",
    "mutuavam": "mutuar",
    "mutuavas": "mutuar",
    "mutuações": "mutuação",
    "mutue": "mutuar",
    "mutuei": "mutuar",
    "mutueis": "mutuar",
    "mutuem": "mutuar",
    "mutuemo": "mutuar",
    "mutuemos": "mutuar",
    "mutues": "mutuar",
    "mutulas": "mutula",
    "mutuo": "mutuar",
    "mutuou": "mutuar",
    "mutuá": "mutuar",
    "mutuámo": "mutuar",
    "mutuámos": "mutuar",
    "mutuáramo": "mutuar",
    "mutuáramos": "mutuar",
    "mutuárei": "mutuar",
    "mutuáreis": "mutuar",
    "mutuária": "mutuário",
    "mutuárias": "mutuário",
    "mutuários": "mutuário",
    "mutuásseis": "mutuar",
    "mutuássemos": "mutuar",
    "mutuávamo": "mutuar",
    "mutuávamos": "mutuar",
    "mutuávei": "mutuar",
    "mutuáveis": "mutuar",
    "mutáveis": "mutável",
    "muxaxas": "muxaxa",
    "muxingas": "muxinga",
    "muzenzes": "muzenze",
    "muzunga": "muzungo",
    "muzungas": "muzungo",
    "muzungos": "muzungo",
    "muzuzura": "muzuzuro",
    "muzuzuras": "muzuzuro",
    "muzuzuros": "muzuzuro",
    "muçulmana": "muçulmano",
    "muçulmanas": "muçulmano",
    "muçulmanismos": "muçulmanismo",
    "muçulmanos": "muçulmano",
    "muís": "muí",
    "má": "mau",
    "mácrons": "mácron",
    "máculas": "mácula",
    "mádida": "mádido",
    "mádidas": "mádido",
    "mádidos": "mádido",
    "máfias": "máfia",
    "máfica": "máfico",
    "máficas": "máfico",
    "máficos": "máfico",
    "mágica": "mágico",
    "mágicas": "mágico",
    "mágicos": "mágico",
    "mágoas": "mágoa",
    "máguas": "mágua",
    "málagas": "málaga",
    "málica": "málico",
    "málicas": "málico",
    "málicos": "málico",
    "máltases": "máltase",
    "máquinas": "máquina",
    "márcia": "márcio",
    "márcias": "márcio",
    "márcida": "márcido",
    "márcidas": "márcido",
    "márcidos": "márcido",
    "márcios": "márcio",
    "mármores": "mármore",
    "mártires": "mártir",
    "más": "mau",
    "máscaras": "máscara",
    "máscula": "másculo",
    "másculas": "másculo",
    "másculos": "másculo",
    "mássica": "mássico",
    "mássicas": "mássico",
    "mássicos": "mássico",
    "másticas": "mástica",
    "mástiques": "mástique",
    "máticos": "mático",
    "mátrias": "mátria",
    "máuseres": "máuser",
    "máxima": "máximo",
    "máximas": "máximo",
    "máximos": "máximo",
    "máxis": "máxi",
    "mândrias": "mândria",
    "mântidas": "mântida",
    "mães": "mãe",
    "mãezeira": "mãezeiro",
    "mãezeiras": "mãezeiro",
    "mãezeiros": "mãezeiro",
    "mãezinha": "pai",
    "mãezinhas": "pai",
    "mãezita": "pai",
    "mãezitas": "pai",
    "mãos": "mão",
    "mãozadas": "mãozada",
    "mãozeira": "mãozeiro",
    "mãozeiras": "mãozeiro",
    "mãozeiros": "mãozeiro",
    "mãozinha": "mão",
    "mãozinhas": "mão",
    "mãozita": "mão",
    "mãozitas": "mão",
    "mãozorras": "mãozorra",
    "mãozuda": "mãozudo",
    "mãozudas": "mãozudo",
    "mãozudos": "mãozudo",
    "média": "médio",
    "médias": "médio",
    "médica": "médico",
    "médicas": "médico",
    "médicos": "médico",
    "médios": "médio",
    "médiuns": "médium",
    "médões": "médão",
    "méis": "mel",
    "mélias": "mélia",
    "mélica": "mélico",
    "mélicas": "mélico",
    "mélicos": "mélico",
    "mélroa": "melro",
    "mélroas": "melro",
    "méltons": "mélton",
    "ménades": "ménade",
    "ménidas": "ménida",
    "mércias": "mércia",
    "méritos": "mérito",
    "mérulas": "mérula",
    "més": "mé",
    "méscias": "méscia",
    "mésica": "mésico",
    "mésicas": "mésico",
    "mésicos": "mésico",
    "métodos": "método",
    "métopas": "métopa",
    "métopes": "métope",
    "métrica": "métrico",
    "métricas": "métrico",
    "métricos": "métrico",
    "mênstruos": "mênstruo",
    "mícrons": "mícron",
    "mígalas": "mígala",
    "míldios": "míldio",
    "mílharas": "mílhara",
    "mílites": "mílite",
    "mílvios": "mílvio",
    "mímica": "mímico",
    "mímicas": "mímico",
    "mímicos": "mímico",
    "mímidas": "mímida",
    "mínguas": "míngua",
    "mínima": "mínimo",
    "mínimas": "mínimo",
    "mínimos": "mínimo",
    "mínios": "mínio",
    "míopes": "míope",
    "mírrea": "mírreo",
    "mírreas": "mírreo",
    "mírreos": "mírreo",
    "mírtea": "mírteo",
    "mírteas": "mírteo",
    "mírteos": "mírteo",
    "míscaros": "míscaro",
    "mísera": "mísero",
    "míseras": "mísero",
    "míseros": "mísero",
    "mísia": "mísio",
    "mísias": "mísio",
    "mísios": "mísio",
    "mísseis": "míssil",
    "mística": "místico",
    "místicas": "místico",
    "místicos": "místico",
    "mísulas": "mísula",
    "mítica": "mítico",
    "míticas": "mítico",
    "míticos": "mítico",
    "mítridas": "mítrida",
    "móbeis": "móbil",
    "móbiles": "móbile",
    "módica": "módico",
    "módicas": "módico",
    "módicos": "módico",
    "módulos": "módulo",
    "mógonos": "mógono",
    "mói": "moer",
    "móis": "moer",
    "mólidas": "mólida",
    "mónacos": "mónaco",
    "mónada": "mónade",
    "mónadas": "mónade",
    "mónades": "mónade",
    "mónicas": "mónica",
    "mónitas": "mónita",
    "mórbica": "mórbico",
    "mórbicas": "mórbico",
    "mórbicos": "mórbico",
    "mórbida": "mórbido",
    "mórbidas": "mórbido",
    "mórbidos": "mórbido",
    "mórfica": "mórfico",
    "mórficas": "mórfico",
    "mórficos": "mórfico",
    "mórmones": "mórmon",
    "mórulas": "mórula",
    "mós": "mó",
    "mósquidas": "mósquida",
    "móveis": "móvel",
    "móvitos": "móvito",
    "múcrons": "múcron",
    "múltipla": "múltiplo",
    "múltiplas": "múltiplo",
    "múltiplos": "múltiplo",
    "múmias": "múmia",
    "múnis": "múni",
    "múrias": "múria",
    "múrices": "múrice",
    "múridas": "múrida",
    "múrmura": "múrmuro",
    "múrmuras": "múrmuro",
    "múrmures": "múrmur",
    "múrmuros": "múrmuro",
    "múscidas": "múscida",
    "músculos": "músculo",
    "música": "músico",
    "músicas": "músico",
    "músicos": "músico",
    "mútua": "mútuo",
    "mútuas": "mútuo",
    "mútulos": "mútulo",
    "mútuos": "mútuo",
    "na": "o",
    "naba": "nabo",
    "nababa": "nababo",
    "nababas": "nababo",
    "nababesca": "nababesco",
    "nababescas": "nababesco",
    "nababescos": "nababesco",
    "nababias": "nababia",
    "nababos": "nababo",
    "nabadas": "nabada",
    "nabais": "nabal",
    "nabantina": "nabantino",
    "nabantinas": "nabantino",
    "nabantinos": "nabantino",
    "nabas": "nabo",
    "nabinhas": "nabinha",
    "nabinheiras": "nabinheira",
    "nabiçais": "nabiçal",
    "nabiças": "nabiça",
    "nablas": "nabla",
    "nablos": "nablo",
    "nabos": "nabo",
    "nabábica": "nabábico",
    "nabábicas": "nabábico",
    "nabábicos": "nabábico",
    "nabídeos": "nabídeo",
    "nacadas": "nacada",
    "nacara": "nacarar",
    "nacarada": "nacarar",
    "nacaradas": "nacarar",
    "nacarado": "nacarar",
    "nacarados": "nacarar",
    "nacarai": "nacarar",
    "nacarais": "nacarar",
    "nacaram": "nacarar",
    "nacaramo": "nacarar",
    "nacaramos": "nacarar",
    "nacarando": "nacarar",
    "nacarara": "nacarar",
    "nacararam": "nacarar",
    "nacararas": "nacarar",
    "nacararde": "nacarar",
    "nacarardes": "nacarar",
    "nacarare": "nacarar",
    "nacararei": "nacarar",
    "nacarareis": "nacarar",
    "nacararem": "nacarar",
    "nacararemos": "nacarar",
    "nacarares": "nacarar",
    "nacararia": "nacarar",
    "nacarariam": "nacarar",
    "nacararias": "nacarar",
    "nacararmo": "nacarar",
    "nacararmos": "nacarar",
    "nacarará": "nacarar",
    "nacararás": "nacarar",
    "nacararão": "nacarar",
    "nacararíamos": "nacarar",
    "nacararíeis": "nacarar",
    "nacaras": "nacarar",
    "nacarasse": "nacarar",
    "nacarassem": "nacarar",
    "nacarasses": "nacarar",
    "nacaraste": "nacarar",
    "nacarastes": "nacarar",
    "nacarava": "nacarar",
    "nacaravam": "nacarar",
    "nacaravas": "nacarar",
    "nacare": "nacarar",
    "nacarei": "nacarar",
    "nacareis": "nacarar",
    "nacarem": "nacarar",
    "nacaremo": "nacarar",
    "nacaremos": "nacarar",
    "nacares": "nacarar",
    "nacarina": "nacarino",
    "nacarinas": "nacarino",
    "nacarinos": "nacarino",
    "nacaro": "nacarar",
    "nacarou": "nacarar",
    "nacará": "nacarar",
    "nacarámo": "nacarar",
    "nacarámos": "nacarar",
    "nacaráramo": "nacarar",
    "nacaráramos": "nacarar",
    "nacarárei": "nacarar",
    "nacaráreis": "nacarar",
    "nacarásseis": "nacarar",
    "nacarássemos": "nacarar",
    "nacarávamo": "nacarar",
    "nacarávamos": "nacarar",
    "nacarávei": "nacarar",
    "nacaráveis": "nacarável",
    "nacas": "naca",
    "nacejas": "naceja",
    "nacelas": "nacela",
    "nacionais": "nacional",
    "nacionalidades": "nacionalidade",
    "nacionalismos": "nacionalismo",
    "nacionalistas": "nacionalista",
    "nacionaliza": "nacionalizar",
    "nacionalizada": "nacionalizar",
    "nacionalizadas": "nacionalizar",
    "nacionalizado": "nacionalizar",
    "nacionalizadora": "nacionalizador",
    "nacionalizadoras": "nacionalizador",
    "nacionalizadores": "nacionalizador",
    "nacionalizados": "nacionalizar",
    "nacionalizai": "nacionalizar",
    "nacionalizais": "nacionalizar",
    "nacionalizam": "nacionalizar",
    "nacionalizamo": "nacionalizar",
    "nacionalizamos": "nacionalizar",
    "nacionalizando": "nacionalizar",
    "nacionalizara": "nacionalizar",
    "nacionalizaram": "nacionalizar",
    "nacionalizaras": "nacionalizar",
    "nacionalizarde": "nacionalizar",
    "nacionalizardes": "nacionalizar",
    "nacionalizare": "nacionalizar",
    "nacionalizarei": "nacionalizar",
    "nacionalizareis": "nacionalizar",
    "nacionalizarem": "nacionalizar",
    "nacionalizaremos": "nacionalizar",
    "nacionalizares": "nacionalizar",
    "nacionalizaria": "nacionalizar",
    "nacionalizariam": "nacionalizar",
    "nacionalizarias": "nacionalizar",
    "nacionalizarmo": "nacionalizar",
    "nacionalizarmos": "nacionalizar",
    "nacionalizará": "nacionalizar",
    "nacionalizarás": "nacionalizar",
    "nacionalizarão": "nacionalizar",
    "nacionalizaríamos": "nacionalizar",
    "nacionalizaríeis": "nacionalizar",
    "nacionalizas": "nacionalizar",
    "nacionalizasse": "nacionalizar",
    "nacionalizassem": "nacionalizar",
    "nacionalizasses": "nacionalizar",
    "nacionalizaste": "nacionalizar",
    "nacionalizastes": "nacionalizar",
    "nacionalizava": "nacionalizar",
    "nacionalizavam": "nacionalizar",
    "nacionalizavas": "nacionalizar",
    "nacionalizações": "nacionalização",
    "nacionalize": "nacionalizar",
    "nacionalizei": "nacionalizar",
    "nacionalizeis": "nacionalizar",
    "nacionalizem": "nacionalizar",
    "nacionalizemo": "nacionalizar",
    "nacionalizemos": "nacionalizar",
    "nacionalizes": "nacionalizar",
    "nacionalizo": "nacionalizar",
    "nacionalizou": "nacionalizar",
    "nacionalizá": "nacionalizar",
    "nacionalizámo": "nacionalizar",
    "nacionalizámos": "nacionalizar",
    "nacionalizáramo": "nacionalizar",
    "nacionalizáramos": "nacionalizar",
    "nacionalizárei": "nacionalizar",
    "nacionalizáreis": "nacionalizar",
    "nacionalizásseis": "nacionalizar",
    "nacionalizássemos": "nacionalizar",
    "nacionalizávamo": "nacionalizar",
    "nacionalizávamos": "nacionalizar",
    "nacionalizávei": "nacionalizar",
    "nacionalizáveis": "nacionalizável",
    "nacos": "naco",
    "nacres": "nacre",
    "nacrites": "nacrite",
    "nada": "nado",
    "nadabaus": "nadabau",
    "nadada": "nadar",
    "nadadas": "nadar",
    "nadadeiras": "nadadeira",
    "nadado": "nadar",
    "nadadora": "nadador",
    "nadadoras": "nadador",
    "nadadores": "nadador",
    "nadados": "nadar",
    "nadaduras": "nadadura",
    "nadai": "nadar",
    "nadais": "nadar",
    "nadam": "nadar",
    "nadamo": "nadar",
    "nadamos": "nadar",
    "nadando": "nadar",
    "nadantes": "nadante",
    "nadara": "nadar",
    "nadaram": "nadar",
    "nadaras": "nadar",
    "nadardes": "nadar",
    "nadarei": "nadar",
    "nadareis": "nadar",
    "nadarem": "nadar",
    "nadaremos": "nadar",
    "nadares": "nadar",
    "nadaria": "nadar",
    "nadariam": "nadar",
    "nadarias": "nadar",
    "nadarmo": "nadar",
    "nadarmos": "nadar",
    "nadará": "nadar",
    "nadarás": "nadar",
    "nadarão": "nadar",
    "nadaríamos": "nadar",
    "nadaríeis": "nadar",
    "nadas": "nado",
    "nadasse": "nadar",
    "nadassem": "nadar",
    "nadasses": "nadar",
    "nadaste": "nadar",
    "nadastes": "nadar",
    "nadava": "nadar",
    "nadavam": "nadar",
    "nadavas": "nadar",
    "nade": "nadar",
    "nadegadas": "nadegada",
    "nadeguda": "nadegudo",
    "nadegudas": "nadegudo",
    "nadegudos": "nadegudo",
    "nadegueira": "nadegueiro",
    "nadegueiras": "nadegueiro",
    "nadegueiros": "nadegueiro",
    "nadei": "nadar",
    "nadeis": "nadar",
    "nadem": "nadar",
    "nademo": "nadar",
    "nademos": "nadar",
    "nades": "nadar",
    "nadinha": "nada",
    "nadirais": "nadiral",
    "nadires": "nadir",
    "nadiva": "nadivo",
    "nadivas": "nadivo",
    "nadivos": "nadivo",
    "nado": "nadar",
    "nados": "nado",
    "nadou": "nadar",
    "nadámo": "nadar",
    "nadámos": "nadar",
    "nadáramo": "nadar",
    "nadáramos": "nadar",
    "nadáreis": "nadar",
    "nadásseis": "nadar",
    "nadássemos": "nadar",
    "nadávamo": "nadar",
    "nadávamos": "nadar",
    "nadáveis": "nadar",
    "naftacenos": "naftaceno",
    "naftagis": "naftagil",
    "naftalenos": "naftaleno",
    "naftalinas": "naftalina",
    "naftalânios": "naftalânio",
    "naftas": "nafta",
    "naftenos": "nafteno",
    "naftoquinonas": "naftoquinona",
    "nafténica": "nafténico",
    "nafténicas": "nafténico",
    "nafténicos": "nafténico",
    "naftóis": "naftol",
    "nafés": "nafé",
    "nagalhos": "nagalho",
    "nagalhés": "nagalhé",
    "naganas": "nagana",
    "nagaras": "nagara",
    "nagas": "naga",
    "naiadáceas": "naiadácea",
    "naidas": "naida",
    "naifadas": "naifada",
    "naifas": "naifa",
    "naifistas": "naifista",
    "naipadas": "naipada",
    "naipeira": "naipeiro",
    "naipeiras": "naipeiro",
    "naipeiros": "naipeiro",
    "naipes": "naipe",
    "nairangias": "nairangia",
    "naires": "naire",
    "najas": "naja",
    "nalgadas": "nalgada",
    "nalgas": "nalga",
    "namarrais": "namarral",
    "namazes": "namaz",
    "namibiana": "namibiano",
    "namibianas": "namibiano",
    "namibianos": "namibiano",
    "namora": "namorar",
    "namorada": "namorar",
    "namoradas": "namorar",
    "namoradeira": "namoradeiro",
    "namoradeiras": "namoradeiro",
    "namoradeiros": "namoradeiro",
    "namoradinha": "namorado",
    "namoradinhas": "namorado",
    "namoradinho": "namorado",
    "namoradinhos": "namorado",
    "namoradita": "namorado",
    "namoraditas": "namorado",
    "namoradito": "namorado",
    "namoraditos": "namorado",
    "namoradiça": "namoradiço",
    "namoradiças": "namoradiço",
    "namoradiços": "namoradiço",
    "namorado": "namorar",
    "namoradora": "namorador",
    "namoradoras": "namorador",
    "namoradores": "namorador",
    "namorados": "namorar",
    "namorai": "namorar",
    "namorais": "namorar",
    "namoram": "namorar",
    "namoramentos": "namoramento",
    "namoramo": "namorar",
    "namoramos": "namorar",
    "namorando": "namorar",
    "namorara": "namorar",
    "namoraram": "namorar",
    "namoraras": "namorar",
    "namorarde": "namorar",
    "namorardes": "namorar",
    "namorare": "namorar",
    "namorarei": "namorar",
    "namorareis": "namorar",
    "namorarem": "namorar",
    "namoraremos": "namorar",
    "namorares": "namorar",
    "namoraria": "namorar",
    "namorariam": "namorar",
    "namorarias": "namorar",
    "namorarmo": "namorar",
    "namorarmos": "namorar",
    "namorará": "namorar",
    "namorarás": "namorar",
    "namorarão": "namorar",
    "namoraríamos": "namorar",
    "namoraríeis": "namorar",
    "namoras": "namorar",
    "namorasse": "namorar",
    "namorassem": "namorar",
    "namorasses": "namorar",
    "namoraste": "namorar",
    "namorastes": "namorar",
    "namoratória": "namoratório",
    "namoratórias": "namoratório",
    "namoratórios": "namoratório",
    "namorava": "namorar",
    "namoravam": "namorar",
    "namoravas": "namorar",
    "namorações": "namoração",
    "namore": "namorar",
    "namorei": "namorar",
    "namoreis": "namorar",
    "namorem": "namorar",
    "namoremo": "namorar",
    "namoremos": "namorar",
    "namores": "namorar",
    "namorica": "namoricar",
    "namoricada": "namoricar",
    "namoricadas": "namoricar",
    "namoricado": "namoricar",
    "namoricados": "namoricar",
    "namoricai": "namoricar",
    "namoricais": "namoricar",
    "namoricam": "namoricar",
    "namoricamo": "namoricar",
    "namoricamos": "namoricar",
    "namoricando": "namoricar",
    "namoricara": "namoricar",
    "namoricaram": "namoricar",
    "namoricaras": "namoricar",
    "namoricarde": "namoricar",
    "namoricardes": "namoricar",
    "namoricare": "namoricar",
    "namoricarei": "namoricar",
    "namoricareis": "namoricar",
    "namoricarem": "namoricar",
    "namoricaremos": "namoricar",
    "namoricares": "namoricar",
    "namoricaria": "namoricar",
    "namoricariam": "namoricar",
    "namoricarias": "namoricar",
    "namoricarmo": "namoricar",
    "namoricarmos": "namoricar",
    "namoricará": "namoricar",
    "namoricarás": "namoricar",
    "namoricarão": "namoricar",
    "namoricaríamos": "namoricar",
    "namoricaríeis": "namoricar",
    "namoricas": "namoricar",
    "namoricasse": "namoricar",
    "namoricassem": "namoricar",
    "namoricasses": "namoricar",
    "namoricaste": "namoricar",
    "namoricastes": "namoricar",
    "namoricava": "namoricar",
    "namoricavam": "namoricar",
    "namoricavas": "namoricar",
    "namorico": "namoricar",
    "namoricos": "namorico",
    "namoricou": "namoricar",
    "namoricá": "namoricar",
    "namoricámo": "namoricar",
    "namoricámos": "namoricar",
    "namoricáramo": "namoricar",
    "namoricáramos": "namoricar",
    "namoricárei": "namoricar",
    "namoricáreis": "namoricar",
    "namoricásseis": "namoricar",
    "namoricássemos": "namoricar",
    "namoricávamo": "namoricar",
    "namoricávamos": "namoricar",
    "namoricávei": "namoricar",
    "namoricáveis": "namoricar",
    "namorique": "namoricar",
    "namoriquei": "namoricar",
    "namoriqueis": "namoricar",
    "namoriquem": "namoricar",
    "namoriquemo": "namoricar",
    "namoriquemos": "namoricar",
    "namoriques": "namoricar",
    "namorisca": "namoriscar",
    "namoriscada": "namoriscar",
    "namoriscadas": "namoriscar",
    "namoriscado": "namoriscar",
    "namoriscados": "namoriscar",
    "namoriscai": "namoriscar",
    "namoriscais": "namoriscar",
    "namoriscam": "namoriscar",
    "namoriscamo": "namoriscar",
    "namoriscamos": "namoriscar",
    "namoriscando": "namoriscar",
    "namoriscara": "namoriscar",
    "namoriscaram": "namoriscar",
    "namoriscaras": "namoriscar",
    "namoriscarde": "namoriscar",
    "namoriscardes": "namoriscar",
    "namoriscare": "namoriscar",
    "namoriscarei": "namoriscar",
    "namoriscareis": "namoriscar",
    "namoriscarem": "namoriscar",
    "namoriscaremos": "namoriscar",
    "namoriscares": "namoriscar",
    "namoriscaria": "namoriscar",
    "namoriscariam": "namoriscar",
    "namoriscarias": "namoriscar",
    "namoriscarmo": "namoriscar",
    "namoriscarmos": "namoriscar",
    "namoriscará": "namoriscar",
    "namoriscarás": "namoriscar",
    "namoriscarão": "namoriscar",
    "namoriscaríamos": "namoriscar",
    "namoriscaríeis": "namoriscar",
    "namoriscas": "namoriscar",
    "namoriscasse": "namoriscar",
    "namoriscassem": "namoriscar",
    "namoriscasses": "namoriscar",
    "namoriscaste": "namoriscar",
    "namoriscastes": "namoriscar",
    "namoriscava": "namoriscar",
    "namoriscavam": "namoriscar",
    "namoriscavas": "namoriscar",
    "namorisco": "namoriscar",
    "namoriscos": "namorisco",
    "namoriscou": "namoriscar",
    "namoriscá": "namoriscar",
    "namoriscámo": "namoriscar",
    "namoriscámos": "namoriscar",
    "namoriscáramo": "namoriscar",
    "namoriscáramos": "namoriscar",
    "namoriscárei": "namoriscar",
    "namoriscáreis": "namoriscar",
    "namoriscásseis": "namoriscar",
    "namoriscássemos": "namoriscar",
    "namoriscávamo": "namoriscar",
    "namoriscávamos": "namoriscar",
    "namoriscávei": "namoriscar",
    "namoriscáveis": "namoriscar",
    "namorismos": "namorismo",
    "namorisque": "namoriscar",
    "namorisquei": "namoriscar",
    "namorisqueis": "namoriscar",
    "namorisquem": "namoriscar",
    "namorisquemo": "namoriscar",
    "namorisquemos": "namoriscar",
    "namorisques": "namoriscar",
    "namoristas": "namorista",
    "namoro": "namorar",
    "namoros": "namoro",
    "namorou": "namorar",
    "namorá": "namorar",
    "namorámo": "namorar",
    "namorámos": "namorar",
    "namoráramo": "namorar",
    "namoráramos": "namorar",
    "namorárei": "namorar",
    "namoráreis": "namorar",
    "namorásseis": "namorar",
    "namorássemos": "namorar",
    "namorávamo": "namorar",
    "namorávamos": "namorar",
    "namorávei": "namorar",
    "namoráveis": "namorar",
    "namurianos": "namuriano",
    "namázis": "namázi",
    "nana": "nanar",
    "nanada": "nanar",
    "nanadas": "nanar",
    "nanado": "nanar",
    "nanados": "nanar",
    "nanai": "nanar",
    "nanais": "nanar",
    "nanam": "nanar",
    "nanamo": "nanar",
    "nanamos": "nanar",
    "nanando": "nanar",
    "nanara": "nanar",
    "nanaram": "nanar",
    "nanaras": "nanar",
    "nanardes": "nanar",
    "nanarei": "nanar",
    "nanareis": "nanar",
    "nanarem": "nanar",
    "nanaremos": "nanar",
    "nanares": "nanar",
    "nanaria": "nanar",
    "nanariam": "nanar",
    "nanarias": "nanar",
    "nanarmo": "nanar",
    "nanarmos": "nanar",
    "nanará": "nanar",
    "nanarás": "nanar",
    "nanarão": "nanar",
    "nanaríamos": "nanar",
    "nanaríeis": "nanar",
    "nanas": "nanar",
    "nanasse": "nanar",
    "nanassem": "nanar",
    "nanasses": "nanar",
    "nanaste": "nanar",
    "nanastes": "nanar",
    "nanava": "nanar",
    "nanavam": "nanar",
    "nanavas": "nanar",
    "nandaias": "nandaia",
    "nandirobas": "nandiroba",
    "nandus": "nandu",
    "nane": "nanar",
    "nanei": "nanar",
    "naneis": "nanar",
    "nanem": "nanar",
    "nanemo": "nanar",
    "nanemos": "nanar",
    "nanequismos": "nanequismo",
    "nanequistas": "nanequista",
    "nanes": "nanar",
    "nangores": "nangor",
    "nanica": "nanico",
    "nanicas": "nanico",
    "nanicos": "nanico",
    "nanismos": "nanismo",
    "nano": "nanar",
    "nanocefalias": "nanocefalia",
    "nanocorma": "nanocormo",
    "nanocormas": "nanocormo",
    "nanocormias": "nanocormia",
    "nanocormos": "nanocormo",
    "nanocéfala": "nanocéfalo",
    "nanocéfalas": "nanocéfalo",
    "nanocéfalos": "nanocéfalo",
    "nanomelias": "nanomelia",
    "nanometros": "nanometro",
    "nanomélica": "nanomélico",
    "nanomélicas": "nanomélico",
    "nanomélicos": "nanomélico",
    "nanoplantónica": "nanoplantónico",
    "nanoplantónicas": "nanoplantónico",
    "nanoplantónicos": "nanoplantónico",
    "nanoplânctons": "nanoplâncton",
    "nanossomias": "nanossomia",
    "nanou": "nanar",
    "nanquins": "nanquim",
    "nanámo": "nanar",
    "nanámos": "nanar",
    "nanáramo": "nanar",
    "nanáramos": "nanar",
    "nanáreis": "nanar",
    "nanásseis": "nanar",
    "nanássemos": "nanar",
    "nanávamo": "nanar",
    "nanávamos": "nanar",
    "nanáveis": "nanar",
    "nanómela": "nanómelo",
    "nanómelas": "nanómelo",
    "nanómelos": "nanómelo",
    "napalmes": "napalm",
    "napas": "napa",
    "napeias": "napeia",
    "napeira": "napeiro",
    "napeiras": "napeiro",
    "napeiros": "napeiro",
    "naperons": "naperon",
    "napiformes": "napiforme",
    "napoleonismos": "napoleonismo",
    "napoleonistas": "napoleonista",
    "napoleónica": "napoleónico",
    "napoleónicas": "napoleónico",
    "napoleónicos": "napoleónico",
    "napoleões": "napoleão",
    "napolitana": "napolitano",
    "napolitanas": "napolitano",
    "napolitanos": "napolitano",
    "napácea": "napáceo",
    "napáceas": "napáceo",
    "napáceos": "napáceo",
    "naras": "nara",
    "narbonenses": "narbonense",
    "narbonesa": "narbonês",
    "narbonesas": "narbonês",
    "narboneses": "narbonês",
    "narcejas": "narceja",
    "narceínas": "narceína",
    "narcisa": "narcisar",
    "narcisada": "narcisar",
    "narcisadas": "narcisar",
    "narcisado": "narcisar",
    "narcisados": "narcisar",
    "narcisai": "narcisar",
    "narcisais": "narcisar",
    "narcisam": "narcisar",
    "narcisamo": "narcisar",
    "narcisamos": "narcisar",
    "narcisando": "narcisar",
    "narcisara": "narcisar",
    "narcisaram": "narcisar",
    "narcisaras": "narcisar",
    "narcisarde": "narcisar",
    "narcisardes": "narcisar",
    "narcisare": "narcisar",
    "narcisarei": "narcisar",
    "narcisareis": "narcisar",
    "narcisarem": "narcisar",
    "narcisaremos": "narcisar",
    "narcisares": "narcisar",
    "narcisaria": "narcisar",
    "narcisariam": "narcisar",
    "narcisarias": "narcisar",
    "narcisarmo": "narcisar",
    "narcisarmos": "narcisar",
    "narcisará": "narcisar",
    "narcisarás": "narcisar",
    "narcisarão": "narcisar",
    "narcisaríamos": "narcisar",
    "narcisaríeis": "narcisar",
    "narcisas": "narcisar",
    "narcisasse": "narcisar",
    "narcisassem": "narcisar",
    "narcisasses": "narcisar",
    "narcisaste": "narcisar",
    "narcisastes": "narcisar",
    "narcisava": "narcisar",
    "narcisavam": "narcisar",
    "narcisavas": "narcisar",
    "narcise": "narcisar",
    "narcisei": "narcisar",
    "narciseis": "narcisar",
    "narcisem": "narcisar",
    "narcisemo": "narcisar",
    "narcisemos": "narcisar",
    "narcises": "narcisar",
    "narcisismos": "narcisismo",
    "narcisistas": "narcisista",
    "narciso": "narcisar",
    "narcisos": "narciso",
    "narcisou": "narcisar",
    "narcisá": "narcisar",
    "narcisáceas": "narcisácea",
    "narcisámo": "narcisar",
    "narcisámos": "narcisar",
    "narcisáramo": "narcisar",
    "narcisáramos": "narcisar",
    "narcisárei": "narcisar",
    "narcisáreis": "narcisar",
    "narcisásseis": "narcisar",
    "narcisássemos": "narcisar",
    "narcisávamo": "narcisar",
    "narcisávamos": "narcisar",
    "narcisávei": "narcisar",
    "narcisáveis": "narcisar",
    "narcisóides": "narcisóide",
    "narcoanálises": "narcoanálise",
    "narcodólares": "narcodólar",
    "narcoipnoses": "narcoipnose",
    "narcolepsias": "narcolepsia",
    "narcomanias": "narcomania",
    "narcomedusas": "narcomedusa",
    "narcoses": "narcose",
    "narcossínteses": "narcossíntese",
    "narcoterapias": "narcoterapia",
    "narcotinas": "narcotina",
    "narcotismos": "narcotismo",
    "narcotiza": "narcotizar",
    "narcotizada": "narcotizar",
    "narcotizadas": "narcotizar",
    "narcotizado": "narcotizar",
    "narcotizados": "narcotizar",
    "narcotizai": "narcotizar",
    "narcotizais": "narcotizar",
    "narcotizam": "narcotizar",
    "narcotizamo": "narcotizar",
    "narcotizamos": "narcotizar",
    "narcotizando": "narcotizar",
    "narcotizara": "narcotizar",
    "narcotizaram": "narcotizar",
    "narcotizaras": "narcotizar",
    "narcotizarde": "narcotizar",
    "narcotizardes": "narcotizar",
    "narcotizare": "narcotizar",
    "narcotizarei": "narcotizar",
    "narcotizareis": "narcotizar",
    "narcotizarem": "narcotizar",
    "narcotizaremos": "narcotizar",
    "narcotizares": "narcotizar",
    "narcotizaria": "narcotizar",
    "narcotizariam": "narcotizar",
    "narcotizarias": "narcotizar",
    "narcotizarmo": "narcotizar",
    "narcotizarmos": "narcotizar",
    "narcotizará": "narcotizar",
    "narcotizarás": "narcotizar",
    "narcotizarão": "narcotizar",
    "narcotizaríamos": "narcotizar",
    "narcotizaríeis": "narcotizar",
    "narcotizas": "narcotizar",
    "narcotizasse": "narcotizar",
    "narcotizassem": "narcotizar",
    "narcotizasses": "narcotizar",
    "narcotizaste": "narcotizar",
    "narcotizastes": "narcotizar",
    "narcotizava": "narcotizar",
    "narcotizavam": "narcotizar",
    "narcotizavas": "narcotizar",
    "narcotizações": "narcotização",
    "narcotize": "narcotizar",
    "narcotizei": "narcotizar",
    "narcotizeis": "narcotizar",
    "narcotizem": "narcotizar",
    "narcotizemo": "narcotizar",
    "narcotizemos": "narcotizar",
    "narcotizes": "narcotizar",
    "narcotizo": "narcotizar",
    "narcotizou": "narcotizar",
    "narcotizá": "narcotizar",
    "narcotizámo": "narcotizar",
    "narcotizámos": "narcotizar",
    "narcotizáramo": "narcotizar",
    "narcotizáramos": "narcotizar",
    "narcotizárei": "narcotizar",
    "narcotizáreis": "narcotizar",
    "narcotizásseis": "narcotizar",
    "narcotizássemos": "narcotizar",
    "narcotizávamo": "narcotizar",
    "narcotizávamos": "narcotizar",
    "narcotizávei": "narcotizar",
    "narcotizáveis": "narcotizável",
    "narcotraficantes": "narcotraficante",
    "narcotrafincantes": "narcotrafincante",
    "narcotráficos": "narcotráfico",
    "narcótica": "narcótico",
    "narcóticas": "narcótico",
    "narcóticos": "narcótico",
    "nardas": "narda",
    "nardina": "nardino",
    "nardinas": "nardino",
    "nardinos": "nardino",
    "nardos": "nardo",
    "narguilhés": "narguilhé",
    "narguilés": "narguilé",
    "narigadas": "narigada",
    "narigangas": "nariganga",
    "narigona": "narigão",
    "narigonas": "narigão",
    "nariguda": "narigudo",
    "narigudas": "narigudo",
    "narigudos": "narigudo",
    "narigueira": "narigueiro",
    "narigueiras": "narigueiro",
    "narigueiros": "narigueiro",
    "nariguetas": "narigueta",
    "narigões": "narigão",
    "narinas": "narina",
    "narizes": "nariz",
    "narizinho": "nariz",
    "narizinhos": "nariz",
    "narizito": "nariz",
    "narizitos": "nariz",
    "narra": "narrar",
    "narrada": "narrar",
    "narradas": "narrar",
    "narrado": "narrar",
    "narradora": "narrador",
    "narradoras": "narrador",
    "narradores": "narrador",
    "narrados": "narrar",
    "narrai": "narrar",
    "narrais": "narrar",
    "narram": "narrar",
    "narramo": "narrar",
    "narramos": "narrar",
    "narrando": "narrar",
    "narrara": "narrar",
    "narraram": "narrar",
    "narraras": "narrar",
    "narrarde": "narrar",
    "narrardes": "narrar",
    "narrare": "narrar",
    "narrarei": "narrar",
    "narrareis": "narrar",
    "narrarem": "narrar",
    "narraremos": "narrar",
    "narrares": "narrar",
    "narraria": "narrar",
    "narrariam": "narrar",
    "narrarias": "narrar",
    "narrarmo": "narrar",
    "narrarmos": "narrar",
    "narrará": "narrar",
    "narrarás": "narrar",
    "narrarão": "narrar",
    "narraríamos": "narrar",
    "narraríeis": "narrar",
    "narras": "narrar",
    "narrasse": "narrar",
    "narrassem": "narrar",
    "narrasses": "narrar",
    "narraste": "narrar",
    "narrastes": "narrar",
    "narrativa": "narrativo",
    "narrativas": "narrativo",
    "narrativos": "narrativo",
    "narratária": "narratário",
    "narratárias": "narratário",
    "narratários": "narratário",
    "narrava": "narrar",
    "narravam": "narrar",
    "narravas": "narrar",
    "narrações": "narração",
    "narre": "narrar",
    "narrei": "narrar",
    "narreis": "narrar",
    "narrem": "narrar",
    "narremo": "narrar",
    "narremos": "narrar",
    "narres": "narrar",
    "narro": "narrar",
    "narrou": "narrar",
    "narrá": "narrar",
    "narrámo": "narrar",
    "narrámos": "narrar",
    "narráramo": "narrar",
    "narráramos": "narrar",
    "narrárei": "narrar",
    "narráreis": "narrar",
    "narrásseis": "narrar",
    "narrássemos": "narrar",
    "narrávamo": "narrar",
    "narrávamos": "narrar",
    "narrávei": "narrar",
    "narráveis": "narrável",
    "narteces": "nartece",
    "narvais": "narval",
    "narículas": "narícula",
    "nas": "o",
    "nasais": "nasal",
    "nasala": "nasalar",
    "nasalada": "nasalar",
    "nasaladas": "nasalar",
    "nasalado": "nasalar",
    "nasalados": "nasalar",
    "nasalai": "nasalar",
    "nasalais": "nasalar",
    "nasalam": "nasalar",
    "nasalamo": "nasalar",
    "nasalamos": "nasalar",
    "nasalando": "nasalar",
    "nasalara": "nasalar",
    "nasalaram": "nasalar",
    "nasalaras": "nasalar",
    "nasalarde": "nasalar",
    "nasalardes": "nasalar",
    "nasalare": "nasalar",
    "nasalarei": "nasalar",
    "nasalareis": "nasalar",
    "nasalarem": "nasalar",
    "nasalaremos": "nasalar",
    "nasalares": "nasalar",
    "nasalaria": "nasalar",
    "nasalariam": "nasalar",
    "nasalarias": "nasalar",
    "nasalarmo": "nasalar",
    "nasalarmos": "nasalar",
    "nasalará": "nasalar",
    "nasalarás": "nasalar",
    "nasalarão": "nasalar",
    "nasalaríamos": "nasalar",
    "nasalaríeis": "nasalar",
    "nasalas": "nasalar",
    "nasalasse": "nasalar",
    "nasalassem": "nasalar",
    "nasalasses": "nasalar",
    "nasalaste": "nasalar",
    "nasalastes": "nasalar",
    "nasalava": "nasalar",
    "nasalavam": "nasalar",
    "nasalavas": "nasalar",
    "nasalações": "nasalação",
    "nasale": "nasalar",
    "nasalei": "nasalar",
    "nasaleis": "nasalar",
    "nasalem": "nasalar",
    "nasalemo": "nasalar",
    "nasalemos": "nasalar",
    "nasales": "nasalar",
    "nasalidades": "nasalidade",
    "nasaliza": "nasalizar",
    "nasalizada": "nasalizar",
    "nasalizadas": "nasalizar",
    "nasalizado": "nasalizar",
    "nasalizados": "nasalizar",
    "nasalizai": "nasalizar",
    "nasalizais": "nasalizar",
    "nasalizam": "nasalizar",
    "nasalizamo": "nasalizar",
    "nasalizamos": "nasalizar",
    "nasalizando": "nasalizar",
    "nasalizara": "nasalizar",
    "nasalizaram": "nasalizar",
    "nasalizaras": "nasalizar",
    "nasalizarde": "nasalizar",
    "nasalizardes": "nasalizar",
    "nasalizare": "nasalizar",
    "nasalizarei": "nasalizar",
    "nasalizareis": "nasalizar",
    "nasalizarem": "nasalizar",
    "nasalizaremos": "nasalizar",
    "nasalizares": "nasalizar",
    "nasalizaria": "nasalizar",
    "nasalizariam": "nasalizar",
    "nasalizarias": "nasalizar",
    "nasalizarmo": "nasalizar",
    "nasalizarmos": "nasalizar",
    "nasalizará": "nasalizar",
    "nasalizarás": "nasalizar",
    "nasalizarão": "nasalizar",
    "nasalizaríamos": "nasalizar",
    "nasalizaríeis": "nasalizar",
    "nasalizas": "nasalizar",
    "nasalizasse": "nasalizar",
    "nasalizassem": "nasalizar",
    "nasalizasses": "nasalizar",
    "nasalizaste": "nasalizar",
    "nasalizastes": "nasalizar",
    "nasalizava": "nasalizar",
    "nasalizavam": "nasalizar",
    "nasalizavas": "nasalizar",
    "nasalize": "nasalizar",
    "nasalizei": "nasalizar",
    "nasalizeis": "nasalizar",
    "nasalizem": "nasalizar",
    "nasalizemo": "nasalizar",
    "nasalizemos": "nasalizar",
    "nasalizes": "nasalizar",
    "nasalizo": "nasalizar",
    "nasalizou": "nasalizar",
    "nasalizá": "nasalizar",
    "nasalizámo": "nasalizar",
    "nasalizámos": "nasalizar",
    "nasalizáramo": "nasalizar",
    "nasalizáramos": "nasalizar",
    "nasalizárei": "nasalizar",
    "nasalizáreis": "nasalizar",
    "nasalizásseis": "nasalizar",
    "nasalizássemos": "nasalizar",
    "nasalizávamo": "nasalizar",
    "nasalizávamos": "nasalizar",
    "nasalizávei": "nasalizar",
    "nasalizáveis": "nasalizável",
    "nasalo": "nasalar",
    "nasalou": "nasalar",
    "nasalá": "nasalar",
    "nasalámo": "nasalar",
    "nasalámos": "nasalar",
    "nasaláramo": "nasalar",
    "nasaláramos": "nasalar",
    "nasalárei": "nasalar",
    "nasaláreis": "nasalar",
    "nasalásseis": "nasalar",
    "nasalássemos": "nasalar",
    "nasalávamo": "nasalar",
    "nasalávamos": "nasalar",
    "nasalávei": "nasalar",
    "nasaláveis": "nasalável",
    "nasce": "nascer",
    "nascediça": "nascediço",
    "nascediças": "nascediço",
    "nascediços": "nascediço",
    "nascedoiros": "nascedoiro",
    "nascedouros": "nascedouro",
    "nascei": "nascer",
    "nasceiros": "nasceiro",
    "nasceis": "nascer",
    "nascem": "nascer",
    "nascemo": "nascer",
    "nascemos": "nascer",
    "nascendo": "nascer",
    "nascentes": "nascente",
    "nascenças": "nascença",
    "nascera": "nascer",
    "nasceram": "nascer",
    "nasceras": "nascer",
    "nascerdes": "nascer",
    "nascerei": "nascer",
    "nascereis": "nascer",
    "nascerem": "nascer",
    "nasceremos": "nascer",
    "nasceres": "nascer",
    "nasceria": "nascer",
    "nasceriam": "nascer",
    "nascerias": "nascer",
    "nascermo": "nascer",
    "nascermos": "nascer",
    "nascerá": "nascer",
    "nascerás": "nascer",
    "nascerão": "nascer",
    "nasceríamos": "nascer",
    "nasceríeis": "nascer",
    "nasces": "nascer",
    "nascesse": "nascer",
    "nascessem": "nascer",
    "nascesses": "nascer",
    "nasceste": "nascer",
    "nascestes": "nascer",
    "nasceu": "nascer",
    "nasci": "nascer",
    "nascia": "nascer",
    "nasciam": "nascer",
    "nascias": "nascer",
    "nascida": "nascido",
    "nascidas": "nascido",
    "nascidiça": "nascidiço",
    "nascidiças": "nascidiço",
    "nascidiços": "nascidiço",
    "nascido": "nascer",
    "nascidos": "nascido",
    "nascimentos": "nascimento",
    "nascitura": "nascituro",
    "nascituras": "nascituro",
    "nascituros": "nascituro",
    "nascêramo": "nascer",
    "nascêramos": "nascer",
    "nascêreis": "nascer",
    "nascêsseis": "nascer",
    "nascêssemos": "nascer",
    "nascíamo": "nascer",
    "nascíamos": "nascer",
    "nascíeis": "nascer",
    "nascíveis": "nascível",
    "nasicórnea": "nasicórneo",
    "nasicórneas": "nasicórneo",
    "nasicórneos": "nasicórneo",
    "nasofaringes": "nasofaringe",
    "nasofaringites": "nasofaringite",
    "nasopalpebrais": "nasopalpebral",
    "nasoscópios": "nasoscópio",
    "nassadas": "nassada",
    "nassas": "nassa",
    "nasserismos": "nasserismo",
    "nasseristas": "nasserista",
    "nastros": "nastro",
    "nasça": "nascer",
    "nasçais": "nascer",
    "nasçam": "nascer",
    "nasçamo": "nascer",
    "nasçamos": "nascer",
    "nasças": "nascer",
    "nasço": "nascer",
    "nata": "nato",
    "natada": "natado",
    "natadas": "natado",
    "natadeiras": "natadeira",
    "natados": "natado",
    "natais": "natal",
    "natalenses": "natalense",
    "natalidades": "natalidade",
    "natalícia": "natalício",
    "natalícias": "natalício",
    "natalícios": "natalício",
    "natas": "nato",
    "natatória": "natatório",
    "natatórias": "natatório",
    "natatórios": "natatório",
    "natações": "natação",
    "nateirada": "nateirado",
    "nateiradas": "nateirado",
    "nateirados": "nateirado",
    "nateiros": "nateiro",
    "natenta": "natento",
    "natentas": "natento",
    "natentos": "natento",
    "natiformes": "natiforme",
    "natimortalidades": "natimortalidade",
    "natios": "natio",
    "nativa": "nativo",
    "nativas": "nativo",
    "natividades": "natividade",
    "nativismos": "nativismo",
    "nativistas": "nativista",
    "nativos": "nativo",
    "natos": "nato",
    "natronites": "natronite",
    "natronitros": "natronitro",
    "natros": "natro",
    "natrólitos": "natrólito",
    "natrómetros": "natrómetro",
    "natrões": "natrão",
    "naturada": "naturado",
    "naturadas": "naturado",
    "naturados": "naturado",
    "naturais": "natural",
    "naturalezas": "naturaleza",
    "naturalidades": "naturalidade",
    "naturalismos": "naturalismo",
    "naturalistas": "naturalista",
    "naturaliza": "naturalizar",
    "naturalizada": "naturalizar",
    "naturalizadas": "naturalizar",
    "naturalizado": "naturalizar",
    "naturalizados": "naturalizar",
    "naturalizai": "naturalizar",
    "naturalizais": "naturalizar",
    "naturalizam": "naturalizar",
    "naturalizamo": "naturalizar",
    "naturalizamos": "naturalizar",
    "naturalizando": "naturalizar",
    "naturalizara": "naturalizar",
    "naturalizaram": "naturalizar",
    "naturalizaras": "naturalizar",
    "naturalizarde": "naturalizar",
    "naturalizardes": "naturalizar",
    "naturalizare": "naturalizar",
    "naturalizarei": "naturalizar",
    "naturalizareis": "naturalizar",
    "naturalizarem": "naturalizar",
    "naturalizaremos": "naturalizar",
    "naturalizares": "naturalizar",
    "naturalizaria": "naturalizar",
    "naturalizariam": "naturalizar",
    "naturalizarias": "naturalizar",
    "naturalizarmo": "naturalizar",
    "naturalizarmos": "naturalizar",
    "naturalizará": "naturalizar",
    "naturalizarás": "naturalizar",
    "naturalizarão": "naturalizar",
    "naturalizaríamos": "naturalizar",
    "naturalizaríeis": "naturalizar",
    "naturalizas": "naturalizar",
    "naturalizasse": "naturalizar",
    "naturalizassem": "naturalizar",
    "naturalizasses": "naturalizar",
    "naturalizaste": "naturalizar",
    "naturalizastes": "naturalizar",
    "naturalizava": "naturalizar",
    "naturalizavam": "naturalizar",
    "naturalizavas": "naturalizar",
    "naturalizações": "naturalização",
    "naturalize": "naturalizar",
    "naturalizei": "naturalizar",
    "naturalizeis": "naturalizar",
    "naturalizem": "naturalizar",
    "naturalizemo": "naturalizar",
    "naturalizemos": "naturalizar",
    "naturalizes": "naturalizar",
    "naturalizo": "naturalizar",
    "naturalizou": "naturalizar",
    "naturalizá": "naturalizar",
    "naturalizámo": "naturalizar",
    "naturalizámos": "naturalizar",
    "naturalizáramo": "naturalizar",
    "naturalizáramos": "naturalizar",
    "naturalizárei": "naturalizar",
    "naturalizáreis": "naturalizar",
    "naturalizásseis": "naturalizar",
    "naturalizássemos": "naturalizar",
    "naturalizávamo": "naturalizar",
    "naturalizávamos": "naturalizar",
    "naturalizávei": "naturalizar",
    "naturalizáveis": "naturalizável",
    "naturalíssima": "natural",
    "naturalíssimas": "natural",
    "naturalíssimo": "natural",
    "naturalíssimos": "natural",
    "naturantes": "naturante",
    "naturanças": "naturança",
    "naturas": "natura",
    "naturezas": "natureza",
    "naturismos": "naturismo",
    "naturistas": "naturista",
    "natária": "natário",
    "natárias": "natário",
    "natários": "natário",
    "natátis": "natátil",
    "nauatles": "nauatle",
    "naufraga": "naufragar",
    "naufragada": "naufragar",
    "naufragadas": "naufragar",
    "naufragado": "naufragar",
    "naufragados": "naufragar",
    "naufragai": "naufragar",
    "naufragais": "naufragar",
    "naufragam": "naufragar",
    "naufragamo": "naufragar",
    "naufragamos": "naufragar",
    "naufragando": "naufragar",
    "naufragantes": "naufragante",
    "naufragara": "naufragar",
    "naufragaram": "naufragar",
    "naufragaras": "naufragar",
    "naufragardes": "naufragar",
    "naufragarei": "naufragar",
    "naufragareis": "naufragar",
    "naufragarem": "naufragar",
    "naufragaremos": "naufragar",
    "naufragares": "naufragar",
    "naufragaria": "naufragar",
    "naufragariam": "naufragar",
    "naufragarias": "naufragar",
    "naufragarmo": "naufragar",
    "naufragarmos": "naufragar",
    "naufragará": "naufragar",
    "naufragarás": "naufragar",
    "naufragarão": "naufragar",
    "naufragaríamos": "naufragar",
    "naufragaríeis": "naufragar",
    "naufragas": "naufragar",
    "naufragasse": "naufragar",
    "naufragassem": "naufragar",
    "naufragasses": "naufragar",
    "naufragaste": "naufragar",
    "naufragastes": "naufragar",
    "naufragava": "naufragar",
    "naufragavam": "naufragar",
    "naufragavas": "naufragar",
    "naufrago": "naufragar",
    "naufragou": "naufragar",
    "naufrague": "naufragar",
    "naufraguei": "naufragar",
    "naufragueis": "naufragar",
    "naufraguem": "naufragar",
    "naufraguemo": "naufragar",
    "naufraguemos": "naufragar",
    "naufragues": "naufragar",
    "naufragámo": "naufragar",
    "naufragámos": "naufragar",
    "naufragáramo": "naufragar",
    "naufragáramos": "naufragar",
    "naufragáreis": "naufragar",
    "naufragásseis": "naufragar",
    "naufragássemos": "naufragar",
    "naufragávamo": "naufragar",
    "naufragávamos": "naufragar",
    "naufragáveis": "naufragável",
    "naufrágios": "naufrágio",
    "naumaquias": "naumaquia",
    "naupatias": "naupatia",
    "naus": "nau",
    "nauscopias": "nauscopia",
    "nauscópios": "nauscópio",
    "nauseabunda": "nauseabundo",
    "nauseabundas": "nauseabundo",
    "nauseabundos": "nauseabundo",
    "nauseada": "nausear",
    "nauseadas": "nausear",
    "nauseado": "nausear",
    "nauseados": "nausear",
    "nauseadíssima": "nauseado",
    "nauseadíssimas": "nauseado",
    "nauseadíssimo": "nauseado",
    "nauseadíssimos": "nauseado",
    "nauseai": "nausear",
    "nauseais": "nausear",
    "nauseamo": "nausear",
    "nauseamos": "nausear",
    "nauseando": "nausear",
    "nauseantes": "nauseante",
    "nauseara": "nausear",
    "nausearam": "nausear",
    "nausearas": "nausear",
    "nausearde": "nausear",
    "nauseardes": "nausear",
    "nauseare": "nausear",
    "nausearei": "nausear",
    "nauseareis": "nausear",
    "nausearem": "nausear",
    "nausearemos": "nausear",
    "nauseares": "nausear",
    "nausearia": "nausear",
    "nauseariam": "nausear",
    "nausearias": "nausear",
    "nausearmo": "nausear",
    "nausearmos": "nausear",
    "nauseará": "nausear",
    "nausearás": "nausear",
    "nausearão": "nausear",
    "nausearíamos": "nausear",
    "nausearíeis": "nausear",
    "nauseasse": "nausear",
    "nauseassem": "nausear",
    "nauseasses": "nausear",
    "nauseaste": "nausear",
    "nauseastes": "nausear",
    "nauseativa": "nauseativo",
    "nauseativas": "nauseativo",
    "nauseativos": "nauseativo",
    "nauseava": "nausear",
    "nauseavam": "nausear",
    "nauseavas": "nausear",
    "nauseei": "nausear",
    "nauseeis": "nausear",
    "nauseemo": "nausear",
    "nauseemos": "nausear",
    "nauseenta": "nauseento",
    "nauseentas": "nauseento",
    "nauseentos": "nauseento",
    "nauseia": "nausear",
    "nauseiam": "nausear",
    "nauseias": "nausear",
    "nauseie": "nausear",
    "nauseiem": "nausear",
    "nauseies": "nausear",
    "nauseio": "nausear",
    "nauseosa": "nauseoso",
    "nauseosas": "nauseoso",
    "nauseosos": "nauseoso",
    "nauseou": "nausear",
    "nauseá": "nausear",
    "nauseámo": "nausear",
    "nauseámos": "nausear",
    "nauseáramo": "nausear",
    "nauseáramos": "nausear",
    "nauseárei": "nausear",
    "nauseáreis": "nausear",
    "nauseásseis": "nausear",
    "nauseássemos": "nausear",
    "nauseávamo": "nausear",
    "nauseávamos": "nausear",
    "nauseávei": "nausear",
    "nauseáveis": "nausear",
    "nautas": "nauta",
    "nautilídeos": "nautilídeo",
    "nautilóides": "nautilóide",
    "nautografias": "nautografia",
    "nautílidas": "nautílida",
    "nautógrafos": "nautógrafo",
    "navais": "naval",
    "navalha": "navalhar",
    "navalhada": "navalhar",
    "navalhadas": "navalhar",
    "navalhado": "navalhar",
    "navalhados": "navalhar",
    "navalhai": "navalhar",
    "navalhais": "navalhar",
    "navalham": "navalhar",
    "navalhamo": "navalhar",
    "navalhamos": "navalhar",
    "navalhando": "navalhar",
    "navalhara": "navalhar",
    "navalharam": "navalhar",
    "navalharas": "navalhar",
    "navalharde": "navalhar",
    "navalhardes": "navalhar",
    "navalhare": "navalhar",
    "navalharei": "navalhar",
    "navalhareis": "navalhar",
    "navalharem": "navalhar",
    "navalharemos": "navalhar",
    "navalhares": "navalhar",
    "navalharia": "navalhar",
    "navalhariam": "navalhar",
    "navalharias": "navalhar",
    "navalharmo": "navalhar",
    "navalharmos": "navalhar",
    "navalhará": "navalhar",
    "navalharás": "navalhar",
    "navalharão": "navalhar",
    "navalharíamos": "navalhar",
    "navalharíeis": "navalhar",
    "navalhas": "navalhar",
    "navalhasse": "navalhar",
    "navalhassem": "navalhar",
    "navalhasses": "navalhar",
    "navalhaste": "navalhar",
    "navalhastes": "navalhar",
    "navalhava": "navalhar",
    "navalhavam": "navalhar",
    "navalhavas": "navalhar",
    "navalhe": "navalhar",
    "navalhei": "navalhar",
    "navalheiras": "navalheira",
    "navalheis": "navalhar",
    "navalhem": "navalhar",
    "navalhemo": "navalhar",
    "navalhemos": "navalhar",
    "navalhes": "navalhar",
    "navalhistas": "navalhista",
    "navalho": "navalhar",
    "navalhou": "navalhar",
    "navalhá": "navalhar",
    "navalhámo": "navalhar",
    "navalhámos": "navalhar",
    "navalháramo": "navalhar",
    "navalháramos": "navalhar",
    "navalhárei": "navalhar",
    "navalháreis": "navalhar",
    "navalhásseis": "navalhar",
    "navalhássemos": "navalhar",
    "navalhávamo": "navalhar",
    "navalhávamos": "navalhar",
    "navalhávei": "navalhar",
    "navalháveis": "navalhar",
    "navalhões": "navalhão",
    "navarcos": "navarco",
    "navarra": "navarro",
    "navarras": "navarro",
    "navarrina": "navarrino",
    "navarrinas": "navarrino",
    "navarrinos": "navarrino",
    "navarros": "navarro",
    "navas": "nava",
    "navega": "navegar",
    "navegabilidades": "navegabilidade",
    "navegada": "navegar",
    "navegadas": "navegar",
    "navegado": "navegar",
    "navegadora": "navegador",
    "navegadoras": "navegador",
    "navegadores": "navegador",
    "navegados": "navegar",
    "navegai": "navegar",
    "navegais": "navegar",
    "navegam": "navegar",
    "navegamo": "navegar",
    "navegamos": "navegar",
    "navegando": "navegar",
    "navegantes": "navegante",
    "navegara": "navegar",
    "navegaram": "navegar",
    "navegaras": "navegar",
    "navegarde": "navegar",
    "navegardes": "navegar",
    "navegare": "navegar",
    "navegarei": "navegar",
    "navegareis": "navegar",
    "navegarem": "navegar",
    "navegaremos": "navegar",
    "navegares": "navegar",
    "navegaria": "navegar",
    "navegariam": "navegar",
    "navegarias": "navegar",
    "navegarmo": "navegar",
    "navegarmos": "navegar",
    "navegará": "navegar",
    "navegarás": "navegar",
    "navegarão": "navegar",
    "navegaríamos": "navegar",
    "navegaríeis": "navegar",
    "navegas": "navegar",
    "navegasse": "navegar",
    "navegassem": "navegar",
    "navegasses": "navegar",
    "navegaste": "navegar",
    "navegastes": "navegar",
    "navegava": "navegar",
    "navegavam": "navegar",
    "navegavas": "navegar",
    "navegações": "navegação",
    "navego": "navegar",
    "navegou": "navegar",
    "navegue": "navegar",
    "naveguei": "navegar",
    "navegueis": "navegar",
    "naveguem": "navegar",
    "naveguemo": "navegar",
    "naveguemos": "navegar",
    "navegues": "navegar",
    "navegá": "navegar",
    "navegámo": "navegar",
    "navegámos": "navegar",
    "navegáramo": "navegar",
    "navegáramos": "navegar",
    "navegárei": "navegar",
    "navegáreis": "navegar",
    "navegásseis": "navegar",
    "navegássemos": "navegar",
    "navegávamo": "navegar",
    "navegávamos": "navegar",
    "navegávei": "navegar",
    "navegáveis": "navegável",
    "naves": "nave",
    "navetas": "naveta",
    "navicelas": "navicela",
    "naviculares": "navicular",
    "naviculários": "naviculário",
    "naviformes": "naviforme",
    "navinheiras": "navinheira",
    "naviomodelismos": "naviomodelismo",
    "naviomodelistas": "naviomodelista",
    "navios": "navio",
    "navículas": "navícula",
    "navífraga": "navífrago",
    "navífragas": "navífrago",
    "navífragos": "navífrago",
    "navígera": "navígero",
    "navígeras": "navígero",
    "navígeros": "navígero",
    "nazarena": "nazareno",
    "nazarenas": "nazareno",
    "nazarenos": "nazareno",
    "nazaritas": "nazarita",
    "nazaritismos": "nazaritismo",
    "nazis": "nazi",
    "nazismos": "nazismo",
    "nazistas": "nazista",
    "nazárea": "nazáreo",
    "nazáreas": "nazáreo",
    "nazáreos": "nazáreo",
    "nações": "nação",
    "naídeos": "naídeo",
    "neandertalenses": "neandertalense",
    "nearómetros": "nearómetro",
    "nebaliáceos": "nebaliáceo",
    "neblina": "neblinar",
    "neblinada": "neblinar",
    "neblinadas": "neblinar",
    "neblinado": "neblinar",
    "neblinados": "neblinar",
    "neblinai": "neblinar",
    "neblinais": "neblinar",
    "neblinam": "neblinar",
    "neblinamo": "neblinar",
    "neblinamos": "neblinar",
    "neblinando": "neblinar",
    "neblinara": "neblinar",
    "neblinaram": "neblinar",
    "neblinaras": "neblinar",
    "neblinardes": "neblinar",
    "neblinarei": "neblinar",
    "neblinareis": "neblinar",
    "neblinarem": "neblinar",
    "neblinaremos": "neblinar",
    "neblinares": "neblinar",
    "neblinaria": "neblinar",
    "neblinariam": "neblinar",
    "neblinarias": "neblinar",
    "neblinarmo": "neblinar",
    "neblinarmos": "neblinar",
    "neblinará": "neblinar",
    "neblinarás": "neblinar",
    "neblinarão": "neblinar",
    "neblinaríamos": "neblinar",
    "neblinaríeis": "neblinar",
    "neblinas": "neblinar",
    "neblinasse": "neblinar",
    "neblinassem": "neblinar",
    "neblinasses": "neblinar",
    "neblinaste": "neblinar",
    "neblinastes": "neblinar",
    "neblinava": "neblinar",
    "neblinavam": "neblinar",
    "neblinavas": "neblinar",
    "nebline": "neblinar",
    "neblinei": "neblinar",
    "neblineis": "neblinar",
    "neblinem": "neblinar",
    "neblinemo": "neblinar",
    "neblinemos": "neblinar",
    "neblines": "neblinar",
    "neblino": "neblinar",
    "neblinou": "neblinar",
    "neblinámo": "neblinar",
    "neblinámos": "neblinar",
    "neblináramo": "neblinar",
    "neblináramos": "neblinar",
    "neblináreis": "neblinar",
    "neblinásseis": "neblinar",
    "neblinássemos": "neblinar",
    "neblinávamo": "neblinar",
    "neblinávamos": "neblinar",
    "neblináveis": "neblinar",
    "nebrina": "nebrinar",
    "nebrinada": "nebrinar",
    "nebrinadas": "nebrinar",
    "nebrinado": "nebrinar",
    "nebrinados": "nebrinar",
    "nebrinagens": "nebrinagem",
    "nebrinai": "nebrinar",
    "nebrinais": "nebrinar",
    "nebrinam": "nebrinar",
    "nebrinamo": "nebrinar",
    "nebrinamos": "nebrinar",
    "nebrinando": "nebrinar",
    "nebrinara": "nebrinar",
    "nebrinaram": "nebrinar",
    "nebrinaras": "nebrinar",
    "nebrinardes": "nebrinar",
    "nebrinarei": "nebrinar",
    "nebrinareis": "nebrinar",
    "nebrinarem": "nebrinar",
    "nebrinaremos": "nebrinar",
    "nebrinares": "nebrinar",
    "nebrinaria": "nebrinar",
    "nebrinariam": "nebrinar",
    "nebrinarias": "nebrinar",
    "nebrinarmo": "nebrinar",
    "nebrinarmos": "nebrinar",
    "nebrinará": "nebrinar",
    "nebrinarás": "nebrinar",
    "nebrinarão": "nebrinar",
    "nebrinaríamos": "nebrinar",
    "nebrinaríeis": "nebrinar",
    "nebrinas": "nebrinar",
    "nebrinasse": "nebrinar",
    "nebrinassem": "nebrinar",
    "nebrinasses": "nebrinar",
    "nebrinaste": "nebrinar",
    "nebrinastes": "nebrinar",
    "nebrinava": "nebrinar",
    "nebrinavam": "nebrinar",
    "nebrinavas": "nebrinar",
    "nebrine": "nebrinar",
    "nebrinei": "nebrinar",
    "nebrineis": "nebrinar",
    "nebrinem": "nebrinar",
    "nebrinemo": "nebrinar",
    "nebrinemos": "nebrinar",
    "nebrines": "nebrinar",
    "nebrino": "nebrinar",
    "nebrinosa": "nebrinoso",
    "nebrinosas": "nebrinoso",
    "nebrinosos": "nebrinoso",
    "nebrinou": "nebrinar",
    "nebrinámo": "nebrinar",
    "nebrinámos": "nebrinar",
    "nebrináramo": "nebrinar",
    "nebrináramos": "nebrinar",
    "nebrináreis": "nebrinar",
    "nebrinásseis": "nebrinar",
    "nebrinássemos": "nebrinar",
    "nebrinávamo": "nebrinar",
    "nebrinávamos": "nebrinar",
    "nebrináveis": "nebrinar",
    "nebris": "nebri",
    "nebriídeos": "nebriídeo",
    "nebríidas": "nebríida",
    "nebuligramas": "nebuligrama",
    "nebulitos": "nebulito",
    "nebuliza": "nebulizar",
    "nebulizada": "nebulizar",
    "nebulizadas": "nebulizar",
    "nebulizado": "nebulizar",
    "nebulizadores": "nebulizador",
    "nebulizados": "nebulizar",
    "nebulizai": "nebulizar",
    "nebulizais": "nebulizar",
    "nebulizam": "nebulizar",
    "nebulizamo": "nebulizar",
    "nebulizamos": "nebulizar",
    "nebulizando": "nebulizar",
    "nebulizara": "nebulizar",
    "nebulizaram": "nebulizar",
    "nebulizaras": "nebulizar",
    "nebulizarde": "nebulizar",
    "nebulizardes": "nebulizar",
    "nebulizare": "nebulizar",
    "nebulizarei": "nebulizar",
    "nebulizareis": "nebulizar",
    "nebulizarem": "nebulizar",
    "nebulizaremos": "nebulizar",
    "nebulizares": "nebulizar",
    "nebulizaria": "nebulizar",
    "nebulizariam": "nebulizar",
    "nebulizarias": "nebulizar",
    "nebulizarmo": "nebulizar",
    "nebulizarmos": "nebulizar",
    "nebulizará": "nebulizar",
    "nebulizarás": "nebulizar",
    "nebulizarão": "nebulizar",
    "nebulizaríamos": "nebulizar",
    "nebulizaríeis": "nebulizar",
    "nebulizas": "nebulizar",
    "nebulizasse": "nebulizar",
    "nebulizassem": "nebulizar",
    "nebulizasses": "nebulizar",
    "nebulizaste": "nebulizar",
    "nebulizastes": "nebulizar",
    "nebulizava": "nebulizar",
    "nebulizavam": "nebulizar",
    "nebulizavas": "nebulizar",
    "nebulizações": "nebulização",
    "nebulize": "nebulizar",
    "nebulizei": "nebulizar",
    "nebulizeis": "nebulizar",
    "nebulizem": "nebulizar",
    "nebulizemo": "nebulizar",
    "nebulizemos": "nebulizar",
    "nebulizes": "nebulizar",
    "nebulizo": "nebulizar",
    "nebulizou": "nebulizar",
    "nebulizá": "nebulizar",
    "nebulizámo": "nebulizar",
    "nebulizámos": "nebulizar",
    "nebulizáramo": "nebulizar",
    "nebulizáramos": "nebulizar",
    "nebulizárei": "nebulizar",
    "nebulizáreis": "nebulizar",
    "nebulizásseis": "nebulizar",
    "nebulizássemos": "nebulizar",
    "nebulizávamo": "nebulizar",
    "nebulizávamos": "nebulizar",
    "nebulizávei": "nebulizar",
    "nebulizáveis": "nebulizar",
    "nebulosa": "nebuloso",
    "nebulosas": "nebuloso",
    "nebulosidades": "nebulosidade",
    "nebulosos": "nebuloso",
    "neceada": "necear",
    "neceadas": "necear",
    "neceado": "necear",
    "neceados": "necear",
    "neceai": "necear",
    "neceais": "necear",
    "neceamo": "necear",
    "neceamos": "necear",
    "neceando": "necear",
    "neceara": "necear",
    "necearam": "necear",
    "necearas": "necear",
    "neceardes": "necear",
    "necearei": "necear",
    "neceareis": "necear",
    "necearem": "necear",
    "necearemos": "necear",
    "neceares": "necear",
    "necearia": "necear",
    "neceariam": "necear",
    "necearias": "necear",
    "necearmo": "necear",
    "necearmos": "necear",
    "neceará": "necear",
    "necearás": "necear",
    "necearão": "necear",
    "necearíamos": "necear",
    "necearíeis": "necear",
    "neceasse": "necear",
    "neceassem": "necear",
    "neceasses": "necear",
    "neceaste": "necear",
    "neceastes": "necear",
    "neceava": "necear",
    "neceavam": "necear",
    "neceavas": "necear",
    "necedades": "necedade",
    "neceei": "necear",
    "neceeis": "necear",
    "neceemo": "necear",
    "neceemos": "necear",
    "neceia": "necear",
    "neceiam": "necear",
    "neceias": "necear",
    "neceie": "necear",
    "neceiem": "necear",
    "neceies": "necear",
    "neceio": "necear",
    "neceou": "necear",
    "necessidades": "necessidade",
    "necessita": "necessitar",
    "necessitada": "necessitar",
    "necessitadas": "necessitar",
    "necessitado": "necessitar",
    "necessitados": "necessitar",
    "necessitadíssima": "necessitado",
    "necessitadíssimas": "necessitado",
    "necessitadíssimo": "necessitado",
    "necessitadíssimos": "necessitado",
    "necessitai": "necessitar",
    "necessitais": "necessitar",
    "necessitam": "necessitar",
    "necessitamo": "necessitar",
    "necessitamos": "necessitar",
    "necessitando": "necessitar",
    "necessitantes": "necessitante",
    "necessitara": "necessitar",
    "necessitaram": "necessitar",
    "necessitaras": "necessitar",
    "necessitarde": "necessitar",
    "necessitardes": "necessitar",
    "necessitare": "necessitar",
    "necessitarei": "necessitar",
    "necessitareis": "necessitar",
    "necessitarem": "necessitar",
    "necessitaremos": "necessitar",
    "necessitares": "necessitar",
    "necessitaria": "necessitar",
    "necessitariam": "necessitar",
    "necessitarias": "necessitar",
    "necessitarmo": "necessitar",
    "necessitarmos": "necessitar",
    "necessitará": "necessitar",
    "necessitarás": "necessitar",
    "necessitarão": "necessitar",
    "necessitaríamos": "necessitar",
    "necessitaríeis": "necessitar",
    "necessitas": "necessitar",
    "necessitasse": "necessitar",
    "necessitassem": "necessitar",
    "necessitasses": "necessitar",
    "necessitaste": "necessitar",
    "necessitastes": "necessitar",
    "necessitava": "necessitar",
    "necessitavam": "necessitar",
    "necessitavas": "necessitar",
    "necessite": "necessitar",
    "necessitei": "necessitar",
    "necessiteis": "necessitar",
    "necessitem": "necessitar",
    "necessitemo": "necessitar",
    "necessitemos": "necessitar",
    "necessites": "necessitar",
    "necessito": "necessitar",
    "necessitosa": "necessitoso",
    "necessitosas": "necessitoso",
    "necessitosos": "necessitoso",
    "necessitou": "necessitar",
    "necessitá": "necessitar",
    "necessitámo": "necessitar",
    "necessitámos": "necessitar",
    "necessitáramo": "necessitar",
    "necessitáramos": "necessitar",
    "necessitárei": "necessitar",
    "necessitáreis": "necessitar",
    "necessitária": "necessitário",
    "necessitárias": "necessitário",
    "necessitários": "necessitário",
    "necessitásseis": "necessitar",
    "necessitássemos": "necessitar",
    "necessitávamo": "necessitar",
    "necessitávamos": "necessitar",
    "necessitávei": "necessitar",
    "necessitáveis": "necessitar",
    "necessária": "necessário",
    "necessárias": "necessário",
    "necessários": "necessário",
    "neceámo": "necear",
    "neceámos": "necear",
    "neceáramo": "necear",
    "neceáramos": "necear",
    "neceáreis": "necear",
    "neceásseis": "necear",
    "neceássemos": "necear",
    "neceávamo": "necear",
    "neceávamos": "necear",
    "neceáveis": "necear",
    "necrobioses": "necrobiose",
    "necrodulias": "necrodulia",
    "necrofagias": "necrofagia",
    "necrofilias": "necrofilia",
    "necrofoba": "necrofobo",
    "necrofobas": "necrofobo",
    "necrofobias": "necrofobia",
    "necrofobos": "necrofobo",
    "necrogénea": "necrogéneo",
    "necrogéneas": "necrogéneo",
    "necrogéneos": "necrogéneo",
    "necrolatras": "necrolatra",
    "necrolatrias": "necrolatria",
    "necrologias": "necrologia",
    "necrologistas": "necrologista",
    "necrológica": "necrológico",
    "necrológicas": "necrológico",
    "necrológicos": "necrológico",
    "necrológios": "necrológio",
    "necromancias": "necromancia",
    "necromantes": "necromante",
    "necromântica": "necromântico",
    "necromânticas": "necromântico",
    "necromânticos": "necromântico",
    "necropatas": "necropata",
    "necropatias": "necropatia",
    "necropsias": "necropsia",
    "necrosa": "necrosar",
    "necrosada": "necrosar",
    "necrosadas": "necrosar",
    "necrosado": "necrosar",
    "necrosados": "necrosar",
    "necrosai": "necrosar",
    "necrosais": "necrosar",
    "necrosam": "necrosar",
    "necrosamo": "necrosar",
    "necrosamos": "necrosar",
    "necrosando": "necrosar",
    "necrosara": "necrosar",
    "necrosaram": "necrosar",
    "necrosaras": "necrosar",
    "necrosarde": "necrosar",
    "necrosardes": "necrosar",
    "necrosare": "necrosar",
    "necrosarei": "necrosar",
    "necrosareis": "necrosar",
    "necrosarem": "necrosar",
    "necrosaremos": "necrosar",
    "necrosares": "necrosar",
    "necrosaria": "necrosar",
    "necrosariam": "necrosar",
    "necrosarias": "necrosar",
    "necrosarmo": "necrosar",
    "necrosarmos": "necrosar",
    "necrosará": "necrosar",
    "necrosarás": "necrosar",
    "necrosarão": "necrosar",
    "necrosaríamos": "necrosar",
    "necrosaríeis": "necrosar",
    "necrosas": "necrosar",
    "necrosasse": "necrosar",
    "necrosassem": "necrosar",
    "necrosasses": "necrosar",
    "necrosaste": "necrosar",
    "necrosastes": "necrosar",
    "necrosava": "necrosar",
    "necrosavam": "necrosar",
    "necrosavas": "necrosar",
    "necroscopias": "necroscopia",
    "necroscópica": "necroscópico",
    "necroscópicas": "necroscópico",
    "necroscópicos": "necroscópico",
    "necrose": "necrosar",
    "necrosei": "necrosar",
    "necroseis": "necrosar",
    "necrosem": "necrosar",
    "necrosemo": "necrosar",
    "necrosemos": "necrosar",
    "necroses": "necrose",
    "necroso": "necrosar",
    "necrosou": "necrosar",
    "necrosá": "necrosar",
    "necrosámo": "necrosar",
    "necrosámos": "necrosar",
    "necrosáramo": "necrosar",
    "necrosáramos": "necrosar",
    "necrosárei": "necrosar",
    "necrosáreis": "necrosar",
    "necrosásseis": "necrosar",
    "necrosássemos": "necrosar",
    "necrosávamo": "necrosar",
    "necrosávamos": "necrosar",
    "necrosávei": "necrosar",
    "necrosáveis": "necrosar",
    "necrotomias": "necrotomia",
    "necrotérios": "necrotério",
    "necróbias": "necróbia",
    "necrófaga": "necrófago",
    "necrófagas": "necrófago",
    "necrófagos": "necrófago",
    "necrófila": "necrófilo",
    "necrófilas": "necrófilo",
    "necrófilos": "necrófilo",
    "necrófoba": "necrófobo",
    "necrófobas": "necrófobo",
    "necrófobos": "necrófobo",
    "necróforos": "necróforo",
    "necrólatras": "necrólatra",
    "necróloga": "necrólogo",
    "necrólogas": "necrólogo",
    "necrólogos": "necrólogo",
    "necrópoles": "necrópole",
    "necróptica": "necróptico",
    "necrópticas": "necróptico",
    "necrópticos": "necróptico",
    "necrótica": "necrótico",
    "necróticas": "necrótico",
    "necróticos": "necrótico",
    "nectarinas": "nectarina",
    "nectariza": "nectarizar",
    "nectarizada": "nectarizar",
    "nectarizadas": "nectarizar",
    "nectarizado": "nectarizar",
    "nectarizados": "nectarizar",
    "nectarizai": "nectarizar",
    "nectarizais": "nectarizar",
    "nectarizam": "nectarizar",
    "nectarizamo": "nectarizar",
    "nectarizamos": "nectarizar",
    "nectarizando": "nectarizar",
    "nectarizara": "nectarizar",
    "nectarizaram": "nectarizar",
    "nectarizaras": "nectarizar",
    "nectarizarde": "nectarizar",
    "nectarizardes": "nectarizar",
    "nectarizare": "nectarizar",
    "nectarizarei": "nectarizar",
    "nectarizareis": "nectarizar",
    "nectarizarem": "nectarizar",
    "nectarizaremos": "nectarizar",
    "nectarizares": "nectarizar",
    "nectarizaria": "nectarizar",
    "nectarizariam": "nectarizar",
    "nectarizarias": "nectarizar",
    "nectarizarmo": "nectarizar",
    "nectarizarmos": "nectarizar",
    "nectarizará": "nectarizar",
    "nectarizarás": "nectarizar",
    "nectarizarão": "nectarizar",
    "nectarizaríamos": "nectarizar",
    "nectarizaríeis": "nectarizar",
    "nectarizas": "nectarizar",
    "nectarizasse": "nectarizar",
    "nectarizassem": "nectarizar",
    "nectarizasses": "nectarizar",
    "nectarizaste": "nectarizar",
    "nectarizastes": "nectarizar",
    "nectarizava": "nectarizar",
    "nectarizavam": "nectarizar",
    "nectarizavas": "nectarizar",
    "nectarize": "nectarizar",
    "nectarizei": "nectarizar",
    "nectarizeis": "nectarizar",
    "nectarizem": "nectarizar",
    "nectarizemo": "nectarizar",
    "nectarizemos": "nectarizar",
    "nectarizes": "nectarizar",
    "nectarizo": "nectarizar",
    "nectarizou": "nectarizar",
    "nectarizá": "nectarizar",
    "nectarizámo": "nectarizar",
    "nectarizámos": "nectarizar",
    "nectarizáramo": "nectarizar",
    "nectarizáramos": "nectarizar",
    "nectarizárei": "nectarizar",
    "nectarizáreis": "nectarizar",
    "nectarizásseis": "nectarizar",
    "nectarizássemos": "nectarizar",
    "nectarizávamo": "nectarizar",
    "nectarizávamos": "nectarizar",
    "nectarizávei": "nectarizar",
    "nectarizáveis": "nectarizar",
    "nectarífera": "nectarífero",
    "nectaríferas": "nectarífero",
    "nectaríferos": "nectarífero",
    "nectárea": "nectáreo",
    "nectáreas": "nectáreo",
    "nectáreos": "nectáreo",
    "nectários": "nectário",
    "necídalos": "necídalo",
    "nediez": "nedieza",
    "nediezas": "nedieza",
    "neerlandesa": "neerlandês",
    "neerlandesas": "neerlandês",
    "neerlandeses": "neerlandês",
    "nefanda": "nefando",
    "nefandas": "nefando",
    "nefandos": "nefando",
    "nefasta": "nefasto",
    "nefastas": "nefasto",
    "nefastos": "nefasto",
    "nefastíssima": "nefasto",
    "nefastíssimas": "nefasto",
    "nefastíssimo": "nefasto",
    "nefastíssimos": "nefasto",
    "nefelibatas": "nefelibata",
    "nefelibatices": "nefelibatice",
    "nefelibatismos": "nefelibatismo",
    "nefelibática": "nefelibático",
    "nefelibáticas": "nefelibático",
    "nefelibáticos": "nefelibático",
    "nefelinas": "nefelina",
    "nefelinitos": "nefelinito",
    "nefelometrias": "nefelometria",
    "nefelómetros": "nefelómetro",
    "nefoscópios": "nefoscópio",
    "nefralgias": "nefralgia",
    "nefrectasias": "nefrectasia",
    "nefrites": "nefrite",
    "nefroceles": "nefrocele",
    "nefrologias": "nefrologia",
    "nefrologistas": "nefrologista",
    "nefromas": "nefroma",
    "nefropias": "nefropia",
    "nefrostomias": "nefrostomia",
    "nefrotomias": "nefrotomia",
    "nefrálgica": "nefrálgico",
    "nefrálgicas": "nefrálgico",
    "nefrálgicos": "nefrálgico",
    "nefrídios": "nefrídio",
    "nefrítica": "nefrítico",
    "nefríticas": "nefrítico",
    "nefríticos": "nefrítico",
    "nefróides": "nefróide",
    "nefróloga": "nefrólogo",
    "nefrólogas": "nefrólogo",
    "nefrólogos": "nefrólogo",
    "nefróstomas": "nefróstoma",
    "nefróstomos": "nefróstomo",
    "nefária": "nefário",
    "nefárias": "nefário",
    "nefários": "nefário",
    "nefélios": "nefélio",
    "nega": "negar",
    "negaceada": "negacear",
    "negaceadas": "negacear",
    "negaceado": "negacear",
    "negaceadora": "negaceador",
    "negaceadoras": "negaceador",
    "negaceadores": "negaceador",
    "negaceados": "negacear",
    "negaceai": "negacear",
    "negaceais": "negacear",
    "negaceamo": "negacear",
    "negaceamos": "negacear",
    "negaceando": "negacear",
    "negaceara": "negacear",
    "negacearam": "negacear",
    "negacearas": "negacear",
    "negacearde": "negacear",
    "negaceardes": "negacear",
    "negaceare": "negacear",
    "negacearei": "negacear",
    "negaceareis": "negacear",
    "negacearem": "negacear",
    "negacearemos": "negacear",
    "negaceares": "negacear",
    "negacearia": "negacear",
    "negaceariam": "negacear",
    "negacearias": "negacear",
    "negacearmo": "negacear",
    "negacearmos": "negacear",
    "negaceará": "negacear",
    "negacearás": "negacear",
    "negacearão": "negacear",
    "negacearíamos": "negacear",
    "negacearíeis": "negacear",
    "negaceasse": "negacear",
    "negaceassem": "negacear",
    "negaceasses": "negacear",
    "negaceaste": "negacear",
    "negaceastes": "negacear",
    "negaceava": "negacear",
    "negaceavam": "negacear",
    "negaceavas": "negacear",
    "negaceei": "negacear",
    "negaceeis": "negacear",
    "negaceemo": "negacear",
    "negaceemos": "negacear",
    "negaceia": "negacear",
    "negaceiam": "negacear",
    "negaceias": "negacear",
    "negaceie": "negacear",
    "negaceiem": "negacear",
    "negaceies": "negacear",
    "negaceio": "negacear",
    "negaceira": "negaceiro",
    "negaceiras": "negaceiro",
    "negaceiros": "negaceiro",
    "negaceou": "negacear",
    "negaceá": "negacear",
    "negaceámo": "negacear",
    "negaceámos": "negacear",
    "negaceáramo": "negacear",
    "negaceáramos": "negacear",
    "negaceárei": "negacear",
    "negaceáreis": "negacear",
    "negaceásseis": "negacear",
    "negaceássemos": "negacear",
    "negaceávamo": "negacear",
    "negaceávamos": "negacear",
    "negaceávei": "negacear",
    "negaceáveis": "negacear",
    "negada": "negar",
    "negadas": "negar",
    "negado": "negar",
    "negadora": "negador",
    "negadoras": "negador",
    "negadores": "negador",
    "negados": "negar",
    "negai": "negar",
    "negais": "negar",
    "negalhos": "negalho",
    "negam": "negar",
    "negamo": "negar",
    "negamos": "negar",
    "negando": "negar",
    "negara": "negar",
    "negaram": "negar",
    "negaras": "negar",
    "negarde": "negar",
    "negardes": "negar",
    "negare": "negar",
    "negarei": "negar",
    "negareis": "negar",
    "negarem": "negar",
    "negaremos": "negar",
    "negares": "negar",
    "negaria": "negar",
    "negariam": "negar",
    "negarias": "negar",
    "negarmo": "negar",
    "negarmos": "negar",
    "negará": "negar",
    "negarás": "negar",
    "negarão": "negar",
    "negaríamos": "negar",
    "negaríeis": "negar",
    "negas": "negar",
    "negasse": "negar",
    "negassem": "negar",
    "negasses": "negar",
    "negaste": "negar",
    "negastes": "negar",
    "negativa": "negativo",
    "negativada": "negativar",
    "negativadas": "negativar",
    "negativado": "negativar",
    "negativados": "negativar",
    "negativai": "negativar",
    "negativais": "negativar",
    "negativam": "negativar",
    "negativamo": "negativar",
    "negativamos": "negativar",
    "negativando": "negativar",
    "negativara": "negativar",
    "negativaram": "negativar",
    "negativaras": "negativar",
    "negativarde": "negativar",
    "negativardes": "negativar",
    "negativare": "negativar",
    "negativarei": "negativar",
    "negativareis": "negativar",
    "negativarem": "negativar",
    "negativaremos": "negativar",
    "negativares": "negativar",
    "negativaria": "negativar",
    "negativariam": "negativar",
    "negativarias": "negativar",
    "negativarmo": "negativar",
    "negativarmos": "negativar",
    "negativará": "negativar",
    "negativarás": "negativar",
    "negativarão": "negativar",
    "negativaríamos": "negativar",
    "negativaríeis": "negativar",
    "negativas": "negativo",
    "negativasse": "negativar",
    "negativassem": "negativar",
    "negativasses": "negativar",
    "negativaste": "negativar",
    "negativastes": "negativar",
    "negativava": "negativar",
    "negativavam": "negativar",
    "negativavas": "negativar",
    "negative": "negativar",
    "negativei": "negativar",
    "negativeis": "negativar",
    "negativem": "negativar",
    "negativemo": "negativar",
    "negativemos": "negativar",
    "negatives": "negativar",
    "negatividades": "negatividade",
    "negativismos": "negativismo",
    "negativistas": "negativista",
    "negativo": "negativar",
    "negativos": "negativo",
    "negativou": "negativar",
    "negativá": "negativar",
    "negativámo": "negativar",
    "negativámos": "negativar",
    "negativáramo": "negativar",
    "negativáramos": "negativar",
    "negativárei": "negativar",
    "negativáreis": "negativar",
    "negativásseis": "negativar",
    "negativássemos": "negativar",
    "negativávamo": "negativar",
    "negativávamos": "negativar",
    "negativávei": "negativar",
    "negativáveis": "negativar",
    "negatoscópios": "negatoscópio",
    "negatrões": "negatrão",
    "negatória": "negatório",
    "negatórias": "negatório",
    "negatórios": "negatório",
    "negatões": "negatão",
    "negava": "negar",
    "negavam": "negar",
    "negavas": "negar",
    "negaças": "negaça",
    "negações": "negação",
    "negligencia": "negligenciar",
    "negligenciada": "negligenciar",
    "negligenciadas": "negligenciar",
    "negligenciado": "negligenciar",
    "negligenciados": "negligenciar",
    "negligenciai": "negligenciar",
    "negligenciais": "negligenciar",
    "negligenciam": "negligenciar",
    "negligenciamo": "negligenciar",
    "negligenciamos": "negligenciar",
    "negligenciando": "negligenciar",
    "negligenciara": "negligenciar",
    "negligenciaram": "negligenciar",
    "negligenciaras": "negligenciar",
    "negligenciarde": "negligenciar",
    "negligenciardes": "negligenciar",
    "negligenciare": "negligenciar",
    "negligenciarei": "negligenciar",
    "negligenciareis": "negligenciar",
    "negligenciarem": "negligenciar",
    "negligenciaremos": "negligenciar",
    "negligenciares": "negligenciar",
    "negligenciaria": "negligenciar",
    "negligenciariam": "negligenciar",
    "negligenciarias": "negligenciar",
    "negligenciarmo": "negligenciar",
    "negligenciarmos": "negligenciar",
    "negligenciará": "negligenciar",
    "negligenciarás": "negligenciar",
    "negligenciarão": "negligenciar",
    "negligenciaríamos": "negligenciar",
    "negligenciaríeis": "negligenciar",
    "negligencias": "negligenciar",
    "negligenciasse": "negligenciar",
    "negligenciassem": "negligenciar",
    "negligenciasses": "negligenciar",
    "negligenciaste": "negligenciar",
    "negligenciastes": "negligenciar",
    "negligenciava": "negligenciar",
    "negligenciavam": "negligenciar",
    "negligenciavas": "negligenciar",
    "negligencie": "negligenciar",
    "negligenciei": "negligenciar",
    "negligencieis": "negligenciar",
    "negligenciem": "negligenciar",
    "negligenciemo": "negligenciar",
    "negligenciemos": "negligenciar",
    "negligencies": "negligenciar",
    "negligencio": "negligenciar",
    "negligenciou": "negligenciar",
    "negligenciá": "negligenciar",
    "negligenciámo": "negligenciar",
    "negligenciámos": "negligenciar",
    "negligenciáramo": "negligenciar",
    "negligenciáramos": "negligenciar",
    "negligenciárei": "negligenciar",
    "negligenciáreis": "negligenciar",
    "negligenciásseis": "negligenciar",
    "negligenciássemos": "negligenciar",
    "negligenciávamo": "negligenciar",
    "negligenciávamos": "negligenciar",
    "negligenciávei": "negligenciar",
    "negligenciáveis": "negligenciável",
    "negligentes": "negligente",
    "negligências": "negligência",
    "nego": "negar",
    "negoceia": "negociar",
    "negoceiam": "negociar",
    "negoceias": "negociar",
    "negoceie": "negociar",
    "negoceiem": "negociar",
    "negoceies": "negociar",
    "negoceio": "negociar",
    "negocia": "negociar",
    "negociabilidades": "negociabilidade",
    "negociada": "negociar",
    "negociadas": "negociar",
    "negociado": "negociar",
    "negociadora": "negociador",
    "negociadoras": "negociador",
    "negociadores": "negociador",
    "negociados": "negociar",
    "negociai": "negociar",
    "negociais": "negociar",
    "negociam": "negociar",
    "negociamentos": "negociamento",
    "negociamo": "negociar",
    "negociamos": "negociar",
    "negociando": "negociar",
    "negociantes": "negociante",
    "negociara": "negociar",
    "negociaram": "negociar",
    "negociaras": "negociar",
    "negociarde": "negociar",
    "negociardes": "negociar",
    "negociare": "negociar",
    "negociarei": "negociar",
    "negociareis": "negociar",
    "negociarem": "negociar",
    "negociaremos": "negociar",
    "negociares": "negociar",
    "negociaria": "negociar",
    "negociariam": "negociar",
    "negociarias": "negociar",
    "negociarmo": "negociar",
    "negociarmos": "negociar",
    "negociará": "negociar",
    "negociarás": "negociar",
    "negociarão": "negociar",
    "negociaríamos": "negociar",
    "negociaríeis": "negociar",
    "negocias": "negociar",
    "negociasse": "negociar",
    "negociassem": "negociar",
    "negociasses": "negociar",
    "negociaste": "negociar",
    "negociastes": "negociar",
    "negociatas": "negociata",
    "negociava": "negociar",
    "negociavam": "negociar",
    "negociavas": "negociar",
    "negociações": "negociação",
    "negocie": "negociar",
    "negociei": "negociar",
    "negocieis": "negociar",
    "negociem": "negociar",
    "negociemo": "negociar",
    "negociemos": "negociar",
    "negocies": "negociar",
    "negocio": "negociar",
    "negociosa": "negocioso",
    "negociosas": "negocioso",
    "negociosos": "negocioso",
    "negociou": "negociar",
    "negociozinho": "negócio",
    "negociozinhos": "negócio",
    "negociozito": "negócio",
    "negociozitos": "negócio",
    "negocistas": "negocista",
    "negociá": "negociar",
    "negociámo": "negociar",
    "negociámos": "negociar",
    "negociáramo": "negociar",
    "negociáramos": "negociar",
    "negociárei": "negociar",
    "negociáreis": "negociar",
    "negociásseis": "negociar",
    "negociássemos": "negociar",
    "negociávamo": "negociar",
    "negociávamos": "negociar",
    "negociávei": "negociar",
    "negociáveis": "negociável",
    "negociões": "negocião",
    "negou": "negar",
    "negra": "negro",
    "negradas": "negrada",
    "negrainhas": "negrainha",
    "negrais": "negral",
    "negralhadas": "negralhada",
    "negralhona": "negralhão",
    "negralhonas": "negralhão",
    "negralhões": "negralhão",
    "negrarias": "negraria",
    "negras": "negro",
    "negrazinha": "negro",
    "negrazinhas": "negro",
    "negrazita": "negro",
    "negrazitas": "negro",
    "negraça": "negraço",
    "negraças": "negraço",
    "negraços": "negraço",
    "negregada": "negregado",
    "negregadas": "negregado",
    "negregados": "negregado",
    "negregosa": "negregoso",
    "negregosas": "negregoso",
    "negregosos": "negregoso",
    "negreguras": "negregura",
    "negreira": "negreiro",
    "negreiras": "negreiro",
    "negreiros": "negreiro",
    "negreja": "negrejar",
    "negrejada": "negrejar",
    "negrejadas": "negrejar",
    "negrejado": "negrejar",
    "negrejados": "negrejar",
    "negrejai": "negrejar",
    "negrejais": "negrejar",
    "negrejam": "negrejar",
    "negrejamentos": "negrejamento",
    "negrejamo": "negrejar",
    "negrejamos": "negrejar",
    "negrejando": "negrejar",
    "negrejantes": "negrejante",
    "negrejara": "negrejar",
    "negrejaram": "negrejar",
    "negrejaras": "negrejar",
    "negrejardes": "negrejar",
    "negrejarei": "negrejar",
    "negrejareis": "negrejar",
    "negrejarem": "negrejar",
    "negrejaremos": "negrejar",
    "negrejares": "negrejar",
    "negrejaria": "negrejar",
    "negrejariam": "negrejar",
    "negrejarias": "negrejar",
    "negrejarmo": "negrejar",
    "negrejarmos": "negrejar",
    "negrejará": "negrejar",
    "negrejarás": "negrejar",
    "negrejarão": "negrejar",
    "negrejaríamos": "negrejar",
    "negrejaríeis": "negrejar",
    "negrejas": "negrejar",
    "negrejasse": "negrejar",
    "negrejassem": "negrejar",
    "negrejasses": "negrejar",
    "negrejaste": "negrejar",
    "negrejastes": "negrejar",
    "negrejava": "negrejar",
    "negrejavam": "negrejar",
    "negrejavas": "negrejar",
    "negreje": "negrejar",
    "negrejei": "negrejar",
    "negrejeis": "negrejar",
    "negrejem": "negrejar",
    "negrejemo": "negrejar",
    "negrejemos": "negrejar",
    "negrejes": "negrejar",
    "negrejo": "negrejar",
    "negrejou": "negrejar",
    "negrejámo": "negrejar",
    "negrejámos": "negrejar",
    "negrejáramo": "negrejar",
    "negrejáramos": "negrejar",
    "negrejáreis": "negrejar",
    "negrejásseis": "negrejar",
    "negrejássemos": "negrejar",
    "negrejávamo": "negrejar",
    "negrejávamos": "negrejar",
    "negrejáveis": "negrejar",
    "negrelas": "negrela",
    "negridões": "negridão",
    "negrilha": "negrilho",
    "negrilhas": "negrilho",
    "negrilhos": "negrilho",
    "negrinha": "negro",
    "negrinhas": "negro",
    "negrinho": "negro",
    "negrinhos": "negro",
    "negrita": "negro",
    "negritas": "negro",
    "negrito": "negro",
    "negritos": "negro",
    "negritudes": "negritude",
    "negroas": "negroa",
    "negrofilias": "negrofilia",
    "negrofobias": "negrofobia",
    "negrolas": "negrola",
    "negrona": "negrão",
    "negronas": "negrão",
    "negrores": "negror",
    "negros": "negro",
    "negrota": "negrote",
    "negrotas": "negrote",
    "negrotes": "negrote",
    "negrozinho": "negro",
    "negrozinhos": "negro",
    "negrozito": "negro",
    "negrozitos": "negro",
    "negrumes": "negrume",
    "negruras": "negrura",
    "negríssima": "negro",
    "negríssimas": "negro",
    "negríssimo": "negro",
    "negríssimos": "negro",
    "negrófila": "negrófilo",
    "negrófilas": "negrófilo",
    "negrófilos": "negrófilo",
    "negrófoba": "negrófobo",
    "negrófobas": "negrófobo",
    "negrófobos": "negrófobo",
    "negróides": "negróide",
    "negrões": "negrão",
    "negue": "negar",
    "neguei": "negar",
    "negueis": "negar",
    "neguem": "negar",
    "neguemo": "negar",
    "neguemos": "negar",
    "negues": "negar",
    "neguses": "negus",
    "negá": "negar",
    "negámo": "negar",
    "negámos": "negar",
    "negáramo": "negar",
    "negáramos": "negar",
    "negárei": "negar",
    "negáreis": "negar",
    "negásseis": "negar",
    "negássemos": "negar",
    "negávamo": "negar",
    "negávamos": "negar",
    "negávei": "negar",
    "negáveis": "negável",
    "negócios": "negócio",
    "neles": "nele",
    "nelumbos": "nelumbo",
    "nelúmbios": "nelúmbio",
    "nematelmintes": "nematelminte",
    "nematocistos": "nematocisto",
    "nematodes": "nematode",
    "nematóides": "nematóide",
    "nembos": "nembo",
    "nemeia": "nemeu",
    "nemeias": "nemeu",
    "nemeus": "nemeu",
    "nemorais": "nemoral",
    "nemorosa": "nemoroso",
    "nemorosas": "nemoroso",
    "nemorosos": "nemoroso",
    "nemática": "nemático",
    "nemáticas": "nemático",
    "nemáticos": "nemático",
    "nemésias": "nemésia",
    "nemésica": "nemésico",
    "nemésicas": "nemésico",
    "nemésicos": "nemésico",
    "nenas": "nena",
    "nengras": "nengra",
    "nenhuma": "nenhum",
    "nenhumas": "nenhum",
    "nenhuns": "nenhum",
    "nenés": "nené",
    "nenúfares": "nenúfar",
    "neoburguesias": "neoburguesia",
    "neocalamitas": "neocalamita",
    "neocaledódea": "neocaledódeo",
    "neocaledódeas": "neocaledódeo",
    "neocaledódeos": "neocaledódeo",
    "neocaledónia": "neocaledónio",
    "neocaledónias": "neocaledónio",
    "neocaledónios": "neocaledónio",
    "neocatolicismos": "neocatolicismo",
    "neocatólica": "neocatólico",
    "neocatólicas": "neocatólico",
    "neocatólicos": "neocatólico",
    "neoceratódios": "neoceratódio",
    "neociências": "neociência",
    "neoclassicismos": "neoclassicismo",
    "neoclassicistas": "neoclassicista",
    "neoclássica": "neoclássico",
    "neoclássicas": "neoclássico",
    "neoclássicos": "neoclássico",
    "neocolonialismos": "neocolonialismo",
    "neocolonialistas": "neocolonialista",
    "neocomianos": "neocomiano",
    "neocomunistas": "neocomunista",
    "neoconservadora": "neoconservador",
    "neoconservadoras": "neoconservador",
    "neoconservadores": "neoconservador",
    "neocorporativismos": "neocorporativismo",
    "neocriticismos": "neocriticismo",
    "neocéltica": "neocéltico",
    "neocélticas": "neocéltico",
    "neocélticos": "neocéltico",
    "neodarwinismos": "neodarwinismo",
    "neodarwinistas": "neodarwinista",
    "neodímios": "neodímio",
    "neofascimos": "neofascimo",
    "neofascistas": "neofascista",
    "neofila": "neofilo",
    "neofilas": "neofilo",
    "neofilos": "neofilo",
    "neofobias": "neofobia",
    "neoformada": "neoformado",
    "neoformadas": "neoformado",
    "neoformados": "neoformado",
    "neoformações": "neoformação",
    "neogarrettiana": "neogarrettiano",
    "neogarrettianas": "neogarrettiano",
    "neogarrettianos": "neogarrettiano",
    "neogarrettismos": "neogarrettismo",
    "neografias": "neografia",
    "neogénea": "neogéneo",
    "neogéneas": "neogéneo",
    "neogéneos": "neogéneo",
    "neogénica": "neogénico",
    "neogénicas": "neogénico",
    "neogénicos": "neogénico",
    "neogótica": "neogótico",
    "neogóticas": "neogótico",
    "neogóticos": "neogótico",
    "neokantismos": "neokantismo",
    "neokantistas": "neokantista",
    "neolamarckismos": "neolamarckismo",
    "neolamarckistas": "neolamarckista",
    "neolatina": "neolatino",
    "neolatinas": "neolatino",
    "neolatinos": "neolatino",
    "neoliberais": "neoliberal",
    "neoliberalismos": "neoliberalismo",
    "neoliberalistas": "neoliberalista",
    "neologias": "neologia",
    "neologismos": "neologismo",
    "neologistas": "neologista",
    "neolítica": "neolítico",
    "neolíticas": "neolítico",
    "neolíticos": "neolítico",
    "neológica": "neológico",
    "neológicas": "neológico",
    "neológicos": "neológico",
    "neomalthusiana": "neomalthusiano",
    "neomalthusianas": "neomalthusiano",
    "neomalthusianismos": "neomalthusianismo",
    "neomalthusianistas": "neomalthusianista",
    "neomalthusianos": "neomalthusiano",
    "neomodernismos": "neomodernismo",
    "neomodernistas": "neomodernista",
    "neoménias": "neoménia",
    "neonata": "neonato",
    "neonatais": "neonatal",
    "neonatas": "neonato",
    "neonatologias": "neonatologia",
    "neonatos": "neonato",
    "neonazis": "neonazi",
    "neonazismos": "neonazismo",
    "neopilinas": "neopilina",
    "neoplasias": "neoplasia",
    "neoplasmas": "neoplasma",
    "neoplastias": "neoplastia",
    "neoplatonismos": "neoplatonismo",
    "neoplatonistas": "neoplatonista",
    "neoplatónica": "neoplatónico",
    "neoplatónicas": "neoplatónico",
    "neoplatónicos": "neoplatónico",
    "neoplásica": "neoplásico",
    "neoplásicas": "neoplásico",
    "neoplásicos": "neoplásico",
    "neoplástica": "neoplástico",
    "neoplásticas": "neoplástico",
    "neoplásticos": "neoplástico",
    "neopositivismos": "neopositivismo",
    "neopositivistas": "neopositivista",
    "neoprenos": "neopreno",
    "neoquinhentismos": "neoquinhentismo",
    "neoquinhentistas": "neoquinhentista",
    "neoramas": "neorama",
    "neotectónica": "neotectónico",
    "neotectónicas": "neotectónico",
    "neotectónicos": "neotectónico",
    "neotenias": "neotenia",
    "neoterismos": "neoterismo",
    "neotomismos": "neotomismo",
    "neotomistas": "neotomista",
    "neotérica": "neotérico",
    "neotéricas": "neotérico",
    "neotéricos": "neotérico",
    "neozelandesa": "neozelandês",
    "neozelandesas": "neozelandês",
    "neozelandeses": "neozelandês",
    "neozóica": "neozóico",
    "neozóicas": "neozóico",
    "neozóicos": "neozóico",
    "nepalenses": "nepalense",
    "nepalesa": "nepalês",
    "nepalesas": "nepalês",
    "nepaleses": "nepalês",
    "nepentes": "nepente",
    "neperiana": "neperiano",
    "neperianas": "neperiano",
    "neperianos": "neperiano",
    "nepotes": "nepote",
    "nepotismos": "nepotismo",
    "nepotistas": "nepotista",
    "neptunais": "neptunal",
    "neptuniana": "neptuniano",
    "neptunianas": "neptuniano",
    "neptunianos": "neptuniano",
    "neptunina": "neptunino",
    "neptuninas": "neptunino",
    "neptuninos": "neptunino",
    "neptunismos": "neptunismo",
    "neptunistas": "neptunista",
    "neptúnios": "neptúnio",
    "nequícias": "nequícia",
    "nereida": "nereide",
    "nereidas": "nereide",
    "nereides": "nereide",
    "nerineias": "nerineia",
    "neriáceas": "neriácea",
    "nervada": "nervado",
    "nervadas": "nervado",
    "nervados": "nervado",
    "nervais": "nerval",
    "nervações": "nervação",
    "nervina": "nervino",
    "nervinas": "nervino",
    "nervinos": "nervino",
    "nervos": "nervo",
    "nervosa": "nervoso",
    "nervosas": "nervoso",
    "nervoseiras": "nervoseira",
    "nervosidades": "nervosidade",
    "nervosismos": "nervosismo",
    "nervosos": "nervoso",
    "nervosíssima": "nervoso",
    "nervosíssimas": "nervoso",
    "nervosíssimo": "nervoso",
    "nervosíssimos": "nervoso",
    "nervuda": "nervudo",
    "nervudas": "nervudo",
    "nervudos": "nervudo",
    "nervuras": "nervura",
    "nerítica": "nerítico",
    "neríticas": "nerítico",
    "neríticos": "nerítico",
    "neróis": "nerol",
    "nesgas": "nesga",
    "nesginha": "nesga",
    "nesginhas": "nesga",
    "nesgita": "nesga",
    "nesgitas": "nesga",
    "nesografias": "nesografia",
    "nespereiras": "nespereira",
    "nespereiros": "nespereiro",
    "nestores": "nestor",
    "nestoriana": "nestoriano",
    "nestorianas": "nestoriano",
    "nestorianismos": "nestorianismo",
    "nestorianistas": "nestorianista",
    "nestorianos": "nestoriano",
    "neta": "neto",
    "netalhadas": "netalhada",
    "netas": "neto",
    "netinha": "neto",
    "netinhas": "neto",
    "netinho": "neto",
    "netinhos": "neto",
    "netita": "neto",
    "netitas": "neto",
    "netito": "neto",
    "netitos": "neto",
    "netos": "neto",
    "neumas": "neuma",
    "neumática": "neumático",
    "neumáticas": "neumático",
    "neumáticos": "neumático",
    "neurais": "neural",
    "neuralgias": "neuralgia",
    "neuralgismos": "neuralgismo",
    "neuras": "neura",
    "neurastenias": "neurastenia",
    "neurasteniza": "neurastenizar",
    "neurastenizada": "neurastenizar",
    "neurastenizadas": "neurastenizar",
    "neurastenizado": "neurastenizar",
    "neurastenizados": "neurastenizar",
    "neurastenizai": "neurastenizar",
    "neurastenizais": "neurastenizar",
    "neurastenizam": "neurastenizar",
    "neurastenizamo": "neurastenizar",
    "neurastenizamos": "neurastenizar",
    "neurastenizando": "neurastenizar",
    "neurastenizara": "neurastenizar",
    "neurastenizaram": "neurastenizar",
    "neurastenizaras": "neurastenizar",
    "neurastenizarde": "neurastenizar",
    "neurastenizardes": "neurastenizar",
    "neurastenizare": "neurastenizar",
    "neurastenizarei": "neurastenizar",
    "neurastenizareis": "neurastenizar",
    "neurastenizarem": "neurastenizar",
    "neurastenizaremos": "neurastenizar",
    "neurastenizares": "neurastenizar",
    "neurastenizaria": "neurastenizar",
    "neurastenizariam": "neurastenizar",
    "neurastenizarias": "neurastenizar",
    "neurastenizarmo": "neurastenizar",
    "neurastenizarmos": "neurastenizar",
    "neurastenizará": "neurastenizar",
    "neurastenizarás": "neurastenizar",
    "neurastenizarão": "neurastenizar",
    "neurastenizaríamos": "neurastenizar",
    "neurastenizaríeis": "neurastenizar",
    "neurastenizas": "neurastenizar",
    "neurastenizasse": "neurastenizar",
    "neurastenizassem": "neurastenizar",
    "neurastenizasses": "neurastenizar",
    "neurastenizaste": "neurastenizar",
    "neurastenizastes": "neurastenizar",
    "neurastenizava": "neurastenizar",
    "neurastenizavam": "neurastenizar",
    "neurastenizavas": "neurastenizar",
    "neurastenize": "neurastenizar",
    "neurastenizei": "neurastenizar",
    "neurastenizeis": "neurastenizar",
    "neurastenizem": "neurastenizar",
    "neurastenizemo": "neurastenizar",
    "neurastenizemos": "neurastenizar",
    "neurastenizes": "neurastenizar",
    "neurastenizo": "neurastenizar",
    "neurastenizou": "neurastenizar",
    "neurastenizá": "neurastenizar",
    "neurastenizámo": "neurastenizar",
    "neurastenizámos": "neurastenizar",
    "neurastenizáramo": "neurastenizar",
    "neurastenizáramos": "neurastenizar",
    "neurastenizárei": "neurastenizar",
    "neurastenizáreis": "neurastenizar",
    "neurastenizásseis": "neurastenizar",
    "neurastenizássemos": "neurastenizar",
    "neurastenizávamo": "neurastenizar",
    "neurastenizávamos": "neurastenizar",
    "neurastenizávei": "neurastenizar",
    "neurastenizáveis": "neurastenizar",
    "neurasténica": "neurasténico",
    "neurasténicas": "neurasténico",
    "neurasténicos": "neurasténico",
    "neurilemas": "neurilema",
    "neurilemites": "neurilemite",
    "neurilidades": "neurilidade",
    "neurilomas": "neuriloma",
    "neurites": "neurite",
    "neurobióloga": "neurobiólogo",
    "neurobiólogas": "neurobiólogo",
    "neurobiólogos": "neurobiólogo",
    "neurocirurgias": "neurocirurgia",
    "neurocirurgiã": "neurocirurgião",
    "neurocirurgiãos": "neurocirurgião",
    "neurocirurgiãs": "neurocirurgião",
    "neurocirurgiões": "neurocirurgião",
    "neurocirúrgica": "neurocirúrgico",
    "neurocirúrgicas": "neurocirúrgico",
    "neurocirúrgicos": "neurocirúrgico",
    "neurofisiologias": "neurofisiologia",
    "neurofrenias": "neurofrenia",
    "neurofrénica": "neurofrénico",
    "neurofrénicas": "neurofrénico",
    "neurofrénicos": "neurofrénico",
    "neurografias": "neurografia",
    "neurolepsias": "neurolepsia",
    "neurologias": "neurologia",
    "neurologistas": "neurologista",
    "neuroléptica": "neuroléptico",
    "neurolépticas": "neuroléptico",
    "neurolépticos": "neuroléptico",
    "neurológica": "neurológico",
    "neurológicas": "neurológico",
    "neurológicos": "neurológico",
    "neuromas": "neuroma",
    "neuromusculares": "neuromuscular",
    "neuronais": "neuronal",
    "neuroparalisias": "neuroparalisia",
    "neuropatas": "neuropata",
    "neuropatias": "neuropatia",
    "neuropatologias": "neuropatologia",
    "neuropatologistas": "neuropatologista",
    "neuropatológica": "neuropatológico",
    "neuropatológicas": "neuropatológico",
    "neuropatológicos": "neuropatológico",
    "neuropsiquiatras": "neuropsiquiatra",
    "neuropsiquiatrias": "neuropsiquiatria",
    "neuropsiquiátrica": "neuropsiquiátrico",
    "neuropsiquiátricas": "neuropsiquiátrico",
    "neuropsiquiátricos": "neuropsiquiátrico",
    "neuropsíquica": "neuropsíquico",
    "neuropsíquicas": "neuropsíquico",
    "neuropsíquicos": "neuropsíquico",
    "neuropática": "neuropático",
    "neuropáticas": "neuropático",
    "neuropáticos": "neuropático",
    "neuros": "neuro",
    "neuroses": "neurose",
    "neurotomias": "neurotomia",
    "neurotransmissores": "neurotransmissor",
    "neurotraumatismos": "neurotraumatismo",
    "neurotraumatologias": "neurotraumatologia",
    "neurotóxica": "neurotóxico",
    "neurotóxicas": "neurotóxico",
    "neurotóxicos": "neurotóxico",
    "neurovegetativa": "neurovegetativo",
    "neurovegetativas": "neurovegetativo",
    "neurovegetativos": "neurovegetativo",
    "neurálgica": "neurálgico",
    "neurálgicas": "neurálgico",
    "neurálgicos": "neurálgico",
    "neurófila": "neurófilo",
    "neurófilas": "neurófilo",
    "neurófilos": "neurófilo",
    "neuróglias": "neuróglia",
    "neuróloga": "neurólogo",
    "neurólogas": "neurólogo",
    "neurólogos": "neurólogo",
    "neurónica": "neurónico",
    "neurónicas": "neurónico",
    "neurónicos": "neurónico",
    "neurónios": "neurónio",
    "neurópteros": "neuróptero",
    "neurótica": "neurótico",
    "neuróticas": "neurótico",
    "neuróticos": "neurótico",
    "neurótomos": "neurótomo",
    "neutra": "neutro",
    "neutrais": "neutral",
    "neutralidades": "neutralidade",
    "neutralismos": "neutralismo",
    "neutralistas": "neutralista",
    "neutraliza": "neutralizar",
    "neutralizada": "neutralizar",
    "neutralizadas": "neutralizar",
    "neutralizado": "neutralizar",
    "neutralizadores": "neutralizador",
    "neutralizados": "neutralizar",
    "neutralizai": "neutralizar",
    "neutralizais": "neutralizar",
    "neutralizam": "neutralizar",
    "neutralizamo": "neutralizar",
    "neutralizamos": "neutralizar",
    "neutralizando": "neutralizar",
    "neutralizantes": "neutralizante",
    "neutralizara": "neutralizar",
    "neutralizaram": "neutralizar",
    "neutralizaras": "neutralizar",
    "neutralizarde": "neutralizar",
    "neutralizardes": "neutralizar",
    "neutralizare": "neutralizar",
    "neutralizarei": "neutralizar",
    "neutralizareis": "neutralizar",
    "neutralizarem": "neutralizar",
    "neutralizaremos": "neutralizar",
    "neutralizares": "neutralizar",
    "neutralizaria": "neutralizar",
    "neutralizariam": "neutralizar",
    "neutralizarias": "neutralizar",
    "neutralizarmo": "neutralizar",
    "neutralizarmos": "neutralizar",
    "neutralizará": "neutralizar",
    "neutralizarás": "neutralizar",
    "neutralizarão": "neutralizar",
    "neutralizaríamos": "neutralizar",
    "neutralizaríeis": "neutralizar",
    "neutralizas": "neutralizar",
    "neutralizasse": "neutralizar",
    "neutralizassem": "neutralizar",
    "neutralizasses": "neutralizar",
    "neutralizaste": "neutralizar",
    "neutralizastes": "neutralizar",
    "neutralizava": "neutralizar",
    "neutralizavam": "neutralizar",
    "neutralizavas": "neutralizar",
    "neutralizações": "neutralização",
    "neutralize": "neutralizar",
    "neutralizei": "neutralizar",
    "neutralizeis": "neutralizar",
    "neutralizem": "neutralizar",
    "neutralizemo": "neutralizar",
    "neutralizemos": "neutralizar",
    "neutralizes": "neutralizar",
    "neutralizo": "neutralizar",
    "neutralizou": "neutralizar",
    "neutralizá": "neutralizar",
    "neutralizámo": "neutralizar",
    "neutralizámos": "neutralizar",
    "neutralizáramo": "neutralizar",
    "neutralizáramos": "neutralizar",
    "neutralizárei": "neutralizar",
    "neutralizáreis": "neutralizar",
    "neutralizásseis": "neutralizar",
    "neutralizássemos": "neutralizar",
    "neutralizávamo": "neutralizar",
    "neutralizávamos": "neutralizar",
    "neutralizávei": "neutralizar",
    "neutralizáveis": "neutralizável",
    "neutralíssima": "neutral",
    "neutralíssimas": "neutral",
    "neutralíssimo": "neutral",
    "neutralíssimos": "neutral",
    "neutras": "neutro",
    "neutretos": "neutreto",
    "neutrinos": "neutrino",
    "neutropausas": "neutropausa",
    "neutros": "neutro",
    "neutrosferas": "neutrosfera",
    "neutrófila": "neutrófilo",
    "neutrófilas": "neutrófilo",
    "neutrófilos": "neutrófilo",
    "neutrónica": "neutrónico",
    "neutrónicas": "neutrónico",
    "neutrónicos": "neutrónico",
    "neutrões": "neutrão",
    "neva": "nevar",
    "nevada": "nevar",
    "nevadas": "nevar",
    "nevado": "nevar",
    "nevados": "nevar",
    "nevai": "nevar",
    "nevam": "nevar",
    "nevando": "nevar",
    "nevara": "nevar",
    "nevaram": "nevar",
    "nevardes": "nevar",
    "nevarem": "nevar",
    "nevares": "nevar",
    "nevaria": "nevar",
    "nevariam": "nevar",
    "nevarmos": "nevar",
    "nevará": "nevar",
    "nevarão": "nevar",
    "nevascas": "nevasca",
    "nevasqueiras": "nevasqueira",
    "nevasse": "nevar",
    "nevassem": "nevar",
    "nevasses": "nevar",
    "nevava": "nevar",
    "nevavam": "nevar",
    "nevações": "nevação",
    "neve": "nevar",
    "neveira": "neveiro",
    "neveiras": "neveiro",
    "neveiros": "neveiro",
    "neveis": "nevar",
    "nevem": "nevar",
    "neves": "neve",
    "nevisca": "neviscar",
    "neviscada": "neviscar",
    "neviscadas": "neviscar",
    "neviscado": "neviscar",
    "neviscados": "neviscar",
    "neviscais": "neviscar",
    "neviscam": "neviscar",
    "neviscamo": "neviscar",
    "neviscamos": "neviscar",
    "neviscando": "neviscar",
    "neviscara": "neviscar",
    "neviscaram": "neviscar",
    "neviscaras": "neviscar",
    "neviscardes": "neviscar",
    "neviscarei": "neviscar",
    "neviscareis": "neviscar",
    "neviscarem": "neviscar",
    "neviscaremos": "neviscar",
    "neviscares": "neviscar",
    "neviscaria": "neviscar",
    "neviscariam": "neviscar",
    "neviscarias": "neviscar",
    "neviscarmo": "neviscar",
    "neviscarmos": "neviscar",
    "neviscará": "neviscar",
    "neviscarás": "neviscar",
    "neviscarão": "neviscar",
    "neviscaríamos": "neviscar",
    "neviscaríeis": "neviscar",
    "neviscas": "neviscar",
    "neviscasse": "neviscar",
    "neviscassem": "neviscar",
    "neviscasses": "neviscar",
    "neviscaste": "neviscar",
    "neviscastes": "neviscar",
    "neviscava": "neviscar",
    "neviscavam": "neviscar",
    "neviscavas": "neviscar",
    "nevisco": "neviscar",
    "neviscou": "neviscar",
    "neviscámo": "neviscar",
    "neviscámos": "neviscar",
    "neviscáramo": "neviscar",
    "neviscáramos": "neviscar",
    "neviscáreis": "neviscar",
    "neviscásseis": "neviscar",
    "neviscássemos": "neviscar",
    "neviscávamo": "neviscar",
    "neviscávamos": "neviscar",
    "neviscáveis": "neviscar",
    "nevisque": "neviscar",
    "nevisquei": "neviscar",
    "nevisqueis": "neviscar",
    "nevisquem": "neviscar",
    "nevisquemos": "neviscar",
    "nevisques": "neviscar",
    "nevoa": "nevoar",
    "nevoada": "nevoar",
    "nevoadas": "nevoar",
    "nevoado": "nevoar",
    "nevoados": "nevoar",
    "nevoai": "nevoar",
    "nevoais": "nevoar",
    "nevoam": "nevoar",
    "nevoamo": "nevoar",
    "nevoamos": "nevoar",
    "nevoando": "nevoar",
    "nevoara": "nevoar",
    "nevoaram": "nevoar",
    "nevoaras": "nevoar",
    "nevoarde": "nevoar",
    "nevoardes": "nevoar",
    "nevoare": "nevoar",
    "nevoarei": "nevoar",
    "nevoareis": "nevoar",
    "nevoarem": "nevoar",
    "nevoaremos": "nevoar",
    "nevoares": "nevoar",
    "nevoaria": "nevoar",
    "nevoariam": "nevoar",
    "nevoarias": "nevoar",
    "nevoarmo": "nevoar",
    "nevoarmos": "nevoar",
    "nevoará": "nevoar",
    "nevoarás": "nevoar",
    "nevoarão": "nevoar",
    "nevoaríamos": "nevoar",
    "nevoaríeis": "nevoar",
    "nevoas": "nevoar",
    "nevoasse": "nevoar",
    "nevoassem": "nevoar",
    "nevoasses": "nevoar",
    "nevoaste": "nevoar",
    "nevoastes": "nevoar",
    "nevoava": "nevoar",
    "nevoavam": "nevoar",
    "nevoavas": "nevoar",
    "nevoaças": "nevoaça",
    "nevoe": "nevoar",
    "nevoei": "nevoar",
    "nevoeiradas": "nevoeirada",
    "nevoeiras": "nevoeira",
    "nevoeirenta": "nevoeirento",
    "nevoeirentas": "nevoeirento",
    "nevoeirentos": "nevoeirento",
    "nevoeiros": "nevoeiro",
    "nevoeis": "nevoar",
    "nevoem": "nevoar",
    "nevoemo": "nevoar",
    "nevoemos": "nevoar",
    "nevoenta": "nevoento",
    "nevoentada": "nevoentar",
    "nevoentadas": "nevoentar",
    "nevoentado": "nevoentar",
    "nevoentados": "nevoentar",
    "nevoentai": "nevoentar",
    "nevoentais": "nevoentar",
    "nevoentam": "nevoentar",
    "nevoentamo": "nevoentar",
    "nevoentamos": "nevoentar",
    "nevoentando": "nevoentar",
    "nevoentara": "nevoentar",
    "nevoentaram": "nevoentar",
    "nevoentaras": "nevoentar",
    "nevoentardes": "nevoentar",
    "nevoentarei": "nevoentar",
    "nevoentareis": "nevoentar",
    "nevoentarem": "nevoentar",
    "nevoentaremos": "nevoentar",
    "nevoentares": "nevoentar",
    "nevoentaria": "nevoentar",
    "nevoentariam": "nevoentar",
    "nevoentarias": "nevoentar",
    "nevoentarmo": "nevoentar",
    "nevoentarmos": "nevoentar",
    "nevoentará": "nevoentar",
    "nevoentarás": "nevoentar",
    "nevoentarão": "nevoentar",
    "nevoentaríamos": "nevoentar",
    "nevoentaríeis": "nevoentar",
    "nevoentas": "nevoento",
    "nevoentasse": "nevoentar",
    "nevoentassem": "nevoentar",
    "nevoentasses": "nevoentar",
    "nevoentaste": "nevoentar",
    "nevoentastes": "nevoentar",
    "nevoentava": "nevoentar",
    "nevoentavam": "nevoentar",
    "nevoentavas": "nevoentar",
    "nevoente": "nevoentar",
    "nevoentei": "nevoentar",
    "nevoenteis": "nevoentar",
    "nevoentem": "nevoentar",
    "nevoentemo": "nevoentar",
    "nevoentemos": "nevoentar",
    "nevoentes": "nevoentar",
    "nevoento": "nevoentar",
    "nevoentos": "nevoento",
    "nevoentou": "nevoentar",
    "nevoentámo": "nevoentar",
    "nevoentámos": "nevoentar",
    "nevoentáramo": "nevoentar",
    "nevoentáramos": "nevoentar",
    "nevoentáreis": "nevoentar",
    "nevoentásseis": "nevoentar",
    "nevoentássemos": "nevoentar",
    "nevoentávamo": "nevoentar",
    "nevoentávamos": "nevoentar",
    "nevoentáveis": "nevoentar",
    "nevoes": "nevoar",
    "nevoo": "nevoar",
    "nevoou": "nevoar",
    "nevos": "nevo",
    "nevosa": "nevoso",
    "nevosas": "nevoso",
    "nevosos": "nevoso",
    "nevou": "nevar",
    "nevoá": "nevoar",
    "nevoámo": "nevoar",
    "nevoámos": "nevoar",
    "nevoáramo": "nevoar",
    "nevoáramos": "nevoar",
    "nevoárei": "nevoar",
    "nevoáreis": "nevoar",
    "nevoásseis": "nevoar",
    "nevoássemos": "nevoar",
    "nevoávamo": "nevoar",
    "nevoávamos": "nevoar",
    "nevoávei": "nevoar",
    "nevoáveis": "nevoar",
    "nevralgias": "nevralgia",
    "nevralgismos": "nevralgismo",
    "nevrilemas": "nevrilema",
    "nevrilomas": "nevriloma",
    "nevrites": "nevrite",
    "nevrologias": "nevrologia",
    "nevrologistas": "nevrologista",
    "nevrológica": "nevrológico",
    "nevrológicas": "nevrológico",
    "nevrológicos": "nevrológico",
    "nevromas": "nevroma",
    "nevroparalisias": "nevroparalisia",
    "nevropatas": "nevropata",
    "nevropatias": "nevropatia",
    "nevropatologias": "nevropatologia",
    "nevropatologistas": "nevropatologista",
    "nevropática": "nevropático",
    "nevropáticas": "nevropático",
    "nevropáticos": "nevropático",
    "nevroses": "nevrose",
    "nevrosezinha": "nevrose",
    "nevrosezinhas": "nevrose",
    "nevrosezita": "nevrose",
    "nevrosezitas": "nevrose",
    "nevrostenias": "nevrostenia",
    "nevrotomias": "nevrotomia",
    "nevrálgica": "nevrálgico",
    "nevrálgicas": "nevrálgico",
    "nevrálgicos": "nevrálgico",
    "nevrítica": "nevrítico",
    "nevríticas": "nevrítico",
    "nevríticos": "nevrítico",
    "nevróglias": "nevróglia",
    "nevróloga": "nevrólogo",
    "nevrólogas": "nevrólogo",
    "nevrólogos": "nevrólogo",
    "nevrópteros": "nevróptero",
    "nevrótica": "nevrótico",
    "nevróticas": "nevrótico",
    "nevróticos": "nevrótico",
    "nevásseis": "nevar",
    "nevássemos": "nevar",
    "nevómetros": "nevómetro",
    "nevões": "nevão",
    "newtoniana": "newtoniano",
    "newtonianas": "newtoniano",
    "newtonianos": "newtoniano",
    "newtons": "newton",
    "nexos": "nexo",
    "neárticas": "neártica",
    "neófita": "neófito",
    "neófitas": "neófito",
    "neófitos": "neófito",
    "neófoba": "neófobo",
    "neófobas": "neófobo",
    "neófobos": "neófobo",
    "neógalas": "neógala",
    "neógama": "neógamo",
    "neógamas": "neógamo",
    "neógamos": "neógamo",
    "neógnatas": "neógnata",
    "neóloga": "neólogo",
    "neólogas": "neólogo",
    "neólogos": "neólogo",
    "neónios": "neónio",
    "neórnitas": "neórnita",
    "neótipos": "neótipo",
    "nhambis": "nhambi",
    "nhandis": "nhandi",
    "nhandus": "nhandu",
    "nhaques": "nhaque",
    "nhoques": "nhoque",
    "nhumbos": "nhumbo",
    "nhus": "nhu",
    "nhúndis": "nhúndi",
    "niaias": "niaia",
    "niais": "nial",
    "nica": "nicar",
    "nicada": "nicar",
    "nicadas": "nicar",
    "nicado": "nicar",
    "nicados": "nicar",
    "nicai": "nicar",
    "nicais": "nicar",
    "nicam": "nicar",
    "nicamo": "nicar",
    "nicamos": "nicar",
    "nicando": "nicar",
    "nicanços": "nicanço",
    "nicara": "nicar",
    "nicaraguana": "nicaraguano",
    "nicaraguanas": "nicaraguano",
    "nicaraguanos": "nicaraguano",
    "nicaraguenses": "nicaraguense",
    "nicaram": "nicar",
    "nicaras": "nicar",
    "nicarde": "nicar",
    "nicardes": "nicar",
    "nicare": "nicar",
    "nicarei": "nicar",
    "nicareis": "nicar",
    "nicarem": "nicar",
    "nicaremos": "nicar",
    "nicares": "nicar",
    "nicaria": "nicar",
    "nicariam": "nicar",
    "nicarias": "nicar",
    "nicarmo": "nicar",
    "nicarmos": "nicar",
    "nicará": "nicar",
    "nicarás": "nicar",
    "nicarão": "nicar",
    "nicaríamos": "nicar",
    "nicaríeis": "nicar",
    "nicas": "nicar",
    "nicasse": "nicar",
    "nicassem": "nicar",
    "nicasses": "nicar",
    "nicaste": "nicar",
    "nicastes": "nicar",
    "nicava": "nicar",
    "nicavam": "nicar",
    "nicavas": "nicar",
    "nicena": "niceno",
    "nicenas": "niceno",
    "nicenos": "niceno",
    "nichos": "nicho",
    "nico": "nicar",
    "nicocianas": "nicociana",
    "nicos": "nico",
    "nicotina": "nicotino",
    "nicotinamidas": "nicotinamida",
    "nicotinas": "nicotino",
    "nicotinismos": "nicotinismo",
    "nicotinos": "nicotino",
    "nicotiza": "nicotizar",
    "nicotizada": "nicotizar",
    "nicotizadas": "nicotizar",
    "nicotizado": "nicotizar",
    "nicotizados": "nicotizar",
    "nicotizai": "nicotizar",
    "nicotizais": "nicotizar",
    "nicotizam": "nicotizar",
    "nicotizamo": "nicotizar",
    "nicotizamos": "nicotizar",
    "nicotizando": "nicotizar",
    "nicotizara": "nicotizar",
    "nicotizaram": "nicotizar",
    "nicotizaras": "nicotizar",
    "nicotizarde": "nicotizar",
    "nicotizardes": "nicotizar",
    "nicotizare": "nicotizar",
    "nicotizarei": "nicotizar",
    "nicotizareis": "nicotizar",
    "nicotizarem": "nicotizar",
    "nicotizaremos": "nicotizar",
    "nicotizares": "nicotizar",
    "nicotizaria": "nicotizar",
    "nicotizariam": "nicotizar",
    "nicotizarias": "nicotizar",
    "nicotizarmo": "nicotizar",
    "nicotizarmos": "nicotizar",
    "nicotizará": "nicotizar",
    "nicotizarás": "nicotizar",
    "nicotizarão": "nicotizar",
    "nicotizaríamos": "nicotizar",
    "nicotizaríeis": "nicotizar",
    "nicotizas": "nicotizar",
    "nicotizasse": "nicotizar",
    "nicotizassem": "nicotizar",
    "nicotizasses": "nicotizar",
    "nicotizaste": "nicotizar",
    "nicotizastes": "nicotizar",
    "nicotizava": "nicotizar",
    "nicotizavam": "nicotizar",
    "nicotizavas": "nicotizar",
    "nicotize": "nicotizar",
    "nicotizei": "nicotizar",
    "nicotizeis": "nicotizar",
    "nicotizem": "nicotizar",
    "nicotizemo": "nicotizar",
    "nicotizemos": "nicotizar",
    "nicotizes": "nicotizar",
    "nicotizo": "nicotizar",
    "nicotizou": "nicotizar",
    "nicotizá": "nicotizar",
    "nicotizámo": "nicotizar",
    "nicotizámos": "nicotizar",
    "nicotizáramo": "nicotizar",
    "nicotizáramos": "nicotizar",
    "nicotizárei": "nicotizar",
    "nicotizáreis": "nicotizar",
    "nicotizásseis": "nicotizar",
    "nicotizássemos": "nicotizar",
    "nicotizávamo": "nicotizar",
    "nicotizávamos": "nicotizar",
    "nicotizávei": "nicotizar",
    "nicotizáveis": "nicotizar",
    "nicotínica": "nicotínico",
    "nicotínicas": "nicotínico",
    "nicotínicos": "nicotínico",
    "nicou": "nicar",
    "nicromos": "nicromo",
    "nictagináceas": "nictaginácea",
    "nictagínea": "nictagíneo",
    "nictagíneas": "nictagíneo",
    "nictagíneos": "nictagíneo",
    "nictalopes": "nictalope",
    "nictalopias": "nictalopia",
    "nictalópica": "nictalópico",
    "nictalópicas": "nictalópico",
    "nictalópicos": "nictalópico",
    "nictantes": "nictante",
    "nictações": "nictação",
    "nictitantes": "nictitante",
    "nictofobias": "nictofobia",
    "nictografias": "nictografia",
    "nictográfica": "nictográfico",
    "nictográficas": "nictográfico",
    "nictográficos": "nictográfico",
    "nictos": "nicto",
    "nictoscópios": "nictoscópio",
    "nictófila": "nictófilo",
    "nictófilas": "nictófilo",
    "nictófilos": "nictófilo",
    "nictófoba": "nictófobo",
    "nictófobas": "nictófobo",
    "nictófobos": "nictófobo",
    "nictógrafos": "nictógrafo",
    "nictómetros": "nictómetro",
    "nictúrias": "nictúria",
    "nicá": "nicar",
    "nicámo": "nicar",
    "nicámos": "nicar",
    "nicáramo": "nicar",
    "nicáramos": "nicar",
    "nicárei": "nicar",
    "nicáreis": "nicar",
    "nicásseis": "nicar",
    "nicássemos": "nicar",
    "nicávamo": "nicar",
    "nicávamos": "nicar",
    "nicávei": "nicar",
    "nicáveis": "nicar",
    "nicóis": "nicol",
    "nidações": "nidação",
    "nidifica": "nidificar",
    "nidificada": "nidificar",
    "nidificadas": "nidificar",
    "nidificado": "nidificar",
    "nidificados": "nidificar",
    "nidificais": "nidificar",
    "nidificam": "nidificar",
    "nidificamo": "nidificar",
    "nidificamos": "nidificar",
    "nidificando": "nidificar",
    "nidificara": "nidificar",
    "nidificaram": "nidificar",
    "nidificaras": "nidificar",
    "nidificardes": "nidificar",
    "nidificarei": "nidificar",
    "nidificareis": "nidificar",
    "nidificarem": "nidificar",
    "nidificaremos": "nidificar",
    "nidificares": "nidificar",
    "nidificaria": "nidificar",
    "nidificariam": "nidificar",
    "nidificarias": "nidificar",
    "nidificarmo": "nidificar",
    "nidificarmos": "nidificar",
    "nidificará": "nidificar",
    "nidificarás": "nidificar",
    "nidificarão": "nidificar",
    "nidificaríamos": "nidificar",
    "nidificaríeis": "nidificar",
    "nidificas": "nidificar",
    "nidificasse": "nidificar",
    "nidificassem": "nidificar",
    "nidificasses": "nidificar",
    "nidificaste": "nidificar",
    "nidificastes": "nidificar",
    "nidificava": "nidificar",
    "nidificavam": "nidificar",
    "nidificavas": "nidificar",
    "nidificações": "nidificação",
    "nidifico": "nidificar",
    "nidificou": "nidificar",
    "nidificámo": "nidificar",
    "nidificámos": "nidificar",
    "nidificáramo": "nidificar",
    "nidificáramos": "nidificar",
    "nidificáreis": "nidificar",
    "nidificásseis": "nidificar",
    "nidificássemos": "nidificar",
    "nidificávamo": "nidificar",
    "nidificávamos": "nidificar",
    "nidificáveis": "nidificar",
    "nidifique": "nidificar",
    "nidifiquei": "nidificar",
    "nidifiqueis": "nidificar",
    "nidifiquem": "nidificar",
    "nidifiquemos": "nidificar",
    "nidifiques": "nidificar",
    "nidiformes": "nidiforme",
    "nidores": "nidor",
    "nidorosa": "nidoroso",
    "nidorosas": "nidoroso",
    "nidorosos": "nidoroso",
    "nidícolas": "nidícola",
    "nidífuga": "nidífugo",
    "nidífugas": "nidífugo",
    "nidífugos": "nidífugo",
    "nieiros": "nieiro",
    "nielos": "nielo",
    "nietzschiana": "nietzschiano",
    "nietzschianas": "nietzschiano",
    "nietzschianos": "nietzschiano",
    "nifes": "nife",
    "nigela": "nigelar",
    "nigelada": "nigelar",
    "nigeladas": "nigelar",
    "nigelado": "nigelar",
    "nigelados": "nigelar",
    "nigelai": "nigelar",
    "nigelais": "nigelar",
    "nigelam": "nigelar",
    "nigelamo": "nigelar",
    "nigelamos": "nigelar",
    "nigelando": "nigelar",
    "nigelara": "nigelar",
    "nigelaram": "nigelar",
    "nigelaras": "nigelar",
    "nigelarde": "nigelar",
    "nigelardes": "nigelar",
    "nigelare": "nigelar",
    "nigelarei": "nigelar",
    "nigelareis": "nigelar",
    "nigelarem": "nigelar",
    "nigelaremos": "nigelar",
    "nigelares": "nigelar",
    "nigelaria": "nigelar",
    "nigelariam": "nigelar",
    "nigelarias": "nigelar",
    "nigelarmo": "nigelar",
    "nigelarmos": "nigelar",
    "nigelará": "nigelar",
    "nigelarás": "nigelar",
    "nigelarão": "nigelar",
    "nigelaríamos": "nigelar",
    "nigelaríeis": "nigelar",
    "nigelas": "nigelar",
    "nigelasse": "nigelar",
    "nigelassem": "nigelar",
    "nigelasses": "nigelar",
    "nigelaste": "nigelar",
    "nigelastes": "nigelar",
    "nigelava": "nigelar",
    "nigelavam": "nigelar",
    "nigelavas": "nigelar",
    "nigele": "nigelar",
    "nigelei": "nigelar",
    "nigeleis": "nigelar",
    "nigelem": "nigelar",
    "nigelemo": "nigelar",
    "nigelemos": "nigelar",
    "nigeles": "nigelar",
    "nigelinas": "nigelina",
    "nigelo": "nigelar",
    "nigelos": "nigelo",
    "nigelou": "nigelar",
    "nigelá": "nigelar",
    "nigelámo": "nigelar",
    "nigelámos": "nigelar",
    "nigeláramo": "nigelar",
    "nigeláramos": "nigelar",
    "nigelárei": "nigelar",
    "nigeláreis": "nigelar",
    "nigelásseis": "nigelar",
    "nigelássemos": "nigelar",
    "nigelávamo": "nigelar",
    "nigelávamos": "nigelar",
    "nigelávei": "nigelar",
    "nigeláveis": "nigelar",
    "nigeriana": "nigeriano",
    "nigerianas": "nigeriano",
    "nigerianos": "nigeriano",
    "nigricórnea": "nigricórneo",
    "nigricórneas": "nigricórneo",
    "nigricórneos": "nigricórneo",
    "nigripenes": "nigripene",
    "nigrirrostra": "nigrirrostro",
    "nigrirrostras": "nigrirrostro",
    "nigrirrostros": "nigrirrostro",
    "nigromancias": "nigromancia",
    "nigromantes": "nigromante",
    "nigromântica": "nigromântico",
    "nigromânticas": "nigromântico",
    "nigromânticos": "nigromântico",
    "nigrícias": "nigrícia",
    "nigrípedes": "nigrípede",
    "nigérrima": "negro",
    "nigérrimas": "negro",
    "nigérrimo": "negro",
    "nigérrimos": "negro",
    "niilificações": "niilificação",
    "niilismos": "niilismo",
    "niilistas": "niilista",
    "nilgós": "nilgó",
    "nilpotentes": "nilpotente",
    "nilómetros": "nilómetro",
    "nilótica": "nilótico",
    "nilóticas": "nilótico",
    "nilóticos": "nilótico",
    "nimba": "nimbar",
    "nimbada": "nimbar",
    "nimbadas": "nimbar",
    "nimbado": "nimbar",
    "nimbados": "nimbar",
    "nimbai": "nimbar",
    "nimbais": "nimbar",
    "nimbam": "nimbar",
    "nimbamo": "nimbar",
    "nimbamos": "nimbar",
    "nimbando": "nimbar",
    "nimbara": "nimbar",
    "nimbaram": "nimbar",
    "nimbaras": "nimbar",
    "nimbarde": "nimbar",
    "nimbardes": "nimbar",
    "nimbare": "nimbar",
    "nimbarei": "nimbar",
    "nimbareis": "nimbar",
    "nimbarem": "nimbar",
    "nimbaremos": "nimbar",
    "nimbares": "nimbar",
    "nimbaria": "nimbar",
    "nimbariam": "nimbar",
    "nimbarias": "nimbar",
    "nimbarmo": "nimbar",
    "nimbarmos": "nimbar",
    "nimbará": "nimbar",
    "nimbarás": "nimbar",
    "nimbarão": "nimbar",
    "nimbaríamos": "nimbar",
    "nimbaríeis": "nimbar",
    "nimbas": "nimbar",
    "nimbasse": "nimbar",
    "nimbassem": "nimbar",
    "nimbasses": "nimbar",
    "nimbaste": "nimbar",
    "nimbastes": "nimbar",
    "nimbava": "nimbar",
    "nimbavam": "nimbar",
    "nimbavas": "nimbar",
    "nimbe": "nimbar",
    "nimbei": "nimbar",
    "nimbeis": "nimbar",
    "nimbem": "nimbar",
    "nimbemo": "nimbar",
    "nimbemos": "nimbar",
    "nimbes": "nimbar",
    "nimbo": "nimbar",
    "nimbos": "nimbo",
    "nimbosa": "nimboso",
    "nimbosas": "nimboso",
    "nimbosos": "nimboso",
    "nimbou": "nimbar",
    "nimbá": "nimbar",
    "nimbámo": "nimbar",
    "nimbámos": "nimbar",
    "nimbáramo": "nimbar",
    "nimbáramos": "nimbar",
    "nimbárei": "nimbar",
    "nimbáreis": "nimbar",
    "nimbásseis": "nimbar",
    "nimbássemos": "nimbar",
    "nimbávamo": "nimbar",
    "nimbávamos": "nimbar",
    "nimbávei": "nimbar",
    "nimbáveis": "nimbar",
    "nimbífera": "nimbífero",
    "nimbíferas": "nimbífero",
    "nimbíferos": "nimbífero",
    "nimiedades": "nimiedade",
    "nimiíssima": "nímio",
    "nimiíssimas": "nímio",
    "nimiíssimo": "nímio",
    "nimiíssimos": "nímio",
    "nina": "nino",
    "ninada": "ninar",
    "ninadas": "ninar",
    "ninado": "ninar",
    "ninados": "ninar",
    "ninai": "ninar",
    "ninais": "ninar",
    "ninam": "ninar",
    "ninamo": "ninar",
    "ninamos": "ninar",
    "ninando": "ninar",
    "ninara": "ninar",
    "ninaram": "ninar",
    "ninaras": "ninar",
    "ninarde": "ninar",
    "ninardes": "ninar",
    "ninare": "ninar",
    "ninarei": "ninar",
    "ninareis": "ninar",
    "ninarem": "ninar",
    "ninaremos": "ninar",
    "ninares": "ninar",
    "ninaria": "ninar",
    "ninariam": "ninar",
    "ninarias": "ninar",
    "ninarmo": "ninar",
    "ninarmos": "ninar",
    "ninará": "ninar",
    "ninarás": "ninar",
    "ninarão": "ninar",
    "ninaríamos": "ninar",
    "ninaríeis": "ninar",
    "ninas": "nino",
    "ninasse": "ninar",
    "ninassem": "ninar",
    "ninasses": "ninar",
    "ninaste": "ninar",
    "ninastes": "ninar",
    "ninava": "ninar",
    "ninavam": "ninar",
    "ninavas": "ninar",
    "nine": "ninar",
    "ninei": "ninar",
    "nineis": "ninar",
    "ninem": "ninar",
    "ninemo": "ninar",
    "ninemos": "ninar",
    "nines": "ninar",
    "ninfalídeos": "ninfalídeo",
    "ninfas": "ninfa",
    "ninfeia": "ninfeu",
    "ninfeias": "ninfeu",
    "ninfeus": "ninfeu",
    "ninfeácea": "ninfeáceo",
    "ninfeáceas": "ninfeáceo",
    "ninfeáceos": "ninfeáceo",
    "ninfomanias": "ninfomania",
    "ninfomaníacas": "ninfomaníaca",
    "ninfoses": "ninfose",
    "ninfotomias": "ninfotomia",
    "ninfálidas": "ninfálida",
    "ninfóides": "ninfóide",
    "ninfómanas": "ninfómana",
    "ningrimanços": "ningrimanço",
    "ninha": "ninhar",
    "ninhada": "ninhar",
    "ninhadas": "ninhar",
    "ninhado": "ninhar",
    "ninhados": "ninhar",
    "ninhai": "ninhar",
    "ninhais": "ninhar",
    "ninham": "ninhar",
    "ninhamo": "ninhar",
    "ninhamos": "ninhar",
    "ninhando": "ninhar",
    "ninhara": "ninhar",
    "ninharam": "ninhar",
    "ninharas": "ninhar",
    "ninhardes": "ninhar",
    "ninharei": "ninhar",
    "ninhareis": "ninhar",
    "ninharem": "ninhar",
    "ninharemos": "ninhar",
    "ninhares": "ninhar",
    "ninharia": "ninhar",
    "ninhariam": "ninhar",
    "ninharias": "ninharia",
    "ninharmo": "ninhar",
    "ninharmos": "ninhar",
    "ninhará": "ninhar",
    "ninharás": "ninhar",
    "ninharão": "ninhar",
    "ninharíamos": "ninhar",
    "ninharíeis": "ninhar",
    "ninhas": "ninhar",
    "ninhasse": "ninhar",
    "ninhassem": "ninhar",
    "ninhasses": "ninhar",
    "ninhaste": "ninhar",
    "ninhastes": "ninhar",
    "ninhava": "ninhar",
    "ninhavam": "ninhar",
    "ninhavas": "ninhar",
    "ninhe": "ninhar",
    "ninhega": "ninhego",
    "ninhegas": "ninhego",
    "ninhegos": "ninhego",
    "ninhei": "ninhar",
    "ninheira": "ninheiro",
    "ninheiras": "ninheiro",
    "ninheiros": "ninheiro",
    "ninheis": "ninhar",
    "ninhem": "ninhar",
    "ninhemo": "ninhar",
    "ninhemos": "ninhar",
    "ninhes": "ninhar",
    "ninho": "ninhar",
    "ninhos": "ninho",
    "ninhou": "ninhar",
    "ninhámo": "ninhar",
    "ninhámos": "ninhar",
    "ninháramo": "ninhar",
    "ninháramos": "ninhar",
    "ninháreis": "ninhar",
    "ninhásseis": "ninhar",
    "ninhássemos": "ninhar",
    "ninhávamo": "ninhar",
    "ninhávamos": "ninhar",
    "ninháveis": "ninhar",
    "ninis": "nini",
    "ninivitas": "ninivita",
    "ninjas": "ninja",
    "nino": "ninar",
    "ninos": "nino",
    "ninou": "ninar",
    "niná": "ninar",
    "ninámo": "ninar",
    "ninámos": "ninar",
    "nináramo": "ninar",
    "nináramos": "ninar",
    "ninárei": "ninar",
    "nináreis": "ninar",
    "ninásseis": "ninar",
    "ninássemos": "ninar",
    "ninávamo": "ninar",
    "ninávamos": "ninar",
    "ninávei": "ninar",
    "nináveis": "ninar",
    "niponenses": "niponense",
    "niponica": "niponico",
    "niponicas": "niponico",
    "niponicos": "niponico",
    "nipónica": "nipónico",
    "nipónicas": "nipónico",
    "nipónicos": "nipónico",
    "nique": "nicar",
    "niquei": "nicar",
    "niqueira": "niqueiro",
    "niqueiras": "niqueiro",
    "niqueiros": "niqueiro",
    "niqueis": "nicar",
    "niquela": "niquelar",
    "niquelada": "niquelar",
    "niqueladas": "niquelar",
    "niquelado": "niquelar",
    "niquelados": "niquelar",
    "niquelagens": "niquelagem",
    "niquelai": "niquelar",
    "niquelais": "niquelar",
    "niquelam": "niquelar",
    "niquelamo": "niquelar",
    "niquelamos": "niquelar",
    "niquelando": "niquelar",
    "niquelara": "niquelar",
    "niquelaram": "niquelar",
    "niquelaras": "niquelar",
    "niquelarde": "niquelar",
    "niquelardes": "niquelar",
    "niquelare": "niquelar",
    "niquelarei": "niquelar",
    "niquelareis": "niquelar",
    "niquelarem": "niquelar",
    "niquelaremos": "niquelar",
    "niquelares": "niquelar",
    "niquelaria": "niquelar",
    "niquelariam": "niquelar",
    "niquelarias": "niquelar",
    "niquelarmo": "niquelar",
    "niquelarmos": "niquelar",
    "niquelará": "niquelar",
    "niquelarás": "niquelar",
    "niquelarão": "niquelar",
    "niquelaríamos": "niquelar",
    "niquelaríeis": "niquelar",
    "niquelas": "niquelar",
    "niquelasse": "niquelar",
    "niquelassem": "niquelar",
    "niquelasses": "niquelar",
    "niquelaste": "niquelar",
    "niquelastes": "niquelar",
    "niquelava": "niquelar",
    "niquelavam": "niquelar",
    "niquelavas": "niquelar",
    "niquele": "niquelar",
    "niquelei": "niquelar",
    "niqueleis": "niquelar",
    "niquelem": "niquelar",
    "niquelemo": "niquelar",
    "niquelemos": "niquelar",
    "niqueles": "niquelar",
    "niquelinas": "niquelina",
    "niquelo": "niquelar",
    "niquelou": "niquelar",
    "niquelá": "niquelar",
    "niquelámo": "niquelar",
    "niquelámos": "niquelar",
    "niqueláramo": "niquelar",
    "niqueláramos": "niquelar",
    "niquelárei": "niquelar",
    "niqueláreis": "niquelar",
    "niquelásseis": "niquelar",
    "niquelássemos": "niquelar",
    "niquelávamo": "niquelar",
    "niquelávamos": "niquelar",
    "niquelávei": "niquelar",
    "niqueláveis": "niquelar",
    "niquelífera": "niquelífero",
    "niquelíferas": "niquelífero",
    "niquelíferos": "niquelífero",
    "niquem": "nicar",
    "niquemo": "nicar",
    "niquemos": "nicar",
    "niquenta": "niquento",
    "niquentas": "niquento",
    "niquentos": "niquento",
    "niques": "nicar",
    "niquices": "niquice",
    "niquinho": "nico",
    "niquinhos": "nico",
    "niquito": "nico",
    "niquitos": "nico",
    "nirvanas": "nirvana",
    "nirvanistas": "nirvanista",
    "nirvânica": "nirvânico",
    "nirvânicas": "nirvânico",
    "nirvânicos": "nirvânico",
    "nis": "nil",
    "niscatos": "niscato",
    "nitentes": "nitente",
    "nitescências": "nitescência",
    "nitidezes": "nitidez",
    "nitidiflora": "nitidifloro",
    "nitidifloras": "nitidifloro",
    "nitidifloros": "nitidifloro",
    "nitidíssima": "nítido",
    "nitidíssimas": "nítido",
    "nitidíssimo": "nítido",
    "nitidíssimos": "nítido",
    "nitra": "nitrir",
    "nitrada": "nitrar",
    "nitradas": "nitrar",
    "nitrado": "nitrar",
    "nitrados": "nitrar",
    "nitrai": "nitrar",
    "nitrais": "nitrar",
    "nitram": "nitrir",
    "nitramo": "nitrar",
    "nitramos": "nitrar",
    "nitrando": "nitrar",
    "nitrara": "nitrar",
    "nitraram": "nitrar",
    "nitraras": "nitrar",
    "nitrarde": "nitrar",
    "nitrardes": "nitrar",
    "nitrare": "nitrar",
    "nitrarei": "nitrar",
    "nitrareis": "nitrar",
    "nitrarem": "nitrar",
    "nitraremos": "nitrar",
    "nitrares": "nitrar",
    "nitraria": "nitrar",
    "nitrariam": "nitrar",
    "nitrarias": "nitrar",
    "nitrarmo": "nitrar",
    "nitrarmos": "nitrar",
    "nitrará": "nitrar",
    "nitrarás": "nitrar",
    "nitrarão": "nitrar",
    "nitraríamos": "nitrar",
    "nitraríeis": "nitrar",
    "nitras": "nitrar",
    "nitrasse": "nitrar",
    "nitrassem": "nitrar",
    "nitrasses": "nitrar",
    "nitraste": "nitrar",
    "nitrastes": "nitrar",
    "nitrata": "nitratar",
    "nitratada": "nitratar",
    "nitratadas": "nitratar",
    "nitratado": "nitratar",
    "nitratados": "nitratar",
    "nitratai": "nitratar",
    "nitratais": "nitratar",
    "nitratam": "nitratar",
    "nitratamo": "nitratar",
    "nitratamos": "nitratar",
    "nitratando": "nitratar",
    "nitratara": "nitratar",
    "nitrataram": "nitratar",
    "nitrataras": "nitratar",
    "nitratarde": "nitratar",
    "nitratardes": "nitratar",
    "nitratare": "nitratar",
    "nitratarei": "nitratar",
    "nitratareis": "nitratar",
    "nitratarem": "nitratar",
    "nitrataremos": "nitratar",
    "nitratares": "nitratar",
    "nitrataria": "nitratar",
    "nitratariam": "nitratar",
    "nitratarias": "nitratar",
    "nitratarmo": "nitratar",
    "nitratarmos": "nitratar",
    "nitratará": "nitratar",
    "nitratarás": "nitratar",
    "nitratarão": "nitratar",
    "nitrataríamos": "nitratar",
    "nitrataríeis": "nitratar",
    "nitratas": "nitratar",
    "nitratasse": "nitratar",
    "nitratassem": "nitratar",
    "nitratasses": "nitratar",
    "nitrataste": "nitratar",
    "nitratastes": "nitratar",
    "nitratava": "nitratar",
    "nitratavam": "nitratar",
    "nitratavas": "nitratar",
    "nitratações": "nitratação",
    "nitrate": "nitratar",
    "nitratei": "nitratar",
    "nitrateis": "nitratar",
    "nitratem": "nitratar",
    "nitratemo": "nitratar",
    "nitratemos": "nitratar",
    "nitrates": "nitratar",
    "nitrato": "nitratar",
    "nitratos": "nitrato",
    "nitratou": "nitratar",
    "nitratá": "nitratar",
    "nitratámo": "nitratar",
    "nitratámos": "nitratar",
    "nitratáramo": "nitratar",
    "nitratáramos": "nitratar",
    "nitratárei": "nitratar",
    "nitratáreis": "nitratar",
    "nitratásseis": "nitratar",
    "nitratássemos": "nitratar",
    "nitratávamo": "nitratar",
    "nitratávamos": "nitratar",
    "nitratávei": "nitratar",
    "nitratáveis": "nitratar",
    "nitrava": "nitrar",
    "nitravam": "nitrar",
    "nitravas": "nitrar",
    "nitrações": "nitração",
    "nitre": "nitrir",
    "nitrei": "nitrar",
    "nitreiras": "nitreira",
    "nitreis": "nitrar",
    "nitrem": "nitrir",
    "nitremo": "nitrar",
    "nitremos": "nitrar",
    "nitres": "nitrar",
    "nitria": "nitrir",
    "nitriam": "nitrir",
    "nitrida": "nitrir",
    "nitridas": "nitrir",
    "nitrido": "nitrir",
    "nitridora": "nitridor",
    "nitridoras": "nitridor",
    "nitridores": "nitridor",
    "nitridos": "nitrir",
    "nitrifica": "nitrificar",
    "nitrificada": "nitrificar",
    "nitrificadas": "nitrificar",
    "nitrificado": "nitrificar",
    "nitrificados": "nitrificar",
    "nitrificai": "nitrificar",
    "nitrificais": "nitrificar",
    "nitrificam": "nitrificar",
    "nitrificamo": "nitrificar",
    "nitrificamos": "nitrificar",
    "nitrificando": "nitrificar",
    "nitrificantes": "nitrificante",
    "nitrificara": "nitrificar",
    "nitrificaram": "nitrificar",
    "nitrificaras": "nitrificar",
    "nitrificarde": "nitrificar",
    "nitrificardes": "nitrificar",
    "nitrificare": "nitrificar",
    "nitrificarei": "nitrificar",
    "nitrificareis": "nitrificar",
    "nitrificarem": "nitrificar",
    "nitrificaremos": "nitrificar",
    "nitrificares": "nitrificar",
    "nitrificaria": "nitrificar",
    "nitrificariam": "nitrificar",
    "nitrificarias": "nitrificar",
    "nitrificarmo": "nitrificar",
    "nitrificarmos": "nitrificar",
    "nitrificará": "nitrificar",
    "nitrificarás": "nitrificar",
    "nitrificarão": "nitrificar",
    "nitrificaríamos": "nitrificar",
    "nitrificaríeis": "nitrificar",
    "nitrificas": "nitrificar",
    "nitrificasse": "nitrificar",
    "nitrificassem": "nitrificar",
    "nitrificasses": "nitrificar",
    "nitrificaste": "nitrificar",
    "nitrificastes": "nitrificar",
    "nitrificava": "nitrificar",
    "nitrificavam": "nitrificar",
    "nitrificavas": "nitrificar",
    "nitrificações": "nitrificação",
    "nitrifico": "nitrificar",
    "nitrificou": "nitrificar",
    "nitrificá": "nitrificar",
    "nitrificámo": "nitrificar",
    "nitrificámos": "nitrificar",
    "nitrificáramo": "nitrificar",
    "nitrificáramos": "nitrificar",
    "nitrificárei": "nitrificar",
    "nitrificáreis": "nitrificar",
    "nitrificásseis": "nitrificar",
    "nitrificássemos": "nitrificar",
    "nitrificávamo": "nitrificar",
    "nitrificávamos": "nitrificar",
    "nitrificávei": "nitrificar",
    "nitrificáveis": "nitrificável",
    "nitrifique": "nitrificar",
    "nitrifiquei": "nitrificar",
    "nitrifiqueis": "nitrificar",
    "nitrifiquem": "nitrificar",
    "nitrifiquemo": "nitrificar",
    "nitrifiquemos": "nitrificar",
    "nitrifiques": "nitrificar",
    "nitrilos": "nitrilo",
    "nitrindo": "nitrir",
    "nitrira": "nitrir",
    "nitriram": "nitrir",
    "nitrirem": "nitrir",
    "nitriria": "nitrir",
    "nitririam": "nitrir",
    "nitrirá": "nitrir",
    "nitrirão": "nitrir",
    "nitrisse": "nitrir",
    "nitrissem": "nitrir",
    "nitritos": "nitrito",
    "nitriu": "nitrir",
    "nitro": "nitrar",
    "nitrobenzenos": "nitrobenzeno",
    "nitrobenzinas": "nitrobenzina",
    "nitroceluloses": "nitrocelulose",
    "nitrofenóis": "nitrofenol",
    "nitroglicerinas": "nitroglicerina",
    "nitrogénios": "nitrogénio",
    "nitros": "nitro",
    "nitrosa": "nitroso",
    "nitrosas": "nitroso",
    "nitrosidades": "nitrosidade",
    "nitrosilos": "nitrosilo",
    "nitrosos": "nitroso",
    "nitrou": "nitrar",
    "nitrá": "nitrar",
    "nitrámo": "nitrar",
    "nitrámos": "nitrar",
    "nitráramo": "nitrar",
    "nitráramos": "nitrar",
    "nitrárei": "nitrar",
    "nitráreis": "nitrar",
    "nitrásseis": "nitrar",
    "nitrássemos": "nitrar",
    "nitrávamo": "nitrar",
    "nitrávamos": "nitrar",
    "nitrávei": "nitrar",
    "nitráveis": "nitrar",
    "nivações": "nivação",
    "niveais": "niveal",
    "nivela": "nivelar",
    "nivelada": "nivelar",
    "niveladas": "nivelar",
    "nivelado": "nivelar",
    "niveladora": "nivelador",
    "niveladoras": "niveladora",
    "niveladores": "nivelador",
    "nivelados": "nivelar",
    "nivelai": "nivelar",
    "nivelais": "nivelar",
    "nivelam": "nivelar",
    "nivelamentos": "nivelamento",
    "nivelamo": "nivelar",
    "nivelamos": "nivelar",
    "nivelando": "nivelar",
    "nivelara": "nivelar",
    "nivelaram": "nivelar",
    "nivelaras": "nivelar",
    "nivelarde": "nivelar",
    "nivelardes": "nivelar",
    "nivelare": "nivelar",
    "nivelarei": "nivelar",
    "nivelareis": "nivelar",
    "nivelarem": "nivelar",
    "nivelaremos": "nivelar",
    "nivelares": "nivelar",
    "nivelaria": "nivelar",
    "nivelariam": "nivelar",
    "nivelarias": "nivelar",
    "nivelarmo": "nivelar",
    "nivelarmos": "nivelar",
    "nivelará": "nivelar",
    "nivelarás": "nivelar",
    "nivelarão": "nivelar",
    "nivelaríamos": "nivelar",
    "nivelaríeis": "nivelar",
    "nivelas": "nivelar",
    "nivelasse": "nivelar",
    "nivelassem": "nivelar",
    "nivelasses": "nivelar",
    "nivelaste": "nivelar",
    "nivelastes": "nivelar",
    "nivelava": "nivelar",
    "nivelavam": "nivelar",
    "nivelavas": "nivelar",
    "nivelações": "nivelação",
    "nivele": "nivelar",
    "nivelei": "nivelar",
    "niveleis": "nivelar",
    "nivelem": "nivelar",
    "nivelemo": "nivelar",
    "nivelemos": "nivelar",
    "niveles": "nivelar",
    "nivelo": "nivelar",
    "nivelou": "nivelar",
    "nivelá": "nivelar",
    "nivelámo": "nivelar",
    "nivelámos": "nivelar",
    "niveláramo": "nivelar",
    "niveláramos": "nivelar",
    "nivelárei": "nivelar",
    "niveláreis": "nivelar",
    "nivelásseis": "nivelar",
    "nivelássemos": "nivelar",
    "nivelávamo": "nivelar",
    "nivelávamos": "nivelar",
    "nivelávei": "nivelar",
    "niveláveis": "nivelável",
    "niveínas": "niveína",
    "niviformes": "niviforme",
    "nivosa": "nivoso",
    "nivosas": "nivoso",
    "nivosos": "nivoso",
    "nivómetros": "nivómetro",
    "nizas": "niza",
    "nióbios": "nióbio",
    "nn": "n",
    "no": "o",
    "noas": "noa",
    "nobelizáveis": "nobelizável",
    "nobiliaristas": "nobiliarista",
    "nobiliarquias": "nobiliarquia",
    "nobilita": "nobilitar",
    "nobilitada": "nobilitar",
    "nobilitadas": "nobilitar",
    "nobilitado": "nobilitar",
    "nobilitados": "nobilitar",
    "nobilitai": "nobilitar",
    "nobilitais": "nobilitar",
    "nobilitam": "nobilitar",
    "nobilitamo": "nobilitar",
    "nobilitamos": "nobilitar",
    "nobilitando": "nobilitar",
    "nobilitantes": "nobilitante",
    "nobilitara": "nobilitar",
    "nobilitaram": "nobilitar",
    "nobilitaras": "nobilitar",
    "nobilitarde": "nobilitar",
    "nobilitardes": "nobilitar",
    "nobilitare": "nobilitar",
    "nobilitarei": "nobilitar",
    "nobilitareis": "nobilitar",
    "nobilitarem": "nobilitar",
    "nobilitaremos": "nobilitar",
    "nobilitares": "nobilitar",
    "nobilitaria": "nobilitar",
    "nobilitariam": "nobilitar",
    "nobilitarias": "nobilitar",
    "nobilitarmo": "nobilitar",
    "nobilitarmos": "nobilitar",
    "nobilitará": "nobilitar",
    "nobilitarás": "nobilitar",
    "nobilitarão": "nobilitar",
    "nobilitaríamos": "nobilitar",
    "nobilitaríeis": "nobilitar",
    "nobilitas": "nobilitar",
    "nobilitasse": "nobilitar",
    "nobilitassem": "nobilitar",
    "nobilitasses": "nobilitar",
    "nobilitaste": "nobilitar",
    "nobilitastes": "nobilitar",
    "nobilitava": "nobilitar",
    "nobilitavam": "nobilitar",
    "nobilitavas": "nobilitar",
    "nobilitações": "nobilitação",
    "nobilite": "nobilitar",
    "nobilitei": "nobilitar",
    "nobiliteis": "nobilitar",
    "nobilitem": "nobilitar",
    "nobilitemo": "nobilitar",
    "nobilitemos": "nobilitar",
    "nobilites": "nobilitar",
    "nobilito": "nobilitar",
    "nobilitou": "nobilitar",
    "nobilitá": "nobilitar",
    "nobilitámo": "nobilitar",
    "nobilitámos": "nobilitar",
    "nobilitáramo": "nobilitar",
    "nobilitáramos": "nobilitar",
    "nobilitárei": "nobilitar",
    "nobilitáreis": "nobilitar",
    "nobilitária": "nobilitário",
    "nobilitárias": "nobilitário",
    "nobilitários": "nobilitário",
    "nobilitásseis": "nobilitar",
    "nobilitássemos": "nobilitar",
    "nobilitávamo": "nobilitar",
    "nobilitávamos": "nobilitar",
    "nobilitávei": "nobilitar",
    "nobilitáveis": "nobilitar",
    "nobiliária": "nobiliário",
    "nobiliárias": "nobiliário",
    "nobiliários": "nobiliário",
    "nobiliárquica": "nobiliárquico",
    "nobiliárquicas": "nobiliárquico",
    "nobiliárquicos": "nobiliárquico",
    "nobilíssima": "nobre",
    "nobilíssimas": "nobre",
    "nobilíssimo": "nobre",
    "nobilíssimos": "nobre",
    "nobrece": "nobrecer",
    "nobrecei": "nobrecer",
    "nobreceis": "nobrecer",
    "nobrecem": "nobrecer",
    "nobrecemo": "nobrecer",
    "nobrecemos": "nobrecer",
    "nobrecendo": "nobrecer",
    "nobrecera": "nobrecer",
    "nobreceram": "nobrecer",
    "nobreceras": "nobrecer",
    "nobrecerde": "nobrecer",
    "nobrecerdes": "nobrecer",
    "nobrecere": "nobrecer",
    "nobrecerei": "nobrecer",
    "nobrecereis": "nobrecer",
    "nobrecerem": "nobrecer",
    "nobreceremos": "nobrecer",
    "nobreceres": "nobrecer",
    "nobreceria": "nobrecer",
    "nobreceriam": "nobrecer",
    "nobrecerias": "nobrecer",
    "nobrecermo": "nobrecer",
    "nobrecermos": "nobrecer",
    "nobrecerá": "nobrecer",
    "nobrecerás": "nobrecer",
    "nobrecerão": "nobrecer",
    "nobreceríamos": "nobrecer",
    "nobreceríeis": "nobrecer",
    "nobreces": "nobrecer",
    "nobrecesse": "nobrecer",
    "nobrecessem": "nobrecer",
    "nobrecesses": "nobrecer",
    "nobreceste": "nobrecer",
    "nobrecestes": "nobrecer",
    "nobreceu": "nobrecer",
    "nobreci": "nobrecer",
    "nobrecia": "nobrecer",
    "nobreciam": "nobrecer",
    "nobrecias": "nobrecer",
    "nobrecida": "nobrecer",
    "nobrecidas": "nobrecer",
    "nobrecido": "nobrecer",
    "nobrecidos": "nobrecer",
    "nobrecê": "nobrecer",
    "nobrecêramo": "nobrecer",
    "nobrecêramos": "nobrecer",
    "nobrecêrei": "nobrecer",
    "nobrecêreis": "nobrecer",
    "nobrecêsseis": "nobrecer",
    "nobrecêssemos": "nobrecer",
    "nobrecíamo": "nobrecer",
    "nobrecíamos": "nobrecer",
    "nobrecíei": "nobrecer",
    "nobrecíeis": "nobrecer",
    "nobres": "nobre",
    "nobrezas": "nobreza",
    "nobreça": "nobrecer",
    "nobreçais": "nobrecer",
    "nobreçam": "nobrecer",
    "nobreçamo": "nobrecer",
    "nobreçamos": "nobrecer",
    "nobreças": "nobrecer",
    "nobreço": "nobrecer",
    "nobríssima": "nobre",
    "nobríssimas": "nobre",
    "nobríssimo": "nobre",
    "nobríssimos": "nobre",
    "nobélios": "nobélio",
    "nocadas": "nocada",
    "nocas": "noca",
    "nocautes": "nocaute",
    "nochatros": "nochatro",
    "nociceptores": "nociceptor",
    "nocilhos": "nocilho",
    "nocionais": "nocional",
    "nociva": "nocivo",
    "nocivas": "nocivo",
    "nocividades": "nocividade",
    "nocivos": "nocivo",
    "nocleações": "nocleação",
    "noctambula": "noctambular",
    "noctambulada": "noctambular",
    "noctambuladas": "noctambular",
    "noctambulado": "noctambular",
    "noctambulados": "noctambular",
    "noctambulai": "noctambular",
    "noctambulais": "noctambular",
    "noctambulam": "noctambular",
    "noctambulamo": "noctambular",
    "noctambulamos": "noctambular",
    "noctambulando": "noctambular",
    "noctambulara": "noctambular",
    "noctambularam": "noctambular",
    "noctambularas": "noctambular",
    "noctambulardes": "noctambular",
    "noctambularei": "noctambular",
    "noctambulareis": "noctambular",
    "noctambularem": "noctambular",
    "noctambularemos": "noctambular",
    "noctambulares": "noctambular",
    "noctambularia": "noctambular",
    "noctambulariam": "noctambular",
    "noctambularias": "noctambular",
    "noctambularmo": "noctambular",
    "noctambularmos": "noctambular",
    "noctambulará": "noctambular",
    "noctambularás": "noctambular",
    "noctambularão": "noctambular",
    "noctambularíamos": "noctambular",
    "noctambularíeis": "noctambular",
    "noctambulas": "noctambular",
    "noctambulasse": "noctambular",
    "noctambulassem": "noctambular",
    "noctambulasses": "noctambular",
    "noctambulaste": "noctambular",
    "noctambulastes": "noctambular",
    "noctambulava": "noctambular",
    "noctambulavam": "noctambular",
    "noctambulavas": "noctambular",
    "noctambulações": "noctambulação",
    "noctambule": "noctambular",
    "noctambulei": "noctambular",
    "noctambuleis": "noctambular",
    "noctambulem": "noctambular",
    "noctambulemo": "noctambular",
    "noctambulemos": "noctambular",
    "noctambules": "noctambular",
    "noctambulismos": "noctambulismo",
    "noctambulo": "noctambular",
    "noctambulou": "noctambular",
    "noctambulámo": "noctambular",
    "noctambulámos": "noctambular",
    "noctambuláramo": "noctambular",
    "noctambuláramos": "noctambular",
    "noctambuláreis": "noctambular",
    "noctambulásseis": "noctambular",
    "noctambulássemos": "noctambular",
    "noctambulávamo": "noctambular",
    "noctambulávamos": "noctambular",
    "noctambuláveis": "noctambular",
    "nocticolores": "nocticolor",
    "noctiflora": "noctifloro",
    "noctifloras": "noctifloro",
    "noctifloros": "noctifloro",
    "noctilúcia": "noctilúcio",
    "noctilúcias": "noctilúcio",
    "noctilúcios": "noctilúcio",
    "noctivisões": "noctivisão",
    "nocturna": "nocturno",
    "nocturnais": "nocturnal",
    "nocturnas": "nocturno",
    "nocturnos": "nocturno",
    "noctuídeos": "noctuídeo",
    "noctâmbula": "noctâmbulo",
    "noctâmbulas": "noctâmbulo",
    "noctâmbulos": "noctâmbulo",
    "noctífoba": "noctífobo",
    "noctífobas": "noctífobo",
    "noctífobos": "noctífobo",
    "noctígena": "noctígeno",
    "noctígenas": "noctígeno",
    "noctígenos": "noctígeno",
    "noctígera": "noctígero",
    "noctígeras": "noctígero",
    "noctígeros": "noctígero",
    "noctívaga": "noctívago",
    "noctívagas": "noctívago",
    "noctívagos": "noctívago",
    "noctívola": "noctívolo",
    "noctívolas": "noctívolo",
    "noctívolos": "noctívolo",
    "nodais": "nodal",
    "nodoa": "nodoar",
    "nodoada": "nodoar",
    "nodoadas": "nodoar",
    "nodoado": "nodoar",
    "nodoados": "nodoar",
    "nodoai": "nodoar",
    "nodoais": "nodoar",
    "nodoam": "nodoar",
    "nodoamo": "nodoar",
    "nodoamos": "nodoar",
    "nodoando": "nodoar",
    "nodoara": "nodoar",
    "nodoaram": "nodoar",
    "nodoaras": "nodoar",
    "nodoarde": "nodoar",
    "nodoardes": "nodoar",
    "nodoare": "nodoar",
    "nodoarei": "nodoar",
    "nodoareis": "nodoar",
    "nodoarem": "nodoar",
    "nodoaremos": "nodoar",
    "nodoares": "nodoar",
    "nodoaria": "nodoar",
    "nodoariam": "nodoar",
    "nodoarias": "nodoar",
    "nodoarmo": "nodoar",
    "nodoarmos": "nodoar",
    "nodoará": "nodoar",
    "nodoarás": "nodoar",
    "nodoarão": "nodoar",
    "nodoaríamos": "nodoar",
    "nodoaríeis": "nodoar",
    "nodoas": "nodoar",
    "nodoasse": "nodoar",
    "nodoassem": "nodoar",
    "nodoasses": "nodoar",
    "nodoaste": "nodoar",
    "nodoastes": "nodoar",
    "nodoava": "nodoar",
    "nodoavam": "nodoar",
    "nodoavas": "nodoar",
    "nodoe": "nodoar",
    "nodoei": "nodoar",
    "nodoeis": "nodoar",
    "nodoem": "nodoar",
    "nodoemo": "nodoar",
    "nodoemos": "nodoar",
    "nodoes": "nodoar",
    "nodoo": "nodoar",
    "nodoou": "nodoar",
    "nodos": "nodo",
    "nodosa": "nodoso",
    "nodosas": "nodoso",
    "nodosidades": "nodosidade",
    "nodosos": "nodoso",
    "nodoá": "nodoar",
    "nodoámo": "nodoar",
    "nodoámos": "nodoar",
    "nodoáramo": "nodoar",
    "nodoáramos": "nodoar",
    "nodoárei": "nodoar",
    "nodoáreis": "nodoar",
    "nodoásseis": "nodoar",
    "nodoássemos": "nodoar",
    "nodoávamo": "nodoar",
    "nodoávamos": "nodoar",
    "nodoávei": "nodoar",
    "nodoáveis": "nodoar",
    "nodula": "nodular",
    "nodulada": "nodular",
    "noduladas": "nodular",
    "nodulado": "nodular",
    "nodulados": "nodular",
    "nodulai": "nodular",
    "nodulais": "nodular",
    "nodulam": "nodular",
    "nodulamo": "nodular",
    "nodulamos": "nodular",
    "nodulando": "nodular",
    "nodulara": "nodular",
    "nodularam": "nodular",
    "nodularas": "nodular",
    "nodularde": "nodular",
    "nodulardes": "nodular",
    "nodulare": "nodular",
    "nodularei": "nodular",
    "nodulareis": "nodular",
    "nodularem": "nodular",
    "nodularemos": "nodular",
    "nodulares": "nodular",
    "nodularia": "nodular",
    "nodulariam": "nodular",
    "nodularias": "nodular",
    "nodularmo": "nodular",
    "nodularmos": "nodular",
    "nodulará": "nodular",
    "nodularás": "nodular",
    "nodularão": "nodular",
    "nodularíamos": "nodular",
    "nodularíeis": "nodular",
    "nodulas": "nodular",
    "nodulasse": "nodular",
    "nodulassem": "nodular",
    "nodulasses": "nodular",
    "nodulaste": "nodular",
    "nodulastes": "nodular",
    "nodulava": "nodular",
    "nodulavam": "nodular",
    "nodulavas": "nodular",
    "nodule": "nodular",
    "nodulei": "nodular",
    "noduleis": "nodular",
    "nodulem": "nodular",
    "nodulemo": "nodular",
    "nodulemos": "nodular",
    "nodules": "nodular",
    "nodulo": "nodular",
    "nodulosa": "noduloso",
    "nodulosas": "noduloso",
    "nodulosos": "noduloso",
    "nodulou": "nodular",
    "nodulá": "nodular",
    "nodulámo": "nodular",
    "nodulámos": "nodular",
    "noduláramo": "nodular",
    "noduláramos": "nodular",
    "nodulárei": "nodular",
    "noduláreis": "nodular",
    "nodulásseis": "nodular",
    "nodulássemos": "nodular",
    "nodulávamo": "nodular",
    "nodulávamos": "nodular",
    "nodulávei": "nodular",
    "noduláveis": "nodular",
    "noelistas": "noelista",
    "noemas": "noema",
    "noemática": "noemático",
    "noemáticas": "noemático",
    "noemáticos": "noemático",
    "noeses": "noese",
    "noetes": "noete",
    "nogadas": "nogada",
    "nogados": "nogado",
    "nogais": "nogal",
    "nogueirada": "nogueirado",
    "nogueiradas": "nogueirado",
    "nogueirados": "nogueirado",
    "nogueirais": "nogueiral",
    "nogueiras": "nogueira",
    "nogões": "nogão",
    "noitadas": "noitada",
    "noites": "noite",
    "noitibós": "noitibó",
    "noitinha": "noite",
    "noitinhas": "noitinha",
    "noitita": "noite",
    "noititas": "noite",
    "noiva": "noivo",
    "noivada": "noivar",
    "noivadas": "noivar",
    "noivado": "noivar",
    "noivados": "noivar",
    "noivai": "noivar",
    "noivais": "noivar",
    "noivam": "noivar",
    "noivamo": "noivar",
    "noivamos": "noivar",
    "noivando": "noivar",
    "noivara": "noivar",
    "noivaram": "noivar",
    "noivaras": "noivar",
    "noivardes": "noivar",
    "noivarei": "noivar",
    "noivareis": "noivar",
    "noivarem": "noivar",
    "noivaremos": "noivar",
    "noivares": "noivar",
    "noivaria": "noivar",
    "noivariam": "noivar",
    "noivarias": "noivar",
    "noivarmo": "noivar",
    "noivarmos": "noivar",
    "noivará": "noivar",
    "noivarás": "noivar",
    "noivarão": "noivar",
    "noivaríamos": "noivar",
    "noivaríeis": "noivar",
    "noivas": "noivo",
    "noivasse": "noivar",
    "noivassem": "noivar",
    "noivasses": "noivar",
    "noivaste": "noivar",
    "noivastes": "noivar",
    "noivava": "noivar",
    "noivavam": "noivar",
    "noivavas": "noivar",
    "noive": "noivar",
    "noivei": "noivar",
    "noiveis": "noivar",
    "noivem": "noivar",
    "noivemo": "noivar",
    "noivemos": "noivar",
    "noives": "noivar",
    "noivo": "noivar",
    "noivos": "noivo",
    "noivou": "noivar",
    "noivámo": "noivar",
    "noivámos": "noivar",
    "noiváramo": "noivar",
    "noiváramos": "noivar",
    "noiváreis": "noivar",
    "noivásseis": "noivar",
    "noivássemos": "noivar",
    "noivávamo": "noivar",
    "noivávamos": "noivar",
    "noiváveis": "noivar",
    "nojeiras": "nojeira",
    "nojenta": "nojento",
    "nojentas": "nojento",
    "nojentos": "nojento",
    "nojices": "nojice",
    "nojos": "nojo",
    "nojosa": "nojoso",
    "nojosas": "nojoso",
    "nojosos": "nojoso",
    "nolições": "nolição",
    "nomadismos": "nomadismo",
    "nomadiza": "nomadizar",
    "nomadizada": "nomadizar",
    "nomadizadas": "nomadizar",
    "nomadizado": "nomadizar",
    "nomadizados": "nomadizar",
    "nomadizai": "nomadizar",
    "nomadizais": "nomadizar",
    "nomadizam": "nomadizar",
    "nomadizamo": "nomadizar",
    "nomadizamos": "nomadizar",
    "nomadizando": "nomadizar",
    "nomadizara": "nomadizar",
    "nomadizaram": "nomadizar",
    "nomadizaras": "nomadizar",
    "nomadizarde": "nomadizar",
    "nomadizardes": "nomadizar",
    "nomadizare": "nomadizar",
    "nomadizarei": "nomadizar",
    "nomadizareis": "nomadizar",
    "nomadizarem": "nomadizar",
    "nomadizaremos": "nomadizar",
    "nomadizares": "nomadizar",
    "nomadizaria": "nomadizar",
    "nomadizariam": "nomadizar",
    "nomadizarias": "nomadizar",
    "nomadizarmo": "nomadizar",
    "nomadizarmos": "nomadizar",
    "nomadizará": "nomadizar",
    "nomadizarás": "nomadizar",
    "nomadizarão": "nomadizar",
    "nomadizaríamos": "nomadizar",
    "nomadizaríeis": "nomadizar",
    "nomadizas": "nomadizar",
    "nomadizasse": "nomadizar",
    "nomadizassem": "nomadizar",
    "nomadizasses": "nomadizar",
    "nomadizaste": "nomadizar",
    "nomadizastes": "nomadizar",
    "nomadizava": "nomadizar",
    "nomadizavam": "nomadizar",
    "nomadizavas": "nomadizar",
    "nomadizações": "nomadização",
    "nomadize": "nomadizar",
    "nomadizei": "nomadizar",
    "nomadizeis": "nomadizar",
    "nomadizem": "nomadizar",
    "nomadizemo": "nomadizar",
    "nomadizemos": "nomadizar",
    "nomadizes": "nomadizar",
    "nomadizo": "nomadizar",
    "nomadizou": "nomadizar",
    "nomadizá": "nomadizar",
    "nomadizámo": "nomadizar",
    "nomadizámos": "nomadizar",
    "nomadizáramo": "nomadizar",
    "nomadizáramos": "nomadizar",
    "nomadizárei": "nomadizar",
    "nomadizáreis": "nomadizar",
    "nomadizásseis": "nomadizar",
    "nomadizássemos": "nomadizar",
    "nomadizávamo": "nomadizar",
    "nomadizávamos": "nomadizar",
    "nomadizávei": "nomadizar",
    "nomadizáveis": "nomadizar",
    "nomancias": "nomancia",
    "nomantes": "nomante",
    "nomarcas": "nomarca",
    "nomarquias": "nomarquia",
    "nomas": "noma",
    "nomeada": "nomear",
    "nomeadas": "nomear",
    "nomeado": "nomear",
    "nomeadora": "nomeador",
    "nomeadoras": "nomeador",
    "nomeadores": "nomeador",
    "nomeados": "nomear",
    "nomeaduras": "nomeadura",
    "nomeai": "nomear",
    "nomeais": "nomear",
    "nomeamo": "nomear",
    "nomeamos": "nomear",
    "nomeando": "nomear",
    "nomeantes": "nomeante",
    "nomeara": "nomear",
    "nomearam": "nomear",
    "nomearas": "nomear",
    "nomearde": "nomear",
    "nomeardes": "nomear",
    "nomeare": "nomear",
    "nomearei": "nomear",
    "nomeareis": "nomear",
    "nomearem": "nomear",
    "nomearemos": "nomear",
    "nomeares": "nomear",
    "nomearia": "nomear",
    "nomeariam": "nomear",
    "nomearias": "nomear",
    "nomearmo": "nomear",
    "nomearmos": "nomear",
    "nomeará": "nomear",
    "nomearás": "nomear",
    "nomearão": "nomear",
    "nomearíamos": "nomear",
    "nomearíeis": "nomear",
    "nomeasse": "nomear",
    "nomeassem": "nomear",
    "nomeasses": "nomear",
    "nomeaste": "nomear",
    "nomeastes": "nomear",
    "nomeava": "nomear",
    "nomeavam": "nomear",
    "nomeavas": "nomear",
    "nomeações": "nomeação",
    "nomeei": "nomear",
    "nomeeis": "nomear",
    "nomeemo": "nomear",
    "nomeemos": "nomear",
    "nomeia": "nomear",
    "nomeiam": "nomear",
    "nomeias": "nomear",
    "nomeie": "nomear",
    "nomeiem": "nomear",
    "nomeies": "nomear",
    "nomeio": "nomear",
    "nomencla": "nomenclar",
    "nomenclada": "nomenclar",
    "nomencladas": "nomenclar",
    "nomenclado": "nomenclar",
    "nomencladora": "nomenclador",
    "nomencladoras": "nomenclador",
    "nomencladores": "nomenclador",
    "nomenclados": "nomenclar",
    "nomenclai": "nomenclar",
    "nomenclais": "nomenclar",
    "nomenclam": "nomenclar",
    "nomenclamo": "nomenclar",
    "nomenclamos": "nomenclar",
    "nomenclando": "nomenclar",
    "nomenclara": "nomenclar",
    "nomenclaram": "nomenclar",
    "nomenclaras": "nomenclar",
    "nomenclarde": "nomenclar",
    "nomenclardes": "nomenclar",
    "nomenclare": "nomenclar",
    "nomenclarei": "nomenclar",
    "nomenclareis": "nomenclar",
    "nomenclarem": "nomenclar",
    "nomenclaremos": "nomenclar",
    "nomenclares": "nomenclar",
    "nomenclaria": "nomenclar",
    "nomenclariam": "nomenclar",
    "nomenclarias": "nomenclar",
    "nomenclarmo": "nomenclar",
    "nomenclarmos": "nomenclar",
    "nomenclará": "nomenclar",
    "nomenclarás": "nomenclar",
    "nomenclarão": "nomenclar",
    "nomenclaríamos": "nomenclar",
    "nomenclaríeis": "nomenclar",
    "nomenclas": "nomenclar",
    "nomenclasse": "nomenclar",
    "nomenclassem": "nomenclar",
    "nomenclasses": "nomenclar",
    "nomenclaste": "nomenclar",
    "nomenclastes": "nomenclar",
    "nomenclaturas": "nomenclatura",
    "nomenclava": "nomenclar",
    "nomenclavam": "nomenclar",
    "nomenclavas": "nomenclar",
    "nomencle": "nomenclar",
    "nomenclei": "nomenclar",
    "nomencleis": "nomenclar",
    "nomenclem": "nomenclar",
    "nomenclemo": "nomenclar",
    "nomenclemos": "nomenclar",
    "nomencles": "nomenclar",
    "nomenclo": "nomenclar",
    "nomenclou": "nomenclar",
    "nomenclá": "nomenclar",
    "nomenclámo": "nomenclar",
    "nomenclámos": "nomenclar",
    "nomencláramo": "nomenclar",
    "nomencláramos": "nomenclar",
    "nomenclárei": "nomenclar",
    "nomencláreis": "nomenclar",
    "nomenclásseis": "nomenclar",
    "nomenclássemos": "nomenclar",
    "nomenclávamo": "nomenclar",
    "nomenclávamos": "nomenclar",
    "nomenclávei": "nomenclar",
    "nomencláveis": "nomenclar",
    "nomeou": "nomear",
    "nomes": "nome",
    "nomezinho": "nome",
    "nomezinhos": "nome",
    "nomezito": "nome",
    "nomezitos": "nome",
    "nomeá": "nomear",
    "nomeámo": "nomear",
    "nomeámos": "nomear",
    "nomeáramo": "nomear",
    "nomeáramos": "nomear",
    "nomeárei": "nomear",
    "nomeáreis": "nomear",
    "nomeásseis": "nomear",
    "nomeássemos": "nomear",
    "nomeávamo": "nomear",
    "nomeávamos": "nomear",
    "nomeávei": "nomear",
    "nomeáveis": "nomeável",
    "nomilogistas": "nomilogista",
    "nominais": "nominal",
    "nominalidades": "nominalidade",
    "nominalismos": "nominalismo",
    "nominalistas": "nominalista",
    "nominativa": "nominativo",
    "nominativas": "nominativo",
    "nominativos": "nominativo",
    "nominações": "nominação",
    "nomografias": "nomografia",
    "nomogramas": "nomograma",
    "nomográfica": "nomográfico",
    "nomográficas": "nomográfico",
    "nomográficos": "nomográfico",
    "nomologias": "nomologia",
    "nomológica": "nomológico",
    "nomológicas": "nomológico",
    "nomológicos": "nomológico",
    "nomos": "nomo",
    "nomântica": "nomântico",
    "nomânticas": "nomântico",
    "nomânticos": "nomântico",
    "nona": "nono",
    "nonadas": "nonada",
    "nonagenária": "nonagenário",
    "nonagenárias": "nonagenário",
    "nonagenários": "nonagenário",
    "nonagésima": "nonagésimo",
    "nonagésimas": "nonagésimo",
    "nonagésimos": "nonagésimo",
    "nonandra": "nonandro",
    "nonandras": "nonandro",
    "nonandros": "nonandro",
    "nonas": "nono",
    "nonata": "nonato",
    "nonatas": "nonato",
    "nonatos": "nonato",
    "nongentésima": "nongentésimo",
    "nongentésimas": "nongentésimo",
    "nongentésimos": "nongentésimo",
    "noningentésima": "noningentésimo",
    "noningentésimas": "noningentésimo",
    "noningentésimos": "noningentésimo",
    "nonos": "nono",
    "nontronites": "nontronite",
    "nonôs": "nonô",
    "noocentrismos": "noocentrismo",
    "noologias": "noologia",
    "noológica": "noológico",
    "noológicas": "noológico",
    "noológicos": "noológico",
    "noosferas": "noosfera",
    "nopais": "nopal",
    "nopáleas": "nopálea",
    "noras": "nora",
    "nordestadas": "nordestada",
    "nordesteada": "nordestear",
    "nordesteadas": "nordestear",
    "nordesteado": "nordestear",
    "nordesteados": "nordestear",
    "nordesteai": "nordestear",
    "nordesteais": "nordestear",
    "nordesteamo": "nordestear",
    "nordesteamos": "nordestear",
    "nordesteando": "nordestear",
    "nordesteara": "nordestear",
    "nordestearam": "nordestear",
    "nordestearas": "nordestear",
    "nordesteardes": "nordestear",
    "nordestearei": "nordestear",
    "nordesteareis": "nordestear",
    "nordestearem": "nordestear",
    "nordestearemos": "nordestear",
    "nordesteares": "nordestear",
    "nordestearia": "nordestear",
    "nordesteariam": "nordestear",
    "nordestearias": "nordestear",
    "nordestearmo": "nordestear",
    "nordestearmos": "nordestear",
    "nordesteará": "nordestear",
    "nordestearás": "nordestear",
    "nordestearão": "nordestear",
    "nordestearíamos": "nordestear",
    "nordestearíeis": "nordestear",
    "nordesteasse": "nordestear",
    "nordesteassem": "nordestear",
    "nordesteasses": "nordestear",
    "nordesteaste": "nordestear",
    "nordesteastes": "nordestear",
    "nordesteava": "nordestear",
    "nordesteavam": "nordestear",
    "nordesteavas": "nordestear",
    "nordesteei": "nordestear",
    "nordesteeis": "nordestear",
    "nordesteemo": "nordestear",
    "nordesteemos": "nordestear",
    "nordesteia": "nordestear",
    "nordesteiam": "nordestear",
    "nordesteias": "nordestear",
    "nordesteie": "nordestear",
    "nordesteiem": "nordestear",
    "nordesteies": "nordestear",
    "nordesteio": "nordestear",
    "nordesteou": "nordestear",
    "nordestes": "nordeste",
    "nordesteámo": "nordestear",
    "nordesteámos": "nordestear",
    "nordesteáramo": "nordestear",
    "nordesteáramos": "nordestear",
    "nordesteáreis": "nordestear",
    "nordesteásseis": "nordestear",
    "nordesteássemos": "nordestear",
    "nordesteávamo": "nordestear",
    "nordesteávamos": "nordestear",
    "nordesteáveis": "nordestear",
    "nordestias": "nordestia",
    "nordestina": "nordestino",
    "nordestinas": "nordestino",
    "nordestinos": "nordestino",
    "nordéstea": "nordésteo",
    "nordésteas": "nordésteo",
    "nordésteos": "nordésteo",
    "norianos": "noriano",
    "norites": "norite",
    "noritos": "norito",
    "normais": "normal",
    "normalidades": "normalidade",
    "normalistas": "normalista",
    "normaliza": "normalizar",
    "normalizada": "normalizar",
    "normalizadas": "normalizar",
    "normalizado": "normalizar",
    "normalizadora": "normalizador",
    "normalizadoras": "normalizador",
    "normalizadores": "normalizador",
    "normalizados": "normalizar",
    "normalizai": "normalizar",
    "normalizais": "normalizar",
    "normalizam": "normalizar",
    "normalizamo": "normalizar",
    "normalizamos": "normalizar",
    "normalizando": "normalizar",
    "normalizara": "normalizar",
    "normalizaram": "normalizar",
    "normalizaras": "normalizar",
    "normalizarde": "normalizar",
    "normalizardes": "normalizar",
    "normalizare": "normalizar",
    "normalizarei": "normalizar",
    "normalizareis": "normalizar",
    "normalizarem": "normalizar",
    "normalizaremos": "normalizar",
    "normalizares": "normalizar",
    "normalizaria": "normalizar",
    "normalizariam": "normalizar",
    "normalizarias": "normalizar",
    "normalizarmo": "normalizar",
    "normalizarmos": "normalizar",
    "normalizará": "normalizar",
    "normalizarás": "normalizar",
    "normalizarão": "normalizar",
    "normalizaríamos": "normalizar",
    "normalizaríeis": "normalizar",
    "normalizas": "normalizar",
    "normalizasse": "normalizar",
    "normalizassem": "normalizar",
    "normalizasses": "normalizar",
    "normalizaste": "normalizar",
    "normalizastes": "normalizar",
    "normalizava": "normalizar",
    "normalizavam": "normalizar",
    "normalizavas": "normalizar",
    "normalizações": "normalização",
    "normalize": "normalizar",
    "normalizei": "normalizar",
    "normalizeis": "normalizar",
    "normalizem": "normalizar",
    "normalizemo": "normalizar",
    "normalizemos": "normalizar",
    "normalizes": "normalizar",
    "normalizo": "normalizar",
    "normalizou": "normalizar",
    "normalizá": "normalizar",
    "normalizámo": "normalizar",
    "normalizámos": "normalizar",
    "normalizáramo": "normalizar",
    "normalizáramos": "normalizar",
    "normalizárei": "normalizar",
    "normalizáreis": "normalizar",
    "normalizásseis": "normalizar",
    "normalizássemos": "normalizar",
    "normalizávamo": "normalizar",
    "normalizávamos": "normalizar",
    "normalizávei": "normalizar",
    "normalizáveis": "normalizável",
    "normalíssima": "normal",
    "normalíssimas": "normal",
    "normalíssimo": "normal",
    "normalíssimos": "normal",
    "normanda": "normando",
    "normandas": "normando",
    "normandos": "normando",
    "normas": "norma",
    "normativa": "normativo",
    "normativas": "normativo",
    "normativizações": "normativização",
    "normativos": "normativo",
    "noroesteada": "noroestear",
    "noroesteadas": "noroestear",
    "noroesteado": "noroestear",
    "noroesteados": "noroestear",
    "noroesteai": "noroestear",
    "noroesteais": "noroestear",
    "noroesteamo": "noroestear",
    "noroesteamos": "noroestear",
    "noroesteando": "noroestear",
    "noroesteara": "noroestear",
    "noroestearam": "noroestear",
    "noroestearas": "noroestear",
    "noroesteardes": "noroestear",
    "noroestearei": "noroestear",
    "noroesteareis": "noroestear",
    "noroestearem": "noroestear",
    "noroestearemos": "noroestear",
    "noroesteares": "noroestear",
    "noroestearia": "noroestear",
    "noroesteariam": "noroestear",
    "noroestearias": "noroestear",
    "noroestearmo": "noroestear",
    "noroestearmos": "noroestear",
    "noroesteará": "noroestear",
    "noroestearás": "noroestear",
    "noroestearão": "noroestear",
    "noroestearíamos": "noroestear",
    "noroestearíeis": "noroestear",
    "noroesteasse": "noroestear",
    "noroesteassem": "noroestear",
    "noroesteasses": "noroestear",
    "noroesteaste": "noroestear",
    "noroesteastes": "noroestear",
    "noroesteava": "noroestear",
    "noroesteavam": "noroestear",
    "noroesteavas": "noroestear",
    "noroesteei": "noroestear",
    "noroesteeis": "noroestear",
    "noroesteemo": "noroestear",
    "noroesteemos": "noroestear",
    "noroesteia": "noroestear",
    "noroesteiam": "noroestear",
    "noroesteias": "noroestear",
    "noroesteie": "noroestear",
    "noroesteiem": "noroestear",
    "noroesteies": "noroestear",
    "noroesteio": "noroestear",
    "noroesteou": "noroestear",
    "noroestes": "noroeste",
    "noroesteámo": "noroestear",
    "noroesteámos": "noroestear",
    "noroesteáramo": "noroestear",
    "noroesteáramos": "noroestear",
    "noroesteáreis": "noroestear",
    "noroesteásseis": "noroestear",
    "noroesteássemos": "noroestear",
    "noroesteávamo": "noroestear",
    "noroesteávamos": "noroestear",
    "noroesteáveis": "noroestear",
    "norrena": "norreno",
    "norrenas": "norreno",
    "norrenos": "norreno",
    "nortadas": "nortada",
    "norteada": "nortear",
    "norteadas": "nortear",
    "norteado": "nortear",
    "norteadora": "norteador",
    "norteadoras": "norteador",
    "norteadores": "norteador",
    "norteados": "nortear",
    "norteai": "nortear",
    "norteais": "nortear",
    "norteamo": "nortear",
    "norteamos": "nortear",
    "norteando": "nortear",
    "norteara": "nortear",
    "nortearam": "nortear",
    "nortearas": "nortear",
    "nortearde": "nortear",
    "norteardes": "nortear",
    "norteare": "nortear",
    "nortearei": "nortear",
    "norteareis": "nortear",
    "nortearem": "nortear",
    "nortearemos": "nortear",
    "norteares": "nortear",
    "nortearia": "nortear",
    "norteariam": "nortear",
    "nortearias": "nortear",
    "nortearmo": "nortear",
    "nortearmos": "nortear",
    "norteará": "nortear",
    "nortearás": "nortear",
    "nortearão": "nortear",
    "nortearíamos": "nortear",
    "nortearíeis": "nortear",
    "norteasse": "nortear",
    "norteassem": "nortear",
    "norteasses": "nortear",
    "norteaste": "nortear",
    "norteastes": "nortear",
    "norteava": "nortear",
    "norteavam": "nortear",
    "norteavas": "nortear",
    "norteações": "norteação",
    "norteei": "nortear",
    "norteeis": "nortear",
    "norteemo": "nortear",
    "norteemos": "nortear",
    "norteia": "nortear",
    "norteiam": "nortear",
    "norteias": "nortear",
    "norteie": "nortear",
    "norteiem": "nortear",
    "norteies": "nortear",
    "norteio": "nortear",
    "nortenha": "nortenho",
    "nortenhas": "nortenho",
    "nortenhos": "nortenho",
    "norteou": "nortear",
    "nortes": "norte",
    "norteá": "nortear",
    "norteámo": "nortear",
    "norteámos": "nortear",
    "norteáramo": "nortear",
    "norteáramos": "nortear",
    "norteárei": "nortear",
    "norteáreis": "nortear",
    "norteásseis": "nortear",
    "norteássemos": "nortear",
    "norteávamo": "nortear",
    "norteávamos": "nortear",
    "norteávei": "nortear",
    "norteáveis": "norteável",
    "nortistas": "nortista",
    "norueguenses": "norueguense",
    "norueguesa": "norueguês",
    "norueguesas": "norueguês",
    "noruegueses": "norueguês",
    "norças": "norça",
    "nos": "o",
    "nosarias": "nosaria",
    "noseanas": "noseana",
    "nosmantes": "nosmante",
    "nosocomiais": "nosocomial",
    "nosocrática": "nosocrático",
    "nosocráticas": "nosocrático",
    "nosocráticos": "nosocrático",
    "nosocómica": "nosocómico",
    "nosocómicas": "nosocómico",
    "nosocómicos": "nosocómico",
    "nosofobias": "nosofobia",
    "nosofóbica": "nosofóbico",
    "nosofóbicas": "nosofóbico",
    "nosofóbicos": "nosofóbico",
    "nosogenias": "nosogenia",
    "nosografias": "nosografia",
    "nosogénica": "nosogénico",
    "nosogénicas": "nosogénico",
    "nosogénicos": "nosogénico",
    "nosologias": "nosologia",
    "nosologistas": "nosologista",
    "nosológica": "nosológico",
    "nosológicas": "nosológico",
    "nosológicos": "nosológico",
    "nosomancias": "nosomancia",
    "nosomanias": "nosomania",
    "nosomaníaca": "nosomaníaco",
    "nosomaníacas": "nosomaníaco",
    "nosomaníacos": "nosomaníaco",
    "nosomânticas": "nosomântica",
    "nossa": "nosso",
    "nossas": "nosso",
    "nossos": "nosso",
    "nostalgias": "nostalgia",
    "nostálgica": "nostálgico",
    "nostálgicas": "nostálgico",
    "nostálgicos": "nostálgico",
    "nosófoba": "nosófobo",
    "nosófobas": "nosófobo",
    "nosófobos": "nosófobo",
    "nota": "noto",
    "notabilidades": "notabilidade",
    "notabiliza": "notabilizar",
    "notabilizada": "notabilizar",
    "notabilizadas": "notabilizar",
    "notabilizado": "notabilizar",
    "notabilizados": "notabilizar",
    "notabilizai": "notabilizar",
    "notabilizais": "notabilizar",
    "notabilizam": "notabilizar",
    "notabilizamo": "notabilizar",
    "notabilizamos": "notabilizar",
    "notabilizando": "notabilizar",
    "notabilizara": "notabilizar",
    "notabilizaram": "notabilizar",
    "notabilizaras": "notabilizar",
    "notabilizarde": "notabilizar",
    "notabilizardes": "notabilizar",
    "notabilizare": "notabilizar",
    "notabilizarei": "notabilizar",
    "notabilizareis": "notabilizar",
    "notabilizarem": "notabilizar",
    "notabilizaremos": "notabilizar",
    "notabilizares": "notabilizar",
    "notabilizaria": "notabilizar",
    "notabilizariam": "notabilizar",
    "notabilizarias": "notabilizar",
    "notabilizarmo": "notabilizar",
    "notabilizarmos": "notabilizar",
    "notabilizará": "notabilizar",
    "notabilizarás": "notabilizar",
    "notabilizarão": "notabilizar",
    "notabilizaríamos": "notabilizar",
    "notabilizaríeis": "notabilizar",
    "notabilizas": "notabilizar",
    "notabilizasse": "notabilizar",
    "notabilizassem": "notabilizar",
    "notabilizasses": "notabilizar",
    "notabilizaste": "notabilizar",
    "notabilizastes": "notabilizar",
    "notabilizava": "notabilizar",
    "notabilizavam": "notabilizar",
    "notabilizavas": "notabilizar",
    "notabilizações": "notabilização",
    "notabilize": "notabilizar",
    "notabilizei": "notabilizar",
    "notabilizeis": "notabilizar",
    "notabilizem": "notabilizar",
    "notabilizemo": "notabilizar",
    "notabilizemos": "notabilizar",
    "notabilizes": "notabilizar",
    "notabilizo": "notabilizar",
    "notabilizou": "notabilizar",
    "notabilizá": "notabilizar",
    "notabilizámo": "notabilizar",
    "notabilizámos": "notabilizar",
    "notabilizáramo": "notabilizar",
    "notabilizáramos": "notabilizar",
    "notabilizárei": "notabilizar",
    "notabilizáreis": "notabilizar",
    "notabilizásseis": "notabilizar",
    "notabilizássemos": "notabilizar",
    "notabilizávamo": "notabilizar",
    "notabilizávamos": "notabilizar",
    "notabilizávei": "notabilizar",
    "notabilizáveis": "notabilizável",
    "notada": "notar",
    "notadas": "notar",
    "notado": "notar",
    "notadora": "notador",
    "notadoras": "notador",
    "notadores": "notador",
    "notados": "notar",
    "notadíssima": "notado",
    "notadíssimas": "notado",
    "notadíssimo": "notado",
    "notadíssimos": "notado",
    "notai": "notar",
    "notais": "notar",
    "notam": "notar",
    "notamo": "notar",
    "notamos": "notar",
    "notando": "notar",
    "notara": "notar",
    "notaram": "notar",
    "notaras": "notar",
    "notarde": "notar",
    "notardes": "notar",
    "notare": "notar",
    "notarei": "notar",
    "notareis": "notar",
    "notarem": "notar",
    "notaremos": "notar",
    "notares": "notar",
    "notaria": "notar",
    "notariados": "notariado",
    "notariais": "notarial",
    "notariam": "notar",
    "notarias": "notar",
    "notarmo": "notar",
    "notarmos": "notar",
    "notará": "notar",
    "notarás": "notar",
    "notarão": "notar",
    "notaríamos": "notar",
    "notaríeis": "notar",
    "notas": "noto",
    "notasse": "notar",
    "notassem": "notar",
    "notasses": "notar",
    "notaste": "notar",
    "notastes": "notar",
    "notava": "notar",
    "notavam": "notar",
    "notavas": "notar",
    "notazinha": "nota",
    "notazinhas": "nota",
    "notazita": "nota",
    "notazitas": "nota",
    "notações": "notação",
    "note": "notar",
    "notei": "notar",
    "noteis": "notar",
    "notem": "notar",
    "notemo": "notar",
    "notemos": "notar",
    "noterófila": "noterófilo",
    "noterófilas": "noterófilo",
    "noterófilos": "noterófilo",
    "notes": "notar",
    "noticia": "noticiar",
    "noticiada": "noticiar",
    "noticiadas": "noticiar",
    "noticiado": "noticiar",
    "noticiadora": "noticiador",
    "noticiadoras": "noticiador",
    "noticiadores": "noticiador",
    "noticiados": "noticiar",
    "noticiai": "noticiar",
    "noticiais": "noticiar",
    "noticiam": "noticiar",
    "noticiamo": "noticiar",
    "noticiamos": "noticiar",
    "noticiando": "noticiar",
    "noticiara": "noticiar",
    "noticiaram": "noticiar",
    "noticiaras": "noticiar",
    "noticiarde": "noticiar",
    "noticiardes": "noticiar",
    "noticiare": "noticiar",
    "noticiarei": "noticiar",
    "noticiareis": "noticiar",
    "noticiarem": "noticiar",
    "noticiaremos": "noticiar",
    "noticiares": "noticiar",
    "noticiaria": "noticiar",
    "noticiariam": "noticiar",
    "noticiarias": "noticiar",
    "noticiaristas": "noticiarista",
    "noticiarmo": "noticiar",
    "noticiarmos": "noticiar",
    "noticiará": "noticiar",
    "noticiarás": "noticiar",
    "noticiarão": "noticiar",
    "noticiaríamos": "noticiar",
    "noticiaríeis": "noticiar",
    "noticias": "noticiar",
    "noticiasse": "noticiar",
    "noticiassem": "noticiar",
    "noticiasses": "noticiar",
    "noticiaste": "noticiar",
    "noticiastes": "noticiar",
    "noticiava": "noticiar",
    "noticiavam": "noticiar",
    "noticiavas": "noticiar",
    "noticie": "noticiar",
    "noticiei": "noticiar",
    "noticieis": "noticiar",
    "noticiem": "noticiar",
    "noticiemo": "noticiar",
    "noticiemos": "noticiar",
    "noticies": "noticiar",
    "noticio": "noticiar",
    "noticiosa": "noticioso",
    "noticiosas": "noticioso",
    "noticiosos": "noticioso",
    "noticiou": "noticiar",
    "noticiá": "noticiar",
    "noticiámo": "noticiar",
    "noticiámos": "noticiar",
    "noticiáramo": "noticiar",
    "noticiáramos": "noticiar",
    "noticiárei": "noticiar",
    "noticiáreis": "noticiar",
    "noticiários": "noticiário",
    "noticiásseis": "noticiar",
    "noticiássemos": "noticiar",
    "noticiávamo": "noticiar",
    "noticiávamos": "noticiar",
    "noticiávei": "noticiar",
    "noticiáveis": "noticiável",
    "notidanídeos": "notidanídeo",
    "notidânidas": "notidânida",
    "notifica": "notificar",
    "notificada": "notificar",
    "notificadas": "notificar",
    "notificado": "notificar",
    "notificadora": "notificador",
    "notificadoras": "notificador",
    "notificadores": "notificador",
    "notificados": "notificar",
    "notificai": "notificar",
    "notificais": "notificar",
    "notificam": "notificar",
    "notificamo": "notificar",
    "notificamos": "notificar",
    "notificando": "notificar",
    "notificantes": "notificante",
    "notificara": "notificar",
    "notificaram": "notificar",
    "notificaras": "notificar",
    "notificarde": "notificar",
    "notificardes": "notificar",
    "notificare": "notificar",
    "notificarei": "notificar",
    "notificareis": "notificar",
    "notificarem": "notificar",
    "notificaremos": "notificar",
    "notificares": "notificar",
    "notificaria": "notificar",
    "notificariam": "notificar",
    "notificarias": "notificar",
    "notificarmo": "notificar",
    "notificarmos": "notificar",
    "notificará": "notificar",
    "notificarás": "notificar",
    "notificarão": "notificar",
    "notificaríamos": "notificar",
    "notificaríeis": "notificar",
    "notificas": "notificar",
    "notificasse": "notificar",
    "notificassem": "notificar",
    "notificasses": "notificar",
    "notificaste": "notificar",
    "notificastes": "notificar",
    "notificativa": "notificativo",
    "notificativas": "notificativo",
    "notificativos": "notificativo",
    "notificatória": "notificatório",
    "notificatórias": "notificatório",
    "notificatórios": "notificatório",
    "notificava": "notificar",
    "notificavam": "notificar",
    "notificavas": "notificar",
    "notificações": "notificação",
    "notifico": "notificar",
    "notificou": "notificar",
    "notificá": "notificar",
    "notificámo": "notificar",
    "notificámos": "notificar",
    "notificáramo": "notificar",
    "notificáramos": "notificar",
    "notificárei": "notificar",
    "notificáreis": "notificar",
    "notificásseis": "notificar",
    "notificássemos": "notificar",
    "notificávamo": "notificar",
    "notificávamos": "notificar",
    "notificávei": "notificar",
    "notificáveis": "notificável",
    "notifique": "notificar",
    "notifiquei": "notificar",
    "notifiqueis": "notificar",
    "notifiquem": "notificar",
    "notifiquemo": "notificar",
    "notifiquemos": "notificar",
    "notifiques": "notificar",
    "notinha": "nota",
    "notinhas": "nota",
    "notita": "nota",
    "notitas": "nota",
    "noto": "notar",
    "notocórdios": "notocórdio",
    "notodontídeos": "notodontídeo",
    "notodôntidas": "notodôntida",
    "notoriedades": "notoriedade",
    "notos": "noto",
    "notossáurios": "notossáurio",
    "notou": "notar",
    "notá": "notar",
    "notámo": "notar",
    "notámos": "notar",
    "notáramo": "notar",
    "notáramos": "notar",
    "notárei": "notar",
    "notáreis": "notar",
    "notários": "notário",
    "notásseis": "notar",
    "notássemos": "notar",
    "notávamo": "notar",
    "notávamos": "notar",
    "notávei": "notar",
    "notáveis": "notável",
    "notícias": "notícia",
    "notória": "notório",
    "notórias": "notório",
    "notórios": "notório",
    "nougats": "nougat",
    "noutadas": "noutada",
    "noutes": "noute",
    "nova": "novo",
    "novadora": "novador",
    "novadoras": "novador",
    "novadores": "novador",
    "novaiorquina": "novaiorquino",
    "novaiorquinas": "novaiorquino",
    "novaiorquinos": "novaiorquino",
    "novais": "noval",
    "novas": "novo",
    "novata": "novato",
    "novatas": "novato",
    "novatos": "novato",
    "novazinha": "novo",
    "novazinhas": "novo",
    "novazita": "novo",
    "novazitas": "novo",
    "novações": "novação",
    "novecentas": "novecentos",
    "novecentistas": "novecentista",
    "novedia": "novedio",
    "novedias": "novedio",
    "novedios": "novedio",
    "noveis": "novel",
    "novela": "novelar",
    "novelada": "novelar",
    "noveladas": "novelar",
    "novelado": "novelar",
    "novelados": "novelar",
    "novelai": "novelar",
    "novelais": "novelar",
    "novelam": "novelar",
    "novelamo": "novelar",
    "novelamos": "novelar",
    "novelando": "novelar",
    "novelara": "novelar",
    "novelaram": "novelar",
    "novelaras": "novelar",
    "novelardes": "novelar",
    "novelarei": "novelar",
    "novelareis": "novelar",
    "novelarem": "novelar",
    "novelaremos": "novelar",
    "novelares": "novelar",
    "novelaria": "novelar",
    "novelariam": "novelar",
    "novelarias": "novelar",
    "novelarmo": "novelar",
    "novelarmos": "novelar",
    "novelará": "novelar",
    "novelarás": "novelar",
    "novelarão": "novelar",
    "novelaríamos": "novelar",
    "novelaríeis": "novelar",
    "novelas": "novelar",
    "novelasse": "novelar",
    "novelassem": "novelar",
    "novelasses": "novelar",
    "novelaste": "novelar",
    "novelastes": "novelar",
    "novelava": "novelar",
    "novelavam": "novelar",
    "novelavas": "novelar",
    "novele": "novelar",
    "novelei": "novelar",
    "noveleira": "noveleiro",
    "noveleiras": "noveleiro",
    "noveleiros": "noveleiro",
    "noveleis": "novelar",
    "novelem": "novelar",
    "novelemo": "novelar",
    "novelemos": "novelar",
    "noveles": "novelar",
    "novelesca": "novelesco",
    "novelescas": "novelesco",
    "novelescos": "novelesco",
    "novelistas": "novelista",
    "novelo": "novelar",
    "novelos": "novelo",
    "novelou": "novelar",
    "novelámo": "novelar",
    "novelámos": "novelar",
    "noveláramo": "novelar",
    "noveláramos": "novelar",
    "noveláreis": "novelar",
    "novelásseis": "novelar",
    "novelássemos": "novelar",
    "novelávamo": "novelar",
    "novelávamos": "novelar",
    "noveláveis": "novelar",
    "novelística": "novelístico",
    "novelísticas": "novelístico",
    "novelísticos": "novelístico",
    "novelões": "novelão",
    "novena": "noveno",
    "novenais": "novenal",
    "novenas": "noveno",
    "novenervada": "novenervado",
    "novenervadas": "novenervado",
    "novenervados": "novenervado",
    "novenos": "noveno",
    "novenvirados": "novenvirado",
    "novenviratos": "novenvirato",
    "novenários": "novenário",
    "novices": "novice",
    "novicia": "noviciar",
    "noviciada": "noviciar",
    "noviciadas": "noviciar",
    "noviciado": "noviciar",
    "noviciados": "noviciar",
    "noviciai": "noviciar",
    "noviciais": "noviciar",
    "noviciam": "noviciar",
    "noviciamo": "noviciar",
    "noviciamos": "noviciar",
    "noviciando": "noviciar",
    "noviciara": "noviciar",
    "noviciaram": "noviciar",
    "noviciaras": "noviciar",
    "noviciardes": "noviciar",
    "noviciarei": "noviciar",
    "noviciareis": "noviciar",
    "noviciarem": "noviciar",
    "noviciaremos": "noviciar",
    "noviciares": "noviciar",
    "noviciaria": "noviciar",
    "noviciariam": "noviciar",
    "noviciarias": "noviciaria",
    "noviciarmo": "noviciar",
    "noviciarmos": "noviciar",
    "noviciará": "noviciar",
    "noviciarás": "noviciar",
    "noviciarão": "noviciar",
    "noviciaríamos": "noviciar",
    "noviciaríeis": "noviciar",
    "novicias": "noviciar",
    "noviciasse": "noviciar",
    "noviciassem": "noviciar",
    "noviciasses": "noviciar",
    "noviciaste": "noviciar",
    "noviciastes": "noviciar",
    "noviciava": "noviciar",
    "noviciavam": "noviciar",
    "noviciavas": "noviciar",
    "novicie": "noviciar",
    "noviciei": "noviciar",
    "novicieis": "noviciar",
    "noviciem": "noviciar",
    "noviciemo": "noviciar",
    "noviciemos": "noviciar",
    "novicies": "noviciar",
    "novicio": "noviciar",
    "noviciou": "noviciar",
    "noviciámo": "noviciar",
    "noviciámos": "noviciar",
    "noviciáramo": "noviciar",
    "noviciáramos": "noviciar",
    "noviciáreis": "noviciar",
    "noviciária": "noviciário",
    "noviciárias": "noviciário",
    "noviciários": "noviciário",
    "noviciásseis": "noviciar",
    "noviciássemos": "noviciar",
    "noviciávamo": "noviciar",
    "noviciávamos": "noviciar",
    "noviciáveis": "noviciar",
    "novidadeira": "novidadeiro",
    "novidadeiras": "novidadeiro",
    "novidadeiros": "novidadeiro",
    "novidades": "novidade",
    "novilatina": "novilatino",
    "novilatinas": "novilatino",
    "novilatinos": "novilatino",
    "novilha": "novilho",
    "novilhadas": "novilhada",
    "novilhas": "novilho",
    "novilheira": "novilheiro",
    "novilheiras": "novilheiro",
    "novilheiros": "novilheiro",
    "novilhos": "novilho",
    "novilunares": "novilunar",
    "novilúnios": "novilúnio",
    "novinha": "novo",
    "novinhas": "novo",
    "novinho": "novo",
    "novinhos": "novo",
    "noviorquina": "noviorquino",
    "noviorquinas": "noviorquino",
    "noviorquinos": "noviorquino",
    "novita": "novo",
    "novitas": "novo",
    "novito": "novo",
    "novitos": "novo",
    "noviça": "noviço",
    "noviças": "noviço",
    "noviços": "noviço",
    "novos": "novo",
    "novozinho": "novo",
    "novozinhos": "novo",
    "novozito": "novo",
    "novozitos": "novo",
    "novénios": "novénio",
    "novênviros": "novênviro",
    "novíssima": "novo",
    "novíssimas": "novo",
    "novíssimo": "novo",
    "novíssimos": "novo",
    "nozelhas": "nozelha",
    "nozes": "noz",
    "nozinho": "nó",
    "nozinhos": "nó",
    "nozito": "nó",
    "nozitos": "nó",
    "noções": "noção",
    "noética": "noético",
    "noéticas": "noético",
    "noéticos": "noético",
    "nua": "nu",
    "nuances": "nuance",
    "nuanças": "nuança",
    "nuas": "nu",
    "nuazinha": "nu",
    "nuazinhas": "nu",
    "nuazita": "nu",
    "nuazitas": "nu",
    "nubentes": "nubente",
    "nubiana": "nubiano",
    "nubianas": "nubiano",
    "nubianos": "nubiano",
    "nubilares": "nubilar",
    "nubilidades": "nubilidade",
    "nubilosa": "nubiloso",
    "nubilosas": "nubiloso",
    "nubilosos": "nubiloso",
    "nubilários": "nubilário",
    "nubla": "nublar",
    "nublada": "nublar",
    "nubladas": "nublar",
    "nublado": "nublar",
    "nublados": "nublar",
    "nubladíssima": "nublado",
    "nubladíssimas": "nublado",
    "nubladíssimo": "nublado",
    "nubladíssimos": "nublado",
    "nublai": "nublar",
    "nublais": "nublar",
    "nublam": "nublar",
    "nublamo": "nublar",
    "nublamos": "nublar",
    "nublando": "nublar",
    "nublara": "nublar",
    "nublaram": "nublar",
    "nublaras": "nublar",
    "nublarde": "nublar",
    "nublardes": "nublar",
    "nublare": "nublar",
    "nublarei": "nublar",
    "nublareis": "nublar",
    "nublarem": "nublar",
    "nublaremos": "nublar",
    "nublares": "nublar",
    "nublaria": "nublar",
    "nublariam": "nublar",
    "nublarias": "nublar",
    "nublarmo": "nublar",
    "nublarmos": "nublar",
    "nublará": "nublar",
    "nublarás": "nublar",
    "nublarão": "nublar",
    "nublaríamos": "nublar",
    "nublaríeis": "nublar",
    "nublas": "nublar",
    "nublasse": "nublar",
    "nublassem": "nublar",
    "nublasses": "nublar",
    "nublaste": "nublar",
    "nublastes": "nublar",
    "nublava": "nublar",
    "nublavam": "nublar",
    "nublavas": "nublar",
    "nuble": "nublar",
    "nublei": "nublar",
    "nubleis": "nublar",
    "nublem": "nublar",
    "nublemo": "nublar",
    "nublemos": "nublar",
    "nubles": "nublar",
    "nublo": "nublar",
    "nublosa": "nubloso",
    "nublosas": "nubloso",
    "nublosos": "nubloso",
    "nublosíssima": "nubloso",
    "nublosíssimas": "nubloso",
    "nublosíssimo": "nubloso",
    "nublosíssimos": "nubloso",
    "nublou": "nublar",
    "nublá": "nublar",
    "nublámo": "nublar",
    "nublámos": "nublar",
    "nubláramo": "nublar",
    "nubláramos": "nublar",
    "nublárei": "nublar",
    "nubláreis": "nublar",
    "nublásseis": "nublar",
    "nublássemos": "nublar",
    "nublávamo": "nublar",
    "nublávamos": "nublar",
    "nublávei": "nublar",
    "nubláveis": "nublar",
    "nubífera": "nubífero",
    "nubíferas": "nubífero",
    "nubíferos": "nubífero",
    "nubífuga": "nubífugo",
    "nubífugas": "nubífugo",
    "nubífugos": "nubífugo",
    "nubígena": "nubígeno",
    "nubígenas": "nubígeno",
    "nubígenos": "nubígeno",
    "nubívaga": "nubívago",
    "nubívagas": "nubívago",
    "nubívagos": "nubívago",
    "nucais": "nucal",
    "nucas": "nuca",
    "nucelas": "nucela",
    "nucelos": "nucelo",
    "nuciformes": "nuciforme",
    "nucinas": "nucina",
    "nucleais": "nucleal",
    "nucleares": "nuclear",
    "nucleofílica": "nucleofílico",
    "nucleofílicas": "nucleofílico",
    "nucleofílicos": "nucleofílico",
    "nucleomas": "nucleoma",
    "nucleínas": "nucleína",
    "nucleófila": "nucleófilo",
    "nucleófilas": "nucleófilo",
    "nucleófilos": "nucleófilo",
    "nucleónica": "nucleónico",
    "nucleónicas": "nucleónico",
    "nucleónicos": "nucleónico",
    "nucleões": "nucleão",
    "nucléolos": "nucléolo",
    "nuclídeos": "nuclídeo",
    "nuculares": "nucular",
    "nuculosa": "nuculoso",
    "nuculosas": "nuculoso",
    "nuculosos": "nuculoso",
    "nuculâneos": "nuculâneo",
    "nucíferas": "nucífera",
    "nucífraga": "nucífrago",
    "nucífragas": "nucífrago",
    "nucífragos": "nucífrago",
    "nucívora": "nucívoro",
    "nucívoras": "nucívoro",
    "nucívoros": "nucívoro",
    "nudações": "nudação",
    "nudezas": "nudeza",
    "nudezes": "nudez",
    "nudibrânquia": "nudibrânquio",
    "nudibrânquias": "nudibrânquio",
    "nudibrânquios": "nudibrânquio",
    "nudicaules": "nudicaule",
    "nudismos": "nudismo",
    "nudissexa": "nudissexo",
    "nudissexas": "nudissexo",
    "nudissexos": "nudissexo",
    "nudistas": "nudista",
    "nudípedes": "nudípede",
    "nuela": "nuelo",
    "nuelas": "nuelo",
    "nuelos": "nuelo",
    "nugacidades": "nugacidade",
    "nugas": "nuga",
    "nugativa": "nugativo",
    "nugativas": "nugativo",
    "nugativos": "nugativo",
    "nugatória": "nugatório",
    "nugatórias": "nugatório",
    "nugatórios": "nugatório",
    "nugações": "nugação",
    "nuinha": "nu",
    "nuinhas": "nu",
    "nuinho": "nu",
    "nuinhos": "nu",
    "nuita": "nu",
    "nuitas": "nu",
    "nuito": "nu",
    "nuitos": "nu",
    "nula": "nulo",
    "nulas": "nulo",
    "nulidades": "nulidade",
    "nulifica": "nulificar",
    "nulificada": "nulificar",
    "nulificadas": "nulificar",
    "nulificado": "nulificar",
    "nulificados": "nulificar",
    "nulificai": "nulificar",
    "nulificais": "nulificar",
    "nulificam": "nulificar",
    "nulificamo": "nulificar",
    "nulificamos": "nulificar",
    "nulificando": "nulificar",
    "nulificara": "nulificar",
    "nulificaram": "nulificar",
    "nulificaras": "nulificar",
    "nulificarde": "nulificar",
    "nulificardes": "nulificar",
    "nulificare": "nulificar",
    "nulificarei": "nulificar",
    "nulificareis": "nulificar",
    "nulificarem": "nulificar",
    "nulificaremos": "nulificar",
    "nulificares": "nulificar",
    "nulificaria": "nulificar",
    "nulificariam": "nulificar",
    "nulificarias": "nulificar",
    "nulificarmo": "nulificar",
    "nulificarmos": "nulificar",
    "nulificará": "nulificar",
    "nulificarás": "nulificar",
    "nulificarão": "nulificar",
    "nulificaríamos": "nulificar",
    "nulificaríeis": "nulificar",
    "nulificas": "nulificar",
    "nulificasse": "nulificar",
    "nulificassem": "nulificar",
    "nulificasses": "nulificar",
    "nulificaste": "nulificar",
    "nulificastes": "nulificar",
    "nulificava": "nulificar",
    "nulificavam": "nulificar",
    "nulificavas": "nulificar",
    "nulificações": "nulificação",
    "nulifico": "nulificar",
    "nulificou": "nulificar",
    "nulificá": "nulificar",
    "nulificámo": "nulificar",
    "nulificámos": "nulificar",
    "nulificáramo": "nulificar",
    "nulificáramos": "nulificar",
    "nulificárei": "nulificar",
    "nulificáreis": "nulificar",
    "nulificásseis": "nulificar",
    "nulificássemos": "nulificar",
    "nulificávamo": "nulificar",
    "nulificávamos": "nulificar",
    "nulificávei": "nulificar",
    "nulificáveis": "nulificar",
    "nulifique": "nulificar",
    "nulifiquei": "nulificar",
    "nulifiqueis": "nulificar",
    "nulifiquem": "nulificar",
    "nulifiquemo": "nulificar",
    "nulifiquemos": "nulificar",
    "nulifiques": "nulificar",
    "nulinerves": "nulinerve",
    "nulos": "nulo",
    "nulíparas": "nulípara",
    "numantina": "numantino",
    "numantinas": "numantino",
    "numantinos": "numantino",
    "nume": "númen",
    "numenais": "numenal",
    "numera": "numerar",
    "numerada": "numerar",
    "numeradas": "numerar",
    "numeradinha": "numerado",
    "numeradinhas": "numerado",
    "numeradinho": "numerado",
    "numeradinhos": "numerado",
    "numeradita": "numerado",
    "numeraditas": "numerado",
    "numeradito": "numerado",
    "numeraditos": "numerado",
    "numerado": "numerar",
    "numeradora": "numerador",
    "numeradoras": "numeradora",
    "numeradores": "numerador",
    "numerados": "numerar",
    "numerai": "numerar",
    "numerais": "numerar",
    "numeram": "numerar",
    "numeramo": "numerar",
    "numeramos": "numerar",
    "numerando": "numerar",
    "numerara": "numerar",
    "numeraram": "numerar",
    "numeraras": "numerar",
    "numerarde": "numerar",
    "numerardes": "numerar",
    "numerare": "numerar",
    "numerarei": "numerar",
    "numerareis": "numerar",
    "numerarem": "numerar",
    "numeraremos": "numerar",
    "numerares": "numerar",
    "numeraria": "numerar",
    "numerariam": "numerar",
    "numerarias": "numerar",
    "numerarmo": "numerar",
    "numerarmos": "numerar",
    "numerará": "numerar",
    "numerarás": "numerar",
    "numerarão": "numerar",
    "numeraríamos": "numerar",
    "numeraríeis": "numerar",
    "numeras": "numerar",
    "numerasse": "numerar",
    "numerassem": "numerar",
    "numerasses": "numerar",
    "numeraste": "numerar",
    "numerastes": "numerar",
    "numerativa": "numerativo",
    "numerativas": "numerativo",
    "numerativos": "numerativo",
    "numerava": "numerar",
    "numeravam": "numerar",
    "numeravas": "numerar",
    "numerações": "numeração",
    "numere": "numerar",
    "numerei": "numerar",
    "numereis": "numerar",
    "numerem": "numerar",
    "numeremo": "numerar",
    "numeremos": "numerar",
    "numeres": "numerar",
    "numero": "numerar",
    "numerologias": "numerologia",
    "numerosa": "numeroso",
    "numerosas": "numeroso",
    "numerosidades": "numerosidade",
    "numerosos": "numeroso",
    "numerosíssima": "numeroso",
    "numerosíssimas": "numeroso",
    "numerosíssimo": "numeroso",
    "numerosíssimos": "numeroso",
    "numerou": "numerar",
    "numerá": "numerar",
    "numerámo": "numerar",
    "numerámos": "numerar",
    "numeráramo": "numerar",
    "numeráramos": "numerar",
    "numerárei": "numerar",
    "numeráreis": "numerar",
    "numerária": "numerário",
    "numerárias": "numerário",
    "numerários": "numerário",
    "numerásseis": "numerar",
    "numerássemos": "numerar",
    "numerávamo": "numerar",
    "numerávamos": "numerar",
    "numerávei": "numerar",
    "numeráveis": "numerável",
    "numes": "númen",
    "numinosa": "numinoso",
    "numinosas": "numinoso",
    "numinosos": "numinoso",
    "numismais": "numismal",
    "numismas": "numisma",
    "numismatas": "numismata",
    "numismatistas": "numismatista",
    "numismática": "numismático",
    "numismáticas": "numismático",
    "numismáticos": "numismático",
    "numulares": "numular",
    "numulites": "numulite",
    "numulárias": "numulária",
    "numulários": "numulário",
    "numulítica": "numulítico",
    "numulíticas": "numulítico",
    "numulíticos": "numulítico",
    "numárias": "numária",
    "numérica": "numérico",
    "numéricas": "numérico",
    "numéricos": "numérico",
    "numídica": "numídico",
    "numídicas": "numídico",
    "numídicos": "numídico",
    "nunalvariana": "nunalvariano",
    "nunalvarianas": "nunalvariano",
    "nunalvarianos": "nunalvariano",
    "nunciaturas": "nunciatura",
    "nuncupativa": "nuncupativo",
    "nuncupativas": "nuncupativo",
    "nuncupativos": "nuncupativo",
    "nuncupatória": "nuncupatório",
    "nuncupatórias": "nuncupatório",
    "nuncupatórios": "nuncupatório",
    "nuncupações": "nuncupação",
    "nupciais": "nupcial",
    "nupcialidades": "nupcialidade",
    "nuperfalecida": "nuperfalecido",
    "nuperfalecidas": "nuperfalecido",
    "nuperfalecidos": "nuperfalecido",
    "nus": "nu",
    "nuta": "nutar",
    "nutada": "nutar",
    "nutadas": "nutar",
    "nutado": "nutar",
    "nutados": "nutar",
    "nutai": "nutar",
    "nutais": "nutar",
    "nutam": "nutar",
    "nutamo": "nutar",
    "nutamos": "nutar",
    "nutando": "nutar",
    "nutantes": "nutante",
    "nutara": "nutar",
    "nutaram": "nutar",
    "nutaras": "nutar",
    "nutardes": "nutar",
    "nutarei": "nutar",
    "nutareis": "nutar",
    "nutarem": "nutar",
    "nutaremos": "nutar",
    "nutares": "nutar",
    "nutaria": "nutar",
    "nutariam": "nutar",
    "nutarias": "nutar",
    "nutarmo": "nutar",
    "nutarmos": "nutar",
    "nutará": "nutar",
    "nutarás": "nutar",
    "nutarão": "nutar",
    "nutaríamos": "nutar",
    "nutaríeis": "nutar",
    "nutas": "nutar",
    "nutasse": "nutar",
    "nutassem": "nutar",
    "nutasses": "nutar",
    "nutaste": "nutar",
    "nutastes": "nutar",
    "nutatória": "nutatório",
    "nutatórias": "nutatório",
    "nutatórios": "nutatório",
    "nutava": "nutar",
    "nutavam": "nutar",
    "nutavas": "nutar",
    "nutações": "nutação",
    "nute": "nutar",
    "nutei": "nutar",
    "nuteis": "nutar",
    "nutem": "nutar",
    "nutemo": "nutar",
    "nutemos": "nutar",
    "nutes": "nutar",
    "nuto": "nutar",
    "nutos": "nuto",
    "nutou": "nutar",
    "nutra": "nutrir",
    "nutrais": "nutrir",
    "nutram": "nutrir",
    "nutramo": "nutrir",
    "nutramos": "nutrir",
    "nutras": "nutrir",
    "nutre": "nutrir",
    "nutrem": "nutrir",
    "nutres": "nutrir",
    "nutri": "nutrir",
    "nutria": "nutrir",
    "nutriam": "nutrir",
    "nutrias": "nutrir",
    "nutribilidades": "nutribilidade",
    "nutrices": "nutrice",
    "nutricionais": "nutricional",
    "nutricionismos": "nutricionismo",
    "nutricionistas": "nutricionista",
    "nutrida": "nutrir",
    "nutridas": "nutrir",
    "nutrido": "nutrir",
    "nutridora": "nutridor",
    "nutridoras": "nutridor",
    "nutridores": "nutridor",
    "nutridos": "nutrir",
    "nutridíssima": "nutrido",
    "nutridíssimas": "nutrido",
    "nutridíssimo": "nutrido",
    "nutridíssimos": "nutrido",
    "nutrientes": "nutriente",
    "nutrifica": "nutrificar",
    "nutrificada": "nutrificar",
    "nutrificadas": "nutrificar",
    "nutrificado": "nutrificar",
    "nutrificados": "nutrificar",
    "nutrificai": "nutrificar",
    "nutrificais": "nutrificar",
    "nutrificam": "nutrificar",
    "nutrificamo": "nutrificar",
    "nutrificamos": "nutrificar",
    "nutrificando": "nutrificar",
    "nutrificara": "nutrificar",
    "nutrificaram": "nutrificar",
    "nutrificaras": "nutrificar",
    "nutrificarde": "nutrificar",
    "nutrificardes": "nutrificar",
    "nutrificare": "nutrificar",
    "nutrificarei": "nutrificar",
    "nutrificareis": "nutrificar",
    "nutrificarem": "nutrificar",
    "nutrificaremos": "nutrificar",
    "nutrificares": "nutrificar",
    "nutrificaria": "nutrificar",
    "nutrificariam": "nutrificar",
    "nutrificarias": "nutrificar",
    "nutrificarmo": "nutrificar",
    "nutrificarmos": "nutrificar",
    "nutrificará": "nutrificar",
    "nutrificarás": "nutrificar",
    "nutrificarão": "nutrificar",
    "nutrificaríamos": "nutrificar",
    "nutrificaríeis": "nutrificar",
    "nutrificas": "nutrificar",
    "nutrificasse": "nutrificar",
    "nutrificassem": "nutrificar",
    "nutrificasses": "nutrificar",
    "nutrificaste": "nutrificar",
    "nutrificastes": "nutrificar",
    "nutrificava": "nutrificar",
    "nutrificavam": "nutrificar",
    "nutrificavas": "nutrificar",
    "nutrifico": "nutrificar",
    "nutrificou": "nutrificar",
    "nutrificá": "nutrificar",
    "nutrificámo": "nutrificar",
    "nutrificámos": "nutrificar",
    "nutrificáramo": "nutrificar",
    "nutrificáramos": "nutrificar",
    "nutrificárei": "nutrificar",
    "nutrificáreis": "nutrificar",
    "nutrificásseis": "nutrificar",
    "nutrificássemos": "nutrificar",
    "nutrificávamo": "nutrificar",
    "nutrificávamos": "nutrificar",
    "nutrificávei": "nutrificar",
    "nutrificáveis": "nutrificar",
    "nutrifique": "nutrificar",
    "nutrifiquei": "nutrificar",
    "nutrifiqueis": "nutrificar",
    "nutrifiquem": "nutrificar",
    "nutrifiquemo": "nutrificar",
    "nutrifiquemos": "nutrificar",
    "nutrifiques": "nutrificar",
    "nutrimentais": "nutrimental",
    "nutrimentos": "nutrimento",
    "nutrimo": "nutrir",
    "nutrimos": "nutrir",
    "nutrindo": "nutrir",
    "nutrira": "nutrir",
    "nutriram": "nutrir",
    "nutriras": "nutrir",
    "nutrirde": "nutrir",
    "nutrirdes": "nutrir",
    "nutrire": "nutrir",
    "nutrirei": "nutrir",
    "nutrireis": "nutrir",
    "nutrirem": "nutrir",
    "nutriremos": "nutrir",
    "nutrires": "nutrir",
    "nutriria": "nutrir",
    "nutririam": "nutrir",
    "nutririas": "nutrir",
    "nutrirmo": "nutrir",
    "nutrirmos": "nutrir",
    "nutrirá": "nutrir",
    "nutrirás": "nutrir",
    "nutrirão": "nutrir",
    "nutriríamos": "nutrir",
    "nutriríeis": "nutrir",
    "nutris": "nutrir",
    "nutrisse": "nutrir",
    "nutrissem": "nutrir",
    "nutrisses": "nutrir",
    "nutriste": "nutrir",
    "nutristes": "nutrir",
    "nutritiva": "nutritivo",
    "nutritivas": "nutritivo",
    "nutritivos": "nutritivo",
    "nutritícia": "nutritício",
    "nutritícias": "nutritício",
    "nutritícios": "nutritício",
    "nutriu": "nutrir",
    "nutrizes": "nutriz",
    "nutrições": "nutrição",
    "nutro": "nutrir",
    "nutríamo": "nutrir",
    "nutríamos": "nutrir",
    "nutrícia": "nutrício",
    "nutrícias": "nutrício",
    "nutrícios": "nutrício",
    "nutríei": "nutrir",
    "nutríeis": "nutrir",
    "nutríramo": "nutrir",
    "nutríramos": "nutrir",
    "nutrírei": "nutrir",
    "nutríreis": "nutrir",
    "nutrísseis": "nutrir",
    "nutríssemos": "nutrir",
    "nutrítica": "nutrítico",
    "nutríticas": "nutrítico",
    "nutríticos": "nutrítico",
    "nutríveis": "nutrível",
    "nutámo": "nutar",
    "nutámos": "nutar",
    "nutáramo": "nutar",
    "nutáramos": "nutar",
    "nutáreis": "nutar",
    "nutásseis": "nutar",
    "nutássemos": "nutar",
    "nutávamo": "nutar",
    "nutávamos": "nutar",
    "nutáveis": "nutar",
    "nuvens": "nuvem",
    "nuvenzinha": "nuvem",
    "nuvenzinhas": "nuvem",
    "nuvenzita": "nuvem",
    "nuvenzitas": "nuvem",
    "nuviosa": "nuvioso",
    "nuviosas": "nuvioso",
    "nuviosos": "nuvioso",
    "nuzinha": "nu",
    "nuzinhas": "nu",
    "nuzinho": "nu",
    "nuzinhos": "nu",
    "nuzita": "nu",
    "nuzitas": "nu",
    "nuzito": "nu",
    "nuzitos": "nu",
    "nuções": "nução",
    "nylons": "nylon",
    "nábidas": "nábida",
    "náblios": "náblio",
    "nácares": "nácar",
    "nádegas": "nádega",
    "náfega": "náfego",
    "náfegas": "náfego",
    "náfegos": "náfego",
    "nágeras": "nágera",
    "náiadas": "náiada",
    "náiades": "náiade",
    "nártexes": "nártex",
    "nátrios": "nátrio",
    "náufraga": "náufrago",
    "náufragas": "náufrago",
    "náufragos": "náufrago",
    "náufragosa": "náufragoso",
    "náufragosas": "náufragoso",
    "náufragosos": "náufragoso",
    "náuseas": "náusea",
    "náutica": "náutico",
    "náuticas": "náutico",
    "náuticos": "náutico",
    "náutilos": "náutilo",
    "náxios": "náxio",
    "názires": "názir",
    "nãos": "não",
    "nébrides": "nébride",
    "nébulas": "nébula",
    "nébéis": "nébel",
    "néctares": "néctar",
    "néctons": "nécton",
    "nédia": "nédio",
    "nédias": "nédio",
    "nédios": "nédio",
    "négligês": "négligê",
    "nénias": "nénia",
    "néons": "néon",
    "nérios": "nério",
    "nérvea": "nérveo",
    "nérveas": "nérveo",
    "nérveos": "nérveo",
    "néscia": "néscio",
    "néscias": "néscio",
    "néscios": "néscio",
    "névoas": "névoa",
    "nêndis": "nêndi",
    "nês": "nê",
    "nêsperas": "nêspera",
    "nêsperos": "nêspero",
    "nêurulas": "nêurula",
    "nêvedas": "nêveda",
    "níguas": "nígua",
    "nílica": "nílico",
    "nílicas": "nílico",
    "nílicos": "nílico",
    "nímia": "nímio",
    "nímias": "nímio",
    "nímios": "nímio",
    "níqueis": "níquel",
    "níscaros": "níscaro",
    "nítida": "nítido",
    "nítidas": "nítido",
    "nítidos": "nítido",
    "nítrica": "nítrico",
    "nítricas": "nítrico",
    "nítricos": "nítrico",
    "nívea": "níveo",
    "níveas": "níveo",
    "níveis": "nível",
    "níveos": "níveo",
    "nízaros": "nízaro",
    "nódoas": "nódoa",
    "nódulos": "nódulo",
    "nómadas": "nómada",
    "nómades": "nómade",
    "nóminas": "nómina",
    "nónios": "nónio",
    "nónupla": "nónuplo",
    "nónuplos": "nónuplo",
    "nórdica": "nórdico",
    "nórdicas": "nórdico",
    "nórdicos": "nórdico",
    "nórica": "nórico",
    "nóricas": "nórico",
    "nóricos": "nórico",
    "nós": "nó",
    "nótulas": "nótula",
    "nóxia": "nóxio",
    "nóxias": "nóxio",
    "nóxios": "nóxio",
    "núbia": "núbio",
    "núbias": "núbio",
    "núbios": "núbio",
    "núbis": "núbil",
    "núcegos": "núcego",
    "núcleos": "núcleo",
    "núculas": "núcula",
    "núfares": "núfar",
    "númenes": "númen",
    "númenos": "númeno",
    "númens": "númen",
    "números": "número",
    "númidas": "númida",
    "núncios": "núncio",
    "núndinas": "núndina",
    "núvea": "núveo",
    "núveas": "núveo",
    "núveos": "núveo",
    "oaristos": "oaristo",
    "oarística": "oarístico",
    "oarísticas": "oarístico",
    "oarísticos": "oarístico",
    "oasiana": "oasiano",
    "oasianas": "oasiano",
    "oasianos": "oasiano",
    "obaudições": "obaudição",
    "obceca": "obcecar",
    "obcecada": "obcecar",
    "obcecadas": "obcecar",
    "obcecado": "obcecar",
    "obcecadora": "obcecador",
    "obcecadoras": "obcecador",
    "obcecadores": "obcecador",
    "obcecados": "obcecar",
    "obcecadíssima": "obcecado",
    "obcecadíssimas": "obcecado",
    "obcecadíssimo": "obcecado",
    "obcecadíssimos": "obcecado",
    "obcecai": "obcecar",
    "obcecais": "obcecar",
    "obcecam": "obcecar",
    "obcecamo": "obcecar",
    "obcecamos": "obcecar",
    "obcecando": "obcecar",
    "obcecantes": "obcecante",
    "obcecara": "obcecar",
    "obcecaram": "obcecar",
    "obcecaras": "obcecar",
    "obcecarde": "obcecar",
    "obcecardes": "obcecar",
    "obcecare": "obcecar",
    "obcecarei": "obcecar",
    "obcecareis": "obcecar",
    "obcecarem": "obcecar",
    "obcecaremos": "obcecar",
    "obcecares": "obcecar",
    "obcecaria": "obcecar",
    "obcecariam": "obcecar",
    "obcecarias": "obcecar",
    "obcecarmo": "obcecar",
    "obcecarmos": "obcecar",
    "obcecará": "obcecar",
    "obcecarás": "obcecar",
    "obcecarão": "obcecar",
    "obcecaríamos": "obcecar",
    "obcecaríeis": "obcecar",
    "obcecas": "obcecar",
    "obcecasse": "obcecar",
    "obcecassem": "obcecar",
    "obcecasses": "obcecar",
    "obcecaste": "obcecar",
    "obcecastes": "obcecar",
    "obcecava": "obcecar",
    "obcecavam": "obcecar",
    "obcecavas": "obcecar",
    "obcecações": "obcecação",
    "obceco": "obcecar",
    "obcecou": "obcecar",
    "obcecá": "obcecar",
    "obcecámo": "obcecar",
    "obcecámos": "obcecar",
    "obcecáramo": "obcecar",
    "obcecáramos": "obcecar",
    "obcecárei": "obcecar",
    "obcecáreis": "obcecar",
    "obcecásseis": "obcecar",
    "obcecássemos": "obcecar",
    "obcecávamo": "obcecar",
    "obcecávamos": "obcecar",
    "obcecávei": "obcecar",
    "obcecáveis": "obcecar",
    "obceque": "obcecar",
    "obcequei": "obcecar",
    "obcequeis": "obcecar",
    "obcequem": "obcecar",
    "obcequemo": "obcecar",
    "obcequemos": "obcecar",
    "obceques": "obcecar",
    "obcordada": "obcordado",
    "obcordadas": "obcordado",
    "obcordados": "obcordado",
    "obcordiformes": "obcordiforme",
    "obcorrentes": "obcorrente",
    "obcónica": "obcónico",
    "obcónicas": "obcónico",
    "obcónicos": "obcónico",
    "obducta": "obducto",
    "obductas": "obducto",
    "obductos": "obducto",
    "obdura": "obdurar",
    "obdurada": "obdurar",
    "obduradas": "obdurar",
    "obdurado": "obdurar",
    "obdurados": "obdurar",
    "obdurai": "obdurar",
    "obdurais": "obdurar",
    "obduram": "obdurar",
    "obduramo": "obdurar",
    "obduramos": "obdurar",
    "obdurando": "obdurar",
    "obdurara": "obdurar",
    "obduraram": "obdurar",
    "obduraras": "obdurar",
    "obdurarde": "obdurar",
    "obdurardes": "obdurar",
    "obdurare": "obdurar",
    "obdurarei": "obdurar",
    "obdurareis": "obdurar",
    "obdurarem": "obdurar",
    "obduraremos": "obdurar",
    "obdurares": "obdurar",
    "obduraria": "obdurar",
    "obdurariam": "obdurar",
    "obdurarias": "obdurar",
    "obdurarmo": "obdurar",
    "obdurarmos": "obdurar",
    "obdurará": "obdurar",
    "obdurarás": "obdurar",
    "obdurarão": "obdurar",
    "obduraríamos": "obdurar",
    "obduraríeis": "obdurar",
    "obduras": "obdurar",
    "obdurasse": "obdurar",
    "obdurassem": "obdurar",
    "obdurasses": "obdurar",
    "obduraste": "obdurar",
    "obdurastes": "obdurar",
    "obdurava": "obdurar",
    "obduravam": "obdurar",
    "obduravas": "obdurar",
    "obdurações": "obduração",
    "obdure": "obdurar",
    "obdurei": "obdurar",
    "obdureis": "obdurar",
    "obdurem": "obdurar",
    "obduremo": "obdurar",
    "obduremos": "obdurar",
    "obdures": "obdurar",
    "obduro": "obdurar",
    "obdurou": "obdurar",
    "obdurá": "obdurar",
    "obdurámo": "obdurar",
    "obdurámos": "obdurar",
    "obduráramo": "obdurar",
    "obduráramos": "obdurar",
    "obdurárei": "obdurar",
    "obduráreis": "obdurar",
    "obdurásseis": "obdurar",
    "obdurássemos": "obdurar",
    "obdurávamo": "obdurar",
    "obdurávamos": "obdurar",
    "obdurávei": "obdurar",
    "obduráveis": "obdurar",
    "obedece": "obedecer",
    "obedecei": "obedecer",
    "obedeceis": "obedecer",
    "obedecem": "obedecer",
    "obedecemo": "obedecer",
    "obedecemos": "obedecer",
    "obedecendo": "obedecer",
    "obedecera": "obedecer",
    "obedeceram": "obedecer",
    "obedeceras": "obedecer",
    "obedecerdes": "obedecer",
    "obedecerei": "obedecer",
    "obedecereis": "obedecer",
    "obedecerem": "obedecer",
    "obedeceremos": "obedecer",
    "obedeceres": "obedecer",
    "obedeceria": "obedecer",
    "obedeceriam": "obedecer",
    "obedecerias": "obedecer",
    "obedecermo": "obedecer",
    "obedecermos": "obedecer",
    "obedecerá": "obedecer",
    "obedecerás": "obedecer",
    "obedecerão": "obedecer",
    "obedeceríamos": "obedecer",
    "obedeceríeis": "obedecer",
    "obedeces": "obedecer",
    "obedecesse": "obedecer",
    "obedecessem": "obedecer",
    "obedecesses": "obedecer",
    "obedeceste": "obedecer",
    "obedecestes": "obedecer",
    "obedeceu": "obedecer",
    "obedeci": "obedecer",
    "obedecia": "obedecer",
    "obedeciam": "obedecer",
    "obedecias": "obedecer",
    "obedecida": "obedecido",
    "obedecidas": "obedecido",
    "obedecido": "obedecer",
    "obedecidos": "obedecido",
    "obedecêramo": "obedecer",
    "obedecêramos": "obedecer",
    "obedecêreis": "obedecer",
    "obedecêsseis": "obedecer",
    "obedecêssemos": "obedecer",
    "obedecíamo": "obedecer",
    "obedecíamos": "obedecer",
    "obedecíeis": "obedecer",
    "obedecíveis": "obedecível",
    "obedeça": "obedecer",
    "obedeçais": "obedecer",
    "obedeçam": "obedecer",
    "obedeçamo": "obedecer",
    "obedeçamos": "obedecer",
    "obedeças": "obedecer",
    "obedeço": "obedecer",
    "obedienciais": "obediencial",
    "obedientes": "obediente",
    "obediências": "obediência",
    "obeliscais": "obeliscal",
    "obeliscos": "obelisco",
    "obera": "oberar",
    "oberada": "oberar",
    "oberadas": "oberar",
    "oberado": "oberar",
    "oberados": "oberar",
    "oberai": "oberar",
    "oberais": "oberar",
    "oberam": "oberar",
    "oberamo": "oberar",
    "oberamos": "oberar",
    "oberando": "oberar",
    "oberara": "oberar",
    "oberaram": "oberar",
    "oberaras": "oberar",
    "oberarde": "oberar",
    "oberardes": "oberar",
    "oberare": "oberar",
    "oberarei": "oberar",
    "oberareis": "oberar",
    "oberarem": "oberar",
    "oberaremos": "oberar",
    "oberares": "oberar",
    "oberaria": "oberar",
    "oberariam": "oberar",
    "oberarias": "oberar",
    "oberarmo": "oberar",
    "oberarmos": "oberar",
    "oberará": "oberar",
    "oberarás": "oberar",
    "oberarão": "oberar",
    "oberaríamos": "oberar",
    "oberaríeis": "oberar",
    "oberas": "oberar",
    "oberasse": "oberar",
    "oberassem": "oberar",
    "oberasses": "oberar",
    "oberaste": "oberar",
    "oberastes": "oberar",
    "oberava": "oberar",
    "oberavam": "oberar",
    "oberavas": "oberar",
    "obere": "oberar",
    "oberei": "oberar",
    "obereis": "oberar",
    "oberem": "oberar",
    "oberemo": "oberar",
    "oberemos": "oberar",
    "oberes": "oberar",
    "obero": "oberar",
    "oberou": "oberar",
    "oberá": "oberar",
    "oberámo": "oberar",
    "oberámos": "oberar",
    "oberáramo": "oberar",
    "oberáramos": "oberar",
    "oberárei": "oberar",
    "oberáreis": "oberar",
    "oberásseis": "oberar",
    "oberássemos": "oberar",
    "oberávamo": "oberar",
    "oberávamos": "oberar",
    "oberávei": "oberar",
    "oberáveis": "oberável",
    "obesa": "obeso",
    "obesas": "obeso",
    "obesidades": "obesidade",
    "obesos": "obeso",
    "obituária": "obituário",
    "obituárias": "obituário",
    "obituários": "obituário",
    "objecta": "objectar",
    "objectada": "objectar",
    "objectadas": "objectar",
    "objectado": "objectar",
    "objectados": "objectar",
    "objectai": "objectar",
    "objectais": "objectar",
    "objectam": "objectar",
    "objectamo": "objectar",
    "objectamos": "objectar",
    "objectando": "objectar",
    "objectantes": "objectante",
    "objectara": "objectar",
    "objectaram": "objectar",
    "objectaras": "objectar",
    "objectarde": "objectar",
    "objectardes": "objectar",
    "objectare": "objectar",
    "objectarei": "objectar",
    "objectareis": "objectar",
    "objectarem": "objectar",
    "objectaremos": "objectar",
    "objectares": "objectar",
    "objectaria": "objectar",
    "objectariam": "objectar",
    "objectarias": "objectar",
    "objectarmo": "objectar",
    "objectarmos": "objectar",
    "objectará": "objectar",
    "objectarás": "objectar",
    "objectarão": "objectar",
    "objectaríamos": "objectar",
    "objectaríeis": "objectar",
    "objectas": "objectar",
    "objectasse": "objectar",
    "objectassem": "objectar",
    "objectasses": "objectar",
    "objectaste": "objectar",
    "objectastes": "objectar",
    "objectava": "objectar",
    "objectavam": "objectar",
    "objectavas": "objectar",
    "objecte": "objectar",
    "objectei": "objectar",
    "objecteis": "objectar",
    "objectem": "objectar",
    "objectemo": "objectar",
    "objectemos": "objectar",
    "objectes": "objectar",
    "objectiva": "objectivo",
    "objectivada": "objectivar",
    "objectivadas": "objectivar",
    "objectivado": "objectivar",
    "objectivados": "objectivar",
    "objectivai": "objectivar",
    "objectivais": "objectivar",
    "objectivam": "objectivar",
    "objectivamo": "objectivar",
    "objectivamos": "objectivar",
    "objectivando": "objectivar",
    "objectivara": "objectivar",
    "objectivaram": "objectivar",
    "objectivaras": "objectivar",
    "objectivarde": "objectivar",
    "objectivardes": "objectivar",
    "objectivare": "objectivar",
    "objectivarei": "objectivar",
    "objectivareis": "objectivar",
    "objectivarem": "objectivar",
    "objectivaremos": "objectivar",
    "objectivares": "objectivar",
    "objectivaria": "objectivar",
    "objectivariam": "objectivar",
    "objectivarias": "objectivar",
    "objectivarmo": "objectivar",
    "objectivarmos": "objectivar",
    "objectivará": "objectivar",
    "objectivarás": "objectivar",
    "objectivarão": "objectivar",
    "objectivaríamos": "objectivar",
    "objectivaríeis": "objectivar",
    "objectivas": "objectivo",
    "objectivasse": "objectivar",
    "objectivassem": "objectivar",
    "objectivasses": "objectivar",
    "objectivaste": "objectivar",
    "objectivastes": "objectivar",
    "objectivava": "objectivar",
    "objectivavam": "objectivar",
    "objectivavas": "objectivar",
    "objectivações": "objectivação",
    "objective": "objectivar",
    "objectivei": "objectivar",
    "objectiveis": "objectivar",
    "objectivem": "objectivar",
    "objectivemo": "objectivar",
    "objectivemos": "objectivar",
    "objectives": "objectivar",
    "objectividades": "objectividade",
    "objectivismos": "objectivismo",
    "objectivo": "objectivar",
    "objectivos": "objectivo",
    "objectivou": "objectivar",
    "objectivá": "objectivar",
    "objectivámo": "objectivar",
    "objectivámos": "objectivar",
    "objectiváramo": "objectivar",
    "objectiváramos": "objectivar",
    "objectivárei": "objectivar",
    "objectiváreis": "objectivar",
    "objectivásseis": "objectivar",
    "objectivássemos": "objectivar",
    "objectivávamo": "objectivar",
    "objectivávamos": "objectivar",
    "objectivávei": "objectivar",
    "objectiváveis": "objectivável",
    "objecto": "objectar",
    "objectora": "objector",
    "objectoras": "objector",
    "objectores": "objector",
    "objectos": "objecto",
    "objectou": "objectar",
    "objectá": "objectar",
    "objectámo": "objectar",
    "objectámos": "objectar",
    "objectáramo": "objectar",
    "objectáramos": "objectar",
    "objectárei": "objectar",
    "objectáreis": "objectar",
    "objectásseis": "objectar",
    "objectássemos": "objectar",
    "objectávamo": "objectar",
    "objectávamos": "objectar",
    "objectávei": "objectar",
    "objectáveis": "objectável",
    "objecções": "objecção",
    "objurga": "objurgar",
    "objurgada": "objurgar",
    "objurgadas": "objurgar",
    "objurgado": "objurgar",
    "objurgados": "objurgar",
    "objurgai": "objurgar",
    "objurgais": "objurgar",
    "objurgam": "objurgar",
    "objurgamo": "objurgar",
    "objurgamos": "objurgar",
    "objurgando": "objurgar",
    "objurgara": "objurgar",
    "objurgaram": "objurgar",
    "objurgaras": "objurgar",
    "objurgarde": "objurgar",
    "objurgardes": "objurgar",
    "objurgare": "objurgar",
    "objurgarei": "objurgar",
    "objurgareis": "objurgar",
    "objurgarem": "objurgar",
    "objurgaremos": "objurgar",
    "objurgares": "objurgar",
    "objurgaria": "objurgar",
    "objurgariam": "objurgar",
    "objurgarias": "objurgar",
    "objurgarmo": "objurgar",
    "objurgarmos": "objurgar",
    "objurgará": "objurgar",
    "objurgarás": "objurgar",
    "objurgarão": "objurgar",
    "objurgaríamos": "objurgar",
    "objurgaríeis": "objurgar",
    "objurgas": "objurgar",
    "objurgasse": "objurgar",
    "objurgassem": "objurgar",
    "objurgasses": "objurgar",
    "objurgaste": "objurgar",
    "objurgastes": "objurgar",
    "objurgatória": "objurgatório",
    "objurgatórias": "objurgatório",
    "objurgatórios": "objurgatório",
    "objurgava": "objurgar",
    "objurgavam": "objurgar",
    "objurgavas": "objurgar",
    "objurgações": "objurgação",
    "objurgo": "objurgar",
    "objurgou": "objurgar",
    "objurgue": "objurgar",
    "objurguei": "objurgar",
    "objurgueis": "objurgar",
    "objurguem": "objurgar",
    "objurguemo": "objurgar",
    "objurguemos": "objurgar",
    "objurgues": "objurgar",
    "objurgá": "objurgar",
    "objurgámo": "objurgar",
    "objurgámos": "objurgar",
    "objurgáramo": "objurgar",
    "objurgáramos": "objurgar",
    "objurgárei": "objurgar",
    "objurgáreis": "objurgar",
    "objurgásseis": "objurgar",
    "objurgássemos": "objurgar",
    "objurgávamo": "objurgar",
    "objurgávamos": "objurgar",
    "objurgávei": "objurgar",
    "objurgáveis": "objurgar",
    "obladas": "oblada",
    "oblata": "oblatar",
    "oblatada": "oblatar",
    "oblatadas": "oblatar",
    "oblatado": "oblatar",
    "oblatados": "oblatar",
    "oblatai": "oblatar",
    "oblatais": "oblatar",
    "oblatam": "oblatar",
    "oblatamo": "oblatar",
    "oblatamos": "oblatar",
    "oblatando": "oblatar",
    "oblatara": "oblatar",
    "oblataram": "oblatar",
    "oblataras": "oblatar",
    "oblatarde": "oblatar",
    "oblatardes": "oblatar",
    "oblatare": "oblatar",
    "oblatarei": "oblatar",
    "oblatareis": "oblatar",
    "oblatarem": "oblatar",
    "oblataremos": "oblatar",
    "oblatares": "oblatar",
    "oblataria": "oblatar",
    "oblatariam": "oblatar",
    "oblatarias": "oblatar",
    "oblatarmo": "oblatar",
    "oblatarmos": "oblatar",
    "oblatará": "oblatar",
    "oblatarás": "oblatar",
    "oblatarão": "oblatar",
    "oblataríamos": "oblatar",
    "oblataríeis": "oblatar",
    "oblatas": "oblatar",
    "oblatasse": "oblatar",
    "oblatassem": "oblatar",
    "oblatasses": "oblatar",
    "oblataste": "oblatar",
    "oblatastes": "oblatar",
    "oblatava": "oblatar",
    "oblatavam": "oblatar",
    "oblatavas": "oblatar",
    "oblate": "oblatar",
    "oblatei": "oblatar",
    "oblateis": "oblatar",
    "oblatem": "oblatar",
    "oblatemo": "oblatar",
    "oblatemos": "oblatar",
    "oblates": "oblatar",
    "oblativa": "oblativo",
    "oblativas": "oblativo",
    "oblatividades": "oblatividade",
    "oblativos": "oblativo",
    "oblato": "oblatar",
    "oblatos": "oblato",
    "oblatou": "oblatar",
    "oblatá": "oblatar",
    "oblatámo": "oblatar",
    "oblatámos": "oblatar",
    "oblatáramo": "oblatar",
    "oblatáramos": "oblatar",
    "oblatárei": "oblatar",
    "oblatáreis": "oblatar",
    "oblatásseis": "oblatar",
    "oblatássemos": "oblatar",
    "oblatávamo": "oblatar",
    "oblatávamos": "oblatar",
    "oblatávei": "oblatar",
    "oblatáveis": "oblatar",
    "oblações": "oblação",
    "obligulada": "obligulado",
    "obliguladas": "obligulado",
    "obligulados": "obligulado",
    "obliqua": "obliquar",
    "obliquada": "obliquar",
    "obliquadas": "obliquar",
    "obliquado": "obliquar",
    "obliquados": "obliquar",
    "obliquai": "obliquar",
    "obliquais": "obliquar",
    "obliquam": "obliquar",
    "obliquamo": "obliquar",
    "obliquamos": "obliquar",
    "obliquando": "obliquar",
    "obliquara": "obliquar",
    "obliquaram": "obliquar",
    "obliquaras": "obliquar",
    "obliquardes": "obliquar",
    "obliquarei": "obliquar",
    "obliquareis": "obliquar",
    "obliquarem": "obliquar",
    "obliquaremos": "obliquar",
    "obliquares": "obliquar",
    "obliquaria": "obliquar",
    "obliquariam": "obliquar",
    "obliquarias": "obliquar",
    "obliquarmo": "obliquar",
    "obliquarmos": "obliquar",
    "obliquará": "obliquar",
    "obliquarás": "obliquar",
    "obliquarão": "obliquar",
    "obliquaríamos": "obliquar",
    "obliquaríeis": "obliquar",
    "obliquas": "obliquar",
    "obliquasse": "obliquar",
    "obliquassem": "obliquar",
    "obliquasses": "obliquar",
    "obliquaste": "obliquar",
    "obliquastes": "obliquar",
    "obliquava": "obliquar",
    "obliquavam": "obliquar",
    "obliquavas": "obliquar",
    "obliquei": "obliquar",
    "obliqueis": "obliquar",
    "obliquemo": "obliquar",
    "obliquemos": "obliquar",
    "obliques": "obliquar",
    "obliquidades": "obliquidade",
    "obliquo": "obliquar",
    "obliquou": "obliquar",
    "obliquámo": "obliquar",
    "obliquámos": "obliquar",
    "obliquáramo": "obliquar",
    "obliquáramos": "obliquar",
    "obliquáreis": "obliquar",
    "obliquásseis": "obliquar",
    "obliquássemos": "obliquar",
    "obliquávamo": "obliquar",
    "obliquávamos": "obliquar",
    "obliquáveis": "obliquar",
    "obliquângula": "obliquângulo",
    "obliquângulas": "obliquângulo",
    "obliquângulos": "obliquângulo",
    "obliqúe": "obliquar",
    "obliqúem": "obliquar",
    "obliqúes": "obliquar",
    "oblitera": "obliterar",
    "obliterada": "obliterar",
    "obliteradas": "obliterar",
    "obliterado": "obliterar",
    "obliteradora": "obliterador",
    "obliteradoras": "obliterador",
    "obliteradores": "obliterador",
    "obliterados": "obliterar",
    "obliterai": "obliterar",
    "obliterais": "obliterar",
    "obliteram": "obliterar",
    "obliteramo": "obliterar",
    "obliteramos": "obliterar",
    "obliterando": "obliterar",
    "obliterantes": "obliterante",
    "obliterara": "obliterar",
    "obliteraram": "obliterar",
    "obliteraras": "obliterar",
    "obliterarde": "obliterar",
    "obliterardes": "obliterar",
    "obliterare": "obliterar",
    "obliterarei": "obliterar",
    "obliterareis": "obliterar",
    "obliterarem": "obliterar",
    "obliteraremos": "obliterar",
    "obliterares": "obliterar",
    "obliteraria": "obliterar",
    "obliterariam": "obliterar",
    "obliterarias": "obliterar",
    "obliterarmo": "obliterar",
    "obliterarmos": "obliterar",
    "obliterará": "obliterar",
    "obliterarás": "obliterar",
    "obliterarão": "obliterar",
    "obliteraríamos": "obliterar",
    "obliteraríeis": "obliterar",
    "obliteras": "obliterar",
    "obliterasse": "obliterar",
    "obliterassem": "obliterar",
    "obliterasses": "obliterar",
    "obliteraste": "obliterar",
    "obliterastes": "obliterar",
    "obliterava": "obliterar",
    "obliteravam": "obliterar",
    "obliteravas": "obliterar",
    "obliterações": "obliteração",
    "oblitere": "obliterar",
    "obliterei": "obliterar",
    "oblitereis": "obliterar",
    "obliterem": "obliterar",
    "obliteremo": "obliterar",
    "obliteremos": "obliterar",
    "obliteres": "obliterar",
    "oblitero": "obliterar",
    "obliterou": "obliterar",
    "obliterá": "obliterar",
    "obliterámo": "obliterar",
    "obliterámos": "obliterar",
    "obliteráramo": "obliterar",
    "obliteráramos": "obliterar",
    "obliterárei": "obliterar",
    "obliteráreis": "obliterar",
    "obliterásseis": "obliterar",
    "obliterássemos": "obliterar",
    "obliterávamo": "obliterar",
    "obliterávamos": "obliterar",
    "obliterávei": "obliterar",
    "obliteráveis": "obliterável",
    "oblonga": "oblongo",
    "oblongada": "oblongado",
    "oblongadas": "oblongado",
    "oblongados": "oblongado",
    "oblongas": "oblongo",
    "oblongifólia": "oblongifólio",
    "oblongifólias": "oblongifólio",
    "oblongifólios": "oblongifólio",
    "oblongos": "oblongo",
    "oblíqua": "oblíquo",
    "oblíquas": "oblíquo",
    "oblíquos": "oblíquo",
    "oblívios": "oblívio",
    "obnubila": "obnubilar",
    "obnubilada": "obnubilar",
    "obnubiladas": "obnubilar",
    "obnubilado": "obnubilar",
    "obnubilados": "obnubilar",
    "obnubilai": "obnubilar",
    "obnubilais": "obnubilar",
    "obnubilam": "obnubilar",
    "obnubilamo": "obnubilar",
    "obnubilamos": "obnubilar",
    "obnubilando": "obnubilar",
    "obnubilara": "obnubilar",
    "obnubilaram": "obnubilar",
    "obnubilaras": "obnubilar",
    "obnubilarde": "obnubilar",
    "obnubilardes": "obnubilar",
    "obnubilare": "obnubilar",
    "obnubilarei": "obnubilar",
    "obnubilareis": "obnubilar",
    "obnubilarem": "obnubilar",
    "obnubilaremos": "obnubilar",
    "obnubilares": "obnubilar",
    "obnubilaria": "obnubilar",
    "obnubilariam": "obnubilar",
    "obnubilarias": "obnubilar",
    "obnubilarmo": "obnubilar",
    "obnubilarmos": "obnubilar",
    "obnubilará": "obnubilar",
    "obnubilarás": "obnubilar",
    "obnubilarão": "obnubilar",
    "obnubilaríamos": "obnubilar",
    "obnubilaríeis": "obnubilar",
    "obnubilas": "obnubilar",
    "obnubilasse": "obnubilar",
    "obnubilassem": "obnubilar",
    "obnubilasses": "obnubilar",
    "obnubilaste": "obnubilar",
    "obnubilastes": "obnubilar",
    "obnubilava": "obnubilar",
    "obnubilavam": "obnubilar",
    "obnubilavas": "obnubilar",
    "obnubilações": "obnubilação",
    "obnubile": "obnubilar",
    "obnubilei": "obnubilar",
    "obnubileis": "obnubilar",
    "obnubilem": "obnubilar",
    "obnubilemo": "obnubilar",
    "obnubilemos": "obnubilar",
    "obnubiles": "obnubilar",
    "obnubilo": "obnubilar",
    "obnubilou": "obnubilar",
    "obnubilá": "obnubilar",
    "obnubilámo": "obnubilar",
    "obnubilámos": "obnubilar",
    "obnubiláramo": "obnubilar",
    "obnubiláramos": "obnubilar",
    "obnubilárei": "obnubilar",
    "obnubiláreis": "obnubilar",
    "obnubilásseis": "obnubilar",
    "obnubilássemos": "obnubilar",
    "obnubilávamo": "obnubilar",
    "obnubilávamos": "obnubilar",
    "obnubilávei": "obnubilar",
    "obnubiláveis": "obnubilar",
    "obnóxia": "obnóxio",
    "obnóxias": "obnóxio",
    "obnóxios": "obnóxio",
    "obovais": "oboval",
    "obovóides": "obovóide",
    "oboés": "oboé",
    "oboístas": "oboísta",
    "obra": "obrar",
    "obrada": "obrar",
    "obradas": "obrar",
    "obrado": "obrar",
    "obradora": "obrador",
    "obradoras": "obrador",
    "obradores": "obrador",
    "obrados": "obrar",
    "obragens": "obragem",
    "obrai": "obrar",
    "obrais": "obrar",
    "obram": "obrar",
    "obramo": "obrar",
    "obramos": "obrar",
    "obrando": "obrar",
    "obrantes": "obrante",
    "obrara": "obrar",
    "obraram": "obrar",
    "obraras": "obrar",
    "obrarde": "obrar",
    "obrardes": "obrar",
    "obrare": "obrar",
    "obrarei": "obrar",
    "obrareis": "obrar",
    "obrarem": "obrar",
    "obraremos": "obrar",
    "obrares": "obrar",
    "obraria": "obrar",
    "obrariam": "obrar",
    "obrarias": "obrar",
    "obrarmo": "obrar",
    "obrarmos": "obrar",
    "obrará": "obrar",
    "obrarás": "obrar",
    "obrarão": "obrar",
    "obraríamos": "obrar",
    "obraríeis": "obrar",
    "obras": "obrar",
    "obrasse": "obrar",
    "obrassem": "obrar",
    "obrasses": "obrar",
    "obraste": "obrar",
    "obrastes": "obrar",
    "obrava": "obrar",
    "obravam": "obrar",
    "obravas": "obrar",
    "obrazinha": "obra",
    "obrazinhas": "obra",
    "obrazita": "obra",
    "obrazitas": "obra",
    "obrações": "obração",
    "obre": "obrar",
    "obreeira": "obreeiro",
    "obreeiras": "obreeiro",
    "obreeiros": "obreeiro",
    "obrei": "obrar",
    "obreias": "obreia",
    "obreira": "obreiro",
    "obreiras": "obreiro",
    "obreiros": "obreiro",
    "obreis": "obrar",
    "obrem": "obrar",
    "obremo": "obrar",
    "obremos": "obrar",
    "obres": "obrar",
    "obriga": "obrigar",
    "obrigacionistas": "obrigacionista",
    "obrigacionária": "obrigacionário",
    "obrigacionárias": "obrigacionário",
    "obrigacionários": "obrigacionário",
    "obrigada": "obrigar",
    "obrigadas": "obrigar",
    "obrigado": "obrigar",
    "obrigadora": "obrigador",
    "obrigadoras": "obrigador",
    "obrigadores": "obrigador",
    "obrigados": "obrigar",
    "obrigai": "obrigar",
    "obrigais": "obrigar",
    "obrigam": "obrigar",
    "obrigamo": "obrigar",
    "obrigamos": "obrigar",
    "obrigando": "obrigar",
    "obrigantes": "obrigante",
    "obrigara": "obrigar",
    "obrigaram": "obrigar",
    "obrigaras": "obrigar",
    "obrigarde": "obrigar",
    "obrigardes": "obrigar",
    "obrigare": "obrigar",
    "obrigarei": "obrigar",
    "obrigareis": "obrigar",
    "obrigarem": "obrigar",
    "obrigaremos": "obrigar",
    "obrigares": "obrigar",
    "obrigaria": "obrigar",
    "obrigariam": "obrigar",
    "obrigarias": "obrigar",
    "obrigarmo": "obrigar",
    "obrigarmos": "obrigar",
    "obrigará": "obrigar",
    "obrigarás": "obrigar",
    "obrigarão": "obrigar",
    "obrigaríamos": "obrigar",
    "obrigaríeis": "obrigar",
    "obrigas": "obrigar",
    "obrigasse": "obrigar",
    "obrigassem": "obrigar",
    "obrigasses": "obrigar",
    "obrigaste": "obrigar",
    "obrigastes": "obrigar",
    "obrigativa": "obrigativo",
    "obrigativas": "obrigativo",
    "obrigativos": "obrigativo",
    "obrigatoriedades": "obrigatoriedade",
    "obrigatária": "obrigatário",
    "obrigatárias": "obrigatário",
    "obrigatários": "obrigatário",
    "obrigatória": "obrigatório",
    "obrigatórias": "obrigatório",
    "obrigatórios": "obrigatório",
    "obrigava": "obrigar",
    "obrigavam": "obrigar",
    "obrigavas": "obrigar",
    "obrigações": "obrigação",
    "obrigo": "obrigar",
    "obrigou": "obrigar",
    "obrigue": "obrigar",
    "obriguei": "obrigar",
    "obrigueis": "obrigar",
    "obriguem": "obrigar",
    "obriguemo": "obrigar",
    "obriguemos": "obrigar",
    "obrigues": "obrigar",
    "obrigá": "obrigar",
    "obrigámo": "obrigar",
    "obrigámos": "obrigar",
    "obrigáramo": "obrigar",
    "obrigáramos": "obrigar",
    "obrigárei": "obrigar",
    "obrigáreis": "obrigar",
    "obrigásseis": "obrigar",
    "obrigássemos": "obrigar",
    "obrigávamo": "obrigar",
    "obrigávamos": "obrigar",
    "obrigávei": "obrigar",
    "obrigáveis": "obrigável",
    "obro": "obrar",
    "obrou": "obrar",
    "obrá": "obrar",
    "obrámo": "obrar",
    "obrámos": "obrar",
    "obráramo": "obrar",
    "obráramos": "obrar",
    "obrárei": "obrar",
    "obráreis": "obrar",
    "obrásseis": "obrar",
    "obrássemos": "obrar",
    "obrávamo": "obrar",
    "obrávamos": "obrar",
    "obrávei": "obrar",
    "obráveis": "obrar",
    "obscena": "obsceno",
    "obscenas": "obsceno",
    "obscenidades": "obscenidade",
    "obscenos": "obsceno",
    "obscura": "obscuro",
    "obscurantes": "obscurante",
    "obscurantismos": "obscurantismo",
    "obscurantistas": "obscurantista",
    "obscurantiza": "obscurantizar",
    "obscurantizada": "obscurantizar",
    "obscurantizadas": "obscurantizar",
    "obscurantizado": "obscurantizar",
    "obscurantizados": "obscurantizar",
    "obscurantizai": "obscurantizar",
    "obscurantizais": "obscurantizar",
    "obscurantizam": "obscurantizar",
    "obscurantizamo": "obscurantizar",
    "obscurantizamos": "obscurantizar",
    "obscurantizando": "obscurantizar",
    "obscurantizara": "obscurantizar",
    "obscurantizaram": "obscurantizar",
    "obscurantizaras": "obscurantizar",
    "obscurantizarde": "obscurantizar",
    "obscurantizardes": "obscurantizar",
    "obscurantizare": "obscurantizar",
    "obscurantizarei": "obscurantizar",
    "obscurantizareis": "obscurantizar",
    "obscurantizarem": "obscurantizar",
    "obscurantizaremos": "obscurantizar",
    "obscurantizares": "obscurantizar",
    "obscurantizaria": "obscurantizar",
    "obscurantizariam": "obscurantizar",
    "obscurantizarias": "obscurantizar",
    "obscurantizarmo": "obscurantizar",
    "obscurantizarmos": "obscurantizar",
    "obscurantizará": "obscurantizar",
    "obscurantizarás": "obscurantizar",
    "obscurantizarão": "obscurantizar",
    "obscurantizaríamos": "obscurantizar",
    "obscurantizaríeis": "obscurantizar",
    "obscurantizas": "obscurantizar",
    "obscurantizasse": "obscurantizar",
    "obscurantizassem": "obscurantizar",
    "obscurantizasses": "obscurantizar",
    "obscurantizaste": "obscurantizar",
    "obscurantizastes": "obscurantizar",
    "obscurantizava": "obscurantizar",
    "obscurantizavam": "obscurantizar",
    "obscurantizavas": "obscurantizar",
    "obscurantize": "obscurantizar",
    "obscurantizei": "obscurantizar",
    "obscurantizeis": "obscurantizar",
    "obscurantizem": "obscurantizar",
    "obscurantizemo": "obscurantizar",
    "obscurantizemos": "obscurantizar",
    "obscurantizes": "obscurantizar",
    "obscurantizo": "obscurantizar",
    "obscurantizou": "obscurantizar",
    "obscurantizá": "obscurantizar",
    "obscurantizámo": "obscurantizar",
    "obscurantizámos": "obscurantizar",
    "obscurantizáramo": "obscurantizar",
    "obscurantizáramos": "obscurantizar",
    "obscurantizárei": "obscurantizar",
    "obscurantizáreis": "obscurantizar",
    "obscurantizásseis": "obscurantizar",
    "obscurantizássemos": "obscurantizar",
    "obscurantizávamo": "obscurantizar",
    "obscurantizávamos": "obscurantizar",
    "obscurantizávei": "obscurantizar",
    "obscurantizáveis": "obscurantizar",
    "obscuras": "obscuro",
    "obscurações": "obscuração",
    "obscurece": "obscurecer",
    "obscurecei": "obscurecer",
    "obscureceis": "obscurecer",
    "obscurecem": "obscurecer",
    "obscurecemo": "obscurecer",
    "obscurecemos": "obscurecer",
    "obscurecendo": "obscurecer",
    "obscurecera": "obscurecer",
    "obscureceram": "obscurecer",
    "obscureceras": "obscurecer",
    "obscurecerde": "obscurecer",
    "obscurecerdes": "obscurecer",
    "obscurecere": "obscurecer",
    "obscurecerei": "obscurecer",
    "obscurecereis": "obscurecer",
    "obscurecerem": "obscurecer",
    "obscureceremos": "obscurecer",
    "obscureceres": "obscurecer",
    "obscureceria": "obscurecer",
    "obscureceriam": "obscurecer",
    "obscurecerias": "obscurecer",
    "obscurecermo": "obscurecer",
    "obscurecermos": "obscurecer",
    "obscurecerá": "obscurecer",
    "obscurecerás": "obscurecer",
    "obscurecerão": "obscurecer",
    "obscureceríamos": "obscurecer",
    "obscureceríeis": "obscurecer",
    "obscureces": "obscurecer",
    "obscurecesse": "obscurecer",
    "obscurecessem": "obscurecer",
    "obscurecesses": "obscurecer",
    "obscureceste": "obscurecer",
    "obscurecestes": "obscurecer",
    "obscureceu": "obscurecer",
    "obscureci": "obscurecer",
    "obscurecia": "obscurecer",
    "obscureciam": "obscurecer",
    "obscurecias": "obscurecer",
    "obscurecida": "obscurecido",
    "obscurecidas": "obscurecido",
    "obscurecido": "obscurecer",
    "obscurecidos": "obscurecido",
    "obscurecimentos": "obscurecimento",
    "obscurecê": "obscurecer",
    "obscurecêramo": "obscurecer",
    "obscurecêramos": "obscurecer",
    "obscurecêrei": "obscurecer",
    "obscurecêreis": "obscurecer",
    "obscurecêsseis": "obscurecer",
    "obscurecêssemos": "obscurecer",
    "obscurecíamo": "obscurecer",
    "obscurecíamos": "obscurecer",
    "obscurecíei": "obscurecer",
    "obscurecíeis": "obscurecer",
    "obscurecíveis": "obscurecível",
    "obscureça": "obscurecer",
    "obscureçais": "obscurecer",
    "obscureçam": "obscurecer",
    "obscureçamo": "obscurecer",
    "obscureçamos": "obscurecer",
    "obscureças": "obscurecer",
    "obscureço": "obscurecer",
    "obscuridades": "obscuridade",
    "obscuros": "obscuro",
    "obsecra": "obsecrar",
    "obsecrada": "obsecrar",
    "obsecradas": "obsecrar",
    "obsecrado": "obsecrar",
    "obsecrados": "obsecrar",
    "obsecrai": "obsecrar",
    "obsecrais": "obsecrar",
    "obsecram": "obsecrar",
    "obsecramo": "obsecrar",
    "obsecramos": "obsecrar",
    "obsecrando": "obsecrar",
    "obsecrara": "obsecrar",
    "obsecraram": "obsecrar",
    "obsecraras": "obsecrar",
    "obsecrarde": "obsecrar",
    "obsecrardes": "obsecrar",
    "obsecrare": "obsecrar",
    "obsecrarei": "obsecrar",
    "obsecrareis": "obsecrar",
    "obsecrarem": "obsecrar",
    "obsecraremos": "obsecrar",
    "obsecrares": "obsecrar",
    "obsecraria": "obsecrar",
    "obsecrariam": "obsecrar",
    "obsecrarias": "obsecrar",
    "obsecrarmo": "obsecrar",
    "obsecrarmos": "obsecrar",
    "obsecrará": "obsecrar",
    "obsecrarás": "obsecrar",
    "obsecrarão": "obsecrar",
    "obsecraríamos": "obsecrar",
    "obsecraríeis": "obsecrar",
    "obsecras": "obsecrar",
    "obsecrasse": "obsecrar",
    "obsecrassem": "obsecrar",
    "obsecrasses": "obsecrar",
    "obsecraste": "obsecrar",
    "obsecrastes": "obsecrar",
    "obsecrava": "obsecrar",
    "obsecravam": "obsecrar",
    "obsecravas": "obsecrar",
    "obsecrações": "obsecração",
    "obsecre": "obsecrar",
    "obsecrei": "obsecrar",
    "obsecreis": "obsecrar",
    "obsecrem": "obsecrar",
    "obsecremo": "obsecrar",
    "obsecremos": "obsecrar",
    "obsecres": "obsecrar",
    "obsecro": "obsecrar",
    "obsecrou": "obsecrar",
    "obsecrá": "obsecrar",
    "obsecrámo": "obsecrar",
    "obsecrámos": "obsecrar",
    "obsecráramo": "obsecrar",
    "obsecráramos": "obsecrar",
    "obsecrárei": "obsecrar",
    "obsecráreis": "obsecrar",
    "obsecrásseis": "obsecrar",
    "obsecrássemos": "obsecrar",
    "obsecrávamo": "obsecrar",
    "obsecrávamos": "obsecrar",
    "obsecrávei": "obsecrar",
    "obsecráveis": "obsecrar",
    "obsequentes": "obsequente",
    "obsequia": "obsequiar",
    "obsequiada": "obsequiar",
    "obsequiadas": "obsequiar",
    "obsequiado": "obsequiar",
    "obsequiadora": "obsequiador",
    "obsequiadoras": "obsequiador",
    "obsequiadores": "obsequiador",
    "obsequiados": "obsequiar",
    "obsequiai": "obsequiar",
    "obsequiais": "obsequiar",
    "obsequiam": "obsequiar",
    "obsequiamo": "obsequiar",
    "obsequiamos": "obsequiar",
    "obsequiando": "obsequiar",
    "obsequiara": "obsequiar",
    "obsequiaram": "obsequiar",
    "obsequiaras": "obsequiar",
    "obsequiarde": "obsequiar",
    "obsequiardes": "obsequiar",
    "obsequiare": "obsequiar",
    "obsequiarei": "obsequiar",
    "obsequiareis": "obsequiar",
    "obsequiarem": "obsequiar",
    "obsequiaremos": "obsequiar",
    "obsequiares": "obsequiar",
    "obsequiaria": "obsequiar",
    "obsequiariam": "obsequiar",
    "obsequiarias": "obsequiar",
    "obsequiarmo": "obsequiar",
    "obsequiarmos": "obsequiar",
    "obsequiará": "obsequiar",
    "obsequiarás": "obsequiar",
    "obsequiarão": "obsequiar",
    "obsequiaríamos": "obsequiar",
    "obsequiaríeis": "obsequiar",
    "obsequias": "obsequiar",
    "obsequiasse": "obsequiar",
    "obsequiassem": "obsequiar",
    "obsequiasses": "obsequiar",
    "obsequiaste": "obsequiar",
    "obsequiastes": "obsequiar",
    "obsequiava": "obsequiar",
    "obsequiavam": "obsequiar",
    "obsequiavas": "obsequiar",
    "obsequie": "obsequiar",
    "obsequiei": "obsequiar",
    "obsequieis": "obsequiar",
    "obsequiem": "obsequiar",
    "obsequiemo": "obsequiar",
    "obsequiemos": "obsequiar",
    "obsequies": "obsequiar",
    "obsequio": "obsequiar",
    "obsequiosa": "obsequioso",
    "obsequiosas": "obsequioso",
    "obsequiosidades": "obsequiosidade",
    "obsequiosos": "obsequioso",
    "obsequiou": "obsequiar",
    "obsequiá": "obsequiar",
    "obsequiámo": "obsequiar",
    "obsequiámos": "obsequiar",
    "obsequiáramo": "obsequiar",
    "obsequiáramos": "obsequiar",
    "obsequiárei": "obsequiar",
    "obsequiáreis": "obsequiar",
    "obsequiásseis": "obsequiar",
    "obsequiássemos": "obsequiar",
    "obsequiávamo": "obsequiar",
    "obsequiávamos": "obsequiar",
    "obsequiávei": "obsequiar",
    "obsequiáveis": "obsequiável",
    "observa": "observar",
    "observada": "observar",
    "observadas": "observar",
    "observado": "observar",
    "observadora": "observador",
    "observadoras": "observador",
    "observadorazinha": "observador",
    "observadorazinhas": "observador",
    "observadorazita": "observador",
    "observadorazitas": "observador",
    "observadores": "observador",
    "observadorzinho": "observador",
    "observadorzinhos": "observador",
    "observadorzito": "observador",
    "observadorzitos": "observador",
    "observados": "observar",
    "observai": "observar",
    "observais": "observar",
    "observam": "observar",
    "observamo": "observar",
    "observamos": "observar",
    "observando": "observar",
    "observantes": "observante",
    "observara": "observar",
    "observaram": "observar",
    "observaras": "observar",
    "observarde": "observar",
    "observardes": "observar",
    "observare": "observar",
    "observarei": "observar",
    "observareis": "observar",
    "observarem": "observar",
    "observaremos": "observar",
    "observares": "observar",
    "observaria": "observar",
    "observariam": "observar",
    "observarias": "observar",
    "observarmo": "observar",
    "observarmos": "observar",
    "observará": "observar",
    "observarás": "observar",
    "observarão": "observar",
    "observaríamos": "observar",
    "observaríeis": "observar",
    "observas": "observar",
    "observasse": "observar",
    "observassem": "observar",
    "observasses": "observar",
    "observaste": "observar",
    "observastes": "observar",
    "observatórios": "observatório",
    "observava": "observar",
    "observavam": "observar",
    "observavas": "observar",
    "observações": "observação",
    "observe": "observar",
    "observei": "observar",
    "observeis": "observar",
    "observem": "observar",
    "observemo": "observar",
    "observemos": "observar",
    "observes": "observar",
    "observo": "observar",
    "observou": "observar",
    "observá": "observar",
    "observámo": "observar",
    "observámos": "observar",
    "observáramo": "observar",
    "observáramos": "observar",
    "observárei": "observar",
    "observáreis": "observar",
    "observásseis": "observar",
    "observássemos": "observar",
    "observávamo": "observar",
    "observávamos": "observar",
    "observávei": "observar",
    "observáveis": "observável",
    "observâncias": "observância",
    "obsessa": "obsesso",
    "obsessas": "obsesso",
    "obsessionantes": "obsessionante",
    "obsessiva": "obsessivo",
    "obsessivas": "obsessivo",
    "obsessivos": "obsessivo",
    "obsessora": "obsessor",
    "obsessoras": "obsessor",
    "obsessores": "obsessor",
    "obsessos": "obsesso",
    "obsessões": "obsessão",
    "obsidentes": "obsidente",
    "obsidia": "obsidiar",
    "obsidiada": "obsidiar",
    "obsidiadas": "obsidiar",
    "obsidiado": "obsidiar",
    "obsidiados": "obsidiar",
    "obsidiai": "obsidiar",
    "obsidiais": "obsidiar",
    "obsidiam": "obsidiar",
    "obsidiamo": "obsidiar",
    "obsidiamos": "obsidiar",
    "obsidianas": "obsidiana",
    "obsidiando": "obsidiar",
    "obsidiantes": "obsidiante",
    "obsidiara": "obsidiar",
    "obsidiaram": "obsidiar",
    "obsidiaras": "obsidiar",
    "obsidiarde": "obsidiar",
    "obsidiardes": "obsidiar",
    "obsidiare": "obsidiar",
    "obsidiarei": "obsidiar",
    "obsidiareis": "obsidiar",
    "obsidiarem": "obsidiar",
    "obsidiaremos": "obsidiar",
    "obsidiares": "obsidiar",
    "obsidiaria": "obsidiar",
    "obsidiariam": "obsidiar",
    "obsidiarias": "obsidiar",
    "obsidiarmo": "obsidiar",
    "obsidiarmos": "obsidiar",
    "obsidiará": "obsidiar",
    "obsidiarás": "obsidiar",
    "obsidiarão": "obsidiar",
    "obsidiaríamos": "obsidiar",
    "obsidiaríeis": "obsidiar",
    "obsidias": "obsidiar",
    "obsidiasse": "obsidiar",
    "obsidiassem": "obsidiar",
    "obsidiasses": "obsidiar",
    "obsidiaste": "obsidiar",
    "obsidiastes": "obsidiar",
    "obsidiava": "obsidiar",
    "obsidiavam": "obsidiar",
    "obsidiavas": "obsidiar",
    "obsidie": "obsidiar",
    "obsidiei": "obsidiar",
    "obsidieis": "obsidiar",
    "obsidiem": "obsidiar",
    "obsidiemo": "obsidiar",
    "obsidiemos": "obsidiar",
    "obsidies": "obsidiar",
    "obsidio": "obsidiar",
    "obsidionais": "obsidional",
    "obsidiou": "obsidiar",
    "obsidiá": "obsidiar",
    "obsidiámo": "obsidiar",
    "obsidiámos": "obsidiar",
    "obsidiáramo": "obsidiar",
    "obsidiáramos": "obsidiar",
    "obsidiárei": "obsidiar",
    "obsidiáreis": "obsidiar",
    "obsidiásseis": "obsidiar",
    "obsidiássemos": "obsidiar",
    "obsidiávamo": "obsidiar",
    "obsidiávamos": "obsidiar",
    "obsidiávei": "obsidiar",
    "obsidiáveis": "obsidiar",
    "obsolescências": "obsolescência",
    "obsoleta": "obsoleto",
    "obsoletas": "obsoleto",
    "obsoletos": "obsoleto",
    "obsta": "obstar",
    "obstaculiza": "obstaculizar",
    "obstaculizada": "obstaculizar",
    "obstaculizadas": "obstaculizar",
    "obstaculizado": "obstaculizar",
    "obstaculizados": "obstaculizar",
    "obstaculizai": "obstaculizar",
    "obstaculizais": "obstaculizar",
    "obstaculizam": "obstaculizar",
    "obstaculizamo": "obstaculizar",
    "obstaculizamos": "obstaculizar",
    "obstaculizando": "obstaculizar",
    "obstaculizara": "obstaculizar",
    "obstaculizaram": "obstaculizar",
    "obstaculizaras": "obstaculizar",
    "obstaculizarde": "obstaculizar",
    "obstaculizardes": "obstaculizar",
    "obstaculizare": "obstaculizar",
    "obstaculizarei": "obstaculizar",
    "obstaculizareis": "obstaculizar",
    "obstaculizarem": "obstaculizar",
    "obstaculizaremos": "obstaculizar",
    "obstaculizares": "obstaculizar",
    "obstaculizaria": "obstaculizar",
    "obstaculizariam": "obstaculizar",
    "obstaculizarias": "obstaculizar",
    "obstaculizarmo": "obstaculizar",
    "obstaculizarmos": "obstaculizar",
    "obstaculizará": "obstaculizar",
    "obstaculizarás": "obstaculizar",
    "obstaculizarão": "obstaculizar",
    "obstaculizaríamos": "obstaculizar",
    "obstaculizaríeis": "obstaculizar",
    "obstaculizas": "obstaculizar",
    "obstaculizasse": "obstaculizar",
    "obstaculizassem": "obstaculizar",
    "obstaculizasses": "obstaculizar",
    "obstaculizaste": "obstaculizar",
    "obstaculizastes": "obstaculizar",
    "obstaculizava": "obstaculizar",
    "obstaculizavam": "obstaculizar",
    "obstaculizavas": "obstaculizar",
    "obstaculize": "obstaculizar",
    "obstaculizei": "obstaculizar",
    "obstaculizeis": "obstaculizar",
    "obstaculizem": "obstaculizar",
    "obstaculizemo": "obstaculizar",
    "obstaculizemos": "obstaculizar",
    "obstaculizes": "obstaculizar",
    "obstaculizo": "obstaculizar",
    "obstaculizou": "obstaculizar",
    "obstaculizá": "obstaculizar",
    "obstaculizámo": "obstaculizar",
    "obstaculizámos": "obstaculizar",
    "obstaculizáramo": "obstaculizar",
    "obstaculizáramos": "obstaculizar",
    "obstaculizárei": "obstaculizar",
    "obstaculizáreis": "obstaculizar",
    "obstaculizásseis": "obstaculizar",
    "obstaculizássemos": "obstaculizar",
    "obstaculizávamo": "obstaculizar",
    "obstaculizávamos": "obstaculizar",
    "obstaculizávei": "obstaculizar",
    "obstaculizáveis": "obstaculizar",
    "obstada": "obstar",
    "obstadas": "obstar",
    "obstado": "obstar",
    "obstados": "obstar",
    "obstai": "obstar",
    "obstais": "obstar",
    "obstam": "obstar",
    "obstamo": "obstar",
    "obstamos": "obstar",
    "obstando": "obstar",
    "obstantes": "obstante",
    "obstara": "obstar",
    "obstaram": "obstar",
    "obstaras": "obstar",
    "obstarde": "obstar",
    "obstardes": "obstar",
    "obstare": "obstar",
    "obstarei": "obstar",
    "obstareis": "obstar",
    "obstarem": "obstar",
    "obstaremos": "obstar",
    "obstares": "obstar",
    "obstaria": "obstar",
    "obstariam": "obstar",
    "obstarias": "obstar",
    "obstarmo": "obstar",
    "obstarmos": "obstar",
    "obstará": "obstar",
    "obstarás": "obstar",
    "obstarão": "obstar",
    "obstaríamos": "obstar",
    "obstaríeis": "obstar",
    "obstas": "obstar",
    "obstasse": "obstar",
    "obstassem": "obstar",
    "obstasses": "obstar",
    "obstaste": "obstar",
    "obstastes": "obstar",
    "obstativa": "obstativo",
    "obstativas": "obstativo",
    "obstativos": "obstativo",
    "obstava": "obstar",
    "obstavam": "obstar",
    "obstavas": "obstar",
    "obste": "obstar",
    "obstei": "obstar",
    "obsteis": "obstar",
    "obstem": "obstar",
    "obstemo": "obstar",
    "obstemos": "obstar",
    "obstes": "obstar",
    "obstetras": "obstetra",
    "obstetricais": "obstetrical",
    "obstetrícia": "obstetrício",
    "obstetrícias": "obstetrício",
    "obstetrícios": "obstetrício",
    "obsticidades": "obsticidade",
    "obstina": "obstinar",
    "obstinada": "obstinar",
    "obstinadas": "obstinar",
    "obstinado": "obstinar",
    "obstinados": "obstinar",
    "obstinadíssima": "obstinado",
    "obstinadíssimas": "obstinado",
    "obstinadíssimo": "obstinado",
    "obstinadíssimos": "obstinado",
    "obstinai": "obstinar",
    "obstinais": "obstinar",
    "obstinam": "obstinar",
    "obstinamo": "obstinar",
    "obstinamos": "obstinar",
    "obstinando": "obstinar",
    "obstinara": "obstinar",
    "obstinaram": "obstinar",
    "obstinaras": "obstinar",
    "obstinarde": "obstinar",
    "obstinardes": "obstinar",
    "obstinare": "obstinar",
    "obstinarei": "obstinar",
    "obstinareis": "obstinar",
    "obstinarem": "obstinar",
    "obstinaremos": "obstinar",
    "obstinares": "obstinar",
    "obstinaria": "obstinar",
    "obstinariam": "obstinar",
    "obstinarias": "obstinar",
    "obstinarmo": "obstinar",
    "obstinarmos": "obstinar",
    "obstinará": "obstinar",
    "obstinarás": "obstinar",
    "obstinarão": "obstinar",
    "obstinaríamos": "obstinar",
    "obstinaríeis": "obstinar",
    "obstinas": "obstinar",
    "obstinasse": "obstinar",
    "obstinassem": "obstinar",
    "obstinasses": "obstinar",
    "obstinaste": "obstinar",
    "obstinastes": "obstinar",
    "obstinava": "obstinar",
    "obstinavam": "obstinar",
    "obstinavas": "obstinar",
    "obstinações": "obstinação",
    "obstine": "obstinar",
    "obstinei": "obstinar",
    "obstineis": "obstinar",
    "obstinem": "obstinar",
    "obstinemo": "obstinar",
    "obstinemos": "obstinar",
    "obstines": "obstinar",
    "obstino": "obstinar",
    "obstinou": "obstinar",
    "obstiná": "obstinar",
    "obstinámo": "obstinar",
    "obstinámos": "obstinar",
    "obstináramo": "obstinar",
    "obstináramos": "obstinar",
    "obstinárei": "obstinar",
    "obstináreis": "obstinar",
    "obstinásseis": "obstinar",
    "obstinássemos": "obstinar",
    "obstinávamo": "obstinar",
    "obstinávamos": "obstinar",
    "obstinávei": "obstinar",
    "obstináveis": "obstinar",
    "obstipa": "obstipar",
    "obstipada": "obstipar",
    "obstipadas": "obstipar",
    "obstipado": "obstipar",
    "obstipados": "obstipar",
    "obstipai": "obstipar",
    "obstipais": "obstipar",
    "obstipam": "obstipar",
    "obstipamo": "obstipar",
    "obstipamos": "obstipar",
    "obstipando": "obstipar",
    "obstipantes": "obstipante",
    "obstipara": "obstipar",
    "obstiparam": "obstipar",
    "obstiparas": "obstipar",
    "obstiparde": "obstipar",
    "obstipardes": "obstipar",
    "obstipare": "obstipar",
    "obstiparei": "obstipar",
    "obstipareis": "obstipar",
    "obstiparem": "obstipar",
    "obstiparemos": "obstipar",
    "obstipares": "obstipar",
    "obstiparia": "obstipar",
    "obstipariam": "obstipar",
    "obstiparias": "obstipar",
    "obstiparmo": "obstipar",
    "obstiparmos": "obstipar",
    "obstipará": "obstipar",
    "obstiparás": "obstipar",
    "obstiparão": "obstipar",
    "obstiparíamos": "obstipar",
    "obstiparíeis": "obstipar",
    "obstipas": "obstipar",
    "obstipasse": "obstipar",
    "obstipassem": "obstipar",
    "obstipasses": "obstipar",
    "obstipaste": "obstipar",
    "obstipastes": "obstipar",
    "obstipava": "obstipar",
    "obstipavam": "obstipar",
    "obstipavas": "obstipar",
    "obstipações": "obstipação",
    "obstipe": "obstipar",
    "obstipei": "obstipar",
    "obstipeis": "obstipar",
    "obstipem": "obstipar",
    "obstipemo": "obstipar",
    "obstipemos": "obstipar",
    "obstipes": "obstipar",
    "obstipo": "obstipar",
    "obstipou": "obstipar",
    "obstipá": "obstipar",
    "obstipámo": "obstipar",
    "obstipámos": "obstipar",
    "obstipáramo": "obstipar",
    "obstipáramos": "obstipar",
    "obstipárei": "obstipar",
    "obstipáreis": "obstipar",
    "obstipásseis": "obstipar",
    "obstipássemos": "obstipar",
    "obstipávamo": "obstipar",
    "obstipávamos": "obstipar",
    "obstipávei": "obstipar",
    "obstipáveis": "obstipar",
    "obsto": "obstar",
    "obstou": "obstar",
    "obstri": "obstruir",
    "obstringe": "obstringir",
    "obstringem": "obstringir",
    "obstringes": "obstringir",
    "obstringi": "obstringir",
    "obstringia": "obstringir",
    "obstringiam": "obstringir",
    "obstringias": "obstringir",
    "obstringida": "obstringir",
    "obstringidas": "obstringir",
    "obstringido": "obstringir",
    "obstringidos": "obstringir",
    "obstringimo": "obstringir",
    "obstringimos": "obstringir",
    "obstringindo": "obstringir",
    "obstringira": "obstringir",
    "obstringiram": "obstringir",
    "obstringiras": "obstringir",
    "obstringirde": "obstringir",
    "obstringirdes": "obstringir",
    "obstringire": "obstringir",
    "obstringirei": "obstringir",
    "obstringireis": "obstringir",
    "obstringirem": "obstringir",
    "obstringiremos": "obstringir",
    "obstringires": "obstringir",
    "obstringiria": "obstringir",
    "obstringiriam": "obstringir",
    "obstringirias": "obstringir",
    "obstringirmo": "obstringir",
    "obstringirmos": "obstringir",
    "obstringirá": "obstringir",
    "obstringirás": "obstringir",
    "obstringirão": "obstringir",
    "obstringiríamos": "obstringir",
    "obstringiríeis": "obstringir",
    "obstringis": "obstringir",
    "obstringisse": "obstringir",
    "obstringissem": "obstringir",
    "obstringisses": "obstringir",
    "obstringiste": "obstringir",
    "obstringistes": "obstringir",
    "obstringiu": "obstringir",
    "obstringíamo": "obstringir",
    "obstringíamos": "obstringir",
    "obstringíei": "obstringir",
    "obstringíeis": "obstringir",
    "obstringíramo": "obstringir",
    "obstringíramos": "obstringir",
    "obstringírei": "obstringir",
    "obstringíreis": "obstringir",
    "obstringísseis": "obstringir",
    "obstringíssemos": "obstringir",
    "obstrinja": "obstringir",
    "obstrinjais": "obstringir",
    "obstrinjam": "obstringir",
    "obstrinjamo": "obstringir",
    "obstrinjamos": "obstringir",
    "obstrinjas": "obstringir",
    "obstrinjo": "obstringir",
    "obstrita": "obstrito",
    "obstritas": "obstrito",
    "obstritos": "obstrito",
    "obstroem": "obstruir",
    "obstrua": "obstruir",
    "obstruais": "obstruir",
    "obstruam": "obstruir",
    "obstruamo": "obstruir",
    "obstruamos": "obstruir",
    "obstruas": "obstruir",
    "obstrucionismos": "obstrucionismo",
    "obstrucionistas": "obstrucionista",
    "obstruem": "obstruir",
    "obstruentes": "obstruente",
    "obstrui": "obstruir",
    "obstruida": "obstruido",
    "obstruidas": "obstruido",
    "obstruidos": "obstruido",
    "obstruindo": "obstruir",
    "obstruirde": "obstruir",
    "obstruirdes": "obstruir",
    "obstruirei": "obstruir",
    "obstruireis": "obstruir",
    "obstruiremos": "obstruir",
    "obstruiria": "obstruir",
    "obstruiriam": "obstruir",
    "obstruirias": "obstruir",
    "obstruirmo": "obstruir",
    "obstruirmos": "obstruir",
    "obstruirá": "obstruir",
    "obstruirás": "obstruir",
    "obstruirão": "obstruir",
    "obstruiríamos": "obstruir",
    "obstruiríeis": "obstruir",
    "obstruis": "obstruir",
    "obstruiu": "obstruir",
    "obstruo": "obstruir",
    "obstrutiva": "obstrutivo",
    "obstrutivas": "obstrutivo",
    "obstrutivos": "obstrutivo",
    "obstrutora": "obstrutor",
    "obstrutoras": "obstrutor",
    "obstrutores": "obstrutor",
    "obstruções": "obstrução",
    "obstruí": "obstruir",
    "obstruía": "obstruir",
    "obstruíam": "obstruir",
    "obstruíamo": "obstruir",
    "obstruíamos": "obstruir",
    "obstruías": "obstruir",
    "obstruída": "obstruir",
    "obstruídas": "obstruir",
    "obstruído": "obstruir",
    "obstruídos": "obstruir",
    "obstruíei": "obstruir",
    "obstruíeis": "obstruir",
    "obstruímo": "obstruir",
    "obstruímos": "obstruir",
    "obstruíra": "obstruir",
    "obstruíram": "obstruir",
    "obstruíramo": "obstruir",
    "obstruíramos": "obstruir",
    "obstruíras": "obstruir",
    "obstruíre": "obstruir",
    "obstruírei": "obstruir",
    "obstruíreis": "obstruir",
    "obstruírem": "obstruir",
    "obstruíres": "obstruir",
    "obstruís": "obstruir",
    "obstruísse": "obstruir",
    "obstruísseis": "obstruir",
    "obstruíssem": "obstruir",
    "obstruíssemos": "obstruir",
    "obstruísses": "obstruir",
    "obstruíste": "obstruir",
    "obstruístes": "obstruir",
    "obstruíveis": "obstruível",
    "obstrói": "obstruir",
    "obstróis": "obstruir",
    "obstupefacta": "obstupefacto",
    "obstupefactas": "obstupefacto",
    "obstupefactos": "obstupefacto",
    "obstupefacções": "obstupefacção",
    "obstá": "obstar",
    "obstáculos": "obstáculo",
    "obstámo": "obstar",
    "obstámos": "obstar",
    "obstáramo": "obstar",
    "obstáramos": "obstar",
    "obstárei": "obstar",
    "obstáreis": "obstar",
    "obstásseis": "obstar",
    "obstássemos": "obstar",
    "obstávamo": "obstar",
    "obstávamos": "obstar",
    "obstávei": "obstar",
    "obstáveis": "obstar",
    "obstétrica": "obstétrico",
    "obstétricas": "obstétrico",
    "obstétricos": "obstétrico",
    "obstúpida": "obstúpido",
    "obstúpidas": "obstúpido",
    "obstúpidos": "obstúpido",
    "obséquios": "obséquio",
    "obsídias": "obsídia",
    "obtemo": "obter",
    "obtemos": "obter",
    "obtempera": "obtemperar",
    "obtemperada": "obtemperar",
    "obtemperadas": "obtemperar",
    "obtemperado": "obtemperar",
    "obtemperados": "obtemperar",
    "obtemperai": "obtemperar",
    "obtemperais": "obtemperar",
    "obtemperam": "obtemperar",
    "obtemperamo": "obtemperar",
    "obtemperamos": "obtemperar",
    "obtemperando": "obtemperar",
    "obtemperara": "obtemperar",
    "obtemperaram": "obtemperar",
    "obtemperaras": "obtemperar",
    "obtemperarde": "obtemperar",
    "obtemperardes": "obtemperar",
    "obtemperare": "obtemperar",
    "obtemperarei": "obtemperar",
    "obtemperareis": "obtemperar",
    "obtemperarem": "obtemperar",
    "obtemperaremos": "obtemperar",
    "obtemperares": "obtemperar",
    "obtemperaria": "obtemperar",
    "obtemperariam": "obtemperar",
    "obtemperarias": "obtemperar",
    "obtemperarmo": "obtemperar",
    "obtemperarmos": "obtemperar",
    "obtemperará": "obtemperar",
    "obtemperarás": "obtemperar",
    "obtemperarão": "obtemperar",
    "obtemperaríamos": "obtemperar",
    "obtemperaríeis": "obtemperar",
    "obtemperas": "obtemperar",
    "obtemperasse": "obtemperar",
    "obtemperassem": "obtemperar",
    "obtemperasses": "obtemperar",
    "obtemperaste": "obtemperar",
    "obtemperastes": "obtemperar",
    "obtemperava": "obtemperar",
    "obtemperavam": "obtemperar",
    "obtemperavas": "obtemperar",
    "obtemperações": "obtemperação",
    "obtempere": "obtemperar",
    "obtemperei": "obtemperar",
    "obtempereis": "obtemperar",
    "obtemperem": "obtemperar",
    "obtemperemo": "obtemperar",
    "obtemperemos": "obtemperar",
    "obtemperes": "obtemperar",
    "obtempero": "obtemperar",
    "obtemperou": "obtemperar",
    "obtemperá": "obtemperar",
    "obtemperámo": "obtemperar",
    "obtemperámos": "obtemperar",
    "obtemperáramo": "obtemperar",
    "obtemperáramos": "obtemperar",
    "obtemperárei": "obtemperar",
    "obtemperáreis": "obtemperar",
    "obtemperásseis": "obtemperar",
    "obtemperássemos": "obtemperar",
    "obtemperávamo": "obtemperar",
    "obtemperávamos": "obtemperar",
    "obtemperávei": "obtemperar",
    "obtemperáveis": "obtemperar",
    "obtende": "obter",
    "obtendes": "obter",
    "obtendo": "obter",
    "obtenha": "obter",
    "obtenhais": "obter",
    "obtenham": "obter",
    "obtenhamo": "obter",
    "obtenhamos": "obter",
    "obtenhas": "obter",
    "obtenho": "obter",
    "obtentora": "obtentor",
    "obtentoras": "obtentor",
    "obtentores": "obtentor",
    "obtenções": "obtenção",
    "obteníveis": "obtenível",
    "obterde": "obter",
    "obterdes": "obter",
    "obtere": "obter",
    "obterei": "obter",
    "obtereis": "obter",
    "obterem": "obter",
    "obteremos": "obter",
    "obteres": "obter",
    "obteria": "obter",
    "obteriam": "obter",
    "obterias": "obter",
    "obtermo": "obter",
    "obtermos": "obter",
    "obterá": "obter",
    "obterás": "obter",
    "obterão": "obter",
    "obteríamos": "obter",
    "obteríeis": "obter",
    "obtesta": "obtestar",
    "obtestada": "obtestar",
    "obtestadas": "obtestar",
    "obtestado": "obtestar",
    "obtestados": "obtestar",
    "obtestai": "obtestar",
    "obtestais": "obtestar",
    "obtestam": "obtestar",
    "obtestamo": "obtestar",
    "obtestamos": "obtestar",
    "obtestando": "obtestar",
    "obtestara": "obtestar",
    "obtestaram": "obtestar",
    "obtestaras": "obtestar",
    "obtestarde": "obtestar",
    "obtestardes": "obtestar",
    "obtestare": "obtestar",
    "obtestarei": "obtestar",
    "obtestareis": "obtestar",
    "obtestarem": "obtestar",
    "obtestaremos": "obtestar",
    "obtestares": "obtestar",
    "obtestaria": "obtestar",
    "obtestariam": "obtestar",
    "obtestarias": "obtestar",
    "obtestarmo": "obtestar",
    "obtestarmos": "obtestar",
    "obtestará": "obtestar",
    "obtestarás": "obtestar",
    "obtestarão": "obtestar",
    "obtestaríamos": "obtestar",
    "obtestaríeis": "obtestar",
    "obtestas": "obtestar",
    "obtestasse": "obtestar",
    "obtestassem": "obtestar",
    "obtestasses": "obtestar",
    "obtestaste": "obtestar",
    "obtestastes": "obtestar",
    "obtestava": "obtestar",
    "obtestavam": "obtestar",
    "obtestavas": "obtestar",
    "obtestações": "obtestação",
    "obteste": "obtestar",
    "obtestei": "obtestar",
    "obtesteis": "obtestar",
    "obtestem": "obtestar",
    "obtestemo": "obtestar",
    "obtestemos": "obtestar",
    "obtestes": "obtestar",
    "obtesto": "obtestar",
    "obtestou": "obtestar",
    "obtestá": "obtestar",
    "obtestámo": "obtestar",
    "obtestámos": "obtestar",
    "obtestáramo": "obtestar",
    "obtestáramos": "obtestar",
    "obtestárei": "obtestar",
    "obtestáreis": "obtestar",
    "obtestásseis": "obtestar",
    "obtestássemos": "obtestar",
    "obtestávamo": "obtestar",
    "obtestávamos": "obtestar",
    "obtestávei": "obtestar",
    "obtestáveis": "obtestar",
    "obteve": "obter",
    "obtida": "obtido",
    "obtidas": "obtido",
    "obtido": "obter",
    "obtidos": "obtido",
    "obtinha": "obter",
    "obtinham": "obter",
    "obtinhas": "obter",
    "obtive": "obter",
    "obtivemo": "obter",
    "obtivemos": "obter",
    "obtiver": "obter",
    "obtivera": "obter",
    "obtiveram": "obter",
    "obtiveras": "obter",
    "obtiverdes": "obter",
    "obtiverem": "obter",
    "obtiveres": "obter",
    "obtivermos": "obter",
    "obtivesse": "obter",
    "obtivessem": "obter",
    "obtivesses": "obter",
    "obtiveste": "obter",
    "obtivestes": "obter",
    "obtivéramo": "obter",
    "obtivéramos": "obter",
    "obtivérei": "obter",
    "obtivéreis": "obter",
    "obtivésseis": "obter",
    "obtivéssemos": "obter",
    "obtunda": "obtundir",
    "obtundais": "obtundir",
    "obtundam": "obtundir",
    "obtundamo": "obtundir",
    "obtundamos": "obtundir",
    "obtundas": "obtundir",
    "obtunde": "obtundir",
    "obtundem": "obtundir",
    "obtundentes": "obtundente",
    "obtundes": "obtundir",
    "obtundi": "obtundir",
    "obtundia": "obtundir",
    "obtundiam": "obtundir",
    "obtundias": "obtundir",
    "obtundida": "obtundir",
    "obtundidas": "obtundir",
    "obtundido": "obtundir",
    "obtundidos": "obtundir",
    "obtundimo": "obtundir",
    "obtundimos": "obtundir",
    "obtundindo": "obtundir",
    "obtundira": "obtundir",
    "obtundiram": "obtundir",
    "obtundiras": "obtundir",
    "obtundirde": "obtundir",
    "obtundirdes": "obtundir",
    "obtundire": "obtundir",
    "obtundirei": "obtundir",
    "obtundireis": "obtundir",
    "obtundirem": "obtundir",
    "obtundiremos": "obtundir",
    "obtundires": "obtundir",
    "obtundiria": "obtundir",
    "obtundiriam": "obtundir",
    "obtundirias": "obtundir",
    "obtundirmo": "obtundir",
    "obtundirmos": "obtundir",
    "obtundirá": "obtundir",
    "obtundirás": "obtundir",
    "obtundirão": "obtundir",
    "obtundiríamos": "obtundir",
    "obtundiríeis": "obtundir",
    "obtundis": "obtundir",
    "obtundisse": "obtundir",
    "obtundissem": "obtundir",
    "obtundisses": "obtundir",
    "obtundiste": "obtundir",
    "obtundistes": "obtundir",
    "obtundiu": "obtundir",
    "obtundo": "obtundir",
    "obtundíamo": "obtundir",
    "obtundíamos": "obtundir",
    "obtundíei": "obtundir",
    "obtundíeis": "obtundir",
    "obtundíramo": "obtundir",
    "obtundíramos": "obtundir",
    "obtundírei": "obtundir",
    "obtundíreis": "obtundir",
    "obtundísseis": "obtundir",
    "obtundíssemos": "obtundir",
    "obtura": "obturar",
    "obturada": "obturar",
    "obturadas": "obturar",
    "obturado": "obturar",
    "obturadora": "obturador",
    "obturadoras": "obturador",
    "obturadores": "obturador",
    "obturados": "obturar",
    "obturai": "obturar",
    "obturais": "obturar",
    "obturam": "obturar",
    "obturamo": "obturar",
    "obturamos": "obturar",
    "obturando": "obturar",
    "obturantes": "obturante",
    "obturara": "obturar",
    "obturaram": "obturar",
    "obturaras": "obturar",
    "obturarde": "obturar",
    "obturardes": "obturar",
    "obturare": "obturar",
    "obturarei": "obturar",
    "obturareis": "obturar",
    "obturarem": "obturar",
    "obturaremos": "obturar",
    "obturares": "obturar",
    "obturaria": "obturar",
    "obturariam": "obturar",
    "obturarias": "obturar",
    "obturarmo": "obturar",
    "obturarmos": "obturar",
    "obturará": "obturar",
    "obturarás": "obturar",
    "obturarão": "obturar",
    "obturaríamos": "obturar",
    "obturaríeis": "obturar",
    "obturas": "obturar",
    "obturasse": "obturar",
    "obturassem": "obturar",
    "obturasses": "obturar",
    "obturaste": "obturar",
    "obturastes": "obturar",
    "obturava": "obturar",
    "obturavam": "obturar",
    "obturavas": "obturar",
    "obturações": "obturação",
    "obturbinada": "obturbinado",
    "obturbinadas": "obturbinado",
    "obturbinados": "obturbinado",
    "obture": "obturar",
    "obturei": "obturar",
    "obtureis": "obturar",
    "obturem": "obturar",
    "obturemo": "obturar",
    "obturemos": "obturar",
    "obtures": "obturar",
    "obturo": "obturar",
    "obturou": "obturar",
    "obturá": "obturar",
    "obturámo": "obturar",
    "obturámos": "obturar",
    "obturáramo": "obturar",
    "obturáramos": "obturar",
    "obturárei": "obturar",
    "obturáreis": "obturar",
    "obturásseis": "obturar",
    "obturássemos": "obturar",
    "obturávamo": "obturar",
    "obturávamos": "obturar",
    "obturávei": "obturar",
    "obturáveis": "obturável",
    "obtusa": "obtuso",
    "obtusada": "obtusado",
    "obtusadas": "obtusado",
    "obtusados": "obtusado",
    "obtusangulada": "obtusangulado",
    "obtusanguladas": "obtusangulado",
    "obtusangulados": "obtusangulado",
    "obtusas": "obtuso",
    "obtusidades": "obtusidade",
    "obtusos": "obtuso",
    "obtusângula": "obtusângulo",
    "obtusângulas": "obtusângulo",
    "obtusângulos": "obtusângulo",
    "obtusões": "obtusão",
    "obtém": "obter",
    "obténs": "obter",
    "obtê": "obter",
    "obtêm": "obter",
    "obtínhamo": "obter",
    "obtínhamos": "obter",
    "obtínhei": "obter",
    "obtínheis": "obter",
    "obtíveis": "obtível",
    "obumbra": "obumbrar",
    "obumbrada": "obumbrar",
    "obumbradas": "obumbrar",
    "obumbrado": "obumbrar",
    "obumbrados": "obumbrar",
    "obumbrai": "obumbrar",
    "obumbrais": "obumbrar",
    "obumbram": "obumbrar",
    "obumbramo": "obumbrar",
    "obumbramos": "obumbrar",
    "obumbrando": "obumbrar",
    "obumbrara": "obumbrar",
    "obumbraram": "obumbrar",
    "obumbraras": "obumbrar",
    "obumbrarde": "obumbrar",
    "obumbrardes": "obumbrar",
    "obumbrare": "obumbrar",
    "obumbrarei": "obumbrar",
    "obumbrareis": "obumbrar",
    "obumbrarem": "obumbrar",
    "obumbraremos": "obumbrar",
    "obumbrares": "obumbrar",
    "obumbraria": "obumbrar",
    "obumbrariam": "obumbrar",
    "obumbrarias": "obumbrar",
    "obumbrarmo": "obumbrar",
    "obumbrarmos": "obumbrar",
    "obumbrará": "obumbrar",
    "obumbrarás": "obumbrar",
    "obumbrarão": "obumbrar",
    "obumbraríamos": "obumbrar",
    "obumbraríeis": "obumbrar",
    "obumbras": "obumbrar",
    "obumbrasse": "obumbrar",
    "obumbrassem": "obumbrar",
    "obumbrasses": "obumbrar",
    "obumbraste": "obumbrar",
    "obumbrastes": "obumbrar",
    "obumbrava": "obumbrar",
    "obumbravam": "obumbrar",
    "obumbravas": "obumbrar",
    "obumbrações": "obumbração",
    "obumbre": "obumbrar",
    "obumbrei": "obumbrar",
    "obumbreis": "obumbrar",
    "obumbrem": "obumbrar",
    "obumbremo": "obumbrar",
    "obumbremos": "obumbrar",
    "obumbres": "obumbrar",
    "obumbro": "obumbrar",
    "obumbrou": "obumbrar",
    "obumbrá": "obumbrar",
    "obumbrámo": "obumbrar",
    "obumbrámos": "obumbrar",
    "obumbráramo": "obumbrar",
    "obumbráramos": "obumbrar",
    "obumbrárei": "obumbrar",
    "obumbráreis": "obumbrar",
    "obumbrásseis": "obumbrar",
    "obumbrássemos": "obumbrar",
    "obumbrávamo": "obumbrar",
    "obumbrávamos": "obumbrar",
    "obumbrávei": "obumbrar",
    "obumbráveis": "obumbrar",
    "obuses": "obus",
    "obveio": "obvir",
    "obvem": "obvir",
    "obvenha": "obvir",
    "obvenhais": "obvir",
    "obvenham": "obvir",
    "obvenhamo": "obvir",
    "obvenhamos": "obvir",
    "obvenhas": "obvir",
    "obvenho": "obvir",
    "obvenções": "obvenção",
    "obversos": "obverso",
    "obvia": "obviar",
    "obviada": "obviar",
    "obviadas": "obviar",
    "obviado": "obviar",
    "obviados": "obviar",
    "obviai": "obviar",
    "obviais": "obviar",
    "obviam": "obviar",
    "obviamo": "obviar",
    "obviamos": "obviar",
    "obviando": "obviar",
    "obviara": "obviar",
    "obviaram": "obviar",
    "obviaras": "obviar",
    "obviardes": "obviar",
    "obviarei": "obviar",
    "obviareis": "obviar",
    "obviarem": "obviar",
    "obviaremos": "obviar",
    "obviares": "obviar",
    "obviaria": "obviar",
    "obviariam": "obviar",
    "obviarias": "obviar",
    "obviarmo": "obviar",
    "obviarmos": "obviar",
    "obviará": "obviar",
    "obviarás": "obviar",
    "obviarão": "obviar",
    "obviaríamos": "obviar",
    "obviaríeis": "obviar",
    "obvias": "obviar",
    "obviasse": "obviar",
    "obviassem": "obviar",
    "obviasses": "obviar",
    "obviaste": "obviar",
    "obviastes": "obviar",
    "obviava": "obviar",
    "obviavam": "obviar",
    "obviavas": "obviar",
    "obvie": "obviar",
    "obviei": "obviar",
    "obvieis": "obviar",
    "obviem": "obviar",
    "obviemo": "obvir",
    "obviemos": "obvir",
    "obvier": "obvir",
    "obviera": "obvir",
    "obvieram": "obvir",
    "obvieras": "obvir",
    "obvierdes": "obvir",
    "obvierem": "obvir",
    "obvieres": "obvir",
    "obviermos": "obvir",
    "obvies": "obviar",
    "obviesse": "obvir",
    "obviessem": "obvir",
    "obviesses": "obvir",
    "obvieste": "obvir",
    "obviestes": "obvir",
    "obvim": "obvir",
    "obvimo": "obvir",
    "obvimos": "obvir",
    "obvinda": "obvir",
    "obvindas": "obvir",
    "obvinde": "obvir",
    "obvindes": "obvir",
    "obvindo": "obvir",
    "obvindos": "obvir",
    "obvinha": "obvir",
    "obvinham": "obvir",
    "obvinhas": "obvir",
    "obvio": "obviar",
    "obviou": "obviar",
    "obvirdes": "obvir",
    "obvirei": "obvir",
    "obvireis": "obvir",
    "obvirem": "obvir",
    "obviremos": "obvir",
    "obvires": "obvir",
    "obviria": "obvir",
    "obviriam": "obvir",
    "obvirias": "obvir",
    "obvirmo": "obvir",
    "obvirmos": "obvir",
    "obvirá": "obvir",
    "obvirás": "obvir",
    "obvirão": "obvir",
    "obviríamos": "obvir",
    "obviríeis": "obvir",
    "obviámo": "obviar",
    "obviámos": "obviar",
    "obviáramo": "obviar",
    "obviáramos": "obviar",
    "obviáreis": "obviar",
    "obviásseis": "obviar",
    "obviássemos": "obviar",
    "obviávamo": "obviar",
    "obviávamos": "obviar",
    "obviáveis": "obviável",
    "obviéramo": "obvir",
    "obviéramos": "obvir",
    "obviéreis": "obvir",
    "obviésseis": "obvir",
    "obviéssemos": "obvir",
    "obvém": "obvir",
    "obvéns": "obvir",
    "obvêm": "obvir",
    "obvínhamo": "obvir",
    "obvínhamos": "obvir",
    "obvínheis": "obvir",
    "obélions": "obélion",
    "obélios": "obélio",
    "obóvea": "obóveo",
    "obóveas": "obóveo",
    "obóveos": "obóveo",
    "oca": "oco",
    "ocada": "ocar",
    "ocadas": "ocar",
    "ocado": "ocar",
    "ocados": "ocar",
    "ocai": "ocar",
    "ocais": "ocar",
    "ocam": "ocar",
    "ocamo": "ocar",
    "ocamos": "ocar",
    "ocando": "ocar",
    "ocanhos": "ocanho",
    "ocara": "ocar",
    "ocaram": "ocar",
    "ocaras": "ocar",
    "ocarde": "ocar",
    "ocardes": "ocar",
    "ocare": "ocar",
    "ocarei": "ocar",
    "ocareis": "ocar",
    "ocarem": "ocar",
    "ocaremos": "ocar",
    "ocares": "ocar",
    "ocaria": "ocar",
    "ocariam": "ocar",
    "ocarias": "ocar",
    "ocarinas": "ocarina",
    "ocarinistas": "ocarinista",
    "ocarmo": "ocar",
    "ocarmos": "ocar",
    "ocará": "ocar",
    "ocarás": "ocar",
    "ocarão": "ocar",
    "ocaríamos": "ocar",
    "ocaríeis": "ocar",
    "ocas": "oco",
    "ocasiona": "ocasionar",
    "ocasionada": "ocasionar",
    "ocasionadas": "ocasionar",
    "ocasionado": "ocasionar",
    "ocasionadora": "ocasionador",
    "ocasionadoras": "ocasionador",
    "ocasionadores": "ocasionador",
    "ocasionados": "ocasionar",
    "ocasionai": "ocasionar",
    "ocasionais": "ocasionar",
    "ocasionalidades": "ocasionalidade",
    "ocasionalismos": "ocasionalismo",
    "ocasionalistas": "ocasionalista",
    "ocasionam": "ocasionar",
    "ocasionamo": "ocasionar",
    "ocasionamos": "ocasionar",
    "ocasionando": "ocasionar",
    "ocasionara": "ocasionar",
    "ocasionaram": "ocasionar",
    "ocasionaras": "ocasionar",
    "ocasionarde": "ocasionar",
    "ocasionardes": "ocasionar",
    "ocasionare": "ocasionar",
    "ocasionarei": "ocasionar",
    "ocasionareis": "ocasionar",
    "ocasionarem": "ocasionar",
    "ocasionaremos": "ocasionar",
    "ocasionares": "ocasionar",
    "ocasionaria": "ocasionar",
    "ocasionariam": "ocasionar",
    "ocasionarias": "ocasionar",
    "ocasionarmo": "ocasionar",
    "ocasionarmos": "ocasionar",
    "ocasionará": "ocasionar",
    "ocasionarás": "ocasionar",
    "ocasionarão": "ocasionar",
    "ocasionaríamos": "ocasionar",
    "ocasionaríeis": "ocasionar",
    "ocasionas": "ocasionar",
    "ocasionasse": "ocasionar",
    "ocasionassem": "ocasionar",
    "ocasionasses": "ocasionar",
    "ocasionaste": "ocasionar",
    "ocasionastes": "ocasionar",
    "ocasionava": "ocasionar",
    "ocasionavam": "ocasionar",
    "ocasionavas": "ocasionar",
    "ocasione": "ocasionar",
    "ocasionei": "ocasionar",
    "ocasioneis": "ocasionar",
    "ocasionem": "ocasionar",
    "ocasionemo": "ocasionar",
    "ocasionemos": "ocasionar",
    "ocasiones": "ocasionar",
    "ocasiono": "ocasionar",
    "ocasionou": "ocasionar",
    "ocasioná": "ocasionar",
    "ocasionámo": "ocasionar",
    "ocasionámos": "ocasionar",
    "ocasionáramo": "ocasionar",
    "ocasionáramos": "ocasionar",
    "ocasionárei": "ocasionar",
    "ocasionáreis": "ocasionar",
    "ocasionásseis": "ocasionar",
    "ocasionássemos": "ocasionar",
    "ocasionávamo": "ocasionar",
    "ocasionávamos": "ocasionar",
    "ocasionávei": "ocasionar",
    "ocasionáveis": "ocasionar",
    "ocasiões": "ocasião",
    "ocasos": "ocaso",
    "ocasse": "ocar",
    "ocassem": "ocar",
    "ocasses": "ocar",
    "ocaste": "ocar",
    "ocastes": "ocar",
    "ocava": "ocar",
    "ocavam": "ocar",
    "ocavas": "ocar",
    "occamismos": "occamismo",
    "occipiciais": "occipicial",
    "occipitais": "occipital",
    "occipícios": "occipício",
    "occipúcios": "occipúcio",
    "occisiva": "occisivo",
    "occisivas": "occisivo",
    "occisivos": "occisivo",
    "occisões": "occisão",
    "occídua": "occíduo",
    "occíduas": "occíduo",
    "occíduos": "occíduo",
    "oceanidades": "oceanidade",
    "oceanites": "oceanite",
    "oceanografias": "oceanografia",
    "oceanográfica": "oceanográfico",
    "oceanográficas": "oceanográfico",
    "oceanográficos": "oceanográfico",
    "oceanos": "oceano",
    "oceanários": "oceanário",
    "oceanógrafa": "oceanógrafo",
    "oceanógrafas": "oceanógrafo",
    "oceanógrafos": "oceanógrafo",
    "oceanóloga": "oceanólogo",
    "oceanólogas": "oceanólogo",
    "oceanólogos": "oceanólogo",
    "ocelada": "ocelado",
    "oceladas": "ocelado",
    "ocelados": "ocelado",
    "ocelos": "ocelo",
    "oces": "oc",
    "oceânica": "oceânico",
    "oceânicas": "oceânico",
    "oceânicos": "oceânico",
    "oceânides": "oceânide",
    "ocidentais": "ocidental",
    "ocidentalidades": "ocidentalidade",
    "ocidentalismos": "ocidentalismo",
    "ocidentalistas": "ocidentalista",
    "ocidentaliza": "ocidentalizar",
    "ocidentalizada": "ocidentalizar",
    "ocidentalizadas": "ocidentalizar",
    "ocidentalizado": "ocidentalizar",
    "ocidentalizados": "ocidentalizar",
    "ocidentalizai": "ocidentalizar",
    "ocidentalizais": "ocidentalizar",
    "ocidentalizam": "ocidentalizar",
    "ocidentalizamo": "ocidentalizar",
    "ocidentalizamos": "ocidentalizar",
    "ocidentalizando": "ocidentalizar",
    "ocidentalizara": "ocidentalizar",
    "ocidentalizaram": "ocidentalizar",
    "ocidentalizaras": "ocidentalizar",
    "ocidentalizarde": "ocidentalizar",
    "ocidentalizardes": "ocidentalizar",
    "ocidentalizare": "ocidentalizar",
    "ocidentalizarei": "ocidentalizar",
    "ocidentalizareis": "ocidentalizar",
    "ocidentalizarem": "ocidentalizar",
    "ocidentalizaremos": "ocidentalizar",
    "ocidentalizares": "ocidentalizar",
    "ocidentalizaria": "ocidentalizar",
    "ocidentalizariam": "ocidentalizar",
    "ocidentalizarias": "ocidentalizar",
    "ocidentalizarmo": "ocidentalizar",
    "ocidentalizarmos": "ocidentalizar",
    "ocidentalizará": "ocidentalizar",
    "ocidentalizarás": "ocidentalizar",
    "ocidentalizarão": "ocidentalizar",
    "ocidentalizaríamos": "ocidentalizar",
    "ocidentalizaríeis": "ocidentalizar",
    "ocidentalizas": "ocidentalizar",
    "ocidentalizasse": "ocidentalizar",
    "ocidentalizassem": "ocidentalizar",
    "ocidentalizasses": "ocidentalizar",
    "ocidentalizaste": "ocidentalizar",
    "ocidentalizastes": "ocidentalizar",
    "ocidentalizava": "ocidentalizar",
    "ocidentalizavam": "ocidentalizar",
    "ocidentalizavas": "ocidentalizar",
    "ocidentalizações": "ocidentalização",
    "ocidentalize": "ocidentalizar",
    "ocidentalizei": "ocidentalizar",
    "ocidentalizeis": "ocidentalizar",
    "ocidentalizem": "ocidentalizar",
    "ocidentalizemo": "ocidentalizar",
    "ocidentalizemos": "ocidentalizar",
    "ocidentalizes": "ocidentalizar",
    "ocidentalizo": "ocidentalizar",
    "ocidentalizou": "ocidentalizar",
    "ocidentalizá": "ocidentalizar",
    "ocidentalizámo": "ocidentalizar",
    "ocidentalizámos": "ocidentalizar",
    "ocidentalizáramo": "ocidentalizar",
    "ocidentalizáramos": "ocidentalizar",
    "ocidentalizárei": "ocidentalizar",
    "ocidentalizáreis": "ocidentalizar",
    "ocidentalizásseis": "ocidentalizar",
    "ocidentalizássemos": "ocidentalizar",
    "ocidentalizávamo": "ocidentalizar",
    "ocidentalizávamos": "ocidentalizar",
    "ocidentalizávei": "ocidentalizar",
    "ocidentalizáveis": "ocidentalizável",
    "ocidentes": "ocidente",
    "ocimóideas": "ocimóidea",
    "ociosa": "ocioso",
    "ociosas": "ocioso",
    "ociosidades": "ociosidade",
    "ociosos": "ocioso",
    "oclocracias": "oclocracia",
    "oclocrática": "oclocrático",
    "oclocráticas": "oclocrático",
    "oclocráticos": "oclocrático",
    "oclusa": "ocluso",
    "oclusas": "ocluso",
    "oclusiva": "oclusivo",
    "oclusivas": "oclusivo",
    "oclusivos": "oclusivo",
    "oclusos": "ocluso",
    "oclusões": "oclusão",
    "oco": "ocar",
    "ocorra": "ocorrer",
    "ocorrais": "ocorrer",
    "ocorram": "ocorrer",
    "ocorramo": "ocorrer",
    "ocorramos": "ocorrer",
    "ocorras": "ocorrer",
    "ocorre": "ocorrer",
    "ocorrei": "ocorrer",
    "ocorreis": "ocorrer",
    "ocorrem": "ocorrer",
    "ocorremo": "ocorrer",
    "ocorremos": "ocorrer",
    "ocorrendo": "ocorrer",
    "ocorrentes": "ocorrente",
    "ocorrera": "ocorrer",
    "ocorreram": "ocorrer",
    "ocorreras": "ocorrer",
    "ocorrerdes": "ocorrer",
    "ocorrerei": "ocorrer",
    "ocorrereis": "ocorrer",
    "ocorrerem": "ocorrer",
    "ocorreremos": "ocorrer",
    "ocorreres": "ocorrer",
    "ocorreria": "ocorrer",
    "ocorreriam": "ocorrer",
    "ocorrerias": "ocorrer",
    "ocorrermo": "ocorrer",
    "ocorrermos": "ocorrer",
    "ocorrerá": "ocorrer",
    "ocorrerás": "ocorrer",
    "ocorrerão": "ocorrer",
    "ocorreríamos": "ocorrer",
    "ocorreríeis": "ocorrer",
    "ocorres": "ocorrer",
    "ocorresse": "ocorrer",
    "ocorressem": "ocorrer",
    "ocorresses": "ocorrer",
    "ocorreste": "ocorrer",
    "ocorrestes": "ocorrer",
    "ocorreu": "ocorrer",
    "ocorri": "ocorrer",
    "ocorria": "ocorrer",
    "ocorriam": "ocorrer",
    "ocorrias": "ocorrer",
    "ocorrida": "ocorrido",
    "ocorridas": "ocorrido",
    "ocorrido": "ocorrer",
    "ocorridos": "ocorrido",
    "ocorro": "ocorrer",
    "ocorrências": "ocorrência",
    "ocorrêramo": "ocorrer",
    "ocorrêramos": "ocorrer",
    "ocorrêreis": "ocorrer",
    "ocorrêsseis": "ocorrer",
    "ocorrêssemos": "ocorrer",
    "ocorríamo": "ocorrer",
    "ocorríamos": "ocorrer",
    "ocorríeis": "ocorrer",
    "ocos": "oco",
    "ocou": "ocar",
    "ocras": "ocra",
    "ocreosa": "ocreoso",
    "ocreosas": "ocreoso",
    "ocreosos": "ocreoso",
    "ocres": "ocre",
    "ocricórnea": "ocricórneo",
    "ocricórneas": "ocricórneo",
    "ocricórneos": "ocricórneo",
    "ocrocéfala": "ocrocéfalo",
    "ocrocéfalas": "ocrocéfalo",
    "ocrocéfalos": "ocrocéfalo",
    "ocrodermias": "ocrodermia",
    "ocrácea": "ocráceo",
    "ocráceas": "ocráceo",
    "ocráceos": "ocráceo",
    "ocrópodes": "ocrópode",
    "ocróptera": "ocróptero",
    "ocrópteras": "ocróptero",
    "ocrópteros": "ocróptero",
    "octacorda": "octacordo",
    "octacordas": "octacordo",
    "octacordos": "octacordo",
    "octaedriformes": "octaedriforme",
    "octaedrites": "octaedrite",
    "octaedros": "octaedro",
    "octaetérides": "octaetéride",
    "octais": "octal",
    "octanagens": "octanagem",
    "octanas": "octana",
    "octandra": "octandro",
    "octandras": "octandro",
    "octandrias": "octandria",
    "octandros": "octandro",
    "octangulares": "octangular",
    "octanos": "octano",
    "octantes": "octante",
    "octateucos": "octateuco",
    "octaviana": "octaviano",
    "octavianas": "octaviano",
    "octavianos": "octaviano",
    "octaédrica": "octaédrico",
    "octaédricas": "octaédrico",
    "octaédricos": "octaédrico",
    "octilhiões": "octilhião",
    "octiliões": "octilião",
    "octingentésima": "octingentésimo",
    "octingentésimas": "octingentésimo",
    "octingentésimos": "octingentésimo",
    "octocoraliários": "octocoraliário",
    "octodontídeos": "octodontídeo",
    "octodôntidas": "octodôntida",
    "octogenária": "octogenário",
    "octogenárias": "octogenário",
    "octogenários": "octogenário",
    "octoginias": "octoginia",
    "octogonais": "octogonal",
    "octogésima": "octogésimo",
    "octogésimas": "octogésimo",
    "octogésimos": "octogésimo",
    "octopétala": "octopétalo",
    "octopétalas": "octopétalo",
    "octopétalos": "octopétalo",
    "octossilábica": "octossilábico",
    "octossilábicas": "octossilábico",
    "octossilábicos": "octossilábico",
    "octossépala": "octossépalo",
    "octossépalas": "octossépalo",
    "octossépalos": "octossépalo",
    "octossílaba": "octossílabo",
    "octossílabas": "octossílabo",
    "octossílabos": "octossílabo",
    "octostilos": "octostilo",
    "octuplica": "octuplicar",
    "octuplicada": "octuplicar",
    "octuplicadas": "octuplicar",
    "octuplicado": "octuplicar",
    "octuplicados": "octuplicar",
    "octuplicai": "octuplicar",
    "octuplicais": "octuplicar",
    "octuplicam": "octuplicar",
    "octuplicamo": "octuplicar",
    "octuplicamos": "octuplicar",
    "octuplicando": "octuplicar",
    "octuplicara": "octuplicar",
    "octuplicaram": "octuplicar",
    "octuplicaras": "octuplicar",
    "octuplicarde": "octuplicar",
    "octuplicardes": "octuplicar",
    "octuplicare": "octuplicar",
    "octuplicarei": "octuplicar",
    "octuplicareis": "octuplicar",
    "octuplicarem": "octuplicar",
    "octuplicaremos": "octuplicar",
    "octuplicares": "octuplicar",
    "octuplicaria": "octuplicar",
    "octuplicariam": "octuplicar",
    "octuplicarias": "octuplicar",
    "octuplicarmo": "octuplicar",
    "octuplicarmos": "octuplicar",
    "octuplicará": "octuplicar",
    "octuplicarás": "octuplicar",
    "octuplicarão": "octuplicar",
    "octuplicaríamos": "octuplicar",
    "octuplicaríeis": "octuplicar",
    "octuplicas": "octuplicar",
    "octuplicasse": "octuplicar",
    "octuplicassem": "octuplicar",
    "octuplicasses": "octuplicar",
    "octuplicaste": "octuplicar",
    "octuplicastes": "octuplicar",
    "octuplicava": "octuplicar",
    "octuplicavam": "octuplicar",
    "octuplicavas": "octuplicar",
    "octuplico": "octuplicar",
    "octuplicou": "octuplicar",
    "octuplicá": "octuplicar",
    "octuplicámo": "octuplicar",
    "octuplicámos": "octuplicar",
    "octuplicáramo": "octuplicar",
    "octuplicáramos": "octuplicar",
    "octuplicárei": "octuplicar",
    "octuplicáreis": "octuplicar",
    "octuplicásseis": "octuplicar",
    "octuplicássemos": "octuplicar",
    "octuplicávamo": "octuplicar",
    "octuplicávamos": "octuplicar",
    "octuplicávei": "octuplicar",
    "octuplicáveis": "octuplicável",
    "octuplique": "octuplicar",
    "octupliquei": "octuplicar",
    "octupliqueis": "octuplicar",
    "octupliquem": "octuplicar",
    "octupliquemo": "octuplicar",
    "octupliquemos": "octuplicar",
    "octupliques": "octuplicar",
    "octândrias": "octândria",
    "octândrica": "octândrico",
    "octândricas": "octândrico",
    "octândricos": "octândrico",
    "octípedes": "octípede",
    "octógina": "octógino",
    "octóginas": "octógino",
    "octóginos": "octógino",
    "octógonos": "octógono",
    "octópodes": "octópode",
    "oculada": "oculado",
    "oculadas": "oculado",
    "oculados": "oculado",
    "oculares": "ocular",
    "ocularidades": "ocularidade",
    "oculações": "oculação",
    "oculiformes": "oculiforme",
    "oculistas": "oculista",
    "oculosa": "oculoso",
    "oculosas": "oculoso",
    "oculosos": "oculoso",
    "oculta": "oculto",
    "ocultada": "ocultar",
    "ocultadas": "ocultar",
    "ocultado": "ocultar",
    "ocultadora": "ocultador",
    "ocultadoras": "ocultador",
    "ocultadores": "ocultador",
    "ocultados": "ocultar",
    "ocultai": "ocultar",
    "ocultais": "ocultar",
    "ocultam": "ocultar",
    "ocultamo": "ocultar",
    "ocultamos": "ocultar",
    "ocultando": "ocultar",
    "ocultantes": "ocultante",
    "ocultara": "ocultar",
    "ocultaram": "ocultar",
    "ocultaras": "ocultar",
    "ocultarde": "ocultar",
    "ocultardes": "ocultar",
    "ocultare": "ocultar",
    "ocultarei": "ocultar",
    "ocultareis": "ocultar",
    "ocultarem": "ocultar",
    "ocultaremos": "ocultar",
    "ocultares": "ocultar",
    "ocultaria": "ocultar",
    "ocultariam": "ocultar",
    "ocultarias": "ocultar",
    "ocultarmo": "ocultar",
    "ocultarmos": "ocultar",
    "ocultará": "ocultar",
    "ocultarás": "ocultar",
    "ocultarão": "ocultar",
    "ocultaríamos": "ocultar",
    "ocultaríeis": "ocultar",
    "ocultas": "oculto",
    "ocultasse": "ocultar",
    "ocultassem": "ocultar",
    "ocultasses": "ocultar",
    "ocultaste": "ocultar",
    "ocultastes": "ocultar",
    "ocultava": "ocultar",
    "ocultavam": "ocultar",
    "ocultavas": "ocultar",
    "ocultações": "ocultação",
    "oculte": "ocultar",
    "ocultei": "ocultar",
    "oculteis": "ocultar",
    "ocultem": "ocultar",
    "ocultemo": "ocultar",
    "ocultemos": "ocultar",
    "ocultes": "ocultar",
    "ocultismos": "ocultismo",
    "ocultistas": "ocultista",
    "oculto": "ocultar",
    "ocultos": "oculto",
    "ocultou": "ocultar",
    "ocultá": "ocultar",
    "ocultámo": "ocultar",
    "ocultámos": "ocultar",
    "ocultáramo": "ocultar",
    "ocultáramos": "ocultar",
    "ocultárei": "ocultar",
    "ocultáreis": "ocultar",
    "ocultásseis": "ocultar",
    "ocultássemos": "ocultar",
    "ocultávamo": "ocultar",
    "ocultávamos": "ocultar",
    "ocultávei": "ocultar",
    "ocultáveis": "ocultável",
    "oculífera": "oculífero",
    "oculíferas": "oculífero",
    "oculíferos": "oculífero",
    "oculísticas": "oculística",
    "ocupa": "ocupar",
    "ocupacionais": "ocupacional",
    "ocupada": "ocupar",
    "ocupadas": "ocupar",
    "ocupado": "ocupar",
    "ocupadora": "ocupador",
    "ocupadoras": "ocupador",
    "ocupadores": "ocupador",
    "ocupados": "ocupar",
    "ocupadíssima": "ocupado",
    "ocupadíssimas": "ocupado",
    "ocupadíssimo": "ocupado",
    "ocupadíssimos": "ocupado",
    "ocupai": "ocupar",
    "ocupais": "ocupar",
    "ocupam": "ocupar",
    "ocupamo": "ocupar",
    "ocupamos": "ocupar",
    "ocupando": "ocupar",
    "ocupantes": "ocupante",
    "ocupara": "ocupar",
    "ocuparam": "ocupar",
    "ocuparas": "ocupar",
    "ocuparde": "ocupar",
    "ocupardes": "ocupar",
    "ocupare": "ocupar",
    "ocuparei": "ocupar",
    "ocupareis": "ocupar",
    "ocuparem": "ocupar",
    "ocuparemos": "ocupar",
    "ocupares": "ocupar",
    "ocuparia": "ocupar",
    "ocupariam": "ocupar",
    "ocuparias": "ocupar",
    "ocuparmo": "ocupar",
    "ocuparmos": "ocupar",
    "ocupará": "ocupar",
    "ocuparás": "ocupar",
    "ocuparão": "ocupar",
    "ocuparíamos": "ocupar",
    "ocuparíeis": "ocupar",
    "ocupas": "ocupar",
    "ocupasse": "ocupar",
    "ocupassem": "ocupar",
    "ocupasses": "ocupar",
    "ocupaste": "ocupar",
    "ocupastes": "ocupar",
    "ocupava": "ocupar",
    "ocupavam": "ocupar",
    "ocupavas": "ocupar",
    "ocupações": "ocupação",
    "ocupe": "ocupar",
    "ocupei": "ocupar",
    "ocupeis": "ocupar",
    "ocupem": "ocupar",
    "ocupemo": "ocupar",
    "ocupemos": "ocupar",
    "ocupes": "ocupar",
    "ocupo": "ocupar",
    "ocupou": "ocupar",
    "ocupá": "ocupar",
    "ocupámo": "ocupar",
    "ocupámos": "ocupar",
    "ocupáramo": "ocupar",
    "ocupáramos": "ocupar",
    "ocupárei": "ocupar",
    "ocupáreis": "ocupar",
    "ocupásseis": "ocupar",
    "ocupássemos": "ocupar",
    "ocupávamo": "ocupar",
    "ocupávamos": "ocupar",
    "ocupávei": "ocupar",
    "ocupáveis": "ocupável",
    "ocá": "ocar",
    "ocámo": "ocar",
    "ocámos": "ocar",
    "ocáramo": "ocar",
    "ocáramos": "ocar",
    "ocárei": "ocar",
    "ocáreis": "ocar",
    "ocásseis": "ocar",
    "ocássemos": "ocar",
    "ocávamo": "ocar",
    "ocávamos": "ocar",
    "ocávei": "ocar",
    "ocáveis": "ocar",
    "odaliscas": "odalisca",
    "odaxesmos": "odaxesmo",
    "odeia": "odiar",
    "odeiam": "odiar",
    "odeias": "odiar",
    "odeie": "odiar",
    "odeiem": "odiar",
    "odeies": "odiar",
    "odeio": "odiar",
    "odes": "ode",
    "odeões": "odeão",
    "odiada": "odiar",
    "odiadas": "odiar",
    "odiado": "odiar",
    "odiados": "odiar",
    "odiadíssima": "odiado",
    "odiadíssimas": "odiado",
    "odiadíssimo": "odiado",
    "odiadíssimos": "odiado",
    "odiai": "odiar",
    "odiais": "odiar",
    "odiamo": "odiar",
    "odiamos": "odiar",
    "odiando": "odiar",
    "odiara": "odiar",
    "odiaram": "odiar",
    "odiaras": "odiar",
    "odiarde": "odiar",
    "odiardes": "odiar",
    "odiare": "odiar",
    "odiarei": "odiar",
    "odiareis": "odiar",
    "odiarem": "odiar",
    "odiaremos": "odiar",
    "odiares": "odiar",
    "odiaria": "odiar",
    "odiariam": "odiar",
    "odiarias": "odiar",
    "odiarmo": "odiar",
    "odiarmos": "odiar",
    "odiará": "odiar",
    "odiarás": "odiar",
    "odiarão": "odiar",
    "odiaríamos": "odiar",
    "odiaríeis": "odiar",
    "odiasse": "odiar",
    "odiassem": "odiar",
    "odiasses": "odiar",
    "odiaste": "odiar",
    "odiastes": "odiar",
    "odiava": "odiar",
    "odiavam": "odiar",
    "odiavas": "odiar",
    "odiei": "odiar",
    "odieis": "odiar",
    "odiemo": "odiar",
    "odiemos": "odiar",
    "odienta": "odiento",
    "odientas": "odiento",
    "odientos": "odiento",
    "odiosa": "odioso",
    "odiosas": "odioso",
    "odiosos": "odioso",
    "odiou": "odiar",
    "odiozinho": "ódio",
    "odiozinhos": "ódio",
    "odiozito": "ódio",
    "odiozitos": "ódio",
    "odisseias": "odisseia",
    "odisseica": "odisseico",
    "odisseicas": "odisseico",
    "odisseicos": "odisseico",
    "odiá": "odiar",
    "odiámo": "odiar",
    "odiámos": "odiar",
    "odiáramo": "odiar",
    "odiáramos": "odiar",
    "odiárei": "odiar",
    "odiáreis": "odiar",
    "odiásseis": "odiar",
    "odiássemos": "odiar",
    "odiávamo": "odiar",
    "odiávamos": "odiar",
    "odiávei": "odiar",
    "odiáveis": "odiável",
    "odonatos": "odonato",
    "odontagogos": "odontagogo",
    "odontagras": "odontagra",
    "odontalgias": "odontalgia",
    "odontiases": "odontiase",
    "odontites": "odontite",
    "odontoblastos": "odontoblasto",
    "odontocetos": "odontoceto",
    "odontogenias": "odontogenia",
    "odontogéneses": "odontogénese",
    "odontolitíases": "odontolitíase",
    "odontologias": "odontologia",
    "odontologistas": "odontologista",
    "odontológica": "odontológico",
    "odontológicas": "odontológico",
    "odontológicos": "odontológico",
    "odontorragias": "odontorragia",
    "odontoses": "odontose",
    "odontotecnias": "odontotecnia",
    "odontotécnica": "odontotécnico",
    "odontotécnicas": "odontotécnico",
    "odontotécnicos": "odontotécnico",
    "odontálgica": "odontálgico",
    "odontálgicas": "odontálgico",
    "odontálgicos": "odontálgico",
    "odontóforos": "odontóforo",
    "odontóides": "odontóide",
    "odontólitos": "odontólito",
    "odontórnitas": "odontórnita",
    "odora": "odorar",
    "odorada": "odorar",
    "odoradas": "odorar",
    "odorado": "odorar",
    "odorados": "odorar",
    "odorai": "odorar",
    "odorais": "odorar",
    "odoram": "odorar",
    "odoramo": "odorar",
    "odoramos": "odorar",
    "odorando": "odorar",
    "odorantes": "odorante",
    "odorara": "odorar",
    "odoraram": "odorar",
    "odoraras": "odorar",
    "odorardes": "odorar",
    "odorarei": "odorar",
    "odorareis": "odorar",
    "odorarem": "odorar",
    "odoraremos": "odorar",
    "odorares": "odorar",
    "odoraria": "odorar",
    "odorariam": "odorar",
    "odorarias": "odorar",
    "odorarmo": "odorar",
    "odorarmos": "odorar",
    "odorará": "odorar",
    "odorarás": "odorar",
    "odorarão": "odorar",
    "odoraríamos": "odorar",
    "odoraríeis": "odorar",
    "odoras": "odorar",
    "odorasse": "odorar",
    "odorassem": "odorar",
    "odorasses": "odorar",
    "odoraste": "odorar",
    "odorastes": "odorar",
    "odorava": "odorar",
    "odoravam": "odorar",
    "odoravas": "odorar",
    "odore": "odorar",
    "odorei": "odorar",
    "odoreis": "odorar",
    "odorem": "odorar",
    "odoremo": "odorar",
    "odoremos": "odorar",
    "odores": "odorar",
    "odorifumantes": "odorifumante",
    "odorimetrias": "odorimetria",
    "odoriza": "odorizar",
    "odorizada": "odorizar",
    "odorizadas": "odorizar",
    "odorizado": "odorizar",
    "odorizados": "odorizar",
    "odorizai": "odorizar",
    "odorizais": "odorizar",
    "odorizam": "odorizar",
    "odorizamo": "odorizar",
    "odorizamos": "odorizar",
    "odorizando": "odorizar",
    "odorizara": "odorizar",
    "odorizaram": "odorizar",
    "odorizaras": "odorizar",
    "odorizarde": "odorizar",
    "odorizardes": "odorizar",
    "odorizare": "odorizar",
    "odorizarei": "odorizar",
    "odorizareis": "odorizar",
    "odorizarem": "odorizar",
    "odorizaremos": "odorizar",
    "odorizares": "odorizar",
    "odorizaria": "odorizar",
    "odorizariam": "odorizar",
    "odorizarias": "odorizar",
    "odorizarmo": "odorizar",
    "odorizarmos": "odorizar",
    "odorizará": "odorizar",
    "odorizarás": "odorizar",
    "odorizarão": "odorizar",
    "odorizaríamos": "odorizar",
    "odorizaríeis": "odorizar",
    "odorizas": "odorizar",
    "odorizasse": "odorizar",
    "odorizassem": "odorizar",
    "odorizasses": "odorizar",
    "odorizaste": "odorizar",
    "odorizastes": "odorizar",
    "odorizava": "odorizar",
    "odorizavam": "odorizar",
    "odorizavas": "odorizar",
    "odorize": "odorizar",
    "odorizei": "odorizar",
    "odorizeis": "odorizar",
    "odorizem": "odorizar",
    "odorizemo": "odorizar",
    "odorizemos": "odorizar",
    "odorizes": "odorizar",
    "odorizo": "odorizar",
    "odorizou": "odorizar",
    "odorizá": "odorizar",
    "odorizámo": "odorizar",
    "odorizámos": "odorizar",
    "odorizáramo": "odorizar",
    "odorizáramos": "odorizar",
    "odorizárei": "odorizar",
    "odorizáreis": "odorizar",
    "odorizásseis": "odorizar",
    "odorizássemos": "odorizar",
    "odorizávamo": "odorizar",
    "odorizávamos": "odorizar",
    "odorizávei": "odorizar",
    "odorizáveis": "odorizar",
    "odoro": "odorar",
    "odorosa": "odoroso",
    "odorosas": "odoroso",
    "odorosos": "odoroso",
    "odorou": "odorar",
    "odorámo": "odorar",
    "odorámos": "odorar",
    "odoráramo": "odorar",
    "odoráramos": "odorar",
    "odoráreis": "odorar",
    "odorásseis": "odorar",
    "odorássemos": "odorar",
    "odorávamo": "odorar",
    "odorávamos": "odorar",
    "odoráveis": "odorar",
    "odorífera": "odorífero",
    "odoríferas": "odorífero",
    "odoríferos": "odorífero",
    "odorífica": "odorífico",
    "odoríficas": "odorífico",
    "odoríficos": "odorífico",
    "odradas": "odrada",
    "odreira": "odreiro",
    "odreiras": "odreiro",
    "odreiros": "odreiro",
    "odres": "odre",
    "odínica": "odínico",
    "odínicas": "odínico",
    "odínicos": "odínico",
    "oersteds": "oersted",
    "oestes": "oeste",
    "ofega": "ofegar",
    "ofegada": "ofegar",
    "ofegadas": "ofegar",
    "ofegado": "ofegar",
    "ofegados": "ofegar",
    "ofegai": "ofegar",
    "ofegais": "ofegar",
    "ofegam": "ofegar",
    "ofegamo": "ofegar",
    "ofegamos": "ofegar",
    "ofegando": "ofegar",
    "ofegantes": "ofegante",
    "ofegara": "ofegar",
    "ofegaram": "ofegar",
    "ofegaras": "ofegar",
    "ofegardes": "ofegar",
    "ofegarei": "ofegar",
    "ofegareis": "ofegar",
    "ofegarem": "ofegar",
    "ofegaremos": "ofegar",
    "ofegares": "ofegar",
    "ofegaria": "ofegar",
    "ofegariam": "ofegar",
    "ofegarias": "ofegar",
    "ofegarmo": "ofegar",
    "ofegarmos": "ofegar",
    "ofegará": "ofegar",
    "ofegarás": "ofegar",
    "ofegarão": "ofegar",
    "ofegaríamos": "ofegar",
    "ofegaríeis": "ofegar",
    "ofegas": "ofegar",
    "ofegasse": "ofegar",
    "ofegassem": "ofegar",
    "ofegasses": "ofegar",
    "ofegaste": "ofegar",
    "ofegastes": "ofegar",
    "ofegava": "ofegar",
    "ofegavam": "ofegar",
    "ofegavas": "ofegar",
    "ofego": "ofegar",
    "ofegos": "ofego",
    "ofegosa": "ofegoso",
    "ofegosas": "ofegoso",
    "ofegosos": "ofegoso",
    "ofegou": "ofegar",
    "ofegue": "ofegar",
    "ofeguei": "ofegar",
    "ofegueis": "ofegar",
    "ofeguem": "ofegar",
    "ofeguemo": "ofegar",
    "ofeguemos": "ofegar",
    "ofeguenta": "ofeguento",
    "ofeguentas": "ofeguento",
    "ofeguentos": "ofeguento",
    "ofegues": "ofegar",
    "ofegámo": "ofegar",
    "ofegámos": "ofegar",
    "ofegáramo": "ofegar",
    "ofegáramos": "ofegar",
    "ofegáreis": "ofegar",
    "ofegásseis": "ofegar",
    "ofegássemos": "ofegar",
    "ofegávamo": "ofegar",
    "ofegávamos": "ofegar",
    "ofegáveis": "ofegar",
    "ofenda": "ofender",
    "ofendais": "ofender",
    "ofendam": "ofender",
    "ofendamo": "ofender",
    "ofendamos": "ofender",
    "ofendas": "ofender",
    "ofende": "ofender",
    "ofendedora": "ofendedor",
    "ofendedoras": "ofendedor",
    "ofendedores": "ofendedor",
    "ofendei": "ofender",
    "ofendeis": "ofender",
    "ofendem": "ofender",
    "ofendemo": "ofender",
    "ofendemos": "ofender",
    "ofendendo": "ofender",
    "ofendera": "ofender",
    "ofenderam": "ofender",
    "ofenderas": "ofender",
    "ofenderde": "ofender",
    "ofenderdes": "ofender",
    "ofendere": "ofender",
    "ofenderei": "ofender",
    "ofendereis": "ofender",
    "ofenderem": "ofender",
    "ofenderemos": "ofender",
    "ofenderes": "ofender",
    "ofenderia": "ofender",
    "ofenderiam": "ofender",
    "ofenderias": "ofender",
    "ofendermo": "ofender",
    "ofendermos": "ofender",
    "ofenderá": "ofender",
    "ofenderás": "ofender",
    "ofenderão": "ofender",
    "ofenderíamos": "ofender",
    "ofenderíeis": "ofender",
    "ofendes": "ofender",
    "ofendesse": "ofender",
    "ofendessem": "ofender",
    "ofendesses": "ofender",
    "ofendeste": "ofender",
    "ofendestes": "ofender",
    "ofendeu": "ofender",
    "ofendi": "ofender",
    "ofendia": "ofender",
    "ofendiam": "ofender",
    "ofendias": "ofender",
    "ofendida": "ofendido",
    "ofendidas": "ofendido",
    "ofendido": "ofender",
    "ofendidos": "ofendido",
    "ofendidíssima": "ofendido",
    "ofendidíssimas": "ofendido",
    "ofendidíssimo": "ofendido",
    "ofendidíssimos": "ofendido",
    "ofendo": "ofender",
    "ofendê": "ofender",
    "ofendêramo": "ofender",
    "ofendêramos": "ofender",
    "ofendêrei": "ofender",
    "ofendêreis": "ofender",
    "ofendêsseis": "ofender",
    "ofendêssemos": "ofender",
    "ofendíamo": "ofender",
    "ofendíamos": "ofender",
    "ofendículos": "ofendículo",
    "ofendíei": "ofender",
    "ofendíeis": "ofender",
    "ofendíveis": "ofendível",
    "ofensa": "ofenso",
    "ofensas": "ofenso",
    "ofensiva": "ofensivo",
    "ofensivas": "ofensivo",
    "ofensivos": "ofensivo",
    "ofensora": "ofensor",
    "ofensoras": "ofensor",
    "ofensores": "ofensor",
    "ofensos": "ofenso",
    "ofensões": "ofensão",
    "oferece": "oferecer",
    "oferecedora": "oferecedor",
    "oferecedoras": "oferecedor",
    "oferecedores": "oferecedor",
    "oferecei": "oferecer",
    "ofereceis": "oferecer",
    "oferecem": "oferecer",
    "oferecemo": "oferecer",
    "oferecemos": "oferecer",
    "oferecendo": "oferecer",
    "oferecera": "oferecer",
    "ofereceram": "oferecer",
    "ofereceras": "oferecer",
    "oferecerde": "oferecer",
    "oferecerdes": "oferecer",
    "oferecere": "oferecer",
    "oferecerei": "oferecer",
    "oferecereis": "oferecer",
    "oferecerem": "oferecer",
    "ofereceremos": "oferecer",
    "ofereceres": "oferecer",
    "ofereceria": "oferecer",
    "ofereceriam": "oferecer",
    "oferecerias": "oferecer",
    "oferecermo": "oferecer",
    "oferecermos": "oferecer",
    "oferecerá": "oferecer",
    "oferecerás": "oferecer",
    "oferecerão": "oferecer",
    "ofereceríamos": "oferecer",
    "ofereceríeis": "oferecer",
    "ofereces": "oferecer",
    "oferecesse": "oferecer",
    "oferecessem": "oferecer",
    "oferecesses": "oferecer",
    "ofereceste": "oferecer",
    "oferecestes": "oferecer",
    "ofereceu": "oferecer",
    "ofereci": "oferecer",
    "oferecia": "oferecer",
    "ofereciam": "oferecer",
    "oferecias": "oferecer",
    "oferecida": "oferecido",
    "oferecidas": "oferecido",
    "oferecido": "oferecer",
    "oferecidos": "oferecido",
    "oferecimentos": "oferecimento",
    "oferecê": "oferecer",
    "oferecêramo": "oferecer",
    "oferecêramos": "oferecer",
    "oferecêrei": "oferecer",
    "oferecêreis": "oferecer",
    "oferecêsseis": "oferecer",
    "oferecêssemos": "oferecer",
    "oferecíamo": "oferecer",
    "oferecíamos": "oferecer",
    "oferecíei": "oferecer",
    "oferecíeis": "oferecer",
    "oferecíveis": "oferecível",
    "oferenda": "oferendar",
    "oferendada": "oferendar",
    "oferendadas": "oferendar",
    "oferendado": "oferendar",
    "oferendados": "oferendar",
    "oferendai": "oferendar",
    "oferendais": "oferendar",
    "oferendam": "oferendar",
    "oferendamo": "oferendar",
    "oferendamos": "oferendar",
    "oferendando": "oferendar",
    "oferendara": "oferendar",
    "oferendaram": "oferendar",
    "oferendaras": "oferendar",
    "oferendarde": "oferendar",
    "oferendardes": "oferendar",
    "oferendare": "oferendar",
    "oferendarei": "oferendar",
    "oferendareis": "oferendar",
    "oferendarem": "oferendar",
    "oferendaremos": "oferendar",
    "oferendares": "oferendar",
    "oferendaria": "oferendar",
    "oferendariam": "oferendar",
    "oferendarias": "oferendar",
    "oferendarmo": "oferendar",
    "oferendarmos": "oferendar",
    "oferendará": "oferendar",
    "oferendarás": "oferendar",
    "oferendarão": "oferendar",
    "oferendaríamos": "oferendar",
    "oferendaríeis": "oferendar",
    "oferendas": "oferendar",
    "oferendasse": "oferendar",
    "oferendassem": "oferendar",
    "oferendasses": "oferendar",
    "oferendaste": "oferendar",
    "oferendastes": "oferendar",
    "oferendava": "oferendar",
    "oferendavam": "oferendar",
    "oferendavas": "oferendar",
    "oferende": "oferendar",
    "oferendei": "oferendar",
    "oferendeis": "oferendar",
    "oferendem": "oferendar",
    "oferendemo": "oferendar",
    "oferendemos": "oferendar",
    "oferendes": "oferendar",
    "oferendo": "oferendar",
    "oferendou": "oferendar",
    "oferendá": "oferendar",
    "oferendámo": "oferendar",
    "oferendámos": "oferendar",
    "oferendáramo": "oferendar",
    "oferendáramos": "oferendar",
    "oferendárei": "oferendar",
    "oferendáreis": "oferendar",
    "oferendásseis": "oferendar",
    "oferendássemos": "oferendar",
    "oferendávamo": "oferendar",
    "oferendávamos": "oferendar",
    "oferendávei": "oferendar",
    "oferendáveis": "oferendar",
    "oferentes": "oferente",
    "ofereça": "oferecer",
    "ofereçais": "oferecer",
    "ofereçam": "oferecer",
    "ofereçamo": "oferecer",
    "ofereçamos": "oferecer",
    "ofereças": "oferecer",
    "ofereço": "oferecer",
    "oferta": "ofertar",
    "ofertada": "ofertar",
    "ofertadas": "ofertar",
    "ofertado": "ofertar",
    "ofertados": "ofertar",
    "ofertai": "ofertar",
    "ofertais": "ofertar",
    "ofertam": "ofertar",
    "ofertamentos": "ofertamento",
    "ofertamo": "ofertar",
    "ofertamos": "ofertar",
    "ofertando": "ofertar",
    "ofertantes": "ofertante",
    "ofertara": "ofertar",
    "ofertaram": "ofertar",
    "ofertaras": "ofertar",
    "ofertarde": "ofertar",
    "ofertardes": "ofertar",
    "ofertare": "ofertar",
    "ofertarei": "ofertar",
    "ofertareis": "ofertar",
    "ofertarem": "ofertar",
    "ofertaremos": "ofertar",
    "ofertares": "ofertar",
    "ofertaria": "ofertar",
    "ofertariam": "ofertar",
    "ofertarias": "ofertar",
    "ofertarmo": "ofertar",
    "ofertarmos": "ofertar",
    "ofertará": "ofertar",
    "ofertarás": "ofertar",
    "ofertarão": "ofertar",
    "ofertaríamos": "ofertar",
    "ofertaríeis": "ofertar",
    "ofertas": "ofertar",
    "ofertasse": "ofertar",
    "ofertassem": "ofertar",
    "ofertasses": "ofertar",
    "ofertaste": "ofertar",
    "ofertastes": "ofertar",
    "ofertava": "ofertar",
    "ofertavam": "ofertar",
    "ofertavas": "ofertar",
    "oferte": "ofertar",
    "ofertei": "ofertar",
    "oferteiras": "oferteira",
    "oferteis": "ofertar",
    "ofertem": "ofertar",
    "ofertemo": "ofertar",
    "ofertemos": "ofertar",
    "ofertes": "ofertar",
    "oferto": "ofertar",
    "ofertou": "ofertar",
    "ofertá": "ofertar",
    "ofertámo": "ofertar",
    "ofertámos": "ofertar",
    "ofertáramo": "ofertar",
    "ofertáramos": "ofertar",
    "ofertárei": "ofertar",
    "ofertáreis": "ofertar",
    "ofertásseis": "ofertar",
    "ofertássemos": "ofertar",
    "ofertávamo": "ofertar",
    "ofertávamos": "ofertar",
    "ofertávei": "ofertar",
    "ofertáveis": "ofertável",
    "ofertórios": "ofertório",
    "offsetes": "offset",
    "oficia": "oficiar",
    "oficiada": "oficiar",
    "oficiadas": "oficiar",
    "oficiado": "oficiar",
    "oficiadora": "oficiador",
    "oficiadoras": "oficiador",
    "oficiadores": "oficiador",
    "oficiados": "oficiar",
    "oficiai": "oficiar",
    "oficiais": "oficiar",
    "oficialatos": "oficialato",
    "oficialidades": "oficialidade",
    "oficialismos": "oficialismo",
    "oficializa": "oficializar",
    "oficializada": "oficializar",
    "oficializadas": "oficializar",
    "oficializado": "oficializar",
    "oficializados": "oficializar",
    "oficializai": "oficializar",
    "oficializais": "oficializar",
    "oficializam": "oficializar",
    "oficializamo": "oficializar",
    "oficializamos": "oficializar",
    "oficializando": "oficializar",
    "oficializara": "oficializar",
    "oficializaram": "oficializar",
    "oficializaras": "oficializar",
    "oficializarde": "oficializar",
    "oficializardes": "oficializar",
    "oficializare": "oficializar",
    "oficializarei": "oficializar",
    "oficializareis": "oficializar",
    "oficializarem": "oficializar",
    "oficializaremos": "oficializar",
    "oficializares": "oficializar",
    "oficializaria": "oficializar",
    "oficializariam": "oficializar",
    "oficializarias": "oficializar",
    "oficializarmo": "oficializar",
    "oficializarmos": "oficializar",
    "oficializará": "oficializar",
    "oficializarás": "oficializar",
    "oficializarão": "oficializar",
    "oficializaríamos": "oficializar",
    "oficializaríeis": "oficializar",
    "oficializas": "oficializar",
    "oficializasse": "oficializar",
    "oficializassem": "oficializar",
    "oficializasses": "oficializar",
    "oficializaste": "oficializar",
    "oficializastes": "oficializar",
    "oficializava": "oficializar",
    "oficializavam": "oficializar",
    "oficializavas": "oficializar",
    "oficializações": "oficialização",
    "oficialize": "oficializar",
    "oficializei": "oficializar",
    "oficializeis": "oficializar",
    "oficializem": "oficializar",
    "oficializemo": "oficializar",
    "oficializemos": "oficializar",
    "oficializes": "oficializar",
    "oficializo": "oficializar",
    "oficializou": "oficializar",
    "oficializá": "oficializar",
    "oficializámo": "oficializar",
    "oficializámos": "oficializar",
    "oficializáramo": "oficializar",
    "oficializáramos": "oficializar",
    "oficializárei": "oficializar",
    "oficializáreis": "oficializar",
    "oficializásseis": "oficializar",
    "oficializássemos": "oficializar",
    "oficializávamo": "oficializar",
    "oficializávamos": "oficializar",
    "oficializávei": "oficializar",
    "oficializáveis": "oficializável",
    "oficiam": "oficiar",
    "oficiamo": "oficiar",
    "oficiamos": "oficiar",
    "oficiando": "oficiar",
    "oficiantes": "oficiante",
    "oficiara": "oficiar",
    "oficiaram": "oficiar",
    "oficiaras": "oficiar",
    "oficiardes": "oficiar",
    "oficiarei": "oficiar",
    "oficiareis": "oficiar",
    "oficiarem": "oficiar",
    "oficiaremos": "oficiar",
    "oficiares": "oficiar",
    "oficiaria": "oficiar",
    "oficiariam": "oficiar",
    "oficiarias": "oficiar",
    "oficiarmo": "oficiar",
    "oficiarmos": "oficiar",
    "oficiará": "oficiar",
    "oficiarás": "oficiar",
    "oficiarão": "oficiar",
    "oficiaríamos": "oficiar",
    "oficiaríeis": "oficiar",
    "oficias": "oficiar",
    "oficiasse": "oficiar",
    "oficiassem": "oficiar",
    "oficiasses": "oficiar",
    "oficiaste": "oficiar",
    "oficiastes": "oficiar",
    "oficiava": "oficiar",
    "oficiavam": "oficiar",
    "oficiavas": "oficiar",
    "oficie": "oficiar",
    "oficiei": "oficiar",
    "oficieis": "oficiar",
    "oficiem": "oficiar",
    "oficiemo": "oficiar",
    "oficiemos": "oficiar",
    "oficies": "oficiar",
    "oficinais": "oficinal",
    "oficinas": "oficina",
    "oficio": "oficiar",
    "oficiosa": "oficioso",
    "oficiosas": "oficioso",
    "oficiosidades": "oficiosidade",
    "oficiosos": "oficioso",
    "oficiou": "oficiar",
    "oficiámo": "oficiar",
    "oficiámos": "oficiar",
    "oficiáramo": "oficiar",
    "oficiáramos": "oficiar",
    "oficiáreis": "oficiar",
    "oficiásseis": "oficiar",
    "oficiássemos": "oficiar",
    "oficiávamo": "oficiar",
    "oficiávamos": "oficiar",
    "oficiáveis": "oficiar",
    "ofidismos": "ofidismo",
    "ofiofagias": "ofiofagia",
    "ofioglossáceas": "ofioglossácea",
    "ofiolatrias": "ofiolatria",
    "ofiomancias": "ofiomancia",
    "ofiófaga": "ofiófago",
    "ofiófagas": "ofiófago",
    "ofiófagos": "ofiófago",
    "ofióidea": "ofióideo",
    "ofióideas": "ofióideo",
    "ofióideos": "ofióideo",
    "ofióides": "ofióide",
    "ofiúros": "ofiúro",
    "oftalgias": "oftalgia",
    "oftalmalgias": "oftalmalgia",
    "oftalmias": "oftalmia",
    "oftalmologias": "oftalmologia",
    "oftalmologistas": "oftalmologista",
    "oftalmológica": "oftalmológico",
    "oftalmológicas": "oftalmológico",
    "oftalmológicos": "oftalmológico",
    "oftalmoplastias": "oftalmoplastia",
    "oftalmoplegias": "oftalmoplegia",
    "oftalmorragias": "oftalmorragia",
    "oftalmoscopias": "oftalmoscopia",
    "oftalmoscópios": "oftalmoscópio",
    "oftalmoterapias": "oftalmoterapia",
    "oftalmotomias": "oftalmotomia",
    "oftalmógrafos": "oftalmógrafo",
    "oftalmóloga": "oftalmólogo",
    "oftalmólogas": "oftalmólogo",
    "oftalmólogos": "oftalmólogo",
    "oftalmómetros": "oftalmómetro",
    "oftálmica": "oftálmico",
    "oftálmicas": "oftálmico",
    "oftálmicos": "oftálmico",
    "ofusca": "ofuscar",
    "ofuscada": "ofuscar",
    "ofuscadas": "ofuscar",
    "ofuscado": "ofuscar",
    "ofuscados": "ofuscar",
    "ofuscai": "ofuscar",
    "ofuscais": "ofuscar",
    "ofuscam": "ofuscar",
    "ofuscamentos": "ofuscamento",
    "ofuscamo": "ofuscar",
    "ofuscamos": "ofuscar",
    "ofuscando": "ofuscar",
    "ofuscantes": "ofuscante",
    "ofuscara": "ofuscar",
    "ofuscaram": "ofuscar",
    "ofuscaras": "ofuscar",
    "ofuscarde": "ofuscar",
    "ofuscardes": "ofuscar",
    "ofuscare": "ofuscar",
    "ofuscarei": "ofuscar",
    "ofuscareis": "ofuscar",
    "ofuscarem": "ofuscar",
    "ofuscaremos": "ofuscar",
    "ofuscares": "ofuscar",
    "ofuscaria": "ofuscar",
    "ofuscariam": "ofuscar",
    "ofuscarias": "ofuscar",
    "ofuscarmo": "ofuscar",
    "ofuscarmos": "ofuscar",
    "ofuscará": "ofuscar",
    "ofuscarás": "ofuscar",
    "ofuscarão": "ofuscar",
    "ofuscaríamos": "ofuscar",
    "ofuscaríeis": "ofuscar",
    "ofuscas": "ofuscar",
    "ofuscasse": "ofuscar",
    "ofuscassem": "ofuscar",
    "ofuscasses": "ofuscar",
    "ofuscaste": "ofuscar",
    "ofuscastes": "ofuscar",
    "ofuscava": "ofuscar",
    "ofuscavam": "ofuscar",
    "ofuscavas": "ofuscar",
    "ofuscações": "ofuscação",
    "ofusco": "ofuscar",
    "ofuscou": "ofuscar",
    "ofuscá": "ofuscar",
    "ofuscámo": "ofuscar",
    "ofuscámos": "ofuscar",
    "ofuscáramo": "ofuscar",
    "ofuscáramos": "ofuscar",
    "ofuscárei": "ofuscar",
    "ofuscáreis": "ofuscar",
    "ofuscásseis": "ofuscar",
    "ofuscássemos": "ofuscar",
    "ofuscávamo": "ofuscar",
    "ofuscávamos": "ofuscar",
    "ofuscávei": "ofuscar",
    "ofuscáveis": "ofuscável",
    "ofusque": "ofuscar",
    "ofusquei": "ofuscar",
    "ofusqueis": "ofuscar",
    "ofusquem": "ofuscar",
    "ofusquemo": "ofuscar",
    "ofusquemos": "ofuscar",
    "ofusques": "ofuscar",
    "ofíases": "ofíase",
    "ofícios": "ofício",
    "ofídia": "ofídio",
    "ofídias": "ofídio",
    "ofídica": "ofídico",
    "ofídicas": "ofídico",
    "ofídicos": "ofídico",
    "ofídios": "ofídio",
    "ogdoedrias": "ogdoedria",
    "ogdoédrica": "ogdoédrico",
    "ogdoédricas": "ogdoédrico",
    "ogdoédricos": "ogdoédrico",
    "ogivada": "ogivado",
    "ogivadas": "ogivado",
    "ogivados": "ogivado",
    "ogivais": "ogival",
    "ogivas": "ogiva",
    "ohms": "ohm",
    "ohmímetros": "ohmímetro",
    "oidiomicoses": "oidiomicose",
    "oira": "oirar",
    "oirada": "oirar",
    "oiradas": "oirar",
    "oirado": "oirar",
    "oirados": "oirar",
    "oirai": "oirar",
    "oirais": "oirar",
    "oiram": "oirar",
    "oiramas": "oirama",
    "oiramo": "oirar",
    "oiramos": "oirar",
    "oirando": "oirar",
    "oirara": "oirar",
    "oiraram": "oirar",
    "oiraras": "oirar",
    "oirarde": "oirar",
    "oirardes": "oirar",
    "oirare": "oirar",
    "oirarei": "oirar",
    "oirareis": "oirar",
    "oirarem": "oirar",
    "oiraremos": "oirar",
    "oirares": "oirar",
    "oiraria": "oirar",
    "oirariam": "oirar",
    "oirarias": "oirar",
    "oirarmo": "oirar",
    "oirarmos": "oirar",
    "oirará": "oirar",
    "oirarás": "oirar",
    "oirarão": "oirar",
    "oiraríamos": "oirar",
    "oiraríeis": "oirar",
    "oiras": "oirar",
    "oirasse": "oirar",
    "oirassem": "oirar",
    "oirasses": "oirar",
    "oiraste": "oirar",
    "oirastes": "oirar",
    "oirava": "oirar",
    "oiravam": "oirar",
    "oiravas": "oirar",
    "oire": "oirar",
    "oiregas": "oirega",
    "oirei": "oirar",
    "oireis": "oirar",
    "oireja": "oirejar",
    "oirejada": "oirejar",
    "oirejadas": "oirejar",
    "oirejado": "oirejar",
    "oirejados": "oirejar",
    "oirejai": "oirejar",
    "oirejais": "oirejar",
    "oirejam": "oirejar",
    "oirejamo": "oirejar",
    "oirejamos": "oirejar",
    "oirejando": "oirejar",
    "oirejara": "oirejar",
    "oirejaram": "oirejar",
    "oirejaras": "oirejar",
    "oirejarde": "oirejar",
    "oirejardes": "oirejar",
    "oirejare": "oirejar",
    "oirejarei": "oirejar",
    "oirejareis": "oirejar",
    "oirejarem": "oirejar",
    "oirejaremos": "oirejar",
    "oirejares": "oirejar",
    "oirejaria": "oirejar",
    "oirejariam": "oirejar",
    "oirejarias": "oirejar",
    "oirejarmo": "oirejar",
    "oirejarmos": "oirejar",
    "oirejará": "oirejar",
    "oirejarás": "oirejar",
    "oirejarão": "oirejar",
    "oirejaríamos": "oirejar",
    "oirejaríeis": "oirejar",
    "oirejas": "oirejar",
    "oirejasse": "oirejar",
    "oirejassem": "oirejar",
    "oirejasses": "oirejar",
    "oirejaste": "oirejar",
    "oirejastes": "oirejar",
    "oirejava": "oirejar",
    "oirejavam": "oirejar",
    "oirejavas": "oirejar",
    "oireje": "oirejar",
    "oirejei": "oirejar",
    "oirejeis": "oirejar",
    "oirejem": "oirejar",
    "oirejemo": "oirejar",
    "oirejemos": "oirejar",
    "oirejes": "oirejar",
    "oirejo": "oirejar",
    "oirejou": "oirejar",
    "oirejá": "oirejar",
    "oirejámo": "oirejar",
    "oirejámos": "oirejar",
    "oirejáramo": "oirejar",
    "oirejáramos": "oirejar",
    "oirejárei": "oirejar",
    "oirejáreis": "oirejar",
    "oirejásseis": "oirejar",
    "oirejássemos": "oirejar",
    "oirejávamo": "oirejar",
    "oirejávamos": "oirejar",
    "oirejávei": "oirejar",
    "oirejáveis": "oirejar",
    "oirem": "oirar",
    "oiremo": "oirar",
    "oiremos": "oirar",
    "oires": "oirar",
    "oirice": "oiriçar",
    "oiricei": "oiriçar",
    "oiriceiras": "oiriceira",
    "oiriceis": "oiriçar",
    "oiricem": "oiriçar",
    "oiricemo": "oiriçar",
    "oiricemos": "oiriçar",
    "oirices": "oiriçar",
    "oiriça": "oiriçar",
    "oiriçada": "oiriçar",
    "oiriçadas": "oiriçar",
    "oiriçado": "oiriçar",
    "oiriçados": "oiriçar",
    "oiriçai": "oiriçar",
    "oiriçais": "oiriçar",
    "oiriçam": "oiriçar",
    "oiriçamo": "oiriçar",
    "oiriçamos": "oiriçar",
    "oiriçando": "oiriçar",
    "oiriçara": "oiriçar",
    "oiriçaram": "oiriçar",
    "oiriçaras": "oiriçar",
    "oiriçarde": "oiriçar",
    "oiriçardes": "oiriçar",
    "oiriçare": "oiriçar",
    "oiriçarei": "oiriçar",
    "oiriçareis": "oiriçar",
    "oiriçarem": "oiriçar",
    "oiriçaremos": "oiriçar",
    "oiriçares": "oiriçar",
    "oiriçaria": "oiriçar",
    "oiriçariam": "oiriçar",
    "oiriçarias": "oiriçar",
    "oiriçarmo": "oiriçar",
    "oiriçarmos": "oiriçar",
    "oiriçará": "oiriçar",
    "oiriçarás": "oiriçar",
    "oiriçarão": "oiriçar",
    "oiriçaríamos": "oiriçar",
    "oiriçaríeis": "oiriçar",
    "oiriças": "oiriçar",
    "oiriçasse": "oiriçar",
    "oiriçassem": "oiriçar",
    "oiriçasses": "oiriçar",
    "oiriçaste": "oiriçar",
    "oiriçastes": "oiriçar",
    "oiriçava": "oiriçar",
    "oiriçavam": "oiriçar",
    "oiriçavas": "oiriçar",
    "oiriço": "oiriçar",
    "oiriços": "oiriço",
    "oiriçou": "oiriçar",
    "oiriçá": "oiriçar",
    "oiriçámo": "oiriçar",
    "oiriçámos": "oiriçar",
    "oiriçáramo": "oiriçar",
    "oiriçáramos": "oiriçar",
    "oiriçárei": "oiriçar",
    "oiriçáreis": "oiriçar",
    "oiriçásseis": "oiriçar",
    "oiriçássemos": "oiriçar",
    "oiriçávamo": "oiriçar",
    "oiriçávamos": "oiriçar",
    "oiriçávei": "oiriçar",
    "oiriçáveis": "oiriçar",
    "oiro": "oirar",
    "oiros": "oiro",
    "oirou": "oirar",
    "oirá": "oirar",
    "oirámo": "oirar",
    "oirámos": "oirar",
    "oiráramo": "oirar",
    "oiráramos": "oirar",
    "oirárei": "oirar",
    "oiráreis": "oirar",
    "oirásseis": "oirar",
    "oirássemos": "oirar",
    "oirávamo": "oirar",
    "oirávamos": "oirar",
    "oirávei": "oirar",
    "oiráveis": "oirar",
    "ois": "oil",
    "oitava": "oitavo",
    "oitavada": "oitavar",
    "oitavadas": "oitavar",
    "oitavado": "oitavar",
    "oitavados": "oitavar",
    "oitavai": "oitavar",
    "oitavais": "oitavar",
    "oitavam": "oitavar",
    "oitavamo": "oitavar",
    "oitavamos": "oitavar",
    "oitavando": "oitavar",
    "oitavara": "oitavar",
    "oitavaram": "oitavar",
    "oitavaras": "oitavar",
    "oitavarde": "oitavar",
    "oitavardes": "oitavar",
    "oitavare": "oitavar",
    "oitavarei": "oitavar",
    "oitavareis": "oitavar",
    "oitavarem": "oitavar",
    "oitavaremos": "oitavar",
    "oitavares": "oitavar",
    "oitavaria": "oitavar",
    "oitavariam": "oitavar",
    "oitavarias": "oitavar",
    "oitavarmo": "oitavar",
    "oitavarmos": "oitavar",
    "oitavará": "oitavar",
    "oitavarás": "oitavar",
    "oitavarão": "oitavar",
    "oitavaríamos": "oitavar",
    "oitavaríeis": "oitavar",
    "oitavas": "oitavo",
    "oitavasse": "oitavar",
    "oitavassem": "oitavar",
    "oitavasses": "oitavar",
    "oitavaste": "oitavar",
    "oitavastes": "oitavar",
    "oitavava": "oitavar",
    "oitavavam": "oitavar",
    "oitavavas": "oitavar",
    "oitave": "oitavar",
    "oitavei": "oitavar",
    "oitaveis": "oitavar",
    "oitavem": "oitavar",
    "oitavemo": "oitavar",
    "oitavemos": "oitavar",
    "oitaves": "oitavar",
    "oitavo": "oitavar",
    "oitavos": "oitavo",
    "oitavou": "oitavar",
    "oitavá": "oitavar",
    "oitavámo": "oitavar",
    "oitavámos": "oitavar",
    "oitaváramo": "oitavar",
    "oitaváramos": "oitavar",
    "oitavárei": "oitavar",
    "oitaváreis": "oitavar",
    "oitavários": "oitavário",
    "oitavásseis": "oitavar",
    "oitavássemos": "oitavar",
    "oitavávamo": "oitavar",
    "oitavávamos": "oitavar",
    "oitavávei": "oitavar",
    "oitaváveis": "oitavar",
    "oiteiristas": "oiteirista",
    "oiteiros": "oiteiro",
    "oitocentas": "oitocentos",
    "oitocentistas": "oitocentista",
    "oiça": "ouvir",
    "oiçais": "ouvir",
    "oiçam": "ouvir",
    "oiçamo": "ouvir",
    "oiçamos": "ouvir",
    "oiças": "ouvir",
    "oiço": "ouvir",
    "ojerizas": "ojeriza",
    "olaias": "olaia",
    "olarias": "olaria",
    "olas": "ola",
    "oldemburguesa": "oldemburguês",
    "oldemburguesas": "oldemburguês",
    "oldemburgueses": "oldemburguês",
    "oleacidímetros": "oleacidímetro",
    "oleada": "olear",
    "oleadas": "olear",
    "oleado": "olear",
    "oleados": "olear",
    "oleagina": "oleaginar",
    "oleaginada": "oleaginar",
    "oleaginadas": "oleaginar",
    "oleaginado": "oleaginar",
    "oleaginados": "oleaginar",
    "oleaginai": "oleaginar",
    "oleaginais": "oleaginar",
    "oleaginam": "oleaginar",
    "oleaginamo": "oleaginar",
    "oleaginamos": "oleaginar",
    "oleaginando": "oleaginar",
    "oleaginara": "oleaginar",
    "oleaginaram": "oleaginar",
    "oleaginaras": "oleaginar",
    "oleaginarde": "oleaginar",
    "oleaginardes": "oleaginar",
    "oleaginare": "oleaginar",
    "oleaginarei": "oleaginar",
    "oleaginareis": "oleaginar",
    "oleaginarem": "oleaginar",
    "oleaginaremos": "oleaginar",
    "oleaginares": "oleaginar",
    "oleaginaria": "oleaginar",
    "oleaginariam": "oleaginar",
    "oleaginarias": "oleaginar",
    "oleaginarmo": "oleaginar",
    "oleaginarmos": "oleaginar",
    "oleaginará": "oleaginar",
    "oleaginarás": "oleaginar",
    "oleaginarão": "oleaginar",
    "oleaginaríamos": "oleaginar",
    "oleaginaríeis": "oleaginar",
    "oleaginas": "oleaginar",
    "oleaginasse": "oleaginar",
    "oleaginassem": "oleaginar",
    "oleaginasses": "oleaginar",
    "oleaginaste": "oleaginar",
    "oleaginastes": "oleaginar",
    "oleaginava": "oleaginar",
    "oleaginavam": "oleaginar",
    "oleaginavas": "oleaginar",
    "oleagine": "oleaginar",
    "oleaginei": "oleaginar",
    "oleagineis": "oleaginar",
    "oleaginem": "oleaginar",
    "oleaginemo": "oleaginar",
    "oleaginemos": "oleaginar",
    "oleagines": "oleaginar",
    "oleagino": "oleaginar",
    "oleaginosa": "oleaginoso",
    "oleaginosas": "oleaginoso",
    "oleaginosos": "oleaginoso",
    "oleaginou": "oleaginar",
    "oleaginá": "oleaginar",
    "oleaginámo": "oleaginar",
    "oleaginámos": "oleaginar",
    "oleagináramo": "oleaginar",
    "oleagináramos": "oleaginar",
    "oleaginárei": "oleaginar",
    "oleagináreis": "oleaginar",
    "oleaginásseis": "oleaginar",
    "oleaginássemos": "oleaginar",
    "oleaginávamo": "oleaginar",
    "oleaginávamos": "oleaginar",
    "oleaginávei": "oleaginar",
    "oleagináveis": "oleaginar",
    "oleagínea": "oleagíneo",
    "oleagíneas": "oleagíneo",
    "oleagíneos": "oleagíneo",
    "oleai": "olear",
    "oleais": "olear",
    "oleamo": "olear",
    "oleamos": "olear",
    "oleando": "olear",
    "oleandros": "oleandro",
    "oleara": "olear",
    "olearam": "olear",
    "olearas": "olear",
    "olearde": "olear",
    "oleardes": "olear",
    "oleare": "olear",
    "olearei": "olear",
    "oleareis": "olear",
    "olearem": "olear",
    "olearemos": "olear",
    "oleares": "olear",
    "olearia": "olear",
    "oleariam": "olear",
    "olearias": "olearia",
    "olearmo": "olear",
    "olearmos": "olear",
    "oleará": "olear",
    "olearás": "olear",
    "olearão": "olear",
    "olearíamos": "olear",
    "olearíeis": "olear",
    "oleasse": "olear",
    "oleassem": "olear",
    "oleasses": "olear",
    "oleaste": "olear",
    "oleastes": "olear",
    "oleastros": "oleastro",
    "oleatos": "oleato",
    "oleava": "olear",
    "oleavam": "olear",
    "oleavas": "olear",
    "olecraniana": "olecraniano",
    "olecranianas": "olecraniano",
    "olecranianos": "olecraniano",
    "olecranos": "olecrano",
    "olecrânios": "olecrânio",
    "oleei": "olear",
    "oleeis": "olear",
    "oleemo": "olear",
    "oleemos": "olear",
    "oleenta": "oleento",
    "oleentas": "oleento",
    "oleentos": "oleento",
    "olefinas": "olefina",
    "oleia": "olear",
    "oleiam": "olear",
    "oleias": "olear",
    "oleica": "oleico",
    "oleicas": "oleico",
    "oleicos": "oleico",
    "oleicultora": "oleicultor",
    "oleicultoras": "oleicultor",
    "oleicultores": "oleicultor",
    "oleiculturas": "oleicultura",
    "oleie": "olear",
    "oleiem": "olear",
    "oleies": "olear",
    "oleificantes": "oleificante",
    "oleifoliada": "oleifoliado",
    "oleifoliadas": "oleifoliado",
    "oleifoliados": "oleifoliado",
    "oleifólia": "oleifólio",
    "oleifólias": "oleifólio",
    "oleifólios": "oleifólio",
    "oleio": "olear",
    "oleira": "oleiro",
    "oleiras": "oleiro",
    "oleiros": "oleiro",
    "olentes": "olente",
    "oleodutos": "oleoduto",
    "oleografias": "oleografia",
    "oleogravuras": "oleogravura",
    "oleográfica": "oleográfico",
    "oleográficas": "oleográfico",
    "oleográficos": "oleográfico",
    "oleogéneses": "oleogénese",
    "oleolados": "oleolado",
    "oleolatos": "oleolato",
    "oleorresinas": "oleorresina",
    "oleorresinosa": "oleorresinoso",
    "oleorresinosas": "oleorresinoso",
    "oleorresinosos": "oleorresinoso",
    "oleosa": "oleoso",
    "oleosas": "oleoso",
    "oleosidades": "oleosidade",
    "oleosos": "oleoso",
    "oleou": "olear",
    "oleá": "olear",
    "oleácea": "oleáceo",
    "oleáceas": "oleáceo",
    "oleáceos": "oleáceo",
    "oleámo": "olear",
    "oleámos": "olear",
    "oleáramo": "olear",
    "oleáramos": "olear",
    "oleárei": "olear",
    "oleáreis": "olear",
    "oleásseis": "olear",
    "oleássemos": "olear",
    "oleávamo": "olear",
    "oleávamos": "olear",
    "oleávei": "olear",
    "oleáveis": "oleável",
    "oleícolas": "oleícola",
    "oleífera": "oleífero",
    "oleíferas": "oleífero",
    "oleíferos": "oleífero",
    "oleígena": "oleígeno",
    "oleígenas": "oleígeno",
    "oleígenos": "oleígeno",
    "oleínas": "oleína",
    "oleóis": "oleol",
    "oleómetros": "oleómetro",
    "olfacta": "olfactar",
    "olfactada": "olfactar",
    "olfactadas": "olfactar",
    "olfactado": "olfactar",
    "olfactados": "olfactar",
    "olfactai": "olfactar",
    "olfactais": "olfactar",
    "olfactam": "olfactar",
    "olfactamo": "olfactar",
    "olfactamos": "olfactar",
    "olfactando": "olfactar",
    "olfactara": "olfactar",
    "olfactaram": "olfactar",
    "olfactaras": "olfactar",
    "olfactarde": "olfactar",
    "olfactardes": "olfactar",
    "olfactare": "olfactar",
    "olfactarei": "olfactar",
    "olfactareis": "olfactar",
    "olfactarem": "olfactar",
    "olfactaremos": "olfactar",
    "olfactares": "olfactar",
    "olfactaria": "olfactar",
    "olfactariam": "olfactar",
    "olfactarias": "olfactar",
    "olfactarmo": "olfactar",
    "olfactarmos": "olfactar",
    "olfactará": "olfactar",
    "olfactarás": "olfactar",
    "olfactarão": "olfactar",
    "olfactaríamos": "olfactar",
    "olfactaríeis": "olfactar",
    "olfactas": "olfactar",
    "olfactasse": "olfactar",
    "olfactassem": "olfactar",
    "olfactasses": "olfactar",
    "olfactaste": "olfactar",
    "olfactastes": "olfactar",
    "olfactava": "olfactar",
    "olfactavam": "olfactar",
    "olfactavas": "olfactar",
    "olfacte": "olfactar",
    "olfactei": "olfactar",
    "olfacteis": "olfactar",
    "olfactem": "olfactar",
    "olfactemo": "olfactar",
    "olfactemos": "olfactar",
    "olfactes": "olfactar",
    "olfactiva": "olfactivo",
    "olfactivas": "olfactivo",
    "olfactivos": "olfactivo",
    "olfacto": "olfactar",
    "olfactometrias": "olfactometria",
    "olfactos": "olfacto",
    "olfactou": "olfactar",
    "olfactá": "olfactar",
    "olfactámo": "olfactar",
    "olfactámos": "olfactar",
    "olfactáramo": "olfactar",
    "olfactáramos": "olfactar",
    "olfactárei": "olfactar",
    "olfactáreis": "olfactar",
    "olfactásseis": "olfactar",
    "olfactássemos": "olfactar",
    "olfactávamo": "olfactar",
    "olfactávamos": "olfactar",
    "olfactávei": "olfactar",
    "olfactáveis": "olfactar",
    "olfactómetros": "olfactómetro",
    "olfacções": "olfacção",
    "olfáctiva": "olfáctivo",
    "olfáctivas": "olfáctivo",
    "olfáctivos": "olfáctivo",
    "olgas": "olga",
    "olha": "olhar",
    "olhada": "olhar",
    "olhadas": "olhar",
    "olhadelas": "olhadela",
    "olhado": "olhar",
    "olhadora": "olhador",
    "olhadoras": "olhador",
    "olhadores": "olhador",
    "olhados": "olhar",
    "olhaduras": "olhadura",
    "olhai": "olhar",
    "olhais": "olhar",
    "olhalva": "olhalvo",
    "olhalvas": "olhalvo",
    "olhalvos": "olhalvo",
    "olham": "olhar",
    "olhamentos": "olhamento",
    "olhamo": "olhar",
    "olhamos": "olhar",
    "olhando": "olhar",
    "olhanenses": "olhanense",
    "olhara": "olhar",
    "olharam": "olhar",
    "olharas": "olhar",
    "olharde": "olhar",
    "olhardes": "olhar",
    "olhare": "olhar",
    "olharei": "olhar",
    "olhareis": "olhar",
    "olharem": "olhar",
    "olharemos": "olhar",
    "olhares": "olhar",
    "olharia": "olhar",
    "olhariam": "olhar",
    "olharias": "olhar",
    "olharmo": "olhar",
    "olharmos": "olhar",
    "olharzinho": "olhar",
    "olharzinhos": "olhar",
    "olharzito": "olhar",
    "olharzitos": "olhar",
    "olhará": "olhar",
    "olharás": "olhar",
    "olharão": "olhar",
    "olharíamos": "olhar",
    "olharíeis": "olhar",
    "olhas": "olhar",
    "olhasse": "olhar",
    "olhassem": "olhar",
    "olhasses": "olhar",
    "olhaste": "olhar",
    "olhastes": "olhar",
    "olhava": "olhar",
    "olhavam": "olhar",
    "olhavas": "olhar",
    "olhe": "olhar",
    "olhei": "olhar",
    "olheira": "olheiro",
    "olheiras": "olheiro",
    "olheirenta": "olheirento",
    "olheirentas": "olheirento",
    "olheirentos": "olheirento",
    "olheirona": "olheirão",
    "olheironas": "olheirão",
    "olheiros": "olheiro",
    "olheirões": "olheirão",
    "olheis": "olhar",
    "olhem": "olhar",
    "olhemo": "olhar",
    "olhemos": "olhar",
    "olhenta": "olhento",
    "olhentas": "olhento",
    "olhentos": "olhento",
    "olhes": "olhar",
    "olhetados": "olhetado",
    "olhetes": "olhete",
    "olhibranca": "olhibranco",
    "olhibrancas": "olhibranco",
    "olhibrancos": "olhibranco",
    "olhinegra": "olhinegro",
    "olhinegras": "olhinegro",
    "olhinegros": "olhinegro",
    "olhinho": "olho",
    "olhinhos": "olho",
    "olhipreta": "olhipreto",
    "olhipretas": "olhipreto",
    "olhipretos": "olhipreto",
    "olhito": "olho",
    "olhitos": "olho",
    "olhizaina": "olhizaino",
    "olhizainas": "olhizaino",
    "olhizainos": "olhizaino",
    "olhizarca": "olhizarco",
    "olhizarcas": "olhizarco",
    "olhizarcos": "olhizarco",
    "olho": "olhar",
    "olhos": "olho",
    "olhou": "olhar",
    "olhozinho": "olho",
    "olhozinhos": "olho",
    "olhozito": "olho",
    "olhozitos": "olho",
    "olhuda": "olhudo",
    "olhudas": "olhudo",
    "olhudos": "olhudo",
    "olhá": "olhar",
    "olhámo": "olhar",
    "olhámos": "olhar",
    "olháramo": "olhar",
    "olháramos": "olhar",
    "olhárei": "olhar",
    "olháreis": "olhar",
    "olhásseis": "olhar",
    "olhássemos": "olhar",
    "olhávamo": "olhar",
    "olhávamos": "olhar",
    "olhávei": "olhar",
    "olháveis": "olhar",
    "olhão": "olho",
    "olhões": "olho",
    "olifantes": "olifante",
    "oligarcas": "oligarca",
    "oligarquias": "oligarquia",
    "oligistos": "oligisto",
    "oligoclásios": "oligoclásio",
    "oligocénica": "oligocénico",
    "oligocénicas": "oligocénico",
    "oligocénicos": "oligocénico",
    "oligofrenias": "oligofrenia",
    "oligofrénica": "oligofrénico",
    "oligofrénicas": "oligofrénico",
    "oligofrénicos": "oligofrénico",
    "oligolecítica": "oligolecítico",
    "oligolecíticas": "oligolecítico",
    "oligolecíticos": "oligolecítico",
    "oligolécita": "oligolécito",
    "oligolécitas": "oligolécito",
    "oligolécitos": "oligolécito",
    "oligoquetas": "oligoqueta",
    "oligárquica": "oligárquico",
    "oligárquicas": "oligárquico",
    "oligárquicos": "oligárquico",
    "oligúrias": "oligúria",
    "olimpiana": "olimpiano",
    "olimpianas": "olimpiano",
    "olimpianos": "olimpiano",
    "olimpos": "olimpo",
    "olimpíadas": "olimpíada",
    "olimpíades": "olimpíade",
    "olissiponenses": "olissiponense",
    "olivais": "olival",
    "olivares": "olivar",
    "olivas": "oliva",
    "olivedos": "olivedo",
    "oliveirais": "oliveiral",
    "oliveiras": "oliveira",
    "oliveirinha": "oliveira",
    "oliveirinhas": "oliveira",
    "oliveirita": "oliveira",
    "oliveiritas": "oliveira",
    "olivicultora": "olivicultor",
    "olivicultoras": "olivicultor",
    "olivicultores": "olivicultor",
    "oliviculturas": "olivicultura",
    "olivilas": "olivila",
    "olivinas": "olivina",
    "olivácea": "oliváceo",
    "oliváceas": "oliváceo",
    "oliváceos": "oliváceo",
    "olivária": "olivário",
    "olivárias": "olivário",
    "olivários": "olivário",
    "olivífera": "olivífero",
    "olivíferas": "olivífero",
    "olivíferos": "olivífero",
    "olmedais": "olmedal",
    "olmedos": "olmedo",
    "olmeiros": "olmeiro",
    "olmos": "olmo",
    "olores": "olor",
    "olorosa": "oloroso",
    "olorosas": "oloroso",
    "olorosos": "oloroso",
    "olvida": "olvidar",
    "olvidada": "olvidar",
    "olvidadas": "olvidar",
    "olvidado": "olvidar",
    "olvidados": "olvidar",
    "olvidai": "olvidar",
    "olvidais": "olvidar",
    "olvidam": "olvidar",
    "olvidamo": "olvidar",
    "olvidamos": "olvidar",
    "olvidando": "olvidar",
    "olvidara": "olvidar",
    "olvidaram": "olvidar",
    "olvidaras": "olvidar",
    "olvidarde": "olvidar",
    "olvidardes": "olvidar",
    "olvidare": "olvidar",
    "olvidarei": "olvidar",
    "olvidareis": "olvidar",
    "olvidarem": "olvidar",
    "olvidaremos": "olvidar",
    "olvidares": "olvidar",
    "olvidaria": "olvidar",
    "olvidariam": "olvidar",
    "olvidarias": "olvidar",
    "olvidarmo": "olvidar",
    "olvidarmos": "olvidar",
    "olvidará": "olvidar",
    "olvidarás": "olvidar",
    "olvidarão": "olvidar",
    "olvidaríamos": "olvidar",
    "olvidaríeis": "olvidar",
    "olvidas": "olvidar",
    "olvidasse": "olvidar",
    "olvidassem": "olvidar",
    "olvidasses": "olvidar",
    "olvidaste": "olvidar",
    "olvidastes": "olvidar",
    "olvidava": "olvidar",
    "olvidavam": "olvidar",
    "olvidavas": "olvidar",
    "olvide": "olvidar",
    "olvidei": "olvidar",
    "olvideis": "olvidar",
    "olvidem": "olvidar",
    "olvidemo": "olvidar",
    "olvidemos": "olvidar",
    "olvides": "olvidar",
    "olvido": "olvidar",
    "olvidos": "olvido",
    "olvidou": "olvidar",
    "olvidá": "olvidar",
    "olvidámo": "olvidar",
    "olvidámos": "olvidar",
    "olvidáramo": "olvidar",
    "olvidáramos": "olvidar",
    "olvidárei": "olvidar",
    "olvidáreis": "olvidar",
    "olvidásseis": "olvidar",
    "olvidássemos": "olvidar",
    "olvidávamo": "olvidar",
    "olvidávamos": "olvidar",
    "olvidávei": "olvidar",
    "olvidáveis": "olvidável",
    "olás": "olá",
    "olências": "olência",
    "olíbanos": "olíbano",
    "olímpia": "olímpio",
    "olímpias": "olímpio",
    "olímpica": "olímpico",
    "olímpicas": "olímpico",
    "olímpicos": "olímpico",
    "olímpios": "olímpio",
    "olívea": "olíveo",
    "olíveas": "olíveo",
    "olíveos": "olíveo",
    "omagras": "omagra",
    "omalgias": "omalgia",
    "ombreada": "ombrear",
    "ombreadas": "ombrear",
    "ombreado": "ombrear",
    "ombreados": "ombrear",
    "ombreai": "ombrear",
    "ombreais": "ombrear",
    "ombreamo": "ombrear",
    "ombreamos": "ombrear",
    "ombreando": "ombrear",
    "ombreara": "ombrear",
    "ombrearam": "ombrear",
    "ombrearas": "ombrear",
    "ombreardes": "ombrear",
    "ombrearei": "ombrear",
    "ombreareis": "ombrear",
    "ombrearem": "ombrear",
    "ombrearemos": "ombrear",
    "ombreares": "ombrear",
    "ombrearia": "ombrear",
    "ombreariam": "ombrear",
    "ombrearias": "ombrear",
    "ombrearmo": "ombrear",
    "ombrearmos": "ombrear",
    "ombreará": "ombrear",
    "ombrearás": "ombrear",
    "ombrearão": "ombrear",
    "ombrearíamos": "ombrear",
    "ombrearíeis": "ombrear",
    "ombreasse": "ombrear",
    "ombreassem": "ombrear",
    "ombreasses": "ombrear",
    "ombreaste": "ombrear",
    "ombreastes": "ombrear",
    "ombreava": "ombrear",
    "ombreavam": "ombrear",
    "ombreavas": "ombrear",
    "ombreei": "ombrear",
    "ombreeis": "ombrear",
    "ombreemo": "ombrear",
    "ombreemos": "ombrear",
    "ombreia": "ombrear",
    "ombreiam": "ombrear",
    "ombreias": "ombrear",
    "ombreie": "ombrear",
    "ombreiem": "ombrear",
    "ombreies": "ombrear",
    "ombreio": "ombrear",
    "ombreiras": "ombreira",
    "ombreou": "ombrear",
    "ombreámo": "ombrear",
    "ombreámos": "ombrear",
    "ombreáramo": "ombrear",
    "ombreáramos": "ombrear",
    "ombreáreis": "ombrear",
    "ombreásseis": "ombrear",
    "ombreássemos": "ombrear",
    "ombreávamo": "ombrear",
    "ombreávamos": "ombrear",
    "ombreáveis": "ombrear",
    "ombros": "ombro",
    "omeletas": "omeleta",
    "omeletes": "omelete",
    "omina": "ominar",
    "ominada": "ominar",
    "ominadas": "ominar",
    "ominado": "ominar",
    "ominados": "ominar",
    "ominai": "ominar",
    "ominais": "ominar",
    "ominam": "ominar",
    "ominamo": "ominar",
    "ominamos": "ominar",
    "ominando": "ominar",
    "ominara": "ominar",
    "ominaram": "ominar",
    "ominaras": "ominar",
    "ominarde": "ominar",
    "ominardes": "ominar",
    "ominare": "ominar",
    "ominarei": "ominar",
    "ominareis": "ominar",
    "ominarem": "ominar",
    "ominaremos": "ominar",
    "ominares": "ominar",
    "ominaria": "ominar",
    "ominariam": "ominar",
    "ominarias": "ominar",
    "ominarmo": "ominar",
    "ominarmos": "ominar",
    "ominará": "ominar",
    "ominarás": "ominar",
    "ominarão": "ominar",
    "ominaríamos": "ominar",
    "ominaríeis": "ominar",
    "ominas": "ominar",
    "ominasse": "ominar",
    "ominassem": "ominar",
    "ominasses": "ominar",
    "ominaste": "ominar",
    "ominastes": "ominar",
    "ominava": "ominar",
    "ominavam": "ominar",
    "ominavas": "ominar",
    "omine": "ominar",
    "ominei": "ominar",
    "omineis": "ominar",
    "ominem": "ominar",
    "ominemo": "ominar",
    "ominemos": "ominar",
    "omines": "ominar",
    "omino": "ominar",
    "ominosa": "ominoso",
    "ominosas": "ominoso",
    "ominosos": "ominoso",
    "ominou": "ominar",
    "ominá": "ominar",
    "ominámo": "ominar",
    "ominámos": "ominar",
    "omináramo": "ominar",
    "omináramos": "ominar",
    "ominárei": "ominar",
    "omináreis": "ominar",
    "ominásseis": "ominar",
    "ominássemos": "ominar",
    "ominávamo": "ominar",
    "ominávamos": "ominar",
    "ominávei": "ominar",
    "omináveis": "ominar",
    "omiris": "omiri",
    "omissa": "omisso",
    "omissas": "omisso",
    "omissos": "omisso",
    "omissória": "omissório",
    "omissórias": "omissório",
    "omissórios": "omissório",
    "omissões": "omissão",
    "omita": "omitir",
    "omitais": "omitir",
    "omitam": "omitir",
    "omitamo": "omitir",
    "omitamos": "omitir",
    "omitas": "omitir",
    "omite": "omitir",
    "omitem": "omitir",
    "omites": "omitir",
    "omiti": "omitir",
    "omitia": "omitir",
    "omitiam": "omitir",
    "omitias": "omitir",
    "omitida": "omitir",
    "omitidas": "omitir",
    "omitido": "omitir",
    "omitidos": "omitir",
    "omitimo": "omitir",
    "omitimos": "omitir",
    "omitindo": "omitir",
    "omitira": "omitir",
    "omitiram": "omitir",
    "omitiras": "omitir",
    "omitirde": "omitir",
    "omitirdes": "omitir",
    "omitire": "omitir",
    "omitirei": "omitir",
    "omitireis": "omitir",
    "omitirem": "omitir",
    "omitiremos": "omitir",
    "omitires": "omitir",
    "omitiria": "omitir",
    "omitiriam": "omitir",
    "omitirias": "omitir",
    "omitirmo": "omitir",
    "omitirmos": "omitir",
    "omitirá": "omitir",
    "omitirás": "omitir",
    "omitirão": "omitir",
    "omitiríamos": "omitir",
    "omitiríeis": "omitir",
    "omitis": "omitir",
    "omitisse": "omitir",
    "omitissem": "omitir",
    "omitisses": "omitir",
    "omitiste": "omitir",
    "omitistes": "omitir",
    "omitiu": "omitir",
    "omito": "omitir",
    "omitíamo": "omitir",
    "omitíamos": "omitir",
    "omitíei": "omitir",
    "omitíeis": "omitir",
    "omitíramo": "omitir",
    "omitíramos": "omitir",
    "omitírei": "omitir",
    "omitíreis": "omitir",
    "omitísseis": "omitir",
    "omitíssemos": "omitir",
    "omitíveis": "omitível",
    "omnicolora": "omnicolor",
    "omnicoloras": "omnicolor",
    "omnicolores": "omnicolor",
    "omniformes": "omniforme",
    "omnifulgentes": "omnifulgente",
    "omnigénera": "omnigénero",
    "omnigéneras": "omnigénero",
    "omnigéneros": "omnigénero",
    "omnilingue": "omnilíngue",
    "omnilingues": "omnilíngue",
    "omnilíngues": "omnilíngue",
    "omniparentes": "omniparente",
    "omnipatentes": "omnipatente",
    "omnipessoais": "omnipessoal",
    "omnipotentes": "omnipotente",
    "omnipotências": "omnipotência",
    "omnipresentes": "omnipresente",
    "omnipresenças": "omnipresença",
    "omniscientes": "omnisciente",
    "omnisciências": "omnisciência",
    "omnímoda": "omnímodo",
    "omnímodas": "omnímodo",
    "omnímodos": "omnímodo",
    "omnípara": "omníparo",
    "omníparas": "omníparo",
    "omníparos": "omníparo",
    "omnívoma": "omnívomo",
    "omnívomas": "omnívomo",
    "omnívomos": "omnívomo",
    "omnívora": "omnívoro",
    "omnívoras": "omnívoro",
    "omnívoros": "omnívoro",
    "omoclaviculares": "omoclavicular",
    "omofagias": "omofagia",
    "omoletas": "omoleta",
    "omoletes": "omolete",
    "omoplatas": "omoplata",
    "omosternos": "omosterno",
    "omófaga": "omófago",
    "omófagas": "omófago",
    "omófagos": "omófago",
    "onagatas": "onagata",
    "onagro": "ónagro",
    "onagros": "ónagro",
    "onagráceas": "onagrácea",
    "onanismos": "onanismo",
    "onanistas": "onanista",
    "oncologias": "oncologia",
    "oncologistas": "oncologista",
    "oncológica": "oncológico",
    "oncológicas": "oncológico",
    "oncológicos": "oncológico",
    "oncotomias": "oncotomia",
    "oncotómica": "oncotómico",
    "oncotómicas": "oncotómico",
    "oncotómicos": "oncotómico",
    "ondas": "onda",
    "ondazinha": "onda",
    "ondazinhas": "onda",
    "ondazita": "onda",
    "ondazitas": "onda",
    "ondeada": "ondear",
    "ondeadas": "ondear",
    "ondeado": "ondear",
    "ondeados": "ondear",
    "ondeai": "ondear",
    "ondeais": "ondear",
    "ondeamentos": "ondeamento",
    "ondeamo": "ondear",
    "ondeamos": "ondear",
    "ondeando": "ondear",
    "ondeantes": "ondeante",
    "ondeara": "ondear",
    "ondearam": "ondear",
    "ondearas": "ondear",
    "ondearde": "ondear",
    "ondeardes": "ondear",
    "ondeare": "ondear",
    "ondearei": "ondear",
    "ondeareis": "ondear",
    "ondearem": "ondear",
    "ondearemos": "ondear",
    "ondeares": "ondear",
    "ondearia": "ondear",
    "ondeariam": "ondear",
    "ondearias": "ondear",
    "ondearmo": "ondear",
    "ondearmos": "ondear",
    "ondeará": "ondear",
    "ondearás": "ondear",
    "ondearão": "ondear",
    "ondearíamos": "ondear",
    "ondearíeis": "ondear",
    "ondeasse": "ondear",
    "ondeassem": "ondear",
    "ondeasses": "ondear",
    "ondeaste": "ondear",
    "ondeastes": "ondear",
    "ondeava": "ondear",
    "ondeavam": "ondear",
    "ondeavas": "ondear",
    "ondeei": "ondear",
    "ondeeis": "ondear",
    "ondeemo": "ondear",
    "ondeemos": "ondear",
    "ondeia": "ondear",
    "ondeiam": "ondear",
    "ondeias": "ondear",
    "ondeie": "ondear",
    "ondeiem": "ondear",
    "ondeies": "ondear",
    "ondeio": "ondear",
    "ondeja": "ondejar",
    "ondejada": "ondejar",
    "ondejadas": "ondejar",
    "ondejado": "ondejar",
    "ondejados": "ondejar",
    "ondejai": "ondejar",
    "ondejais": "ondejar",
    "ondejam": "ondejar",
    "ondejamo": "ondejar",
    "ondejamos": "ondejar",
    "ondejando": "ondejar",
    "ondejantes": "ondejante",
    "ondejara": "ondejar",
    "ondejaram": "ondejar",
    "ondejaras": "ondejar",
    "ondejarde": "ondejar",
    "ondejardes": "ondejar",
    "ondejare": "ondejar",
    "ondejarei": "ondejar",
    "ondejareis": "ondejar",
    "ondejarem": "ondejar",
    "ondejaremos": "ondejar",
    "ondejares": "ondejar",
    "ondejaria": "ondejar",
    "ondejariam": "ondejar",
    "ondejarias": "ondejar",
    "ondejarmo": "ondejar",
    "ondejarmos": "ondejar",
    "ondejará": "ondejar",
    "ondejarás": "ondejar",
    "ondejarão": "ondejar",
    "ondejaríamos": "ondejar",
    "ondejaríeis": "ondejar",
    "ondejas": "ondejar",
    "ondejasse": "ondejar",
    "ondejassem": "ondejar",
    "ondejasses": "ondejar",
    "ondejaste": "ondejar",
    "ondejastes": "ondejar",
    "ondejava": "ondejar",
    "ondejavam": "ondejar",
    "ondejavas": "ondejar",
    "ondeje": "ondejar",
    "ondejei": "ondejar",
    "ondejeis": "ondejar",
    "ondejem": "ondejar",
    "ondejemo": "ondejar",
    "ondejemos": "ondejar",
    "ondejes": "ondejar",
    "ondejo": "ondejar",
    "ondejou": "ondejar",
    "ondejá": "ondejar",
    "ondejámo": "ondejar",
    "ondejámos": "ondejar",
    "ondejáramo": "ondejar",
    "ondejáramos": "ondejar",
    "ondejárei": "ondejar",
    "ondejáreis": "ondejar",
    "ondejásseis": "ondejar",
    "ondejássemos": "ondejar",
    "ondejávamo": "ondejar",
    "ondejávamos": "ondejar",
    "ondejávei": "ondejar",
    "ondejáveis": "ondejar",
    "ondeou": "ondear",
    "ondeá": "ondear",
    "ondeámo": "ondear",
    "ondeámos": "ondear",
    "ondeáramo": "ondear",
    "ondeáramos": "ondear",
    "ondeárei": "ondear",
    "ondeáreis": "ondear",
    "ondeásseis": "ondear",
    "ondeássemos": "ondear",
    "ondeávamo": "ondear",
    "ondeávamos": "ondear",
    "ondeávei": "ondear",
    "ondeáveis": "ondear",
    "ondinha": "onda",
    "ondinhas": "onda",
    "ondinismos": "ondinismo",
    "ondita": "onda",
    "onditas": "onda",
    "ondula": "ondular",
    "ondulada": "ondular",
    "onduladas": "ondular",
    "ondulado": "ondular",
    "ondulados": "ondular",
    "ondulai": "ondular",
    "ondulais": "ondular",
    "ondulam": "ondular",
    "ondulamo": "ondular",
    "ondulamos": "ondular",
    "ondulando": "ondular",
    "ondulantes": "ondulante",
    "ondulara": "ondular",
    "ondularam": "ondular",
    "ondularas": "ondular",
    "ondulardes": "ondular",
    "ondularei": "ondular",
    "ondulareis": "ondular",
    "ondularem": "ondular",
    "ondularemos": "ondular",
    "ondulares": "ondular",
    "ondularia": "ondular",
    "ondulariam": "ondular",
    "ondularias": "ondular",
    "ondularmo": "ondular",
    "ondularmos": "ondular",
    "ondulará": "ondular",
    "ondularás": "ondular",
    "ondularão": "ondular",
    "ondularíamos": "ondular",
    "ondularíeis": "ondular",
    "ondulas": "ondular",
    "ondulasse": "ondular",
    "ondulassem": "ondular",
    "ondulasses": "ondular",
    "ondulaste": "ondular",
    "ondulastes": "ondular",
    "ondulatória": "ondulatório",
    "ondulatórias": "ondulatório",
    "ondulatórios": "ondulatório",
    "ondulava": "ondular",
    "ondulavam": "ondular",
    "ondulavas": "ondular",
    "ondulações": "ondulação",
    "ondule": "ondular",
    "ondulei": "ondular",
    "onduleis": "ondular",
    "ondulem": "ondular",
    "ondulemo": "ondular",
    "ondulemos": "ondular",
    "ondules": "ondular",
    "ondulo": "ondular",
    "ondulosa": "onduloso",
    "ondulosas": "onduloso",
    "ondulosos": "onduloso",
    "ondulou": "ondular",
    "ondulámo": "ondular",
    "ondulámos": "ondular",
    "onduláramo": "ondular",
    "onduláramos": "ondular",
    "onduláreis": "ondular",
    "ondulásseis": "ondular",
    "ondulássemos": "ondular",
    "ondulávamo": "ondular",
    "ondulávamos": "ondular",
    "onduláveis": "ondulável",
    "ondímetros": "ondímetro",
    "onera": "onerar",
    "onerada": "onerar",
    "oneradas": "onerar",
    "onerado": "onerar",
    "onerados": "onerar",
    "onerai": "onerar",
    "onerais": "onerar",
    "oneram": "onerar",
    "oneramo": "onerar",
    "oneramos": "onerar",
    "onerando": "onerar",
    "onerantes": "onerante",
    "onerara": "onerar",
    "oneraram": "onerar",
    "oneraras": "onerar",
    "onerarde": "onerar",
    "onerardes": "onerar",
    "onerare": "onerar",
    "onerarei": "onerar",
    "onerareis": "onerar",
    "onerarem": "onerar",
    "oneraremos": "onerar",
    "onerares": "onerar",
    "oneraria": "onerar",
    "onerariam": "onerar",
    "onerarias": "onerar",
    "onerarmo": "onerar",
    "onerarmos": "onerar",
    "onerará": "onerar",
    "onerarás": "onerar",
    "onerarão": "onerar",
    "oneraríamos": "onerar",
    "oneraríeis": "onerar",
    "oneras": "onerar",
    "onerasse": "onerar",
    "onerassem": "onerar",
    "onerasses": "onerar",
    "oneraste": "onerar",
    "onerastes": "onerar",
    "onerava": "onerar",
    "oneravam": "onerar",
    "oneravas": "onerar",
    "onere": "onerar",
    "onerei": "onerar",
    "onereis": "onerar",
    "onerem": "onerar",
    "oneremo": "onerar",
    "oneremos": "onerar",
    "oneres": "onerar",
    "onero": "onerar",
    "onerosa": "oneroso",
    "onerosas": "oneroso",
    "onerosidades": "onerosidade",
    "onerosos": "oneroso",
    "onerou": "onerar",
    "onerá": "onerar",
    "onerámo": "onerar",
    "onerámos": "onerar",
    "oneráramo": "onerar",
    "oneráramos": "onerar",
    "onerárei": "onerar",
    "oneráreis": "onerar",
    "onerária": "onerário",
    "onerárias": "onerário",
    "onerários": "onerário",
    "onerásseis": "onerar",
    "onerássemos": "onerar",
    "onerávamo": "onerar",
    "onerávamos": "onerar",
    "onerávei": "onerar",
    "oneráveis": "onerável",
    "onfalites": "onfalite",
    "onfalorragias": "onfalorragia",
    "onfalotomias": "onfalotomia",
    "onfalópaga": "onfalópago",
    "onfalópagas": "onfalópago",
    "onfalópagos": "onfalópago",
    "ongletes": "onglete",
    "onicofagias": "onicofagia",
    "onicófaga": "onicófago",
    "onicófagas": "onicófago",
    "onicófagos": "onicófago",
    "onicóforos": "onicóforo",
    "oninas": "onina",
    "oniomanias": "oniomania",
    "onirismos": "onirismo",
    "onirocricias": "onirocricia",
    "onirogmos": "onirogmo",
    "onirologias": "onirologia",
    "oniromancias": "oniromancia",
    "oniromantes": "oniromante",
    "oniscídeos": "oniscídeo",
    "onomancias": "onomancia",
    "onomatologias": "onomatologia",
    "onomatológica": "onomatológico",
    "onomatológicas": "onomatológico",
    "onomatológicos": "onomatológico",
    "onomatomancias": "onomatomancia",
    "onomatomanias": "onomatomania",
    "onomatopaica": "onomatopaico",
    "onomatopaicas": "onomatopaico",
    "onomatopaicos": "onomatopaico",
    "onomatopeias": "onomatopeia",
    "onomatopeica": "onomatopeico",
    "onomatopeicas": "onomatopeico",
    "onomatopeicos": "onomatopeico",
    "onomatóloga": "onomatólogo",
    "onomatólogas": "onomatólogo",
    "onomatólogos": "onomatólogo",
    "onomástica": "onomástico",
    "onomásticas": "onomástico",
    "onomásticos": "onomástico",
    "onomática": "onomático",
    "onomáticas": "onomático",
    "onomáticos": "onomático",
    "ontogenias": "ontogenia",
    "ontogonias": "ontogonia",
    "ontogéneses": "ontogénese",
    "ontogénica": "ontogénico",
    "ontogénicas": "ontogénico",
    "ontogénicos": "ontogénico",
    "ontogónica": "ontogónico",
    "ontogónicas": "ontogónico",
    "ontogónicos": "ontogónico",
    "ontologias": "ontologia",
    "ontologistas": "ontologista",
    "ontológica": "ontológico",
    "ontológicas": "ontológico",
    "ontológicos": "ontológico",
    "ontófaga": "ontófago",
    "ontófagas": "ontófago",
    "ontófagos": "ontófago",
    "ontófila": "ontófilo",
    "ontófilas": "ontófilo",
    "ontófilos": "ontófilo",
    "onusta": "onusto",
    "onustas": "onusto",
    "onustos": "onusto",
    "onzena": "onzeno",
    "onzenada": "onzenar",
    "onzenadas": "onzenar",
    "onzenado": "onzenar",
    "onzenados": "onzenar",
    "onzenai": "onzenar",
    "onzenais": "onzenar",
    "onzenam": "onzenar",
    "onzenamo": "onzenar",
    "onzenamos": "onzenar",
    "onzenando": "onzenar",
    "onzenara": "onzenar",
    "onzenaram": "onzenar",
    "onzenaras": "onzenar",
    "onzenardes": "onzenar",
    "onzenarei": "onzenar",
    "onzenareis": "onzenar",
    "onzenarem": "onzenar",
    "onzenaremos": "onzenar",
    "onzenares": "onzenar",
    "onzenaria": "onzenar",
    "onzenariam": "onzenar",
    "onzenarias": "onzenar",
    "onzenarmo": "onzenar",
    "onzenarmos": "onzenar",
    "onzenará": "onzenar",
    "onzenarás": "onzenar",
    "onzenarão": "onzenar",
    "onzenaríamos": "onzenar",
    "onzenaríeis": "onzenar",
    "onzenas": "onzeno",
    "onzenasse": "onzenar",
    "onzenassem": "onzenar",
    "onzenasses": "onzenar",
    "onzenaste": "onzenar",
    "onzenastes": "onzenar",
    "onzenava": "onzenar",
    "onzenavam": "onzenar",
    "onzenavas": "onzenar",
    "onzene": "onzenar",
    "onzenei": "onzenar",
    "onzeneira": "onzeneiro",
    "onzeneiras": "onzeneiro",
    "onzeneiros": "onzeneiro",
    "onzeneis": "onzenar",
    "onzenem": "onzenar",
    "onzenemo": "onzenar",
    "onzenemos": "onzenar",
    "onzenes": "onzenar",
    "onzenices": "onzenice",
    "onzeno": "onzenar",
    "onzenos": "onzeno",
    "onzenou": "onzenar",
    "onzenámo": "onzenar",
    "onzenámos": "onzenar",
    "onzenáramo": "onzenar",
    "onzenáramos": "onzenar",
    "onzenáreis": "onzenar",
    "onzenária": "onzenário",
    "onzenárias": "onzenário",
    "onzenários": "onzenário",
    "onzenásseis": "onzenar",
    "onzenássemos": "onzenar",
    "onzenávamo": "onzenar",
    "onzenávamos": "onzenar",
    "onzenáveis": "onzenar",
    "onças": "onça",
    "onírica": "onírico",
    "oníricas": "onírico",
    "oníricos": "onírico",
    "oníscidas": "oníscida",
    "oo": "o",
    "ooblastos": "ooblasto",
    "ooforectomias": "ooforectomia",
    "oogenias": "oogenia",
    "oogéneses": "oogénese",
    "oogónias": "oogónia",
    "oogónios": "oogónio",
    "oologias": "oologia",
    "oolítica": "oolítico",
    "oolíticas": "oolítico",
    "oolíticos": "oolítico",
    "oomancias": "oomancia",
    "ooscopias": "ooscopia",
    "ooses": "oose",
    "oosferas": "oosfera",
    "ootecas": "ooteca",
    "opa": "opar",
    "opaca": "opaco",
    "opacas": "opaco",
    "opacidades": "opacidade",
    "opacificações": "opacificação",
    "opacos": "opaco",
    "opada": "opar",
    "opadas": "opar",
    "opado": "opar",
    "opados": "opar",
    "opai": "opar",
    "opais": "opar",
    "opalandas": "opalanda",
    "opalas": "opala",
    "opalesce": "opalescer",
    "opalescei": "opalescer",
    "opalesceis": "opalescer",
    "opalescem": "opalescer",
    "opalescemo": "opalescer",
    "opalescemos": "opalescer",
    "opalescendo": "opalescer",
    "opalescentes": "opalescente",
    "opalescera": "opalescer",
    "opalesceram": "opalescer",
    "opalesceras": "opalescer",
    "opalescerde": "opalescer",
    "opalescerdes": "opalescer",
    "opalescere": "opalescer",
    "opalescerei": "opalescer",
    "opalescereis": "opalescer",
    "opalescerem": "opalescer",
    "opalesceremos": "opalescer",
    "opalesceres": "opalescer",
    "opalesceria": "opalescer",
    "opalesceriam": "opalescer",
    "opalescerias": "opalescer",
    "opalescermo": "opalescer",
    "opalescermos": "opalescer",
    "opalescerá": "opalescer",
    "opalescerás": "opalescer",
    "opalescerão": "opalescer",
    "opalesceríamos": "opalescer",
    "opalesceríeis": "opalescer",
    "opalesces": "opalescer",
    "opalescesse": "opalescer",
    "opalescessem": "opalescer",
    "opalescesses": "opalescer",
    "opalesceste": "opalescer",
    "opalescestes": "opalescer",
    "opalesceu": "opalescer",
    "opalesci": "opalescer",
    "opalescia": "opalescer",
    "opalesciam": "opalescer",
    "opalescias": "opalescer",
    "opalescida": "opalescer",
    "opalescidas": "opalescer",
    "opalescido": "opalescer",
    "opalescidos": "opalescer",
    "opalescê": "opalescer",
    "opalescências": "opalescência",
    "opalescêramo": "opalescer",
    "opalescêramos": "opalescer",
    "opalescêrei": "opalescer",
    "opalescêreis": "opalescer",
    "opalescêsseis": "opalescer",
    "opalescêssemos": "opalescer",
    "opalescíamo": "opalescer",
    "opalescíamos": "opalescer",
    "opalescíei": "opalescer",
    "opalescíeis": "opalescer",
    "opalesça": "opalescer",
    "opalesçais": "opalescer",
    "opalesçam": "opalescer",
    "opalesçamo": "opalescer",
    "opalesçamos": "opalescer",
    "opalesças": "opalescer",
    "opalesço": "opalescer",
    "opalina": "opalino",
    "opalinas": "opalino",
    "opalinidades": "opalinidade",
    "opalinos": "opalino",
    "opalinídeos": "opalinídeo",
    "opaliza": "opalizar",
    "opalizada": "opalizar",
    "opalizadas": "opalizar",
    "opalizado": "opalizar",
    "opalizados": "opalizar",
    "opalizai": "opalizar",
    "opalizais": "opalizar",
    "opalizam": "opalizar",
    "opalizamo": "opalizar",
    "opalizamos": "opalizar",
    "opalizando": "opalizar",
    "opalizara": "opalizar",
    "opalizaram": "opalizar",
    "opalizaras": "opalizar",
    "opalizarde": "opalizar",
    "opalizardes": "opalizar",
    "opalizare": "opalizar",
    "opalizarei": "opalizar",
    "opalizareis": "opalizar",
    "opalizarem": "opalizar",
    "opalizaremos": "opalizar",
    "opalizares": "opalizar",
    "opalizaria": "opalizar",
    "opalizariam": "opalizar",
    "opalizarias": "opalizar",
    "opalizarmo": "opalizar",
    "opalizarmos": "opalizar",
    "opalizará": "opalizar",
    "opalizarás": "opalizar",
    "opalizarão": "opalizar",
    "opalizaríamos": "opalizar",
    "opalizaríeis": "opalizar",
    "opalizas": "opalizar",
    "opalizasse": "opalizar",
    "opalizassem": "opalizar",
    "opalizasses": "opalizar",
    "opalizaste": "opalizar",
    "opalizastes": "opalizar",
    "opalizava": "opalizar",
    "opalizavam": "opalizar",
    "opalizavas": "opalizar",
    "opalizações": "opalização",
    "opalize": "opalizar",
    "opalizei": "opalizar",
    "opalizeis": "opalizar",
    "opalizem": "opalizar",
    "opalizemo": "opalizar",
    "opalizemos": "opalizar",
    "opalizes": "opalizar",
    "opalizo": "opalizar",
    "opalizou": "opalizar",
    "opalizá": "opalizar",
    "opalizámo": "opalizar",
    "opalizámos": "opalizar",
    "opalizáramo": "opalizar",
    "opalizáramos": "opalizar",
    "opalizárei": "opalizar",
    "opalizáreis": "opalizar",
    "opalizásseis": "opalizar",
    "opalizássemos": "opalizar",
    "opalizávamo": "opalizar",
    "opalizávamos": "opalizar",
    "opalizávei": "opalizar",
    "opalizáveis": "opalizar",
    "opam": "opar",
    "opamo": "opar",
    "opamos": "opar",
    "opando": "opar",
    "opara": "opar",
    "oparam": "opar",
    "oparas": "opar",
    "oparde": "opar",
    "opardes": "opar",
    "opare": "opar",
    "oparei": "opar",
    "opareis": "opar",
    "oparem": "opar",
    "oparemos": "opar",
    "opares": "opar",
    "oparia": "opar",
    "opariam": "opar",
    "oparias": "opar",
    "oparmo": "opar",
    "oparmos": "opar",
    "opará": "opar",
    "oparás": "opar",
    "oparão": "opar",
    "oparíamos": "opar",
    "oparíeis": "opar",
    "opas": "opar",
    "opasse": "opar",
    "opassem": "opar",
    "opasses": "opar",
    "opaste": "opar",
    "opastes": "opar",
    "opava": "opar",
    "opavam": "opar",
    "opavas": "opar",
    "opcionais": "opcional",
    "ope": "opar",
    "opei": "opar",
    "opeis": "opar",
    "opem": "opar",
    "opemo": "opar",
    "opemos": "opar",
    "opens": "open",
    "opera": "operar",
    "operacionais": "operacional",
    "operacionalidades": "operacionalidade",
    "operacionalizações": "operacionalização",
    "operada": "operar",
    "operadas": "operar",
    "operado": "operar",
    "operadora": "operador",
    "operadoras": "operador",
    "operadores": "operador",
    "operados": "operar",
    "operagens": "operagem",
    "operai": "operar",
    "operais": "operar",
    "operam": "operar",
    "operamo": "operar",
    "operamos": "operar",
    "operando": "operar",
    "operantes": "operante",
    "operara": "operar",
    "operaram": "operar",
    "operaras": "operar",
    "operarde": "operar",
    "operardes": "operar",
    "operare": "operar",
    "operarei": "operar",
    "operareis": "operar",
    "operarem": "operar",
    "operaremos": "operar",
    "operares": "operar",
    "operaria": "operar",
    "operariados": "operariado",
    "operariam": "operar",
    "operarias": "operar",
    "operarmo": "operar",
    "operarmos": "operar",
    "operará": "operar",
    "operarás": "operar",
    "operarão": "operar",
    "operaríamos": "operar",
    "operaríeis": "operar",
    "operas": "operar",
    "operasse": "operar",
    "operassem": "operar",
    "operasses": "operar",
    "operaste": "operar",
    "operastes": "operar",
    "operativa": "operativo",
    "operativas": "operativo",
    "operativos": "operativo",
    "operatória": "operatório",
    "operatórias": "operatório",
    "operatórios": "operatório",
    "operava": "operar",
    "operavam": "operar",
    "operavas": "operar",
    "operaçãozinha": "operação",
    "operaçãozita": "operação",
    "operações": "operação",
    "operaçõezinhas": "operação",
    "operaçõezitas": "operação",
    "operculada": "operculado",
    "operculadas": "operculado",
    "operculados": "operculado",
    "operculiformes": "operculiforme",
    "operculífera": "operculífero",
    "operculíferas": "operculífero",
    "operculíferos": "operculífero",
    "opere": "operar",
    "operei": "operar",
    "opereis": "operar",
    "operem": "operar",
    "operemo": "operar",
    "operemos": "operar",
    "operes": "operar",
    "operetas": "opereta",
    "operetistas": "operetista",
    "opero": "operar",
    "operosa": "operoso",
    "operosas": "operoso",
    "operosidades": "operosidade",
    "operosos": "operoso",
    "operou": "operar",
    "operá": "operar",
    "operámo": "operar",
    "operámos": "operar",
    "operáramo": "operar",
    "operáramos": "operar",
    "operárei": "operar",
    "operáreis": "operar",
    "operária": "operário",
    "operárias": "operário",
    "operários": "operário",
    "operásseis": "operar",
    "operássemos": "operar",
    "operática": "operático",
    "operáticas": "operático",
    "operáticos": "operático",
    "operávamo": "operar",
    "operávamos": "operar",
    "operávei": "operar",
    "operáveis": "operável",
    "opes": "opar",
    "opia": "opiar",
    "opiada": "opiar",
    "opiadas": "opiar",
    "opiado": "opiar",
    "opiados": "opiar",
    "opiai": "opiar",
    "opiais": "opiar",
    "opiam": "opiar",
    "opiamo": "opiar",
    "opiamos": "opiar",
    "opiando": "opiar",
    "opiara": "opiar",
    "opiaram": "opiar",
    "opiaras": "opiar",
    "opiarde": "opiar",
    "opiardes": "opiar",
    "opiare": "opiar",
    "opiarei": "opiar",
    "opiareis": "opiar",
    "opiarem": "opiar",
    "opiaremos": "opiar",
    "opiares": "opiar",
    "opiaria": "opiar",
    "opiariam": "opiar",
    "opiarias": "opiar",
    "opiarmo": "opiar",
    "opiarmos": "opiar",
    "opiará": "opiar",
    "opiarás": "opiar",
    "opiarão": "opiar",
    "opiaríamos": "opiar",
    "opiaríeis": "opiar",
    "opias": "opiar",
    "opiasse": "opiar",
    "opiassem": "opiar",
    "opiasses": "opiar",
    "opiaste": "opiar",
    "opiastes": "opiar",
    "opiatos": "opiato",
    "opiava": "opiar",
    "opiavam": "opiar",
    "opiavas": "opiar",
    "opie": "opiar",
    "opiei": "opiar",
    "opieis": "opiar",
    "opiem": "opiar",
    "opiemo": "opiar",
    "opiemos": "opiar",
    "opies": "opiar",
    "opifícios": "opifício",
    "opila": "opilar",
    "opilada": "opilar",
    "opiladas": "opilar",
    "opilado": "opilar",
    "opilados": "opilar",
    "opilai": "opilar",
    "opilais": "opilar",
    "opilam": "opilar",
    "opilamo": "opilar",
    "opilamos": "opilar",
    "opilando": "opilar",
    "opilantes": "opilante",
    "opilara": "opilar",
    "opilaram": "opilar",
    "opilaras": "opilar",
    "opilarde": "opilar",
    "opilardes": "opilar",
    "opilare": "opilar",
    "opilarei": "opilar",
    "opilareis": "opilar",
    "opilarem": "opilar",
    "opilaremos": "opilar",
    "opilares": "opilar",
    "opilaria": "opilar",
    "opilariam": "opilar",
    "opilarias": "opilar",
    "opilarmo": "opilar",
    "opilarmos": "opilar",
    "opilará": "opilar",
    "opilarás": "opilar",
    "opilarão": "opilar",
    "opilaríamos": "opilar",
    "opilaríeis": "opilar",
    "opilas": "opilar",
    "opilasse": "opilar",
    "opilassem": "opilar",
    "opilasses": "opilar",
    "opilaste": "opilar",
    "opilastes": "opilar",
    "opilativa": "opilativo",
    "opilativas": "opilativo",
    "opilativos": "opilativo",
    "opilava": "opilar",
    "opilavam": "opilar",
    "opilavas": "opilar",
    "opilações": "opilação",
    "opile": "opilar",
    "opilei": "opilar",
    "opileis": "opilar",
    "opilem": "opilar",
    "opilemo": "opilar",
    "opilemos": "opilar",
    "opiles": "opilar",
    "opilo": "opilar",
    "opilou": "opilar",
    "opilá": "opilar",
    "opilámo": "opilar",
    "opilámos": "opilar",
    "opiláramo": "opilar",
    "opiláramos": "opilar",
    "opilárei": "opilar",
    "opiláreis": "opilar",
    "opilásseis": "opilar",
    "opilássemos": "opilar",
    "opilávamo": "opilar",
    "opilávamos": "opilar",
    "opilávei": "opilar",
    "opiláveis": "opilar",
    "opima": "opimo",
    "opimas": "opimo",
    "opimos": "opimo",
    "opina": "opinar",
    "opinada": "opinar",
    "opinadas": "opinar",
    "opinado": "opinar",
    "opinadora": "opinador",
    "opinadoras": "opinador",
    "opinadores": "opinador",
    "opinados": "opinar",
    "opinai": "opinar",
    "opinais": "opinar",
    "opinam": "opinar",
    "opinamo": "opinar",
    "opinamos": "opinar",
    "opinando": "opinar",
    "opinantes": "opinante",
    "opinara": "opinar",
    "opinaram": "opinar",
    "opinaras": "opinar",
    "opinarde": "opinar",
    "opinardes": "opinar",
    "opinare": "opinar",
    "opinarei": "opinar",
    "opinareis": "opinar",
    "opinarem": "opinar",
    "opinaremos": "opinar",
    "opinares": "opinar",
    "opinaria": "opinar",
    "opinariam": "opinar",
    "opinarias": "opinar",
    "opinarmo": "opinar",
    "opinarmos": "opinar",
    "opinará": "opinar",
    "opinarás": "opinar",
    "opinarão": "opinar",
    "opinaríamos": "opinar",
    "opinaríeis": "opinar",
    "opinas": "opinar",
    "opinasse": "opinar",
    "opinassem": "opinar",
    "opinasses": "opinar",
    "opinaste": "opinar",
    "opinastes": "opinar",
    "opinativa": "opinativo",
    "opinativas": "opinativo",
    "opinativos": "opinativo",
    "opinava": "opinar",
    "opinavam": "opinar",
    "opinavas": "opinar",
    "opine": "opinar",
    "opinei": "opinar",
    "opineis": "opinar",
    "opinem": "opinar",
    "opinemo": "opinar",
    "opinemos": "opinar",
    "opines": "opinar",
    "opinionários": "opinionário",
    "opiniática": "opiniático",
    "opiniáticas": "opiniático",
    "opiniáticos": "opiniático",
    "opiniões": "opinião",
    "opino": "opinar",
    "opinosa": "opinoso",
    "opinosas": "opinoso",
    "opinosos": "opinoso",
    "opinou": "opinar",
    "opiná": "opinar",
    "opinámo": "opinar",
    "opinámos": "opinar",
    "opináramo": "opinar",
    "opináramos": "opinar",
    "opinárei": "opinar",
    "opináreis": "opinar",
    "opinásseis": "opinar",
    "opinássemos": "opinar",
    "opinávamo": "opinar",
    "opinávamos": "opinar",
    "opinávei": "opinar",
    "opináveis": "opinável",
    "opio": "opiar",
    "opiofagias": "opiofagia",
    "opiologias": "opiologia",
    "opiomanias": "opiomania",
    "opiou": "opiar",
    "opistobrânquios": "opistobrânquio",
    "opistocélica": "opistocélico",
    "opistocélicas": "opistocélico",
    "opistocélicos": "opistocélico",
    "opistografias": "opistografia",
    "opistogástrica": "opistogástrico",
    "opistogástricas": "opistogástrico",
    "opistogástricos": "opistogástrico",
    "opistopárias": "opistopária",
    "opistóglifas": "opistóglifa",
    "opistógrafa": "opistógrafo",
    "opistógrafas": "opistógrafo",
    "opistógrafos": "opistógrafo",
    "opistóticos": "opistótico",
    "opiá": "opiar",
    "opiácea": "opiáceo",
    "opiáceas": "opiáceo",
    "opiáceos": "opiáceo",
    "opiámo": "opiar",
    "opiámos": "opiar",
    "opiáramo": "opiar",
    "opiáramos": "opiar",
    "opiárei": "opiar",
    "opiáreis": "opiar",
    "opiásseis": "opiar",
    "opiássemos": "opiar",
    "opiávamo": "opiar",
    "opiávamos": "opiar",
    "opiávei": "opiar",
    "opiáveis": "opiar",
    "opiófaga": "opiófago",
    "opiófagas": "opiófago",
    "opiófagos": "opiófago",
    "opióloga": "opiólogo",
    "opiólogas": "opiólogo",
    "opiólogos": "opiólogo",
    "opiómana": "opiómano",
    "opiómanas": "opiómano",
    "opiómanos": "opiómano",
    "opo": "opar",
    "opobalsameiras": "opobalsameira",
    "opobálsamos": "opobálsamo",
    "opocéfalos": "opocéfalo",
    "opodeldoques": "opodeldoque",
    "opoentes": "opoente",
    "opomo": "opor",
    "opomos": "opor",
    "oponde": "opor",
    "opondes": "opor",
    "opondo": "opor",
    "oponentes": "oponente",
    "oponha": "opor",
    "oponhais": "opor",
    "oponham": "opor",
    "oponhamo": "opor",
    "oponhamos": "opor",
    "oponhas": "opor",
    "oponho": "opor",
    "oponibilidades": "oponibilidade",
    "oponíveis": "oponível",
    "opopânaces": "opopânace",
    "oporde": "opor",
    "opordes": "opor",
    "opore": "opor",
    "oporei": "opor",
    "oporeis": "opor",
    "oporem": "opor",
    "oporemos": "opor",
    "opores": "opor",
    "oporia": "opor",
    "oporiam": "opor",
    "oporias": "opor",
    "opormo": "opor",
    "opormos": "opor",
    "oportuna": "oportuno",
    "oportunas": "oportuno",
    "oportunidades": "oportunidade",
    "oportunismos": "oportunismo",
    "oportunistas": "oportunista",
    "oportunos": "oportuno",
    "oportuníssima": "oportuno",
    "oportuníssimas": "oportuno",
    "oportuníssimo": "oportuno",
    "oportuníssimos": "oportuno",
    "oporá": "opor",
    "oporás": "opor",
    "oporão": "opor",
    "oporíamos": "opor",
    "oporíeis": "opor",
    "oposicionistas": "oposicionista",
    "opositipétala": "opositipétalo",
    "opositipétalas": "opositipétalo",
    "opositipétalos": "opositipétalo",
    "opositiva": "opositivo",
    "opositivas": "opositivo",
    "opositivos": "opositivo",
    "opositora": "opositor",
    "opositoras": "opositor",
    "opositores": "opositor",
    "oposições": "oposição",
    "opossuns": "opossum",
    "oposta": "oposto",
    "opostas": "oposto",
    "oposto": "opor",
    "opostos": "oposto",
    "opoterapias": "opoterapia",
    "opoterápica": "opoterápico",
    "opoterápicas": "opoterápico",
    "opoterápicos": "opoterápico",
    "opou": "opar",
    "opressa": "opresso",
    "opressas": "opresso",
    "opressiva": "opressivo",
    "opressivas": "opressivo",
    "opressivos": "opressivo",
    "opressora": "opressor",
    "opressoras": "opressor",
    "opressores": "opressor",
    "opressos": "opresso",
    "opressória": "opressório",
    "opressórias": "opressório",
    "opressórios": "opressório",
    "opressões": "opressão",
    "oprima": "oprimir",
    "oprimais": "oprimir",
    "oprimam": "oprimir",
    "oprimamo": "oprimir",
    "oprimamos": "oprimir",
    "oprimas": "oprimir",
    "oprime": "oprimir",
    "oprimem": "oprimir",
    "oprimentes": "oprimente",
    "oprimes": "oprimir",
    "oprimi": "oprimir",
    "oprimia": "oprimir",
    "oprimiam": "oprimir",
    "oprimias": "oprimir",
    "oprimida": "oprimir",
    "oprimidas": "oprimir",
    "oprimido": "oprimir",
    "oprimidos": "oprimir",
    "oprimidíssima": "oprimido",
    "oprimidíssimas": "oprimido",
    "oprimidíssimo": "oprimido",
    "oprimidíssimos": "oprimido",
    "oprimimo": "oprimir",
    "oprimimos": "oprimir",
    "oprimindo": "oprimir",
    "oprimira": "oprimir",
    "oprimiram": "oprimir",
    "oprimiras": "oprimir",
    "oprimirde": "oprimir",
    "oprimirdes": "oprimir",
    "oprimire": "oprimir",
    "oprimirei": "oprimir",
    "oprimireis": "oprimir",
    "oprimirem": "oprimir",
    "oprimiremos": "oprimir",
    "oprimires": "oprimir",
    "oprimiria": "oprimir",
    "oprimiriam": "oprimir",
    "oprimirias": "oprimir",
    "oprimirmo": "oprimir",
    "oprimirmos": "oprimir",
    "oprimirá": "oprimir",
    "oprimirás": "oprimir",
    "oprimirão": "oprimir",
    "oprimiríamos": "oprimir",
    "oprimiríeis": "oprimir",
    "oprimis": "oprimir",
    "oprimisse": "oprimir",
    "oprimissem": "oprimir",
    "oprimisses": "oprimir",
    "oprimiste": "oprimir",
    "oprimistes": "oprimir",
    "oprimiu": "oprimir",
    "oprimo": "oprimir",
    "oprimíamo": "oprimir",
    "oprimíamos": "oprimir",
    "oprimíei": "oprimir",
    "oprimíeis": "oprimir",
    "oprimíramo": "oprimir",
    "oprimíramos": "oprimir",
    "oprimírei": "oprimir",
    "oprimíreis": "oprimir",
    "oprimísseis": "oprimir",
    "oprimíssemos": "oprimir",
    "oprimíveis": "oprimível",
    "oprobriosa": "oprobrioso",
    "oprobriosas": "oprobrioso",
    "oprobriosos": "oprobrioso",
    "opróbrios": "opróbrio",
    "opsiometrias": "opsiometria",
    "opsiométrica": "opsiométrico",
    "opsiométricas": "opsiométrico",
    "opsiométricos": "opsiométrico",
    "opsiómetros": "opsiómetro",
    "opsígona": "opsígono",
    "opsígonas": "opsígono",
    "opsígonos": "opsígono",
    "opta": "optar",
    "optada": "optar",
    "optadas": "optar",
    "optado": "optar",
    "optados": "optar",
    "optai": "optar",
    "optais": "optar",
    "optam": "optar",
    "optamo": "optar",
    "optamos": "optar",
    "optando": "optar",
    "optantes": "optante",
    "optara": "optar",
    "optaram": "optar",
    "optaras": "optar",
    "optardes": "optar",
    "optarei": "optar",
    "optareis": "optar",
    "optarem": "optar",
    "optaremos": "optar",
    "optares": "optar",
    "optaria": "optar",
    "optariam": "optar",
    "optarias": "optar",
    "optarmo": "optar",
    "optarmos": "optar",
    "optará": "optar",
    "optarás": "optar",
    "optarão": "optar",
    "optaríamos": "optar",
    "optaríeis": "optar",
    "optas": "optar",
    "optasse": "optar",
    "optassem": "optar",
    "optasses": "optar",
    "optaste": "optar",
    "optastes": "optar",
    "optativa": "optativo",
    "optativas": "optativo",
    "optativos": "optativo",
    "optava": "optar",
    "optavam": "optar",
    "optavas": "optar",
    "optações": "optação",
    "opte": "optar",
    "optei": "optar",
    "opteis": "optar",
    "optem": "optar",
    "optemo": "optar",
    "optemos": "optar",
    "optes": "optar",
    "opticidades": "opticidade",
    "opticistas": "opticista",
    "opticometrias": "opticometria",
    "opticométrica": "opticométrico",
    "opticométricas": "opticométrico",
    "opticométricos": "opticométrico",
    "opticómetros": "opticómetro",
    "optimacias": "optimacia",
    "optimates": "optimate",
    "optimismos": "optimismo",
    "optimistas": "optimista",
    "optimiza": "optimizar",
    "optimizada": "optimizar",
    "optimizadas": "optimizar",
    "optimizado": "optimizar",
    "optimizados": "optimizar",
    "optimizai": "optimizar",
    "optimizais": "optimizar",
    "optimizam": "optimizar",
    "optimizamo": "optimizar",
    "optimizamos": "optimizar",
    "optimizando": "optimizar",
    "optimizara": "optimizar",
    "optimizaram": "optimizar",
    "optimizaras": "optimizar",
    "optimizarde": "optimizar",
    "optimizardes": "optimizar",
    "optimizare": "optimizar",
    "optimizarei": "optimizar",
    "optimizareis": "optimizar",
    "optimizarem": "optimizar",
    "optimizaremos": "optimizar",
    "optimizares": "optimizar",
    "optimizaria": "optimizar",
    "optimizariam": "optimizar",
    "optimizarias": "optimizar",
    "optimizarmo": "optimizar",
    "optimizarmos": "optimizar",
    "optimizará": "optimizar",
    "optimizarás": "optimizar",
    "optimizarão": "optimizar",
    "optimizaríamos": "optimizar",
    "optimizaríeis": "optimizar",
    "optimizas": "optimizar",
    "optimizasse": "optimizar",
    "optimizassem": "optimizar",
    "optimizasses": "optimizar",
    "optimizaste": "optimizar",
    "optimizastes": "optimizar",
    "optimizava": "optimizar",
    "optimizavam": "optimizar",
    "optimizavas": "optimizar",
    "optimizações": "optimização",
    "optimize": "optimizar",
    "optimizei": "optimizar",
    "optimizeis": "optimizar",
    "optimizem": "optimizar",
    "optimizemo": "optimizar",
    "optimizemos": "optimizar",
    "optimizes": "optimizar",
    "optimizo": "optimizar",
    "optimizou": "optimizar",
    "optimizá": "optimizar",
    "optimizámo": "optimizar",
    "optimizámos": "optimizar",
    "optimizáramo": "optimizar",
    "optimizáramos": "optimizar",
    "optimizárei": "optimizar",
    "optimizáreis": "optimizar",
    "optimizásseis": "optimizar",
    "optimizássemos": "optimizar",
    "optimizávamo": "optimizar",
    "optimizávamos": "optimizar",
    "optimizávei": "optimizar",
    "optimizáveis": "optimizável",
    "opto": "optar",
    "optofones": "optofone",
    "optografias": "optografia",
    "optometrias": "optometria",
    "optométrica": "optométrico",
    "optométricas": "optométrico",
    "optométricos": "optométrico",
    "optou": "optar",
    "optámo": "optar",
    "optámos": "optar",
    "optáramo": "optar",
    "optáramos": "optar",
    "optáreis": "optar",
    "optásseis": "optar",
    "optássemos": "optar",
    "optávamo": "optar",
    "optávamos": "optar",
    "optáveis": "optar",
    "optógrafos": "optógrafo",
    "optómetros": "optómetro",
    "opugna": "opugnar",
    "opugnada": "opugnar",
    "opugnadas": "opugnar",
    "opugnado": "opugnar",
    "opugnadora": "opugnador",
    "opugnadoras": "opugnador",
    "opugnadores": "opugnador",
    "opugnados": "opugnar",
    "opugnai": "opugnar",
    "opugnais": "opugnar",
    "opugnam": "opugnar",
    "opugnamo": "opugnar",
    "opugnamos": "opugnar",
    "opugnando": "opugnar",
    "opugnara": "opugnar",
    "opugnaram": "opugnar",
    "opugnaras": "opugnar",
    "opugnarde": "opugnar",
    "opugnardes": "opugnar",
    "opugnare": "opugnar",
    "opugnarei": "opugnar",
    "opugnareis": "opugnar",
    "opugnarem": "opugnar",
    "opugnaremos": "opugnar",
    "opugnares": "opugnar",
    "opugnaria": "opugnar",
    "opugnariam": "opugnar",
    "opugnarias": "opugnar",
    "opugnarmo": "opugnar",
    "opugnarmos": "opugnar",
    "opugnará": "opugnar",
    "opugnarás": "opugnar",
    "opugnarão": "opugnar",
    "opugnaríamos": "opugnar",
    "opugnaríeis": "opugnar",
    "opugnas": "opugnar",
    "opugnasse": "opugnar",
    "opugnassem": "opugnar",
    "opugnasses": "opugnar",
    "opugnaste": "opugnar",
    "opugnastes": "opugnar",
    "opugnava": "opugnar",
    "opugnavam": "opugnar",
    "opugnavas": "opugnar",
    "opugnações": "opugnação",
    "opugne": "opugnar",
    "opugnei": "opugnar",
    "opugneis": "opugnar",
    "opugnem": "opugnar",
    "opugnemo": "opugnar",
    "opugnemos": "opugnar",
    "opugnes": "opugnar",
    "opugno": "opugnar",
    "opugnou": "opugnar",
    "opugná": "opugnar",
    "opugnámo": "opugnar",
    "opugnámos": "opugnar",
    "opugnáramo": "opugnar",
    "opugnáramos": "opugnar",
    "opugnárei": "opugnar",
    "opugnáreis": "opugnar",
    "opugnásseis": "opugnar",
    "opugnássemos": "opugnar",
    "opugnávamo": "opugnar",
    "opugnávamos": "opugnar",
    "opugnávei": "opugnar",
    "opugnáveis": "opugnar",
    "opulenta": "opulento",
    "opulentada": "opulentar",
    "opulentadas": "opulentar",
    "opulentado": "opulentar",
    "opulentados": "opulentar",
    "opulentai": "opulentar",
    "opulentais": "opulentar",
    "opulentam": "opulentar",
    "opulentamo": "opulentar",
    "opulentamos": "opulentar",
    "opulentando": "opulentar",
    "opulentara": "opulentar",
    "opulentaram": "opulentar",
    "opulentaras": "opulentar",
    "opulentarde": "opulentar",
    "opulentardes": "opulentar",
    "opulentare": "opulentar",
    "opulentarei": "opulentar",
    "opulentareis": "opulentar",
    "opulentarem": "opulentar",
    "opulentaremos": "opulentar",
    "opulentares": "opulentar",
    "opulentaria": "opulentar",
    "opulentariam": "opulentar",
    "opulentarias": "opulentar",
    "opulentarmo": "opulentar",
    "opulentarmos": "opulentar",
    "opulentará": "opulentar",
    "opulentarás": "opulentar",
    "opulentarão": "opulentar",
    "opulentaríamos": "opulentar",
    "opulentaríeis": "opulentar",
    "opulentas": "opulento",
    "opulentasse": "opulentar",
    "opulentassem": "opulentar",
    "opulentasses": "opulentar",
    "opulentaste": "opulentar",
    "opulentastes": "opulentar",
    "opulentava": "opulentar",
    "opulentavam": "opulentar",
    "opulentavas": "opulentar",
    "opulente": "opulentar",
    "opulentei": "opulentar",
    "opulenteis": "opulentar",
    "opulentem": "opulentar",
    "opulentemo": "opulentar",
    "opulentemos": "opulentar",
    "opulentes": "opulentar",
    "opulento": "opulentar",
    "opulentos": "opulento",
    "opulentou": "opulentar",
    "opulentá": "opulentar",
    "opulentámo": "opulentar",
    "opulentámos": "opulentar",
    "opulentáramo": "opulentar",
    "opulentáramos": "opulentar",
    "opulentárei": "opulentar",
    "opulentáreis": "opulentar",
    "opulentásseis": "opulentar",
    "opulentássemos": "opulentar",
    "opulentávamo": "opulentar",
    "opulentávamos": "opulentar",
    "opulentávei": "opulentar",
    "opulentáveis": "opulentar",
    "opulências": "opulência",
    "opunha": "opor",
    "opunham": "opor",
    "opunhas": "opor",
    "opus": "opor",
    "opusemo": "opor",
    "opusemos": "opor",
    "opuser": "opor",
    "opusera": "opor",
    "opuseram": "opor",
    "opuseras": "opor",
    "opuserdes": "opor",
    "opuserem": "opor",
    "opuseres": "opor",
    "opusermos": "opor",
    "opusesse": "opor",
    "opusessem": "opor",
    "opusesses": "opor",
    "opuseste": "opor",
    "opusestes": "opor",
    "opuséramo": "opor",
    "opuséramos": "opor",
    "opusérei": "opor",
    "opuséreis": "opor",
    "opusésseis": "opor",
    "opuséssemos": "opor",
    "opá": "opar",
    "opámo": "opar",
    "opámos": "opar",
    "opáramo": "opar",
    "opáramos": "opar",
    "opárei": "opar",
    "opáreis": "opar",
    "opásseis": "opar",
    "opássemos": "opar",
    "opávamo": "opar",
    "opávamos": "opar",
    "opávei": "opar",
    "opáveis": "opar",
    "opções": "opção",
    "opérculos": "opérculo",
    "opífera": "opífero",
    "opíferas": "opífero",
    "opíferos": "opífero",
    "opípara": "opíparo",
    "opíparas": "opíparo",
    "opíparos": "opíparo",
    "opístions": "opístion",
    "opístios": "opístio",
    "opópanaxes": "opópanax",
    "opô": "opor",
    "opôs": "opor",
    "opõe": "opor",
    "opõem": "opor",
    "opões": "opor",
    "opúncias": "opúncia",
    "opúnhamo": "opor",
    "opúnhamos": "opor",
    "opúnhei": "opor",
    "opúnheis": "opor",
    "opúsculos": "opúsculo",
    "oque": "ocar",
    "oquei": "ocar",
    "oqueis": "ocar",
    "oquem": "ocar",
    "oquemo": "ocar",
    "oquemos": "ocar",
    "oques": "ocar",
    "ora": "orar",
    "oracionais": "oracional",
    "oraculares": "oracular",
    "oraculina": "oraculino",
    "oraculinas": "oraculino",
    "oraculinos": "oraculino",
    "oraculiza": "oraculizar",
    "oraculizada": "oraculizar",
    "oraculizadas": "oraculizar",
    "oraculizado": "oraculizar",
    "oraculizados": "oraculizar",
    "oraculizai": "oraculizar",
    "oraculizais": "oraculizar",
    "oraculizam": "oraculizar",
    "oraculizamo": "oraculizar",
    "oraculizamos": "oraculizar",
    "oraculizando": "oraculizar",
    "oraculizara": "oraculizar",
    "oraculizaram": "oraculizar",
    "oraculizaras": "oraculizar",
    "oraculizardes": "oraculizar",
    "oraculizarei": "oraculizar",
    "oraculizareis": "oraculizar",
    "oraculizarem": "oraculizar",
    "oraculizaremos": "oraculizar",
    "oraculizares": "oraculizar",
    "oraculizaria": "oraculizar",
    "oraculizariam": "oraculizar",
    "oraculizarias": "oraculizar",
    "oraculizarmo": "oraculizar",
    "oraculizarmos": "oraculizar",
    "oraculizará": "oraculizar",
    "oraculizarás": "oraculizar",
    "oraculizarão": "oraculizar",
    "oraculizaríamos": "oraculizar",
    "oraculizaríeis": "oraculizar",
    "oraculizas": "oraculizar",
    "oraculizasse": "oraculizar",
    "oraculizassem": "oraculizar",
    "oraculizasses": "oraculizar",
    "oraculizaste": "oraculizar",
    "oraculizastes": "oraculizar",
    "oraculizava": "oraculizar",
    "oraculizavam": "oraculizar",
    "oraculizavas": "oraculizar",
    "oraculize": "oraculizar",
    "oraculizei": "oraculizar",
    "oraculizeis": "oraculizar",
    "oraculizem": "oraculizar",
    "oraculizemo": "oraculizar",
    "oraculizemos": "oraculizar",
    "oraculizes": "oraculizar",
    "oraculizo": "oraculizar",
    "oraculizou": "oraculizar",
    "oraculizámo": "oraculizar",
    "oraculizámos": "oraculizar",
    "oraculizáramo": "oraculizar",
    "oraculizáramos": "oraculizar",
    "oraculizáreis": "oraculizar",
    "oraculizásseis": "oraculizar",
    "oraculizássemos": "oraculizar",
    "oraculizávamo": "oraculizar",
    "oraculizávamos": "oraculizar",
    "oraculizáveis": "oraculizar",
    "orada": "orar",
    "oradas": "orar",
    "orado": "orar",
    "oradora": "orador",
    "oradoras": "orador",
    "oradorazinha": "orador",
    "oradorazinhas": "orador",
    "oradorazita": "orador",
    "oradorazitas": "orador",
    "oradores": "orador",
    "oradorzinho": "orador",
    "oradorzinhos": "orador",
    "oradorzito": "orador",
    "oradorzitos": "orador",
    "orados": "orar",
    "oraga": "orago",
    "oragas": "orago",
    "oragos": "orago",
    "orai": "orar",
    "orais": "orar",
    "oralidades": "oralidade",
    "oram": "orar",
    "oramo": "orar",
    "oramos": "orar",
    "orando": "orar",
    "orangotangos": "orangotango",
    "orara": "orar",
    "oraram": "orar",
    "oraras": "orar",
    "orardes": "orar",
    "orarei": "orar",
    "orareis": "orar",
    "orarem": "orar",
    "oraremos": "orar",
    "orares": "orar",
    "oraria": "orar",
    "orariam": "orar",
    "orarias": "orar",
    "orarmo": "orar",
    "orarmos": "orar",
    "orará": "orar",
    "orarás": "orar",
    "orarão": "orar",
    "oraríamos": "orar",
    "oraríeis": "orar",
    "oras": "orar",
    "orasse": "orar",
    "orassem": "orar",
    "orasses": "orar",
    "oraste": "orar",
    "orastes": "orar",
    "orates": "orate",
    "oratoriana": "oratoriano",
    "oratorianas": "oratoriano",
    "oratorianos": "oratoriano",
    "oratória": "oratório",
    "oratórias": "oratório",
    "oratórios": "oratório",
    "orava": "orar",
    "oravam": "orar",
    "oravas": "orar",
    "orações": "oração",
    "orbes": "orbe",
    "orbiculares": "orbicular",
    "orbita": "orbitar",
    "orbitada": "orbitar",
    "orbitadas": "orbitar",
    "orbitado": "orbitar",
    "orbitados": "orbitar",
    "orbitai": "orbitar",
    "orbitais": "orbitar",
    "orbitam": "orbitar",
    "orbitamo": "orbitar",
    "orbitamos": "orbitar",
    "orbitando": "orbitar",
    "orbitara": "orbitar",
    "orbitaram": "orbitar",
    "orbitaras": "orbitar",
    "orbitardes": "orbitar",
    "orbitarei": "orbitar",
    "orbitareis": "orbitar",
    "orbitarem": "orbitar",
    "orbitaremos": "orbitar",
    "orbitares": "orbitar",
    "orbitaria": "orbitar",
    "orbitariam": "orbitar",
    "orbitarias": "orbitar",
    "orbitarmo": "orbitar",
    "orbitarmos": "orbitar",
    "orbitará": "orbitar",
    "orbitarás": "orbitar",
    "orbitarão": "orbitar",
    "orbitaríamos": "orbitar",
    "orbitaríeis": "orbitar",
    "orbitas": "orbitar",
    "orbitasse": "orbitar",
    "orbitassem": "orbitar",
    "orbitasses": "orbitar",
    "orbitaste": "orbitar",
    "orbitastes": "orbitar",
    "orbitava": "orbitar",
    "orbitavam": "orbitar",
    "orbitavas": "orbitar",
    "orbite": "orbitar",
    "orbitei": "orbitar",
    "orbiteis": "orbitar",
    "orbitem": "orbitar",
    "orbitemo": "orbitar",
    "orbitemos": "orbitar",
    "orbites": "orbitar",
    "orbito": "orbitar",
    "orbitou": "orbitar",
    "orbitámo": "orbitar",
    "orbitámos": "orbitar",
    "orbitáramo": "orbitar",
    "orbitáramos": "orbitar",
    "orbitáreis": "orbitar",
    "orbitária": "orbitário",
    "orbitárias": "orbitário",
    "orbitários": "orbitário",
    "orbitásseis": "orbitar",
    "orbitássemos": "orbitar",
    "orbitávamo": "orbitar",
    "orbitávamos": "orbitar",
    "orbitáveis": "orbitar",
    "orbícolas": "orbícola",
    "orbículas": "orbícula",
    "orbículos": "orbículo",
    "orbívaga": "orbívago",
    "orbívagas": "orbívago",
    "orbívagos": "orbívago",
    "orcas": "orca",
    "orce": "orçar",
    "orcei": "orçar",
    "orceis": "orçar",
    "orcem": "orçar",
    "orcemo": "orçar",
    "orcemos": "orçar",
    "orces": "orçar",
    "orchatas": "orchata",
    "orcinas": "orcina",
    "orcos": "orco",
    "ordeira": "ordeiro",
    "ordeiras": "ordeiro",
    "ordeiros": "ordeiro",
    "ordena": "ordenar",
    "ordenada": "ordenar",
    "ordenadas": "ordenar",
    "ordenado": "ordenar",
    "ordenadora": "ordenador",
    "ordenadoras": "ordenador",
    "ordenadores": "ordenador",
    "ordenados": "ordenar",
    "ordenai": "ordenar",
    "ordenais": "ordenar",
    "ordenam": "ordenar",
    "ordenamentos": "ordenamento",
    "ordenamo": "ordenar",
    "ordenamos": "ordenar",
    "ordenando": "ordenar",
    "ordenanças": "ordenança",
    "ordenara": "ordenar",
    "ordenaram": "ordenar",
    "ordenaras": "ordenar",
    "ordenarde": "ordenar",
    "ordenardes": "ordenar",
    "ordenare": "ordenar",
    "ordenarei": "ordenar",
    "ordenareis": "ordenar",
    "ordenarem": "ordenar",
    "ordenaremos": "ordenar",
    "ordenares": "ordenar",
    "ordenaria": "ordenar",
    "ordenariam": "ordenar",
    "ordenarias": "ordenar",
    "ordenarmo": "ordenar",
    "ordenarmos": "ordenar",
    "ordenará": "ordenar",
    "ordenarás": "ordenar",
    "ordenarão": "ordenar",
    "ordenaríamos": "ordenar",
    "ordenaríeis": "ordenar",
    "ordenas": "ordenar",
    "ordenasse": "ordenar",
    "ordenassem": "ordenar",
    "ordenasses": "ordenar",
    "ordenaste": "ordenar",
    "ordenastes": "ordenar",
    "ordenava": "ordenar",
    "ordenavam": "ordenar",
    "ordenavas": "ordenar",
    "ordenações": "ordenação",
    "ordene": "ordenar",
    "ordenei": "ordenar",
    "ordeneis": "ordenar",
    "ordenem": "ordenar",
    "ordenemo": "ordenar",
    "ordenemos": "ordenar",
    "ordenes": "ordenar",
    "ordenha": "ordenhar",
    "ordenhada": "ordenhar",
    "ordenhadas": "ordenhar",
    "ordenhadeira": "ordenhador",
    "ordenhadeiras": "ordenhador",
    "ordenhado": "ordenhar",
    "ordenhadora": "ordenhador",
    "ordenhadoras": "ordenhador",
    "ordenhadores": "ordenhador",
    "ordenhados": "ordenhar",
    "ordenhai": "ordenhar",
    "ordenhais": "ordenhar",
    "ordenham": "ordenhar",
    "ordenhamo": "ordenhar",
    "ordenhamos": "ordenhar",
    "ordenhando": "ordenhar",
    "ordenhara": "ordenhar",
    "ordenharam": "ordenhar",
    "ordenharas": "ordenhar",
    "ordenharde": "ordenhar",
    "ordenhardes": "ordenhar",
    "ordenhare": "ordenhar",
    "ordenharei": "ordenhar",
    "ordenhareis": "ordenhar",
    "ordenharem": "ordenhar",
    "ordenharemos": "ordenhar",
    "ordenhares": "ordenhar",
    "ordenharia": "ordenhar",
    "ordenhariam": "ordenhar",
    "ordenharias": "ordenhar",
    "ordenharmo": "ordenhar",
    "ordenharmos": "ordenhar",
    "ordenhará": "ordenhar",
    "ordenharás": "ordenhar",
    "ordenharão": "ordenhar",
    "ordenharíamos": "ordenhar",
    "ordenharíeis": "ordenhar",
    "ordenhas": "ordenhar",
    "ordenhasse": "ordenhar",
    "ordenhassem": "ordenhar",
    "ordenhasses": "ordenhar",
    "ordenhaste": "ordenhar",
    "ordenhastes": "ordenhar",
    "ordenhava": "ordenhar",
    "ordenhavam": "ordenhar",
    "ordenhavas": "ordenhar",
    "ordenhe": "ordenhar",
    "ordenhei": "ordenhar",
    "ordenheis": "ordenhar",
    "ordenhem": "ordenhar",
    "ordenhemo": "ordenhar",
    "ordenhemos": "ordenhar",
    "ordenhes": "ordenhar",
    "ordenho": "ordenhar",
    "ordenhou": "ordenhar",
    "ordenhá": "ordenhar",
    "ordenhámo": "ordenhar",
    "ordenhámos": "ordenhar",
    "ordenháramo": "ordenhar",
    "ordenháramos": "ordenhar",
    "ordenhárei": "ordenhar",
    "ordenháreis": "ordenhar",
    "ordenhásseis": "ordenhar",
    "ordenhássemos": "ordenhar",
    "ordenhávamo": "ordenhar",
    "ordenhávamos": "ordenhar",
    "ordenhávei": "ordenhar",
    "ordenháveis": "ordenhar",
    "ordeno": "ordenar",
    "ordenou": "ordenar",
    "ordens": "ordem",
    "ordená": "ordenar",
    "ordenámo": "ordenar",
    "ordenámos": "ordenar",
    "ordenáramo": "ordenar",
    "ordenáramos": "ordenar",
    "ordenárei": "ordenar",
    "ordenáreis": "ordenar",
    "ordenásseis": "ordenar",
    "ordenássemos": "ordenar",
    "ordenávamo": "ordenar",
    "ordenávamos": "ordenar",
    "ordenávei": "ordenar",
    "ordenáveis": "ordenável",
    "ordinais": "ordinal",
    "ordinanda": "ordinando",
    "ordinandas": "ordinando",
    "ordinandos": "ordinando",
    "ordinantes": "ordinante",
    "ordinarices": "ordinarice",
    "ordinária": "ordinário",
    "ordinárias": "ordinário",
    "ordinários": "ordinário",
    "ordovícicos": "ordovícico",
    "ordálios": "ordálio",
    "ore": "orar",
    "oreada": "orear",
    "oreadas": "orear",
    "oreado": "orear",
    "oreados": "orear",
    "oreai": "orear",
    "oreais": "orear",
    "oreamo": "orear",
    "oreamos": "orear",
    "oreando": "orear",
    "oreara": "orear",
    "orearam": "orear",
    "orearas": "orear",
    "orearde": "orear",
    "oreardes": "orear",
    "oreare": "orear",
    "orearei": "orear",
    "oreareis": "orear",
    "orearem": "orear",
    "orearemos": "orear",
    "oreares": "orear",
    "orearia": "orear",
    "oreariam": "orear",
    "orearias": "orear",
    "orearmo": "orear",
    "orearmos": "orear",
    "oreará": "orear",
    "orearás": "orear",
    "orearão": "orear",
    "orearíamos": "orear",
    "orearíeis": "orear",
    "oreasse": "orear",
    "oreassem": "orear",
    "oreasses": "orear",
    "oreaste": "orear",
    "oreastes": "orear",
    "oreava": "orear",
    "oreavam": "orear",
    "oreavas": "orear",
    "oreei": "orear",
    "oreeis": "orear",
    "oreemo": "orear",
    "oreemos": "orear",
    "oregas": "orega",
    "orei": "orar",
    "oreia": "orear",
    "oreiam": "orear",
    "oreias": "orear",
    "oreie": "orear",
    "oreiem": "orear",
    "oreies": "orear",
    "oreio": "orear",
    "oreis": "orar",
    "orelanas": "orelana",
    "orelha": "orelhar",
    "orelhada": "orelhar",
    "orelhadas": "orelhar",
    "orelhado": "orelhar",
    "orelhados": "orelhar",
    "orelhai": "orelhar",
    "orelhais": "orelhar",
    "orelham": "orelhar",
    "orelhamo": "orelhar",
    "orelhamos": "orelhar",
    "orelhando": "orelhar",
    "orelhara": "orelhar",
    "orelharam": "orelhar",
    "orelharas": "orelhar",
    "orelharde": "orelhar",
    "orelhardes": "orelhar",
    "orelhare": "orelhar",
    "orelharei": "orelhar",
    "orelhareis": "orelhar",
    "orelharem": "orelhar",
    "orelharemos": "orelhar",
    "orelhares": "orelhar",
    "orelharia": "orelhar",
    "orelhariam": "orelhar",
    "orelharias": "orelhar",
    "orelharmo": "orelhar",
    "orelharmos": "orelhar",
    "orelhará": "orelhar",
    "orelharás": "orelhar",
    "orelharão": "orelhar",
    "orelharíamos": "orelhar",
    "orelharíeis": "orelhar",
    "orelhas": "orelhar",
    "orelhasse": "orelhar",
    "orelhassem": "orelhar",
    "orelhasses": "orelhar",
    "orelhaste": "orelhar",
    "orelhastes": "orelhar",
    "orelhava": "orelhar",
    "orelhavam": "orelhar",
    "orelhavas": "orelhar",
    "orelhe": "orelhar",
    "orelhei": "orelhar",
    "orelheiras": "orelheira",
    "orelheis": "orelhar",
    "orelhem": "orelhar",
    "orelhemo": "orelhar",
    "orelhemos": "orelhar",
    "orelhes": "orelhar",
    "orelhinha": "orelha",
    "orelhinhas": "orelha",
    "orelhita": "orelha",
    "orelhitas": "orelha",
    "orelho": "orelhar",
    "orelhou": "orelhar",
    "orelhuda": "orelhudo",
    "orelhudas": "orelhudo",
    "orelhudos": "orelhudo",
    "orelhá": "orelhar",
    "orelhámo": "orelhar",
    "orelhámos": "orelhar",
    "orelháramo": "orelhar",
    "orelháramos": "orelhar",
    "orelhárei": "orelhar",
    "orelháreis": "orelhar",
    "orelhásseis": "orelhar",
    "orelhássemos": "orelhar",
    "orelhávamo": "orelhar",
    "orelhávamos": "orelhar",
    "orelhávei": "orelhar",
    "orelháveis": "orelhar",
    "orelhões": "orelhão",
    "orelinas": "orelina",
    "orem": "orar",
    "oremo": "orar",
    "oremos": "orar",
    "oreopitecos": "oreopiteco",
    "oreou": "orear",
    "ores": "orar",
    "oressas": "oressa",
    "orexias": "orexia",
    "orexomanias": "orexomania",
    "oreá": "orear",
    "oreámo": "orear",
    "oreámos": "orear",
    "oreáramo": "orear",
    "oreáramos": "orear",
    "oreárei": "orear",
    "oreáreis": "orear",
    "oreásseis": "orear",
    "oreássemos": "orear",
    "oreávamo": "orear",
    "oreávamos": "orear",
    "oreávei": "orear",
    "oreáveis": "orear",
    "orfana": "orfanar",
    "orfanada": "orfanar",
    "orfanadas": "orfanar",
    "orfanado": "orfanar",
    "orfanados": "orfanar",
    "orfanai": "orfanar",
    "orfanais": "orfanar",
    "orfanam": "orfanar",
    "orfanamo": "orfanar",
    "orfanamos": "orfanar",
    "orfanando": "orfanar",
    "orfanara": "orfanar",
    "orfanaram": "orfanar",
    "orfanaras": "orfanar",
    "orfanarde": "orfanar",
    "orfanardes": "orfanar",
    "orfanare": "orfanar",
    "orfanarei": "orfanar",
    "orfanareis": "orfanar",
    "orfanarem": "orfanar",
    "orfanaremos": "orfanar",
    "orfanares": "orfanar",
    "orfanaria": "orfanar",
    "orfanariam": "orfanar",
    "orfanarias": "orfanar",
    "orfanarmo": "orfanar",
    "orfanarmos": "orfanar",
    "orfanará": "orfanar",
    "orfanarás": "orfanar",
    "orfanarão": "orfanar",
    "orfanaríamos": "orfanar",
    "orfanaríeis": "orfanar",
    "orfanas": "orfanar",
    "orfanasse": "orfanar",
    "orfanassem": "orfanar",
    "orfanasses": "orfanar",
    "orfanaste": "orfanar",
    "orfanastes": "orfanar",
    "orfanatos": "orfanato",
    "orfanava": "orfanar",
    "orfanavam": "orfanar",
    "orfanavas": "orfanar",
    "orfandades": "orfandade",
    "orfane": "orfanar",
    "orfanei": "orfanar",
    "orfaneis": "orfanar",
    "orfanem": "orfanar",
    "orfanemo": "orfanar",
    "orfanemos": "orfanar",
    "orfanes": "orfanar",
    "orfano": "orfanar",
    "orfanologias": "orfanologia",
    "orfanológica": "orfanológico",
    "orfanológicas": "orfanológico",
    "orfanológicos": "orfanológico",
    "orfanou": "orfanar",
    "orfaná": "orfanar",
    "orfanámo": "orfanar",
    "orfanámos": "orfanar",
    "orfanáramo": "orfanar",
    "orfanáramos": "orfanar",
    "orfanárei": "orfanar",
    "orfanáreis": "orfanar",
    "orfanásseis": "orfanar",
    "orfanássemos": "orfanar",
    "orfanávamo": "orfanar",
    "orfanávamos": "orfanar",
    "orfanávei": "orfanar",
    "orfanáveis": "orfanar",
    "orfeica": "orfeico",
    "orfeicas": "orfeico",
    "orfeicos": "orfeico",
    "orfeonistas": "orfeonista",
    "orfeónica": "orfeónico",
    "orfeónicas": "orfeónico",
    "orfeónicos": "orfeónico",
    "orfeões": "orfeão",
    "orgadas": "orgada",
    "organdis": "organdi",
    "organeira": "organeiro",
    "organeiras": "organeiro",
    "organeiros": "organeiro",
    "organicismos": "organicismo",
    "organicistas": "organicista",
    "organigramas": "organigrama",
    "organismos": "organismo",
    "organistas": "organista",
    "organitos": "organito",
    "organiza": "organizar",
    "organizacionais": "organizacional",
    "organizada": "organizar",
    "organizadas": "organizar",
    "organizado": "organizar",
    "organizadora": "organizador",
    "organizadoras": "organizador",
    "organizadores": "organizador",
    "organizados": "organizar",
    "organizadíssima": "organizado",
    "organizadíssimas": "organizado",
    "organizadíssimo": "organizado",
    "organizadíssimos": "organizado",
    "organizai": "organizar",
    "organizais": "organizar",
    "organizam": "organizar",
    "organizamo": "organizar",
    "organizamos": "organizar",
    "organizando": "organizar",
    "organizara": "organizar",
    "organizaram": "organizar",
    "organizaras": "organizar",
    "organizarde": "organizar",
    "organizardes": "organizar",
    "organizare": "organizar",
    "organizarei": "organizar",
    "organizareis": "organizar",
    "organizarem": "organizar",
    "organizaremos": "organizar",
    "organizares": "organizar",
    "organizaria": "organizar",
    "organizariam": "organizar",
    "organizarias": "organizar",
    "organizarmo": "organizar",
    "organizarmos": "organizar",
    "organizará": "organizar",
    "organizarás": "organizar",
    "organizarão": "organizar",
    "organizaríamos": "organizar",
    "organizaríeis": "organizar",
    "organizas": "organizar",
    "organizasse": "organizar",
    "organizassem": "organizar",
    "organizasses": "organizar",
    "organizaste": "organizar",
    "organizastes": "organizar",
    "organizativa": "organizativo",
    "organizativas": "organizativo",
    "organizativos": "organizativo",
    "organizava": "organizar",
    "organizavam": "organizar",
    "organizavas": "organizar",
    "organizações": "organização",
    "organize": "organizar",
    "organizei": "organizar",
    "organizeis": "organizar",
    "organizem": "organizar",
    "organizemo": "organizar",
    "organizemos": "organizar",
    "organizes": "organizar",
    "organizo": "organizar",
    "organizou": "organizar",
    "organizá": "organizar",
    "organizámo": "organizar",
    "organizámos": "organizar",
    "organizáramo": "organizar",
    "organizáramos": "organizar",
    "organizárei": "organizar",
    "organizáreis": "organizar",
    "organizásseis": "organizar",
    "organizássemos": "organizar",
    "organizávamo": "organizar",
    "organizávamos": "organizar",
    "organizávei": "organizar",
    "organizáveis": "organizável",
    "organogenesias": "organogenesia",
    "organogenias": "organogenia",
    "organogenética": "organogenético",
    "organogenéticas": "organogenético",
    "organogenéticos": "organogenético",
    "organografias": "organografia",
    "organogramas": "organograma",
    "organográfica": "organográfico",
    "organográficas": "organográfico",
    "organográficos": "organográfico",
    "organogéneses": "organogénese",
    "organoléptica": "organoléptico",
    "organolépticas": "organoléptico",
    "organolépticos": "organoléptico",
    "organometálica": "organometálico",
    "organometálicas": "organometálico",
    "organometálicos": "organometálico",
    "organonímias": "organonímia",
    "organonímica": "organonímico",
    "organonímicas": "organonímico",
    "organonímicos": "organonímico",
    "organopatias": "organopatia",
    "organoscopias": "organoscopia",
    "organoscópica": "organoscópico",
    "organoscópicas": "organoscópico",
    "organoscópicos": "organoscópico",
    "organotaxias": "organotaxia",
    "organotáctica": "organotáctico",
    "organotácticas": "organotáctico",
    "organotácticos": "organotáctico",
    "organsina": "organsinar",
    "organsinada": "organsinar",
    "organsinadas": "organsinar",
    "organsinado": "organsinar",
    "organsinados": "organsinar",
    "organsinai": "organsinar",
    "organsinais": "organsinar",
    "organsinam": "organsinar",
    "organsinamo": "organsinar",
    "organsinamos": "organsinar",
    "organsinando": "organsinar",
    "organsinara": "organsinar",
    "organsinaram": "organsinar",
    "organsinaras": "organsinar",
    "organsinarde": "organsinar",
    "organsinardes": "organsinar",
    "organsinare": "organsinar",
    "organsinarei": "organsinar",
    "organsinareis": "organsinar",
    "organsinarem": "organsinar",
    "organsinaremos": "organsinar",
    "organsinares": "organsinar",
    "organsinaria": "organsinar",
    "organsinariam": "organsinar",
    "organsinarias": "organsinar",
    "organsinarmo": "organsinar",
    "organsinarmos": "organsinar",
    "organsinará": "organsinar",
    "organsinarás": "organsinar",
    "organsinarão": "organsinar",
    "organsinaríamos": "organsinar",
    "organsinaríeis": "organsinar",
    "organsinas": "organsinar",
    "organsinasse": "organsinar",
    "organsinassem": "organsinar",
    "organsinasses": "organsinar",
    "organsinaste": "organsinar",
    "organsinastes": "organsinar",
    "organsinava": "organsinar",
    "organsinavam": "organsinar",
    "organsinavas": "organsinar",
    "organsine": "organsinar",
    "organsinei": "organsinar",
    "organsineis": "organsinar",
    "organsinem": "organsinar",
    "organsinemo": "organsinar",
    "organsinemos": "organsinar",
    "organsines": "organsinar",
    "organsino": "organsinar",
    "organsinos": "organsino",
    "organsinou": "organsinar",
    "organsins": "organsim",
    "organsiná": "organsinar",
    "organsinámo": "organsinar",
    "organsinámos": "organsinar",
    "organsináramo": "organsinar",
    "organsináramos": "organsinar",
    "organsinárei": "organsinar",
    "organsináreis": "organsinar",
    "organsinásseis": "organsinar",
    "organsinássemos": "organsinar",
    "organsinávamo": "organsinar",
    "organsinávamos": "organsinar",
    "organsinávei": "organsinar",
    "organsináveis": "organsinar",
    "organzas": "organza",
    "organóides": "organóide",
    "orgasmos": "orgasmo",
    "orgevões": "orgevão",
    "orgias": "orgia",
    "orgiastas": "orgiasta",
    "orgivões": "orgivão",
    "orgiástica": "orgiástico",
    "orgiásticas": "orgiástico",
    "orgiásticos": "orgiástico",
    "orgulha": "orgulhar",
    "orgulhada": "orgulhar",
    "orgulhadas": "orgulhar",
    "orgulhado": "orgulhar",
    "orgulhados": "orgulhar",
    "orgulhai": "orgulhar",
    "orgulhais": "orgulhar",
    "orgulham": "orgulhar",
    "orgulhamo": "orgulhar",
    "orgulhamos": "orgulhar",
    "orgulhando": "orgulhar",
    "orgulhara": "orgulhar",
    "orgulharam": "orgulhar",
    "orgulharas": "orgulhar",
    "orgulharde": "orgulhar",
    "orgulhardes": "orgulhar",
    "orgulhare": "orgulhar",
    "orgulharei": "orgulhar",
    "orgulhareis": "orgulhar",
    "orgulharem": "orgulhar",
    "orgulharemos": "orgulhar",
    "orgulhares": "orgulhar",
    "orgulharia": "orgulhar",
    "orgulhariam": "orgulhar",
    "orgulharias": "orgulhar",
    "orgulharmo": "orgulhar",
    "orgulharmos": "orgulhar",
    "orgulhará": "orgulhar",
    "orgulharás": "orgulhar",
    "orgulharão": "orgulhar",
    "orgulharíamos": "orgulhar",
    "orgulharíeis": "orgulhar",
    "orgulhas": "orgulhar",
    "orgulhasse": "orgulhar",
    "orgulhassem": "orgulhar",
    "orgulhasses": "orgulhar",
    "orgulhaste": "orgulhar",
    "orgulhastes": "orgulhar",
    "orgulhava": "orgulhar",
    "orgulhavam": "orgulhar",
    "orgulhavas": "orgulhar",
    "orgulhe": "orgulhar",
    "orgulhece": "orgulhecer",
    "orgulhecei": "orgulhecer",
    "orgulheceis": "orgulhecer",
    "orgulhecem": "orgulhecer",
    "orgulhecemo": "orgulhecer",
    "orgulhecemos": "orgulhecer",
    "orgulhecendo": "orgulhecer",
    "orgulhecera": "orgulhecer",
    "orgulheceram": "orgulhecer",
    "orgulheceras": "orgulhecer",
    "orgulhecerde": "orgulhecer",
    "orgulhecerdes": "orgulhecer",
    "orgulhecere": "orgulhecer",
    "orgulhecerei": "orgulhecer",
    "orgulhecereis": "orgulhecer",
    "orgulhecerem": "orgulhecer",
    "orgulheceremos": "orgulhecer",
    "orgulheceres": "orgulhecer",
    "orgulheceria": "orgulhecer",
    "orgulheceriam": "orgulhecer",
    "orgulhecerias": "orgulhecer",
    "orgulhecermo": "orgulhecer",
    "orgulhecermos": "orgulhecer",
    "orgulhecerá": "orgulhecer",
    "orgulhecerás": "orgulhecer",
    "orgulhecerão": "orgulhecer",
    "orgulheceríamos": "orgulhecer",
    "orgulheceríeis": "orgulhecer",
    "orgulheces": "orgulhecer",
    "orgulhecesse": "orgulhecer",
    "orgulhecessem": "orgulhecer",
    "orgulhecesses": "orgulhecer",
    "orgulheceste": "orgulhecer",
    "orgulhecestes": "orgulhecer",
    "orgulheceu": "orgulhecer",
    "orgulheci": "orgulhecer",
    "orgulhecia": "orgulhecer",
    "orgulheciam": "orgulhecer",
    "orgulhecias": "orgulhecer",
    "orgulhecida": "orgulhecer",
    "orgulhecidas": "orgulhecer",
    "orgulhecido": "orgulhecer",
    "orgulhecidos": "orgulhecer",
    "orgulhecê": "orgulhecer",
    "orgulhecêramo": "orgulhecer",
    "orgulhecêramos": "orgulhecer",
    "orgulhecêrei": "orgulhecer",
    "orgulhecêreis": "orgulhecer",
    "orgulhecêsseis": "orgulhecer",
    "orgulhecêssemos": "orgulhecer",
    "orgulhecíamo": "orgulhecer",
    "orgulhecíamos": "orgulhecer",
    "orgulhecíei": "orgulhecer",
    "orgulhecíeis": "orgulhecer",
    "orgulhei": "orgulhar",
    "orgulheis": "orgulhar",
    "orgulhem": "orgulhar",
    "orgulhemo": "orgulhar",
    "orgulhemos": "orgulhar",
    "orgulhes": "orgulhar",
    "orgulheça": "orgulhecer",
    "orgulheçais": "orgulhecer",
    "orgulheçam": "orgulhecer",
    "orgulheçamo": "orgulhecer",
    "orgulheçamos": "orgulhecer",
    "orgulheças": "orgulhecer",
    "orgulheço": "orgulhecer",
    "orgulhinho": "orgulho",
    "orgulhinhos": "orgulho",
    "orgulhito": "orgulho",
    "orgulhitos": "orgulho",
    "orgulho": "orgulhar",
    "orgulhos": "orgulho",
    "orgulhosa": "orgulhoso",
    "orgulhosas": "orgulhoso",
    "orgulhosos": "orgulhoso",
    "orgulhou": "orgulhar",
    "orgulhá": "orgulhar",
    "orgulhámo": "orgulhar",
    "orgulhámos": "orgulhar",
    "orgulháramo": "orgulhar",
    "orgulháramos": "orgulhar",
    "orgulhárei": "orgulhar",
    "orgulháreis": "orgulhar",
    "orgulhásseis": "orgulhar",
    "orgulhássemos": "orgulhar",
    "orgulhávamo": "orgulhar",
    "orgulhávamos": "orgulhar",
    "orgulhávei": "orgulhar",
    "orgulháveis": "orgulhar",
    "orgástica": "orgástico",
    "orgásticas": "orgástico",
    "orgásticos": "orgástico",
    "orgânica": "orgânico",
    "orgânicas": "orgânico",
    "orgânicos": "orgânico",
    "orgíaca": "orgíaco",
    "orgíacas": "orgíaco",
    "orgíacos": "orgíaco",
    "oribatídeos": "oribatídeo",
    "oribátidas": "oribátida",
    "oricalcos": "oricalco",
    "orictognosias": "orictognosia",
    "orictologias": "orictologia",
    "orienta": "orientar",
    "orientada": "orientar",
    "orientadas": "orientar",
    "orientado": "orientar",
    "orientadora": "orientador",
    "orientadoras": "orientador",
    "orientadores": "orientador",
    "orientados": "orientar",
    "orientai": "orientar",
    "orientais": "orientar",
    "orientalidades": "orientalidade",
    "orientalismos": "orientalismo",
    "orientalistas": "orientalista",
    "orientaliza": "orientalizar",
    "orientalizada": "orientalizar",
    "orientalizadas": "orientalizar",
    "orientalizado": "orientalizar",
    "orientalizados": "orientalizar",
    "orientalizai": "orientalizar",
    "orientalizais": "orientalizar",
    "orientalizam": "orientalizar",
    "orientalizamo": "orientalizar",
    "orientalizamos": "orientalizar",
    "orientalizando": "orientalizar",
    "orientalizara": "orientalizar",
    "orientalizaram": "orientalizar",
    "orientalizaras": "orientalizar",
    "orientalizarde": "orientalizar",
    "orientalizardes": "orientalizar",
    "orientalizare": "orientalizar",
    "orientalizarei": "orientalizar",
    "orientalizareis": "orientalizar",
    "orientalizarem": "orientalizar",
    "orientalizaremos": "orientalizar",
    "orientalizares": "orientalizar",
    "orientalizaria": "orientalizar",
    "orientalizariam": "orientalizar",
    "orientalizarias": "orientalizar",
    "orientalizarmo": "orientalizar",
    "orientalizarmos": "orientalizar",
    "orientalizará": "orientalizar",
    "orientalizarás": "orientalizar",
    "orientalizarão": "orientalizar",
    "orientalizaríamos": "orientalizar",
    "orientalizaríeis": "orientalizar",
    "orientalizas": "orientalizar",
    "orientalizasse": "orientalizar",
    "orientalizassem": "orientalizar",
    "orientalizasses": "orientalizar",
    "orientalizaste": "orientalizar",
    "orientalizastes": "orientalizar",
    "orientalizava": "orientalizar",
    "orientalizavam": "orientalizar",
    "orientalizavas": "orientalizar",
    "orientalize": "orientalizar",
    "orientalizei": "orientalizar",
    "orientalizeis": "orientalizar",
    "orientalizem": "orientalizar",
    "orientalizemo": "orientalizar",
    "orientalizemos": "orientalizar",
    "orientalizes": "orientalizar",
    "orientalizo": "orientalizar",
    "orientalizou": "orientalizar",
    "orientalizá": "orientalizar",
    "orientalizámo": "orientalizar",
    "orientalizámos": "orientalizar",
    "orientalizáramo": "orientalizar",
    "orientalizáramos": "orientalizar",
    "orientalizárei": "orientalizar",
    "orientalizáreis": "orientalizar",
    "orientalizásseis": "orientalizar",
    "orientalizássemos": "orientalizar",
    "orientalizávamo": "orientalizar",
    "orientalizávamos": "orientalizar",
    "orientalizávei": "orientalizar",
    "orientalizáveis": "orientalizável",
    "orientam": "orientar",
    "orientamo": "orientar",
    "orientamos": "orientar",
    "orientando": "orientar",
    "orientara": "orientar",
    "orientaram": "orientar",
    "orientaras": "orientar",
    "orientarde": "orientar",
    "orientardes": "orientar",
    "orientare": "orientar",
    "orientarei": "orientar",
    "orientareis": "orientar",
    "orientarem": "orientar",
    "orientaremos": "orientar",
    "orientares": "orientar",
    "orientaria": "orientar",
    "orientariam": "orientar",
    "orientarias": "orientar",
    "orientarmo": "orientar",
    "orientarmos": "orientar",
    "orientará": "orientar",
    "orientarás": "orientar",
    "orientarão": "orientar",
    "orientaríamos": "orientar",
    "orientaríeis": "orientar",
    "orientas": "orientar",
    "orientasse": "orientar",
    "orientassem": "orientar",
    "orientasses": "orientar",
    "orientaste": "orientar",
    "orientastes": "orientar",
    "orientava": "orientar",
    "orientavam": "orientar",
    "orientavas": "orientar",
    "orientações": "orientação",
    "oriente": "orientar",
    "orientei": "orientar",
    "orienteis": "orientar",
    "orientem": "orientar",
    "orientemo": "orientar",
    "orientemos": "orientar",
    "orientes": "oriente",
    "oriento": "orientar",
    "orientou": "orientar",
    "orientá": "orientar",
    "orientámo": "orientar",
    "orientámos": "orientar",
    "orientáramo": "orientar",
    "orientáramos": "orientar",
    "orientárei": "orientar",
    "orientáreis": "orientar",
    "orientásseis": "orientar",
    "orientássemos": "orientar",
    "orientávamo": "orientar",
    "orientávamos": "orientar",
    "orientávei": "orientar",
    "orientáveis": "orientável",
    "oriflamas": "oriflama",
    "oriformes": "oriforme",
    "orifícios": "orifício",
    "origens": "origem",
    "origina": "originar",
    "originada": "originar",
    "originadas": "originar",
    "originado": "originar",
    "originadora": "originador",
    "originadoras": "originador",
    "originadores": "originador",
    "originados": "originar",
    "originai": "originar",
    "originais": "originar",
    "originalidades": "originalidade",
    "originalíssima": "original",
    "originalíssimas": "original",
    "originalíssimo": "original",
    "originalíssimos": "original",
    "originam": "originar",
    "originamo": "originar",
    "originamos": "originar",
    "originando": "originar",
    "originara": "originar",
    "originaram": "originar",
    "originaras": "originar",
    "originarde": "originar",
    "originardes": "originar",
    "originare": "originar",
    "originarei": "originar",
    "originareis": "originar",
    "originarem": "originar",
    "originaremos": "originar",
    "originares": "originar",
    "originaria": "originar",
    "originariam": "originar",
    "originarias": "originar",
    "originarmo": "originar",
    "originarmos": "originar",
    "originará": "originar",
    "originarás": "originar",
    "originarão": "originar",
    "originaríamos": "originar",
    "originaríeis": "originar",
    "originas": "originar",
    "originasse": "originar",
    "originassem": "originar",
    "originasses": "originar",
    "originaste": "originar",
    "originastes": "originar",
    "originava": "originar",
    "originavam": "originar",
    "originavas": "originar",
    "origine": "originar",
    "originei": "originar",
    "origineis": "originar",
    "originem": "originar",
    "originemo": "originar",
    "originemos": "originar",
    "origines": "originar",
    "origino": "originar",
    "originou": "originar",
    "originá": "originar",
    "originámo": "originar",
    "originámos": "originar",
    "origináramo": "originar",
    "origináramos": "originar",
    "originárei": "originar",
    "origináreis": "originar",
    "originária": "originário",
    "originárias": "originário",
    "originários": "originário",
    "originásseis": "originar",
    "originássemos": "originar",
    "originávamo": "originar",
    "originávamos": "originar",
    "originávei": "originar",
    "origináveis": "originar",
    "origmas": "origma",
    "orilhas": "orilha",
    "oriolídeos": "oriolídeo",
    "oriunda": "oriundo",
    "oriundas": "oriundo",
    "oriundos": "oriundo",
    "orizicultora": "orizicultor",
    "orizicultoras": "orizicultor",
    "orizicultores": "orizicultor",
    "oriziculturas": "orizicultura",
    "orizícolas": "orizícola",
    "orizívora": "orizívoro",
    "orizívoras": "orizívoro",
    "orizívoros": "orizívoro",
    "orizófaga": "orizófago",
    "orizófagas": "orizófago",
    "orizófagos": "orizófago",
    "orizóides": "orizóide",
    "oriólidas": "oriólida",
    "orla": "orlar",
    "orlada": "orlar",
    "orladas": "orlar",
    "orlado": "orlar",
    "orlados": "orlar",
    "orlai": "orlar",
    "orlais": "orlar",
    "orlam": "orlar",
    "orlamo": "orlar",
    "orlamos": "orlar",
    "orlando": "orlar",
    "orlara": "orlar",
    "orlaram": "orlar",
    "orlaras": "orlar",
    "orlarde": "orlar",
    "orlardes": "orlar",
    "orlare": "orlar",
    "orlarei": "orlar",
    "orlareis": "orlar",
    "orlarem": "orlar",
    "orlaremos": "orlar",
    "orlares": "orlar",
    "orlaria": "orlar",
    "orlariam": "orlar",
    "orlarias": "orlar",
    "orlarmo": "orlar",
    "orlarmos": "orlar",
    "orlará": "orlar",
    "orlarás": "orlar",
    "orlarão": "orlar",
    "orlaríamos": "orlar",
    "orlaríeis": "orlar",
    "orlas": "orlar",
    "orlasse": "orlar",
    "orlassem": "orlar",
    "orlasses": "orlar",
    "orlaste": "orlar",
    "orlastes": "orlar",
    "orlava": "orlar",
    "orlavam": "orlar",
    "orlavas": "orlar",
    "orle": "orlar",
    "orleaneses": "orleanês",
    "orleanistas": "orleanista",
    "orlei": "orlar",
    "orleis": "orlar",
    "orlem": "orlar",
    "orlemo": "orlar",
    "orlemos": "orlar",
    "orles": "orlar",
    "orleãs": "orleã",
    "orlo": "orlar",
    "orlou": "orlar",
    "orlá": "orlar",
    "orlámo": "orlar",
    "orlámos": "orlar",
    "orláramo": "orlar",
    "orláramos": "orlar",
    "orlárei": "orlar",
    "orláreis": "orlar",
    "orlásseis": "orlar",
    "orlássemos": "orlar",
    "orlávamo": "orlar",
    "orlávamos": "orlar",
    "orlávei": "orlar",
    "orláveis": "orlar",
    "orna": "ornar",
    "ornada": "ornar",
    "ornadas": "ornar",
    "ornado": "ornar",
    "ornadora": "ornador",
    "ornadoras": "ornador",
    "ornadores": "ornador",
    "ornados": "ornar",
    "ornai": "ornar",
    "ornais": "ornar",
    "ornam": "ornar",
    "ornamenta": "ornamentar",
    "ornamentada": "ornamentar",
    "ornamentadas": "ornamentar",
    "ornamentado": "ornamentar",
    "ornamentadora": "ornamentador",
    "ornamentadoras": "ornamentador",
    "ornamentadores": "ornamentador",
    "ornamentados": "ornamentar",
    "ornamentai": "ornamentar",
    "ornamentais": "ornamentar",
    "ornamentam": "ornamentar",
    "ornamentamo": "ornamentar",
    "ornamentamos": "ornamentar",
    "ornamentando": "ornamentar",
    "ornamentara": "ornamentar",
    "ornamentaram": "ornamentar",
    "ornamentaras": "ornamentar",
    "ornamentarde": "ornamentar",
    "ornamentardes": "ornamentar",
    "ornamentare": "ornamentar",
    "ornamentarei": "ornamentar",
    "ornamentareis": "ornamentar",
    "ornamentarem": "ornamentar",
    "ornamentaremos": "ornamentar",
    "ornamentares": "ornamentar",
    "ornamentaria": "ornamentar",
    "ornamentariam": "ornamentar",
    "ornamentarias": "ornamentar",
    "ornamentarmo": "ornamentar",
    "ornamentarmos": "ornamentar",
    "ornamentará": "ornamentar",
    "ornamentarás": "ornamentar",
    "ornamentarão": "ornamentar",
    "ornamentaríamos": "ornamentar",
    "ornamentaríeis": "ornamentar",
    "ornamentas": "ornamentar",
    "ornamentasse": "ornamentar",
    "ornamentassem": "ornamentar",
    "ornamentasses": "ornamentar",
    "ornamentaste": "ornamentar",
    "ornamentastes": "ornamentar",
    "ornamentava": "ornamentar",
    "ornamentavam": "ornamentar",
    "ornamentavas": "ornamentar",
    "ornamentações": "ornamentação",
    "ornamente": "ornamentar",
    "ornamentei": "ornamentar",
    "ornamenteis": "ornamentar",
    "ornamentem": "ornamentar",
    "ornamentemo": "ornamentar",
    "ornamentemos": "ornamentar",
    "ornamentes": "ornamentar",
    "ornamentistas": "ornamentista",
    "ornamento": "ornamentar",
    "ornamentos": "ornamento",
    "ornamentou": "ornamentar",
    "ornamentá": "ornamentar",
    "ornamentámo": "ornamentar",
    "ornamentámos": "ornamentar",
    "ornamentáramo": "ornamentar",
    "ornamentáramos": "ornamentar",
    "ornamentárei": "ornamentar",
    "ornamentáreis": "ornamentar",
    "ornamentárias": "ornamentária",
    "ornamentásseis": "ornamentar",
    "ornamentássemos": "ornamentar",
    "ornamentávamo": "ornamentar",
    "ornamentávamos": "ornamentar",
    "ornamentávei": "ornamentar",
    "ornamentáveis": "ornamentável",
    "ornamo": "ornar",
    "ornamos": "ornar",
    "ornando": "ornar",
    "ornara": "ornar",
    "ornaram": "ornar",
    "ornaras": "ornar",
    "ornarde": "ornar",
    "ornardes": "ornar",
    "ornare": "ornar",
    "ornarei": "ornar",
    "ornareis": "ornar",
    "ornarem": "ornar",
    "ornaremos": "ornar",
    "ornares": "ornar",
    "ornaria": "ornar",
    "ornariam": "ornar",
    "ornarias": "ornar",
    "ornarmo": "ornar",
    "ornarmos": "ornar",
    "ornará": "ornar",
    "ornarás": "ornar",
    "ornarão": "ornar",
    "ornaríamos": "ornar",
    "ornaríeis": "ornar",
    "ornas": "ornar",
    "ornasse": "ornar",
    "ornassem": "ornar",
    "ornasses": "ornar",
    "ornaste": "ornar",
    "ornastes": "ornar",
    "ornatos": "ornato",
    "ornava": "ornar",
    "ornavam": "ornar",
    "ornavas": "ornar",
    "orne": "ornar",
    "orneada": "ornear",
    "orneadas": "ornear",
    "orneado": "ornear",
    "orneados": "ornear",
    "orneai": "ornear",
    "orneais": "ornear",
    "orneamo": "ornear",
    "orneamos": "ornear",
    "orneando": "ornear",
    "orneara": "ornear",
    "ornearam": "ornear",
    "ornearas": "ornear",
    "orneardes": "ornear",
    "ornearei": "ornear",
    "orneareis": "ornear",
    "ornearem": "ornear",
    "ornearemos": "ornear",
    "orneares": "ornear",
    "ornearia": "ornear",
    "orneariam": "ornear",
    "ornearias": "ornear",
    "ornearmo": "ornear",
    "ornearmos": "ornear",
    "orneará": "ornear",
    "ornearás": "ornear",
    "ornearão": "ornear",
    "ornearíamos": "ornear",
    "ornearíeis": "ornear",
    "orneasse": "ornear",
    "orneassem": "ornear",
    "orneasses": "ornear",
    "orneaste": "ornear",
    "orneastes": "ornear",
    "orneava": "ornear",
    "orneavam": "ornear",
    "orneavas": "ornear",
    "orneei": "ornear",
    "orneeis": "ornear",
    "orneemo": "ornear",
    "orneemos": "ornear",
    "ornei": "ornar",
    "orneia": "ornear",
    "orneiam": "ornear",
    "orneias": "ornear",
    "orneie": "ornear",
    "orneiem": "ornear",
    "orneies": "ornear",
    "orneio": "ornear",
    "orneios": "orneio",
    "orneis": "ornar",
    "orneja": "ornejar",
    "ornejada": "ornejar",
    "ornejadas": "ornejar",
    "ornejado": "ornejar",
    "ornejadora": "ornejador",
    "ornejadoras": "ornejador",
    "ornejadores": "ornejador",
    "ornejados": "ornejar",
    "ornejai": "ornejar",
    "ornejais": "ornejar",
    "ornejam": "ornejar",
    "ornejamo": "ornejar",
    "ornejamos": "ornejar",
    "ornejando": "ornejar",
    "ornejara": "ornejar",
    "ornejaram": "ornejar",
    "ornejaras": "ornejar",
    "ornejardes": "ornejar",
    "ornejarei": "ornejar",
    "ornejareis": "ornejar",
    "ornejarem": "ornejar",
    "ornejaremos": "ornejar",
    "ornejares": "ornejar",
    "ornejaria": "ornejar",
    "ornejariam": "ornejar",
    "ornejarias": "ornejar",
    "ornejarmo": "ornejar",
    "ornejarmos": "ornejar",
    "ornejará": "ornejar",
    "ornejarás": "ornejar",
    "ornejarão": "ornejar",
    "ornejaríamos": "ornejar",
    "ornejaríeis": "ornejar",
    "ornejas": "ornejar",
    "ornejasse": "ornejar",
    "ornejassem": "ornejar",
    "ornejasses": "ornejar",
    "ornejaste": "ornejar",
    "ornejastes": "ornejar",
    "ornejava": "ornejar",
    "ornejavam": "ornejar",
    "ornejavas": "ornejar",
    "orneje": "ornejar",
    "ornejei": "ornejar",
    "ornejeis": "ornejar",
    "ornejem": "ornejar",
    "ornejemo": "ornejar",
    "ornejemos": "ornejar",
    "ornejes": "ornejar",
    "ornejo": "ornejar",
    "ornejos": "ornejo",
    "ornejou": "ornejar",
    "ornejámo": "ornejar",
    "ornejámos": "ornejar",
    "ornejáramo": "ornejar",
    "ornejáramos": "ornejar",
    "ornejáreis": "ornejar",
    "ornejásseis": "ornejar",
    "ornejássemos": "ornejar",
    "ornejávamo": "ornejar",
    "ornejávamos": "ornejar",
    "ornejáveis": "ornejar",
    "ornem": "ornar",
    "ornemo": "ornar",
    "ornemos": "ornar",
    "orneou": "ornear",
    "ornes": "ornar",
    "orneámo": "ornear",
    "orneámos": "ornear",
    "orneáramo": "ornear",
    "orneáramos": "ornear",
    "orneáreis": "ornear",
    "orneásseis": "ornear",
    "orneássemos": "ornear",
    "orneávamo": "ornear",
    "orneávamos": "ornear",
    "orneáveis": "ornear",
    "ornises": "ornis",
    "ornitisquianos": "ornitisquiano",
    "ornitofonias": "ornitofonia",
    "ornitologias": "ornitologia",
    "ornitologistas": "ornitologista",
    "ornitológica": "ornitológico",
    "ornitológicas": "ornitológico",
    "ornitológicos": "ornitológico",
    "ornitomancias": "ornitomancia",
    "ornitomanias": "ornitomania",
    "ornitorrincos": "ornitorrinco",
    "ornitotomias": "ornitotomia",
    "ornitotrofias": "ornitotrofia",
    "ornitófila": "ornitófilo",
    "ornitófilas": "ornitófilo",
    "ornitófilos": "ornitófilo",
    "ornitólogos": "ornitólogo",
    "ornitópodes": "ornitópode",
    "orno": "ornar",
    "ornou": "ornar",
    "orná": "ornar",
    "ornámo": "ornar",
    "ornámos": "ornar",
    "ornáramo": "ornar",
    "ornáramos": "ornar",
    "ornárei": "ornar",
    "ornáreis": "ornar",
    "ornásseis": "ornar",
    "ornássemos": "ornar",
    "ornávamo": "ornar",
    "ornávamos": "ornar",
    "ornávei": "ornar",
    "ornáveis": "ornar",
    "oro": "orar",
    "orobancáceas": "orobancácea",
    "orogenias": "orogenia",
    "orogenética": "orogenético",
    "orogenéticas": "orogenético",
    "orogenéticos": "orogenético",
    "orognosias": "orognosia",
    "orognóstica": "orognóstico",
    "orognósticas": "orognóstico",
    "orognósticos": "orognóstico",
    "orografias": "orografia",
    "orográfica": "orográfico",
    "orográficas": "orográfico",
    "orográficos": "orográfico",
    "orogéneses": "orogénese",
    "orogénica": "orogénico",
    "orogénicas": "orogénico",
    "orogénicos": "orogénico",
    "oroidrografias": "oroidrografia",
    "oroidrográfica": "oroidrográfico",
    "oroidrográficas": "oroidrográfico",
    "oroidrográficos": "oroidrográfico",
    "orologias": "orologia",
    "orológica": "orológico",
    "orológicas": "orológico",
    "orológicos": "orológico",
    "orometrias": "orometria",
    "orosferas": "orosfera",
    "orosférica": "orosférico",
    "orosféricas": "orosférico",
    "orosféricos": "orosférico",
    "orou": "orar",
    "orquestra": "orquestrar",
    "orquestrada": "orquestrar",
    "orquestradas": "orquestrar",
    "orquestrado": "orquestrar",
    "orquestrados": "orquestrar",
    "orquestrai": "orquestrar",
    "orquestrais": "orquestrar",
    "orquestram": "orquestrar",
    "orquestramo": "orquestrar",
    "orquestramos": "orquestrar",
    "orquestrando": "orquestrar",
    "orquestrara": "orquestrar",
    "orquestraram": "orquestrar",
    "orquestraras": "orquestrar",
    "orquestrarde": "orquestrar",
    "orquestrardes": "orquestrar",
    "orquestrare": "orquestrar",
    "orquestrarei": "orquestrar",
    "orquestrareis": "orquestrar",
    "orquestrarem": "orquestrar",
    "orquestraremos": "orquestrar",
    "orquestrares": "orquestrar",
    "orquestraria": "orquestrar",
    "orquestrariam": "orquestrar",
    "orquestrarias": "orquestrar",
    "orquestrarmo": "orquestrar",
    "orquestrarmos": "orquestrar",
    "orquestrará": "orquestrar",
    "orquestrarás": "orquestrar",
    "orquestrarão": "orquestrar",
    "orquestraríamos": "orquestrar",
    "orquestraríeis": "orquestrar",
    "orquestras": "orquestrar",
    "orquestrasse": "orquestrar",
    "orquestrassem": "orquestrar",
    "orquestrasses": "orquestrar",
    "orquestraste": "orquestrar",
    "orquestrastes": "orquestrar",
    "orquestrava": "orquestrar",
    "orquestravam": "orquestrar",
    "orquestravas": "orquestrar",
    "orquestrações": "orquestração",
    "orquestre": "orquestrar",
    "orquestrei": "orquestrar",
    "orquestreis": "orquestrar",
    "orquestrem": "orquestrar",
    "orquestremo": "orquestrar",
    "orquestremos": "orquestrar",
    "orquestres": "orquestrar",
    "orquestro": "orquestrar",
    "orquestrou": "orquestrar",
    "orquestrá": "orquestrar",
    "orquestrámo": "orquestrar",
    "orquestrámos": "orquestrar",
    "orquestráramo": "orquestrar",
    "orquestráramos": "orquestrar",
    "orquestrárei": "orquestrar",
    "orquestráreis": "orquestrar",
    "orquestrásseis": "orquestrar",
    "orquestrássemos": "orquestrar",
    "orquestrávamo": "orquestrar",
    "orquestrávamos": "orquestrar",
    "orquestrávei": "orquestrar",
    "orquestráveis": "orquestrável",
    "orquialgias": "orquialgia",
    "orquidácea": "orquidáceo",
    "orquidáceas": "orquidáceo",
    "orquidáceos": "orquidáceo",
    "orquiectomias": "orquiectomia",
    "orquioceles": "orquiocele",
    "orquiotomias": "orquiotomia",
    "orquites": "orquite",
    "orquídeas": "orquídea",
    "orretas": "orreta",
    "orticonoscópios": "orticonoscópio",
    "ortiga": "ortigar",
    "ortigada": "ortigar",
    "ortigadas": "ortigar",
    "ortigado": "ortigar",
    "ortigados": "ortigar",
    "ortigai": "ortigar",
    "ortigais": "ortigar",
    "ortigam": "ortigar",
    "ortigamo": "ortigar",
    "ortigamos": "ortigar",
    "ortigando": "ortigar",
    "ortigara": "ortigar",
    "ortigaram": "ortigar",
    "ortigaras": "ortigar",
    "ortigarde": "ortigar",
    "ortigardes": "ortigar",
    "ortigare": "ortigar",
    "ortigarei": "ortigar",
    "ortigareis": "ortigar",
    "ortigarem": "ortigar",
    "ortigaremos": "ortigar",
    "ortigares": "ortigar",
    "ortigaria": "ortigar",
    "ortigariam": "ortigar",
    "ortigarias": "ortigar",
    "ortigarmo": "ortigar",
    "ortigarmos": "ortigar",
    "ortigará": "ortigar",
    "ortigarás": "ortigar",
    "ortigarão": "ortigar",
    "ortigaríamos": "ortigar",
    "ortigaríeis": "ortigar",
    "ortigas": "ortigar",
    "ortigasse": "ortigar",
    "ortigassem": "ortigar",
    "ortigasses": "ortigar",
    "ortigaste": "ortigar",
    "ortigastes": "ortigar",
    "ortigava": "ortigar",
    "ortigavam": "ortigar",
    "ortigavas": "ortigar",
    "ortiginha": "ortiga",
    "ortiginhas": "ortiga",
    "ortigita": "ortiga",
    "ortigitas": "ortiga",
    "ortigo": "ortigar",
    "ortigou": "ortigar",
    "ortigue": "ortigar",
    "ortiguei": "ortigar",
    "ortigueis": "ortigar",
    "ortiguem": "ortigar",
    "ortiguemo": "ortigar",
    "ortiguemos": "ortigar",
    "ortigues": "ortigar",
    "ortigá": "ortigar",
    "ortigámo": "ortigar",
    "ortigámos": "ortigar",
    "ortigáramo": "ortigar",
    "ortigáramos": "ortigar",
    "ortigárei": "ortigar",
    "ortigáreis": "ortigar",
    "ortigásseis": "ortigar",
    "ortigássemos": "ortigar",
    "ortigávamo": "ortigar",
    "ortigávamos": "ortigar",
    "ortigávei": "ortigar",
    "ortigáveis": "ortigar",
    "ortites": "ortite",
    "ortiva": "ortivo",
    "ortivas": "ortivo",
    "ortivos": "ortivo",
    "ortobárica": "ortobárico",
    "ortobáricas": "ortobárico",
    "ortobáricos": "ortobárico",
    "ortocentros": "ortocentro",
    "ortocitoses": "ortocitose",
    "ortoclásios": "ortoclásio",
    "ortocromatismos": "ortocromatismo",
    "ortocromática": "ortocromático",
    "ortocromáticas": "ortocromático",
    "ortocromáticos": "ortocromático",
    "ortocáctila": "ortocáctilo",
    "ortocáctilas": "ortocáctilo",
    "ortocáctilos": "ortocáctilo",
    "ortodiagonais": "ortodiagonal",
    "ortodontes": "ortodonte",
    "ortodontias": "ortodontia",
    "ortodontopedias": "ortodontopedia",
    "ortodoxa": "ortodoxo",
    "ortodoxas": "ortodoxo",
    "ortodoxias": "ortodoxia",
    "ortodoxos": "ortodoxo",
    "ortodromias": "ortodromia",
    "ortoedrias": "ortoedria",
    "ortoepias": "ortoepia",
    "ortofonias": "ortofonia",
    "ortofrenias": "ortofrenia",
    "ortofónica": "ortofónico",
    "ortofónicas": "ortofónico",
    "ortofónicos": "ortofónico",
    "ortogenética": "ortogenético",
    "ortogenéticas": "ortogenético",
    "ortogenéticos": "ortogenético",
    "ortognaisses": "ortognaisse",
    "ortogonais": "ortogonal",
    "ortografa": "ortografar",
    "ortografada": "ortografar",
    "ortografadas": "ortografar",
    "ortografado": "ortografar",
    "ortografados": "ortografar",
    "ortografai": "ortografar",
    "ortografais": "ortografar",
    "ortografam": "ortografar",
    "ortografamo": "ortografar",
    "ortografamos": "ortografar",
    "ortografando": "ortografar",
    "ortografara": "ortografar",
    "ortografaram": "ortografar",
    "ortografaras": "ortografar",
    "ortografarde": "ortografar",
    "ortografardes": "ortografar",
    "ortografare": "ortografar",
    "ortografarei": "ortografar",
    "ortografareis": "ortografar",
    "ortografarem": "ortografar",
    "ortografaremos": "ortografar",
    "ortografares": "ortografar",
    "ortografaria": "ortografar",
    "ortografariam": "ortografar",
    "ortografarias": "ortografar",
    "ortografarmo": "ortografar",
    "ortografarmos": "ortografar",
    "ortografará": "ortografar",
    "ortografarás": "ortografar",
    "ortografarão": "ortografar",
    "ortografaríamos": "ortografar",
    "ortografaríeis": "ortografar",
    "ortografas": "ortografar",
    "ortografasse": "ortografar",
    "ortografassem": "ortografar",
    "ortografasses": "ortografar",
    "ortografaste": "ortografar",
    "ortografastes": "ortografar",
    "ortografava": "ortografar",
    "ortografavam": "ortografar",
    "ortografavas": "ortografar",
    "ortografe": "ortografar",
    "ortografei": "ortografar",
    "ortografeis": "ortografar",
    "ortografem": "ortografar",
    "ortografemo": "ortografar",
    "ortografemos": "ortografar",
    "ortografes": "ortografar",
    "ortografias": "ortografia",
    "ortografistas": "ortografista",
    "ortografo": "ortografar",
    "ortografou": "ortografar",
    "ortografá": "ortografar",
    "ortografámo": "ortografar",
    "ortografámos": "ortografar",
    "ortografáramo": "ortografar",
    "ortografáramos": "ortografar",
    "ortografárei": "ortografar",
    "ortografáreis": "ortografar",
    "ortografásseis": "ortografar",
    "ortografássemos": "ortografar",
    "ortografávamo": "ortografar",
    "ortografávamos": "ortografar",
    "ortografávei": "ortografar",
    "ortografáveis": "ortografar",
    "ortográfica": "ortográfico",
    "ortográficas": "ortográfico",
    "ortográficos": "ortográfico",
    "ortoidrogénios": "ortoidrogénio",
    "ortolexias": "ortolexia",
    "ortologias": "ortologia",
    "ortoléxica": "ortoléxico",
    "ortoléxicas": "ortoléxico",
    "ortoléxicos": "ortoléxico",
    "ortometamórfica": "ortometamórfico",
    "ortometamórficas": "ortometamórfico",
    "ortometamórficos": "ortometamórfico",
    "ortometrias": "ortometria",
    "ortomorfias": "ortomorfia",
    "ortomórfica": "ortomórfico",
    "ortomórficas": "ortomórfico",
    "ortomórficos": "ortomórfico",
    "ortoneurópteros": "ortoneuróptero",
    "ortopedias": "ortopedia",
    "ortopedistas": "ortopedista",
    "ortopinacóides": "ortopinacóide",
    "ortopneias": "ortopneia",
    "ortopnóica": "ortopnóico",
    "ortopnóicas": "ortopnóico",
    "ortopnóicos": "ortopnóico",
    "ortopsicopedias": "ortopsicopedia",
    "ortoptistas": "ortoptista",
    "ortopédica": "ortopédico",
    "ortopédicas": "ortopédico",
    "ortopédicos": "ortopédico",
    "ortoquartzíticos": "ortoquartzítico",
    "ortorrafos": "ortorrafo",
    "ortorrômbica": "ortorrômbico",
    "ortorrômbicas": "ortorrômbico",
    "ortorrômbicos": "ortorrômbico",
    "ortos": "orto",
    "ortosa": "ortose",
    "ortosas": "ortose",
    "ortoscópica": "ortoscópico",
    "ortoscópicas": "ortoscópico",
    "ortoscópicos": "ortoscópico",
    "ortoses": "ortose",
    "ortostasias": "ortostasia",
    "ortostilos": "ortostilo",
    "ortoterapias": "ortoterapia",
    "ortotómica": "ortotómico",
    "ortotómicas": "ortotómico",
    "ortotómicos": "ortotómico",
    "ortoédrica": "ortoédrico",
    "ortoédricas": "ortoédrico",
    "ortoédricos": "ortoédrico",
    "ortoépias": "ortoépia",
    "ortoépica": "ortoépico",
    "ortoépicas": "ortoépico",
    "ortoépicos": "ortoépico",
    "ortógona": "ortógono",
    "ortógonas": "ortógono",
    "ortógonos": "ortógono",
    "ortógrafa": "ortógrafo",
    "ortógrafas": "ortógrafo",
    "ortógrafos": "ortógrafo",
    "ortónimos": "ortónimo",
    "ortóptera": "ortóptero",
    "ortópteras": "ortóptero",
    "ortópteros": "ortóptero",
    "ortótropa": "ortótropo",
    "ortótropas": "ortótropo",
    "ortótropos": "ortótropo",
    "orvalha": "orvalhar",
    "orvalhada": "orvalhar",
    "orvalhadas": "orvalhar",
    "orvalhado": "orvalhar",
    "orvalhados": "orvalhar",
    "orvalhai": "orvalhar",
    "orvalhais": "orvalhar",
    "orvalham": "orvalhar",
    "orvalhamo": "orvalhar",
    "orvalhamos": "orvalhar",
    "orvalhando": "orvalhar",
    "orvalhara": "orvalhar",
    "orvalharam": "orvalhar",
    "orvalharas": "orvalhar",
    "orvalharde": "orvalhar",
    "orvalhardes": "orvalhar",
    "orvalhare": "orvalhar",
    "orvalharei": "orvalhar",
    "orvalhareis": "orvalhar",
    "orvalharem": "orvalhar",
    "orvalharemos": "orvalhar",
    "orvalhares": "orvalhar",
    "orvalharia": "orvalhar",
    "orvalhariam": "orvalhar",
    "orvalharias": "orvalhar",
    "orvalharmo": "orvalhar",
    "orvalharmos": "orvalhar",
    "orvalhará": "orvalhar",
    "orvalharás": "orvalhar",
    "orvalharão": "orvalhar",
    "orvalharíamos": "orvalhar",
    "orvalharíeis": "orvalhar",
    "orvalhas": "orvalhar",
    "orvalhasse": "orvalhar",
    "orvalhassem": "orvalhar",
    "orvalhasses": "orvalhar",
    "orvalhaste": "orvalhar",
    "orvalhastes": "orvalhar",
    "orvalhava": "orvalhar",
    "orvalhavam": "orvalhar",
    "orvalhavas": "orvalhar",
    "orvalhe": "orvalhar",
    "orvalhei": "orvalhar",
    "orvalheiras": "orvalheira",
    "orvalheis": "orvalhar",
    "orvalhem": "orvalhar",
    "orvalhemo": "orvalhar",
    "orvalhemos": "orvalhar",
    "orvalhes": "orvalhar",
    "orvalhinhas": "orvalhinha",
    "orvalhinho": "orvalho",
    "orvalhinhos": "orvalho",
    "orvalhito": "orvalho",
    "orvalhitos": "orvalho",
    "orvalho": "orvalhar",
    "orvalhos": "orvalho",
    "orvalhosa": "orvalhoso",
    "orvalhosas": "orvalhoso",
    "orvalhosos": "orvalhoso",
    "orvalhou": "orvalhar",
    "orvalhá": "orvalhar",
    "orvalhámo": "orvalhar",
    "orvalhámos": "orvalhar",
    "orvalháramo": "orvalhar",
    "orvalháramos": "orvalhar",
    "orvalhárei": "orvalhar",
    "orvalháreis": "orvalhar",
    "orvalhásseis": "orvalhar",
    "orvalhássemos": "orvalhar",
    "orvalhávamo": "orvalhar",
    "orvalhávamos": "orvalhar",
    "orvalhávei": "orvalhar",
    "orvalháveis": "orvalhar",
    "oráculos": "oráculo",
    "orámo": "orar",
    "orámos": "orar",
    "oráramo": "orar",
    "oráramos": "orar",
    "oráreis": "orar",
    "orários": "orário",
    "orásseis": "orar",
    "orássemos": "orar",
    "orávamo": "orar",
    "orávamos": "orar",
    "oráveis": "orar",
    "orça": "orçar",
    "orçada": "orçar",
    "orçadas": "orçar",
    "orçado": "orçar",
    "orçadora": "orçador",
    "orçadoras": "orçador",
    "orçadores": "orçador",
    "orçados": "orçar",
    "orçai": "orçar",
    "orçais": "orçar",
    "orçam": "orçar",
    "orçamenta": "orçamentar",
    "orçamentada": "orçamentar",
    "orçamentadas": "orçamentar",
    "orçamentado": "orçamentar",
    "orçamentados": "orçamentar",
    "orçamentai": "orçamentar",
    "orçamentais": "orçamentar",
    "orçamentam": "orçamentar",
    "orçamentamo": "orçamentar",
    "orçamentamos": "orçamentar",
    "orçamentando": "orçamentar",
    "orçamentar": "amentar",
    "orçamentara": "orçamentar",
    "orçamentaram": "orçamentar",
    "orçamentaras": "orçamentar",
    "orçamentarde": "orçamentar",
    "orçamentardes": "orçamentar",
    "orçamentare": "orçamentar",
    "orçamentarei": "orçamentar",
    "orçamentareis": "orçamentar",
    "orçamentarem": "orçamentar",
    "orçamentaremos": "orçamentar",
    "orçamentares": "orçamentar",
    "orçamentaria": "orçamentar",
    "orçamentariam": "orçamentar",
    "orçamentarias": "orçamentar",
    "orçamentarmo": "orçamentar",
    "orçamentarmos": "orçamentar",
    "orçamentará": "orçamentar",
    "orçamentarás": "orçamentar",
    "orçamentarão": "orçamentar",
    "orçamentaríamos": "orçamentar",
    "orçamentaríeis": "orçamentar",
    "orçamentas": "orçamentar",
    "orçamentasse": "orçamentar",
    "orçamentassem": "orçamentar",
    "orçamentasses": "orçamentar",
    "orçamentaste": "orçamentar",
    "orçamentastes": "orçamentar",
    "orçamentava": "orçamentar",
    "orçamentavam": "orçamentar",
    "orçamentavas": "orçamentar",
    "orçamente": "orçamentar",
    "orçamentei": "orçamentar",
    "orçamenteis": "orçamentar",
    "orçamentem": "orçamentar",
    "orçamentemo": "orçamentar",
    "orçamentemos": "orçamentar",
    "orçamentes": "orçamentar",
    "orçamentistas": "orçamentista",
    "orçamento": "orçamentar",
    "orçamentos": "orçamento",
    "orçamentou": "orçamentar",
    "orçamentá": "orçamentar",
    "orçamentámo": "orçamentar",
    "orçamentámos": "orçamentar",
    "orçamentáramo": "orçamentar",
    "orçamentáramos": "orçamentar",
    "orçamentárei": "orçamentar",
    "orçamentáreis": "orçamentar",
    "orçamentárua": "orçamentáruo",
    "orçamentáruas": "orçamentáruo",
    "orçamentáruos": "orçamentáruo",
    "orçamentásseis": "orçamentar",
    "orçamentássemos": "orçamentar",
    "orçamentávamo": "orçamentar",
    "orçamentávamos": "orçamentar",
    "orçamentávei": "orçamentar",
    "orçamentáveis": "orçamentável",
    "orçamo": "orçar",
    "orçamos": "orçar",
    "orçando": "orçar",
    "orçara": "orçar",
    "orçaram": "orçar",
    "orçaras": "orçar",
    "orçarde": "orçar",
    "orçardes": "orçar",
    "orçare": "orçar",
    "orçarei": "orçar",
    "orçareis": "orçar",
    "orçarem": "orçar",
    "orçaremos": "orçar",
    "orçares": "orçar",
    "orçaria": "orçar",
    "orçariam": "orçar",
    "orçarias": "orçar",
    "orçarmo": "orçar",
    "orçarmos": "orçar",
    "orçará": "orçar",
    "orçarás": "orçar",
    "orçarão": "orçar",
    "orçaríamos": "orçar",
    "orçaríeis": "orçar",
    "orças": "orçar",
    "orçasse": "orçar",
    "orçassem": "orçar",
    "orçasses": "orçar",
    "orçaste": "orçar",
    "orçastes": "orçar",
    "orçava": "orçar",
    "orçavam": "orçar",
    "orçavas": "orçar",
    "orçazes": "orçaz",
    "orço": "orçar",
    "orçou": "orçar",
    "orçá": "orçar",
    "orçámo": "orçar",
    "orçámos": "orçar",
    "orçáramo": "orçar",
    "orçáramos": "orçar",
    "orçárei": "orçar",
    "orçáreis": "orçar",
    "orçásseis": "orçar",
    "orçássemos": "orçar",
    "orçávamo": "orçar",
    "orçávamos": "orçar",
    "orçávei": "orçar",
    "orçáveis": "orçável",
    "oréades": "oréade",
    "orégões": "orégão",
    "orélias": "orélia",
    "oríbatas": "oríbata",
    "orízeas": "orízea",
    "orófitos": "orófito",
    "orógrafa": "orógrafo",
    "orógrafas": "orógrafo",
    "orógrafos": "orógrafo",
    "orómetros": "orómetro",
    "os": "o",
    "osca": "osco",
    "oscas": "osco",
    "oscila": "oscilar",
    "oscilada": "oscilar",
    "osciladas": "oscilar",
    "oscilado": "oscilar",
    "osciladora": "oscilador",
    "osciladoras": "oscilador",
    "osciladores": "oscilador",
    "oscilados": "oscilar",
    "oscilai": "oscilar",
    "oscilais": "oscilar",
    "oscilam": "oscilar",
    "oscilamo": "oscilar",
    "oscilamos": "oscilar",
    "oscilando": "oscilar",
    "oscilantes": "oscilante",
    "oscilara": "oscilar",
    "oscilaram": "oscilar",
    "oscilaras": "oscilar",
    "oscilardes": "oscilar",
    "oscilarei": "oscilar",
    "oscilareis": "oscilar",
    "oscilarem": "oscilar",
    "oscilaremos": "oscilar",
    "oscilares": "oscilar",
    "oscilaria": "oscilar",
    "oscilariam": "oscilar",
    "oscilarias": "oscilar",
    "oscilarmo": "oscilar",
    "oscilarmos": "oscilar",
    "oscilará": "oscilar",
    "oscilarás": "oscilar",
    "oscilarão": "oscilar",
    "oscilaríamos": "oscilar",
    "oscilaríeis": "oscilar",
    "oscilas": "oscilar",
    "oscilasse": "oscilar",
    "oscilassem": "oscilar",
    "oscilasses": "oscilar",
    "oscilaste": "oscilar",
    "oscilastes": "oscilar",
    "oscilatoriáceas": "oscilatoriácea",
    "oscilatória": "oscilatório",
    "oscilatórias": "oscilatório",
    "oscilatórios": "oscilatório",
    "oscilava": "oscilar",
    "oscilavam": "oscilar",
    "oscilavas": "oscilar",
    "oscilações": "oscilação",
    "oscile": "oscilar",
    "oscilei": "oscilar",
    "oscileis": "oscilar",
    "oscilem": "oscilar",
    "oscilemo": "oscilar",
    "oscilemos": "oscilar",
    "osciles": "oscilar",
    "oscilo": "oscilar",
    "osciloscópios": "osciloscópio",
    "oscilou": "oscilar",
    "oscilámo": "oscilar",
    "oscilámos": "oscilar",
    "osciláramo": "oscilar",
    "osciláramos": "oscilar",
    "osciláreis": "oscilar",
    "oscilárias": "oscilária",
    "oscilásseis": "oscilar",
    "oscilássemos": "oscilar",
    "oscilávamo": "oscilar",
    "oscilávamos": "oscilar",
    "osciláveis": "oscilar",
    "oscilógrafos": "oscilógrafo",
    "oscilómetros": "oscilómetro",
    "oscita": "oscitar",
    "oscitada": "oscitar",
    "oscitadas": "oscitar",
    "oscitado": "oscitar",
    "oscitados": "oscitar",
    "oscitai": "oscitar",
    "oscitais": "oscitar",
    "oscitam": "oscitar",
    "oscitamo": "oscitar",
    "oscitamos": "oscitar",
    "oscitando": "oscitar",
    "oscitantes": "oscitante",
    "oscitara": "oscitar",
    "oscitaram": "oscitar",
    "oscitaras": "oscitar",
    "oscitardes": "oscitar",
    "oscitarei": "oscitar",
    "oscitareis": "oscitar",
    "oscitarem": "oscitar",
    "oscitaremos": "oscitar",
    "oscitares": "oscitar",
    "oscitaria": "oscitar",
    "oscitariam": "oscitar",
    "oscitarias": "oscitar",
    "oscitarmo": "oscitar",
    "oscitarmos": "oscitar",
    "oscitará": "oscitar",
    "oscitarás": "oscitar",
    "oscitarão": "oscitar",
    "oscitaríamos": "oscitar",
    "oscitaríeis": "oscitar",
    "oscitas": "oscitar",
    "oscitasse": "oscitar",
    "oscitassem": "oscitar",
    "oscitasses": "oscitar",
    "oscitaste": "oscitar",
    "oscitastes": "oscitar",
    "oscitava": "oscitar",
    "oscitavam": "oscitar",
    "oscitavas": "oscitar",
    "oscitações": "oscitação",
    "oscite": "oscitar",
    "oscitei": "oscitar",
    "osciteis": "oscitar",
    "oscitem": "oscitar",
    "oscitemo": "oscitar",
    "oscitemos": "oscitar",
    "oscites": "oscitar",
    "oscito": "oscitar",
    "oscitou": "oscitar",
    "oscitámo": "oscitar",
    "oscitámos": "oscitar",
    "oscitáramo": "oscitar",
    "oscitáramos": "oscitar",
    "oscitáreis": "oscitar",
    "oscitásseis": "oscitar",
    "oscitássemos": "oscitar",
    "oscitávamo": "oscitar",
    "oscitávamos": "oscitar",
    "oscitáveis": "oscitar",
    "oscos": "osco",
    "oscula": "oscular",
    "osculada": "oscular",
    "osculadas": "oscular",
    "osculado": "oscular",
    "osculadora": "osculador",
    "osculadoras": "osculador",
    "osculadores": "osculador",
    "osculados": "oscular",
    "osculai": "oscular",
    "osculais": "oscular",
    "osculam": "oscular",
    "osculamo": "oscular",
    "osculamos": "oscular",
    "osculando": "oscular",
    "osculara": "oscular",
    "oscularam": "oscular",
    "oscularas": "oscular",
    "oscularde": "oscular",
    "osculardes": "oscular",
    "osculare": "oscular",
    "oscularei": "oscular",
    "osculareis": "oscular",
    "oscularem": "oscular",
    "oscularemos": "oscular",
    "osculares": "oscular",
    "oscularia": "oscular",
    "osculariam": "oscular",
    "oscularias": "oscular",
    "oscularmo": "oscular",
    "oscularmos": "oscular",
    "osculará": "oscular",
    "oscularás": "oscular",
    "oscularão": "oscular",
    "oscularíamos": "oscular",
    "oscularíeis": "oscular",
    "osculas": "oscular",
    "osculasse": "oscular",
    "osculassem": "oscular",
    "osculasses": "oscular",
    "osculaste": "oscular",
    "osculastes": "oscular",
    "osculatória": "osculatório",
    "osculatórias": "osculatório",
    "osculatórios": "osculatório",
    "osculava": "oscular",
    "osculavam": "oscular",
    "osculavas": "oscular",
    "osculações": "osculação",
    "oscule": "oscular",
    "osculei": "oscular",
    "osculeis": "oscular",
    "osculem": "oscular",
    "osculemo": "oscular",
    "osculemos": "oscular",
    "oscules": "oscular",
    "osculo": "oscular",
    "osculou": "oscular",
    "osculá": "oscular",
    "osculámo": "oscular",
    "osculámos": "oscular",
    "osculáramo": "oscular",
    "osculáramos": "oscular",
    "osculárei": "oscular",
    "osculáreis": "oscular",
    "osculásseis": "oscular",
    "osculássemos": "oscular",
    "osculávamo": "oscular",
    "osculávamos": "oscular",
    "osculávei": "oscular",
    "osculáveis": "oscular",
    "oses": "ose",
    "osfresiologias": "osfresiologia",
    "osgas": "osga",
    "osmandis": "osmandi",
    "osmanlis": "osmanli",
    "osmazomas": "osmazoma",
    "osmirídios": "osmirídio",
    "osmologias": "osmologia",
    "osmológica": "osmológico",
    "osmológicas": "osmológico",
    "osmológicos": "osmológico",
    "osmoses": "osmose",
    "osmundácea": "osmundáceo",
    "osmundáceas": "osmundáceo",
    "osmundáceos": "osmundáceo",
    "osmática": "osmático",
    "osmáticas": "osmático",
    "osmáticos": "osmático",
    "osmómetros": "osmómetro",
    "osmótica": "osmótico",
    "osmóticas": "osmótico",
    "osmóticos": "osmótico",
    "ossadas": "ossada",
    "ossamentas": "ossamenta",
    "ossamentos": "ossamento",
    "ossarias": "ossaria",
    "ossariozinho": "ossário",
    "ossariozinhos": "ossário",
    "ossariozito": "ossário",
    "ossariozitos": "ossário",
    "ossaturas": "ossatura",
    "osseínas": "osseína",
    "ossiculada": "ossiculado",
    "ossiculadas": "ossiculado",
    "ossiculados": "ossiculado",
    "ossiculares": "ossicular",
    "ossifica": "ossificar",
    "ossificada": "ossificar",
    "ossificadas": "ossificar",
    "ossificado": "ossificar",
    "ossificados": "ossificar",
    "ossificai": "ossificar",
    "ossificais": "ossificar",
    "ossificam": "ossificar",
    "ossificamo": "ossificar",
    "ossificamos": "ossificar",
    "ossificando": "ossificar",
    "ossificara": "ossificar",
    "ossificaram": "ossificar",
    "ossificaras": "ossificar",
    "ossificarde": "ossificar",
    "ossificardes": "ossificar",
    "ossificare": "ossificar",
    "ossificarei": "ossificar",
    "ossificareis": "ossificar",
    "ossificarem": "ossificar",
    "ossificaremos": "ossificar",
    "ossificares": "ossificar",
    "ossificaria": "ossificar",
    "ossificariam": "ossificar",
    "ossificarias": "ossificar",
    "ossificarmo": "ossificar",
    "ossificarmos": "ossificar",
    "ossificará": "ossificar",
    "ossificarás": "ossificar",
    "ossificarão": "ossificar",
    "ossificaríamos": "ossificar",
    "ossificaríeis": "ossificar",
    "ossificas": "ossificar",
    "ossificasse": "ossificar",
    "ossificassem": "ossificar",
    "ossificasses": "ossificar",
    "ossificaste": "ossificar",
    "ossificastes": "ossificar",
    "ossificava": "ossificar",
    "ossificavam": "ossificar",
    "ossificavas": "ossificar",
    "ossificações": "ossificação",
    "ossifico": "ossificar",
    "ossificou": "ossificar",
    "ossificá": "ossificar",
    "ossificámo": "ossificar",
    "ossificámos": "ossificar",
    "ossificáramo": "ossificar",
    "ossificáramos": "ossificar",
    "ossificárei": "ossificar",
    "ossificáreis": "ossificar",
    "ossificásseis": "ossificar",
    "ossificássemos": "ossificar",
    "ossificávamo": "ossificar",
    "ossificávamos": "ossificar",
    "ossificávei": "ossificar",
    "ossificáveis": "ossificar",
    "ossifique": "ossificar",
    "ossifiquei": "ossificar",
    "ossifiqueis": "ossificar",
    "ossifiquem": "ossificar",
    "ossifiquemo": "ossificar",
    "ossifiquemos": "ossificar",
    "ossifiques": "ossificar",
    "ossiformes": "ossiforme",
    "ossinho": "osso",
    "ossinhos": "osso",
    "ossito": "osso",
    "ossitos": "osso",
    "ossiânica": "ossiânico",
    "ossiânicas": "ossiânico",
    "ossiânicos": "ossiânico",
    "ossos": "osso",
    "ossuda": "ossudo",
    "ossudas": "ossudo",
    "ossudos": "ossudo",
    "ossuosa": "ossuoso",
    "ossuosas": "ossuoso",
    "ossuosos": "ossuoso",
    "ossuários": "ossuário",
    "ossários": "ossário",
    "ossículos": "ossículo",
    "ossífera": "ossífero",
    "ossíferas": "ossífero",
    "ossíferos": "ossífero",
    "ossífraga": "ossífrago",
    "ossífragas": "ossífrago",
    "ossífragos": "ossífrago",
    "ossívora": "ossívoro",
    "ossívoras": "ossívoro",
    "ossívoros": "ossívoro",
    "ostagas": "ostaga",
    "ostealgias": "ostealgia",
    "ostensiva": "ostensivo",
    "ostensivas": "ostensivo",
    "ostensivos": "ostensivo",
    "ostensora": "ostensor",
    "ostensoras": "ostensor",
    "ostensores": "ostensor",
    "ostensíveis": "ostensível",
    "ostensória": "ostensório",
    "ostensórias": "ostensório",
    "ostensórios": "ostensório",
    "ostensões": "ostensão",
    "ostenta": "ostentar",
    "ostentada": "ostentar",
    "ostentadas": "ostentar",
    "ostentado": "ostentar",
    "ostentadora": "ostentador",
    "ostentadoras": "ostentador",
    "ostentadores": "ostentador",
    "ostentados": "ostentar",
    "ostentai": "ostentar",
    "ostentais": "ostentar",
    "ostentam": "ostentar",
    "ostentamo": "ostentar",
    "ostentamos": "ostentar",
    "ostentando": "ostentar",
    "ostentara": "ostentar",
    "ostentaram": "ostentar",
    "ostentaras": "ostentar",
    "ostentarde": "ostentar",
    "ostentardes": "ostentar",
    "ostentare": "ostentar",
    "ostentarei": "ostentar",
    "ostentareis": "ostentar",
    "ostentarem": "ostentar",
    "ostentaremos": "ostentar",
    "ostentares": "ostentar",
    "ostentaria": "ostentar",
    "ostentariam": "ostentar",
    "ostentarias": "ostentar",
    "ostentarmo": "ostentar",
    "ostentarmos": "ostentar",
    "ostentará": "ostentar",
    "ostentarás": "ostentar",
    "ostentarão": "ostentar",
    "ostentaríamos": "ostentar",
    "ostentaríeis": "ostentar",
    "ostentas": "ostentar",
    "ostentasse": "ostentar",
    "ostentassem": "ostentar",
    "ostentasses": "ostentar",
    "ostentaste": "ostentar",
    "ostentastes": "ostentar",
    "ostentativa": "ostentativo",
    "ostentativas": "ostentativo",
    "ostentativos": "ostentativo",
    "ostentava": "ostentar",
    "ostentavam": "ostentar",
    "ostentavas": "ostentar",
    "ostentações": "ostentação",
    "ostente": "ostentar",
    "ostentei": "ostentar",
    "ostenteis": "ostentar",
    "ostentem": "ostentar",
    "ostentemo": "ostentar",
    "ostentemos": "ostentar",
    "ostentes": "ostentar",
    "ostento": "ostentar",
    "ostentosa": "ostentoso",
    "ostentosas": "ostentoso",
    "ostentosos": "ostentoso",
    "ostentou": "ostentar",
    "ostentá": "ostentar",
    "ostentámo": "ostentar",
    "ostentámos": "ostentar",
    "ostentáramo": "ostentar",
    "ostentáramos": "ostentar",
    "ostentárei": "ostentar",
    "ostentáreis": "ostentar",
    "ostentásseis": "ostentar",
    "ostentássemos": "ostentar",
    "ostentávamo": "ostentar",
    "ostentávamos": "ostentar",
    "ostentávei": "ostentar",
    "ostentáveis": "ostentar",
    "osteoblastos": "osteoblasto",
    "osteoceles": "osteocele",
    "osteoclases": "osteoclase",
    "osteoclastias": "osteoclastia",
    "osteoclastos": "osteoclasto",
    "osteocolas": "osteocola",
    "osteoderma": "osteodermo",
    "osteodermas": "osteodermo",
    "osteodermos": "osteodermo",
    "osteodinias": "osteodinia",
    "osteofimias": "osteofimia",
    "osteofítica": "osteofítico",
    "osteofíticas": "osteofítico",
    "osteofíticos": "osteofítico",
    "osteoganóides": "osteoganóide",
    "osteogenias": "osteogenia",
    "osteografias": "osteografia",
    "osteográfica": "osteográfico",
    "osteográficas": "osteográfico",
    "osteográficos": "osteográfico",
    "osteogéneses": "osteogénese",
    "osteogénica": "osteogénico",
    "osteogénicas": "osteogénico",
    "osteogénicos": "osteogénico",
    "osteologias": "osteologia",
    "osteologistas": "osteologista",
    "osteomas": "osteoma",
    "osteometrias": "osteometria",
    "osteomielites": "osteomielite",
    "osteomizada": "osteomizado",
    "osteomizadas": "osteomizado",
    "osteomizados": "osteomizado",
    "osteométrica": "osteométrico",
    "osteométricas": "osteométrico",
    "osteométricos": "osteométrico",
    "osteopatias": "osteopatia",
    "osteoperiosteítes": "osteoperiosteíte",
    "osteoplastias": "osteoplastia",
    "osteoplastos": "osteoplasto",
    "osteoporoses": "osteoporose",
    "osteossarcomas": "osteossarcoma",
    "osteotomias": "osteotomia",
    "osteotómica": "osteotómico",
    "osteotómicas": "osteotómico",
    "osteotómicos": "osteotómico",
    "osteozoária": "osteozoário",
    "osteozoárias": "osteozoário",
    "osteozoários": "osteozoário",
    "ostes": "oste",
    "osteálgica": "osteálgico",
    "osteálgicas": "osteálgico",
    "osteálgicos": "osteálgico",
    "osteínas": "osteína",
    "osteítes": "osteíte",
    "osteócitos": "osteócito",
    "osteófaga": "osteófago",
    "osteófagas": "osteófago",
    "osteófagos": "osteófago",
    "osteófitos": "osteófito",
    "osteólitos": "osteólito",
    "osteóloga": "osteólogo",
    "osteólogas": "osteólogo",
    "osteólogos": "osteólogo",
    "osteótomos": "osteótomo",
    "ostiariatos": "ostiariato",
    "ostiários": "ostiário",
    "ostomizada": "ostomizado",
    "ostomizadas": "ostomizado",
    "ostomizados": "ostomizado",
    "ostraceiros": "ostraceiro",
    "ostracina": "ostracino",
    "ostracinas": "ostracino",
    "ostracinos": "ostracino",
    "ostracionídeos": "ostracionídeo",
    "ostracismos": "ostracismo",
    "ostracistas": "ostracista",
    "ostraciza": "ostracizar",
    "ostracizada": "ostracizar",
    "ostracizadas": "ostracizar",
    "ostracizado": "ostracizar",
    "ostracizados": "ostracizar",
    "ostracizai": "ostracizar",
    "ostracizais": "ostracizar",
    "ostracizam": "ostracizar",
    "ostracizamo": "ostracizar",
    "ostracizamos": "ostracizar",
    "ostracizando": "ostracizar",
    "ostracizara": "ostracizar",
    "ostracizaram": "ostracizar",
    "ostracizaras": "ostracizar",
    "ostracizarde": "ostracizar",
    "ostracizardes": "ostracizar",
    "ostracizare": "ostracizar",
    "ostracizarei": "ostracizar",
    "ostracizareis": "ostracizar",
    "ostracizarem": "ostracizar",
    "ostracizaremos": "ostracizar",
    "ostracizares": "ostracizar",
    "ostracizaria": "ostracizar",
    "ostracizariam": "ostracizar",
    "ostracizarias": "ostracizar",
    "ostracizarmo": "ostracizar",
    "ostracizarmos": "ostracizar",
    "ostracizará": "ostracizar",
    "ostracizarás": "ostracizar",
    "ostracizarão": "ostracizar",
    "ostracizaríamos": "ostracizar",
    "ostracizaríeis": "ostracizar",
    "ostracizas": "ostracizar",
    "ostracizasse": "ostracizar",
    "ostracizassem": "ostracizar",
    "ostracizasses": "ostracizar",
    "ostracizaste": "ostracizar",
    "ostracizastes": "ostracizar",
    "ostracizava": "ostracizar",
    "ostracizavam": "ostracizar",
    "ostracizavas": "ostracizar",
    "ostracize": "ostracizar",
    "ostracizei": "ostracizar",
    "ostracizeis": "ostracizar",
    "ostracizem": "ostracizar",
    "ostracizemo": "ostracizar",
    "ostracizemos": "ostracizar",
    "ostracizes": "ostracizar",
    "ostracizo": "ostracizar",
    "ostracizou": "ostracizar",
    "ostracizá": "ostracizar",
    "ostracizámo": "ostracizar",
    "ostracizámos": "ostracizar",
    "ostracizáramo": "ostracizar",
    "ostracizáramos": "ostracizar",
    "ostracizárei": "ostracizar",
    "ostracizáreis": "ostracizar",
    "ostracizásseis": "ostracizar",
    "ostracizássemos": "ostracizar",
    "ostracizávamo": "ostracizar",
    "ostracizávamos": "ostracizar",
    "ostracizávei": "ostracizar",
    "ostracizáveis": "ostracizar",
    "ostracodermos": "ostracodermo",
    "ostracodes": "ostracode",
    "ostracologias": "ostracologia",
    "ostrarias": "ostraria",
    "ostras": "ostra",
    "ostrazinha": "ostra",
    "ostrazinhas": "ostra",
    "ostrazita": "ostra",
    "ostrazitas": "ostra",
    "ostreicultora": "ostreicultor",
    "ostreicultoras": "ostreicultor",
    "ostreicultores": "ostreicultor",
    "ostreiculturas": "ostreicultura",
    "ostreidas": "ostreida",
    "ostreiformes": "ostreiforme",
    "ostreira": "ostreiro",
    "ostreiras": "ostreiro",
    "ostreiros": "ostreiro",
    "ostreícolas": "ostreícola",
    "ostreídeos": "ostreídeo",
    "ostreífera": "ostreífero",
    "ostreíferas": "ostreífero",
    "ostreíferos": "ostreífero",
    "ostreínas": "ostreína",
    "ostricultora": "ostricultor",
    "ostricultoras": "ostricultor",
    "ostricultores": "ostricultor",
    "ostriculturas": "ostricultura",
    "ostrinha": "ostra",
    "ostrinhas": "ostra",
    "ostrita": "ostra",
    "ostritas": "ostra",
    "ostrogoda": "ostrogodo",
    "ostrogodas": "ostrogodo",
    "ostrogodos": "ostrogodo",
    "ostrácea": "ostráceo",
    "ostráceas": "ostráceo",
    "ostráceos": "ostráceo",
    "ostrífera": "ostrífero",
    "ostríferas": "ostrífero",
    "ostríferos": "ostrífero",
    "ostíolos": "ostíolo",
    "otalgias": "otalgia",
    "otites": "otite",
    "otoantrites": "otoantrite",
    "otocéfala": "otocéfalo",
    "otocéfalas": "otocéfalo",
    "otocéfalos": "otocéfalo",
    "otodinias": "otodinia",
    "otologias": "otologia",
    "otologistas": "otologista",
    "otolítica": "otolítico",
    "otolíticas": "otolítico",
    "otolíticos": "otolítico",
    "otológica": "otológico",
    "otológicas": "otológico",
    "otológicos": "otológico",
    "otomana": "otomano",
    "otomanas": "otomano",
    "otomanos": "otomano",
    "otopatias": "otopatia",
    "otoplastias": "otoplastia",
    "otorrinolaringologias": "otorrinolaringologia",
    "otorrinolaringologistas": "otorrinolaringologista",
    "otorrinos": "otorrino",
    "otoscleroses": "otosclerose",
    "otoscopias": "otoscopia",
    "otoscópios": "otoscópio",
    "otoses": "otose",
    "ototerápica": "ototerápico",
    "ototerápicas": "ototerápico",
    "ototerápicos": "ototerápico",
    "ototomias": "ototomia",
    "otozamites": "otozamite",
    "otálgica": "otálgico",
    "otálgicas": "otálgico",
    "otálgicos": "otálgico",
    "otárias": "otária",
    "otários": "otário",
    "otólitos": "otólito",
    "ouga": "ougar",
    "ougada": "ougar",
    "ougadas": "ougar",
    "ougado": "ougar",
    "ougados": "ougar",
    "ougai": "ougar",
    "ougais": "ougar",
    "ougam": "ougar",
    "ougamo": "ougar",
    "ougamos": "ougar",
    "ougando": "ougar",
    "ougara": "ougar",
    "ougaram": "ougar",
    "ougaras": "ougar",
    "ougardes": "ougar",
    "ougarei": "ougar",
    "ougareis": "ougar",
    "ougarem": "ougar",
    "ougaremos": "ougar",
    "ougares": "ougar",
    "ougaria": "ougar",
    "ougariam": "ougar",
    "ougarias": "ougar",
    "ougarmo": "ougar",
    "ougarmos": "ougar",
    "ougará": "ougar",
    "ougarás": "ougar",
    "ougarão": "ougar",
    "ougaríamos": "ougar",
    "ougaríeis": "ougar",
    "ougas": "ougar",
    "ougasse": "ougar",
    "ougassem": "ougar",
    "ougasses": "ougar",
    "ougaste": "ougar",
    "ougastes": "ougar",
    "ougava": "ougar",
    "ougavam": "ougar",
    "ougavas": "ougar",
    "ougo": "ougar",
    "ougou": "ougar",
    "ougue": "ougar",
    "ouguei": "ougar",
    "ougueis": "ougar",
    "ouguem": "ougar",
    "ouguemo": "ougar",
    "ouguemos": "ougar",
    "ougues": "ougar",
    "ougámo": "ougar",
    "ougámos": "ougar",
    "ougáramo": "ougar",
    "ougáramos": "ougar",
    "ougáreis": "ougar",
    "ougásseis": "ougar",
    "ougássemos": "ougar",
    "ougávamo": "ougar",
    "ougávamos": "ougar",
    "ougáveis": "ougar",
    "oura": "ourar",
    "ourada": "ourar",
    "ouradas": "ourar",
    "ourado": "ourar",
    "ourados": "ourar",
    "ourai": "ourar",
    "ourais": "ourar",
    "ouram": "ourar",
    "ouramas": "ourama",
    "ouramo": "ourar",
    "ouramos": "ourar",
    "ourando": "ourar",
    "ourara": "ourar",
    "ouraram": "ourar",
    "ouraras": "ourar",
    "ourarde": "ourar",
    "ourardes": "ourar",
    "ourare": "ourar",
    "ourarei": "ourar",
    "ourareis": "ourar",
    "ourarem": "ourar",
    "ouraremos": "ourar",
    "ourares": "ourar",
    "ouraria": "ourar",
    "ourariam": "ourar",
    "ourarias": "ourar",
    "ourarmo": "ourar",
    "ourarmos": "ourar",
    "ourará": "ourar",
    "ourarás": "ourar",
    "ourarão": "ourar",
    "ouraríamos": "ourar",
    "ouraríeis": "ourar",
    "ouras": "ourar",
    "ourasse": "ourar",
    "ourassem": "ourar",
    "ourasses": "ourar",
    "ouraste": "ourar",
    "ourastes": "ourar",
    "ourava": "ourar",
    "ouravam": "ourar",
    "ouravas": "ourar",
    "oure": "ourar",
    "ouregos": "ourego",
    "ourei": "ourar",
    "oureis": "ourar",
    "oureja": "ourejar",
    "ourejada": "ourejar",
    "ourejadas": "ourejar",
    "ourejado": "ourejar",
    "ourejados": "ourejar",
    "ourejai": "ourejar",
    "ourejais": "ourejar",
    "ourejam": "ourejar",
    "ourejamo": "ourejar",
    "ourejamos": "ourejar",
    "ourejando": "ourejar",
    "ourejara": "ourejar",
    "ourejaram": "ourejar",
    "ourejaras": "ourejar",
    "ourejarde": "ourejar",
    "ourejardes": "ourejar",
    "ourejare": "ourejar",
    "ourejarei": "ourejar",
    "ourejareis": "ourejar",
    "ourejarem": "ourejar",
    "ourejaremos": "ourejar",
    "ourejares": "ourejar",
    "ourejaria": "ourejar",
    "ourejariam": "ourejar",
    "ourejarias": "ourejar",
    "ourejarmo": "ourejar",
    "ourejarmos": "ourejar",
    "ourejará": "ourejar",
    "ourejarás": "ourejar",
    "ourejarão": "ourejar",
    "ourejaríamos": "ourejar",
    "ourejaríeis": "ourejar",
    "ourejas": "ourejar",
    "ourejasse": "ourejar",
    "ourejassem": "ourejar",
    "ourejasses": "ourejar",
    "ourejaste": "ourejar",
    "ourejastes": "ourejar",
    "ourejava": "ourejar",
    "ourejavam": "ourejar",
    "ourejavas": "ourejar",
    "oureje": "ourejar",
    "ourejei": "ourejar",
    "ourejeis": "ourejar",
    "ourejem": "ourejar",
    "ourejemo": "ourejar",
    "ourejemos": "ourejar",
    "ourejes": "ourejar",
    "ourejo": "ourejar",
    "ourejou": "ourejar",
    "ourejá": "ourejar",
    "ourejámo": "ourejar",
    "ourejámos": "ourejar",
    "ourejáramo": "ourejar",
    "ourejáramos": "ourejar",
    "ourejárei": "ourejar",
    "ourejáreis": "ourejar",
    "ourejásseis": "ourejar",
    "ourejássemos": "ourejar",
    "ourejávamo": "ourejar",
    "ourejávamos": "ourejar",
    "ourejávei": "ourejar",
    "ourejáveis": "ourejar",
    "ourelas": "ourela",
    "ourelos": "ourelo",
    "ourem": "ourar",
    "ouremo": "ourar",
    "ouremos": "ourar",
    "oures": "ourar",
    "ourice": "ouriçar",
    "ouricei": "ouriçar",
    "ouriceis": "ouriçar",
    "ouricem": "ouriçar",
    "ouricemo": "ouriçar",
    "ouricemos": "ouriçar",
    "ourices": "ouriçar",
    "ourinques": "ourinque",
    "ourivesarias": "ourivesaria",
    "ouriça": "ouriçar",
    "ouriçada": "ouriçar",
    "ouriçadas": "ouriçar",
    "ouriçado": "ouriçar",
    "ouriçados": "ouriçar",
    "ouriçai": "ouriçar",
    "ouriçais": "ouriçar",
    "ouriçam": "ouriçar",
    "ouriçamo": "ouriçar",
    "ouriçamos": "ouriçar",
    "ouriçanas": "ouriçana",
    "ouriçando": "ouriçar",
    "ouriçara": "ouriçar",
    "ouriçaram": "ouriçar",
    "ouriçaras": "ouriçar",
    "ouriçarde": "ouriçar",
    "ouriçardes": "ouriçar",
    "ouriçare": "ouriçar",
    "ouriçarei": "ouriçar",
    "ouriçareis": "ouriçar",
    "ouriçarem": "ouriçar",
    "ouriçaremos": "ouriçar",
    "ouriçares": "ouriçar",
    "ouriçaria": "ouriçar",
    "ouriçariam": "ouriçar",
    "ouriçarias": "ouriçar",
    "ouriçarmo": "ouriçar",
    "ouriçarmos": "ouriçar",
    "ouriçará": "ouriçar",
    "ouriçarás": "ouriçar",
    "ouriçarão": "ouriçar",
    "ouriçaríamos": "ouriçar",
    "ouriçaríeis": "ouriçar",
    "ouriças": "ouriçar",
    "ouriçasse": "ouriçar",
    "ouriçassem": "ouriçar",
    "ouriçasses": "ouriçar",
    "ouriçaste": "ouriçar",
    "ouriçastes": "ouriçar",
    "ouriçava": "ouriçar",
    "ouriçavam": "ouriçar",
    "ouriçavas": "ouriçar",
    "ouriço": "ouriçar",
    "ouriços": "ouriço",
    "ouriçou": "ouriçar",
    "ouriçá": "ouriçar",
    "ouriçámo": "ouriçar",
    "ouriçámos": "ouriçar",
    "ouriçáramo": "ouriçar",
    "ouriçáramos": "ouriçar",
    "ouriçárei": "ouriçar",
    "ouriçáreis": "ouriçar",
    "ouriçásseis": "ouriçar",
    "ouriçássemos": "ouriçar",
    "ouriçávamo": "ouriçar",
    "ouriçávamos": "ouriçar",
    "ouriçávei": "ouriçar",
    "ouriçáveis": "ouriçar",
    "ouro": "ourar",
    "ouropesos": "ouropeso",
    "ouropéis": "ouropel",
    "ouros": "ouro",
    "ourou": "ourar",
    "ourá": "ourar",
    "ourámo": "ourar",
    "ourámos": "ourar",
    "ouráramo": "ourar",
    "ouráramos": "ourar",
    "ourárei": "ourar",
    "ouráreis": "ourar",
    "ourásseis": "ourar",
    "ourássemos": "ourar",
    "ourávamo": "ourar",
    "ourávamos": "ourar",
    "ourávei": "ourar",
    "ouráveis": "ourar",
    "ourégões": "ourégão",
    "ousa": "ousar",
    "ousada": "ousar",
    "ousadas": "ousar",
    "ousadias": "ousadia",
    "ousado": "ousar",
    "ousados": "ousar",
    "ousadíssima": "ousado",
    "ousadíssimas": "ousado",
    "ousadíssimo": "ousado",
    "ousadíssimos": "ousado",
    "ousai": "ousar",
    "ousais": "ousar",
    "ousam": "ousar",
    "ousamo": "ousar",
    "ousamos": "ousar",
    "ousando": "ousar",
    "ousara": "ousar",
    "ousaram": "ousar",
    "ousaras": "ousar",
    "ousarde": "ousar",
    "ousardes": "ousar",
    "ousare": "ousar",
    "ousarei": "ousar",
    "ousareis": "ousar",
    "ousarem": "ousar",
    "ousaremos": "ousar",
    "ousares": "ousar",
    "ousaria": "ousar",
    "ousariam": "ousar",
    "ousarias": "ousar",
    "ousarmo": "ousar",
    "ousarmos": "ousar",
    "ousará": "ousar",
    "ousarás": "ousar",
    "ousarão": "ousar",
    "ousaríamos": "ousar",
    "ousaríeis": "ousar",
    "ousas": "ousar",
    "ousasse": "ousar",
    "ousassem": "ousar",
    "ousasses": "ousar",
    "ousaste": "ousar",
    "ousastes": "ousar",
    "ousava": "ousar",
    "ousavam": "ousar",
    "ousavas": "ousar",
    "ouse": "ousar",
    "ousei": "ousar",
    "ouseis": "ousar",
    "ousem": "ousar",
    "ousemo": "ousar",
    "ousemos": "ousar",
    "ouses": "ousar",
    "ousios": "ousio",
    "ouso": "ousar",
    "ousou": "ousar",
    "ousá": "ousar",
    "ousámo": "ousar",
    "ousámos": "ousar",
    "ousáramo": "ousar",
    "ousáramos": "ousar",
    "ousárei": "ousar",
    "ousáreis": "ousar",
    "ousásseis": "ousar",
    "ousássemos": "ousar",
    "ousávamo": "ousar",
    "ousávamos": "ousar",
    "ousávei": "ousar",
    "ousáveis": "ousar",
    "outa": "outar",
    "outada": "outar",
    "outadas": "outar",
    "outado": "outar",
    "outados": "outar",
    "outai": "outar",
    "outais": "outar",
    "outam": "outar",
    "outamo": "outar",
    "outamos": "outar",
    "outando": "outar",
    "outara": "outar",
    "outaram": "outar",
    "outaras": "outar",
    "outarde": "outar",
    "outardes": "outar",
    "outare": "outar",
    "outarei": "outar",
    "outareis": "outar",
    "outarem": "outar",
    "outaremos": "outar",
    "outares": "outar",
    "outaria": "outar",
    "outariam": "outar",
    "outarias": "outar",
    "outarmo": "outar",
    "outarmos": "outar",
    "outará": "outar",
    "outarás": "outar",
    "outarão": "outar",
    "outaríamos": "outar",
    "outaríeis": "outar",
    "outas": "outar",
    "outasse": "outar",
    "outassem": "outar",
    "outasses": "outar",
    "outaste": "outar",
    "outastes": "outar",
    "outava": "outar",
    "outavam": "outar",
    "outavas": "outar",
    "oute": "outar",
    "outei": "outar",
    "outeiristas": "outeirista",
    "outeiros": "outeiro",
    "outeis": "outar",
    "outem": "outar",
    "outemo": "outar",
    "outemos": "outar",
    "outes": "outar",
    "outivas": "outiva",
    "outo": "outar",
    "outona": "outonar",
    "outonada": "outonar",
    "outonadas": "outonar",
    "outonado": "outonar",
    "outonados": "outonar",
    "outonai": "outonar",
    "outonais": "outonar",
    "outonam": "outonar",
    "outonamo": "outonar",
    "outonamos": "outonar",
    "outonando": "outonar",
    "outonara": "outonar",
    "outonaram": "outonar",
    "outonaras": "outonar",
    "outonarde": "outonar",
    "outonardes": "outonar",
    "outonare": "outonar",
    "outonarei": "outonar",
    "outonareis": "outonar",
    "outonarem": "outonar",
    "outonaremos": "outonar",
    "outonares": "outonar",
    "outonaria": "outonar",
    "outonariam": "outonar",
    "outonarias": "outonar",
    "outonarmo": "outonar",
    "outonarmos": "outonar",
    "outonará": "outonar",
    "outonarás": "outonar",
    "outonarão": "outonar",
    "outonaríamos": "outonar",
    "outonaríeis": "outonar",
    "outonas": "outonar",
    "outonasse": "outonar",
    "outonassem": "outonar",
    "outonasses": "outonar",
    "outonaste": "outonar",
    "outonastes": "outonar",
    "outonava": "outonar",
    "outonavam": "outonar",
    "outonavas": "outonar",
    "outone": "outonar",
    "outonei": "outonar",
    "outoneis": "outonar",
    "outonem": "outonar",
    "outonemo": "outonar",
    "outonemos": "outonar",
    "outones": "outonar",
    "outoniça": "outoniço",
    "outoniças": "outoniço",
    "outoniços": "outoniço",
    "outono": "outonar",
    "outonos": "outono",
    "outonou": "outonar",
    "outoná": "outonar",
    "outonámo": "outonar",
    "outonámos": "outonar",
    "outonáramo": "outonar",
    "outonáramos": "outonar",
    "outonárei": "outonar",
    "outonáreis": "outonar",
    "outonásseis": "outonar",
    "outonássemos": "outonar",
    "outonávamo": "outonar",
    "outonávamos": "outonar",
    "outonávei": "outonar",
    "outonáveis": "outonar",
    "outorga": "outorgar",
    "outorgada": "outorgar",
    "outorgadas": "outorgar",
    "outorgado": "outorgar",
    "outorgadora": "outorgador",
    "outorgadoras": "outorgador",
    "outorgadores": "outorgador",
    "outorgados": "outorgar",
    "outorgai": "outorgar",
    "outorgais": "outorgar",
    "outorgam": "outorgar",
    "outorgamentos": "outorgamento",
    "outorgamo": "outorgar",
    "outorgamos": "outorgar",
    "outorgando": "outorgar",
    "outorgantes": "outorgante",
    "outorgara": "outorgar",
    "outorgaram": "outorgar",
    "outorgaras": "outorgar",
    "outorgarde": "outorgar",
    "outorgardes": "outorgar",
    "outorgare": "outorgar",
    "outorgarei": "outorgar",
    "outorgareis": "outorgar",
    "outorgarem": "outorgar",
    "outorgaremos": "outorgar",
    "outorgares": "outorgar",
    "outorgaria": "outorgar",
    "outorgariam": "outorgar",
    "outorgarias": "outorgar",
    "outorgarmo": "outorgar",
    "outorgarmos": "outorgar",
    "outorgará": "outorgar",
    "outorgarás": "outorgar",
    "outorgarão": "outorgar",
    "outorgaríamos": "outorgar",
    "outorgaríeis": "outorgar",
    "outorgas": "outorgar",
    "outorgasse": "outorgar",
    "outorgassem": "outorgar",
    "outorgasses": "outorgar",
    "outorgaste": "outorgar",
    "outorgastes": "outorgar",
    "outorgava": "outorgar",
    "outorgavam": "outorgar",
    "outorgavas": "outorgar",
    "outorgações": "outorgação",
    "outorgo": "outorgar",
    "outorgou": "outorgar",
    "outorgue": "outorgar",
    "outorguei": "outorgar",
    "outorgueis": "outorgar",
    "outorguem": "outorgar",
    "outorguemo": "outorgar",
    "outorguemos": "outorgar",
    "outorgues": "outorgar",
    "outorgá": "outorgar",
    "outorgámo": "outorgar",
    "outorgámos": "outorgar",
    "outorgáramo": "outorgar",
    "outorgáramos": "outorgar",
    "outorgárei": "outorgar",
    "outorgáreis": "outorgar",
    "outorgásseis": "outorgar",
    "outorgássemos": "outorgar",
    "outorgávamo": "outorgar",
    "outorgávamos": "outorgar",
    "outorgávei": "outorgar",
    "outorgáveis": "outorgável",
    "outos": "outo",
    "outou": "outar",
    "outputes": "output",
    "outra": "outro",
    "outras": "outro",
    "outros": "outro",
    "outá": "outar",
    "outámo": "outar",
    "outámos": "outar",
    "outáramo": "outar",
    "outáramos": "outar",
    "outárei": "outar",
    "outáreis": "outar",
    "outásseis": "outar",
    "outássemos": "outar",
    "outávamo": "outar",
    "outávamos": "outar",
    "outávei": "outar",
    "outáveis": "outar",
    "outões": "outão",
    "ouve": "ouvir",
    "ouvem": "ouvir",
    "ouves": "ouvir",
    "ouvi": "ouvir",
    "ouvia": "ouvir",
    "ouviam": "ouvir",
    "ouvias": "ouvir",
    "ouvida": "ouvir",
    "ouvidas": "ouvir",
    "ouvidinho": "ouvido",
    "ouvidinhos": "ouvido",
    "ouvidito": "ouvido",
    "ouviditos": "ouvido",
    "ouvido": "ouvir",
    "ouvidora": "ouvidor",
    "ouvidoras": "ouvidor",
    "ouvidores": "ouvidor",
    "ouvidorias": "ouvidoria",
    "ouvidos": "ouvir",
    "ouvimo": "ouvir",
    "ouvimos": "ouvir",
    "ouvindo": "ouvir",
    "ouvintes": "ouvinte",
    "ouvira": "ouvir",
    "ouviram": "ouvir",
    "ouviras": "ouvir",
    "ouvirde": "ouvir",
    "ouvirdes": "ouvir",
    "ouvire": "ouvir",
    "ouvirei": "ouvir",
    "ouvireis": "ouvir",
    "ouvirem": "ouvir",
    "ouviremos": "ouvir",
    "ouvires": "ouvir",
    "ouviria": "ouvir",
    "ouviriam": "ouvir",
    "ouvirias": "ouvir",
    "ouvirmo": "ouvir",
    "ouvirmos": "ouvir",
    "ouvirá": "ouvir",
    "ouvirás": "ouvir",
    "ouvirão": "ouvir",
    "ouviríamos": "ouvir",
    "ouviríeis": "ouvir",
    "ouvis": "ouvir",
    "ouvisse": "ouvir",
    "ouvissem": "ouvir",
    "ouvisses": "ouvir",
    "ouviste": "ouvir",
    "ouvistes": "ouvir",
    "ouviu": "ouvir",
    "ouvíamo": "ouvir",
    "ouvíamos": "ouvir",
    "ouvíei": "ouvir",
    "ouvíeis": "ouvir",
    "ouvíramo": "ouvir",
    "ouvíramos": "ouvir",
    "ouvírei": "ouvir",
    "ouvíreis": "ouvir",
    "ouvísseis": "ouvir",
    "ouvíssemos": "ouvir",
    "ouça": "ouvir",
    "ouçais": "ouvir",
    "ouçam": "ouvir",
    "ouçamo": "ouvir",
    "ouçamos": "ouvir",
    "ouças": "ouvir",
    "ouço": "ouvir",
    "ouções": "oução",
    "ova": "ovar",
    "ovaciona": "ovacionar",
    "ovacionada": "ovacionar",
    "ovacionadas": "ovacionar",
    "ovacionado": "ovacionar",
    "ovacionados": "ovacionar",
    "ovacionadíssima": "ovacionado",
    "ovacionadíssimas": "ovacionado",
    "ovacionadíssimo": "ovacionado",
    "ovacionadíssimos": "ovacionado",
    "ovacionai": "ovacionar",
    "ovacionais": "ovacionar",
    "ovacionam": "ovacionar",
    "ovacionamo": "ovacionar",
    "ovacionamos": "ovacionar",
    "ovacionando": "ovacionar",
    "ovacionara": "ovacionar",
    "ovacionaram": "ovacionar",
    "ovacionaras": "ovacionar",
    "ovacionarde": "ovacionar",
    "ovacionardes": "ovacionar",
    "ovacionare": "ovacionar",
    "ovacionarei": "ovacionar",
    "ovacionareis": "ovacionar",
    "ovacionarem": "ovacionar",
    "ovacionaremos": "ovacionar",
    "ovacionares": "ovacionar",
    "ovacionaria": "ovacionar",
    "ovacionariam": "ovacionar",
    "ovacionarias": "ovacionar",
    "ovacionarmo": "ovacionar",
    "ovacionarmos": "ovacionar",
    "ovacionará": "ovacionar",
    "ovacionarás": "ovacionar",
    "ovacionarão": "ovacionar",
    "ovacionaríamos": "ovacionar",
    "ovacionaríeis": "ovacionar",
    "ovacionas": "ovacionar",
    "ovacionasse": "ovacionar",
    "ovacionassem": "ovacionar",
    "ovacionasses": "ovacionar",
    "ovacionaste": "ovacionar",
    "ovacionastes": "ovacionar",
    "ovacionava": "ovacionar",
    "ovacionavam": "ovacionar",
    "ovacionavas": "ovacionar",
    "ovacione": "ovacionar",
    "ovacionei": "ovacionar",
    "ovacioneis": "ovacionar",
    "ovacionem": "ovacionar",
    "ovacionemo": "ovacionar",
    "ovacionemos": "ovacionar",
    "ovaciones": "ovacionar",
    "ovaciono": "ovacionar",
    "ovacionou": "ovacionar",
    "ovacioná": "ovacionar",
    "ovacionámo": "ovacionar",
    "ovacionámos": "ovacionar",
    "ovacionáramo": "ovacionar",
    "ovacionáramos": "ovacionar",
    "ovacionárei": "ovacionar",
    "ovacionáreis": "ovacionar",
    "ovacionásseis": "ovacionar",
    "ovacionássemos": "ovacionar",
    "ovacionávamo": "ovacionar",
    "ovacionávamos": "ovacionar",
    "ovacionávei": "ovacionar",
    "ovacionáveis": "ovacionar",
    "ovada": "ovar",
    "ovadas": "ovar",
    "ovado": "ovar",
    "ovados": "ovar",
    "ovai": "ovar",
    "ovais": "ovar",
    "ovala": "ovalar",
    "ovalada": "ovalar",
    "ovaladas": "ovalar",
    "ovalado": "ovalar",
    "ovalados": "ovalar",
    "ovalai": "ovalar",
    "ovalais": "ovalar",
    "ovalam": "ovalar",
    "ovalamo": "ovalar",
    "ovalamos": "ovalar",
    "ovalando": "ovalar",
    "ovalara": "ovalar",
    "ovalaram": "ovalar",
    "ovalaras": "ovalar",
    "ovalarde": "ovalar",
    "ovalardes": "ovalar",
    "ovalare": "ovalar",
    "ovalarei": "ovalar",
    "ovalareis": "ovalar",
    "ovalarem": "ovalar",
    "ovalaremos": "ovalar",
    "ovalares": "ovalar",
    "ovalaria": "ovalar",
    "ovalariam": "ovalar",
    "ovalarias": "ovalar",
    "ovalarmo": "ovalar",
    "ovalarmos": "ovalar",
    "ovalará": "ovalar",
    "ovalarás": "ovalar",
    "ovalarão": "ovalar",
    "ovalaríamos": "ovalar",
    "ovalaríeis": "ovalar",
    "ovalas": "ovalar",
    "ovalasse": "ovalar",
    "ovalassem": "ovalar",
    "ovalasses": "ovalar",
    "ovalaste": "ovalar",
    "ovalastes": "ovalar",
    "ovalava": "ovalar",
    "ovalavam": "ovalar",
    "ovalavas": "ovalar",
    "ovalações": "ovalação",
    "ovale": "ovalar",
    "ovalei": "ovalar",
    "ovaleis": "ovalar",
    "ovalem": "ovalar",
    "ovalemo": "ovalar",
    "ovalemos": "ovalar",
    "ovales": "ovalar",
    "ovaliza": "ovalizar",
    "ovalizada": "ovalizar",
    "ovalizadas": "ovalizar",
    "ovalizado": "ovalizar",
    "ovalizados": "ovalizar",
    "ovalizai": "ovalizar",
    "ovalizais": "ovalizar",
    "ovalizam": "ovalizar",
    "ovalizamo": "ovalizar",
    "ovalizamos": "ovalizar",
    "ovalizando": "ovalizar",
    "ovalizara": "ovalizar",
    "ovalizaram": "ovalizar",
    "ovalizaras": "ovalizar",
    "ovalizarde": "ovalizar",
    "ovalizardes": "ovalizar",
    "ovalizare": "ovalizar",
    "ovalizarei": "ovalizar",
    "ovalizareis": "ovalizar",
    "ovalizarem": "ovalizar",
    "ovalizaremos": "ovalizar",
    "ovalizares": "ovalizar",
    "ovalizaria": "ovalizar",
    "ovalizariam": "ovalizar",
    "ovalizarias": "ovalizar",
    "ovalizarmo": "ovalizar",
    "ovalizarmos": "ovalizar",
    "ovalizará": "ovalizar",
    "ovalizarás": "ovalizar",
    "ovalizarão": "ovalizar",
    "ovalizaríamos": "ovalizar",
    "ovalizaríeis": "ovalizar",
    "ovalizas": "ovalizar",
    "ovalizasse": "ovalizar",
    "ovalizassem": "ovalizar",
    "ovalizasses": "ovalizar",
    "ovalizaste": "ovalizar",
    "ovalizastes": "ovalizar",
    "ovalizava": "ovalizar",
    "ovalizavam": "ovalizar",
    "ovalizavas": "ovalizar",
    "ovalize": "ovalizar",
    "ovalizei": "ovalizar",
    "ovalizeis": "ovalizar",
    "ovalizem": "ovalizar",
    "ovalizemo": "ovalizar",
    "ovalizemos": "ovalizar",
    "ovalizes": "ovalizar",
    "ovalizo": "ovalizar",
    "ovalizou": "ovalizar",
    "ovalizá": "ovalizar",
    "ovalizámo": "ovalizar",
    "ovalizámos": "ovalizar",
    "ovalizáramo": "ovalizar",
    "ovalizáramos": "ovalizar",
    "ovalizárei": "ovalizar",
    "ovalizáreis": "ovalizar",
    "ovalizásseis": "ovalizar",
    "ovalizássemos": "ovalizar",
    "ovalizávamo": "ovalizar",
    "ovalizávamos": "ovalizar",
    "ovalizávei": "ovalizar",
    "ovalizáveis": "ovalizar",
    "ovalo": "ovalar",
    "ovalou": "ovalar",
    "ovalá": "ovalar",
    "ovalámo": "ovalar",
    "ovalámos": "ovalar",
    "ovaláramo": "ovalar",
    "ovaláramos": "ovalar",
    "ovalárei": "ovalar",
    "ovaláreis": "ovalar",
    "ovalásseis": "ovalar",
    "ovalássemos": "ovalar",
    "ovalávamo": "ovalar",
    "ovalávamos": "ovalar",
    "ovalávei": "ovalar",
    "ovaláveis": "ovalável",
    "ovam": "ovar",
    "ovamo": "ovar",
    "ovamos": "ovar",
    "ovando": "ovar",
    "ovantes": "ovante",
    "ovara": "ovar",
    "ovaram": "ovar",
    "ovaras": "ovar",
    "ovarde": "ovar",
    "ovardes": "ovar",
    "ovare": "ovar",
    "ovarei": "ovar",
    "ovareis": "ovar",
    "ovarem": "ovar",
    "ovaremos": "ovar",
    "ovarenses": "ovarense",
    "ovares": "ovar",
    "ovaria": "ovar",
    "ovariam": "ovar",
    "ovariana": "ovariano",
    "ovarianas": "ovariano",
    "ovarianos": "ovariano",
    "ovarias": "ovar",
    "ovariectomias": "ovariectomia",
    "ovarina": "ovarino",
    "ovarinas": "ovarino",
    "ovarinos": "ovarino",
    "ovariotomias": "ovariotomia",
    "ovariotómica": "ovariotómico",
    "ovariotómicas": "ovariotómico",
    "ovariotómicos": "ovariotómico",
    "ovarites": "ovarite",
    "ovarmo": "ovar",
    "ovarmos": "ovar",
    "ovará": "ovar",
    "ovarás": "ovar",
    "ovarão": "ovar",
    "ovaríamos": "ovar",
    "ovaríeis": "ovar",
    "ovas": "ovar",
    "ovasse": "ovar",
    "ovassem": "ovar",
    "ovasses": "ovar",
    "ovaste": "ovar",
    "ovastes": "ovar",
    "ovava": "ovar",
    "ovavam": "ovar",
    "ovavas": "ovar",
    "ovações": "ovação",
    "ove": "ovar",
    "ovei": "ovar",
    "oveiras": "oveira",
    "oveiros": "oveiro",
    "oveis": "ovar",
    "ovelhadas": "ovelhada",
    "ovelhas": "ovelha",
    "ovelheira": "ovelheiro",
    "ovelheiras": "ovelheiro",
    "ovelheiros": "ovelheiro",
    "ovelhuns": "ovelhum",
    "ovem": "ovar",
    "ovemo": "ovar",
    "ovemos": "ovar",
    "ovenças": "ovença",
    "overdoses": "overdose",
    "overnights": "overnight",
    "oves": "ovar",
    "ovetenses": "ovetense",
    "ovidiana": "ovidiano",
    "ovidianas": "ovidiano",
    "ovidianos": "ovidiano",
    "ovidutos": "oviduto",
    "ovificações": "ovificação",
    "oviformes": "oviforme",
    "ovina": "ovino",
    "ovinas": "ovino",
    "ovinho": "ovo",
    "ovinhos": "ovo",
    "ovinos": "ovino",
    "oviparidades": "oviparidade",
    "oviparismos": "oviparismo",
    "ovis": "ovil",
    "ovissacos": "ovissaco",
    "ovito": "ovo",
    "ovitos": "ovo",
    "oviários": "oviário",
    "ovnis": "ovni",
    "ovo": "ovar",
    "ovoblastos": "ovoblasto",
    "ovocélulas": "ovocélula",
    "ovofagias": "ovofagia",
    "ovogenias": "ovogenia",
    "ovogéneses": "ovogénese",
    "ovogénica": "ovogénico",
    "ovogénicas": "ovogénico",
    "ovogénicos": "ovogénico",
    "ovogónias": "ovogónia",
    "ovolares": "ovolar",
    "ovologias": "ovologia",
    "ovos": "ovo",
    "ovoscopias": "ovoscopia",
    "ovoscópios": "ovoscópio",
    "ovou": "ovar",
    "ovovivípara": "ovovivíparo",
    "ovovivíparas": "ovovivíparo",
    "ovovivíparos": "ovovivíparo",
    "ovovípara": "ovovíparo",
    "ovovíparas": "ovovíparo",
    "ovovíparos": "ovovíparo",
    "ovulações": "ovulação",
    "ovuliformes": "ovuliforme",
    "ovulogéneses": "ovulogénese",
    "ovulífera": "ovulífero",
    "ovulíferas": "ovulífero",
    "ovulíferos": "ovulífero",
    "ovulígera": "ovulígero",
    "ovulígeras": "ovulígero",
    "ovulígeros": "ovulígero",
    "ová": "ovar",
    "ovámo": "ovar",
    "ovámos": "ovar",
    "ováramo": "ovar",
    "ováramos": "ovar",
    "ovárei": "ovar",
    "ováreis": "ovar",
    "ovárica": "ovárico",
    "ováricas": "ovárico",
    "ováricos": "ovárico",
    "ovários": "ovário",
    "ovásseis": "ovar",
    "ovássemos": "ovar",
    "ovávamo": "ovar",
    "ovávamos": "ovar",
    "ovávei": "ovar",
    "ováveis": "ovar",
    "ovéns": "ovém",
    "ovículos": "ovículo",
    "ovídeos": "ovídeo",
    "ovípara": "ovíparo",
    "ovíparas": "ovíparo",
    "ovíparos": "ovíparo",
    "ovívora": "ovívoro",
    "ovívoras": "ovívoro",
    "ovívoros": "ovívoro",
    "ovóides": "ovóide",
    "oxalatos": "oxalato",
    "oxalidáceas": "oxalidácea",
    "oxalífera": "oxalífero",
    "oxalíferas": "oxalífero",
    "oxalíferos": "oxalífero",
    "oxfordianos": "oxfordiano",
    "oxiacetilénica": "oxiacetilénico",
    "oxiacetilénicas": "oxiacetilénico",
    "oxiacetilénicos": "oxiacetilénico",
    "oxicedros": "oxicedro",
    "oxicratos": "oxicrato",
    "oxida": "oxidar",
    "oxidabilidades": "oxidabilidade",
    "oxidada": "oxidar",
    "oxidadas": "oxidar",
    "oxidado": "oxidar",
    "oxidados": "oxidar",
    "oxidai": "oxidar",
    "oxidais": "oxidar",
    "oxidam": "oxidar",
    "oxidamo": "oxidar",
    "oxidamos": "oxidar",
    "oxidando": "oxidar",
    "oxidantes": "oxidante",
    "oxidara": "oxidar",
    "oxidaram": "oxidar",
    "oxidaras": "oxidar",
    "oxidarde": "oxidar",
    "oxidardes": "oxidar",
    "oxidare": "oxidar",
    "oxidarei": "oxidar",
    "oxidareis": "oxidar",
    "oxidarem": "oxidar",
    "oxidaremos": "oxidar",
    "oxidares": "oxidar",
    "oxidaria": "oxidar",
    "oxidariam": "oxidar",
    "oxidarias": "oxidar",
    "oxidarmo": "oxidar",
    "oxidarmos": "oxidar",
    "oxidará": "oxidar",
    "oxidarás": "oxidar",
    "oxidarão": "oxidar",
    "oxidaríamos": "oxidar",
    "oxidaríeis": "oxidar",
    "oxidas": "oxidar",
    "oxidases": "oxidase",
    "oxidasse": "oxidar",
    "oxidassem": "oxidar",
    "oxidasses": "oxidar",
    "oxidaste": "oxidar",
    "oxidastes": "oxidar",
    "oxidava": "oxidar",
    "oxidavam": "oxidar",
    "oxidavas": "oxidar",
    "oxidações": "oxidação",
    "oxide": "oxidar",
    "oxidei": "oxidar",
    "oxideis": "oxidar",
    "oxidem": "oxidar",
    "oxidemo": "oxidar",
    "oxidemos": "oxidar",
    "oxides": "oxidar",
    "oxidimetrias": "oxidimetria",
    "oxido": "oxidar",
    "oxidou": "oxidar",
    "oxidrilos": "oxidrilo",
    "oxidula": "oxidular",
    "oxidulada": "oxidular",
    "oxiduladas": "oxidular",
    "oxidulado": "oxidular",
    "oxidulados": "oxidular",
    "oxidulai": "oxidular",
    "oxidulais": "oxidular",
    "oxidulam": "oxidular",
    "oxidulamo": "oxidular",
    "oxidulamos": "oxidular",
    "oxidulando": "oxidular",
    "oxidulara": "oxidular",
    "oxidularam": "oxidular",
    "oxidularas": "oxidular",
    "oxidularde": "oxidular",
    "oxidulardes": "oxidular",
    "oxidulare": "oxidular",
    "oxidularei": "oxidular",
    "oxidulareis": "oxidular",
    "oxidularem": "oxidular",
    "oxidularemos": "oxidular",
    "oxidulares": "oxidular",
    "oxidularia": "oxidular",
    "oxidulariam": "oxidular",
    "oxidularias": "oxidular",
    "oxidularmo": "oxidular",
    "oxidularmos": "oxidular",
    "oxidulará": "oxidular",
    "oxidularás": "oxidular",
    "oxidularão": "oxidular",
    "oxidularíamos": "oxidular",
    "oxidularíeis": "oxidular",
    "oxidulas": "oxidular",
    "oxidulasse": "oxidular",
    "oxidulassem": "oxidular",
    "oxidulasses": "oxidular",
    "oxidulaste": "oxidular",
    "oxidulastes": "oxidular",
    "oxidulava": "oxidular",
    "oxidulavam": "oxidular",
    "oxidulavas": "oxidular",
    "oxidule": "oxidular",
    "oxidulei": "oxidular",
    "oxiduleis": "oxidular",
    "oxidulem": "oxidular",
    "oxidulemo": "oxidular",
    "oxidulemos": "oxidular",
    "oxidules": "oxidular",
    "oxidulo": "oxidular",
    "oxidulou": "oxidular",
    "oxidulá": "oxidular",
    "oxidulámo": "oxidular",
    "oxidulámos": "oxidular",
    "oxiduláramo": "oxidular",
    "oxiduláramos": "oxidular",
    "oxidulárei": "oxidular",
    "oxiduláreis": "oxidular",
    "oxidulásseis": "oxidular",
    "oxidulássemos": "oxidular",
    "oxidulávamo": "oxidular",
    "oxidulávamos": "oxidular",
    "oxidulávei": "oxidular",
    "oxiduláveis": "oxidular",
    "oxidá": "oxidar",
    "oxidámo": "oxidar",
    "oxidámos": "oxidar",
    "oxidáramo": "oxidar",
    "oxidáramos": "oxidar",
    "oxidárei": "oxidar",
    "oxidáreis": "oxidar",
    "oxidásseis": "oxidar",
    "oxidássemos": "oxidar",
    "oxidávamo": "oxidar",
    "oxidávamos": "oxidar",
    "oxidávei": "oxidar",
    "oxidáveis": "oxidável",
    "oxiemoglobinas": "oxiemoglobina",
    "oxigena": "oxigenar",
    "oxigenabilidades": "oxigenabilidade",
    "oxigenada": "oxigenar",
    "oxigenadas": "oxigenar",
    "oxigenado": "oxigenar",
    "oxigenados": "oxigenar",
    "oxigenai": "oxigenar",
    "oxigenais": "oxigenar",
    "oxigenam": "oxigenar",
    "oxigenamo": "oxigenar",
    "oxigenamos": "oxigenar",
    "oxigenando": "oxigenar",
    "oxigenantes": "oxigenante",
    "oxigenara": "oxigenar",
    "oxigenaram": "oxigenar",
    "oxigenaras": "oxigenar",
    "oxigenarde": "oxigenar",
    "oxigenardes": "oxigenar",
    "oxigenare": "oxigenar",
    "oxigenarei": "oxigenar",
    "oxigenareis": "oxigenar",
    "oxigenarem": "oxigenar",
    "oxigenaremos": "oxigenar",
    "oxigenares": "oxigenar",
    "oxigenaria": "oxigenar",
    "oxigenariam": "oxigenar",
    "oxigenarias": "oxigenar",
    "oxigenarmo": "oxigenar",
    "oxigenarmos": "oxigenar",
    "oxigenará": "oxigenar",
    "oxigenarás": "oxigenar",
    "oxigenarão": "oxigenar",
    "oxigenaríamos": "oxigenar",
    "oxigenaríeis": "oxigenar",
    "oxigenas": "oxigenar",
    "oxigenasse": "oxigenar",
    "oxigenassem": "oxigenar",
    "oxigenasses": "oxigenar",
    "oxigenaste": "oxigenar",
    "oxigenastes": "oxigenar",
    "oxigenava": "oxigenar",
    "oxigenavam": "oxigenar",
    "oxigenavas": "oxigenar",
    "oxigenações": "oxigenação",
    "oxigene": "oxigenar",
    "oxigenei": "oxigenar",
    "oxigeneis": "oxigenar",
    "oxigenem": "oxigenar",
    "oxigenemo": "oxigenar",
    "oxigenemos": "oxigenar",
    "oxigenes": "oxigenar",
    "oxigeno": "oxigenar",
    "oxigenoterapias": "oxigenoterapia",
    "oxigenou": "oxigenar",
    "oxigená": "oxigenar",
    "oxigenámo": "oxigenar",
    "oxigenámos": "oxigenar",
    "oxigenáramo": "oxigenar",
    "oxigenáramos": "oxigenar",
    "oxigenárei": "oxigenar",
    "oxigenáreis": "oxigenar",
    "oxigenásseis": "oxigenar",
    "oxigenássemos": "oxigenar",
    "oxigenávamo": "oxigenar",
    "oxigenávamos": "oxigenar",
    "oxigenávei": "oxigenar",
    "oxigenáveis": "oxigenável",
    "oxigénios": "oxigénio",
    "oximetrias": "oximetria",
    "oximéis": "oximel",
    "oxiopias": "oxiopia",
    "oxiopsias": "oxiopsia",
    "oxitonias": "oxitonia",
    "oxitoniza": "oxitonizar",
    "oxitonizada": "oxitonizar",
    "oxitonizadas": "oxitonizar",
    "oxitonizado": "oxitonizar",
    "oxitonizados": "oxitonizar",
    "oxitonizai": "oxitonizar",
    "oxitonizais": "oxitonizar",
    "oxitonizam": "oxitonizar",
    "oxitonizamo": "oxitonizar",
    "oxitonizamos": "oxitonizar",
    "oxitonizando": "oxitonizar",
    "oxitonizara": "oxitonizar",
    "oxitonizaram": "oxitonizar",
    "oxitonizaras": "oxitonizar",
    "oxitonizarde": "oxitonizar",
    "oxitonizardes": "oxitonizar",
    "oxitonizare": "oxitonizar",
    "oxitonizarei": "oxitonizar",
    "oxitonizareis": "oxitonizar",
    "oxitonizarem": "oxitonizar",
    "oxitonizaremos": "oxitonizar",
    "oxitonizares": "oxitonizar",
    "oxitonizaria": "oxitonizar",
    "oxitonizariam": "oxitonizar",
    "oxitonizarias": "oxitonizar",
    "oxitonizarmo": "oxitonizar",
    "oxitonizarmos": "oxitonizar",
    "oxitonizará": "oxitonizar",
    "oxitonizarás": "oxitonizar",
    "oxitonizarão": "oxitonizar",
    "oxitonizaríamos": "oxitonizar",
    "oxitonizaríeis": "oxitonizar",
    "oxitonizas": "oxitonizar",
    "oxitonizasse": "oxitonizar",
    "oxitonizassem": "oxitonizar",
    "oxitonizasses": "oxitonizar",
    "oxitonizaste": "oxitonizar",
    "oxitonizastes": "oxitonizar",
    "oxitonizava": "oxitonizar",
    "oxitonizavam": "oxitonizar",
    "oxitonizavas": "oxitonizar",
    "oxitonize": "oxitonizar",
    "oxitonizei": "oxitonizar",
    "oxitonizeis": "oxitonizar",
    "oxitonizem": "oxitonizar",
    "oxitonizemo": "oxitonizar",
    "oxitonizemos": "oxitonizar",
    "oxitonizes": "oxitonizar",
    "oxitonizo": "oxitonizar",
    "oxitonizou": "oxitonizar",
    "oxitonizá": "oxitonizar",
    "oxitonizámo": "oxitonizar",
    "oxitonizámos": "oxitonizar",
    "oxitonizáramo": "oxitonizar",
    "oxitonizáramos": "oxitonizar",
    "oxitonizárei": "oxitonizar",
    "oxitonizáreis": "oxitonizar",
    "oxitonizásseis": "oxitonizar",
    "oxitonizássemos": "oxitonizar",
    "oxitonizávamo": "oxitonizar",
    "oxitonizávamos": "oxitonizar",
    "oxitonizávei": "oxitonizar",
    "oxitonizáveis": "oxitonizar",
    "oxiuroses": "oxiurose",
    "oxiurídeos": "oxiurídeo",
    "oxiúros": "oxiúro",
    "oxácidos": "oxácido",
    "oxálica": "oxálico",
    "oxálicas": "oxálico",
    "oxálicos": "oxálico",
    "oxídrica": "oxídrico",
    "oxídricas": "oxídrico",
    "oxídricos": "oxídrico",
    "oxídulos": "oxídulo",
    "oxígalas": "oxígala",
    "oxígona": "oxígono",
    "oxígonas": "oxígono",
    "oxígonos": "oxígono",
    "oxílitos": "oxílito",
    "oxímoros": "oxímoro",
    "oxítona": "oxítono",
    "oxítonas": "oxítono",
    "oxítonos": "oxítono",
    "ozenas": "ozena",
    "ozocerites": "ozocerite",
    "ozona": "ozonar",
    "ozonada": "ozonar",
    "ozonadas": "ozonar",
    "ozonado": "ozonar",
    "ozonados": "ozonar",
    "ozonai": "ozonar",
    "ozonais": "ozonar",
    "ozonam": "ozonar",
    "ozonamo": "ozonar",
    "ozonamos": "ozonar",
    "ozonando": "ozonar",
    "ozonara": "ozonar",
    "ozonaram": "ozonar",
    "ozonaras": "ozonar",
    "ozonarde": "ozonar",
    "ozonardes": "ozonar",
    "ozonare": "ozonar",
    "ozonarei": "ozonar",
    "ozonareis": "ozonar",
    "ozonarem": "ozonar",
    "ozonaremos": "ozonar",
    "ozonares": "ozonar",
    "ozonaria": "ozonar",
    "ozonariam": "ozonar",
    "ozonarias": "ozonar",
    "ozonarmo": "ozonar",
    "ozonarmos": "ozonar",
    "ozonará": "ozonar",
    "ozonarás": "ozonar",
    "ozonarão": "ozonar",
    "ozonaríamos": "ozonar",
    "ozonaríeis": "ozonar",
    "ozonas": "ozonar",
    "ozonasse": "ozonar",
    "ozonassem": "ozonar",
    "ozonasses": "ozonar",
    "ozonaste": "ozonar",
    "ozonastes": "ozonar",
    "ozonava": "ozonar",
    "ozonavam": "ozonar",
    "ozonavas": "ozonar",
    "ozone": "ozonar",
    "ozonei": "ozonar",
    "ozoneis": "ozonar",
    "ozonem": "ozonar",
    "ozonemo": "ozonar",
    "ozonemos": "ozonar",
    "ozones": "ozone",
    "ozonifica": "ozonificar",
    "ozonificada": "ozonificar",
    "ozonificadas": "ozonificar",
    "ozonificado": "ozonificar",
    "ozonificados": "ozonificar",
    "ozonificai": "ozonificar",
    "ozonificais": "ozonificar",
    "ozonificam": "ozonificar",
    "ozonificamo": "ozonificar",
    "ozonificamos": "ozonificar",
    "ozonificando": "ozonificar",
    "ozonificara": "ozonificar",
    "ozonificaram": "ozonificar",
    "ozonificaras": "ozonificar",
    "ozonificarde": "ozonificar",
    "ozonificardes": "ozonificar",
    "ozonificare": "ozonificar",
    "ozonificarei": "ozonificar",
    "ozonificareis": "ozonificar",
    "ozonificarem": "ozonificar",
    "ozonificaremos": "ozonificar",
    "ozonificares": "ozonificar",
    "ozonificaria": "ozonificar",
    "ozonificariam": "ozonificar",
    "ozonificarias": "ozonificar",
    "ozonificarmo": "ozonificar",
    "ozonificarmos": "ozonificar",
    "ozonificará": "ozonificar",
    "ozonificarás": "ozonificar",
    "ozonificarão": "ozonificar",
    "ozonificaríamos": "ozonificar",
    "ozonificaríeis": "ozonificar",
    "ozonificas": "ozonificar",
    "ozonificasse": "ozonificar",
    "ozonificassem": "ozonificar",
    "ozonificasses": "ozonificar",
    "ozonificaste": "ozonificar",
    "ozonificastes": "ozonificar",
    "ozonificava": "ozonificar",
    "ozonificavam": "ozonificar",
    "ozonificavas": "ozonificar",
    "ozonifico": "ozonificar",
    "ozonificou": "ozonificar",
    "ozonificá": "ozonificar",
    "ozonificámo": "ozonificar",
    "ozonificámos": "ozonificar",
    "ozonificáramo": "ozonificar",
    "ozonificáramos": "ozonificar",
    "ozonificárei": "ozonificar",
    "ozonificáreis": "ozonificar",
    "ozonificásseis": "ozonificar",
    "ozonificássemos": "ozonificar",
    "ozonificávamo": "ozonificar",
    "ozonificávamos": "ozonificar",
    "ozonificávei": "ozonificar",
    "ozonificáveis": "ozonificável",
    "ozonifique": "ozonificar",
    "ozonifiquei": "ozonificar",
    "ozonifiqueis": "ozonificar",
    "ozonifiquem": "ozonificar",
    "ozonifiquemo": "ozonificar",
    "ozonifiquemos": "ozonificar",
    "ozonifiques": "ozonificar",
    "ozoniza": "ozonizar",
    "ozonizada": "ozonizar",
    "ozonizadas": "ozonizar",
    "ozonizado": "ozonizar",
    "ozonizadora": "ozonizador",
    "ozonizadoras": "ozonizador",
    "ozonizadores": "ozonizador",
    "ozonizados": "ozonizar",
    "ozonizai": "ozonizar",
    "ozonizais": "ozonizar",
    "ozonizam": "ozonizar",
    "ozonizamo": "ozonizar",
    "ozonizamos": "ozonizar",
    "ozonizando": "ozonizar",
    "ozonizara": "ozonizar",
    "ozonizaram": "ozonizar",
    "ozonizaras": "ozonizar",
    "ozonizarde": "ozonizar",
    "ozonizardes": "ozonizar",
    "ozonizare": "ozonizar",
    "ozonizarei": "ozonizar",
    "ozonizareis": "ozonizar",
    "ozonizarem": "ozonizar",
    "ozonizaremos": "ozonizar",
    "ozonizares": "ozonizar",
    "ozonizaria": "ozonizar",
    "ozonizariam": "ozonizar",
    "ozonizarias": "ozonizar",
    "ozonizarmo": "ozonizar",
    "ozonizarmos": "ozonizar",
    "ozonizará": "ozonizar",
    "ozonizarás": "ozonizar",
    "ozonizarão": "ozonizar",
    "ozonizaríamos": "ozonizar",
    "ozonizaríeis": "ozonizar",
    "ozonizas": "ozonizar",
    "ozonizasse": "ozonizar",
    "ozonizassem": "ozonizar",
    "ozonizasses": "ozonizar",
    "ozonizaste": "ozonizar",
    "ozonizastes": "ozonizar",
    "ozonizava": "ozonizar",
    "ozonizavam": "ozonizar",
    "ozonizavas": "ozonizar",
    "ozonizações": "ozonização",
    "ozonize": "ozonizar",
    "ozonizei": "ozonizar",
    "ozonizeis": "ozonizar",
    "ozonizem": "ozonizar",
    "ozonizemo": "ozonizar",
    "ozonizemos": "ozonizar",
    "ozonizes": "ozonizar",
    "ozonizo": "ozonizar",
    "ozonizou": "ozonizar",
    "ozonizá": "ozonizar",
    "ozonizámo": "ozonizar",
    "ozonizámos": "ozonizar",
    "ozonizáramo": "ozonizar",
    "ozonizáramos": "ozonizar",
    "ozonizárei": "ozonizar",
    "ozonizáreis": "ozonizar",
    "ozonizásseis": "ozonizar",
    "ozonizássemos": "ozonizar",
    "ozonizávamo": "ozonizar",
    "ozonizávamos": "ozonizar",
    "ozonizávei": "ozonizar",
    "ozonizáveis": "ozonizável",
    "ozono": "ozonar",
    "ozonometrias": "ozonometria",
    "ozonométrica": "ozonométrico",
    "ozonométricas": "ozonométrico",
    "ozonométricos": "ozonométrico",
    "ozonos": "ozono",
    "ozonou": "ozonar",
    "ozoná": "ozonar",
    "ozonámo": "ozonar",
    "ozonámos": "ozonar",
    "ozonáramo": "ozonar",
    "ozonáramos": "ozonar",
    "ozonárei": "ozonar",
    "ozonáreis": "ozonar",
    "ozonásseis": "ozonar",
    "ozonássemos": "ozonar",
    "ozonávamo": "ozonar",
    "ozonávamos": "ozonar",
    "ozonávei": "ozonar",
    "ozonáveis": "ozonável",
    "ozonómetros": "ozonómetro",
    "ozostomias": "ozostomia",
    "ozénica": "ozénico",
    "ozénicas": "ozénico",
    "ozénicos": "ozénico",
    "ozónios": "ozónio",
    "oásica": "oásico",
    "oásicas": "oásico",
    "oásicos": "oásico",
    "oídios": "oídio",
    "oócitos": "oócito",
    "oólitos": "oólito",
    "oótipos": "oótipo",
    "pabula": "pabular",
    "pabulada": "pabular",
    "pabuladas": "pabular",
    "pabulado": "pabular",
    "pabulados": "pabular",
    "pabulagens": "pabulagem",
    "pabulai": "pabular",
    "pabulais": "pabular",
    "pabulam": "pabular",
    "pabulamo": "pabular",
    "pabulamos": "pabular",
    "pabulando": "pabular",
    "pabulara": "pabular",
    "pabularam": "pabular",
    "pabularas": "pabular",
    "pabulardes": "pabular",
    "pabularei": "pabular",
    "pabulareis": "pabular",
    "pabularem": "pabular",
    "pabularemos": "pabular",
    "pabulares": "pabular",
    "pabularia": "pabular",
    "pabulariam": "pabular",
    "pabularias": "pabular",
    "pabularmo": "pabular",
    "pabularmos": "pabular",
    "pabulará": "pabular",
    "pabularás": "pabular",
    "pabularão": "pabular",
    "pabularíamos": "pabular",
    "pabularíeis": "pabular",
    "pabulas": "pabular",
    "pabulasse": "pabular",
    "pabulassem": "pabular",
    "pabulasses": "pabular",
    "pabulaste": "pabular",
    "pabulastes": "pabular",
    "pabulava": "pabular",
    "pabulavam": "pabular",
    "pabulavas": "pabular",
    "pabule": "pabular",
    "pabulei": "pabular",
    "pabuleis": "pabular",
    "pabulem": "pabular",
    "pabulemo": "pabular",
    "pabulemos": "pabular",
    "pabules": "pabular",
    "pabulo": "pabular",
    "pabulou": "pabular",
    "pabulámo": "pabular",
    "pabulámos": "pabular",
    "pabuláramo": "pabular",
    "pabuláramos": "pabular",
    "pabuláreis": "pabular",
    "pabulásseis": "pabular",
    "pabulássemos": "pabular",
    "pabulávamo": "pabular",
    "pabulávamos": "pabular",
    "pabuláveis": "pabular",
    "pacaris": "pacari",
    "pacas": "paca",
    "pacata": "pacato",
    "pacatas": "pacato",
    "pacatazinha": "pacato",
    "pacatazinhas": "pacato",
    "pacatazita": "pacato",
    "pacatazitas": "pacato",
    "pacataça": "pacato",
    "pacataças": "pacato",
    "pacataço": "pacato",
    "pacataços": "pacato",
    "pacatezes": "pacatez",
    "pacatinha": "pacato",
    "pacatinhas": "pacato",
    "pacatinho": "pacato",
    "pacatinhos": "pacato",
    "pacatita": "pacato",
    "pacatitas": "pacato",
    "pacatito": "pacato",
    "pacatitos": "pacato",
    "pacatona": "pacato",
    "pacatonas": "pacato",
    "pacatos": "pacato",
    "pacatozinho": "pacato",
    "pacatozinhos": "pacato",
    "pacatozito": "pacato",
    "pacatozitos": "pacato",
    "pacatão": "pacato",
    "pacatíssima": "pacato",
    "pacatíssimas": "pacato",
    "pacatíssimo": "pacato",
    "pacatíssimos": "pacato",
    "pacatória": "pacatório",
    "pacatórias": "pacatório",
    "pacatórios": "pacatório",
    "pacatões": "pacato",
    "pacaus": "pacau",
    "pacaças": "pacaça",
    "paceira": "paceiro",
    "paceiras": "paceiro",
    "paceiros": "paceiro",
    "pacenha": "pacenho",
    "pacenhas": "pacenho",
    "pacenhos": "pacenho",
    "pacenses": "pacense",
    "pachacins": "pachacim",
    "pacharis": "pacharil",
    "pacharros": "pacharro",
    "pachavelões": "pachavelão",
    "pachecais": "pachecal",
    "pachequices": "pachequice",
    "pachocha": "pachocho",
    "pachochadas": "pachochada",
    "pachochas": "pachocho",
    "pachochos": "pachocho",
    "pacholas": "pachola",
    "pacholices": "pacholice",
    "pachorras": "pachorra",
    "pachorrenta": "pachorrento",
    "pachorrentas": "pachorrento",
    "pachorrentos": "pachorrento",
    "pachorrentíssima": "pachorrento",
    "pachorrentíssimas": "pachorrento",
    "pachorrentíssimo": "pachorrento",
    "pachorrentíssimos": "pachorrento",
    "pachos": "pacho",
    "pachouchadas": "pachouchada",
    "pachéis": "pachel",
    "pacientes": "paciente",
    "pacientíssima": "paciente",
    "pacientíssimas": "paciente",
    "pacientíssimo": "paciente",
    "pacientíssimos": "paciente",
    "pacifica": "pacificar",
    "pacificada": "pacificar",
    "pacificadas": "pacificar",
    "pacificado": "pacificar",
    "pacificadora": "pacificador",
    "pacificadoras": "pacificador",
    "pacificadores": "pacificador",
    "pacificados": "pacificar",
    "pacificai": "pacificar",
    "pacificais": "pacificar",
    "pacificam": "pacificar",
    "pacificamo": "pacificar",
    "pacificamos": "pacificar",
    "pacificando": "pacificar",
    "pacificara": "pacificar",
    "pacificaram": "pacificar",
    "pacificaras": "pacificar",
    "pacificarde": "pacificar",
    "pacificardes": "pacificar",
    "pacificare": "pacificar",
    "pacificarei": "pacificar",
    "pacificareis": "pacificar",
    "pacificarem": "pacificar",
    "pacificaremos": "pacificar",
    "pacificares": "pacificar",
    "pacificaria": "pacificar",
    "pacificariam": "pacificar",
    "pacificarias": "pacificar",
    "pacificarmo": "pacificar",
    "pacificarmos": "pacificar",
    "pacificará": "pacificar",
    "pacificarás": "pacificar",
    "pacificarão": "pacificar",
    "pacificaríamos": "pacificar",
    "pacificaríeis": "pacificar",
    "pacificas": "pacificar",
    "pacificasse": "pacificar",
    "pacificassem": "pacificar",
    "pacificasses": "pacificar",
    "pacificaste": "pacificar",
    "pacificastes": "pacificar",
    "pacificava": "pacificar",
    "pacificavam": "pacificar",
    "pacificavas": "pacificar",
    "pacificações": "pacificação",
    "pacificidades": "pacificidade",
    "pacifico": "pacificar",
    "pacificou": "pacificar",
    "pacificá": "pacificar",
    "pacificámo": "pacificar",
    "pacificámos": "pacificar",
    "pacificáramo": "pacificar",
    "pacificáramos": "pacificar",
    "pacificárei": "pacificar",
    "pacificáreis": "pacificar",
    "pacificásseis": "pacificar",
    "pacificássemos": "pacificar",
    "pacificávamo": "pacificar",
    "pacificávamos": "pacificar",
    "pacificávei": "pacificar",
    "pacificáveis": "pacificável",
    "pacifique": "pacificar",
    "pacifiquei": "pacificar",
    "pacifiqueis": "pacificar",
    "pacifiquem": "pacificar",
    "pacifiquemo": "pacificar",
    "pacifiquemos": "pacificar",
    "pacifiques": "pacificar",
    "pacifismos": "pacifismo",
    "pacifistas": "pacifista",
    "paciências": "paciência",
    "pacobas": "pacoba",
    "pacobeiras": "pacobeira",
    "pacotes": "pacote",
    "pacotilhas": "pacotilha",
    "pacotilhos": "pacotilho",
    "pacotinho": "pacote",
    "pacotinhos": "pacote",
    "pacotito": "pacote",
    "pacotitos": "pacote",
    "pacovas": "pacova",
    "pacoveiras": "pacoveira",
    "pacovices": "pacovice",
    "pacteada": "pactear",
    "pacteadas": "pactear",
    "pacteado": "pactear",
    "pacteados": "pactear",
    "pacteai": "pactear",
    "pacteais": "pactear",
    "pacteamo": "pactear",
    "pacteamos": "pactear",
    "pacteando": "pactear",
    "pacteara": "pactear",
    "pactearam": "pactear",
    "pactearas": "pactear",
    "pacteardes": "pactear",
    "pactearei": "pactear",
    "pacteareis": "pactear",
    "pactearem": "pactear",
    "pactearemos": "pactear",
    "pacteares": "pactear",
    "pactearia": "pactear",
    "pacteariam": "pactear",
    "pactearias": "pactear",
    "pactearmo": "pactear",
    "pactearmos": "pactear",
    "pacteará": "pactear",
    "pactearás": "pactear",
    "pactearão": "pactear",
    "pactearíamos": "pactear",
    "pactearíeis": "pactear",
    "pacteasse": "pactear",
    "pacteassem": "pactear",
    "pacteasses": "pactear",
    "pacteaste": "pactear",
    "pacteastes": "pactear",
    "pacteava": "pactear",
    "pacteavam": "pactear",
    "pacteavas": "pactear",
    "pacteei": "pactear",
    "pacteeis": "pactear",
    "pacteemo": "pactear",
    "pacteemos": "pactear",
    "pacteia": "pactear",
    "pacteiam": "pactear",
    "pacteias": "pactear",
    "pacteie": "pactear",
    "pacteiem": "pactear",
    "pacteies": "pactear",
    "pacteio": "pactear",
    "pacteou": "pactear",
    "pacteámo": "pactear",
    "pacteámos": "pactear",
    "pacteáramo": "pactear",
    "pacteáramos": "pactear",
    "pacteáreis": "pactear",
    "pacteásseis": "pactear",
    "pacteássemos": "pactear",
    "pacteávamo": "pactear",
    "pacteávamos": "pactear",
    "pacteáveis": "pactear",
    "pactos": "pacto",
    "pactua": "pactuar",
    "pactuada": "pactuar",
    "pactuadas": "pactuar",
    "pactuado": "pactuar",
    "pactuados": "pactuar",
    "pactuai": "pactuar",
    "pactuais": "pactuar",
    "pactuam": "pactuar",
    "pactuamo": "pactuar",
    "pactuamos": "pactuar",
    "pactuando": "pactuar",
    "pactuantes": "pactuante",
    "pactuara": "pactuar",
    "pactuaram": "pactuar",
    "pactuaras": "pactuar",
    "pactuarde": "pactuar",
    "pactuardes": "pactuar",
    "pactuare": "pactuar",
    "pactuarei": "pactuar",
    "pactuareis": "pactuar",
    "pactuarem": "pactuar",
    "pactuaremos": "pactuar",
    "pactuares": "pactuar",
    "pactuaria": "pactuar",
    "pactuariam": "pactuar",
    "pactuarias": "pactuar",
    "pactuarmo": "pactuar",
    "pactuarmos": "pactuar",
    "pactuará": "pactuar",
    "pactuarás": "pactuar",
    "pactuarão": "pactuar",
    "pactuaríamos": "pactuar",
    "pactuaríeis": "pactuar",
    "pactuas": "pactuar",
    "pactuasse": "pactuar",
    "pactuassem": "pactuar",
    "pactuasses": "pactuar",
    "pactuaste": "pactuar",
    "pactuastes": "pactuar",
    "pactuava": "pactuar",
    "pactuavam": "pactuar",
    "pactuavas": "pactuar",
    "pactue": "pactuar",
    "pactuei": "pactuar",
    "pactueis": "pactuar",
    "pactuem": "pactuar",
    "pactuemo": "pactuar",
    "pactuemos": "pactuar",
    "pactues": "pactuar",
    "pactuo": "pactuar",
    "pactuou": "pactuar",
    "pactuá": "pactuar",
    "pactuámo": "pactuar",
    "pactuámos": "pactuar",
    "pactuáramo": "pactuar",
    "pactuáramos": "pactuar",
    "pactuárei": "pactuar",
    "pactuáreis": "pactuar",
    "pactuária": "pactuário",
    "pactuárias": "pactuário",
    "pactuários": "pactuário",
    "pactuásseis": "pactuar",
    "pactuássemos": "pactuar",
    "pactuávamo": "pactuar",
    "pactuávamos": "pactuar",
    "pactuávei": "pactuar",
    "pactuáveis": "pactuável",
    "pacífica": "pacífico",
    "pacíficas": "pacífico",
    "pacíficos": "pacífico",
    "pacóvia": "pacóvio",
    "pacóvias": "pacóvio",
    "pacóvios": "pacóvio",
    "padarias": "padaria",
    "padas": "pada",
    "padece": "padecer",
    "padecedora": "padecedor",
    "padecedoras": "padecedor",
    "padecedores": "padecedor",
    "padecei": "padecer",
    "padeceis": "padecer",
    "padecem": "padecer",
    "padecemo": "padecer",
    "padecemos": "padecer",
    "padecendo": "padecer",
    "padecentes": "padecente",
    "padecera": "padecer",
    "padeceram": "padecer",
    "padeceras": "padecer",
    "padecerdes": "padecer",
    "padecerei": "padecer",
    "padecereis": "padecer",
    "padecerem": "padecer",
    "padeceremos": "padecer",
    "padeceres": "padecer",
    "padeceria": "padecer",
    "padeceriam": "padecer",
    "padecerias": "padecer",
    "padecermo": "padecer",
    "padecermos": "padecer",
    "padecerá": "padecer",
    "padecerás": "padecer",
    "padecerão": "padecer",
    "padeceríamos": "padecer",
    "padeceríeis": "padecer",
    "padeces": "padecer",
    "padecesse": "padecer",
    "padecessem": "padecer",
    "padecesses": "padecer",
    "padeceste": "padecer",
    "padecestes": "padecer",
    "padeceu": "padecer",
    "padeci": "padecer",
    "padecia": "padecer",
    "padeciam": "padecer",
    "padecias": "padecer",
    "padecida": "padecido",
    "padecidas": "padecido",
    "padecido": "padecer",
    "padecidos": "padecido",
    "padecimentos": "padecimento",
    "padecêramo": "padecer",
    "padecêramos": "padecer",
    "padecêreis": "padecer",
    "padecêsseis": "padecer",
    "padecêssemos": "padecer",
    "padecíamo": "padecer",
    "padecíamos": "padecer",
    "padecíeis": "padecer",
    "padecíveis": "padecível",
    "padeira": "padeiro",
    "padeiras": "padeiro",
    "padeiros": "padeiro",
    "padeja": "padejar",
    "padejada": "padejar",
    "padejadas": "padejar",
    "padejado": "padejar",
    "padejadora": "padejador",
    "padejadoras": "padejador",
    "padejadores": "padejador",
    "padejados": "padejar",
    "padejai": "padejar",
    "padejais": "padejar",
    "padejam": "padejar",
    "padejamo": "padejar",
    "padejamos": "padejar",
    "padejando": "padejar",
    "padejara": "padejar",
    "padejaram": "padejar",
    "padejaras": "padejar",
    "padejarde": "padejar",
    "padejardes": "padejar",
    "padejare": "padejar",
    "padejarei": "padejar",
    "padejareis": "padejar",
    "padejarem": "padejar",
    "padejaremos": "padejar",
    "padejares": "padejar",
    "padejaria": "padejar",
    "padejariam": "padejar",
    "padejarias": "padejar",
    "padejarmo": "padejar",
    "padejarmos": "padejar",
    "padejará": "padejar",
    "padejarás": "padejar",
    "padejarão": "padejar",
    "padejaríamos": "padejar",
    "padejaríeis": "padejar",
    "padejas": "padejar",
    "padejasse": "padejar",
    "padejassem": "padejar",
    "padejasses": "padejar",
    "padejaste": "padejar",
    "padejastes": "padejar",
    "padejava": "padejar",
    "padejavam": "padejar",
    "padejavas": "padejar",
    "padeje": "padejar",
    "padejei": "padejar",
    "padejeis": "padejar",
    "padejem": "padejar",
    "padejemo": "padejar",
    "padejemos": "padejar",
    "padejes": "padejar",
    "padejo": "padejar",
    "padejos": "padejo",
    "padejou": "padejar",
    "padejá": "padejar",
    "padejámo": "padejar",
    "padejámos": "padejar",
    "padejáramo": "padejar",
    "padejáramos": "padejar",
    "padejárei": "padejar",
    "padejáreis": "padejar",
    "padejásseis": "padejar",
    "padejássemos": "padejar",
    "padejávamo": "padejar",
    "padejávamos": "padejar",
    "padejávei": "padejar",
    "padejáveis": "padejar",
    "padelas": "padela",
    "padeses": "padês",
    "padeça": "padecer",
    "padeçais": "padecer",
    "padeçam": "padecer",
    "padeçamo": "padecer",
    "padeçamos": "padecer",
    "padeças": "padecer",
    "padeço": "padecer",
    "padieiras": "padieira",
    "padinhas": "padinha",
    "padiolas": "padiola",
    "padioleira": "padioleiro",
    "padioleiras": "padioleiro",
    "padioleiros": "padioleiro",
    "padixás": "padixá",
    "pados": "pado",
    "padra": "padrar",
    "padrada": "padrar",
    "padradas": "padrar",
    "padrado": "padrar",
    "padrados": "padrar",
    "padrai": "padrar",
    "padrais": "padrar",
    "padralhadas": "padralhada",
    "padram": "padrar",
    "padramo": "padrar",
    "padramos": "padrar",
    "padrando": "padrar",
    "padrara": "padrar",
    "padraram": "padrar",
    "padraras": "padrar",
    "padrarde": "padrar",
    "padrardes": "padrar",
    "padrare": "padrar",
    "padrarei": "padrar",
    "padrareis": "padrar",
    "padrarem": "padrar",
    "padraremos": "padrar",
    "padrares": "padrar",
    "padraria": "padrar",
    "padrariam": "padrar",
    "padrarias": "padraria",
    "padrarmo": "padrar",
    "padrarmos": "padrar",
    "padrará": "padrar",
    "padrarás": "padrar",
    "padrarão": "padrar",
    "padraríamos": "padrar",
    "padraríeis": "padrar",
    "padras": "padrar",
    "padrasse": "padrar",
    "padrassem": "padrar",
    "padrasses": "padrar",
    "padraste": "padrar",
    "padrastes": "padrar",
    "padrastos": "padrasto",
    "padrava": "padrar",
    "padravam": "padrar",
    "padravas": "padrar",
    "padre": "padrar",
    "padreada": "padrear",
    "padreadas": "padrear",
    "padreado": "padrear",
    "padreadora": "padreador",
    "padreadoras": "padreador",
    "padreadores": "padreador",
    "padreados": "padrear",
    "padreai": "padrear",
    "padreais": "padrear",
    "padreamo": "padrear",
    "padreamos": "padrear",
    "padreando": "padrear",
    "padreara": "padrear",
    "padrearam": "padrear",
    "padrearas": "padrear",
    "padrearde": "padrear",
    "padreardes": "padrear",
    "padreare": "padrear",
    "padrearei": "padrear",
    "padreareis": "padrear",
    "padrearem": "padrear",
    "padrearemos": "padrear",
    "padreares": "padrear",
    "padrearia": "padrear",
    "padreariam": "padrear",
    "padrearias": "padrear",
    "padrearmo": "padrear",
    "padrearmos": "padrear",
    "padreará": "padrear",
    "padrearás": "padrear",
    "padrearão": "padrear",
    "padrearíamos": "padrear",
    "padrearíeis": "padrear",
    "padreasse": "padrear",
    "padreassem": "padrear",
    "padreasses": "padrear",
    "padreaste": "padrear",
    "padreastes": "padrear",
    "padreava": "padrear",
    "padreavam": "padrear",
    "padreavas": "padrear",
    "padrecas": "padreca",
    "padrecos": "padreco",
    "padreei": "padrear",
    "padreeis": "padrear",
    "padreemo": "padrear",
    "padreemos": "padrear",
    "padrei": "padrar",
    "padreia": "padrear",
    "padreiam": "padrear",
    "padreias": "padrear",
    "padreie": "padrear",
    "padreiem": "padrear",
    "padreies": "padrear",
    "padreio": "padrear",
    "padreiros": "padreiro",
    "padreis": "padrar",
    "padrem": "padrar",
    "padremo": "padrar",
    "padremos": "padrar",
    "padreou": "padrear",
    "padres": "padre",
    "padresca": "padresco",
    "padrescas": "padresco",
    "padrescos": "padresco",
    "padreá": "padrear",
    "padreámo": "padrear",
    "padreámos": "padrear",
    "padreáramo": "padrear",
    "padreáramos": "padrear",
    "padreárei": "padrear",
    "padreáreis": "padrear",
    "padreásseis": "padrear",
    "padreássemos": "padrear",
    "padreávamo": "padrear",
    "padreávamos": "padrear",
    "padreávei": "padrear",
    "padreáveis": "padrear",
    "padrinhos": "padrinho",
    "padro": "padrar",
    "padroados": "padroado",
    "padroeira": "padroeiro",
    "padroeiras": "padroeiro",
    "padroeiros": "padroeiro",
    "padroniza": "padronizar",
    "padronizada": "padronizar",
    "padronizadas": "padronizar",
    "padronizado": "padronizar",
    "padronizados": "padronizar",
    "padronizai": "padronizar",
    "padronizais": "padronizar",
    "padronizam": "padronizar",
    "padronizamo": "padronizar",
    "padronizamos": "padronizar",
    "padronizando": "padronizar",
    "padronizara": "padronizar",
    "padronizaram": "padronizar",
    "padronizaras": "padronizar",
    "padronizarde": "padronizar",
    "padronizardes": "padronizar",
    "padronizare": "padronizar",
    "padronizarei": "padronizar",
    "padronizareis": "padronizar",
    "padronizarem": "padronizar",
    "padronizaremos": "padronizar",
    "padronizares": "padronizar",
    "padronizaria": "padronizar",
    "padronizariam": "padronizar",
    "padronizarias": "padronizar",
    "padronizarmo": "padronizar",
    "padronizarmos": "padronizar",
    "padronizará": "padronizar",
    "padronizarás": "padronizar",
    "padronizarão": "padronizar",
    "padronizaríamos": "padronizar",
    "padronizaríeis": "padronizar",
    "padronizas": "padronizar",
    "padronizasse": "padronizar",
    "padronizassem": "padronizar",
    "padronizasses": "padronizar",
    "padronizaste": "padronizar",
    "padronizastes": "padronizar",
    "padronizava": "padronizar",
    "padronizavam": "padronizar",
    "padronizavas": "padronizar",
    "padronizações": "padronização",
    "padronize": "padronizar",
    "padronizei": "padronizar",
    "padronizeis": "padronizar",
    "padronizem": "padronizar",
    "padronizemo": "padronizar",
    "padronizemos": "padronizar",
    "padronizes": "padronizar",
    "padronizo": "padronizar",
    "padronizou": "padronizar",
    "padronizá": "padronizar",
    "padronizámo": "padronizar",
    "padronizámos": "padronizar",
    "padronizáramo": "padronizar",
    "padronizáramos": "padronizar",
    "padronizárei": "padronizar",
    "padronizáreis": "padronizar",
    "padronizásseis": "padronizar",
    "padronizássemos": "padronizar",
    "padronizávamo": "padronizar",
    "padronizávamos": "padronizar",
    "padronizávei": "padronizar",
    "padronizáveis": "padronizável",
    "padrou": "padrar",
    "padrá": "padrar",
    "padrámo": "padrar",
    "padrámos": "padrar",
    "padráramo": "padrar",
    "padráramos": "padrar",
    "padrárei": "padrar",
    "padráreis": "padrar",
    "padrásseis": "padrar",
    "padrássemos": "padrar",
    "padrávamo": "padrar",
    "padrávamos": "padrar",
    "padrávei": "padrar",
    "padráveis": "padrar",
    "padrões": "padrão",
    "paduana": "paduano",
    "paduanas": "paduano",
    "paduanos": "paduano",
    "paelhas": "paelha",
    "paga": "pago",
    "pagada": "pagar",
    "pagadas": "pagar",
    "pagado": "pagar",
    "pagadora": "pagador",
    "pagadoras": "pagador",
    "pagadores": "pagador",
    "pagadorias": "pagadoria",
    "pagados": "pagar",
    "pagai": "pagar",
    "pagais": "pagar",
    "pagam": "pagar",
    "pagamentos": "pagamento",
    "pagamo": "pagar",
    "pagamos": "pagar",
    "pagando": "pagar",
    "paganismos": "paganismo",
    "paganiza": "paganizar",
    "paganizada": "paganizar",
    "paganizadas": "paganizar",
    "paganizado": "paganizar",
    "paganizadora": "paganizador",
    "paganizadoras": "paganizador",
    "paganizadores": "paganizador",
    "paganizados": "paganizar",
    "paganizai": "paganizar",
    "paganizais": "paganizar",
    "paganizam": "paganizar",
    "paganizamo": "paganizar",
    "paganizamos": "paganizar",
    "paganizando": "paganizar",
    "paganizantes": "paganizante",
    "paganizara": "paganizar",
    "paganizaram": "paganizar",
    "paganizaras": "paganizar",
    "paganizarde": "paganizar",
    "paganizardes": "paganizar",
    "paganizare": "paganizar",
    "paganizarei": "paganizar",
    "paganizareis": "paganizar",
    "paganizarem": "paganizar",
    "paganizaremos": "paganizar",
    "paganizares": "paganizar",
    "paganizaria": "paganizar",
    "paganizariam": "paganizar",
    "paganizarias": "paganizar",
    "paganizarmo": "paganizar",
    "paganizarmos": "paganizar",
    "paganizará": "paganizar",
    "paganizarás": "paganizar",
    "paganizarão": "paganizar",
    "paganizaríamos": "paganizar",
    "paganizaríeis": "paganizar",
    "paganizas": "paganizar",
    "paganizasse": "paganizar",
    "paganizassem": "paganizar",
    "paganizasses": "paganizar",
    "paganizaste": "paganizar",
    "paganizastes": "paganizar",
    "paganizava": "paganizar",
    "paganizavam": "paganizar",
    "paganizavas": "paganizar",
    "paganizações": "paganização",
    "paganize": "paganizar",
    "paganizei": "paganizar",
    "paganizeis": "paganizar",
    "paganizem": "paganizar",
    "paganizemo": "paganizar",
    "paganizemos": "paganizar",
    "paganizes": "paganizar",
    "paganizo": "paganizar",
    "paganizou": "paganizar",
    "paganizá": "paganizar",
    "paganizámo": "paganizar",
    "paganizámos": "paganizar",
    "paganizáramo": "paganizar",
    "paganizáramos": "paganizar",
    "paganizárei": "paganizar",
    "paganizáreis": "paganizar",
    "paganizásseis": "paganizar",
    "paganizássemos": "paganizar",
    "paganizávamo": "paganizar",
    "paganizávamos": "paganizar",
    "paganizávei": "paganizar",
    "paganizáveis": "paganizável",
    "pagantes": "pagante",
    "pagara": "pagar",
    "pagaram": "pagar",
    "pagaras": "pagar",
    "pagarde": "pagar",
    "pagardes": "pagar",
    "pagare": "pagar",
    "pagarei": "pagar",
    "pagareis": "pagar",
    "pagarem": "pagar",
    "pagaremos": "pagar",
    "pagares": "pagar",
    "pagaria": "pagar",
    "pagariam": "pagar",
    "pagarias": "pagar",
    "pagarmo": "pagar",
    "pagarmos": "pagar",
    "pagará": "pagar",
    "pagarás": "pagar",
    "pagarão": "pagar",
    "pagaríamos": "pagar",
    "pagaríeis": "pagar",
    "pagas": "pago",
    "pagasse": "pagar",
    "pagassem": "pagar",
    "pagasses": "pagar",
    "pagaste": "pagar",
    "pagastes": "pagar",
    "pagava": "pagar",
    "pagavam": "pagar",
    "pagavas": "pagar",
    "pagelas": "pagela",
    "pagina": "paginar",
    "paginada": "paginar",
    "paginadas": "paginar",
    "paginado": "paginar",
    "paginadora": "paginador",
    "paginadoras": "paginador",
    "paginadores": "paginador",
    "paginados": "paginar",
    "paginai": "paginar",
    "paginais": "paginar",
    "paginam": "paginar",
    "paginamo": "paginar",
    "paginamos": "paginar",
    "paginando": "paginar",
    "paginara": "paginar",
    "paginaram": "paginar",
    "paginaras": "paginar",
    "paginarde": "paginar",
    "paginardes": "paginar",
    "paginare": "paginar",
    "paginarei": "paginar",
    "paginareis": "paginar",
    "paginarem": "paginar",
    "paginaremos": "paginar",
    "paginares": "paginar",
    "paginaria": "paginar",
    "paginariam": "paginar",
    "paginarias": "paginar",
    "paginarmo": "paginar",
    "paginarmos": "paginar",
    "paginará": "paginar",
    "paginarás": "paginar",
    "paginarão": "paginar",
    "paginaríamos": "paginar",
    "paginaríeis": "paginar",
    "paginas": "paginar",
    "paginasse": "paginar",
    "paginassem": "paginar",
    "paginasses": "paginar",
    "paginaste": "paginar",
    "paginastes": "paginar",
    "paginava": "paginar",
    "paginavam": "paginar",
    "paginavas": "paginar",
    "paginazinha": "página",
    "paginazinhas": "página",
    "paginazita": "página",
    "paginazitas": "página",
    "paginações": "paginação",
    "pagine": "paginar",
    "paginei": "paginar",
    "pagineis": "paginar",
    "paginem": "paginar",
    "paginemo": "paginar",
    "paginemos": "paginar",
    "pagines": "paginar",
    "pagino": "paginar",
    "paginou": "paginar",
    "paginá": "paginar",
    "paginámo": "paginar",
    "paginámos": "paginar",
    "pagináramo": "paginar",
    "pagináramos": "paginar",
    "paginárei": "paginar",
    "pagináreis": "paginar",
    "paginásseis": "paginar",
    "paginássemos": "paginar",
    "paginávamo": "paginar",
    "paginávamos": "paginar",
    "paginávei": "paginar",
    "pagináveis": "paginável",
    "pago": "pagar",
    "pagodeada": "pagodear",
    "pagodeadas": "pagodear",
    "pagodeado": "pagodear",
    "pagodeados": "pagodear",
    "pagodeai": "pagodear",
    "pagodeais": "pagodear",
    "pagodeamo": "pagodear",
    "pagodeamos": "pagodear",
    "pagodeando": "pagodear",
    "pagodeara": "pagodear",
    "pagodearam": "pagodear",
    "pagodearas": "pagodear",
    "pagodearde": "pagodear",
    "pagodeardes": "pagodear",
    "pagodeare": "pagodear",
    "pagodearei": "pagodear",
    "pagodeareis": "pagodear",
    "pagodearem": "pagodear",
    "pagodearemos": "pagodear",
    "pagodeares": "pagodear",
    "pagodearia": "pagodear",
    "pagodeariam": "pagodear",
    "pagodearias": "pagodear",
    "pagodearmo": "pagodear",
    "pagodearmos": "pagodear",
    "pagodeará": "pagodear",
    "pagodearás": "pagodear",
    "pagodearão": "pagodear",
    "pagodearíamos": "pagodear",
    "pagodearíeis": "pagodear",
    "pagodeasse": "pagodear",
    "pagodeassem": "pagodear",
    "pagodeasses": "pagodear",
    "pagodeaste": "pagodear",
    "pagodeastes": "pagodear",
    "pagodeava": "pagodear",
    "pagodeavam": "pagodear",
    "pagodeavas": "pagodear",
    "pagodeei": "pagodear",
    "pagodeeis": "pagodear",
    "pagodeemo": "pagodear",
    "pagodeemos": "pagodear",
    "pagodeia": "pagodear",
    "pagodeiam": "pagodear",
    "pagodeias": "pagodear",
    "pagodeie": "pagodear",
    "pagodeiem": "pagodear",
    "pagodeies": "pagodear",
    "pagodeio": "pagodear",
    "pagodeira": "pagodeiro",
    "pagodeiras": "pagodeiro",
    "pagodeiros": "pagodeiro",
    "pagodeou": "pagodear",
    "pagodes": "pagode",
    "pagodeá": "pagodear",
    "pagodeámo": "pagodear",
    "pagodeámos": "pagodear",
    "pagodeáramo": "pagodear",
    "pagodeáramos": "pagodear",
    "pagodeárei": "pagodear",
    "pagodeáreis": "pagodear",
    "pagodeásseis": "pagodear",
    "pagodeássemos": "pagodear",
    "pagodeávamo": "pagodear",
    "pagodeávamos": "pagodear",
    "pagodeávei": "pagodear",
    "pagodeáveis": "pagodear",
    "pagodices": "pagodice",
    "pagodistas": "pagodista",
    "pagos": "pago",
    "pagou": "pagar",
    "pague": "pagar",
    "paguei": "pagar",
    "pagueis": "pagar",
    "paguem": "pagar",
    "paguemo": "pagar",
    "paguemos": "pagar",
    "pagueres": "paguer",
    "pagues": "pagar",
    "paguilhas": "paguilha",
    "paguros": "paguro",
    "paguéis": "paguel",
    "pagá": "pagar",
    "pagámo": "pagar",
    "pagámos": "pagar",
    "pagáramo": "pagar",
    "pagáramos": "pagar",
    "pagárei": "pagar",
    "pagáreis": "pagar",
    "pagásseis": "pagar",
    "pagássemos": "pagar",
    "pagávamo": "pagar",
    "pagávamos": "pagar",
    "pagávei": "pagar",
    "pagáveis": "pagável",
    "pagã": "pagão",
    "pagãos": "pagão",
    "pagãs": "pagão",
    "pailonas": "pailona",
    "painas": "paina",
    "paineiras": "paineira",
    "painhos": "painho",
    "pains": "paim",
    "painças": "painça",
    "painços": "painço",
    "painéis": "painel",
    "paioleira": "paioleiro",
    "paioleiras": "paioleiro",
    "paioleiros": "paioleiro",
    "paios": "paio",
    "paiozinho": "paio",
    "paiozinhos": "paio",
    "paiozito": "paio",
    "paiozitos": "paio",
    "paira": "pairar",
    "pairada": "pairar",
    "pairadas": "pairar",
    "pairado": "pairar",
    "pairados": "pairar",
    "pairai": "pairar",
    "pairais": "pairar",
    "pairam": "pairar",
    "pairamo": "pairar",
    "pairamos": "pairar",
    "pairando": "pairar",
    "pairara": "pairar",
    "pairaram": "pairar",
    "pairaras": "pairar",
    "pairardes": "pairar",
    "pairarei": "pairar",
    "pairareis": "pairar",
    "pairarem": "pairar",
    "pairaremos": "pairar",
    "pairares": "pairar",
    "pairaria": "pairar",
    "pairariam": "pairar",
    "pairarias": "pairar",
    "pairarmo": "pairar",
    "pairarmos": "pairar",
    "pairará": "pairar",
    "pairarás": "pairar",
    "pairarão": "pairar",
    "pairaríamos": "pairar",
    "pairaríeis": "pairar",
    "pairas": "pairar",
    "pairasse": "pairar",
    "pairassem": "pairar",
    "pairasses": "pairar",
    "pairaste": "pairar",
    "pairastes": "pairar",
    "pairava": "pairar",
    "pairavam": "pairar",
    "pairavas": "pairar",
    "paire": "pairar",
    "pairei": "pairar",
    "paireis": "pairar",
    "pairem": "pairar",
    "pairemo": "pairar",
    "pairemos": "pairar",
    "paires": "pairar",
    "pairo": "pairar",
    "pairos": "pairo",
    "pairou": "pairar",
    "pairámo": "pairar",
    "pairámos": "pairar",
    "pairáramo": "pairar",
    "pairáramos": "pairar",
    "pairáreis": "pairar",
    "pairásseis": "pairar",
    "pairássemos": "pairar",
    "pairávamo": "pairar",
    "pairávamos": "pairar",
    "pairáveis": "pairar",
    "pais": "pai",
    "paisagens": "paisagem",
    "paisagesca": "paisagesco",
    "paisagescas": "paisagesco",
    "paisagescos": "paisagesco",
    "paisagismos": "paisagismo",
    "paisagistas": "paisagista",
    "paisagística": "paisagístico",
    "paisagísticas": "paisagístico",
    "paisagísticos": "paisagístico",
    "paisana": "paisano",
    "paisanadas": "paisanada",
    "paisanas": "paisano",
    "paisanos": "paisano",
    "paisistas": "paisista",
    "paivantes": "paivante",
    "paivenses": "paivense",
    "paivota": "paivoto",
    "paivotas": "paivoto",
    "paivotos": "paivoto",
    "paixonetas": "paixoneta",
    "paixãozinha": "paixão",
    "paixãozita": "paixão",
    "paixões": "paixão",
    "paixõezinhas": "paixão",
    "paixõezitas": "paixão",
    "paizinho": "pai",
    "paizinhos": "pai",
    "paizito": "pai",
    "paizitos": "pai",
    "paióis": "paiol",
    "pajeada": "pajear",
    "pajeadas": "pajear",
    "pajeado": "pajear",
    "pajeados": "pajear",
    "pajeai": "pajear",
    "pajeais": "pajear",
    "pajeamo": "pajear",
    "pajeamos": "pajear",
    "pajeando": "pajear",
    "pajeara": "pajear",
    "pajearam": "pajear",
    "pajearas": "pajear",
    "pajearde": "pajear",
    "pajeardes": "pajear",
    "pajeare": "pajear",
    "pajearei": "pajear",
    "pajeareis": "pajear",
    "pajearem": "pajear",
    "pajearemos": "pajear",
    "pajeares": "pajear",
    "pajearia": "pajear",
    "pajeariam": "pajear",
    "pajearias": "pajear",
    "pajearmo": "pajear",
    "pajearmos": "pajear",
    "pajeará": "pajear",
    "pajearás": "pajear",
    "pajearão": "pajear",
    "pajearíamos": "pajear",
    "pajearíeis": "pajear",
    "pajeasse": "pajear",
    "pajeassem": "pajear",
    "pajeasses": "pajear",
    "pajeaste": "pajear",
    "pajeastes": "pajear",
    "pajeava": "pajear",
    "pajeavam": "pajear",
    "pajeavas": "pajear",
    "pajeei": "pajear",
    "pajeeis": "pajear",
    "pajeemo": "pajear",
    "pajeemos": "pajear",
    "pajeia": "pajear",
    "pajeiam": "pajear",
    "pajeias": "pajear",
    "pajeie": "pajear",
    "pajeiem": "pajear",
    "pajeies": "pajear",
    "pajeio": "pajear",
    "pajens": "pajem",
    "pajeou": "pajear",
    "pajes": "paje",
    "pajeá": "pajear",
    "pajeámo": "pajear",
    "pajeámos": "pajear",
    "pajeáramo": "pajear",
    "pajeáramos": "pajear",
    "pajeárei": "pajear",
    "pajeáreis": "pajear",
    "pajeásseis": "pajear",
    "pajeássemos": "pajear",
    "pajeávamo": "pajear",
    "pajeávamos": "pajear",
    "pajeávei": "pajear",
    "pajeáveis": "pajear",
    "pajões": "pajão",
    "palacetes": "palacete",
    "palaciana": "palaciano",
    "palacianas": "palaciano",
    "palacianismos": "palacianismo",
    "palacianos": "palaciano",
    "palacianíssima": "palaciano",
    "palacianíssimas": "palaciano",
    "palacianíssimo": "palaciano",
    "palacianíssimos": "palaciano",
    "paladares": "paladar",
    "paladinos": "paladino",
    "paladins": "paladim",
    "paladínica": "paladínico",
    "paladínicas": "paladínico",
    "paladínicos": "paladínico",
    "palafitas": "palafita",
    "palafreneiros": "palafreneiro",
    "palafréns": "palafrém",
    "palagonites": "palagonite",
    "palaios": "palaio",
    "palamalhares": "palamalhar",
    "palamalhos": "palamalho",
    "palamentas": "palamenta",
    "palanca": "palancar",
    "palancada": "palancar",
    "palancadas": "palancar",
    "palancado": "palancar",
    "palancados": "palancar",
    "palancai": "palancar",
    "palancais": "palancar",
    "palancam": "palancar",
    "palancamo": "palancar",
    "palancamos": "palancar",
    "palancando": "palancar",
    "palancara": "palancar",
    "palancaram": "palancar",
    "palancaras": "palancar",
    "palancarde": "palancar",
    "palancardes": "palancar",
    "palancare": "palancar",
    "palancarei": "palancar",
    "palancareis": "palancar",
    "palancarem": "palancar",
    "palancaremos": "palancar",
    "palancares": "palancar",
    "palancaria": "palancar",
    "palancariam": "palancar",
    "palancarias": "palancar",
    "palancarmo": "palancar",
    "palancarmos": "palancar",
    "palancará": "palancar",
    "palancarás": "palancar",
    "palancarão": "palancar",
    "palancaríamos": "palancar",
    "palancaríeis": "palancar",
    "palancas": "palancar",
    "palancasse": "palancar",
    "palancassem": "palancar",
    "palancasses": "palancar",
    "palancaste": "palancar",
    "palancastes": "palancar",
    "palancava": "palancar",
    "palancavam": "palancar",
    "palancavas": "palancar",
    "palanco": "palancar",
    "palancos": "palanco",
    "palancou": "palancar",
    "palancá": "palancar",
    "palancámo": "palancar",
    "palancámos": "palancar",
    "palancáramo": "palancar",
    "palancáramos": "palancar",
    "palancárei": "palancar",
    "palancáreis": "palancar",
    "palancásseis": "palancar",
    "palancássemos": "palancar",
    "palancávamo": "palancar",
    "palancávamos": "palancar",
    "palancávei": "palancar",
    "palancáveis": "palancar",
    "palanfrórios": "palanfrório",
    "palanganas": "palangana",
    "palanque": "palancar",
    "palanquei": "palancar",
    "palanqueira": "palanqueiro",
    "palanqueiras": "palanqueiro",
    "palanqueiros": "palanqueiro",
    "palanqueis": "palancar",
    "palanquem": "palancar",
    "palanquemo": "palancar",
    "palanquemos": "palancar",
    "palanques": "palanque",
    "palanquins": "palanquim",
    "palas": "pala",
    "palatais": "palatal",
    "palataliza": "palatalizar",
    "palatalizada": "palatalizar",
    "palatalizadas": "palatalizar",
    "palatalizado": "palatalizar",
    "palatalizados": "palatalizar",
    "palatalizai": "palatalizar",
    "palatalizais": "palatalizar",
    "palatalizam": "palatalizar",
    "palatalizamo": "palatalizar",
    "palatalizamos": "palatalizar",
    "palatalizando": "palatalizar",
    "palatalizara": "palatalizar",
    "palatalizaram": "palatalizar",
    "palatalizaras": "palatalizar",
    "palatalizarde": "palatalizar",
    "palatalizardes": "palatalizar",
    "palatalizare": "palatalizar",
    "palatalizarei": "palatalizar",
    "palatalizareis": "palatalizar",
    "palatalizarem": "palatalizar",
    "palatalizaremos": "palatalizar",
    "palatalizares": "palatalizar",
    "palatalizaria": "palatalizar",
    "palatalizariam": "palatalizar",
    "palatalizarias": "palatalizar",
    "palatalizarmo": "palatalizar",
    "palatalizarmos": "palatalizar",
    "palatalizará": "palatalizar",
    "palatalizarás": "palatalizar",
    "palatalizarão": "palatalizar",
    "palatalizaríamos": "palatalizar",
    "palatalizaríeis": "palatalizar",
    "palatalizas": "palatalizar",
    "palatalizasse": "palatalizar",
    "palatalizassem": "palatalizar",
    "palatalizasses": "palatalizar",
    "palatalizaste": "palatalizar",
    "palatalizastes": "palatalizar",
    "palatalizava": "palatalizar",
    "palatalizavam": "palatalizar",
    "palatalizavas": "palatalizar",
    "palatalizações": "palatalização",
    "palatalize": "palatalizar",
    "palatalizei": "palatalizar",
    "palatalizeis": "palatalizar",
    "palatalizem": "palatalizar",
    "palatalizemo": "palatalizar",
    "palatalizemos": "palatalizar",
    "palatalizes": "palatalizar",
    "palatalizo": "palatalizar",
    "palatalizou": "palatalizar",
    "palatalizá": "palatalizar",
    "palatalizámo": "palatalizar",
    "palatalizámos": "palatalizar",
    "palatalizáramo": "palatalizar",
    "palatalizáramos": "palatalizar",
    "palatalizárei": "palatalizar",
    "palatalizáreis": "palatalizar",
    "palatalizásseis": "palatalizar",
    "palatalizássemos": "palatalizar",
    "palatalizávamo": "palatalizar",
    "palatalizávamos": "palatalizar",
    "palatalizávei": "palatalizar",
    "palatalizáveis": "palatalizável",
    "palatina": "palatino",
    "palatinados": "palatinado",
    "palatinas": "palatino",
    "palatinos": "palatino",
    "palatites": "palatite",
    "palatiza": "palatizar",
    "palatizada": "palatizar",
    "palatizadas": "palatizar",
    "palatizado": "palatizar",
    "palatizados": "palatizar",
    "palatizai": "palatizar",
    "palatizais": "palatizar",
    "palatizam": "palatizar",
    "palatizamo": "palatizar",
    "palatizamos": "palatizar",
    "palatizando": "palatizar",
    "palatizara": "palatizar",
    "palatizaram": "palatizar",
    "palatizaras": "palatizar",
    "palatizarde": "palatizar",
    "palatizardes": "palatizar",
    "palatizare": "palatizar",
    "palatizarei": "palatizar",
    "palatizareis": "palatizar",
    "palatizarem": "palatizar",
    "palatizaremos": "palatizar",
    "palatizares": "palatizar",
    "palatizaria": "palatizar",
    "palatizariam": "palatizar",
    "palatizarias": "palatizar",
    "palatizarmo": "palatizar",
    "palatizarmos": "palatizar",
    "palatizará": "palatizar",
    "palatizarás": "palatizar",
    "palatizarão": "palatizar",
    "palatizaríamos": "palatizar",
    "palatizaríeis": "palatizar",
    "palatizas": "palatizar",
    "palatizasse": "palatizar",
    "palatizassem": "palatizar",
    "palatizasses": "palatizar",
    "palatizaste": "palatizar",
    "palatizastes": "palatizar",
    "palatizava": "palatizar",
    "palatizavam": "palatizar",
    "palatizavas": "palatizar",
    "palatizações": "palatização",
    "palatize": "palatizar",
    "palatizei": "palatizar",
    "palatizeis": "palatizar",
    "palatizem": "palatizar",
    "palatizemo": "palatizar",
    "palatizemos": "palatizar",
    "palatizes": "palatizar",
    "palatizo": "palatizar",
    "palatizou": "palatizar",
    "palatizá": "palatizar",
    "palatizámo": "palatizar",
    "palatizámos": "palatizar",
    "palatizáramo": "palatizar",
    "palatizáramos": "palatizar",
    "palatizárei": "palatizar",
    "palatizáreis": "palatizar",
    "palatizásseis": "palatizar",
    "palatizássemos": "palatizar",
    "palatizávamo": "palatizar",
    "palatizávamos": "palatizar",
    "palatizávei": "palatizar",
    "palatizáveis": "palatizar",
    "palatos": "palato",
    "palavradas": "palavrada",
    "palavras": "palavra",
    "palavreada": "palavrear",
    "palavreadas": "palavrear",
    "palavreadinho": "palavreado",
    "palavreadinhos": "palavreado",
    "palavreadito": "palavreado",
    "palavreaditos": "palavreado",
    "palavreado": "palavrear",
    "palavreadora": "palavreador",
    "palavreadoras": "palavreador",
    "palavreadores": "palavreador",
    "palavreados": "palavrear",
    "palavreadozinho": "palavreado",
    "palavreadozinhos": "palavreado",
    "palavreadozito": "palavreado",
    "palavreadozitos": "palavreado",
    "palavreai": "palavrear",
    "palavreais": "palavrear",
    "palavreamo": "palavrear",
    "palavreamos": "palavrear",
    "palavreando": "palavrear",
    "palavreara": "palavrear",
    "palavrearam": "palavrear",
    "palavrearas": "palavrear",
    "palavreardes": "palavrear",
    "palavrearei": "palavrear",
    "palavreareis": "palavrear",
    "palavrearem": "palavrear",
    "palavrearemos": "palavrear",
    "palavreares": "palavrear",
    "palavrearia": "palavrear",
    "palavreariam": "palavrear",
    "palavrearias": "palavrear",
    "palavrearmo": "palavrear",
    "palavrearmos": "palavrear",
    "palavreará": "palavrear",
    "palavrearás": "palavrear",
    "palavrearão": "palavrear",
    "palavrearíamos": "palavrear",
    "palavrearíeis": "palavrear",
    "palavreasse": "palavrear",
    "palavreassem": "palavrear",
    "palavreasses": "palavrear",
    "palavreaste": "palavrear",
    "palavreastes": "palavrear",
    "palavreava": "palavrear",
    "palavreavam": "palavrear",
    "palavreavas": "palavrear",
    "palavreei": "palavrear",
    "palavreeis": "palavrear",
    "palavreemo": "palavrear",
    "palavreemos": "palavrear",
    "palavreia": "palavrear",
    "palavreiam": "palavrear",
    "palavreias": "palavrear",
    "palavreie": "palavrear",
    "palavreiem": "palavrear",
    "palavreies": "palavrear",
    "palavreio": "palavrear",
    "palavreira": "palavreiro",
    "palavreiras": "palavreiro",
    "palavreiros": "palavreiro",
    "palavreou": "palavrear",
    "palavreámo": "palavrear",
    "palavreámos": "palavrear",
    "palavreáramo": "palavrear",
    "palavreáramos": "palavrear",
    "palavreáreis": "palavrear",
    "palavreásseis": "palavrear",
    "palavreássemos": "palavrear",
    "palavreávamo": "palavrear",
    "palavreávamos": "palavrear",
    "palavreáveis": "palavrear",
    "palavrinha": "palavra",
    "palavrinhas": "palavrinha",
    "palavrita": "palavra",
    "palavritas": "palavra",
    "palavrosa": "palavroso",
    "palavrosas": "palavroso",
    "palavrosos": "palavroso",
    "palavrórios": "palavrório",
    "palavrões": "palavrão",
    "palavões": "palavão",
    "palcos": "palco",
    "paleada": "palear",
    "paleadas": "palear",
    "paleado": "palear",
    "paleados": "palear",
    "paleai": "palear",
    "paleais": "palear",
    "paleamo": "palear",
    "paleamos": "palear",
    "paleando": "palear",
    "paleantropologias": "paleantropologia",
    "paleantropologistas": "paleantropologista",
    "paleantropológica": "paleantropológico",
    "paleantropológicas": "paleantropológico",
    "paleantropológicos": "paleantropológico",
    "paleantropóloga": "paleantropólogo",
    "paleantropólogas": "paleantropólogo",
    "paleantropólogos": "paleantropólogo",
    "paleara": "palear",
    "palearam": "palear",
    "palearas": "palear",
    "paleardes": "palear",
    "palearei": "palear",
    "paleareis": "palear",
    "palearem": "palear",
    "palearemos": "palear",
    "paleares": "palear",
    "palearia": "palear",
    "paleariam": "palear",
    "palearias": "palear",
    "palearmo": "palear",
    "palearmos": "palear",
    "paleará": "palear",
    "palearás": "palear",
    "palearão": "palear",
    "palearíamos": "palear",
    "palearíeis": "palear",
    "paleasse": "palear",
    "paleassem": "palear",
    "paleasses": "palear",
    "paleaste": "palear",
    "paleastes": "palear",
    "paleava": "palear",
    "paleavam": "palear",
    "paleavas": "palear",
    "paleações": "paleação",
    "paleei": "palear",
    "paleeis": "palear",
    "paleemo": "palear",
    "paleemos": "palear",
    "paleia": "palear",
    "paleiam": "palear",
    "paleias": "palear",
    "paleie": "palear",
    "paleiem": "palear",
    "paleies": "palear",
    "paleiformes": "paleiforme",
    "paleio": "palear",
    "paleios": "paleio",
    "palemonídeos": "palemonídeo",
    "palemónidas": "palemónida",
    "paleobotânica": "paleobotânico",
    "paleobotânicas": "paleobotânico",
    "paleobotânicos": "paleobotânico",
    "paleografias": "paleografia",
    "paleográfica": "paleográfico",
    "paleográficas": "paleográfico",
    "paleográficos": "paleográfico",
    "paleogénica": "paleogénico",
    "paleogénicas": "paleogénico",
    "paleogénicos": "paleogénico",
    "paleologias": "paleologia",
    "paleologistas": "paleologista",
    "paleolítica": "paleolítico",
    "paleolíticas": "paleolítico",
    "paleolíticos": "paleolítico",
    "paleológica": "paleológico",
    "paleológicas": "paleológico",
    "paleológicos": "paleológico",
    "paleoniscóides": "paleoniscóide",
    "paleontografias": "paleontografia",
    "paleontografistas": "paleontografista",
    "paleontologias": "paleontologia",
    "paleontologistas": "paleontologista",
    "paleontógrafa": "paleontógrafo",
    "paleontógrafas": "paleontógrafo",
    "paleontógrafos": "paleontógrafo",
    "paleontóloga": "paleontólogo",
    "paleontólogas": "paleontólogo",
    "paleontólogos": "paleontólogo",
    "paleostráceos": "paleostráceo",
    "paleotemperaturas": "paleotemperatura",
    "paleotéricos": "paleotérico",
    "paleotérios": "paleotério",
    "paleou": "palear",
    "paleozoologias": "paleozoologia",
    "paleozoologistas": "paleozoologista",
    "paleozoóloga": "paleozoólogo",
    "paleozoólogas": "paleozoólogo",
    "paleozoólogos": "paleozoólogo",
    "paleozóica": "paleozóico",
    "paleozóicas": "paleozóico",
    "paleozóicos": "paleozóico",
    "palermas": "palerma",
    "palermices": "palermice",
    "palerminha": "palerma",
    "palerminhas": "palerma",
    "palermita": "palerma",
    "palermitana": "palermitano",
    "palermitanas": "palermitano",
    "palermitanos": "palermitano",
    "palermitas": "palerma",
    "palestesias": "palestesia",
    "palestina": "palestino",
    "palestinas": "palestino",
    "palestiniana": "palestiniano",
    "palestinianas": "palestiniano",
    "palestinianos": "palestiniano",
    "palestinos": "palestino",
    "palestra": "palestrar",
    "palestrada": "palestrar",
    "palestradas": "palestrar",
    "palestrado": "palestrar",
    "palestrados": "palestrar",
    "palestrai": "palestrar",
    "palestrais": "palestrar",
    "palestram": "palestrar",
    "palestramo": "palestrar",
    "palestramos": "palestrar",
    "palestrando": "palestrar",
    "palestrara": "palestrar",
    "palestraram": "palestrar",
    "palestraras": "palestrar",
    "palestrardes": "palestrar",
    "palestrarei": "palestrar",
    "palestrareis": "palestrar",
    "palestrarem": "palestrar",
    "palestraremos": "palestrar",
    "palestrares": "palestrar",
    "palestraria": "palestrar",
    "palestrariam": "palestrar",
    "palestrarias": "palestrar",
    "palestrarmo": "palestrar",
    "palestrarmos": "palestrar",
    "palestrará": "palestrar",
    "palestrarás": "palestrar",
    "palestrarão": "palestrar",
    "palestraríamos": "palestrar",
    "palestraríeis": "palestrar",
    "palestras": "palestrar",
    "palestrasse": "palestrar",
    "palestrassem": "palestrar",
    "palestrasses": "palestrar",
    "palestraste": "palestrar",
    "palestrastes": "palestrar",
    "palestrava": "palestrar",
    "palestravam": "palestrar",
    "palestravas": "palestrar",
    "palestre": "palestrar",
    "palestreada": "palestrear",
    "palestreadas": "palestrear",
    "palestreado": "palestrear",
    "palestreados": "palestrear",
    "palestreai": "palestrear",
    "palestreais": "palestrear",
    "palestreamo": "palestrear",
    "palestreamos": "palestrear",
    "palestreando": "palestrear",
    "palestreara": "palestrear",
    "palestrearam": "palestrear",
    "palestrearas": "palestrear",
    "palestreardes": "palestrear",
    "palestrearei": "palestrear",
    "palestreareis": "palestrear",
    "palestrearem": "palestrear",
    "palestrearemos": "palestrear",
    "palestreares": "palestrear",
    "palestrearia": "palestrear",
    "palestreariam": "palestrear",
    "palestrearias": "palestrear",
    "palestrearmo": "palestrear",
    "palestrearmos": "palestrear",
    "palestreará": "palestrear",
    "palestrearás": "palestrear",
    "palestrearão": "palestrear",
    "palestrearíamos": "palestrear",
    "palestrearíeis": "palestrear",
    "palestreasse": "palestrear",
    "palestreassem": "palestrear",
    "palestreasses": "palestrear",
    "palestreaste": "palestrear",
    "palestreastes": "palestrear",
    "palestreava": "palestrear",
    "palestreavam": "palestrear",
    "palestreavas": "palestrear",
    "palestreei": "palestrear",
    "palestreeis": "palestrear",
    "palestreemo": "palestrear",
    "palestreemos": "palestrear",
    "palestrei": "palestrar",
    "palestreia": "palestrear",
    "palestreiam": "palestrear",
    "palestreias": "palestrear",
    "palestreie": "palestrear",
    "palestreiem": "palestrear",
    "palestreies": "palestrear",
    "palestreio": "palestrear",
    "palestreira": "palestreiro",
    "palestreiras": "palestreiro",
    "palestreiros": "palestreiro",
    "palestreis": "palestrar",
    "palestrem": "palestrar",
    "palestremo": "palestrar",
    "palestremos": "palestrar",
    "palestreou": "palestrear",
    "palestres": "palestrar",
    "palestreámo": "palestrear",
    "palestreámos": "palestrear",
    "palestreáramo": "palestrear",
    "palestreáramos": "palestrear",
    "palestreáreis": "palestrear",
    "palestreásseis": "palestrear",
    "palestreássemos": "palestrear",
    "palestreávamo": "palestrear",
    "palestreávamos": "palestrear",
    "palestreáveis": "palestrear",
    "palestriniana": "palestriniano",
    "palestrinianas": "palestriniano",
    "palestrinianos": "palestriniano",
    "palestro": "palestrar",
    "palestrou": "palestrar",
    "palestrámo": "palestrar",
    "palestrámos": "palestrar",
    "palestráramo": "palestrar",
    "palestráramos": "palestrar",
    "palestráreis": "palestrar",
    "palestrásseis": "palestrar",
    "palestrássemos": "palestrar",
    "palestrávamo": "palestrar",
    "palestrávamos": "palestrar",
    "palestráveis": "palestrar",
    "palestésica": "palestésico",
    "palestésicas": "palestésico",
    "palestésicos": "palestésico",
    "paletas": "paleta",
    "paletós": "paletó",
    "paleácea": "paleáceo",
    "paleáceas": "paleáceo",
    "paleáceos": "paleáceo",
    "paleámo": "palear",
    "paleámos": "palear",
    "paleáramo": "palear",
    "paleáramos": "palear",
    "paleáreis": "palear",
    "paleárticas": "paleártica",
    "paleásseis": "palear",
    "paleássemos": "palear",
    "paleávamo": "palear",
    "paleávamos": "palear",
    "paleáveis": "palear",
    "paleógrafa": "paleógrafo",
    "paleógrafas": "paleógrafo",
    "paleógrafos": "paleógrafo",
    "paleóloga": "paleólogo",
    "paleólogas": "paleólogo",
    "paleólogos": "paleólogo",
    "paleótipos": "paleótipo",
    "palhaboteiros": "palhaboteiro",
    "palhabotes": "palhabote",
    "palhacinha": "palhaço",
    "palhacinhas": "palhaço",
    "palhacinho": "palhaço",
    "palhacinhos": "palhaço",
    "palhacita": "palhaço",
    "palhacitas": "palhaço",
    "palhacito": "palhaço",
    "palhacitos": "palhaço",
    "palhadas": "palhada",
    "palhais": "palhal",
    "palharesca": "palharesco",
    "palharescas": "palharesco",
    "palharescos": "palharesco",
    "palhas": "palha",
    "palhaça": "palhaço",
    "palhaçadas": "palhaçada",
    "palhaçais": "palhaçal",
    "palhaças": "palhaço",
    "palhaços": "palhaço",
    "palheiras": "palheira",
    "palheireira": "palheireiro",
    "palheireiras": "palheireiro",
    "palheireiros": "palheireiro",
    "palheiros": "palheiro",
    "palheirões": "palheirão",
    "palheta": "palheto",
    "palhetada": "palhetar",
    "palhetadas": "palhetar",
    "palhetado": "palhetar",
    "palhetados": "palhetar",
    "palhetai": "palhetar",
    "palhetais": "palhetar",
    "palhetam": "palhetar",
    "palhetamo": "palhetar",
    "palhetamos": "palhetar",
    "palhetando": "palhetar",
    "palhetara": "palhetar",
    "palhetaram": "palhetar",
    "palhetaras": "palhetar",
    "palhetardes": "palhetar",
    "palhetarei": "palhetar",
    "palhetareis": "palhetar",
    "palhetarem": "palhetar",
    "palhetaremos": "palhetar",
    "palhetares": "palhetar",
    "palhetaria": "palhetar",
    "palhetariam": "palhetar",
    "palhetarias": "palhetaria",
    "palhetarmo": "palhetar",
    "palhetarmos": "palhetar",
    "palhetará": "palhetar",
    "palhetarás": "palhetar",
    "palhetarão": "palhetar",
    "palhetaríamos": "palhetar",
    "palhetaríeis": "palhetar",
    "palhetas": "palheto",
    "palhetasse": "palhetar",
    "palhetassem": "palhetar",
    "palhetasses": "palhetar",
    "palhetaste": "palhetar",
    "palhetastes": "palhetar",
    "palhetava": "palhetar",
    "palhetavam": "palhetar",
    "palhetavas": "palhetar",
    "palhete": "palhetar",
    "palheteada": "palhetear",
    "palheteadas": "palhetear",
    "palheteado": "palhetear",
    "palheteados": "palhetear",
    "palheteai": "palhetear",
    "palheteais": "palhetear",
    "palheteamo": "palhetear",
    "palheteamos": "palhetear",
    "palheteando": "palhetear",
    "palheteara": "palhetear",
    "palhetearam": "palhetear",
    "palhetearas": "palhetear",
    "palheteardes": "palhetear",
    "palhetearei": "palhetear",
    "palheteareis": "palhetear",
    "palhetearem": "palhetear",
    "palhetearemos": "palhetear",
    "palheteares": "palhetear",
    "palhetearia": "palhetear",
    "palheteariam": "palhetear",
    "palhetearias": "palhetear",
    "palhetearmo": "palhetear",
    "palhetearmos": "palhetear",
    "palheteará": "palhetear",
    "palhetearás": "palhetear",
    "palhetearão": "palhetear",
    "palhetearíamos": "palhetear",
    "palhetearíeis": "palhetear",
    "palheteasse": "palhetear",
    "palheteassem": "palhetear",
    "palheteasses": "palhetear",
    "palheteaste": "palhetear",
    "palheteastes": "palhetear",
    "palheteava": "palhetear",
    "palheteavam": "palhetear",
    "palheteavas": "palhetear",
    "palheteei": "palhetear",
    "palheteeis": "palhetear",
    "palheteemo": "palhetear",
    "palheteemos": "palhetear",
    "palhetei": "palhetar",
    "palheteia": "palhetear",
    "palheteiam": "palhetear",
    "palheteias": "palhetear",
    "palheteie": "palhetear",
    "palheteiem": "palhetear",
    "palheteies": "palhetear",
    "palheteio": "palhetear",
    "palheteis": "palhetar",
    "palhetem": "palhetar",
    "palhetemo": "palhetar",
    "palhetemos": "palhetar",
    "palheteou": "palhetear",
    "palhetes": "palhete",
    "palheteámo": "palhetear",
    "palheteámos": "palhetear",
    "palheteáramo": "palhetear",
    "palheteáramos": "palhetear",
    "palheteáreis": "palhetear",
    "palheteásseis": "palhetear",
    "palheteássemos": "palhetear",
    "palheteávamo": "palhetear",
    "palheteávamos": "palhetear",
    "palheteáveis": "palhetear",
    "palheto": "palhetar",
    "palhetos": "palheto",
    "palhetou": "palhetar",
    "palhetámo": "palhetar",
    "palhetámos": "palhetar",
    "palhetáramo": "palhetar",
    "palhetáramos": "palhetar",
    "palhetáreis": "palhetar",
    "palhetásseis": "palhetar",
    "palhetássemos": "palhetar",
    "palhetávamo": "palhetar",
    "palhetávamos": "palhetar",
    "palhetáveis": "palhetar",
    "palhetões": "palhetão",
    "palhinha": "palha",
    "palhinhas": "palhinha",
    "palhita": "palha",
    "palhitas": "palha",
    "palhiça": "palhiço",
    "palhiças": "palhiço",
    "palhiços": "palhiço",
    "palhoceira": "palhoceiro",
    "palhoceiras": "palhoceiro",
    "palhoceiros": "palhoceiro",
    "palhotas": "palhota",
    "palhotes": "palhote",
    "palhoças": "palhoça",
    "palhuços": "palhuço",
    "palia": "paliar",
    "paliada": "paliar",
    "paliadas": "paliar",
    "paliado": "paliar",
    "paliados": "paliar",
    "paliai": "paliar",
    "paliais": "paliar",
    "paliam": "paliar",
    "paliamo": "paliar",
    "paliamos": "paliar",
    "paliando": "paliar",
    "paliara": "paliar",
    "paliaram": "paliar",
    "paliaras": "paliar",
    "paliarde": "paliar",
    "paliardes": "paliar",
    "paliare": "paliar",
    "paliarei": "paliar",
    "paliareis": "paliar",
    "paliarem": "paliar",
    "paliaremos": "paliar",
    "paliares": "paliar",
    "paliaria": "paliar",
    "paliariam": "paliar",
    "paliarias": "paliar",
    "paliarmo": "paliar",
    "paliarmos": "paliar",
    "paliará": "paliar",
    "paliarás": "paliar",
    "paliarão": "paliar",
    "paliaríamos": "paliar",
    "paliaríeis": "paliar",
    "palias": "paliar",
    "paliasse": "paliar",
    "paliassem": "paliar",
    "paliasses": "paliar",
    "paliaste": "paliar",
    "paliastes": "paliar",
    "paliativa": "paliativo",
    "paliativas": "paliativo",
    "paliativos": "paliativo",
    "paliava": "paliar",
    "paliavam": "paliar",
    "paliavas": "paliar",
    "paliações": "paliação",
    "palicinesias": "palicinesia",
    "palicinésica": "palicinésico",
    "palicinésicas": "palicinésico",
    "palicinésicos": "palicinésico",
    "palicários": "palicário",
    "palidazinha": "pálido",
    "palidazinhas": "pálido",
    "palidazita": "pálido",
    "palidazitas": "pálido",
    "palideja": "palidejar",
    "palidejada": "palidejar",
    "palidejadas": "palidejar",
    "palidejado": "palidejar",
    "palidejados": "palidejar",
    "palidejai": "palidejar",
    "palidejais": "palidejar",
    "palidejam": "palidejar",
    "palidejamo": "palidejar",
    "palidejamos": "palidejar",
    "palidejando": "palidejar",
    "palidejara": "palidejar",
    "palidejaram": "palidejar",
    "palidejaras": "palidejar",
    "palidejardes": "palidejar",
    "palidejarei": "palidejar",
    "palidejareis": "palidejar",
    "palidejarem": "palidejar",
    "palidejaremos": "palidejar",
    "palidejares": "palidejar",
    "palidejaria": "palidejar",
    "palidejariam": "palidejar",
    "palidejarias": "palidejar",
    "palidejarmo": "palidejar",
    "palidejarmos": "palidejar",
    "palidejará": "palidejar",
    "palidejarás": "palidejar",
    "palidejarão": "palidejar",
    "palidejaríamos": "palidejar",
    "palidejaríeis": "palidejar",
    "palidejas": "palidejar",
    "palidejasse": "palidejar",
    "palidejassem": "palidejar",
    "palidejasses": "palidejar",
    "palidejaste": "palidejar",
    "palidejastes": "palidejar",
    "palidejava": "palidejar",
    "palidejavam": "palidejar",
    "palidejavas": "palidejar",
    "palideje": "palidejar",
    "palidejei": "palidejar",
    "palidejeis": "palidejar",
    "palidejem": "palidejar",
    "palidejemo": "palidejar",
    "palidejemos": "palidejar",
    "palidejes": "palidejar",
    "palidejo": "palidejar",
    "palidejou": "palidejar",
    "palidejámo": "palidejar",
    "palidejámos": "palidejar",
    "palidejáramo": "palidejar",
    "palidejáramos": "palidejar",
    "palidejáreis": "palidejar",
    "palidejásseis": "palidejar",
    "palidejássemos": "palidejar",
    "palidejávamo": "palidejar",
    "palidejávamos": "palidejar",
    "palidejáveis": "palidejar",
    "palidezes": "palidez",
    "palidozinho": "pálido",
    "palidozinhos": "pálido",
    "palidozito": "pálido",
    "palidozitos": "pálido",
    "palidíssima": "pálido",
    "palidíssimas": "pálido",
    "palidíssimo": "pálido",
    "palidíssimos": "pálido",
    "palie": "paliar",
    "paliei": "paliar",
    "palieis": "paliar",
    "paliem": "paliar",
    "paliemo": "paliar",
    "paliemos": "paliar",
    "palies": "paliar",
    "palifemias": "palifemia",
    "palifica": "palificar",
    "palificada": "palificar",
    "palificadas": "palificar",
    "palificado": "palificar",
    "palificados": "palificar",
    "palificai": "palificar",
    "palificais": "palificar",
    "palificam": "palificar",
    "palificamo": "palificar",
    "palificamos": "palificar",
    "palificando": "palificar",
    "palificara": "palificar",
    "palificaram": "palificar",
    "palificaras": "palificar",
    "palificarde": "palificar",
    "palificardes": "palificar",
    "palificare": "palificar",
    "palificarei": "palificar",
    "palificareis": "palificar",
    "palificarem": "palificar",
    "palificaremos": "palificar",
    "palificares": "palificar",
    "palificaria": "palificar",
    "palificariam": "palificar",
    "palificarias": "palificar",
    "palificarmo": "palificar",
    "palificarmos": "palificar",
    "palificará": "palificar",
    "palificarás": "palificar",
    "palificarão": "palificar",
    "palificaríamos": "palificar",
    "palificaríeis": "palificar",
    "palificas": "palificar",
    "palificasse": "palificar",
    "palificassem": "palificar",
    "palificasses": "palificar",
    "palificaste": "palificar",
    "palificastes": "palificar",
    "palificava": "palificar",
    "palificavam": "palificar",
    "palificavas": "palificar",
    "palifico": "palificar",
    "palificou": "palificar",
    "palificá": "palificar",
    "palificámo": "palificar",
    "palificámos": "palificar",
    "palificáramo": "palificar",
    "palificáramos": "palificar",
    "palificárei": "palificar",
    "palificáreis": "palificar",
    "palificásseis": "palificar",
    "palificássemos": "palificar",
    "palificávamo": "palificar",
    "palificávamos": "palificar",
    "palificávei": "palificar",
    "palificáveis": "palificar",
    "palifique": "palificar",
    "palifiquei": "palificar",
    "palifiqueis": "palificar",
    "palifiquem": "palificar",
    "palifiquemo": "palificar",
    "palifiquemos": "palificar",
    "palifiques": "palificar",
    "palifémica": "palifémico",
    "palifémicas": "palifémico",
    "palifémicos": "palifémico",
    "paligorsquites": "paligorsquite",
    "paligrafias": "paligrafia",
    "paligráfica": "paligráfico",
    "paligráficas": "paligráfico",
    "paligráficos": "paligráfico",
    "palilhos": "palilho",
    "palilogias": "palilogia",
    "palilógica": "palilógico",
    "palilógicas": "palilógico",
    "palilógicos": "palilógico",
    "palimpsestos": "palimpsesto",
    "palimpséstica": "palimpséstico",
    "palimpsésticas": "palimpséstico",
    "palimpsésticos": "palimpséstico",
    "palindromias": "palindromia",
    "palinfrasias": "palinfrasia",
    "palinfrásica": "palinfrásico",
    "palinfrásicas": "palinfrásico",
    "palinfrásicos": "palinfrásico",
    "palingenesias": "palingenesia",
    "palingenésica": "palingenésico",
    "palingenésicas": "palingenésico",
    "palingenésicos": "palingenésico",
    "palingéneses": "palingénese",
    "palinodistas": "palinodista",
    "palinologias": "palinologia",
    "palinologistas": "palinologista",
    "palinológica": "palinológico",
    "palinológicas": "palinológico",
    "palinológicos": "palinológico",
    "palinuros": "palinuro",
    "palinurídea": "palinurídeo",
    "palinurídeas": "palinurídeo",
    "palinurídeos": "palinurídeo",
    "palinódias": "palinódia",
    "palinódica": "palinódico",
    "palinódicas": "palinódico",
    "palinódicos": "palinódico",
    "palinóloga": "palinólogo",
    "palinólogas": "palinólogo",
    "palinólogos": "palinólogo",
    "palinúridas": "palinúrida",
    "palio": "paliar",
    "paliopsias": "paliopsia",
    "paliou": "paliar",
    "palita": "palitar",
    "palitada": "palitar",
    "palitadas": "palitar",
    "palitado": "palitar",
    "palitados": "palitar",
    "palitai": "palitar",
    "palitais": "palitar",
    "palitam": "palitar",
    "palitamo": "palitar",
    "palitamos": "palitar",
    "palitando": "palitar",
    "palitara": "palitar",
    "palitaram": "palitar",
    "palitaras": "palitar",
    "palitarde": "palitar",
    "palitardes": "palitar",
    "palitare": "palitar",
    "palitarei": "palitar",
    "palitareis": "palitar",
    "palitarem": "palitar",
    "palitaremos": "palitar",
    "palitares": "palitar",
    "palitaria": "palitar",
    "palitariam": "palitar",
    "palitarias": "palitar",
    "palitarmo": "palitar",
    "palitarmos": "palitar",
    "palitará": "palitar",
    "palitarás": "palitar",
    "palitarão": "palitar",
    "palitaríamos": "palitar",
    "palitaríeis": "palitar",
    "palitas": "palitar",
    "palitasse": "palitar",
    "palitassem": "palitar",
    "palitasses": "palitar",
    "palitaste": "palitar",
    "palitastes": "palitar",
    "palitava": "palitar",
    "palitavam": "palitar",
    "palitavas": "palitar",
    "palite": "palitar",
    "palitei": "palitar",
    "paliteira": "paliteiro",
    "paliteiras": "paliteiro",
    "paliteiros": "paliteiro",
    "paliteis": "palitar",
    "palitem": "palitar",
    "palitemo": "palitar",
    "palitemos": "palitar",
    "palites": "palitar",
    "palitinho": "palito",
    "palitinhos": "palito",
    "palitito": "palito",
    "palititos": "palito",
    "palito": "palitar",
    "palitos": "palito",
    "palitou": "palitar",
    "palitá": "palitar",
    "palitámo": "palitar",
    "palitámos": "palitar",
    "palitáramo": "palitar",
    "palitáramos": "palitar",
    "palitárei": "palitar",
    "palitáreis": "palitar",
    "palitásseis": "palitar",
    "palitássemos": "palitar",
    "palitávamo": "palitar",
    "palitávamos": "palitar",
    "palitávei": "palitar",
    "palitáveis": "palitar",
    "paliá": "paliar",
    "paliámo": "paliar",
    "paliámos": "paliar",
    "paliáramo": "paliar",
    "paliáramos": "paliar",
    "paliárei": "paliar",
    "paliáreis": "paliar",
    "paliásseis": "paliar",
    "paliássemos": "paliar",
    "paliávamo": "paliar",
    "paliávamos": "paliar",
    "paliávei": "paliar",
    "paliáveis": "paliável",
    "paliçadas": "paliçada",
    "paliópsica": "paliópsico",
    "paliópsicas": "paliópsico",
    "paliópsicos": "paliópsico",
    "palma": "palmar",
    "palmada": "palmar",
    "palmadas": "palmar",
    "palmadinha": "palmada",
    "palmadinhas": "palmada",
    "palmadita": "palmada",
    "palmaditas": "palmada",
    "palmado": "palmar",
    "palmados": "palmar",
    "palmai": "palmar",
    "palmais": "palmar",
    "palmam": "palmar",
    "palmamo": "palmar",
    "palmamos": "palmar",
    "palmando": "palmar",
    "palmara": "palmar",
    "palmaram": "palmar",
    "palmaras": "palmar",
    "palmarde": "palmar",
    "palmardes": "palmar",
    "palmare": "palmar",
    "palmarei": "palmar",
    "palmareis": "palmar",
    "palmarem": "palmar",
    "palmaremos": "palmar",
    "palmares": "palmar",
    "palmaria": "palmar",
    "palmariam": "palmar",
    "palmarias": "palmar",
    "palmarmo": "palmar",
    "palmarmos": "palmar",
    "palmará": "palmar",
    "palmarás": "palmar",
    "palmarão": "palmar",
    "palmaríamos": "palmar",
    "palmaríeis": "palmar",
    "palmas": "palmar",
    "palmasse": "palmar",
    "palmassem": "palmar",
    "palmasses": "palmar",
    "palmaste": "palmar",
    "palmastes": "palmar",
    "palmatiflora": "palmatifloro",
    "palmatifloras": "palmatifloro",
    "palmatifloros": "palmatifloro",
    "palmatifoliada": "palmatifoliado",
    "palmatifoliadas": "palmatifoliado",
    "palmatifoliados": "palmatifoliado",
    "palmatilobada": "palmatilobado",
    "palmatilobadas": "palmatilobado",
    "palmatilobados": "palmatilobado",
    "palmatipartida": "palmatipartido",
    "palmatipartidas": "palmatipartido",
    "palmatipartidos": "palmatipartido",
    "palmatoa": "palmatoar",
    "palmatoada": "palmatoar",
    "palmatoadas": "palmatoar",
    "palmatoado": "palmatoar",
    "palmatoados": "palmatoar",
    "palmatoai": "palmatoar",
    "palmatoais": "palmatoar",
    "palmatoam": "palmatoar",
    "palmatoamo": "palmatoar",
    "palmatoamos": "palmatoar",
    "palmatoando": "palmatoar",
    "palmatoara": "palmatoar",
    "palmatoaram": "palmatoar",
    "palmatoaras": "palmatoar",
    "palmatoarde": "palmatoar",
    "palmatoardes": "palmatoar",
    "palmatoare": "palmatoar",
    "palmatoarei": "palmatoar",
    "palmatoareis": "palmatoar",
    "palmatoarem": "palmatoar",
    "palmatoaremos": "palmatoar",
    "palmatoares": "palmatoar",
    "palmatoaria": "palmatoar",
    "palmatoariam": "palmatoar",
    "palmatoarias": "palmatoar",
    "palmatoarmo": "palmatoar",
    "palmatoarmos": "palmatoar",
    "palmatoará": "palmatoar",
    "palmatoarás": "palmatoar",
    "palmatoarão": "palmatoar",
    "palmatoaríamos": "palmatoar",
    "palmatoaríeis": "palmatoar",
    "palmatoas": "palmatoar",
    "palmatoasse": "palmatoar",
    "palmatoassem": "palmatoar",
    "palmatoasses": "palmatoar",
    "palmatoaste": "palmatoar",
    "palmatoastes": "palmatoar",
    "palmatoava": "palmatoar",
    "palmatoavam": "palmatoar",
    "palmatoavas": "palmatoar",
    "palmatoe": "palmatoar",
    "palmatoei": "palmatoar",
    "palmatoeis": "palmatoar",
    "palmatoem": "palmatoar",
    "palmatoemo": "palmatoar",
    "palmatoemos": "palmatoar",
    "palmatoes": "palmatoar",
    "palmatoo": "palmatoar",
    "palmatoou": "palmatoar",
    "palmatoria": "palmatoriar",
    "palmatoriada": "palmatoriar",
    "palmatoriadas": "palmatoriar",
    "palmatoriado": "palmatoriar",
    "palmatoriados": "palmatoriar",
    "palmatoriai": "palmatoriar",
    "palmatoriais": "palmatoriar",
    "palmatoriam": "palmatoriar",
    "palmatoriamo": "palmatoriar",
    "palmatoriamos": "palmatoriar",
    "palmatoriando": "palmatoriar",
    "palmatoriara": "palmatoriar",
    "palmatoriaram": "palmatoriar",
    "palmatoriaras": "palmatoriar",
    "palmatoriarde": "palmatoriar",
    "palmatoriardes": "palmatoriar",
    "palmatoriare": "palmatoriar",
    "palmatoriarei": "palmatoriar",
    "palmatoriareis": "palmatoriar",
    "palmatoriarem": "palmatoriar",
    "palmatoriaremos": "palmatoriar",
    "palmatoriares": "palmatoriar",
    "palmatoriaria": "palmatoriar",
    "palmatoriariam": "palmatoriar",
    "palmatoriarias": "palmatoriar",
    "palmatoriarmo": "palmatoriar",
    "palmatoriarmos": "palmatoriar",
    "palmatoriará": "palmatoriar",
    "palmatoriarás": "palmatoriar",
    "palmatoriarão": "palmatoriar",
    "palmatoriaríamos": "palmatoriar",
    "palmatoriaríeis": "palmatoriar",
    "palmatorias": "palmatoriar",
    "palmatoriasse": "palmatoriar",
    "palmatoriassem": "palmatoriar",
    "palmatoriasses": "palmatoriar",
    "palmatoriaste": "palmatoriar",
    "palmatoriastes": "palmatoriar",
    "palmatoriava": "palmatoriar",
    "palmatoriavam": "palmatoriar",
    "palmatoriavas": "palmatoriar",
    "palmatorie": "palmatoriar",
    "palmatoriei": "palmatoriar",
    "palmatorieis": "palmatoriar",
    "palmatoriem": "palmatoriar",
    "palmatoriemo": "palmatoriar",
    "palmatoriemos": "palmatoriar",
    "palmatories": "palmatoriar",
    "palmatorio": "palmatoriar",
    "palmatoriou": "palmatoriar",
    "palmatoriá": "palmatoriar",
    "palmatoriámo": "palmatoriar",
    "palmatoriámos": "palmatoriar",
    "palmatoriáramo": "palmatoriar",
    "palmatoriáramos": "palmatoriar",
    "palmatoriárei": "palmatoriar",
    "palmatoriáreis": "palmatoriar",
    "palmatoriásseis": "palmatoriar",
    "palmatoriássemos": "palmatoriar",
    "palmatoriávamo": "palmatoriar",
    "palmatoriávamos": "palmatoriar",
    "palmatoriávei": "palmatoriar",
    "palmatoriáveis": "palmatoriar",
    "palmatoá": "palmatoar",
    "palmatoámo": "palmatoar",
    "palmatoámos": "palmatoar",
    "palmatoáramo": "palmatoar",
    "palmatoáramos": "palmatoar",
    "palmatoárei": "palmatoar",
    "palmatoáreis": "palmatoar",
    "palmatoásseis": "palmatoar",
    "palmatoássemos": "palmatoar",
    "palmatoávamo": "palmatoar",
    "palmatoávamos": "palmatoar",
    "palmatoávei": "palmatoar",
    "palmatoáveis": "palmatoar",
    "palmatífida": "palmatífido",
    "palmatífidas": "palmatífido",
    "palmatífidos": "palmatífido",
    "palmatórias": "palmatória",
    "palmava": "palmar",
    "palmavam": "palmar",
    "palmavas": "palmar",
    "palmaços": "palmaço",
    "palme": "palmar",
    "palmeada": "palmear",
    "palmeadas": "palmear",
    "palmeado": "palmear",
    "palmeadora": "palmeador",
    "palmeadoras": "palmeador",
    "palmeadores": "palmeador",
    "palmeados": "palmear",
    "palmeai": "palmear",
    "palmeais": "palmear",
    "palmeamo": "palmear",
    "palmeamos": "palmear",
    "palmeando": "palmear",
    "palmeara": "palmear",
    "palmearam": "palmear",
    "palmearas": "palmear",
    "palmearde": "palmear",
    "palmeardes": "palmear",
    "palmeare": "palmear",
    "palmearei": "palmear",
    "palmeareis": "palmear",
    "palmearem": "palmear",
    "palmearemos": "palmear",
    "palmeares": "palmear",
    "palmearia": "palmear",
    "palmeariam": "palmear",
    "palmearias": "palmear",
    "palmearmo": "palmear",
    "palmearmos": "palmear",
    "palmeará": "palmear",
    "palmearás": "palmear",
    "palmearão": "palmear",
    "palmearíamos": "palmear",
    "palmearíeis": "palmear",
    "palmeasse": "palmear",
    "palmeassem": "palmear",
    "palmeasses": "palmear",
    "palmeaste": "palmear",
    "palmeastes": "palmear",
    "palmeava": "palmear",
    "palmeavam": "palmear",
    "palmeavas": "palmear",
    "palmeei": "palmear",
    "palmeeis": "palmear",
    "palmeemo": "palmear",
    "palmeemos": "palmear",
    "palmei": "palmar",
    "palmeia": "palmear",
    "palmeiam": "palmear",
    "palmeias": "palmear",
    "palmeie": "palmear",
    "palmeiem": "palmear",
    "palmeies": "palmear",
    "palmeio": "palmear",
    "palmeira": "palmeiro",
    "palmeirais": "palmeiral",
    "palmeiras": "palmeiro",
    "palmeireirenses": "palmeireirense",
    "palmeirinha": "palmeira",
    "palmeirinhas": "palmeira",
    "palmeirita": "palmeira",
    "palmeiritas": "palmeira",
    "palmeiros": "palmeiro",
    "palmeis": "palmar",
    "palmeja": "palmejar",
    "palmejada": "palmejar",
    "palmejadas": "palmejar",
    "palmejado": "palmejar",
    "palmejados": "palmejar",
    "palmejai": "palmejar",
    "palmejais": "palmejar",
    "palmejam": "palmejar",
    "palmejamo": "palmejar",
    "palmejamos": "palmejar",
    "palmejando": "palmejar",
    "palmejara": "palmejar",
    "palmejaram": "palmejar",
    "palmejaras": "palmejar",
    "palmejarde": "palmejar",
    "palmejardes": "palmejar",
    "palmejare": "palmejar",
    "palmejarei": "palmejar",
    "palmejareis": "palmejar",
    "palmejarem": "palmejar",
    "palmejaremos": "palmejar",
    "palmejares": "palmejar",
    "palmejaria": "palmejar",
    "palmejariam": "palmejar",
    "palmejarias": "palmejar",
    "palmejarmo": "palmejar",
    "palmejarmos": "palmejar",
    "palmejará": "palmejar",
    "palmejarás": "palmejar",
    "palmejarão": "palmejar",
    "palmejaríamos": "palmejar",
    "palmejaríeis": "palmejar",
    "palmejas": "palmejar",
    "palmejasse": "palmejar",
    "palmejassem": "palmejar",
    "palmejasses": "palmejar",
    "palmejaste": "palmejar",
    "palmejastes": "palmejar",
    "palmejava": "palmejar",
    "palmejavam": "palmejar",
    "palmejavas": "palmejar",
    "palmeje": "palmejar",
    "palmejei": "palmejar",
    "palmejeis": "palmejar",
    "palmejem": "palmejar",
    "palmejemo": "palmejar",
    "palmejemos": "palmejar",
    "palmejes": "palmejar",
    "palmejo": "palmejar",
    "palmejou": "palmejar",
    "palmejá": "palmejar",
    "palmejámo": "palmejar",
    "palmejámos": "palmejar",
    "palmejáramo": "palmejar",
    "palmejáramos": "palmejar",
    "palmejárei": "palmejar",
    "palmejáreis": "palmejar",
    "palmejásseis": "palmejar",
    "palmejássemos": "palmejar",
    "palmejávamo": "palmejar",
    "palmejávamos": "palmejar",
    "palmejávei": "palmejar",
    "palmejáveis": "palmejar",
    "palmelenses": "palmelense",
    "palmem": "palmar",
    "palmemo": "palmar",
    "palmemos": "palmar",
    "palmeou": "palmear",
    "palmes": "palmar",
    "palmetas": "palmeta",
    "palmeteada": "palmetear",
    "palmeteadas": "palmetear",
    "palmeteado": "palmetear",
    "palmeteados": "palmetear",
    "palmeteai": "palmetear",
    "palmeteais": "palmetear",
    "palmeteamo": "palmetear",
    "palmeteamos": "palmetear",
    "palmeteando": "palmetear",
    "palmeteara": "palmetear",
    "palmetearam": "palmetear",
    "palmetearas": "palmetear",
    "palmetearde": "palmetear",
    "palmeteardes": "palmetear",
    "palmeteare": "palmetear",
    "palmetearei": "palmetear",
    "palmeteareis": "palmetear",
    "palmetearem": "palmetear",
    "palmetearemos": "palmetear",
    "palmeteares": "palmetear",
    "palmetearia": "palmetear",
    "palmeteariam": "palmetear",
    "palmetearias": "palmetear",
    "palmetearmo": "palmetear",
    "palmetearmos": "palmetear",
    "palmeteará": "palmetear",
    "palmetearás": "palmetear",
    "palmetearão": "palmetear",
    "palmetearíamos": "palmetear",
    "palmetearíeis": "palmetear",
    "palmeteasse": "palmetear",
    "palmeteassem": "palmetear",
    "palmeteasses": "palmetear",
    "palmeteaste": "palmetear",
    "palmeteastes": "palmetear",
    "palmeteava": "palmetear",
    "palmeteavam": "palmetear",
    "palmeteavas": "palmetear",
    "palmeteei": "palmetear",
    "palmeteeis": "palmetear",
    "palmeteemo": "palmetear",
    "palmeteemos": "palmetear",
    "palmeteia": "palmetear",
    "palmeteiam": "palmetear",
    "palmeteias": "palmetear",
    "palmeteie": "palmetear",
    "palmeteiem": "palmetear",
    "palmeteies": "palmetear",
    "palmeteio": "palmetear",
    "palmeteou": "palmetear",
    "palmeteá": "palmetear",
    "palmeteámo": "palmetear",
    "palmeteámos": "palmetear",
    "palmeteáramo": "palmetear",
    "palmeteáramos": "palmetear",
    "palmeteárei": "palmetear",
    "palmeteáreis": "palmetear",
    "palmeteásseis": "palmetear",
    "palmeteássemos": "palmetear",
    "palmeteávamo": "palmetear",
    "palmeteávamos": "palmetear",
    "palmeteávei": "palmetear",
    "palmeteáveis": "palmetear",
    "palmeá": "palmear",
    "palmeámo": "palmear",
    "palmeámos": "palmear",
    "palmeáramo": "palmear",
    "palmeáramos": "palmear",
    "palmeárei": "palmear",
    "palmeáreis": "palmear",
    "palmeásseis": "palmear",
    "palmeássemos": "palmear",
    "palmeávamo": "palmear",
    "palmeávamos": "palmear",
    "palmeávei": "palmear",
    "palmeáveis": "palmear",
    "palmiformes": "palmiforme",
    "palmilha": "palmilhar",
    "palmilhada": "palmilhar",
    "palmilhadas": "palmilhar",
    "palmilhadeira": "palmilhadeiro",
    "palmilhadeiras": "palmilhadeiro",
    "palmilhadeiros": "palmilhadeiro",
    "palmilhado": "palmilhar",
    "palmilhados": "palmilhar",
    "palmilhai": "palmilhar",
    "palmilhais": "palmilhar",
    "palmilham": "palmilhar",
    "palmilhamo": "palmilhar",
    "palmilhamos": "palmilhar",
    "palmilhando": "palmilhar",
    "palmilhara": "palmilhar",
    "palmilharam": "palmilhar",
    "palmilharas": "palmilhar",
    "palmilharde": "palmilhar",
    "palmilhardes": "palmilhar",
    "palmilhare": "palmilhar",
    "palmilharei": "palmilhar",
    "palmilhareis": "palmilhar",
    "palmilharem": "palmilhar",
    "palmilharemos": "palmilhar",
    "palmilhares": "palmilhar",
    "palmilharia": "palmilhar",
    "palmilhariam": "palmilhar",
    "palmilharias": "palmilhar",
    "palmilharmo": "palmilhar",
    "palmilharmos": "palmilhar",
    "palmilhará": "palmilhar",
    "palmilharás": "palmilhar",
    "palmilharão": "palmilhar",
    "palmilharíamos": "palmilhar",
    "palmilharíeis": "palmilhar",
    "palmilhas": "palmilhar",
    "palmilhasse": "palmilhar",
    "palmilhassem": "palmilhar",
    "palmilhasses": "palmilhar",
    "palmilhaste": "palmilhar",
    "palmilhastes": "palmilhar",
    "palmilhava": "palmilhar",
    "palmilhavam": "palmilhar",
    "palmilhavas": "palmilhar",
    "palmilhe": "palmilhar",
    "palmilhei": "palmilhar",
    "palmilheis": "palmilhar",
    "palmilhem": "palmilhar",
    "palmilhemo": "palmilhar",
    "palmilhemos": "palmilhar",
    "palmilhes": "palmilhar",
    "palmilho": "palmilhar",
    "palmilhou": "palmilhar",
    "palmilhá": "palmilhar",
    "palmilhámo": "palmilhar",
    "palmilhámos": "palmilhar",
    "palmilháramo": "palmilhar",
    "palmilháramos": "palmilhar",
    "palmilhárei": "palmilhar",
    "palmilháreis": "palmilhar",
    "palmilhásseis": "palmilhar",
    "palmilhássemos": "palmilhar",
    "palmilhávamo": "palmilhar",
    "palmilhávamos": "palmilhar",
    "palmilhávei": "palmilhar",
    "palmilháveis": "palmilhar",
    "palminhas": "palminha",
    "palminho": "palmo",
    "palminhos": "palmo",
    "palminérvea": "palminérveo",
    "palminérveas": "palminérveo",
    "palminérveos": "palminérveo",
    "palmistes": "palmiste",
    "palmitais": "palmital",
    "palmitatos": "palmitato",
    "palmitinas": "palmitina",
    "palmito": "palmo",
    "palmitos": "palmo",
    "palmo": "palmar",
    "palmoiras": "palmoira",
    "palmos": "palmo",
    "palmou": "palmar",
    "palmouras": "palmoura",
    "palmuras": "palmura",
    "palmá": "palmar",
    "palmácea": "palmáceo",
    "palmáceas": "palmáceo",
    "palmáceos": "palmáceo",
    "palmámo": "palmar",
    "palmámos": "palmar",
    "palmáramo": "palmar",
    "palmáramos": "palmar",
    "palmárei": "palmar",
    "palmáreis": "palmar",
    "palmásseis": "palmar",
    "palmássemos": "palmar",
    "palmávamo": "palmar",
    "palmávamos": "palmar",
    "palmávei": "palmar",
    "palmáveis": "palmável",
    "palmífera": "palmífero",
    "palmíferas": "palmífero",
    "palmíferos": "palmífero",
    "palmípedes": "palmípede",
    "palmítica": "palmítico",
    "palmíticas": "palmítico",
    "palmíticos": "palmítico",
    "paloma": "palomar",
    "palomada": "palomar",
    "palomadas": "palomar",
    "palomado": "palomar",
    "palomados": "palomar",
    "palomai": "palomar",
    "palomais": "palomar",
    "palomam": "palomar",
    "palomamo": "palomar",
    "palomamos": "palomar",
    "palomando": "palomar",
    "palomara": "palomar",
    "palomaram": "palomar",
    "palomaras": "palomar",
    "palomarde": "palomar",
    "palomardes": "palomar",
    "palomare": "palomar",
    "palomarei": "palomar",
    "palomareis": "palomar",
    "palomarem": "palomar",
    "palomaremos": "palomar",
    "palomares": "palomar",
    "palomaria": "palomar",
    "palomariam": "palomar",
    "palomarias": "palomar",
    "palomarmo": "palomar",
    "palomarmos": "palomar",
    "palomará": "palomar",
    "palomarás": "palomar",
    "palomarão": "palomar",
    "palomaríamos": "palomar",
    "palomaríeis": "palomar",
    "palomas": "palomar",
    "palomasse": "palomar",
    "palomassem": "palomar",
    "palomasses": "palomar",
    "palomaste": "palomar",
    "palomastes": "palomar",
    "palomava": "palomar",
    "palomavam": "palomar",
    "palomavas": "palomar",
    "palomba": "palombar",
    "palombada": "palombar",
    "palombadas": "palombar",
    "palombado": "palombar",
    "palombados": "palombar",
    "palombai": "palombar",
    "palombais": "palombar",
    "palombam": "palombar",
    "palombamo": "palombar",
    "palombamos": "palombar",
    "palombando": "palombar",
    "palombara": "palombar",
    "palombaram": "palombar",
    "palombaras": "palombar",
    "palombarde": "palombar",
    "palombardes": "palombar",
    "palombare": "palombar",
    "palombarei": "palombar",
    "palombareis": "palombar",
    "palombarem": "palombar",
    "palombaremos": "palombar",
    "palombares": "palombar",
    "palombaria": "palombar",
    "palombariam": "palombar",
    "palombarias": "palombar",
    "palombarmo": "palombar",
    "palombarmos": "palombar",
    "palombará": "palombar",
    "palombarás": "palombar",
    "palombarão": "palombar",
    "palombaríamos": "palombar",
    "palombaríeis": "palombar",
    "palombas": "palombar",
    "palombasse": "palombar",
    "palombassem": "palombar",
    "palombasses": "palombar",
    "palombaste": "palombar",
    "palombastes": "palombar",
    "palombava": "palombar",
    "palombavam": "palombar",
    "palombavas": "palombar",
    "palombe": "palombar",
    "palombei": "palombar",
    "palombeis": "palombar",
    "palombem": "palombar",
    "palombemo": "palombar",
    "palombemos": "palombar",
    "palombes": "palombar",
    "palombinos": "palombino",
    "palombo": "palombar",
    "palombou": "palombar",
    "palombá": "palombar",
    "palombámo": "palombar",
    "palombámos": "palombar",
    "palombáramo": "palombar",
    "palombáramos": "palombar",
    "palombárei": "palombar",
    "palombáreis": "palombar",
    "palombásseis": "palombar",
    "palombássemos": "palombar",
    "palombávamo": "palombar",
    "palombávamos": "palombar",
    "palombávei": "palombar",
    "palombáveis": "palombar",
    "palome": "palomar",
    "palomei": "palomar",
    "palomeis": "palomar",
    "palomem": "palomar",
    "palomemo": "palomar",
    "palomemos": "palomar",
    "palomes": "palomar",
    "palomo": "palomar",
    "palomou": "palomar",
    "palomá": "palomar",
    "palomámo": "palomar",
    "palomámos": "palomar",
    "palomáramo": "palomar",
    "palomáramos": "palomar",
    "palomárei": "palomar",
    "palomáreis": "palomar",
    "palomásseis": "palomar",
    "palomássemos": "palomar",
    "palomávamo": "palomar",
    "palomávamos": "palomar",
    "palomávei": "palomar",
    "palomáveis": "palomar",
    "palonça": "palonço",
    "palonças": "palonço",
    "palonços": "palonço",
    "paloreja": "palorejar",
    "palorejada": "palorejar",
    "palorejadas": "palorejar",
    "palorejado": "palorejar",
    "palorejados": "palorejar",
    "palorejai": "palorejar",
    "palorejais": "palorejar",
    "palorejam": "palorejar",
    "palorejamo": "palorejar",
    "palorejamos": "palorejar",
    "palorejando": "palorejar",
    "palorejara": "palorejar",
    "palorejaram": "palorejar",
    "palorejaras": "palorejar",
    "palorejardes": "palorejar",
    "palorejarei": "palorejar",
    "palorejareis": "palorejar",
    "palorejarem": "palorejar",
    "palorejaremos": "palorejar",
    "palorejares": "palorejar",
    "palorejaria": "palorejar",
    "palorejariam": "palorejar",
    "palorejarias": "palorejar",
    "palorejarmo": "palorejar",
    "palorejarmos": "palorejar",
    "palorejará": "palorejar",
    "palorejarás": "palorejar",
    "palorejarão": "palorejar",
    "palorejaríamos": "palorejar",
    "palorejaríeis": "palorejar",
    "palorejas": "palorejar",
    "palorejasse": "palorejar",
    "palorejassem": "palorejar",
    "palorejasses": "palorejar",
    "palorejaste": "palorejar",
    "palorejastes": "palorejar",
    "palorejava": "palorejar",
    "palorejavam": "palorejar",
    "palorejavas": "palorejar",
    "paloreje": "palorejar",
    "palorejei": "palorejar",
    "palorejeis": "palorejar",
    "palorejem": "palorejar",
    "palorejemo": "palorejar",
    "palorejemos": "palorejar",
    "palorejes": "palorejar",
    "palorejo": "palorejar",
    "palorejou": "palorejar",
    "palorejámo": "palorejar",
    "palorejámos": "palorejar",
    "palorejáramo": "palorejar",
    "palorejáramos": "palorejar",
    "palorejáreis": "palorejar",
    "palorejásseis": "palorejar",
    "palorejássemos": "palorejar",
    "palorejávamo": "palorejar",
    "palorejávamos": "palorejar",
    "palorejáveis": "palorejar",
    "palores": "palor",
    "palouça": "palouço",
    "palouças": "palouço",
    "palouços": "palouço",
    "palpa": "palpar",
    "palpabilidades": "palpabilidade",
    "palpabiliza": "palpabilizar",
    "palpabilizada": "palpabilizar",
    "palpabilizadas": "palpabilizar",
    "palpabilizado": "palpabilizar",
    "palpabilizados": "palpabilizar",
    "palpabilizai": "palpabilizar",
    "palpabilizais": "palpabilizar",
    "palpabilizam": "palpabilizar",
    "palpabilizamo": "palpabilizar",
    "palpabilizamos": "palpabilizar",
    "palpabilizando": "palpabilizar",
    "palpabilizara": "palpabilizar",
    "palpabilizaram": "palpabilizar",
    "palpabilizaras": "palpabilizar",
    "palpabilizarde": "palpabilizar",
    "palpabilizardes": "palpabilizar",
    "palpabilizare": "palpabilizar",
    "palpabilizarei": "palpabilizar",
    "palpabilizareis": "palpabilizar",
    "palpabilizarem": "palpabilizar",
    "palpabilizaremos": "palpabilizar",
    "palpabilizares": "palpabilizar",
    "palpabilizaria": "palpabilizar",
    "palpabilizariam": "palpabilizar",
    "palpabilizarias": "palpabilizar",
    "palpabilizarmo": "palpabilizar",
    "palpabilizarmos": "palpabilizar",
    "palpabilizará": "palpabilizar",
    "palpabilizarás": "palpabilizar",
    "palpabilizarão": "palpabilizar",
    "palpabilizaríamos": "palpabilizar",
    "palpabilizaríeis": "palpabilizar",
    "palpabilizas": "palpabilizar",
    "palpabilizasse": "palpabilizar",
    "palpabilizassem": "palpabilizar",
    "palpabilizasses": "palpabilizar",
    "palpabilizaste": "palpabilizar",
    "palpabilizastes": "palpabilizar",
    "palpabilizava": "palpabilizar",
    "palpabilizavam": "palpabilizar",
    "palpabilizavas": "palpabilizar",
    "palpabilize": "palpabilizar",
    "palpabilizei": "palpabilizar",
    "palpabilizeis": "palpabilizar",
    "palpabilizem": "palpabilizar",
    "palpabilizemo": "palpabilizar",
    "palpabilizemos": "palpabilizar",
    "palpabilizes": "palpabilizar",
    "palpabilizo": "palpabilizar",
    "palpabilizou": "palpabilizar",
    "palpabilizá": "palpabilizar",
    "palpabilizámo": "palpabilizar",
    "palpabilizámos": "palpabilizar",
    "palpabilizáramo": "palpabilizar",
    "palpabilizáramos": "palpabilizar",
    "palpabilizárei": "palpabilizar",
    "palpabilizáreis": "palpabilizar",
    "palpabilizásseis": "palpabilizar",
    "palpabilizássemos": "palpabilizar",
    "palpabilizávamo": "palpabilizar",
    "palpabilizávamos": "palpabilizar",
    "palpabilizávei": "palpabilizar",
    "palpabilizáveis": "palpabilizar",
    "palpada": "palpar",
    "palpadas": "palpar",
    "palpadelas": "palpadela",
    "palpado": "palpar",
    "palpados": "palpar",
    "palpai": "palpar",
    "palpais": "palpar",
    "palpam": "palpar",
    "palpamo": "palpar",
    "palpamos": "palpar",
    "palpando": "palpar",
    "palpara": "palpar",
    "palparam": "palpar",
    "palparas": "palpar",
    "palparde": "palpar",
    "palpardes": "palpar",
    "palpare": "palpar",
    "palparei": "palpar",
    "palpareis": "palpar",
    "palparem": "palpar",
    "palparemos": "palpar",
    "palpares": "palpar",
    "palparia": "palpar",
    "palpariam": "palpar",
    "palparias": "palpar",
    "palparmo": "palpar",
    "palparmos": "palpar",
    "palpará": "palpar",
    "palparás": "palpar",
    "palparão": "palpar",
    "palparíamos": "palpar",
    "palparíeis": "palpar",
    "palpas": "palpar",
    "palpasse": "palpar",
    "palpassem": "palpar",
    "palpasses": "palpar",
    "palpaste": "palpar",
    "palpastes": "palpar",
    "palpava": "palpar",
    "palpavam": "palpar",
    "palpavas": "palpar",
    "palpações": "palpação",
    "palpe": "palpar",
    "palpebrada": "palpebrado",
    "palpebradas": "palpebrado",
    "palpebrados": "palpebrado",
    "palpebrais": "palpebral",
    "palpebrações": "palpebração",
    "palpebrites": "palpebrite",
    "palpei": "palpar",
    "palpeis": "palpar",
    "palpem": "palpar",
    "palpemo": "palpar",
    "palpemos": "palpar",
    "palpes": "palpar",
    "palpita": "palpitar",
    "palpitada": "palpitar",
    "palpitadas": "palpitar",
    "palpitado": "palpitar",
    "palpitados": "palpitar",
    "palpitai": "palpitar",
    "palpitais": "palpitar",
    "palpitam": "palpitar",
    "palpitamo": "palpitar",
    "palpitamos": "palpitar",
    "palpitando": "palpitar",
    "palpitantes": "palpitante",
    "palpitara": "palpitar",
    "palpitaram": "palpitar",
    "palpitaras": "palpitar",
    "palpitardes": "palpitar",
    "palpitarei": "palpitar",
    "palpitareis": "palpitar",
    "palpitarem": "palpitar",
    "palpitaremos": "palpitar",
    "palpitares": "palpitar",
    "palpitaria": "palpitar",
    "palpitariam": "palpitar",
    "palpitarias": "palpitar",
    "palpitarmo": "palpitar",
    "palpitarmos": "palpitar",
    "palpitará": "palpitar",
    "palpitarás": "palpitar",
    "palpitarão": "palpitar",
    "palpitaríamos": "palpitar",
    "palpitaríeis": "palpitar",
    "palpitas": "palpitar",
    "palpitasse": "palpitar",
    "palpitassem": "palpitar",
    "palpitasses": "palpitar",
    "palpitaste": "palpitar",
    "palpitastes": "palpitar",
    "palpitava": "palpitar",
    "palpitavam": "palpitar",
    "palpitavas": "palpitar",
    "palpitações": "palpitação",
    "palpite": "palpitar",
    "palpitei": "palpitar",
    "palpiteis": "palpitar",
    "palpitem": "palpitar",
    "palpitemo": "palpitar",
    "palpitemos": "palpitar",
    "palpites": "palpite",
    "palpito": "palpitar",
    "palpitou": "palpitar",
    "palpitámo": "palpitar",
    "palpitámos": "palpitar",
    "palpitáramo": "palpitar",
    "palpitáramos": "palpitar",
    "palpitáreis": "palpitar",
    "palpitásseis": "palpitar",
    "palpitássemos": "palpitar",
    "palpitávamo": "palpitar",
    "palpitávamos": "palpitar",
    "palpitáveis": "palpitar",
    "palpo": "palpar",
    "palpos": "palpo",
    "palpou": "palpar",
    "palpá": "palpar",
    "palpámo": "palpar",
    "palpámos": "palpar",
    "palpáramo": "palpar",
    "palpáramos": "palpar",
    "palpárei": "palpar",
    "palpáreis": "palpar",
    "palpásseis": "palpar",
    "palpássemos": "palpar",
    "palpávamo": "palpar",
    "palpávamos": "palpar",
    "palpávei": "palpar",
    "palpáveis": "palpável",
    "palra": "palrar",
    "palrada": "palrar",
    "palradas": "palrar",
    "palradeira": "palradeiro",
    "palradeiras": "palradeiro",
    "palradeiros": "palradeiro",
    "palrado": "palrar",
    "palradora": "palrador",
    "palradoras": "palrador",
    "palradores": "palrador",
    "palrados": "palrar",
    "palrai": "palrar",
    "palrais": "palrar",
    "palram": "palrar",
    "palramo": "palrar",
    "palramos": "palrar",
    "palrando": "palrar",
    "palrara": "palrar",
    "palraram": "palrar",
    "palraras": "palrar",
    "palrarde": "palrar",
    "palrardes": "palrar",
    "palrare": "palrar",
    "palrarei": "palrar",
    "palrareis": "palrar",
    "palrarem": "palrar",
    "palraremos": "palrar",
    "palrares": "palrar",
    "palraria": "palrar",
    "palrariam": "palrar",
    "palrarias": "palraria",
    "palrarmo": "palrar",
    "palrarmos": "palrar",
    "palrará": "palrar",
    "palrarás": "palrar",
    "palrarão": "palrar",
    "palraríamos": "palrar",
    "palraríeis": "palrar",
    "palras": "palrar",
    "palrasse": "palrar",
    "palrassem": "palrar",
    "palrasses": "palrar",
    "palraste": "palrar",
    "palrastes": "palrar",
    "palratórios": "palratório",
    "palrava": "palrar",
    "palravam": "palrar",
    "palravas": "palrar",
    "palrações": "palração",
    "palre": "palrar",
    "palrei": "palrar",
    "palreira": "palreiro",
    "palreiras": "palreiro",
    "palreiros": "palreiro",
    "palreis": "palrar",
    "palrem": "palrar",
    "palremo": "palrar",
    "palremos": "palrar",
    "palres": "palrar",
    "palrices": "palrice",
    "palro": "palrar",
    "palrona": "palrão",
    "palronas": "palrão",
    "palrou": "palrar",
    "palrá": "palrar",
    "palrámo": "palrar",
    "palrámos": "palrar",
    "palráramo": "palrar",
    "palráramos": "palrar",
    "palrárei": "palrar",
    "palráreis": "palrar",
    "palrásseis": "palrar",
    "palrássemos": "palrar",
    "palrávamo": "palrar",
    "palrávamos": "palrar",
    "palrávei": "palrar",
    "palráveis": "palrar",
    "palrões": "palrão",
    "paludes": "palude",
    "paludiais": "paludial",
    "paludismos": "paludismo",
    "paludosa": "paludoso",
    "paludosas": "paludoso",
    "paludosos": "paludoso",
    "palurdices": "palurdice",
    "palustres": "palustre",
    "palácios": "palácio",
    "paládios": "paládio",
    "palémones": "palémon",
    "palígrafa": "palígrafo",
    "palígrafas": "palígrafo",
    "palígrafos": "palígrafo",
    "palóia": "palóio",
    "palóias": "palóio",
    "palóios": "palóio",
    "palós": "paló",
    "palões": "palão",
    "palúdica": "palúdico",
    "palúdicas": "palúdico",
    "palúdicos": "palúdico",
    "palúrdia": "palúrdio",
    "palúrdias": "palúrdio",
    "palúrdios": "palúrdio",
    "pamonhas": "pamonha",
    "pamonhices": "pamonhice",
    "pampa": "pampo",
    "pampanosa": "pampanoso",
    "pampanosas": "pampanoso",
    "pampanosos": "pampanoso",
    "pampas": "pampo",
    "pampeiros": "pampeiro",
    "pampilhos": "pampilho",
    "pampinosa": "pampinoso",
    "pampinosas": "pampinoso",
    "pampinosos": "pampinoso",
    "pamplinas": "pamplina",
    "pampolinhas": "pampolinha",
    "pampos": "pampo",
    "pampsiquismos": "pampsiquismo",
    "pampsiquistas": "pampsiquista",
    "pampínea": "pampíneo",
    "pampíneas": "pampíneo",
    "pampíneos": "pampíneo",
    "pana": "panar",
    "panaceias": "panaceia",
    "panachés": "panaché",
    "panada": "panar",
    "panadas": "panar",
    "panadinha": "panado",
    "panadinhas": "panado",
    "panadinho": "panado",
    "panadinhos": "panado",
    "panadita": "panado",
    "panaditas": "panado",
    "panadito": "panado",
    "panaditos": "panado",
    "panado": "panar",
    "panados": "panar",
    "panai": "panar",
    "panais": "panar",
    "panalis": "panall",
    "panam": "panar",
    "panamenhos": "panamenho",
    "panamenses": "panamense",
    "panamiana": "panamiano",
    "panamianas": "panamiano",
    "panamianos": "panamiano",
    "panamistas": "panamista",
    "panamo": "panar",
    "panamos": "panar",
    "panamás": "panamá",
    "panando": "panar",
    "panara": "panar",
    "panaram": "panar",
    "panaras": "panar",
    "panarde": "panar",
    "panardes": "panar",
    "panare": "panar",
    "panarei": "panar",
    "panareis": "panar",
    "panarem": "panar",
    "panaremos": "panar",
    "panares": "panar",
    "panaria": "panar",
    "panariam": "panar",
    "panarias": "panar",
    "panarizes": "panariz",
    "panarmo": "panar",
    "panarmos": "panar",
    "panará": "panar",
    "panarás": "panar",
    "panarão": "panar",
    "panaríamos": "panar",
    "panarícios": "panarício",
    "panaríeis": "panar",
    "panas": "panar",
    "panascais": "panascal",
    "panascas": "panasca",
    "panascos": "panasco",
    "panasqueiras": "panasqueira",
    "panasqueiros": "panasqueiro",
    "panasse": "panar",
    "panassem": "panar",
    "panasses": "panar",
    "panaste": "panar",
    "panastes": "panar",
    "panava": "panar",
    "panavam": "panar",
    "panavas": "panar",
    "panaças": "panaça",
    "pancadarias": "pancadaria",
    "pancadas": "pancada",
    "pancadinha": "pancada",
    "pancadinhas": "pancada",
    "pancadita": "pancada",
    "pancaditas": "pancada",
    "pancadões": "pancadão",
    "pancalismos": "pancalismo",
    "pancalistas": "pancalista",
    "pancas": "panca",
    "pancinha": "pança",
    "pancinhas": "pança",
    "pancita": "pança",
    "pancitas": "pança",
    "panclastites": "panclastite",
    "pancona": "pancão",
    "panconas": "pancão",
    "pancreatalgias": "pancreatalgia",
    "pancreatinas": "pancreatina",
    "pancreatites": "pancreatite",
    "pancreatálgica": "pancreatálgico",
    "pancreatálgicas": "pancreatálgico",
    "pancreatálgicos": "pancreatálgico",
    "pancreatítica": "pancreatítico",
    "pancreatíticas": "pancreatítico",
    "pancreatíticos": "pancreatítico",
    "pancreática": "pancreático",
    "pancreáticas": "pancreático",
    "pancreáticos": "pancreático",
    "pancromática": "pancromático",
    "pancromáticas": "pancromático",
    "pancromáticos": "pancromático",
    "pancrácia": "pancrácio",
    "pancrácias": "pancrácio",
    "pancrácios": "pancrácio",
    "pancões": "pancão",
    "panda": "pando",
    "pandangas": "pandanga",
    "pandas": "pando",
    "pandectas": "pandecta",
    "pandega": "pandegar",
    "pandegada": "pandegar",
    "pandegadas": "pandegar",
    "pandegado": "pandegar",
    "pandegados": "pandegar",
    "pandegai": "pandegar",
    "pandegais": "pandegar",
    "pandegam": "pandegar",
    "pandegamo": "pandegar",
    "pandegamos": "pandegar",
    "pandegando": "pandegar",
    "pandegara": "pandegar",
    "pandegaram": "pandegar",
    "pandegaras": "pandegar",
    "pandegardes": "pandegar",
    "pandegarei": "pandegar",
    "pandegareis": "pandegar",
    "pandegarem": "pandegar",
    "pandegaremos": "pandegar",
    "pandegares": "pandegar",
    "pandegaria": "pandegar",
    "pandegariam": "pandegar",
    "pandegarias": "pandegar",
    "pandegarmo": "pandegar",
    "pandegarmos": "pandegar",
    "pandegará": "pandegar",
    "pandegarás": "pandegar",
    "pandegarão": "pandegar",
    "pandegaríamos": "pandegar",
    "pandegaríeis": "pandegar",
    "pandegas": "pandegar",
    "pandegasse": "pandegar",
    "pandegassem": "pandegar",
    "pandegasses": "pandegar",
    "pandegaste": "pandegar",
    "pandegastes": "pandegar",
    "pandegava": "pandegar",
    "pandegavam": "pandegar",
    "pandegavas": "pandegar",
    "pandego": "pandegar",
    "pandegou": "pandegar",
    "pandegue": "pandegar",
    "pandeguei": "pandegar",
    "pandegueira": "pandegueiro",
    "pandegueiras": "pandegueiro",
    "pandegueiros": "pandegueiro",
    "pandegueis": "pandegar",
    "pandeguem": "pandegar",
    "pandeguemo": "pandegar",
    "pandeguemos": "pandegar",
    "pandegues": "pandegar",
    "pandegámo": "pandegar",
    "pandegámos": "pandegar",
    "pandegáramo": "pandegar",
    "pandegáramos": "pandegar",
    "pandegáreis": "pandegar",
    "pandegásseis": "pandegar",
    "pandegássemos": "pandegar",
    "pandegávamo": "pandegar",
    "pandegávamos": "pandegar",
    "pandegáveis": "pandegar",
    "pandeireira": "pandeireiro",
    "pandeireiras": "pandeireiro",
    "pandeireiros": "pandeireiro",
    "pandeiretas": "pandeireta",
    "pandeiros": "pandeiro",
    "pandemias": "pandemia",
    "pandemónios": "pandemónio",
    "pandiculações": "pandiculação",
    "pandilha": "pandilhar",
    "pandilhada": "pandilhar",
    "pandilhadas": "pandilhar",
    "pandilhado": "pandilhar",
    "pandilhados": "pandilhar",
    "pandilhai": "pandilhar",
    "pandilhais": "pandilhar",
    "pandilham": "pandilhar",
    "pandilhamo": "pandilhar",
    "pandilhamos": "pandilhar",
    "pandilhando": "pandilhar",
    "pandilhara": "pandilhar",
    "pandilharam": "pandilhar",
    "pandilharas": "pandilhar",
    "pandilhardes": "pandilhar",
    "pandilharei": "pandilhar",
    "pandilhareis": "pandilhar",
    "pandilharem": "pandilhar",
    "pandilharemos": "pandilhar",
    "pandilhares": "pandilhar",
    "pandilharia": "pandilhar",
    "pandilhariam": "pandilhar",
    "pandilharias": "pandilhar",
    "pandilharmo": "pandilhar",
    "pandilharmos": "pandilhar",
    "pandilhará": "pandilhar",
    "pandilharás": "pandilhar",
    "pandilharão": "pandilhar",
    "pandilharíamos": "pandilhar",
    "pandilharíeis": "pandilhar",
    "pandilhas": "pandilhar",
    "pandilhasse": "pandilhar",
    "pandilhassem": "pandilhar",
    "pandilhasses": "pandilhar",
    "pandilhaste": "pandilhar",
    "pandilhastes": "pandilhar",
    "pandilhava": "pandilhar",
    "pandilhavam": "pandilhar",
    "pandilhavas": "pandilhar",
    "pandilhe": "pandilhar",
    "pandilhei": "pandilhar",
    "pandilheira": "pandilheiro",
    "pandilheiras": "pandilheiro",
    "pandilheiros": "pandilheiro",
    "pandilheis": "pandilhar",
    "pandilhem": "pandilhar",
    "pandilhemo": "pandilhar",
    "pandilhemos": "pandilhar",
    "pandilhes": "pandilhar",
    "pandilho": "pandilhar",
    "pandilhou": "pandilhar",
    "pandilhámo": "pandilhar",
    "pandilhámos": "pandilhar",
    "pandilháramo": "pandilhar",
    "pandilháramos": "pandilhar",
    "pandilháreis": "pandilhar",
    "pandilhásseis": "pandilhar",
    "pandilhássemos": "pandilhar",
    "pandilhávamo": "pandilhar",
    "pandilhávamos": "pandilhar",
    "pandilháveis": "pandilhar",
    "pandoras": "pandora",
    "pandorcas": "pandorca",
    "pandorgas": "pandorga",
    "pandos": "pando",
    "panduras": "pandura",
    "pandáceas": "pandácea",
    "pandémica": "pandémico",
    "pandémicas": "pandémico",
    "pandémicos": "pandémico",
    "pane": "panar",
    "panegirica": "panegiricar",
    "panegiricada": "panegiricar",
    "panegiricadas": "panegiricar",
    "panegiricado": "panegiricar",
    "panegiricados": "panegiricar",
    "panegiricai": "panegiricar",
    "panegiricais": "panegiricar",
    "panegiricam": "panegiricar",
    "panegiricamo": "panegiricar",
    "panegiricamos": "panegiricar",
    "panegiricando": "panegiricar",
    "panegiricara": "panegiricar",
    "panegiricaram": "panegiricar",
    "panegiricaras": "panegiricar",
    "panegiricarde": "panegiricar",
    "panegiricardes": "panegiricar",
    "panegiricare": "panegiricar",
    "panegiricarei": "panegiricar",
    "panegiricareis": "panegiricar",
    "panegiricarem": "panegiricar",
    "panegiricaremos": "panegiricar",
    "panegiricares": "panegiricar",
    "panegiricaria": "panegiricar",
    "panegiricariam": "panegiricar",
    "panegiricarias": "panegiricar",
    "panegiricarmo": "panegiricar",
    "panegiricarmos": "panegiricar",
    "panegiricará": "panegiricar",
    "panegiricarás": "panegiricar",
    "panegiricarão": "panegiricar",
    "panegiricaríamos": "panegiricar",
    "panegiricaríeis": "panegiricar",
    "panegiricas": "panegiricar",
    "panegiricasse": "panegiricar",
    "panegiricassem": "panegiricar",
    "panegiricasses": "panegiricar",
    "panegiricaste": "panegiricar",
    "panegiricastes": "panegiricar",
    "panegiricava": "panegiricar",
    "panegiricavam": "panegiricar",
    "panegiricavas": "panegiricar",
    "panegirico": "panegiricar",
    "panegiricou": "panegiricar",
    "panegiricá": "panegiricar",
    "panegiricámo": "panegiricar",
    "panegiricámos": "panegiricar",
    "panegiricáramo": "panegiricar",
    "panegiricáramos": "panegiricar",
    "panegiricárei": "panegiricar",
    "panegiricáreis": "panegiricar",
    "panegiricásseis": "panegiricar",
    "panegiricássemos": "panegiricar",
    "panegiricávamo": "panegiricar",
    "panegiricávamos": "panegiricar",
    "panegiricávei": "panegiricar",
    "panegiricáveis": "panegiricar",
    "panegirique": "panegiricar",
    "panegiriquei": "panegiricar",
    "panegiriqueis": "panegiricar",
    "panegiriquem": "panegiricar",
    "panegiriquemo": "panegiricar",
    "panegiriquemos": "panegiricar",
    "panegiriques": "panegiricar",
    "panegiristas": "panegirista",
    "panegírica": "panegírico",
    "panegíricas": "panegírico",
    "panegíricos": "panegírico",
    "panei": "panar",
    "paneira": "paneiro",
    "paneiras": "paneiro",
    "paneiros": "paneiro",
    "paneis": "panar",
    "paneja": "panejar",
    "panejada": "panejar",
    "panejadas": "panejar",
    "panejado": "panejar",
    "panejados": "panejar",
    "panejai": "panejar",
    "panejais": "panejar",
    "panejam": "panejar",
    "panejamentos": "panejamento",
    "panejamo": "panejar",
    "panejamos": "panejar",
    "panejando": "panejar",
    "panejara": "panejar",
    "panejaram": "panejar",
    "panejaras": "panejar",
    "panejarde": "panejar",
    "panejardes": "panejar",
    "panejare": "panejar",
    "panejarei": "panejar",
    "panejareis": "panejar",
    "panejarem": "panejar",
    "panejaremos": "panejar",
    "panejares": "panejar",
    "panejaria": "panejar",
    "panejariam": "panejar",
    "panejarias": "panejar",
    "panejarmo": "panejar",
    "panejarmos": "panejar",
    "panejará": "panejar",
    "panejarás": "panejar",
    "panejarão": "panejar",
    "panejaríamos": "panejar",
    "panejaríeis": "panejar",
    "panejas": "panejar",
    "panejasse": "panejar",
    "panejassem": "panejar",
    "panejasses": "panejar",
    "panejaste": "panejar",
    "panejastes": "panejar",
    "panejava": "panejar",
    "panejavam": "panejar",
    "panejavas": "panejar",
    "paneje": "panejar",
    "panejei": "panejar",
    "panejeis": "panejar",
    "panejem": "panejar",
    "panejemo": "panejar",
    "panejemos": "panejar",
    "panejes": "panejar",
    "panejo": "panejar",
    "panejou": "panejar",
    "panejá": "panejar",
    "panejámo": "panejar",
    "panejámos": "panejar",
    "panejáramo": "panejar",
    "panejáramos": "panejar",
    "panejárei": "panejar",
    "panejáreis": "panejar",
    "panejásseis": "panejar",
    "panejássemos": "panejar",
    "panejávamo": "panejar",
    "panejávamos": "panejar",
    "panejávei": "panejar",
    "panejáveis": "panejar",
    "paneladas": "panelada",
    "panelas": "panela",
    "paneleira": "paneleiro",
    "paneleiras": "paneleiro",
    "paneleiros": "paneleiro",
    "panelinha": "panela",
    "panelinhas": "panela",
    "panelita": "panela",
    "panelitas": "panela",
    "panelos": "panelo",
    "panem": "panar",
    "panemas": "panema",
    "panemo": "panar",
    "panemos": "panar",
    "panes": "pane",
    "panfleteira": "panfleteiro",
    "panfleteiras": "panfleteiro",
    "panfleteiros": "panfleteiro",
    "panfletistas": "panfletista",
    "panfletos": "panfleto",
    "panfletária": "panfletário",
    "panfletárias": "panfletário",
    "panfletários": "panfletário",
    "pangaia": "pangaiar",
    "pangaiada": "pangaiar",
    "pangaiadas": "pangaiar",
    "pangaiado": "pangaiar",
    "pangaiados": "pangaiar",
    "pangaiai": "pangaiar",
    "pangaiais": "pangaiar",
    "pangaiam": "pangaiar",
    "pangaiamo": "pangaiar",
    "pangaiamos": "pangaiar",
    "pangaiando": "pangaiar",
    "pangaiara": "pangaiar",
    "pangaiaram": "pangaiar",
    "pangaiaras": "pangaiar",
    "pangaiardes": "pangaiar",
    "pangaiarei": "pangaiar",
    "pangaiareis": "pangaiar",
    "pangaiarem": "pangaiar",
    "pangaiaremos": "pangaiar",
    "pangaiares": "pangaiar",
    "pangaiaria": "pangaiar",
    "pangaiariam": "pangaiar",
    "pangaiarias": "pangaiar",
    "pangaiarmo": "pangaiar",
    "pangaiarmos": "pangaiar",
    "pangaiará": "pangaiar",
    "pangaiarás": "pangaiar",
    "pangaiarão": "pangaiar",
    "pangaiaríamos": "pangaiar",
    "pangaiaríeis": "pangaiar",
    "pangaias": "pangaiar",
    "pangaiasse": "pangaiar",
    "pangaiassem": "pangaiar",
    "pangaiasses": "pangaiar",
    "pangaiaste": "pangaiar",
    "pangaiastes": "pangaiar",
    "pangaiava": "pangaiar",
    "pangaiavam": "pangaiar",
    "pangaiavas": "pangaiar",
    "pangaie": "pangaiar",
    "pangaiei": "pangaiar",
    "pangaieis": "pangaiar",
    "pangaiem": "pangaiar",
    "pangaiemo": "pangaiar",
    "pangaiemos": "pangaiar",
    "pangaies": "pangaiar",
    "pangaio": "pangaiar",
    "pangaios": "pangaio",
    "pangaiou": "pangaiar",
    "pangaiámo": "pangaiar",
    "pangaiámos": "pangaiar",
    "pangaiáramo": "pangaiar",
    "pangaiáramos": "pangaiar",
    "pangaiáreis": "pangaiar",
    "pangaiásseis": "pangaiar",
    "pangaiássemos": "pangaiar",
    "pangaiávamo": "pangaiar",
    "pangaiávamos": "pangaiar",
    "pangaiáveis": "pangaiar",
    "pangermanismos": "pangermanismo",
    "pangermanistas": "pangermanista",
    "pangermânica": "pangermânico",
    "pangermânicas": "pangermânico",
    "pangermânicos": "pangermânico",
    "pangos": "pango",
    "paniculares": "panicular",
    "panifica": "panificar",
    "panificada": "panificar",
    "panificadas": "panificar",
    "panificado": "panificar",
    "panificadora": "panificador",
    "panificadoras": "panificador",
    "panificadores": "panificador",
    "panificados": "panificar",
    "panificai": "panificar",
    "panificais": "panificar",
    "panificam": "panificar",
    "panificamo": "panificar",
    "panificamos": "panificar",
    "panificando": "panificar",
    "panificara": "panificar",
    "panificaram": "panificar",
    "panificaras": "panificar",
    "panificarde": "panificar",
    "panificardes": "panificar",
    "panificare": "panificar",
    "panificarei": "panificar",
    "panificareis": "panificar",
    "panificarem": "panificar",
    "panificaremos": "panificar",
    "panificares": "panificar",
    "panificaria": "panificar",
    "panificariam": "panificar",
    "panificarias": "panificar",
    "panificarmo": "panificar",
    "panificarmos": "panificar",
    "panificará": "panificar",
    "panificarás": "panificar",
    "panificarão": "panificar",
    "panificaríamos": "panificar",
    "panificaríeis": "panificar",
    "panificas": "panificar",
    "panificasse": "panificar",
    "panificassem": "panificar",
    "panificasses": "panificar",
    "panificaste": "panificar",
    "panificastes": "panificar",
    "panificava": "panificar",
    "panificavam": "panificar",
    "panificavas": "panificar",
    "panificações": "panificação",
    "panifico": "panificar",
    "panificou": "panificar",
    "panificá": "panificar",
    "panificámo": "panificar",
    "panificámos": "panificar",
    "panificáramo": "panificar",
    "panificáramos": "panificar",
    "panificárei": "panificar",
    "panificáreis": "panificar",
    "panificásseis": "panificar",
    "panificássemos": "panificar",
    "panificávamo": "panificar",
    "panificávamos": "panificar",
    "panificávei": "panificar",
    "panificáveis": "panificável",
    "panifique": "panificar",
    "panifiquei": "panificar",
    "panifiqueis": "panificar",
    "panifiquem": "panificar",
    "panifiquemo": "panificar",
    "panifiquemos": "panificar",
    "panifiques": "panificar",
    "paninho": "pano",
    "paninhos": "pano",
    "panito": "pano",
    "panitos": "pano",
    "panjas": "panja",
    "panlecítica": "panlecítico",
    "panlecíticas": "panlecítico",
    "panlecíticos": "panlecítico",
    "panlogismos": "panlogismo",
    "panlogistas": "panlogista",
    "panlogística": "panlogístico",
    "panlogísticas": "panlogístico",
    "panlogísticos": "panlogístico",
    "panmixias": "panmixia",
    "panmíxica": "panmíxico",
    "panmíxicas": "panmíxico",
    "panmíxicos": "panmíxico",
    "pano": "panar",
    "panona": "panão",
    "panonas": "panão",
    "panoramas": "panorama",
    "panoramistas": "panoramista",
    "panorâmica": "panorâmico",
    "panorâmicas": "panorâmico",
    "panorâmicos": "panorâmico",
    "panos": "pano",
    "panou": "panar",
    "panquecas": "panqueca",
    "panria": "panriar",
    "panriada": "panriar",
    "panriadas": "panriar",
    "panriado": "panriar",
    "panriados": "panriar",
    "panriai": "panriar",
    "panriais": "panriar",
    "panriam": "panriar",
    "panriamo": "panriar",
    "panriamos": "panriar",
    "panriando": "panriar",
    "panriara": "panriar",
    "panriaram": "panriar",
    "panriaras": "panriar",
    "panriardes": "panriar",
    "panriarei": "panriar",
    "panriareis": "panriar",
    "panriarem": "panriar",
    "panriaremos": "panriar",
    "panriares": "panriar",
    "panriaria": "panriar",
    "panriariam": "panriar",
    "panriarias": "panriar",
    "panriarmo": "panriar",
    "panriarmos": "panriar",
    "panriará": "panriar",
    "panriarás": "panriar",
    "panriarão": "panriar",
    "panriaríamos": "panriar",
    "panriaríeis": "panriar",
    "panrias": "panriar",
    "panriasse": "panriar",
    "panriassem": "panriar",
    "panriasses": "panriar",
    "panriaste": "panriar",
    "panriastes": "panriar",
    "panriava": "panriar",
    "panriavam": "panriar",
    "panriavas": "panriar",
    "panrie": "panriar",
    "panriei": "panriar",
    "panrieis": "panriar",
    "panriem": "panriar",
    "panriemo": "panriar",
    "panriemos": "panriar",
    "panries": "panriar",
    "panrio": "panriar",
    "panriou": "panriar",
    "panriámo": "panriar",
    "panriámos": "panriar",
    "panriáramo": "panriar",
    "panriáramos": "panriar",
    "panriáreis": "panriar",
    "panriásseis": "panriar",
    "panriássemos": "panriar",
    "panriávamo": "panriar",
    "panriávamos": "panriar",
    "panriáveis": "panriar",
    "pansofias": "pansofia",
    "pansofistas": "pansofista",
    "pansófica": "pansófico",
    "pansóficas": "pansófico",
    "pansóficos": "pansófico",
    "pantafaçuda": "pantafaçudo",
    "pantafaçudas": "pantafaçudo",
    "pantafaçudos": "pantafaçudo",
    "pantagruelismos": "pantagruelismo",
    "pantagruelistas": "pantagruelista",
    "pantagruélica": "pantagruélico",
    "pantagruélicas": "pantagruélico",
    "pantagruélicos": "pantagruélico",
    "pantalhas": "pantalha",
    "pantalões": "pantalão",
    "pantanais": "pantanal",
    "pantanas": "pantana",
    "pantaniza": "pantanizar",
    "pantanizada": "pantanizar",
    "pantanizadas": "pantanizar",
    "pantanizado": "pantanizar",
    "pantanizados": "pantanizar",
    "pantanizai": "pantanizar",
    "pantanizais": "pantanizar",
    "pantanizam": "pantanizar",
    "pantanizamo": "pantanizar",
    "pantanizamos": "pantanizar",
    "pantanizando": "pantanizar",
    "pantanizara": "pantanizar",
    "pantanizaram": "pantanizar",
    "pantanizaras": "pantanizar",
    "pantanizarde": "pantanizar",
    "pantanizardes": "pantanizar",
    "pantanizare": "pantanizar",
    "pantanizarei": "pantanizar",
    "pantanizareis": "pantanizar",
    "pantanizarem": "pantanizar",
    "pantanizaremos": "pantanizar",
    "pantanizares": "pantanizar",
    "pantanizaria": "pantanizar",
    "pantanizariam": "pantanizar",
    "pantanizarias": "pantanizar",
    "pantanizarmo": "pantanizar",
    "pantanizarmos": "pantanizar",
    "pantanizará": "pantanizar",
    "pantanizarás": "pantanizar",
    "pantanizarão": "pantanizar",
    "pantanizaríamos": "pantanizar",
    "pantanizaríeis": "pantanizar",
    "pantanizas": "pantanizar",
    "pantanizasse": "pantanizar",
    "pantanizassem": "pantanizar",
    "pantanizasses": "pantanizar",
    "pantanizaste": "pantanizar",
    "pantanizastes": "pantanizar",
    "pantanizava": "pantanizar",
    "pantanizavam": "pantanizar",
    "pantanizavas": "pantanizar",
    "pantanize": "pantanizar",
    "pantanizei": "pantanizar",
    "pantanizeis": "pantanizar",
    "pantanizem": "pantanizar",
    "pantanizemo": "pantanizar",
    "pantanizemos": "pantanizar",
    "pantanizes": "pantanizar",
    "pantanizo": "pantanizar",
    "pantanizou": "pantanizar",
    "pantanizá": "pantanizar",
    "pantanizámo": "pantanizar",
    "pantanizámos": "pantanizar",
    "pantanizáramo": "pantanizar",
    "pantanizáramos": "pantanizar",
    "pantanizárei": "pantanizar",
    "pantanizáreis": "pantanizar",
    "pantanizásseis": "pantanizar",
    "pantanizássemos": "pantanizar",
    "pantanizávamo": "pantanizar",
    "pantanizávamos": "pantanizar",
    "pantanizávei": "pantanizar",
    "pantanizáveis": "pantanizar",
    "pantanosa": "pantanoso",
    "pantanosas": "pantanoso",
    "pantanosos": "pantanoso",
    "panteada": "pantear",
    "panteadas": "pantear",
    "panteado": "pantear",
    "panteados": "pantear",
    "panteai": "pantear",
    "panteais": "pantear",
    "panteamo": "pantear",
    "panteamos": "pantear",
    "panteando": "pantear",
    "panteara": "pantear",
    "pantearam": "pantear",
    "pantearas": "pantear",
    "panteardes": "pantear",
    "pantearei": "pantear",
    "panteareis": "pantear",
    "pantearem": "pantear",
    "pantearemos": "pantear",
    "panteares": "pantear",
    "pantearia": "pantear",
    "panteariam": "pantear",
    "pantearias": "pantear",
    "pantearmo": "pantear",
    "pantearmos": "pantear",
    "panteará": "pantear",
    "pantearás": "pantear",
    "pantearão": "pantear",
    "pantearíamos": "pantear",
    "pantearíeis": "pantear",
    "panteasse": "pantear",
    "panteassem": "pantear",
    "panteasses": "pantear",
    "panteaste": "pantear",
    "panteastes": "pantear",
    "panteava": "pantear",
    "panteavam": "pantear",
    "panteavas": "pantear",
    "panteei": "pantear",
    "panteeis": "pantear",
    "panteemo": "pantear",
    "panteemos": "pantear",
    "panteia": "pantear",
    "panteiam": "pantear",
    "panteias": "pantear",
    "panteie": "pantear",
    "panteiem": "pantear",
    "panteies": "pantear",
    "panteio": "pantear",
    "pantenogenésica": "pantenogenésico",
    "pantenogenésicas": "pantenogenésico",
    "pantenogenésicos": "pantenogenésico",
    "pantenogenética": "pantenogenético",
    "pantenogenéticas": "pantenogenético",
    "pantenogenéticos": "pantenogenético",
    "pantenogénica": "pantenogénico",
    "pantenogénicas": "pantenogénico",
    "pantenogénicos": "pantenogénico",
    "pantenomântica": "pantenomântico",
    "pantenomânticas": "pantenomântico",
    "pantenomânticos": "pantenomântico",
    "panteologias": "panteologia",
    "panteologistas": "panteologista",
    "panteológica": "panteológico",
    "panteológicas": "panteológico",
    "panteológicos": "panteológico",
    "panteomímica": "panteomímico",
    "panteomímicas": "panteomímico",
    "panteomímicos": "panteomímico",
    "panteonímias": "panteonímia",
    "panteou": "pantear",
    "panteras": "pantera",
    "panteámo": "pantear",
    "panteámos": "pantear",
    "panteáramo": "pantear",
    "panteáramos": "pantear",
    "panteáreis": "pantear",
    "panteásseis": "pantear",
    "panteássemos": "pantear",
    "panteávamo": "pantear",
    "panteávamos": "pantear",
    "panteáveis": "pantear",
    "panteísmos": "panteísmo",
    "panteístas": "panteísta",
    "panteóloga": "panteólogo",
    "panteólogas": "panteólogo",
    "panteólogos": "panteólogo",
    "panteónimos": "panteónimo",
    "panteões": "panteão",
    "pantgráfica": "pantgráfico",
    "pantgráficas": "pantgráfico",
    "pantgráficos": "pantgráfico",
    "pantofobias": "pantofobia",
    "pantofóbica": "pantofóbico",
    "pantofóbicas": "pantofóbico",
    "pantofóbicos": "pantofóbico",
    "pantografias": "pantografia",
    "pantomima": "pantomimo",
    "pantomimada": "pantomimar",
    "pantomimadas": "pantomimar",
    "pantomimado": "pantomimar",
    "pantomimados": "pantomimar",
    "pantomimai": "pantomimar",
    "pantomimais": "pantomimar",
    "pantomimam": "pantomimar",
    "pantomimamo": "pantomimar",
    "pantomimamos": "pantomimar",
    "pantomimando": "pantomimar",
    "pantomimara": "pantomimar",
    "pantomimaram": "pantomimar",
    "pantomimaras": "pantomimar",
    "pantomimardes": "pantomimar",
    "pantomimarei": "pantomimar",
    "pantomimareis": "pantomimar",
    "pantomimarem": "pantomimar",
    "pantomimaremos": "pantomimar",
    "pantomimares": "pantomimar",
    "pantomimaria": "pantomimar",
    "pantomimariam": "pantomimar",
    "pantomimarias": "pantomimar",
    "pantomimarmo": "pantomimar",
    "pantomimarmos": "pantomimar",
    "pantomimará": "pantomimar",
    "pantomimarás": "pantomimar",
    "pantomimarão": "pantomimar",
    "pantomimaríamos": "pantomimar",
    "pantomimaríeis": "pantomimar",
    "pantomimas": "pantomimo",
    "pantomimasse": "pantomimar",
    "pantomimassem": "pantomimar",
    "pantomimasses": "pantomimar",
    "pantomimaste": "pantomimar",
    "pantomimastes": "pantomimar",
    "pantomimava": "pantomimar",
    "pantomimavam": "pantomimar",
    "pantomimavas": "pantomimar",
    "pantomime": "pantomimar",
    "pantomimei": "pantomimar",
    "pantomimeis": "pantomimar",
    "pantomimem": "pantomimar",
    "pantomimemo": "pantomimar",
    "pantomimemos": "pantomimar",
    "pantomimes": "pantomimar",
    "pantomimo": "pantomimar",
    "pantomimos": "pantomimo",
    "pantomimou": "pantomimar",
    "pantomimámo": "pantomimar",
    "pantomimámos": "pantomimar",
    "pantomimáramo": "pantomimar",
    "pantomimáramos": "pantomimar",
    "pantomimáreis": "pantomimar",
    "pantomimásseis": "pantomimar",
    "pantomimássemos": "pantomimar",
    "pantomimávamo": "pantomimar",
    "pantomimávamos": "pantomimar",
    "pantomimáveis": "pantomimável",
    "pantomina": "pantominar",
    "pantominada": "pantominar",
    "pantominadas": "pantominar",
    "pantominado": "pantominar",
    "pantominados": "pantominar",
    "pantominai": "pantominar",
    "pantominais": "pantominar",
    "pantominam": "pantominar",
    "pantominamo": "pantominar",
    "pantominamos": "pantominar",
    "pantominando": "pantominar",
    "pantominara": "pantominar",
    "pantominaram": "pantominar",
    "pantominaras": "pantominar",
    "pantominardes": "pantominar",
    "pantominarei": "pantominar",
    "pantominareis": "pantominar",
    "pantominarem": "pantominar",
    "pantominaremos": "pantominar",
    "pantominares": "pantominar",
    "pantominaria": "pantominar",
    "pantominariam": "pantominar",
    "pantominarias": "pantominar",
    "pantominarmo": "pantominar",
    "pantominarmos": "pantominar",
    "pantominará": "pantominar",
    "pantominarás": "pantominar",
    "pantominarão": "pantominar",
    "pantominaríamos": "pantominar",
    "pantominaríeis": "pantominar",
    "pantominas": "pantominar",
    "pantominasse": "pantominar",
    "pantominassem": "pantominar",
    "pantominasses": "pantominar",
    "pantominaste": "pantominar",
    "pantominastes": "pantominar",
    "pantominava": "pantominar",
    "pantominavam": "pantominar",
    "pantominavas": "pantominar",
    "pantomine": "pantominar",
    "pantominei": "pantominar",
    "pantomineira": "pantomineiro",
    "pantomineiras": "pantomineiro",
    "pantomineiros": "pantomineiro",
    "pantomineis": "pantominar",
    "pantominem": "pantominar",
    "pantominemo": "pantominar",
    "pantominemos": "pantominar",
    "pantomines": "pantominar",
    "pantominices": "pantominice",
    "pantomino": "pantominar",
    "pantominou": "pantominar",
    "pantominámo": "pantominar",
    "pantominámos": "pantominar",
    "pantomináramo": "pantominar",
    "pantomináramos": "pantominar",
    "pantomináreis": "pantominar",
    "pantominásseis": "pantominar",
    "pantominássemos": "pantominar",
    "pantominávamo": "pantominar",
    "pantominávamos": "pantominar",
    "pantomináveis": "pantominar",
    "pantomomeira": "pantomomeiro",
    "pantomomeiras": "pantomomeiro",
    "pantomomeiros": "pantomomeiro",
    "pantométrica": "pantométrico",
    "pantométricas": "pantométrico",
    "pantométricos": "pantométrico",
    "pantomímica": "pantomímico",
    "pantomímicas": "pantomímico",
    "pantomímicos": "pantomímico",
    "pantorrilhas": "pantorrilha",
    "pantufas": "pantufa",
    "pantufinha": "pantufa",
    "pantufinhas": "pantufa",
    "pantufita": "pantufa",
    "pantufitas": "pantufa",
    "pantufos": "pantufo",
    "panturras": "panturra",
    "pantófoba": "pantófobo",
    "pantófobas": "pantófobo",
    "pantófobos": "pantófobo",
    "pantógrafos": "pantógrafo",
    "pantómetros": "pantómetro",
    "panzootias": "panzootia",
    "panzoótica": "panzoótico",
    "panzoóticas": "panzoótico",
    "panzoóticos": "panzoótico",
    "paná": "panar",
    "panámo": "panar",
    "panámos": "panar",
    "panáramo": "panar",
    "panáramos": "panar",
    "panárei": "panar",
    "panáreis": "panar",
    "panásseis": "panar",
    "panássemos": "panar",
    "panávamo": "panar",
    "panávamos": "panar",
    "panávei": "panar",
    "panáveis": "panável",
    "panázios": "panázio",
    "pançadas": "pançada",
    "panças": "pança",
    "pançuda": "pançudo",
    "pançudas": "pançudo",
    "pançudos": "pançudo",
    "panículas": "panícula",
    "panículos": "panículo",
    "panífera": "panífero",
    "paníferas": "panífero",
    "paníferos": "panífero",
    "panóplias": "panóplia",
    "panões": "panão",
    "papa": "papar",
    "papada": "papar",
    "papadas": "papar",
    "papado": "papar",
    "papados": "papar",
    "papaeiras": "papaeira",
    "papagaiais": "papagaial",
    "papagaios": "papagaio",
    "papagueada": "papaguear",
    "papagueadas": "papaguear",
    "papagueado": "papaguear",
    "papagueados": "papaguear",
    "papagueai": "papaguear",
    "papagueais": "papaguear",
    "papagueamentos": "papagueamento",
    "papagueamo": "papaguear",
    "papagueamos": "papaguear",
    "papagueando": "papaguear",
    "papagueara": "papaguear",
    "papaguearam": "papaguear",
    "papaguearas": "papaguear",
    "papaguearde": "papaguear",
    "papagueardes": "papaguear",
    "papagueare": "papaguear",
    "papaguearei": "papaguear",
    "papagueareis": "papaguear",
    "papaguearem": "papaguear",
    "papaguearemos": "papaguear",
    "papagueares": "papaguear",
    "papaguearia": "papaguear",
    "papagueariam": "papaguear",
    "papaguearias": "papaguear",
    "papaguearmo": "papaguear",
    "papaguearmos": "papaguear",
    "papagueará": "papaguear",
    "papaguearás": "papaguear",
    "papaguearão": "papaguear",
    "papaguearíamos": "papaguear",
    "papaguearíeis": "papaguear",
    "papagueasse": "papaguear",
    "papagueassem": "papaguear",
    "papagueasses": "papaguear",
    "papagueaste": "papaguear",
    "papagueastes": "papaguear",
    "papagueava": "papaguear",
    "papagueavam": "papaguear",
    "papagueavas": "papaguear",
    "papagueei": "papaguear",
    "papagueeis": "papaguear",
    "papagueemo": "papaguear",
    "papagueemos": "papaguear",
    "papagueia": "papaguear",
    "papagueiam": "papaguear",
    "papagueias": "papaguear",
    "papagueie": "papaguear",
    "papagueiem": "papaguear",
    "papagueies": "papaguear",
    "papagueio": "papaguear",
    "papagueios": "papagueio",
    "papagueou": "papaguear",
    "papagueá": "papaguear",
    "papagueámo": "papaguear",
    "papagueámos": "papaguear",
    "papagueáramo": "papaguear",
    "papagueáramos": "papaguear",
    "papagueárei": "papaguear",
    "papagueáreis": "papaguear",
    "papagueásseis": "papaguear",
    "papagueássemos": "papaguear",
    "papagueávamo": "papaguear",
    "papagueávamos": "papaguear",
    "papagueávei": "papaguear",
    "papagueáveis": "papaguear",
    "papai": "papar",
    "papaias": "papaia",
    "papaieiras": "papaieira",
    "papais": "papar",
    "papalina": "papalino",
    "papalinas": "papalino",
    "papalinos": "papalino",
    "papalva": "papalvo",
    "papalvas": "papalvo",
    "papalvices": "papalvice",
    "papalvos": "papalvo",
    "papam": "papar",
    "papamo": "papar",
    "papamos": "papar",
    "papando": "papar",
    "papanças": "papança",
    "papara": "papar",
    "paparam": "papar",
    "paparas": "papar",
    "paparde": "papar",
    "papardes": "papar",
    "papare": "papar",
    "paparei": "papar",
    "papareis": "papar",
    "paparem": "papar",
    "paparemos": "papar",
    "papares": "papar",
    "paparia": "papar",
    "papariam": "papar",
    "paparias": "papar",
    "paparica": "paparicar",
    "paparicada": "paparicar",
    "paparicadas": "paparicar",
    "paparicado": "paparicar",
    "paparicados": "paparicar",
    "paparicai": "paparicar",
    "paparicais": "paparicar",
    "paparicam": "paparicar",
    "paparicamo": "paparicar",
    "paparicamos": "paparicar",
    "paparicando": "paparicar",
    "paparicara": "paparicar",
    "paparicaram": "paparicar",
    "paparicaras": "paparicar",
    "paparicarde": "paparicar",
    "paparicardes": "paparicar",
    "paparicare": "paparicar",
    "paparicarei": "paparicar",
    "paparicareis": "paparicar",
    "paparicarem": "paparicar",
    "paparicaremos": "paparicar",
    "paparicares": "paparicar",
    "paparicaria": "paparicar",
    "paparicariam": "paparicar",
    "paparicarias": "paparicar",
    "paparicarmo": "paparicar",
    "paparicarmos": "paparicar",
    "paparicará": "paparicar",
    "paparicarás": "paparicar",
    "paparicarão": "paparicar",
    "paparicaríamos": "paparicar",
    "paparicaríeis": "paparicar",
    "paparicas": "paparicar",
    "paparicasse": "paparicar",
    "paparicassem": "paparicar",
    "paparicasses": "paparicar",
    "paparicaste": "paparicar",
    "paparicastes": "paparicar",
    "paparicava": "paparicar",
    "paparicavam": "paparicar",
    "paparicavas": "paparicar",
    "paparico": "paparicar",
    "paparicou": "paparicar",
    "paparicá": "paparicar",
    "paparicámo": "paparicar",
    "paparicámos": "paparicar",
    "paparicáramo": "paparicar",
    "paparicáramos": "paparicar",
    "paparicárei": "paparicar",
    "paparicáreis": "paparicar",
    "paparicásseis": "paparicar",
    "paparicássemos": "paparicar",
    "paparicávamo": "paparicar",
    "paparicávamos": "paparicar",
    "paparicávei": "paparicar",
    "paparicáveis": "paparicar",
    "paparique": "paparicar",
    "papariquei": "paparicar",
    "papariqueis": "paparicar",
    "papariquem": "paparicar",
    "papariquemo": "paparicar",
    "papariquemos": "paparicar",
    "papariques": "paparicar",
    "paparmo": "papar",
    "paparmos": "papar",
    "paparocas": "paparoca",
    "paparotes": "paparote",
    "paparrazes": "paparraz",
    "paparretas": "paparreta",
    "paparrofona": "paparrofão",
    "paparrofonas": "paparrofão",
    "paparrofões": "paparrofão",
    "paparrotadas": "paparrotada",
    "paparrotagens": "paparrotagem",
    "paparroteada": "paparrotear",
    "paparroteadas": "paparrotear",
    "paparroteado": "paparrotear",
    "paparroteados": "paparrotear",
    "paparroteai": "paparrotear",
    "paparroteais": "paparrotear",
    "paparroteamo": "paparrotear",
    "paparroteamos": "paparrotear",
    "paparroteando": "paparrotear",
    "paparroteara": "paparrotear",
    "paparrotearam": "paparrotear",
    "paparrotearas": "paparrotear",
    "paparrotearde": "paparrotear",
    "paparroteardes": "paparrotear",
    "paparroteare": "paparrotear",
    "paparrotearei": "paparrotear",
    "paparroteareis": "paparrotear",
    "paparrotearem": "paparrotear",
    "paparrotearemos": "paparrotear",
    "paparroteares": "paparrotear",
    "paparrotearia": "paparrotear",
    "paparroteariam": "paparrotear",
    "paparrotearias": "paparrotear",
    "paparrotearmo": "paparrotear",
    "paparrotearmos": "paparrotear",
    "paparroteará": "paparrotear",
    "paparrotearás": "paparrotear",
    "paparrotearão": "paparrotear",
    "paparrotearíamos": "paparrotear",
    "paparrotearíeis": "paparrotear",
    "paparroteasse": "paparrotear",
    "paparroteassem": "paparrotear",
    "paparroteasses": "paparrotear",
    "paparroteaste": "paparrotear",
    "paparroteastes": "paparrotear",
    "paparroteava": "paparrotear",
    "paparroteavam": "paparrotear",
    "paparroteavas": "paparrotear",
    "paparroteei": "paparrotear",
    "paparroteeis": "paparrotear",
    "paparroteemo": "paparrotear",
    "paparroteemos": "paparrotear",
    "paparroteia": "paparrotear",
    "paparroteiam": "paparrotear",
    "paparroteias": "paparrotear",
    "paparroteie": "paparrotear",
    "paparroteiem": "paparrotear",
    "paparroteies": "paparrotear",
    "paparroteio": "paparrotear",
    "paparroteou": "paparrotear",
    "paparroteá": "paparrotear",
    "paparroteámo": "paparrotear",
    "paparroteámos": "paparrotear",
    "paparroteáramo": "paparrotear",
    "paparroteáramos": "paparrotear",
    "paparroteárei": "paparrotear",
    "paparroteáreis": "paparrotear",
    "paparroteásseis": "paparrotear",
    "paparroteássemos": "paparrotear",
    "paparroteávamo": "paparrotear",
    "paparroteávamos": "paparrotear",
    "paparroteávei": "paparrotear",
    "paparroteáveis": "paparrotear",
    "paparrotices": "paparrotice",
    "paparrotona": "paparrotão",
    "paparrotonas": "paparrotão",
    "paparrotões": "paparrotão",
    "papará": "papar",
    "paparás": "papar",
    "paparão": "papar",
    "paparíamos": "papar",
    "paparíeis": "papar",
    "papas": "papar",
    "papasse": "papar",
    "papassem": "papar",
    "papasses": "papar",
    "papaste": "papar",
    "papastes": "papar",
    "papava": "papar",
    "papavam": "papar",
    "papavas": "papar",
    "papaverinas": "papaverina",
    "papaveráceas": "papaverácea",
    "papazanas": "papazana",
    "papazes": "papaz",
    "papazinho": "papá",
    "papazinhos": "papá",
    "papazito": "papá",
    "papazitos": "papá",
    "papaínas": "papaína",
    "papaúlhas": "papaúlha",
    "pape": "papar",
    "papeada": "papear",
    "papeadas": "papear",
    "papeado": "papear",
    "papeados": "papear",
    "papeai": "papear",
    "papeais": "papear",
    "papeamo": "papear",
    "papeamos": "papear",
    "papeando": "papear",
    "papeara": "papear",
    "papearam": "papear",
    "papearas": "papear",
    "papeardes": "papear",
    "papearei": "papear",
    "papeareis": "papear",
    "papearem": "papear",
    "papearemos": "papear",
    "papeares": "papear",
    "papearia": "papear",
    "papeariam": "papear",
    "papearias": "papear",
    "papearmo": "papear",
    "papearmos": "papear",
    "papeará": "papear",
    "papearás": "papear",
    "papearão": "papear",
    "papearíamos": "papear",
    "papearíeis": "papear",
    "papeasse": "papear",
    "papeassem": "papear",
    "papeasses": "papear",
    "papeaste": "papear",
    "papeastes": "papear",
    "papeava": "papear",
    "papeavam": "papear",
    "papeavas": "papear",
    "papeei": "papear",
    "papeeis": "papear",
    "papeemo": "papear",
    "papeemos": "papear",
    "papei": "papar",
    "papeia": "papear",
    "papeiam": "papear",
    "papeias": "papear",
    "papeie": "papear",
    "papeiem": "papear",
    "papeies": "papear",
    "papeio": "papear",
    "papeira": "papeiro",
    "papeiras": "papeiro",
    "papeiros": "papeiro",
    "papeis": "papar",
    "papeizinhos": "papel",
    "papeizitos": "papel",
    "papeja": "papejar",
    "papejada": "papejar",
    "papejadas": "papejar",
    "papejado": "papejar",
    "papejados": "papejar",
    "papejai": "papejar",
    "papejais": "papejar",
    "papejam": "papejar",
    "papejamo": "papejar",
    "papejamos": "papejar",
    "papejando": "papejar",
    "papejara": "papejar",
    "papejaram": "papejar",
    "papejaras": "papejar",
    "papejardes": "papejar",
    "papejarei": "papejar",
    "papejareis": "papejar",
    "papejarem": "papejar",
    "papejaremos": "papejar",
    "papejares": "papejar",
    "papejaria": "papejar",
    "papejariam": "papejar",
    "papejarias": "papejar",
    "papejarmo": "papejar",
    "papejarmos": "papejar",
    "papejará": "papejar",
    "papejarás": "papejar",
    "papejarão": "papejar",
    "papejaríamos": "papejar",
    "papejaríeis": "papejar",
    "papejas": "papejar",
    "papejasse": "papejar",
    "papejassem": "papejar",
    "papejasses": "papejar",
    "papejaste": "papejar",
    "papejastes": "papejar",
    "papejava": "papejar",
    "papejavam": "papejar",
    "papejavas": "papejar",
    "papeje": "papejar",
    "papejei": "papejar",
    "papejeis": "papejar",
    "papejem": "papejar",
    "papejemo": "papejar",
    "papejemos": "papejar",
    "papejes": "papejar",
    "papejo": "papejar",
    "papejou": "papejar",
    "papejámo": "papejar",
    "papejámos": "papejar",
    "papejáramo": "papejar",
    "papejáramos": "papejar",
    "papejáreis": "papejar",
    "papejásseis": "papejar",
    "papejássemos": "papejar",
    "papejávamo": "papejar",
    "papejávamos": "papejar",
    "papejáveis": "papejar",
    "papeladas": "papelada",
    "papelarias": "papelaria",
    "papeleira": "papeleiro",
    "papeleiras": "papeleiro",
    "papeleiros": "papeleiro",
    "papelejos": "papelejo",
    "papeletas": "papeleta",
    "papelinho": "papel",
    "papelinhos": "papelinho",
    "papelistas": "papelista",
    "papelito": "papel",
    "papelitos": "papel",
    "papeliços": "papeliço",
    "papelosas": "papelosa",
    "papelotes": "papelote",
    "papeluchos": "papelucho",
    "papelzinho": "papel",
    "papelzito": "papel",
    "papelórios": "papelório",
    "papelões": "papelão",
    "papem": "papar",
    "papemo": "papar",
    "papemos": "papar",
    "papeou": "papear",
    "papes": "papar",
    "papesas": "papesa",
    "papeámo": "papear",
    "papeámos": "papear",
    "papeáramo": "papear",
    "papeáramos": "papear",
    "papeáreis": "papear",
    "papeásseis": "papear",
    "papeássemos": "papear",
    "papeávamo": "papear",
    "papeávamos": "papear",
    "papeáveis": "papear",
    "papiformes": "papiforme",
    "papilares": "papilar",
    "papilas": "papila",
    "papilhos": "papilho",
    "papilionáceas": "papilionácea",
    "papilionídeos": "papilionídeo",
    "papiliónidas": "papiliónida",
    "papilomas": "papiloma",
    "papinha": "papa",
    "papinhas": "papa",
    "papinho": "papo",
    "papinhos": "papo",
    "papireiros": "papireiro",
    "papiriformes": "papiriforme",
    "papirologias": "papirologia",
    "papirongas": "papironga",
    "papiros": "papiro",
    "papirácea": "papiráceo",
    "papiráceas": "papiráceo",
    "papiráceos": "papiráceo",
    "papirífera": "papirífero",
    "papiríferas": "papirífero",
    "papiríferos": "papirífero",
    "papirólitos": "papirólito",
    "papisa": "papa",
    "papisas": "papa",
    "papismos": "papismo",
    "papistas": "papista",
    "papita": "papa",
    "papitas": "papa",
    "papito": "papo",
    "papitos": "papo",
    "papo": "papar",
    "papoilas": "papoila",
    "papos": "papo",
    "papossecos": "paposseco",
    "papou": "papar",
    "papoulas": "papoula",
    "papricas": "paprica",
    "papuas": "papua",
    "papuda": "papudo",
    "papudas": "papudo",
    "papudazinha": "papudo",
    "papudazinhas": "papudo",
    "papudazita": "papudo",
    "papudazitas": "papudo",
    "papudinha": "papudo",
    "papudinhas": "papudo",
    "papudinho": "papudo",
    "papudinhos": "papudo",
    "papudita": "papudo",
    "papuditas": "papudo",
    "papudito": "papudo",
    "papuditos": "papudo",
    "papudos": "papudo",
    "papudozinho": "papudo",
    "papudozinhos": "papudo",
    "papudozito": "papudo",
    "papudozitos": "papudo",
    "papudíssima": "papudo",
    "papudíssimas": "papudo",
    "papudíssimo": "papudo",
    "papudíssimos": "papudo",
    "papuja": "papujar",
    "papujada": "papujar",
    "papujadas": "papujar",
    "papujado": "papujar",
    "papujados": "papujar",
    "papujai": "papujar",
    "papujais": "papujar",
    "papujam": "papujar",
    "papujamo": "papujar",
    "papujamos": "papujar",
    "papujando": "papujar",
    "papujara": "papujar",
    "papujaram": "papujar",
    "papujaras": "papujar",
    "papujardes": "papujar",
    "papujarei": "papujar",
    "papujareis": "papujar",
    "papujarem": "papujar",
    "papujaremos": "papujar",
    "papujares": "papujar",
    "papujaria": "papujar",
    "papujariam": "papujar",
    "papujarias": "papujar",
    "papujarmo": "papujar",
    "papujarmos": "papujar",
    "papujará": "papujar",
    "papujarás": "papujar",
    "papujarão": "papujar",
    "papujaríamos": "papujar",
    "papujaríeis": "papujar",
    "papujas": "papujar",
    "papujasse": "papujar",
    "papujassem": "papujar",
    "papujasses": "papujar",
    "papujaste": "papujar",
    "papujastes": "papujar",
    "papujava": "papujar",
    "papujavam": "papujar",
    "papujavas": "papujar",
    "papuje": "papujar",
    "papujei": "papujar",
    "papujeis": "papujar",
    "papujem": "papujar",
    "papujemo": "papujar",
    "papujemos": "papujar",
    "papujes": "papujar",
    "papujo": "papujar",
    "papujou": "papujar",
    "papujámo": "papujar",
    "papujámos": "papujar",
    "papujáramo": "papujar",
    "papujáramos": "papujar",
    "papujáreis": "papujar",
    "papujásseis": "papujar",
    "papujássemos": "papujar",
    "papujávamo": "papujar",
    "papujávamos": "papujar",
    "papujáveis": "papujar",
    "papulares": "papular",
    "papuliformes": "papuliforme",
    "papulosa": "papuloso",
    "papulosas": "papuloso",
    "papulosos": "papuloso",
    "papuses": "papus",
    "papá": "papar",
    "papámo": "papar",
    "papámos": "papar",
    "papáramo": "papar",
    "papáramos": "papar",
    "papárei": "papar",
    "papáreis": "papar",
    "papás": "papá",
    "papásseis": "papar",
    "papássemos": "papar",
    "papávamo": "papar",
    "papávamos": "papar",
    "papávei": "papar",
    "papáveis": "papável",
    "papéis": "papel",
    "papírea": "papíreo",
    "papíreas": "papíreo",
    "papíreos": "papíreo",
    "papões": "papão",
    "paqueboteira": "paqueboteiro",
    "paqueboteiras": "paqueboteiro",
    "paqueboteiros": "paqueboteiro",
    "paquebotes": "paquebote",
    "paquetes": "paquete",
    "paquidactilias": "paquidactilia",
    "paquidactílica": "paquidactílico",
    "paquidactílicas": "paquidactílico",
    "paquidactílicos": "paquidactílico",
    "paquidermes": "paquiderme",
    "paquidáctila": "paquidáctilo",
    "paquidáctilas": "paquidáctilo",
    "paquidáctilos": "paquidáctilo",
    "paquifes": "paquife",
    "paquinhas": "paquinha",
    "paquistanesa": "paquistanês",
    "paquistanesas": "paquistanês",
    "paquistaneses": "paquistanês",
    "paquímetros": "paquímetro",
    "para": "parir",
    "parabeniza": "parabenizar",
    "parabenizada": "parabenizar",
    "parabenizadas": "parabenizar",
    "parabenizado": "parabenizar",
    "parabenizados": "parabenizar",
    "parabenizai": "parabenizar",
    "parabenizais": "parabenizar",
    "parabenizam": "parabenizar",
    "parabenizamo": "parabenizar",
    "parabenizamos": "parabenizar",
    "parabenizando": "parabenizar",
    "parabenizara": "parabenizar",
    "parabenizaram": "parabenizar",
    "parabenizaras": "parabenizar",
    "parabenizarde": "parabenizar",
    "parabenizardes": "parabenizar",
    "parabenizare": "parabenizar",
    "parabenizarei": "parabenizar",
    "parabenizareis": "parabenizar",
    "parabenizarem": "parabenizar",
    "parabenizaremos": "parabenizar",
    "parabenizares": "parabenizar",
    "parabenizaria": "parabenizar",
    "parabenizariam": "parabenizar",
    "parabenizarias": "parabenizar",
    "parabenizarmo": "parabenizar",
    "parabenizarmos": "parabenizar",
    "parabenizará": "parabenizar",
    "parabenizarás": "parabenizar",
    "parabenizarão": "parabenizar",
    "parabenizaríamos": "parabenizar",
    "parabenizaríeis": "parabenizar",
    "parabenizas": "parabenizar",
    "parabenizasse": "parabenizar",
    "parabenizassem": "parabenizar",
    "parabenizasses": "parabenizar",
    "parabenizaste": "parabenizar",
    "parabenizastes": "parabenizar",
    "parabenizava": "parabenizar",
    "parabenizavam": "parabenizar",
    "parabenizavas": "parabenizar",
    "parabenize": "parabenizar",
    "parabenizei": "parabenizar",
    "parabenizeis": "parabenizar",
    "parabenizem": "parabenizar",
    "parabenizemo": "parabenizar",
    "parabenizemos": "parabenizar",
    "parabenizes": "parabenizar",
    "parabenizo": "parabenizar",
    "parabenizou": "parabenizar",
    "parabenizá": "parabenizar",
    "parabenizámo": "parabenizar",
    "parabenizámos": "parabenizar",
    "parabenizáramo": "parabenizar",
    "parabenizáramos": "parabenizar",
    "parabenizárei": "parabenizar",
    "parabenizáreis": "parabenizar",
    "parabenizásseis": "parabenizar",
    "parabenizássemos": "parabenizar",
    "parabenizávamo": "parabenizar",
    "parabenizávamos": "parabenizar",
    "parabenizávei": "parabenizar",
    "parabenizáveis": "parabenizar",
    "parabenteada": "parabentear",
    "parabenteadas": "parabentear",
    "parabenteado": "parabentear",
    "parabenteados": "parabentear",
    "parabenteai": "parabentear",
    "parabenteais": "parabentear",
    "parabenteamo": "parabentear",
    "parabenteamos": "parabentear",
    "parabenteando": "parabentear",
    "parabenteara": "parabentear",
    "parabentearam": "parabentear",
    "parabentearas": "parabentear",
    "parabentearde": "parabentear",
    "parabenteardes": "parabentear",
    "parabenteare": "parabentear",
    "parabentearei": "parabentear",
    "parabenteareis": "parabentear",
    "parabentearem": "parabentear",
    "parabentearemos": "parabentear",
    "parabenteares": "parabentear",
    "parabentearia": "parabentear",
    "parabenteariam": "parabentear",
    "parabentearias": "parabentear",
    "parabentearmo": "parabentear",
    "parabentearmos": "parabentear",
    "parabenteará": "parabentear",
    "parabentearás": "parabentear",
    "parabentearão": "parabentear",
    "parabentearíamos": "parabentear",
    "parabentearíeis": "parabentear",
    "parabenteasse": "parabentear",
    "parabenteassem": "parabentear",
    "parabenteasses": "parabentear",
    "parabenteaste": "parabentear",
    "parabenteastes": "parabentear",
    "parabenteava": "parabentear",
    "parabenteavam": "parabentear",
    "parabenteavas": "parabentear",
    "parabenteei": "parabentear",
    "parabenteeis": "parabentear",
    "parabenteemo": "parabentear",
    "parabenteemos": "parabentear",
    "parabenteia": "parabentear",
    "parabenteiam": "parabentear",
    "parabenteias": "parabentear",
    "parabenteie": "parabentear",
    "parabenteiem": "parabentear",
    "parabenteies": "parabentear",
    "parabenteio": "parabentear",
    "parabenteou": "parabentear",
    "parabenteá": "parabentear",
    "parabenteámo": "parabentear",
    "parabenteámos": "parabentear",
    "parabenteáramo": "parabentear",
    "parabenteáramos": "parabentear",
    "parabenteárei": "parabentear",
    "parabenteáreis": "parabentear",
    "parabenteásseis": "parabentear",
    "parabenteássemos": "parabentear",
    "parabenteávamo": "parabentear",
    "parabenteávamos": "parabentear",
    "parabenteávei": "parabentear",
    "parabenteáveis": "parabentear",
    "parabolismos": "parabolismo",
    "parabolistas": "parabolista",
    "paraboliza": "parabolizar",
    "parabolizada": "parabolizar",
    "parabolizadas": "parabolizar",
    "parabolizado": "parabolizar",
    "parabolizados": "parabolizar",
    "parabolizai": "parabolizar",
    "parabolizais": "parabolizar",
    "parabolizam": "parabolizar",
    "parabolizamo": "parabolizar",
    "parabolizamos": "parabolizar",
    "parabolizando": "parabolizar",
    "parabolizara": "parabolizar",
    "parabolizaram": "parabolizar",
    "parabolizaras": "parabolizar",
    "parabolizarde": "parabolizar",
    "parabolizardes": "parabolizar",
    "parabolizare": "parabolizar",
    "parabolizarei": "parabolizar",
    "parabolizareis": "parabolizar",
    "parabolizarem": "parabolizar",
    "parabolizaremos": "parabolizar",
    "parabolizares": "parabolizar",
    "parabolizaria": "parabolizar",
    "parabolizariam": "parabolizar",
    "parabolizarias": "parabolizar",
    "parabolizarmo": "parabolizar",
    "parabolizarmos": "parabolizar",
    "parabolizará": "parabolizar",
    "parabolizarás": "parabolizar",
    "parabolizarão": "parabolizar",
    "parabolizaríamos": "parabolizar",
    "parabolizaríeis": "parabolizar",
    "parabolizas": "parabolizar",
    "parabolizasse": "parabolizar",
    "parabolizassem": "parabolizar",
    "parabolizasses": "parabolizar",
    "parabolizaste": "parabolizar",
    "parabolizastes": "parabolizar",
    "parabolizava": "parabolizar",
    "parabolizavam": "parabolizar",
    "parabolizavas": "parabolizar",
    "parabolize": "parabolizar",
    "parabolizei": "parabolizar",
    "parabolizeis": "parabolizar",
    "parabolizem": "parabolizar",
    "parabolizemo": "parabolizar",
    "parabolizemos": "parabolizar",
    "parabolizes": "parabolizar",
    "parabolizo": "parabolizar",
    "parabolizou": "parabolizar",
    "parabolizá": "parabolizar",
    "parabolizámo": "parabolizar",
    "parabolizámos": "parabolizar",
    "parabolizáramo": "parabolizar",
    "parabolizáramos": "parabolizar",
    "parabolizárei": "parabolizar",
    "parabolizáreis": "parabolizar",
    "parabolizásseis": "parabolizar",
    "parabolizássemos": "parabolizar",
    "parabolizávamo": "parabolizar",
    "parabolizávamos": "parabolizar",
    "parabolizávei": "parabolizar",
    "parabolizáveis": "parabolizar",
    "parabolística": "parabolístico",
    "parabolísticas": "parabolístico",
    "parabolísticos": "parabolístico",
    "parabolóides": "parabolóide",
    "parabéns": "parabém",
    "parabólica": "parabólico",
    "parabólicas": "parabólico",
    "parabólicos": "parabólico",
    "paracefálica": "paracefálico",
    "paracefálicas": "paracefálico",
    "paracefálicos": "paracefálico",
    "paracelsismos": "paracelsismo",
    "paracleteada": "paracletear",
    "paracleteadas": "paracletear",
    "paracleteado": "paracletear",
    "paracleteados": "paracletear",
    "paracleteai": "paracletear",
    "paracleteais": "paracletear",
    "paracleteamo": "paracletear",
    "paracleteamos": "paracletear",
    "paracleteando": "paracletear",
    "paracleteara": "paracletear",
    "paracletearam": "paracletear",
    "paracletearas": "paracletear",
    "paracletearde": "paracletear",
    "paracleteardes": "paracletear",
    "paracleteare": "paracletear",
    "paracletearei": "paracletear",
    "paracleteareis": "paracletear",
    "paracletearem": "paracletear",
    "paracletearemos": "paracletear",
    "paracleteares": "paracletear",
    "paracletearia": "paracletear",
    "paracleteariam": "paracletear",
    "paracletearias": "paracletear",
    "paracletearmo": "paracletear",
    "paracletearmos": "paracletear",
    "paracleteará": "paracletear",
    "paracletearás": "paracletear",
    "paracletearão": "paracletear",
    "paracletearíamos": "paracletear",
    "paracletearíeis": "paracletear",
    "paracleteasse": "paracletear",
    "paracleteassem": "paracletear",
    "paracleteasses": "paracletear",
    "paracleteaste": "paracletear",
    "paracleteastes": "paracletear",
    "paracleteava": "paracletear",
    "paracleteavam": "paracletear",
    "paracleteavas": "paracletear",
    "paracleteei": "paracletear",
    "paracleteeis": "paracletear",
    "paracleteemo": "paracletear",
    "paracleteemos": "paracletear",
    "paracleteia": "paracletear",
    "paracleteiam": "paracletear",
    "paracleteias": "paracletear",
    "paracleteie": "paracletear",
    "paracleteiem": "paracletear",
    "paracleteies": "paracletear",
    "paracleteio": "paracletear",
    "paracleteou": "paracletear",
    "paracleteá": "paracletear",
    "paracleteámo": "paracletear",
    "paracleteámos": "paracletear",
    "paracleteáramo": "paracletear",
    "paracleteáramos": "paracletear",
    "paracleteárei": "paracletear",
    "paracleteáreis": "paracletear",
    "paracleteásseis": "paracletear",
    "paracleteássemos": "paracletear",
    "paracleteávamo": "paracletear",
    "paracleteávamos": "paracletear",
    "paracleteávei": "paracletear",
    "paracleteáveis": "paracletear",
    "paracletos": "paracleto",
    "paraclítica": "paraclítico",
    "paraclíticas": "paraclítico",
    "paraclíticos": "paraclítico",
    "paracronismos": "paracronismo",
    "paracronística": "paracronístico",
    "paracronísticas": "paracronístico",
    "paracronísticos": "paracronístico",
    "paracrónica": "paracrónico",
    "paracrónicas": "paracrónico",
    "paracrónicos": "paracrónico",
    "paracéfala": "paracéfalo",
    "paracéfalas": "paracéfalo",
    "paracéfalos": "paracéfalo",
    "parada": "parar",
    "paradas": "parar",
    "paradeiros": "paradeiro",
    "paradelas": "paradela",
    "paradigmais": "paradigmal",
    "paradigmas": "paradigma",
    "paradigmática": "paradigmático",
    "paradigmáticas": "paradigmático",
    "paradigmáticos": "paradigmático",
    "paradinha": "parado",
    "paradinhas": "parado",
    "paradinho": "parado",
    "paradinhos": "parado",
    "paradiseídeos": "paradiseídeo",
    "paradisíaca": "paradisíaco",
    "paradisíacas": "paradisíaco",
    "paradisíacos": "paradisíaco",
    "paradita": "parado",
    "paraditas": "parado",
    "paradito": "parado",
    "paraditos": "parado",
    "parado": "parar",
    "paradoiros": "paradoiro",
    "parados": "parar",
    "paradouros": "paradouro",
    "paradoxa": "paradoxo",
    "paradoxada": "paradoxar",
    "paradoxadas": "paradoxar",
    "paradoxado": "paradoxar",
    "paradoxados": "paradoxar",
    "paradoxai": "paradoxar",
    "paradoxais": "paradoxar",
    "paradoxam": "paradoxar",
    "paradoxamo": "paradoxar",
    "paradoxamos": "paradoxar",
    "paradoxando": "paradoxar",
    "paradoxara": "paradoxar",
    "paradoxaram": "paradoxar",
    "paradoxaras": "paradoxar",
    "paradoxardes": "paradoxar",
    "paradoxarei": "paradoxar",
    "paradoxareis": "paradoxar",
    "paradoxarem": "paradoxar",
    "paradoxaremos": "paradoxar",
    "paradoxares": "paradoxar",
    "paradoxaria": "paradoxar",
    "paradoxariam": "paradoxar",
    "paradoxarias": "paradoxar",
    "paradoxarmo": "paradoxar",
    "paradoxarmos": "paradoxar",
    "paradoxará": "paradoxar",
    "paradoxarás": "paradoxar",
    "paradoxarão": "paradoxar",
    "paradoxaríamos": "paradoxar",
    "paradoxaríeis": "paradoxar",
    "paradoxas": "paradoxo",
    "paradoxasse": "paradoxar",
    "paradoxassem": "paradoxar",
    "paradoxasses": "paradoxar",
    "paradoxaste": "paradoxar",
    "paradoxastes": "paradoxar",
    "paradoxava": "paradoxar",
    "paradoxavam": "paradoxar",
    "paradoxavas": "paradoxar",
    "paradoxe": "paradoxar",
    "paradoxei": "paradoxar",
    "paradoxeis": "paradoxar",
    "paradoxem": "paradoxar",
    "paradoxemo": "paradoxar",
    "paradoxemos": "paradoxar",
    "paradoxes": "paradoxar",
    "paradoxo": "paradoxar",
    "paradoxos": "paradoxo",
    "paradoxou": "paradoxar",
    "paradoxámo": "paradoxar",
    "paradoxámos": "paradoxar",
    "paradoxáramo": "paradoxar",
    "paradoxáramos": "paradoxar",
    "paradoxáreis": "paradoxar",
    "paradoxásseis": "paradoxar",
    "paradoxássemos": "paradoxar",
    "paradoxávamo": "paradoxar",
    "paradoxávamos": "paradoxar",
    "paradoxáveis": "paradoxar",
    "paradísica": "paradísico",
    "paradísicas": "paradísico",
    "paradísicos": "paradísico",
    "paradíssima": "parado",
    "paradíssimas": "parado",
    "paradíssimo": "parado",
    "paradíssimos": "parado",
    "paraenses": "paraense",
    "parafernais": "parafernal",
    "parafernalidades": "parafernalidade",
    "parafernálias": "parafernália",
    "parafina": "parafinar",
    "parafinada": "parafinar",
    "parafinadas": "parafinar",
    "parafinado": "parafinar",
    "parafinados": "parafinar",
    "parafinagens": "parafinagem",
    "parafinai": "parafinar",
    "parafinais": "parafinar",
    "parafinam": "parafinar",
    "parafinamo": "parafinar",
    "parafinamos": "parafinar",
    "parafinando": "parafinar",
    "parafinara": "parafinar",
    "parafinaram": "parafinar",
    "parafinaras": "parafinar",
    "parafinarde": "parafinar",
    "parafinardes": "parafinar",
    "parafinare": "parafinar",
    "parafinarei": "parafinar",
    "parafinareis": "parafinar",
    "parafinarem": "parafinar",
    "parafinaremos": "parafinar",
    "parafinares": "parafinar",
    "parafinaria": "parafinar",
    "parafinariam": "parafinar",
    "parafinarias": "parafinar",
    "parafinarmo": "parafinar",
    "parafinarmos": "parafinar",
    "parafinará": "parafinar",
    "parafinarás": "parafinar",
    "parafinarão": "parafinar",
    "parafinaríamos": "parafinar",
    "parafinaríeis": "parafinar",
    "parafinas": "parafinar",
    "parafinasse": "parafinar",
    "parafinassem": "parafinar",
    "parafinasses": "parafinar",
    "parafinaste": "parafinar",
    "parafinastes": "parafinar",
    "parafinava": "parafinar",
    "parafinavam": "parafinar",
    "parafinavas": "parafinar",
    "parafine": "parafinar",
    "parafinei": "parafinar",
    "parafineis": "parafinar",
    "parafinem": "parafinar",
    "parafinemo": "parafinar",
    "parafinemos": "parafinar",
    "parafines": "parafinar",
    "parafiniza": "parafinizar",
    "parafinizada": "parafinizar",
    "parafinizadas": "parafinizar",
    "parafinizado": "parafinizar",
    "parafinizados": "parafinizar",
    "parafinizai": "parafinizar",
    "parafinizais": "parafinizar",
    "parafinizam": "parafinizar",
    "parafinizamo": "parafinizar",
    "parafinizamos": "parafinizar",
    "parafinizando": "parafinizar",
    "parafinizara": "parafinizar",
    "parafinizaram": "parafinizar",
    "parafinizaras": "parafinizar",
    "parafinizarde": "parafinizar",
    "parafinizardes": "parafinizar",
    "parafinizare": "parafinizar",
    "parafinizarei": "parafinizar",
    "parafinizareis": "parafinizar",
    "parafinizarem": "parafinizar",
    "parafinizaremos": "parafinizar",
    "parafinizares": "parafinizar",
    "parafinizaria": "parafinizar",
    "parafinizariam": "parafinizar",
    "parafinizarias": "parafinizar",
    "parafinizarmo": "parafinizar",
    "parafinizarmos": "parafinizar",
    "parafinizará": "parafinizar",
    "parafinizarás": "parafinizar",
    "parafinizarão": "parafinizar",
    "parafinizaríamos": "parafinizar",
    "parafinizaríeis": "parafinizar",
    "parafinizas": "parafinizar",
    "parafinizasse": "parafinizar",
    "parafinizassem": "parafinizar",
    "parafinizasses": "parafinizar",
    "parafinizaste": "parafinizar",
    "parafinizastes": "parafinizar",
    "parafinizava": "parafinizar",
    "parafinizavam": "parafinizar",
    "parafinizavas": "parafinizar",
    "parafinize": "parafinizar",
    "parafinizei": "parafinizar",
    "parafinizeis": "parafinizar",
    "parafinizem": "parafinizar",
    "parafinizemo": "parafinizar",
    "parafinizemos": "parafinizar",
    "parafinizes": "parafinizar",
    "parafinizo": "parafinizar",
    "parafinizou": "parafinizar",
    "parafinizá": "parafinizar",
    "parafinizámo": "parafinizar",
    "parafinizámos": "parafinizar",
    "parafinizáramo": "parafinizar",
    "parafinizáramos": "parafinizar",
    "parafinizárei": "parafinizar",
    "parafinizáreis": "parafinizar",
    "parafinizásseis": "parafinizar",
    "parafinizássemos": "parafinizar",
    "parafinizávamo": "parafinizar",
    "parafinizávamos": "parafinizar",
    "parafinizávei": "parafinizar",
    "parafinizáveis": "parafinizar",
    "parafino": "parafinar",
    "parafinou": "parafinar",
    "parafiná": "parafinar",
    "parafinámo": "parafinar",
    "parafinámos": "parafinar",
    "parafináramo": "parafinar",
    "parafináramos": "parafinar",
    "parafinárei": "parafinar",
    "parafináreis": "parafinar",
    "parafinásseis": "parafinar",
    "parafinássemos": "parafinar",
    "parafinávamo": "parafinar",
    "parafinávamos": "parafinar",
    "parafinávei": "parafinar",
    "parafináveis": "parafinar",
    "parafiscais": "parafiscal",
    "parafraseada": "parafrasear",
    "parafraseadas": "parafrasear",
    "parafraseado": "parafrasear",
    "parafraseadora": "parafraseador",
    "parafraseadoras": "parafraseador",
    "parafraseadores": "parafraseador",
    "parafraseados": "parafrasear",
    "parafraseai": "parafrasear",
    "parafraseais": "parafrasear",
    "parafraseamo": "parafrasear",
    "parafraseamos": "parafrasear",
    "parafraseando": "parafrasear",
    "parafraseara": "parafrasear",
    "parafrasearam": "parafrasear",
    "parafrasearas": "parafrasear",
    "parafrasearde": "parafrasear",
    "parafraseardes": "parafrasear",
    "parafraseare": "parafrasear",
    "parafrasearei": "parafrasear",
    "parafraseareis": "parafrasear",
    "parafrasearem": "parafrasear",
    "parafrasearemos": "parafrasear",
    "parafraseares": "parafrasear",
    "parafrasearia": "parafrasear",
    "parafraseariam": "parafrasear",
    "parafrasearias": "parafrasear",
    "parafrasearmo": "parafrasear",
    "parafrasearmos": "parafrasear",
    "parafraseará": "parafrasear",
    "parafrasearás": "parafrasear",
    "parafrasearão": "parafrasear",
    "parafrasearíamos": "parafrasear",
    "parafrasearíeis": "parafrasear",
    "parafraseasse": "parafrasear",
    "parafraseassem": "parafrasear",
    "parafraseasses": "parafrasear",
    "parafraseaste": "parafrasear",
    "parafraseastes": "parafrasear",
    "parafraseava": "parafrasear",
    "parafraseavam": "parafrasear",
    "parafraseavas": "parafrasear",
    "parafraseei": "parafrasear",
    "parafraseeis": "parafrasear",
    "parafraseemo": "parafrasear",
    "parafraseemos": "parafrasear",
    "parafraseia": "parafrasear",
    "parafraseiam": "parafrasear",
    "parafraseias": "parafrasear",
    "parafraseie": "parafrasear",
    "parafraseiem": "parafrasear",
    "parafraseies": "parafrasear",
    "parafraseio": "parafrasear",
    "parafraseou": "parafrasear",
    "parafraseá": "parafrasear",
    "parafraseámo": "parafrasear",
    "parafraseámos": "parafrasear",
    "parafraseáramo": "parafrasear",
    "parafraseáramos": "parafrasear",
    "parafraseárei": "parafrasear",
    "parafraseáreis": "parafrasear",
    "parafraseásseis": "parafrasear",
    "parafraseássemos": "parafrasear",
    "parafraseávamo": "parafrasear",
    "parafraseávamos": "parafrasear",
    "parafraseávei": "parafrasear",
    "parafraseáveis": "parafraseável",
    "parafrastas": "parafrasta",
    "parafrástica": "parafrástico",
    "parafrásticas": "parafrástico",
    "parafrásticos": "parafrástico",
    "parafusa": "parafusar",
    "parafusada": "parafusar",
    "parafusadas": "parafusar",
    "parafusado": "parafusar",
    "parafusadora": "parafusador",
    "parafusadoras": "parafusador",
    "parafusadores": "parafusador",
    "parafusados": "parafusar",
    "parafusai": "parafusar",
    "parafusais": "parafusar",
    "parafusam": "parafusar",
    "parafusamo": "parafusar",
    "parafusamos": "parafusar",
    "parafusando": "parafusar",
    "parafusara": "parafusar",
    "parafusaram": "parafusar",
    "parafusaras": "parafusar",
    "parafusarde": "parafusar",
    "parafusardes": "parafusar",
    "parafusare": "parafusar",
    "parafusarei": "parafusar",
    "parafusareis": "parafusar",
    "parafusarem": "parafusar",
    "parafusaremos": "parafusar",
    "parafusares": "parafusar",
    "parafusaria": "parafusar",
    "parafusariam": "parafusar",
    "parafusarias": "parafusaria",
    "parafusarmo": "parafusar",
    "parafusarmos": "parafusar",
    "parafusará": "parafusar",
    "parafusarás": "parafusar",
    "parafusarão": "parafusar",
    "parafusaríamos": "parafusar",
    "parafusaríeis": "parafusar",
    "parafusas": "parafusar",
    "parafusasse": "parafusar",
    "parafusassem": "parafusar",
    "parafusasses": "parafusar",
    "parafusaste": "parafusar",
    "parafusastes": "parafusar",
    "parafusava": "parafusar",
    "parafusavam": "parafusar",
    "parafusavas": "parafusar",
    "parafusações": "parafusação",
    "parafuse": "parafusar",
    "parafusei": "parafusar",
    "parafuseis": "parafusar",
    "parafusem": "parafusar",
    "parafusemo": "parafusar",
    "parafusemos": "parafusar",
    "parafuses": "parafusar",
    "parafuso": "parafusar",
    "parafusos": "parafuso",
    "parafusou": "parafusar",
    "parafusá": "parafusar",
    "parafusámo": "parafusar",
    "parafusámos": "parafusar",
    "parafusáramo": "parafusar",
    "parafusáramos": "parafusar",
    "parafusárei": "parafusar",
    "parafusáreis": "parafusar",
    "parafusásseis": "parafusar",
    "parafusássemos": "parafusar",
    "parafusávamo": "parafusar",
    "parafusávamos": "parafusar",
    "parafusávei": "parafusar",
    "parafusáveis": "parafusar",
    "parafínica": "parafínico",
    "parafínicas": "parafínico",
    "parafínicos": "parafínico",
    "parafítica": "parafítico",
    "parafíticas": "parafítico",
    "parafíticos": "parafítico",
    "paragens": "paragem",
    "paragenésica": "paragenésico",
    "paragenésicas": "paragenésico",
    "paragenésicos": "paragenésico",
    "paragenética": "paragenético",
    "paragenéticas": "paragenético",
    "paragenéticos": "paragenético",
    "paragoges": "paragoge",
    "paragona": "paragonar",
    "paragonada": "paragonar",
    "paragonadas": "paragonar",
    "paragonado": "paragonar",
    "paragonados": "paragonar",
    "paragonai": "paragonar",
    "paragonais": "paragonar",
    "paragonam": "paragonar",
    "paragonamo": "paragonar",
    "paragonamos": "paragonar",
    "paragonando": "paragonar",
    "paragonara": "paragonar",
    "paragonaram": "paragonar",
    "paragonaras": "paragonar",
    "paragonarde": "paragonar",
    "paragonardes": "paragonar",
    "paragonare": "paragonar",
    "paragonarei": "paragonar",
    "paragonareis": "paragonar",
    "paragonarem": "paragonar",
    "paragonaremos": "paragonar",
    "paragonares": "paragonar",
    "paragonaria": "paragonar",
    "paragonariam": "paragonar",
    "paragonarias": "paragonar",
    "paragonarmo": "paragonar",
    "paragonarmos": "paragonar",
    "paragonará": "paragonar",
    "paragonarás": "paragonar",
    "paragonarão": "paragonar",
    "paragonaríamos": "paragonar",
    "paragonaríeis": "paragonar",
    "paragonas": "paragonar",
    "paragonasse": "paragonar",
    "paragonassem": "paragonar",
    "paragonasses": "paragonar",
    "paragonaste": "paragonar",
    "paragonastes": "paragonar",
    "paragonava": "paragonar",
    "paragonavam": "paragonar",
    "paragonavas": "paragonar",
    "paragone": "paragonar",
    "paragonei": "paragonar",
    "paragoneis": "paragonar",
    "paragonem": "paragonar",
    "paragonemo": "paragonar",
    "paragonemos": "paragonar",
    "paragones": "paragonar",
    "paragono": "paragonar",
    "paragonou": "paragonar",
    "paragoná": "paragonar",
    "paragonámo": "paragonar",
    "paragonámos": "paragonar",
    "paragonáramo": "paragonar",
    "paragonáramos": "paragonar",
    "paragonárei": "paragonar",
    "paragonáreis": "paragonar",
    "paragonásseis": "paragonar",
    "paragonássemos": "paragonar",
    "paragonávamo": "paragonar",
    "paragonávamos": "paragonar",
    "paragonávei": "paragonar",
    "paragonáveis": "paragonar",
    "paragrafa": "paragrafar",
    "paragrafada": "paragrafar",
    "paragrafadas": "paragrafar",
    "paragrafado": "paragrafar",
    "paragrafados": "paragrafar",
    "paragrafai": "paragrafar",
    "paragrafais": "paragrafar",
    "paragrafam": "paragrafar",
    "paragrafamo": "paragrafar",
    "paragrafamos": "paragrafar",
    "paragrafando": "paragrafar",
    "paragrafara": "paragrafar",
    "paragrafaram": "paragrafar",
    "paragrafaras": "paragrafar",
    "paragrafarde": "paragrafar",
    "paragrafardes": "paragrafar",
    "paragrafare": "paragrafar",
    "paragrafarei": "paragrafar",
    "paragrafareis": "paragrafar",
    "paragrafarem": "paragrafar",
    "paragrafaremos": "paragrafar",
    "paragrafares": "paragrafar",
    "paragrafaria": "paragrafar",
    "paragrafariam": "paragrafar",
    "paragrafarias": "paragrafar",
    "paragrafarmo": "paragrafar",
    "paragrafarmos": "paragrafar",
    "paragrafará": "paragrafar",
    "paragrafarás": "paragrafar",
    "paragrafarão": "paragrafar",
    "paragrafaríamos": "paragrafar",
    "paragrafaríeis": "paragrafar",
    "paragrafas": "paragrafar",
    "paragrafasse": "paragrafar",
    "paragrafassem": "paragrafar",
    "paragrafasses": "paragrafar",
    "paragrafaste": "paragrafar",
    "paragrafastes": "paragrafar",
    "paragrafava": "paragrafar",
    "paragrafavam": "paragrafar",
    "paragrafavas": "paragrafar",
    "paragrafe": "paragrafar",
    "paragrafei": "paragrafar",
    "paragrafeis": "paragrafar",
    "paragrafem": "paragrafar",
    "paragrafemo": "paragrafar",
    "paragrafemos": "paragrafar",
    "paragrafes": "paragrafar",
    "paragrafo": "paragrafar",
    "paragrafou": "paragrafar",
    "paragrafá": "paragrafar",
    "paragrafámo": "paragrafar",
    "paragrafámos": "paragrafar",
    "paragrafáramo": "paragrafar",
    "paragrafáramos": "paragrafar",
    "paragrafárei": "paragrafar",
    "paragrafáreis": "paragrafar",
    "paragrafásseis": "paragrafar",
    "paragrafássemos": "paragrafar",
    "paragrafávamo": "paragrafar",
    "paragrafávamos": "paragrafar",
    "paragrafávei": "paragrafar",
    "paragrafáveis": "paragrafar",
    "paragramas": "paragrama",
    "paragramatismos": "paragramatismo",
    "paragramática": "paragramático",
    "paragramáticas": "paragramático",
    "paragramáticos": "paragramático",
    "paraguaia": "paraguaio",
    "paraguaiana": "paraguaiano",
    "paraguaianas": "paraguaiano",
    "paraguaianos": "paraguaiano",
    "paraguaias": "paraguaio",
    "paraguaios": "paraguaio",
    "paragéneses": "paragénese",
    "paragógica": "paragógico",
    "paragógicas": "paragógico",
    "paragógicos": "paragógico",
    "parai": "parar",
    "paraidrogénios": "paraidrogénio",
    "parais": "parir",
    "parajurisdicionais": "parajurisdicional",
    "paralalias": "paralalia",
    "paralambdacística": "paralambdacístico",
    "paralambdacísticas": "paralambdacístico",
    "paralambdacísticos": "paralambdacístico",
    "paralampsias": "paralampsia",
    "paralaxes": "paralaxe",
    "paraldeídos": "paraldeído",
    "paralela": "paralelo",
    "paralelas": "paralelo",
    "paralelepípedos": "paralelepípedo",
    "paralelinérvea": "paralelinérveo",
    "paralelinérveas": "paralelinérveo",
    "paralelinérveos": "paralelinérveo",
    "paralelinérvica": "paralelinérvico",
    "paralelinérvicas": "paralelinérvico",
    "paralelinérvicos": "paralelinérvico",
    "paralelismos": "paralelismo",
    "paraleliza": "paralelizar",
    "paralelizada": "paralelizar",
    "paralelizadas": "paralelizar",
    "paralelizado": "paralelizar",
    "paralelizados": "paralelizar",
    "paralelizai": "paralelizar",
    "paralelizais": "paralelizar",
    "paralelizam": "paralelizar",
    "paralelizamo": "paralelizar",
    "paralelizamos": "paralelizar",
    "paralelizando": "paralelizar",
    "paralelizara": "paralelizar",
    "paralelizaram": "paralelizar",
    "paralelizaras": "paralelizar",
    "paralelizarde": "paralelizar",
    "paralelizardes": "paralelizar",
    "paralelizare": "paralelizar",
    "paralelizarei": "paralelizar",
    "paralelizareis": "paralelizar",
    "paralelizarem": "paralelizar",
    "paralelizaremos": "paralelizar",
    "paralelizares": "paralelizar",
    "paralelizaria": "paralelizar",
    "paralelizariam": "paralelizar",
    "paralelizarias": "paralelizar",
    "paralelizarmo": "paralelizar",
    "paralelizarmos": "paralelizar",
    "paralelizará": "paralelizar",
    "paralelizarás": "paralelizar",
    "paralelizarão": "paralelizar",
    "paralelizaríamos": "paralelizar",
    "paralelizaríeis": "paralelizar",
    "paralelizas": "paralelizar",
    "paralelizasse": "paralelizar",
    "paralelizassem": "paralelizar",
    "paralelizasses": "paralelizar",
    "paralelizaste": "paralelizar",
    "paralelizastes": "paralelizar",
    "paralelizava": "paralelizar",
    "paralelizavam": "paralelizar",
    "paralelizavas": "paralelizar",
    "paralelize": "paralelizar",
    "paralelizei": "paralelizar",
    "paralelizeis": "paralelizar",
    "paralelizem": "paralelizar",
    "paralelizemo": "paralelizar",
    "paralelizemos": "paralelizar",
    "paralelizes": "paralelizar",
    "paralelizo": "paralelizar",
    "paralelizou": "paralelizar",
    "paralelizá": "paralelizar",
    "paralelizámo": "paralelizar",
    "paralelizámos": "paralelizar",
    "paralelizáramo": "paralelizar",
    "paralelizáramos": "paralelizar",
    "paralelizárei": "paralelizar",
    "paralelizáreis": "paralelizar",
    "paralelizásseis": "paralelizar",
    "paralelizássemos": "paralelizar",
    "paralelizávamo": "paralelizar",
    "paralelizávamos": "paralelizar",
    "paralelizávei": "paralelizar",
    "paralelizáveis": "paralelizável",
    "paralelogramos": "paralelogramo",
    "paralelos": "paralelo",
    "paralelística": "paralelístico",
    "paralelísticas": "paralelístico",
    "paralelísticos": "paralelístico",
    "paralexias": "paralexia",
    "paralheiros": "paralheiro",
    "paralipses": "paralipse",
    "paralipómenos": "paralipómeno",
    "paralisa": "paralisar",
    "paralisada": "paralisar",
    "paralisadas": "paralisar",
    "paralisado": "paralisar",
    "paralisadora": "paralisador",
    "paralisadoras": "paralisador",
    "paralisadores": "paralisador",
    "paralisados": "paralisar",
    "paralisai": "paralisar",
    "paralisais": "paralisar",
    "paralisam": "paralisar",
    "paralisamo": "paralisar",
    "paralisamos": "paralisar",
    "paralisando": "paralisar",
    "paralisantes": "paralisante",
    "paralisara": "paralisar",
    "paralisaram": "paralisar",
    "paralisaras": "paralisar",
    "paralisarde": "paralisar",
    "paralisardes": "paralisar",
    "paralisare": "paralisar",
    "paralisarei": "paralisar",
    "paralisareis": "paralisar",
    "paralisarem": "paralisar",
    "paralisaremos": "paralisar",
    "paralisares": "paralisar",
    "paralisaria": "paralisar",
    "paralisariam": "paralisar",
    "paralisarias": "paralisar",
    "paralisarmo": "paralisar",
    "paralisarmos": "paralisar",
    "paralisará": "paralisar",
    "paralisarás": "paralisar",
    "paralisarão": "paralisar",
    "paralisaríamos": "paralisar",
    "paralisaríeis": "paralisar",
    "paralisas": "paralisar",
    "paralisasse": "paralisar",
    "paralisassem": "paralisar",
    "paralisasses": "paralisar",
    "paralisaste": "paralisar",
    "paralisastes": "paralisar",
    "paralisava": "paralisar",
    "paralisavam": "paralisar",
    "paralisavas": "paralisar",
    "paralisações": "paralisação",
    "paralise": "paralisar",
    "paralisei": "paralisar",
    "paraliseis": "paralisar",
    "paralisem": "paralisar",
    "paralisemo": "paralisar",
    "paralisemos": "paralisar",
    "paralises": "paralisar",
    "paralisias": "paralisia",
    "paraliso": "paralisar",
    "paralisou": "paralisar",
    "paralisá": "paralisar",
    "paralisámo": "paralisar",
    "paralisámos": "paralisar",
    "paralisáramo": "paralisar",
    "paralisáramos": "paralisar",
    "paralisárei": "paralisar",
    "paralisáreis": "paralisar",
    "paralisásseis": "paralisar",
    "paralisássemos": "paralisar",
    "paralisávamo": "paralisar",
    "paralisávamos": "paralisar",
    "paralisávei": "paralisar",
    "paralisáveis": "paralisável",
    "paralogias": "paralogia",
    "paralogismos": "paralogismo",
    "paraloleítica": "paraloleítico",
    "paraloleíticas": "paraloleítico",
    "paraloleíticos": "paraloleítico",
    "paraltas": "paralta",
    "paraltices": "paraltice",
    "paralálica": "paralálico",
    "paralálicas": "paralálico",
    "paralálicos": "paralálico",
    "paraláxica": "paraláxico",
    "paraláxicas": "paraláxico",
    "paraláxicos": "paraláxico",
    "paraléxica": "paraléxico",
    "paraléxicas": "paraléxico",
    "paraléxicos": "paraléxico",
    "paralíptica": "paralíptico",
    "paralípticas": "paralíptico",
    "paralípticos": "paralíptico",
    "paralítica": "paralítico",
    "paralíticas": "paralítico",
    "paralíticos": "paralítico",
    "paralógica": "paralógico",
    "paralógicas": "paralógico",
    "paralógicos": "paralógico",
    "param": "parir",
    "paramagnetismos": "paramagnetismo",
    "paramagnética": "paramagnético",
    "paramagnéticas": "paramagnético",
    "paramagnéticos": "paramagnético",
    "parambulacrária": "parambulacrário",
    "parambulacrárias": "parambulacrário",
    "parambulacrários": "parambulacrário",
    "paramecídeos": "paramecídeo",
    "paramenta": "paramentar",
    "paramentada": "paramentar",
    "paramentadas": "paramentar",
    "paramentado": "paramentar",
    "paramentados": "paramentar",
    "paramentai": "paramentar",
    "paramentais": "paramentar",
    "paramentam": "paramentar",
    "paramentamo": "paramentar",
    "paramentamos": "paramentar",
    "paramentando": "paramentar",
    "paramentara": "paramentar",
    "paramentaram": "paramentar",
    "paramentaras": "paramentar",
    "paramentarde": "paramentar",
    "paramentardes": "paramentar",
    "paramentare": "paramentar",
    "paramentarei": "paramentar",
    "paramentareis": "paramentar",
    "paramentarem": "paramentar",
    "paramentaremos": "paramentar",
    "paramentares": "paramentar",
    "paramentaria": "paramentar",
    "paramentariam": "paramentar",
    "paramentarias": "paramentar",
    "paramentarmo": "paramentar",
    "paramentarmos": "paramentar",
    "paramentará": "paramentar",
    "paramentarás": "paramentar",
    "paramentarão": "paramentar",
    "paramentaríamos": "paramentar",
    "paramentaríeis": "paramentar",
    "paramentas": "paramentar",
    "paramentasse": "paramentar",
    "paramentassem": "paramentar",
    "paramentasses": "paramentar",
    "paramentaste": "paramentar",
    "paramentastes": "paramentar",
    "paramentava": "paramentar",
    "paramentavam": "paramentar",
    "paramentavas": "paramentar",
    "paramente": "paramentar",
    "paramentei": "paramentar",
    "paramenteira": "paramenteiro",
    "paramenteiras": "paramenteiro",
    "paramenteiros": "paramenteiro",
    "paramenteis": "paramentar",
    "paramentem": "paramentar",
    "paramentemo": "paramentar",
    "paramentemos": "paramentar",
    "paramentes": "paramentar",
    "paramento": "paramentar",
    "paramentos": "paramento",
    "paramentosa": "paramentoso",
    "paramentosas": "paramentoso",
    "paramentosos": "paramentoso",
    "paramentou": "paramentar",
    "paramentá": "paramentar",
    "paramentámo": "paramentar",
    "paramentámos": "paramentar",
    "paramentáramo": "paramentar",
    "paramentáramos": "paramentar",
    "paramentárei": "paramentar",
    "paramentáreis": "paramentar",
    "paramentásseis": "paramentar",
    "paramentássemos": "paramentar",
    "paramentávamo": "paramentar",
    "paramentávamos": "paramentar",
    "paramentávei": "paramentar",
    "paramentáveis": "paramentar",
    "paramilitares": "paramilitar",
    "paramiloidoses": "paramiloidose",
    "paramiloidótica": "paramiloidótico",
    "paramiloidóticas": "paramiloidótico",
    "paramiloidóticos": "paramiloidótico",
    "paramimias": "paramimia",
    "paramnésias": "paramnésia",
    "paramnésica": "paramnésico",
    "paramnésicas": "paramnésico",
    "paramnésicos": "paramnésico",
    "paramo": "parir",
    "paramos": "parir",
    "paramécias": "paramécia",
    "paramécidas": "paramécida",
    "paramédica": "paramédico",
    "paramédicas": "paramédico",
    "paramédicos": "paramédico",
    "paramétrica": "paramétrico",
    "paramétricas": "paramétrico",
    "paramétricos": "paramétrico",
    "paramímica": "paramímico",
    "paramímicas": "paramímico",
    "paramímicos": "paramímico",
    "paranaenses": "paranaense",
    "parando": "parar",
    "paranefrites": "paranefrite",
    "paranefrítica": "paranefrítico",
    "paranefríticas": "paranefrítico",
    "paranefríticos": "paranefrítico",
    "paraneias": "paraneia",
    "paraneica": "paraneico",
    "paraneicas": "paraneico",
    "paraneicos": "paraneico",
    "parangona": "parangonar",
    "parangonada": "parangonar",
    "parangonadas": "parangonar",
    "parangonado": "parangonar",
    "parangonados": "parangonar",
    "parangonai": "parangonar",
    "parangonais": "parangonar",
    "parangonam": "parangonar",
    "parangonamo": "parangonar",
    "parangonamos": "parangonar",
    "parangonando": "parangonar",
    "parangonara": "parangonar",
    "parangonaram": "parangonar",
    "parangonaras": "parangonar",
    "parangonarde": "parangonar",
    "parangonardes": "parangonar",
    "parangonare": "parangonar",
    "parangonarei": "parangonar",
    "parangonareis": "parangonar",
    "parangonarem": "parangonar",
    "parangonaremos": "parangonar",
    "parangonares": "parangonar",
    "parangonaria": "parangonar",
    "parangonariam": "parangonar",
    "parangonarias": "parangonar",
    "parangonarmo": "parangonar",
    "parangonarmos": "parangonar",
    "parangonará": "parangonar",
    "parangonarás": "parangonar",
    "parangonarão": "parangonar",
    "parangonaríamos": "parangonar",
    "parangonaríeis": "parangonar",
    "parangonas": "parangonar",
    "parangonasse": "parangonar",
    "parangonassem": "parangonar",
    "parangonasses": "parangonar",
    "parangonaste": "parangonar",
    "parangonastes": "parangonar",
    "parangonava": "parangonar",
    "parangonavam": "parangonar",
    "parangonavas": "parangonar",
    "parangone": "parangonar",
    "parangonei": "parangonar",
    "parangoneis": "parangonar",
    "parangonem": "parangonar",
    "parangonemo": "parangonar",
    "parangonemos": "parangonar",
    "parangones": "parangonar",
    "parangono": "parangonar",
    "parangonou": "parangonar",
    "parangoná": "parangonar",
    "parangonámo": "parangonar",
    "parangonámos": "parangonar",
    "parangonáramo": "parangonar",
    "parangonáramos": "parangonar",
    "parangonárei": "parangonar",
    "parangonáreis": "parangonar",
    "parangonásseis": "parangonar",
    "parangonássemos": "parangonar",
    "parangonávamo": "parangonar",
    "parangonávamos": "parangonar",
    "parangonávei": "parangonar",
    "parangonáveis": "parangonar",
    "parangónia": "parangónio",
    "parangónias": "parangónio",
    "parangónios": "parangónio",
    "paraninfa": "paraninfar",
    "paraninfada": "paraninfar",
    "paraninfadas": "paraninfar",
    "paraninfado": "paraninfar",
    "paraninfados": "paraninfar",
    "paraninfai": "paraninfar",
    "paraninfais": "paraninfar",
    "paraninfam": "paraninfar",
    "paraninfamo": "paraninfar",
    "paraninfamos": "paraninfar",
    "paraninfando": "paraninfar",
    "paraninfara": "paraninfar",
    "paraninfaram": "paraninfar",
    "paraninfaras": "paraninfar",
    "paraninfarde": "paraninfar",
    "paraninfardes": "paraninfar",
    "paraninfare": "paraninfar",
    "paraninfarei": "paraninfar",
    "paraninfareis": "paraninfar",
    "paraninfarem": "paraninfar",
    "paraninfaremos": "paraninfar",
    "paraninfares": "paraninfar",
    "paraninfaria": "paraninfar",
    "paraninfariam": "paraninfar",
    "paraninfarias": "paraninfar",
    "paraninfarmo": "paraninfar",
    "paraninfarmos": "paraninfar",
    "paraninfará": "paraninfar",
    "paraninfarás": "paraninfar",
    "paraninfarão": "paraninfar",
    "paraninfaríamos": "paraninfar",
    "paraninfaríeis": "paraninfar",
    "paraninfas": "paraninfar",
    "paraninfasse": "paraninfar",
    "paraninfassem": "paraninfar",
    "paraninfasses": "paraninfar",
    "paraninfaste": "paraninfar",
    "paraninfastes": "paraninfar",
    "paraninfava": "paraninfar",
    "paraninfavam": "paraninfar",
    "paraninfavas": "paraninfar",
    "paraninfe": "paraninfar",
    "paraninfei": "paraninfar",
    "paraninfeis": "paraninfar",
    "paraninfem": "paraninfar",
    "paraninfemo": "paraninfar",
    "paraninfemos": "paraninfar",
    "paraninfes": "paraninfar",
    "paraninfo": "paraninfar",
    "paraninfos": "paraninfo",
    "paraninfou": "paraninfar",
    "paraninfá": "paraninfar",
    "paraninfámo": "paraninfar",
    "paraninfámos": "paraninfar",
    "paraninfáramo": "paraninfar",
    "paraninfáramos": "paraninfar",
    "paraninfárei": "paraninfar",
    "paraninfáreis": "paraninfar",
    "paraninfásseis": "paraninfar",
    "paraninfássemos": "paraninfar",
    "paraninfávamo": "paraninfar",
    "paraninfávamos": "paraninfar",
    "paraninfávei": "paraninfar",
    "paraninfáveis": "paraninfar",
    "paranomásias": "paranomásia",
    "paranomásica": "paranomásico",
    "paranomásicas": "paranomásico",
    "paranomásicos": "paranomásico",
    "paranormais": "paranormal",
    "paranças": "parança",
    "paranínfica": "paranínfico",
    "paranínficas": "paranínfico",
    "paranínficos": "paranínfico",
    "paranóias": "paranóia",
    "paranóica": "paranóico",
    "paranóicas": "paranóico",
    "paranóicos": "paranóico",
    "parapeita": "parapeitar",
    "parapeitada": "parapeitar",
    "parapeitadas": "parapeitar",
    "parapeitado": "parapeitar",
    "parapeitados": "parapeitar",
    "parapeitai": "parapeitar",
    "parapeitais": "parapeitar",
    "parapeitam": "parapeitar",
    "parapeitamo": "parapeitar",
    "parapeitamos": "parapeitar",
    "parapeitando": "parapeitar",
    "parapeitara": "parapeitar",
    "parapeitaram": "parapeitar",
    "parapeitaras": "parapeitar",
    "parapeitarde": "parapeitar",
    "parapeitardes": "parapeitar",
    "parapeitare": "parapeitar",
    "parapeitarei": "parapeitar",
    "parapeitareis": "parapeitar",
    "parapeitarem": "parapeitar",
    "parapeitaremos": "parapeitar",
    "parapeitares": "parapeitar",
    "parapeitaria": "parapeitar",
    "parapeitariam": "parapeitar",
    "parapeitarias": "parapeitar",
    "parapeitarmo": "parapeitar",
    "parapeitarmos": "parapeitar",
    "parapeitará": "parapeitar",
    "parapeitarás": "parapeitar",
    "parapeitarão": "parapeitar",
    "parapeitaríamos": "parapeitar",
    "parapeitaríeis": "parapeitar",
    "parapeitas": "parapeitar",
    "parapeitasse": "parapeitar",
    "parapeitassem": "parapeitar",
    "parapeitasses": "parapeitar",
    "parapeitaste": "parapeitar",
    "parapeitastes": "parapeitar",
    "parapeitava": "parapeitar",
    "parapeitavam": "parapeitar",
    "parapeitavas": "parapeitar",
    "parapeite": "parapeitar",
    "parapeitei": "parapeitar",
    "parapeiteis": "parapeitar",
    "parapeitem": "parapeitar",
    "parapeitemo": "parapeitar",
    "parapeitemos": "parapeitar",
    "parapeites": "parapeitar",
    "parapeito": "parapeitar",
    "parapeitos": "parapeito",
    "parapeitou": "parapeitar",
    "parapeitá": "parapeitar",
    "parapeitámo": "parapeitar",
    "parapeitámos": "parapeitar",
    "parapeitáramo": "parapeitar",
    "parapeitáramos": "parapeitar",
    "parapeitárei": "parapeitar",
    "parapeitáreis": "parapeitar",
    "parapeitásseis": "parapeitar",
    "parapeitássemos": "parapeitar",
    "parapeitávamo": "parapeitar",
    "parapeitávamos": "parapeitar",
    "parapeitávei": "parapeitar",
    "parapeitáveis": "parapeitar",
    "paraplasmas": "paraplasma",
    "paraplasmática": "paraplasmático",
    "paraplasmáticas": "paraplasmático",
    "paraplasmáticos": "paraplasmático",
    "paraplegias": "paraplegia",
    "parapleuras": "parapleura",
    "paraplexias": "paraplexia",
    "paraplégica": "paraplégico",
    "paraplégicas": "paraplégico",
    "paraplégicos": "paraplégico",
    "parapléxica": "parapléxico",
    "parapléxicas": "parapléxico",
    "parapléxicos": "parapléxico",
    "parapraxias": "parapraxia",
    "parapráxica": "parapráxico",
    "parapráxicas": "parapráxico",
    "parapráxicos": "parapráxico",
    "parapsicologias": "parapsicologia",
    "parapsicologistas": "parapsicologista",
    "parapsicológica": "parapsicológico",
    "parapsicológicas": "parapsicológico",
    "parapsicológicos": "parapsicológico",
    "parapsicóloga": "parapsicólogo",
    "parapsicólogas": "parapsicólogo",
    "parapsicólogos": "parapsicólogo",
    "paraquedistas": "paraquedista",
    "parara": "parar",
    "pararam": "parar",
    "pararas": "parar",
    "pararde": "parar",
    "parardes": "parar",
    "parare": "parar",
    "pararei": "parar",
    "parareis": "parar",
    "pararem": "parar",
    "pararemos": "parar",
    "parares": "parar",
    "pararia": "parar",
    "parariam": "parar",
    "pararias": "parar",
    "pararmo": "parar",
    "pararmos": "parar",
    "parará": "parar",
    "pararás": "parar",
    "pararão": "parar",
    "pararíamos": "parar",
    "pararíeis": "parar",
    "paras": "parir",
    "parasceves": "parasceve",
    "parasita": "parasito",
    "parasitada": "parasitar",
    "parasitadas": "parasitar",
    "parasitado": "parasitar",
    "parasitados": "parasitar",
    "parasitagens": "parasitagem",
    "parasitai": "parasitar",
    "parasitais": "parasitar",
    "parasitam": "parasitar",
    "parasitamo": "parasitar",
    "parasitamos": "parasitar",
    "parasitando": "parasitar",
    "parasitara": "parasitar",
    "parasitaram": "parasitar",
    "parasitaras": "parasitar",
    "parasitarde": "parasitar",
    "parasitardes": "parasitar",
    "parasitare": "parasitar",
    "parasitarei": "parasitar",
    "parasitareis": "parasitar",
    "parasitarem": "parasitar",
    "parasitaremos": "parasitar",
    "parasitares": "parasitar",
    "parasitaria": "parasitar",
    "parasitariam": "parasitar",
    "parasitarias": "parasitar",
    "parasitarmo": "parasitar",
    "parasitarmos": "parasitar",
    "parasitará": "parasitar",
    "parasitarás": "parasitar",
    "parasitarão": "parasitar",
    "parasitaríamos": "parasitar",
    "parasitaríeis": "parasitar",
    "parasitas": "parasito",
    "parasitasse": "parasitar",
    "parasitassem": "parasitar",
    "parasitasses": "parasitar",
    "parasitaste": "parasitar",
    "parasitastes": "parasitar",
    "parasitava": "parasitar",
    "parasitavam": "parasitar",
    "parasitavas": "parasitar",
    "parasitações": "parasitação",
    "parasite": "parasitar",
    "parasiteada": "parasitear",
    "parasiteadas": "parasitear",
    "parasiteado": "parasitear",
    "parasiteados": "parasitear",
    "parasiteai": "parasitear",
    "parasiteais": "parasitear",
    "parasiteamo": "parasitear",
    "parasiteamos": "parasitear",
    "parasiteando": "parasitear",
    "parasiteara": "parasitear",
    "parasitearam": "parasitear",
    "parasitearas": "parasitear",
    "parasiteardes": "parasitear",
    "parasitearei": "parasitear",
    "parasiteareis": "parasitear",
    "parasitearem": "parasitear",
    "parasitearemos": "parasitear",
    "parasiteares": "parasitear",
    "parasitearia": "parasitear",
    "parasiteariam": "parasitear",
    "parasitearias": "parasitear",
    "parasitearmo": "parasitear",
    "parasitearmos": "parasitear",
    "parasiteará": "parasitear",
    "parasitearás": "parasitear",
    "parasitearão": "parasitear",
    "parasitearíamos": "parasitear",
    "parasitearíeis": "parasitear",
    "parasiteasse": "parasitear",
    "parasiteassem": "parasitear",
    "parasiteasses": "parasitear",
    "parasiteaste": "parasitear",
    "parasiteastes": "parasitear",
    "parasiteava": "parasitear",
    "parasiteavam": "parasitear",
    "parasiteavas": "parasitear",
    "parasiteei": "parasitear",
    "parasiteeis": "parasitear",
    "parasiteemo": "parasitear",
    "parasiteemos": "parasitear",
    "parasitei": "parasitar",
    "parasiteia": "parasitear",
    "parasiteiam": "parasitear",
    "parasiteias": "parasitear",
    "parasiteie": "parasitear",
    "parasiteiem": "parasitear",
    "parasiteies": "parasitear",
    "parasiteio": "parasitear",
    "parasiteis": "parasitar",
    "parasitem": "parasitar",
    "parasitemo": "parasitar",
    "parasitemos": "parasitar",
    "parasiteou": "parasitear",
    "parasites": "parasitar",
    "parasiteámo": "parasitear",
    "parasiteámos": "parasitear",
    "parasiteáramo": "parasitear",
    "parasiteáramos": "parasitear",
    "parasiteáreis": "parasitear",
    "parasiteásseis": "parasitear",
    "parasiteássemos": "parasitear",
    "parasiteávamo": "parasitear",
    "parasiteávamos": "parasitear",
    "parasiteáveis": "parasitear",
    "parasiticidas": "parasiticida",
    "parasitismos": "parasitismo",
    "parasito": "parasitar",
    "parasitologias": "parasitologia",
    "parasitologistas": "parasitologista",
    "parasitológica": "parasitológico",
    "parasitológicas": "parasitológico",
    "parasitológicos": "parasitológico",
    "parasitos": "parasito",
    "parasitou": "parasitar",
    "parasitá": "parasitar",
    "parasitámo": "parasitar",
    "parasitámos": "parasitar",
    "parasitáramo": "parasitar",
    "parasitáramos": "parasitar",
    "parasitárei": "parasitar",
    "parasitáreis": "parasitar",
    "parasitária": "parasitário",
    "parasitárias": "parasitário",
    "parasitários": "parasitário",
    "parasitásseis": "parasitar",
    "parasitássemos": "parasitar",
    "parasitávamo": "parasitar",
    "parasitávamos": "parasitar",
    "parasitávei": "parasitar",
    "parasitáveis": "parasitar",
    "parasitífera": "parasitífero",
    "parasitíferas": "parasitífero",
    "parasitíferos": "parasitífero",
    "parasitóloga": "parasitólogo",
    "parasitólogas": "parasitólogo",
    "parasitólogos": "parasitólogo",
    "parasse": "parar",
    "parasselénios": "parasselénio",
    "parassem": "parar",
    "parasses": "parar",
    "parassifilítica": "parassifilítico",
    "parassifilíticas": "parassifilítico",
    "parassifilíticos": "parassifilítico",
    "parassigmatismos": "parassigmatismo",
    "parassigmática": "parassigmático",
    "parassigmáticas": "parassigmático",
    "parassigmáticos": "parassigmático",
    "parassimpaticotonias": "parassimpaticotonia",
    "parassimpaticotónica": "parassimpaticotónico",
    "parassimpaticotónicas": "parassimpaticotónico",
    "parassimpaticotónicos": "parassimpaticotónico",
    "parassimpática": "parassimpático",
    "parassimpáticas": "parassimpático",
    "parassimpáticos": "parassimpático",
    "parassintética": "parassintético",
    "parassintéticas": "parassintético",
    "parassintéticos": "parassintético",
    "parassínteses": "parassíntese",
    "paraste": "parar",
    "parastes": "parar",
    "parastáticas": "parastática",
    "parasítica": "parasítico",
    "parasíticas": "parasítico",
    "parasíticos": "parasítico",
    "parataxes": "parataxe",
    "paratifos": "paratifo",
    "paratifóides": "paratifóide",
    "paratireoideia": "paratireoideu",
    "paratireoideias": "paratireoideu",
    "paratireoideus": "paratireoideu",
    "paratireoidiana": "paratireoidiano",
    "paratireoidianas": "paratireoidiano",
    "paratireoidianos": "paratireoidiano",
    "paratireóidea": "paratireóideo",
    "paratireóideas": "paratireóideo",
    "paratireóideos": "paratireóideo",
    "paratireóides": "paratireóide",
    "paratiroideia": "paratiroideu",
    "paratiroideias": "paratiroideu",
    "paratiroideus": "paratiroideu",
    "paratiroidiana": "paratiroidiano",
    "paratiroidianas": "paratiroidiano",
    "paratiroidianos": "paratiroidiano",
    "paratiróides": "paratiróide",
    "paratis": "parati",
    "paratitlos": "paratitlo",
    "paratitlários": "paratitlário",
    "paratáctica": "paratáctico",
    "paratácticas": "paratáctico",
    "paratácticos": "paratáctico",
    "paratífica": "paratífico",
    "paratíficas": "paratífico",
    "paratíficos": "paratífico",
    "paratípica": "paratípico",
    "paratípicas": "paratípico",
    "paratípicos": "paratípico",
    "paraus": "parau",
    "parava": "parar",
    "paravam": "parar",
    "paravantes": "paravante",
    "paravas": "parar",
    "paraxiais": "paraxial",
    "paraísos": "paraíso",
    "parca": "parco",
    "parcas": "parco",
    "parceira": "parceiro",
    "parceiras": "parceiro",
    "parceiros": "parceiro",
    "parcela": "parcelar",
    "parcelada": "parcelar",
    "parceladas": "parcelar",
    "parcelado": "parcelar",
    "parcelados": "parcelar",
    "parcelai": "parcelar",
    "parcelais": "parcelar",
    "parcelam": "parcelar",
    "parcelamentos": "parcelamento",
    "parcelamo": "parcelar",
    "parcelamos": "parcelar",
    "parcelando": "parcelar",
    "parcelara": "parcelar",
    "parcelaram": "parcelar",
    "parcelaras": "parcelar",
    "parcelarde": "parcelar",
    "parcelardes": "parcelar",
    "parcelare": "parcelar",
    "parcelarei": "parcelar",
    "parcelareis": "parcelar",
    "parcelarem": "parcelar",
    "parcelaremos": "parcelar",
    "parcelares": "parcelar",
    "parcelaria": "parcelar",
    "parcelariam": "parcelar",
    "parcelarias": "parcelar",
    "parcelarmo": "parcelar",
    "parcelarmos": "parcelar",
    "parcelará": "parcelar",
    "parcelarás": "parcelar",
    "parcelarão": "parcelar",
    "parcelaríamos": "parcelar",
    "parcelaríeis": "parcelar",
    "parcelas": "parcelar",
    "parcelasse": "parcelar",
    "parcelassem": "parcelar",
    "parcelasses": "parcelar",
    "parcelaste": "parcelar",
    "parcelastes": "parcelar",
    "parcelava": "parcelar",
    "parcelavam": "parcelar",
    "parcelavas": "parcelar",
    "parcele": "parcelar",
    "parcelei": "parcelar",
    "parceleis": "parcelar",
    "parcelem": "parcelar",
    "parcelemo": "parcelar",
    "parcelemos": "parcelar",
    "parceles": "parcelar",
    "parcelo": "parcelar",
    "parcelou": "parcelar",
    "parcelá": "parcelar",
    "parcelámo": "parcelar",
    "parcelámos": "parcelar",
    "parceláramo": "parcelar",
    "parceláramos": "parcelar",
    "parcelárei": "parcelar",
    "parceláreis": "parcelar",
    "parcelária": "parcelário",
    "parcelárias": "parcelário",
    "parcelários": "parcelário",
    "parcelásseis": "parcelar",
    "parcelássemos": "parcelar",
    "parcelávamo": "parcelar",
    "parcelávamos": "parcelar",
    "parcelávei": "parcelar",
    "parceláveis": "parcelar",
    "parcerias": "parceria",
    "parchas": "parcha",
    "parcheada": "parchear",
    "parcheadas": "parchear",
    "parcheado": "parchear",
    "parcheados": "parchear",
    "parcheai": "parchear",
    "parcheais": "parchear",
    "parcheamo": "parchear",
    "parcheamos": "parchear",
    "parcheando": "parchear",
    "parcheara": "parchear",
    "parchearam": "parchear",
    "parchearas": "parchear",
    "parchearde": "parchear",
    "parcheardes": "parchear",
    "parcheare": "parchear",
    "parchearei": "parchear",
    "parcheareis": "parchear",
    "parchearem": "parchear",
    "parchearemos": "parchear",
    "parcheares": "parchear",
    "parchearia": "parchear",
    "parcheariam": "parchear",
    "parchearias": "parchear",
    "parchearmo": "parchear",
    "parchearmos": "parchear",
    "parcheará": "parchear",
    "parchearás": "parchear",
    "parchearão": "parchear",
    "parchearíamos": "parchear",
    "parchearíeis": "parchear",
    "parcheasse": "parchear",
    "parcheassem": "parchear",
    "parcheasses": "parchear",
    "parcheaste": "parchear",
    "parcheastes": "parchear",
    "parcheava": "parchear",
    "parcheavam": "parchear",
    "parcheavas": "parchear",
    "parcheei": "parchear",
    "parcheeis": "parchear",
    "parcheemo": "parchear",
    "parcheemos": "parchear",
    "parcheia": "parchear",
    "parcheiam": "parchear",
    "parcheias": "parchear",
    "parcheie": "parchear",
    "parcheiem": "parchear",
    "parcheies": "parchear",
    "parcheio": "parchear",
    "parcheou": "parchear",
    "parches": "parche",
    "parcheá": "parchear",
    "parcheámo": "parchear",
    "parcheámos": "parchear",
    "parcheáramo": "parchear",
    "parcheáramos": "parchear",
    "parcheárei": "parchear",
    "parcheáreis": "parchear",
    "parcheásseis": "parchear",
    "parcheássemos": "parchear",
    "parcheávamo": "parchear",
    "parcheávamos": "parchear",
    "parcheávei": "parchear",
    "parcheáveis": "parchear",
    "parciais": "parcial",
    "parcialidades": "parcialidade",
    "parcialistas": "parcialista",
    "parcializa": "parcializar",
    "parcializada": "parcializar",
    "parcializadas": "parcializar",
    "parcializado": "parcializar",
    "parcializados": "parcializar",
    "parcializai": "parcializar",
    "parcializais": "parcializar",
    "parcializam": "parcializar",
    "parcializamo": "parcializar",
    "parcializamos": "parcializar",
    "parcializando": "parcializar",
    "parcializara": "parcializar",
    "parcializaram": "parcializar",
    "parcializaras": "parcializar",
    "parcializarde": "parcializar",
    "parcializardes": "parcializar",
    "parcializare": "parcializar",
    "parcializarei": "parcializar",
    "parcializareis": "parcializar",
    "parcializarem": "parcializar",
    "parcializaremos": "parcializar",
    "parcializares": "parcializar",
    "parcializaria": "parcializar",
    "parcializariam": "parcializar",
    "parcializarias": "parcializar",
    "parcializarmo": "parcializar",
    "parcializarmos": "parcializar",
    "parcializará": "parcializar",
    "parcializarás": "parcializar",
    "parcializarão": "parcializar",
    "parcializaríamos": "parcializar",
    "parcializaríeis": "parcializar",
    "parcializas": "parcializar",
    "parcializasse": "parcializar",
    "parcializassem": "parcializar",
    "parcializasses": "parcializar",
    "parcializaste": "parcializar",
    "parcializastes": "parcializar",
    "parcializava": "parcializar",
    "parcializavam": "parcializar",
    "parcializavas": "parcializar",
    "parcializações": "parcialização",
    "parcialize": "parcializar",
    "parcializei": "parcializar",
    "parcializeis": "parcializar",
    "parcializem": "parcializar",
    "parcializemo": "parcializar",
    "parcializemos": "parcializar",
    "parcializes": "parcializar",
    "parcializo": "parcializar",
    "parcializou": "parcializar",
    "parcializá": "parcializar",
    "parcializámo": "parcializar",
    "parcializámos": "parcializar",
    "parcializáramo": "parcializar",
    "parcializáramos": "parcializar",
    "parcializárei": "parcializar",
    "parcializáreis": "parcializar",
    "parcializásseis": "parcializar",
    "parcializássemos": "parcializar",
    "parcializávamo": "parcializar",
    "parcializávamos": "parcializar",
    "parcializávei": "parcializar",
    "parcializáveis": "parcializar",
    "parcialíssima": "parcial",
    "parcialíssimas": "parcial",
    "parcialíssimo": "parcial",
    "parcialíssimos": "parcial",
    "parcimoniosa": "parcimonioso",
    "parcimoniosas": "parcimonioso",
    "parcimoniosos": "parcimonioso",
    "parcimoniosíssima": "parcimonioso",
    "parcimoniosíssimas": "parcimonioso",
    "parcimoniosíssimo": "parcimonioso",
    "parcimoniosíssimos": "parcimonioso",
    "parcimónias": "parcimónia",
    "parciária": "parciário",
    "parciárias": "parciário",
    "parciários": "parciário",
    "parcos": "parco",
    "parcéis": "parcel",
    "parcíssima": "parco",
    "parcíssimas": "parco",
    "parcíssimo": "parco",
    "parcíssimos": "parco",
    "parcómetros": "parcómetro",
    "parda": "pardo",
    "pardacenta": "pardacento",
    "pardacentas": "pardacento",
    "pardacentos": "pardacento",
    "pardais": "pardal",
    "pardala": "pardal",
    "pardaladas": "pardalada",
    "pardalas": "pardal",
    "pardaleja": "pardalejo",
    "pardalejas": "pardalejo",
    "pardalejos": "pardalejo",
    "pardalocas": "pardaloca",
    "pardalona": "pardalão",
    "pardalonas": "pardalão",
    "pardalões": "pardalão",
    "pardas": "pardo",
    "pardaus": "pardau",
    "pardavasca": "pardavasco",
    "pardavascas": "pardavasco",
    "pardavascos": "pardavasco",
    "pardazinha": "pardo",
    "pardazinhas": "pardo",
    "pardazita": "pardo",
    "pardazitas": "pardo",
    "pardeja": "pardejo",
    "pardejas": "pardejo",
    "pardejos": "pardejo",
    "pardelas": "pardela",
    "pardelhas": "pardelha",
    "pardieiros": "pardieiro",
    "pardilha": "pardilho",
    "pardilhas": "pardilho",
    "pardilheiras": "pardilheira",
    "pardilhos": "pardilho",
    "pardilhões": "pardilhão",
    "pardinha": "pardo",
    "pardinhas": "pardo",
    "pardinho": "pardo",
    "pardinhos": "pardo",
    "pardita": "pardo",
    "parditas": "pardo",
    "pardito": "pardo",
    "parditos": "pardo",
    "pardoca": "pardoco",
    "pardocas": "pardoco",
    "pardocos": "pardoco",
    "pardos": "pardo",
    "pardozinho": "pardo",
    "pardozinhos": "pardo",
    "pardozito": "pardo",
    "pardozitos": "pardo",
    "pardusca": "pardusco",
    "parduscas": "pardusco",
    "parduscos": "pardusco",
    "pare": "parir",
    "pareada": "parear",
    "pareadas": "parear",
    "pareado": "parear",
    "pareados": "parear",
    "pareai": "parear",
    "pareais": "parear",
    "pareamo": "parear",
    "pareamos": "parear",
    "pareando": "parear",
    "pareara": "parear",
    "parearam": "parear",
    "parearas": "parear",
    "parearde": "parear",
    "pareardes": "parear",
    "pareare": "parear",
    "parearei": "parear",
    "pareareis": "parear",
    "parearem": "parear",
    "parearemos": "parear",
    "pareares": "parear",
    "parearia": "parear",
    "pareariam": "parear",
    "parearias": "parear",
    "parearmo": "parear",
    "parearmos": "parear",
    "pareará": "parear",
    "parearás": "parear",
    "parearão": "parear",
    "parearíamos": "parear",
    "parearíeis": "parear",
    "pareasse": "parear",
    "pareassem": "parear",
    "pareasses": "parear",
    "pareaste": "parear",
    "pareastes": "parear",
    "pareava": "parear",
    "pareavam": "parear",
    "pareavas": "parear",
    "parece": "parecer",
    "parecei": "parecer",
    "pareceis": "parecer",
    "parecem": "parecer",
    "parecemo": "parecer",
    "parecemos": "parecer",
    "parecendo": "parecer",
    "parecentes": "parecente",
    "parecenças": "parecença",
    "parecera": "parecer",
    "pareceram": "parecer",
    "pareceras": "parecer",
    "parecerde": "parecer",
    "parecerdes": "parecer",
    "parecere": "parecer",
    "parecerei": "parecer",
    "parecereis": "parecer",
    "parecerem": "parecer",
    "pareceremos": "parecer",
    "pareceres": "parecer",
    "pareceria": "parecer",
    "pareceriam": "parecer",
    "parecerias": "parecer",
    "parecermo": "parecer",
    "parecermos": "parecer",
    "parecerá": "parecer",
    "parecerás": "parecer",
    "parecerão": "parecer",
    "pareceríamos": "parecer",
    "pareceríeis": "parecer",
    "pareces": "parecer",
    "parecesse": "parecer",
    "parecessem": "parecer",
    "parecesses": "parecer",
    "pareceste": "parecer",
    "parecestes": "parecer",
    "pareceu": "parecer",
    "pareci": "parecer",
    "parecia": "parecer",
    "pareciam": "parecer",
    "parecias": "parecer",
    "parecida": "parecido",
    "parecidas": "parecido",
    "parecido": "parecer",
    "parecidos": "parecido",
    "parecidíssima": "parecido",
    "parecidíssimas": "parecido",
    "parecidíssimo": "parecido",
    "parecidíssimos": "parecido",
    "parectásica": "parectásico",
    "parectásicas": "parectásico",
    "parectásicos": "parectásico",
    "parecê": "parecer",
    "parecêramo": "parecer",
    "parecêramos": "parecer",
    "parecêrei": "parecer",
    "parecêreis": "parecer",
    "parecêsseis": "parecer",
    "parecêssemos": "parecer",
    "parecíamo": "parecer",
    "parecíamos": "parecer",
    "parecíei": "parecer",
    "parecíeis": "parecer",
    "paredeira": "paredeiro",
    "paredeiras": "paredeiro",
    "paredeiros": "paredeiro",
    "paredes": "parede",
    "paredistas": "paredista",
    "paredra": "paredro",
    "paredras": "paredro",
    "paredros": "paredro",
    "paredões": "paredão",
    "pareei": "parear",
    "pareeis": "parear",
    "pareemo": "parear",
    "pareemos": "parear",
    "paregórica": "paregórico",
    "paregóricas": "paregórico",
    "paregóricos": "paregórico",
    "parei": "parar",
    "pareia": "parear",
    "pareiam": "parear",
    "pareias": "pareia",
    "pareie": "parear",
    "pareiem": "parear",
    "pareies": "parear",
    "pareio": "parear",
    "pareis": "parar",
    "parelha": "parelho",
    "parelhas": "parelho",
    "parelhos": "parelho",
    "parem": "parir",
    "paremiologias": "paremiologia",
    "paremiológica": "paremiológico",
    "paremiológicas": "paremiológico",
    "paremiológicos": "paremiológico",
    "paremo": "parar",
    "paremos": "parar",
    "parenquimatosa": "parenquimatoso",
    "parenquimatosas": "parenquimatoso",
    "parenquimatosos": "parenquimatoso",
    "parenquimática": "parenquimático",
    "parenquimáticas": "parenquimático",
    "parenquimáticos": "parenquimático",
    "parentais": "parental",
    "parentalhas": "parentalha",
    "parentas": "parenta",
    "parenteada": "parentear",
    "parenteadas": "parentear",
    "parenteado": "parentear",
    "parenteados": "parentear",
    "parenteai": "parentear",
    "parenteais": "parentear",
    "parenteamo": "parentear",
    "parenteamos": "parentear",
    "parenteando": "parentear",
    "parenteara": "parentear",
    "parentearam": "parentear",
    "parentearas": "parentear",
    "parenteardes": "parentear",
    "parentearei": "parentear",
    "parenteareis": "parentear",
    "parentearem": "parentear",
    "parentearemos": "parentear",
    "parenteares": "parentear",
    "parentearia": "parentear",
    "parenteariam": "parentear",
    "parentearias": "parentear",
    "parentearmo": "parentear",
    "parentearmos": "parentear",
    "parenteará": "parentear",
    "parentearás": "parentear",
    "parentearão": "parentear",
    "parentearíamos": "parentear",
    "parentearíeis": "parentear",
    "parenteasse": "parentear",
    "parenteassem": "parentear",
    "parenteasses": "parentear",
    "parenteaste": "parentear",
    "parenteastes": "parentear",
    "parenteava": "parentear",
    "parenteavam": "parentear",
    "parenteavas": "parentear",
    "parenteei": "parentear",
    "parenteeis": "parentear",
    "parenteemo": "parentear",
    "parenteemos": "parentear",
    "parenteia": "parentear",
    "parenteiam": "parentear",
    "parenteias": "parentear",
    "parenteie": "parentear",
    "parenteiem": "parentear",
    "parenteies": "parentear",
    "parenteio": "parentear",
    "parentelas": "parentela",
    "parenteou": "parentear",
    "parenterais": "parenteral",
    "parentes": "parente",
    "parentescos": "parentesco",
    "parentezinha": "parente",
    "parentezinhas": "parente",
    "parentezinho": "parente",
    "parentezinhos": "parente",
    "parentezita": "parente",
    "parentezitas": "parente",
    "parentezito": "parente",
    "parentezitos": "parente",
    "parenteámo": "parentear",
    "parenteámos": "parentear",
    "parenteáramo": "parentear",
    "parenteáramos": "parentear",
    "parenteáreis": "parentear",
    "parenteásseis": "parentear",
    "parenteássemos": "parentear",
    "parenteávamo": "parentear",
    "parenteávamos": "parentear",
    "parenteáveis": "parentear",
    "parentérica": "parentérico",
    "parentéricas": "parentérico",
    "parentéricos": "parentérico",
    "parentética": "parentético",
    "parentéticas": "parentético",
    "parentéticos": "parentético",
    "parenésica": "parenésico",
    "parenésicas": "parenésico",
    "parenésicos": "parenésico",
    "parenética": "parenético",
    "parenéticas": "parenético",
    "parenéticos": "parenético",
    "pareou": "parear",
    "parequemas": "parequema",
    "pares": "parir",
    "paresia": "paresiar",
    "paresiada": "paresiar",
    "paresiadas": "paresiar",
    "paresiado": "paresiar",
    "paresiados": "paresiar",
    "paresiai": "paresiar",
    "paresiais": "paresiar",
    "paresiam": "paresiar",
    "paresiamo": "paresiar",
    "paresiamos": "paresiar",
    "paresiando": "paresiar",
    "paresiara": "paresiar",
    "paresiaram": "paresiar",
    "paresiaras": "paresiar",
    "paresiarde": "paresiar",
    "paresiardes": "paresiar",
    "paresiare": "paresiar",
    "paresiarei": "paresiar",
    "paresiareis": "paresiar",
    "paresiarem": "paresiar",
    "paresiaremos": "paresiar",
    "paresiares": "paresiar",
    "paresiaria": "paresiar",
    "paresiariam": "paresiar",
    "paresiarias": "paresiar",
    "paresiarmo": "paresiar",
    "paresiarmos": "paresiar",
    "paresiará": "paresiar",
    "paresiarás": "paresiar",
    "paresiarão": "paresiar",
    "paresiaríamos": "paresiar",
    "paresiaríeis": "paresiar",
    "paresias": "paresiar",
    "paresiasse": "paresiar",
    "paresiassem": "paresiar",
    "paresiasses": "paresiar",
    "paresiaste": "paresiar",
    "paresiastes": "paresiar",
    "paresiava": "paresiar",
    "paresiavam": "paresiar",
    "paresiavas": "paresiar",
    "paresiações": "paresiação",
    "paresie": "paresiar",
    "paresiei": "paresiar",
    "paresieis": "paresiar",
    "paresiem": "paresiar",
    "paresiemo": "paresiar",
    "paresiemos": "paresiar",
    "paresies": "paresiar",
    "paresio": "paresiar",
    "paresiou": "paresiar",
    "paresiá": "paresiar",
    "paresiámo": "paresiar",
    "paresiámos": "paresiar",
    "paresiáramo": "paresiar",
    "paresiáramos": "paresiar",
    "paresiárei": "paresiar",
    "paresiáreis": "paresiar",
    "paresiásseis": "paresiar",
    "paresiássemos": "paresiar",
    "paresiávamo": "paresiar",
    "paresiávamos": "paresiar",
    "paresiávei": "paresiar",
    "paresiáveis": "paresiar",
    "parestesias": "parestesia",
    "parestésica": "parestésico",
    "parestésicas": "parestésico",
    "parestésicos": "parestésico",
    "pareá": "parear",
    "pareámo": "parear",
    "pareámos": "parear",
    "pareáramo": "parear",
    "pareáramos": "parear",
    "pareárei": "parear",
    "pareáreis": "parear",
    "pareásseis": "parear",
    "pareássemos": "parear",
    "pareávamo": "parear",
    "pareávamos": "parear",
    "pareávei": "parear",
    "pareáveis": "parear",
    "pareça": "parecer",
    "pareçais": "parecer",
    "pareçam": "parecer",
    "pareçamo": "parecer",
    "pareçamos": "parecer",
    "pareças": "parecer",
    "pareço": "parecer",
    "pargas": "parga",
    "pargasites": "pargasite",
    "pargatas": "pargata",
    "pargos": "pargo",
    "parguetes": "parguete",
    "pari": "parir",
    "paria": "parir",
    "pariam": "parir",
    "pariambos": "pariambo",
    "parias": "parir",
    "pariatos": "pariato",
    "parida": "parir",
    "paridades": "paridade",
    "paridas": "parir",
    "parideiras": "parideira",
    "paridelas": "paridela",
    "parido": "parir",
    "paridos": "parir",
    "paridrogénica": "paridrogénico",
    "paridrogénicas": "paridrogénico",
    "paridrogénicos": "paridrogénico",
    "paridrogénios": "paridrogénio",
    "pariduras": "paridura",
    "parietais": "parietal",
    "parietinas": "parietina",
    "parietária": "parietário",
    "parietárias": "parietário",
    "parietários": "parietário",
    "pariformes": "pariforme",
    "parilidades": "parilidade",
    "parimo": "parir",
    "parimos": "parir",
    "parindo": "parir",
    "paripinulada": "paripinulado",
    "paripinuladas": "paripinulado",
    "paripinulados": "paripinulado",
    "parira": "parir",
    "pariram": "parir",
    "pariras": "parir",
    "parirde": "parir",
    "parirdes": "parir",
    "parire": "parir",
    "parirei": "parir",
    "parireis": "parir",
    "parirem": "parir",
    "pariremos": "parir",
    "parires": "parir",
    "pariria": "parir",
    "paririam": "parir",
    "paririas": "parir",
    "parirmo": "parir",
    "parirmos": "parir",
    "parirá": "parir",
    "parirás": "parir",
    "parirão": "parir",
    "pariríamos": "parir",
    "pariríeis": "parir",
    "paris": "parir",
    "parisienses": "parisiense",
    "parisse": "parir",
    "parissem": "parir",
    "parisses": "parir",
    "parissílaba": "parissílabo",
    "parissílabas": "parissílabo",
    "parissílabos": "parissílabo",
    "pariste": "parir",
    "paristes": "parir",
    "paritária": "paritário",
    "paritárias": "paritário",
    "paritários": "paritário",
    "pariu": "parir",
    "pariás": "pariá",
    "parições": "parição",
    "parkinsoniana": "parkinsoniano",
    "parkinsonianas": "parkinsoniano",
    "parkinsonianos": "parkinsoniano",
    "parkinsonismos": "parkinsonismo",
    "parla": "parlar",
    "parlada": "parlar",
    "parladas": "parlar",
    "parlado": "parlar",
    "parlados": "parlar",
    "parlai": "parlar",
    "parlais": "parlar",
    "parlam": "parlar",
    "parlamenta": "parlamentar",
    "parlamentada": "parlamentar",
    "parlamentadas": "parlamentar",
    "parlamentado": "parlamentar",
    "parlamentados": "parlamentar",
    "parlamentai": "parlamentar",
    "parlamentais": "parlamentar",
    "parlamentam": "parlamentar",
    "parlamentamo": "parlamentar",
    "parlamentamos": "parlamentar",
    "parlamentando": "parlamentar",
    "parlamentara": "parlamentar",
    "parlamentaram": "parlamentar",
    "parlamentaras": "parlamentar",
    "parlamentarde": "parlamentar",
    "parlamentardes": "parlamentar",
    "parlamentare": "parlamentar",
    "parlamentarei": "parlamentar",
    "parlamentareis": "parlamentar",
    "parlamentarem": "parlamentar",
    "parlamentaremos": "parlamentar",
    "parlamentares": "parlamentar",
    "parlamentaria": "parlamentar",
    "parlamentariam": "parlamentar",
    "parlamentarias": "parlamentar",
    "parlamentarismos": "parlamentarismo",
    "parlamentaristas": "parlamentarista",
    "parlamentarmo": "parlamentar",
    "parlamentarmos": "parlamentar",
    "parlamentará": "parlamentar",
    "parlamentarás": "parlamentar",
    "parlamentarão": "parlamentar",
    "parlamentaríamos": "parlamentar",
    "parlamentaríeis": "parlamentar",
    "parlamentas": "parlamentar",
    "parlamentasse": "parlamentar",
    "parlamentassem": "parlamentar",
    "parlamentasses": "parlamentar",
    "parlamentaste": "parlamentar",
    "parlamentastes": "parlamentar",
    "parlamentava": "parlamentar",
    "parlamentavam": "parlamentar",
    "parlamentavas": "parlamentar",
    "parlamentações": "parlamentação",
    "parlamente": "parlamentar",
    "parlamenteada": "parlamentear",
    "parlamenteadas": "parlamentear",
    "parlamenteado": "parlamentear",
    "parlamenteados": "parlamentear",
    "parlamenteai": "parlamentear",
    "parlamenteais": "parlamentear",
    "parlamenteamo": "parlamentear",
    "parlamenteamos": "parlamentear",
    "parlamenteando": "parlamentear",
    "parlamenteara": "parlamentear",
    "parlamentearam": "parlamentear",
    "parlamentearas": "parlamentear",
    "parlamentearde": "parlamentear",
    "parlamenteardes": "parlamentear",
    "parlamenteare": "parlamentear",
    "parlamentearei": "parlamentear",
    "parlamenteareis": "parlamentear",
    "parlamentearem": "parlamentear",
    "parlamentearemos": "parlamentear",
    "parlamenteares": "parlamentear",
    "parlamentearia": "parlamentear",
    "parlamenteariam": "parlamentear",
    "parlamentearias": "parlamentear",
    "parlamentearmo": "parlamentear",
    "parlamentearmos": "parlamentear",
    "parlamenteará": "parlamentear",
    "parlamentearás": "parlamentear",
    "parlamentearão": "parlamentear",
    "parlamentearíamos": "parlamentear",
    "parlamentearíeis": "parlamentear",
    "parlamenteasse": "parlamentear",
    "parlamenteassem": "parlamentear",
    "parlamenteasses": "parlamentear",
    "parlamenteaste": "parlamentear",
    "parlamenteastes": "parlamentear",
    "parlamenteava": "parlamentear",
    "parlamenteavam": "parlamentear",
    "parlamenteavas": "parlamentear",
    "parlamenteei": "parlamentear",
    "parlamenteeis": "parlamentear",
    "parlamenteemo": "parlamentear",
    "parlamenteemos": "parlamentear",
    "parlamentei": "parlamentar",
    "parlamenteia": "parlamentear",
    "parlamenteiam": "parlamentear",
    "parlamenteias": "parlamentear",
    "parlamenteie": "parlamentear",
    "parlamenteiem": "parlamentear",
    "parlamenteies": "parlamentear",
    "parlamenteio": "parlamentear",
    "parlamenteis": "parlamentar",
    "parlamentem": "parlamentar",
    "parlamentemo": "parlamentar",
    "parlamentemos": "parlamentar",
    "parlamenteou": "parlamentear",
    "parlamentes": "parlamentar",
    "parlamenteá": "parlamentear",
    "parlamenteámo": "parlamentear",
    "parlamenteámos": "parlamentear",
    "parlamenteáramo": "parlamentear",
    "parlamenteáramos": "parlamentear",
    "parlamenteárei": "parlamentear",
    "parlamenteáreis": "parlamentear",
    "parlamenteásseis": "parlamentear",
    "parlamenteássemos": "parlamentear",
    "parlamenteávamo": "parlamentear",
    "parlamenteávamos": "parlamentear",
    "parlamenteávei": "parlamentear",
    "parlamenteáveis": "parlamentear",
    "parlamento": "parlamentar",
    "parlamentos": "parlamento",
    "parlamentou": "parlamentar",
    "parlamentá": "parlamentar",
    "parlamentámo": "parlamentar",
    "parlamentámos": "parlamentar",
    "parlamentáramo": "parlamentar",
    "parlamentáramos": "parlamentar",
    "parlamentárei": "parlamentar",
    "parlamentáreis": "parlamentar",
    "parlamentária": "parlamentário",
    "parlamentárias": "parlamentário",
    "parlamentários": "parlamentário",
    "parlamentásseis": "parlamentar",
    "parlamentássemos": "parlamentar",
    "parlamentávamo": "parlamentar",
    "parlamentávamos": "parlamentar",
    "parlamentávei": "parlamentar",
    "parlamentáveis": "parlamentar",
    "parlamo": "parlar",
    "parlamos": "parlar",
    "parlandas": "parlanda",
    "parlando": "parlar",
    "parlapateada": "parlapatear",
    "parlapateadas": "parlapatear",
    "parlapateado": "parlapatear",
    "parlapateados": "parlapatear",
    "parlapateai": "parlapatear",
    "parlapateais": "parlapatear",
    "parlapateamo": "parlapatear",
    "parlapateamos": "parlapatear",
    "parlapateando": "parlapatear",
    "parlapateara": "parlapatear",
    "parlapatearam": "parlapatear",
    "parlapatearas": "parlapatear",
    "parlapatearde": "parlapatear",
    "parlapateardes": "parlapatear",
    "parlapateare": "parlapatear",
    "parlapatearei": "parlapatear",
    "parlapateareis": "parlapatear",
    "parlapatearem": "parlapatear",
    "parlapatearemos": "parlapatear",
    "parlapateares": "parlapatear",
    "parlapatearia": "parlapatear",
    "parlapateariam": "parlapatear",
    "parlapatearias": "parlapatear",
    "parlapatearmo": "parlapatear",
    "parlapatearmos": "parlapatear",
    "parlapateará": "parlapatear",
    "parlapatearás": "parlapatear",
    "parlapatearão": "parlapatear",
    "parlapatearíamos": "parlapatear",
    "parlapatearíeis": "parlapatear",
    "parlapateasse": "parlapatear",
    "parlapateassem": "parlapatear",
    "parlapateasses": "parlapatear",
    "parlapateaste": "parlapatear",
    "parlapateastes": "parlapatear",
    "parlapateava": "parlapatear",
    "parlapateavam": "parlapatear",
    "parlapateavas": "parlapatear",
    "parlapateei": "parlapatear",
    "parlapateeis": "parlapatear",
    "parlapateemo": "parlapatear",
    "parlapateemos": "parlapatear",
    "parlapateia": "parlapatear",
    "parlapateiam": "parlapatear",
    "parlapateias": "parlapatear",
    "parlapateie": "parlapatear",
    "parlapateiem": "parlapatear",
    "parlapateies": "parlapatear",
    "parlapateio": "parlapatear",
    "parlapateou": "parlapatear",
    "parlapateá": "parlapatear",
    "parlapateámo": "parlapatear",
    "parlapateámos": "parlapatear",
    "parlapateáramo": "parlapatear",
    "parlapateáramos": "parlapatear",
    "parlapateárei": "parlapatear",
    "parlapateáreis": "parlapatear",
    "parlapateásseis": "parlapatear",
    "parlapateássemos": "parlapatear",
    "parlapateávamo": "parlapatear",
    "parlapateávamos": "parlapatear",
    "parlapateávei": "parlapatear",
    "parlapateáveis": "parlapatear",
    "parlapatices": "parlapatice",
    "parlapatona": "parlapatão",
    "parlapatonas": "parlapatão",
    "parlapatórios": "parlapatório",
    "parlapatões": "parlapatão",
    "parlara": "parlar",
    "parlaram": "parlar",
    "parlaras": "parlar",
    "parlardes": "parlar",
    "parlarei": "parlar",
    "parlareis": "parlar",
    "parlarem": "parlar",
    "parlaremos": "parlar",
    "parlares": "parlar",
    "parlaria": "parlar",
    "parlariam": "parlar",
    "parlarias": "parlar",
    "parlarmo": "parlar",
    "parlarmos": "parlar",
    "parlará": "parlar",
    "parlarás": "parlar",
    "parlarão": "parlar",
    "parlaríamos": "parlar",
    "parlaríeis": "parlar",
    "parlas": "parlar",
    "parlasse": "parlar",
    "parlassem": "parlar",
    "parlasses": "parlar",
    "parlaste": "parlar",
    "parlastes": "parlar",
    "parlatórios": "parlatório",
    "parlava": "parlar",
    "parlavam": "parlar",
    "parlavas": "parlar",
    "parle": "parlar",
    "parlei": "parlar",
    "parleis": "parlar",
    "parlem": "parlar",
    "parlemo": "parlar",
    "parlemos": "parlar",
    "parlendas": "parlenda",
    "parlengas": "parlenga",
    "parlentas": "parlenta",
    "parles": "parlar",
    "parlo": "parlar",
    "parlou": "parlar",
    "parlámo": "parlar",
    "parlámos": "parlar",
    "parláramo": "parlar",
    "parláramos": "parlar",
    "parláreis": "parlar",
    "parlásseis": "parlar",
    "parlássemos": "parlar",
    "parlávamo": "parlar",
    "parlávamos": "parlar",
    "parláveis": "parlar",
    "parmas": "parma",
    "parmesã": "parmesão",
    "parmesãos": "parmesão",
    "parmesãs": "parmesão",
    "parnasiana": "parnasiano",
    "parnasianas": "parnasiano",
    "parnasianismos": "parnasianismo",
    "parnasianistas": "parnasianista",
    "parnasianos": "parnasiano",
    "parnasos": "parnaso",
    "paro": "parir",
    "parodia": "parodiar",
    "parodiada": "parodiar",
    "parodiadas": "parodiar",
    "parodiado": "parodiar",
    "parodiadora": "parodiador",
    "parodiadoras": "parodiador",
    "parodiadores": "parodiador",
    "parodiados": "parodiar",
    "parodiai": "parodiar",
    "parodiais": "parodiar",
    "parodiam": "parodiar",
    "parodiamo": "parodiar",
    "parodiamos": "parodiar",
    "parodiando": "parodiar",
    "parodiara": "parodiar",
    "parodiaram": "parodiar",
    "parodiaras": "parodiar",
    "parodiarde": "parodiar",
    "parodiardes": "parodiar",
    "parodiare": "parodiar",
    "parodiarei": "parodiar",
    "parodiareis": "parodiar",
    "parodiarem": "parodiar",
    "parodiaremos": "parodiar",
    "parodiares": "parodiar",
    "parodiaria": "parodiar",
    "parodiariam": "parodiar",
    "parodiarias": "parodiar",
    "parodiarmo": "parodiar",
    "parodiarmos": "parodiar",
    "parodiará": "parodiar",
    "parodiarás": "parodiar",
    "parodiarão": "parodiar",
    "parodiaríamos": "parodiar",
    "parodiaríeis": "parodiar",
    "parodias": "parodiar",
    "parodiasse": "parodiar",
    "parodiassem": "parodiar",
    "parodiasses": "parodiar",
    "parodiaste": "parodiar",
    "parodiastes": "parodiar",
    "parodiava": "parodiar",
    "parodiavam": "parodiar",
    "parodiavas": "parodiar",
    "parodie": "parodiar",
    "parodiei": "parodiar",
    "parodieis": "parodiar",
    "parodiem": "parodiar",
    "parodiemo": "parodiar",
    "parodiemos": "parodiar",
    "parodies": "parodiar",
    "parodio": "parodiar",
    "parodiou": "parodiar",
    "parodistas": "parodista",
    "parodiá": "parodiar",
    "parodiámo": "parodiar",
    "parodiámos": "parodiar",
    "parodiáramo": "parodiar",
    "parodiáramos": "parodiar",
    "parodiárei": "parodiar",
    "parodiáreis": "parodiar",
    "parodiásseis": "parodiar",
    "parodiássemos": "parodiar",
    "parodiávamo": "parodiar",
    "parodiávamos": "parodiar",
    "parodiávei": "parodiar",
    "parodiáveis": "parodiar",
    "parodontites": "parodontite",
    "parola": "parolo",
    "parolada": "parolar",
    "paroladas": "parolar",
    "parolado": "parolar",
    "paroladora": "parolador",
    "paroladoras": "parolador",
    "paroladores": "parolador",
    "parolados": "parolar",
    "parolagens": "parolagem",
    "parolai": "parolar",
    "parolais": "parolar",
    "parolam": "parolar",
    "parolamo": "parolar",
    "parolamos": "parolar",
    "parolando": "parolar",
    "parolara": "parolar",
    "parolaram": "parolar",
    "parolaras": "parolar",
    "parolardes": "parolar",
    "parolarei": "parolar",
    "parolareis": "parolar",
    "parolarem": "parolar",
    "parolaremos": "parolar",
    "parolares": "parolar",
    "parolaria": "parolar",
    "parolariam": "parolar",
    "parolarias": "parolar",
    "parolarmo": "parolar",
    "parolarmos": "parolar",
    "parolará": "parolar",
    "parolarás": "parolar",
    "parolarão": "parolar",
    "parolaríamos": "parolar",
    "parolaríeis": "parolar",
    "parolas": "parolo",
    "parolasse": "parolar",
    "parolassem": "parolar",
    "parolasses": "parolar",
    "parolaste": "parolar",
    "parolastes": "parolar",
    "parolava": "parolar",
    "parolavam": "parolar",
    "parolavas": "parolar",
    "parole": "parolar",
    "paroleada": "parolear",
    "paroleadas": "parolear",
    "paroleado": "parolear",
    "paroleados": "parolear",
    "paroleai": "parolear",
    "paroleais": "parolear",
    "paroleamo": "parolear",
    "paroleamos": "parolear",
    "paroleando": "parolear",
    "paroleara": "parolear",
    "parolearam": "parolear",
    "parolearas": "parolear",
    "paroleardes": "parolear",
    "parolearei": "parolear",
    "paroleareis": "parolear",
    "parolearem": "parolear",
    "parolearemos": "parolear",
    "paroleares": "parolear",
    "parolearia": "parolear",
    "paroleariam": "parolear",
    "parolearias": "parolear",
    "parolearmo": "parolear",
    "parolearmos": "parolear",
    "paroleará": "parolear",
    "parolearás": "parolear",
    "parolearão": "parolear",
    "parolearíamos": "parolear",
    "parolearíeis": "parolear",
    "paroleasse": "parolear",
    "paroleassem": "parolear",
    "paroleasses": "parolear",
    "paroleaste": "parolear",
    "paroleastes": "parolear",
    "paroleava": "parolear",
    "paroleavam": "parolear",
    "paroleavas": "parolear",
    "paroleei": "parolear",
    "paroleeis": "parolear",
    "paroleemo": "parolear",
    "paroleemos": "parolear",
    "parolei": "parolar",
    "paroleia": "parolear",
    "paroleiam": "parolear",
    "paroleias": "parolear",
    "paroleie": "parolear",
    "paroleiem": "parolear",
    "paroleies": "parolear",
    "paroleio": "parolear",
    "paroleira": "paroleiro",
    "paroleiras": "paroleiro",
    "paroleiros": "paroleiro",
    "paroleis": "parolar",
    "parolem": "parolar",
    "parolemo": "parolar",
    "parolemos": "parolar",
    "paroleou": "parolear",
    "paroles": "parolar",
    "paroleámo": "parolear",
    "paroleámos": "parolear",
    "paroleáramo": "parolear",
    "paroleáramos": "parolear",
    "paroleáreis": "parolear",
    "paroleásseis": "parolear",
    "paroleássemos": "parolear",
    "paroleávamo": "parolear",
    "paroleávamos": "parolear",
    "paroleáveis": "parolear",
    "parolices": "parolice",
    "parolo": "parolar",
    "parolos": "parolo",
    "parolou": "parolar",
    "parolámo": "parolar",
    "parolámos": "parolar",
    "paroláramo": "parolar",
    "paroláramos": "parolar",
    "paroláreis": "parolar",
    "parolásseis": "parolar",
    "parolássemos": "parolar",
    "parolávamo": "parolar",
    "parolávamos": "parolar",
    "paroláveis": "parolar",
    "paronomásias": "paronomásia",
    "paronímias": "paronímia",
    "paronímica": "paronímico",
    "paronímicas": "paronímico",
    "paronímicos": "paronímico",
    "paroníquias": "paroníquia",
    "paropsias": "paropsia",
    "paroquia": "paroquiar",
    "paroquiada": "paroquiar",
    "paroquiadas": "paroquiar",
    "paroquiado": "paroquiar",
    "paroquiados": "paroquiar",
    "paroquiai": "paroquiar",
    "paroquiais": "paroquiar",
    "paroquialidades": "paroquialidade",
    "paroquiam": "paroquiar",
    "paroquiamentos": "paroquiamento",
    "paroquiamo": "paroquiar",
    "paroquiamos": "paroquiar",
    "paroquiana": "paroquiano",
    "paroquianas": "paroquiano",
    "paroquiando": "paroquiar",
    "paroquianos": "paroquiano",
    "paroquiara": "paroquiar",
    "paroquiaram": "paroquiar",
    "paroquiaras": "paroquiar",
    "paroquiarde": "paroquiar",
    "paroquiardes": "paroquiar",
    "paroquiare": "paroquiar",
    "paroquiarei": "paroquiar",
    "paroquiareis": "paroquiar",
    "paroquiarem": "paroquiar",
    "paroquiaremos": "paroquiar",
    "paroquiares": "paroquiar",
    "paroquiaria": "paroquiar",
    "paroquiariam": "paroquiar",
    "paroquiarias": "paroquiar",
    "paroquiarmo": "paroquiar",
    "paroquiarmos": "paroquiar",
    "paroquiará": "paroquiar",
    "paroquiarás": "paroquiar",
    "paroquiarão": "paroquiar",
    "paroquiaríamos": "paroquiar",
    "paroquiaríeis": "paroquiar",
    "paroquias": "paroquiar",
    "paroquiasse": "paroquiar",
    "paroquiassem": "paroquiar",
    "paroquiasses": "paroquiar",
    "paroquiaste": "paroquiar",
    "paroquiastes": "paroquiar",
    "paroquiava": "paroquiar",
    "paroquiavam": "paroquiar",
    "paroquiavas": "paroquiar",
    "paroquie": "paroquiar",
    "paroquiei": "paroquiar",
    "paroquieis": "paroquiar",
    "paroquiem": "paroquiar",
    "paroquiemo": "paroquiar",
    "paroquiemos": "paroquiar",
    "paroquies": "paroquiar",
    "paroquio": "paroquiar",
    "paroquiou": "paroquiar",
    "paroquiá": "paroquiar",
    "paroquiámo": "paroquiar",
    "paroquiámos": "paroquiar",
    "paroquiáramo": "paroquiar",
    "paroquiáramos": "paroquiar",
    "paroquiárei": "paroquiar",
    "paroquiáreis": "paroquiar",
    "paroquiásseis": "paroquiar",
    "paroquiássemos": "paroquiar",
    "paroquiávamo": "paroquiar",
    "paroquiávamos": "paroquiar",
    "paroquiávei": "paroquiar",
    "paroquiáveis": "paroquiar",
    "parorases": "parorase",
    "parorásica": "parorásico",
    "parorásicas": "parorásico",
    "parorásicos": "parorásico",
    "parosmias": "parosmia",
    "parotidiana": "parotidiano",
    "parotidianas": "parotidiano",
    "parotidianos": "parotidiano",
    "parotidites": "parotidite",
    "parotídea": "parotídeo",
    "parotídeas": "parotídeo",
    "parotídeos": "parotídeo",
    "parotídica": "parotídico",
    "parotídicas": "parotídico",
    "parotídicos": "parotídico",
    "parou": "parar",
    "parouveias": "parouveia",
    "parouvelas": "parouvela",
    "paroxismais": "paroxismal",
    "paroxismos": "paroxismo",
    "paroxísmica": "paroxísmico",
    "paroxísmicas": "paroxísmico",
    "paroxísmicos": "paroxísmico",
    "paroxística": "paroxístico",
    "paroxísticas": "paroxístico",
    "paroxísticos": "paroxístico",
    "paroxítona": "paroxítono",
    "paroxítonas": "paroxítono",
    "paroxítonos": "paroxítono",
    "parqueada": "parquear",
    "parqueadas": "parquear",
    "parqueado": "parquear",
    "parqueados": "parquear",
    "parqueai": "parquear",
    "parqueais": "parquear",
    "parqueamentos": "parqueamento",
    "parqueamo": "parquear",
    "parqueamos": "parquear",
    "parqueando": "parquear",
    "parqueara": "parquear",
    "parquearam": "parquear",
    "parquearas": "parquear",
    "parquearde": "parquear",
    "parqueardes": "parquear",
    "parqueare": "parquear",
    "parquearei": "parquear",
    "parqueareis": "parquear",
    "parquearem": "parquear",
    "parquearemos": "parquear",
    "parqueares": "parquear",
    "parquearia": "parquear",
    "parqueariam": "parquear",
    "parquearias": "parquear",
    "parquearmo": "parquear",
    "parquearmos": "parquear",
    "parqueará": "parquear",
    "parquearás": "parquear",
    "parquearão": "parquear",
    "parquearíamos": "parquear",
    "parquearíeis": "parquear",
    "parqueasse": "parquear",
    "parqueassem": "parquear",
    "parqueasses": "parquear",
    "parqueaste": "parquear",
    "parqueastes": "parquear",
    "parqueava": "parquear",
    "parqueavam": "parquear",
    "parqueavas": "parquear",
    "parqueei": "parquear",
    "parqueeis": "parquear",
    "parqueemo": "parquear",
    "parqueemos": "parquear",
    "parqueia": "parquear",
    "parqueiam": "parquear",
    "parqueias": "parquear",
    "parqueie": "parquear",
    "parqueiem": "parquear",
    "parqueies": "parquear",
    "parqueio": "parquear",
    "parqueou": "parquear",
    "parques": "parque",
    "parquetes": "parquete",
    "parquets": "parquet",
    "parqueá": "parquear",
    "parqueámo": "parquear",
    "parqueámos": "parquear",
    "parqueáramo": "parquear",
    "parqueáramos": "parquear",
    "parqueárei": "parquear",
    "parqueáreis": "parquear",
    "parqueásseis": "parquear",
    "parqueássemos": "parquear",
    "parqueávamo": "parquear",
    "parqueávamos": "parquear",
    "parqueávei": "parquear",
    "parqueáveis": "parquear",
    "parqués": "parqué",
    "parquímetros": "parquímetro",
    "parra": "parrar",
    "parracha": "parracho",
    "parrachas": "parracho",
    "parrachazinha": "parracho",
    "parrachazinhas": "parracho",
    "parrachazita": "parracho",
    "parrachazitas": "parracho",
    "parrachinha": "parracho",
    "parrachinhas": "parracho",
    "parrachinho": "parracho",
    "parrachinhos": "parracho",
    "parrachita": "parracho",
    "parrachitas": "parracho",
    "parrachito": "parracho",
    "parrachitos": "parracho",
    "parrachos": "parracho",
    "parrachozinho": "parracho",
    "parrachozinhos": "parracho",
    "parrachozito": "parracho",
    "parrachozitos": "parracho",
    "parrada": "parrar",
    "parradas": "parrar",
    "parrado": "parrar",
    "parrados": "parrar",
    "parrai": "parrar",
    "parrais": "parrar",
    "parram": "parrar",
    "parramo": "parrar",
    "parramos": "parrar",
    "parranas": "parrana",
    "parrancices": "parrancice",
    "parrando": "parrar",
    "parranices": "parranice",
    "parrara": "parrar",
    "parraram": "parrar",
    "parraras": "parrar",
    "parrarde": "parrar",
    "parrardes": "parrar",
    "parrare": "parrar",
    "parrarei": "parrar",
    "parrareis": "parrar",
    "parrarem": "parrar",
    "parraremos": "parrar",
    "parrares": "parrar",
    "parraria": "parrar",
    "parrariam": "parrar",
    "parrarias": "parrar",
    "parrarmo": "parrar",
    "parrarmos": "parrar",
    "parrará": "parrar",
    "parrarás": "parrar",
    "parrarão": "parrar",
    "parraríamos": "parrar",
    "parraríeis": "parrar",
    "parras": "parrar",
    "parrascana": "parrascano",
    "parrascanas": "parrascano",
    "parrascanos": "parrascano",
    "parrasse": "parrar",
    "parrassem": "parrar",
    "parrasses": "parrar",
    "parraste": "parrar",
    "parrastes": "parrar",
    "parrava": "parrar",
    "parravam": "parrar",
    "parravas": "parrar",
    "parre": "parrar",
    "parreca": "parreco",
    "parrecas": "parreco",
    "parrecos": "parreco",
    "parrei": "parrar",
    "parreirais": "parreiral",
    "parreiras": "parreira",
    "parreis": "parrar",
    "parrem": "parrar",
    "parremo": "parrar",
    "parremos": "parrar",
    "parres": "parrar",
    "parricidas": "parricida",
    "parricídios": "parricídio",
    "parrilhas": "parrilha",
    "parro": "parrar",
    "parrou": "parrar",
    "parruda": "parrudo",
    "parrudas": "parrudo",
    "parrudos": "parrudo",
    "parrá": "parrar",
    "parrámo": "parrar",
    "parrámos": "parrar",
    "parráramo": "parrar",
    "parráramos": "parrar",
    "parrárei": "parrar",
    "parráreis": "parrar",
    "parrásseis": "parrar",
    "parrássemos": "parrar",
    "parrávamo": "parrar",
    "parrávamos": "parrar",
    "parrávei": "parrar",
    "parráveis": "parrar",
    "parrésias": "parrésia",
    "parrésica": "parrésico",
    "parrésicas": "parrésico",
    "parrésicos": "parrésico",
    "parsecs": "parsec",
    "parses": "parse",
    "parsiana": "parsiano",
    "parsianas": "parsiano",
    "parsianos": "parsiano",
    "parta": "partir",
    "partais": "partir",
    "partam": "partir",
    "partamo": "partir",
    "partamos": "partir",
    "partas": "partir",
    "partasanas": "partasana",
    "parte": "partir",
    "parteira": "parteiro",
    "parteiras": "parteiro",
    "parteiros": "parteiro",
    "parteja": "partejar",
    "partejada": "partejar",
    "partejadas": "partejar",
    "partejado": "partejar",
    "partejados": "partejar",
    "partejai": "partejar",
    "partejais": "partejar",
    "partejam": "partejar",
    "partejamentos": "partejamento",
    "partejamo": "partejar",
    "partejamos": "partejar",
    "partejando": "partejar",
    "partejara": "partejar",
    "partejaram": "partejar",
    "partejaras": "partejar",
    "partejarde": "partejar",
    "partejardes": "partejar",
    "partejare": "partejar",
    "partejarei": "partejar",
    "partejareis": "partejar",
    "partejarem": "partejar",
    "partejaremos": "partejar",
    "partejares": "partejar",
    "partejaria": "partejar",
    "partejariam": "partejar",
    "partejarias": "partejar",
    "partejarmo": "partejar",
    "partejarmos": "partejar",
    "partejará": "partejar",
    "partejarás": "partejar",
    "partejarão": "partejar",
    "partejaríamos": "partejar",
    "partejaríeis": "partejar",
    "partejas": "partejar",
    "partejasse": "partejar",
    "partejassem": "partejar",
    "partejasses": "partejar",
    "partejaste": "partejar",
    "partejastes": "partejar",
    "partejava": "partejar",
    "partejavam": "partejar",
    "partejavas": "partejar",
    "parteje": "partejar",
    "partejei": "partejar",
    "partejeis": "partejar",
    "partejem": "partejar",
    "partejemo": "partejar",
    "partejemos": "partejar",
    "partejes": "partejar",
    "partejo": "partejar",
    "partejos": "partejo",
    "partejou": "partejar",
    "partejá": "partejar",
    "partejámo": "partejar",
    "partejámos": "partejar",
    "partejáramo": "partejar",
    "partejáramos": "partejar",
    "partejárei": "partejar",
    "partejáreis": "partejar",
    "partejásseis": "partejar",
    "partejássemos": "partejar",
    "partejávamo": "partejar",
    "partejávamos": "partejar",
    "partejávei": "partejar",
    "partejáveis": "partejar",
    "partem": "partir",
    "partenariados": "partenariado",
    "partenogéneses": "partenogénese",
    "partenomancias": "partenomancia",
    "partenomantes": "partenomante",
    "partenopeia": "partenopeu",
    "partenopeias": "partenopeu",
    "partenopeus": "partenopeu",
    "partenões": "partenão",
    "partes": "partir",
    "parti": "partir",
    "partia": "partir",
    "partiam": "partir",
    "partias": "partir",
    "participa": "participar",
    "participada": "participar",
    "participadas": "participar",
    "participado": "participar",
    "participadora": "participador",
    "participadoras": "participador",
    "participadores": "participador",
    "participados": "participar",
    "participai": "participar",
    "participais": "participar",
    "participam": "participar",
    "participamo": "participar",
    "participamos": "participar",
    "participando": "participar",
    "participantes": "participante",
    "participara": "participar",
    "participaram": "participar",
    "participaras": "participar",
    "participarde": "participar",
    "participardes": "participar",
    "participare": "participar",
    "participarei": "participar",
    "participareis": "participar",
    "participarem": "participar",
    "participaremos": "participar",
    "participares": "participar",
    "participaria": "participar",
    "participariam": "participar",
    "participarias": "participar",
    "participarmo": "participar",
    "participarmos": "participar",
    "participará": "participar",
    "participarás": "participar",
    "participarão": "participar",
    "participaríamos": "participar",
    "participaríeis": "participar",
    "participas": "participar",
    "participasse": "participar",
    "participassem": "participar",
    "participasses": "participar",
    "participaste": "participar",
    "participastes": "participar",
    "participativa": "participativo",
    "participativas": "participativo",
    "participativos": "participativo",
    "participava": "participar",
    "participavam": "participar",
    "participavas": "participar",
    "participações": "participação",
    "participe": "participar",
    "participei": "participar",
    "participeis": "participar",
    "participem": "participar",
    "participemo": "participar",
    "participemos": "participar",
    "participes": "participar",
    "participiais": "participial",
    "participo": "participar",
    "participou": "participar",
    "participá": "participar",
    "participámo": "participar",
    "participámos": "participar",
    "participáramo": "participar",
    "participáramos": "participar",
    "participárei": "participar",
    "participáreis": "participar",
    "participásseis": "participar",
    "participássemos": "participar",
    "participávamo": "participar",
    "participávamos": "participar",
    "participávei": "participar",
    "participáveis": "participável",
    "particulares": "particular",
    "particularidades": "particularidade",
    "particularismos": "particularismo",
    "particularistas": "particularista",
    "particulariza": "particularizar",
    "particularizada": "particularizar",
    "particularizadas": "particularizar",
    "particularizado": "particularizar",
    "particularizados": "particularizar",
    "particularizai": "particularizar",
    "particularizais": "particularizar",
    "particularizam": "particularizar",
    "particularizamo": "particularizar",
    "particularizamos": "particularizar",
    "particularizando": "particularizar",
    "particularizara": "particularizar",
    "particularizaram": "particularizar",
    "particularizaras": "particularizar",
    "particularizarde": "particularizar",
    "particularizardes": "particularizar",
    "particularizare": "particularizar",
    "particularizarei": "particularizar",
    "particularizareis": "particularizar",
    "particularizarem": "particularizar",
    "particularizaremos": "particularizar",
    "particularizares": "particularizar",
    "particularizaria": "particularizar",
    "particularizariam": "particularizar",
    "particularizarias": "particularizar",
    "particularizarmo": "particularizar",
    "particularizarmos": "particularizar",
    "particularizará": "particularizar",
    "particularizarás": "particularizar",
    "particularizarão": "particularizar",
    "particularizaríamos": "particularizar",
    "particularizaríeis": "particularizar",
    "particularizas": "particularizar",
    "particularizasse": "particularizar",
    "particularizassem": "particularizar",
    "particularizasses": "particularizar",
    "particularizaste": "particularizar",
    "particularizastes": "particularizar",
    "particularizava": "particularizar",
    "particularizavam": "particularizar",
    "particularizavas": "particularizar",
    "particularizações": "particularização",
    "particularize": "particularizar",
    "particularizei": "particularizar",
    "particularizeis": "particularizar",
    "particularizem": "particularizar",
    "particularizemo": "particularizar",
    "particularizemos": "particularizar",
    "particularizes": "particularizar",
    "particularizo": "particularizar",
    "particularizou": "particularizar",
    "particularizá": "particularizar",
    "particularizámo": "particularizar",
    "particularizámos": "particularizar",
    "particularizáramo": "particularizar",
    "particularizáramos": "particularizar",
    "particularizárei": "particularizar",
    "particularizáreis": "particularizar",
    "particularizásseis": "particularizar",
    "particularizássemos": "particularizar",
    "particularizávamo": "particularizar",
    "particularizávamos": "particularizar",
    "particularizávei": "particularizar",
    "particularizáveis": "particularizável",
    "particularíssima": "particular",
    "particularíssimas": "particular",
    "particularíssimo": "particular",
    "particularíssimos": "particular",
    "particípios": "particípio",
    "partida": "partir",
    "partidarismos": "partidarismo",
    "partidaristas": "partidarista",
    "partidariza": "partidarizar",
    "partidarizada": "partidarizar",
    "partidarizadas": "partidarizar",
    "partidarizado": "partidarizar",
    "partidarizados": "partidarizar",
    "partidarizai": "partidarizar",
    "partidarizais": "partidarizar",
    "partidarizam": "partidarizar",
    "partidarizamo": "partidarizar",
    "partidarizamos": "partidarizar",
    "partidarizando": "partidarizar",
    "partidarizara": "partidarizar",
    "partidarizaram": "partidarizar",
    "partidarizaras": "partidarizar",
    "partidarizarde": "partidarizar",
    "partidarizardes": "partidarizar",
    "partidarizare": "partidarizar",
    "partidarizarei": "partidarizar",
    "partidarizareis": "partidarizar",
    "partidarizarem": "partidarizar",
    "partidarizaremos": "partidarizar",
    "partidarizares": "partidarizar",
    "partidarizaria": "partidarizar",
    "partidarizariam": "partidarizar",
    "partidarizarias": "partidarizar",
    "partidarizarmo": "partidarizar",
    "partidarizarmos": "partidarizar",
    "partidarizará": "partidarizar",
    "partidarizarás": "partidarizar",
    "partidarizarão": "partidarizar",
    "partidarizaríamos": "partidarizar",
    "partidarizaríeis": "partidarizar",
    "partidarizas": "partidarizar",
    "partidarizasse": "partidarizar",
    "partidarizassem": "partidarizar",
    "partidarizasses": "partidarizar",
    "partidarizaste": "partidarizar",
    "partidarizastes": "partidarizar",
    "partidarizava": "partidarizar",
    "partidarizavam": "partidarizar",
    "partidarizavas": "partidarizar",
    "partidarizações": "partidarização",
    "partidarize": "partidarizar",
    "partidarizei": "partidarizar",
    "partidarizeis": "partidarizar",
    "partidarizem": "partidarizar",
    "partidarizemo": "partidarizar",
    "partidarizemos": "partidarizar",
    "partidarizes": "partidarizar",
    "partidarizo": "partidarizar",
    "partidarizou": "partidarizar",
    "partidarizá": "partidarizar",
    "partidarizámo": "partidarizar",
    "partidarizámos": "partidarizar",
    "partidarizáramo": "partidarizar",
    "partidarizáramos": "partidarizar",
    "partidarizárei": "partidarizar",
    "partidarizáreis": "partidarizar",
    "partidarizásseis": "partidarizar",
    "partidarizássemos": "partidarizar",
    "partidarizávamo": "partidarizar",
    "partidarizávamos": "partidarizar",
    "partidarizávei": "partidarizar",
    "partidarizáveis": "partidarizar",
    "partidas": "partir",
    "partidazinha": "partido",
    "partidazinhas": "partido",
    "partidazita": "partido",
    "partidazitas": "partido",
    "partidinha": "partido",
    "partidinhas": "partido",
    "partidinho": "partido",
    "partidinhos": "partido",
    "partidismos": "partidismo",
    "partidistas": "partidista",
    "partidita": "partido",
    "partiditas": "partido",
    "partidito": "partido",
    "partiditos": "partido",
    "partido": "partir",
    "partidoiras": "partidoira",
    "partidos": "partir",
    "partidouras": "partidoura",
    "partidozinho": "partido",
    "partidozinhos": "partido",
    "partidozito": "partido",
    "partidozitos": "partido",
    "partidária": "partidário",
    "partidárias": "partidário",
    "partidários": "partidário",
    "partidíssima": "partido",
    "partidíssimas": "partido",
    "partidíssimo": "partido",
    "partidíssimos": "partido",
    "partidões": "partidão",
    "partilha": "partilhar",
    "partilhada": "partilhar",
    "partilhadas": "partilhar",
    "partilhado": "partilhar",
    "partilhados": "partilhar",
    "partilhai": "partilhar",
    "partilhais": "partilhar",
    "partilham": "partilhar",
    "partilhamo": "partilhar",
    "partilhamos": "partilhar",
    "partilhando": "partilhar",
    "partilhara": "partilhar",
    "partilharam": "partilhar",
    "partilharas": "partilhar",
    "partilharde": "partilhar",
    "partilhardes": "partilhar",
    "partilhare": "partilhar",
    "partilharei": "partilhar",
    "partilhareis": "partilhar",
    "partilharem": "partilhar",
    "partilharemos": "partilhar",
    "partilhares": "partilhar",
    "partilharia": "partilhar",
    "partilhariam": "partilhar",
    "partilharias": "partilhar",
    "partilharmo": "partilhar",
    "partilharmos": "partilhar",
    "partilhará": "partilhar",
    "partilharás": "partilhar",
    "partilharão": "partilhar",
    "partilharíamos": "partilhar",
    "partilharíeis": "partilhar",
    "partilhas": "partilhar",
    "partilhasse": "partilhar",
    "partilhassem": "partilhar",
    "partilhasses": "partilhar",
    "partilhaste": "partilhar",
    "partilhastes": "partilhar",
    "partilhava": "partilhar",
    "partilhavam": "partilhar",
    "partilhavas": "partilhar",
    "partilhe": "partilhar",
    "partilhei": "partilhar",
    "partilheis": "partilhar",
    "partilhem": "partilhar",
    "partilhemo": "partilhar",
    "partilhemos": "partilhar",
    "partilhes": "partilhar",
    "partilho": "partilhar",
    "partilhou": "partilhar",
    "partilhá": "partilhar",
    "partilhámo": "partilhar",
    "partilhámos": "partilhar",
    "partilháramo": "partilhar",
    "partilháramos": "partilhar",
    "partilhárei": "partilhar",
    "partilháreis": "partilhar",
    "partilhásseis": "partilhar",
    "partilhássemos": "partilhar",
    "partilhávamo": "partilhar",
    "partilhávamos": "partilhar",
    "partilhávei": "partilhar",
    "partilháveis": "partilhável",
    "partimentos": "partimento",
    "partimo": "partir",
    "partimos": "partir",
    "partindo": "partir",
    "partira": "partir",
    "partiram": "partir",
    "partiras": "partir",
    "partirde": "partir",
    "partirdes": "partir",
    "partire": "partir",
    "partirei": "partir",
    "partireis": "partir",
    "partirem": "partir",
    "partiremos": "partir",
    "partires": "partir",
    "partiria": "partir",
    "partiriam": "partir",
    "partirias": "partir",
    "partirmo": "partir",
    "partirmos": "partir",
    "partirá": "partir",
    "partirás": "partir",
    "partirão": "partir",
    "partiríamos": "partir",
    "partiríeis": "partir",
    "partis": "partir",
    "partisse": "partir",
    "partissem": "partir",
    "partisses": "partir",
    "partiste": "partir",
    "partistes": "partir",
    "partitiva": "partitivo",
    "partitivas": "partitivo",
    "partitivos": "partitivo",
    "partituras": "partitura",
    "partiu": "partir",
    "partições": "partição",
    "parto": "partir",
    "partos": "parto",
    "partura": "parturir",
    "parturais": "parturir",
    "parturam": "parturir",
    "parturamo": "parturir",
    "parturamos": "parturir",
    "parturas": "parturir",
    "parture": "parturir",
    "partureja": "parturejar",
    "parturejada": "parturejar",
    "parturejadas": "parturejar",
    "parturejado": "parturejar",
    "parturejados": "parturejar",
    "parturejai": "parturejar",
    "parturejais": "parturejar",
    "parturejam": "parturejar",
    "parturejamo": "parturejar",
    "parturejamos": "parturejar",
    "parturejando": "parturejar",
    "parturejara": "parturejar",
    "parturejaram": "parturejar",
    "parturejaras": "parturejar",
    "parturejarde": "parturejar",
    "parturejardes": "parturejar",
    "parturejare": "parturejar",
    "parturejarei": "parturejar",
    "parturejareis": "parturejar",
    "parturejarem": "parturejar",
    "parturejaremos": "parturejar",
    "parturejares": "parturejar",
    "parturejaria": "parturejar",
    "parturejariam": "parturejar",
    "parturejarias": "parturejar",
    "parturejarmo": "parturejar",
    "parturejarmos": "parturejar",
    "parturejará": "parturejar",
    "parturejarás": "parturejar",
    "parturejarão": "parturejar",
    "parturejaríamos": "parturejar",
    "parturejaríeis": "parturejar",
    "parturejas": "parturejar",
    "parturejasse": "parturejar",
    "parturejassem": "parturejar",
    "parturejasses": "parturejar",
    "parturejaste": "parturejar",
    "parturejastes": "parturejar",
    "parturejava": "parturejar",
    "parturejavam": "parturejar",
    "parturejavas": "parturejar",
    "partureje": "parturejar",
    "parturejei": "parturejar",
    "parturejeis": "parturejar",
    "parturejem": "parturejar",
    "parturejemo": "parturejar",
    "parturejemos": "parturejar",
    "parturejes": "parturejar",
    "parturejo": "parturejar",
    "parturejou": "parturejar",
    "parturejá": "parturejar",
    "parturejámo": "parturejar",
    "parturejámos": "parturejar",
    "parturejáramo": "parturejar",
    "parturejáramos": "parturejar",
    "parturejárei": "parturejar",
    "parturejáreis": "parturejar",
    "parturejásseis": "parturejar",
    "parturejássemos": "parturejar",
    "parturejávamo": "parturejar",
    "parturejávamos": "parturejar",
    "parturejávei": "parturejar",
    "parturejáveis": "parturejar",
    "parturem": "parturir",
    "partures": "parturir",
    "parturi": "parturir",
    "parturia": "parturir",
    "parturiam": "parturir",
    "parturias": "parturir",
    "parturida": "parturir",
    "parturidas": "parturir",
    "parturido": "parturir",
    "parturidos": "parturir",
    "parturientes": "parturiente",
    "parturimo": "parturir",
    "parturimos": "parturir",
    "parturindo": "parturir",
    "parturira": "parturir",
    "parturiram": "parturir",
    "parturiras": "parturir",
    "parturirde": "parturir",
    "parturirdes": "parturir",
    "parturire": "parturir",
    "parturirei": "parturir",
    "parturireis": "parturir",
    "parturirem": "parturir",
    "parturiremos": "parturir",
    "parturires": "parturir",
    "parturiria": "parturir",
    "partuririam": "parturir",
    "parturirias": "parturir",
    "parturirmo": "parturir",
    "parturirmos": "parturir",
    "parturirá": "parturir",
    "parturirás": "parturir",
    "parturirão": "parturir",
    "parturiríamos": "parturir",
    "parturiríeis": "parturir",
    "parturis": "parturir",
    "parturisse": "parturir",
    "parturissem": "parturir",
    "parturisses": "parturir",
    "parturiste": "parturir",
    "parturistes": "parturir",
    "parturiu": "parturir",
    "parturições": "parturição",
    "parturo": "parturir",
    "parturíamo": "parturir",
    "parturíamos": "parturir",
    "parturíei": "parturir",
    "parturíeis": "parturir",
    "parturíramo": "parturir",
    "parturíramos": "parturir",
    "parturírei": "parturir",
    "parturíreis": "parturir",
    "parturísseis": "parturir",
    "parturíssemos": "parturir",
    "partíamo": "partir",
    "partíamos": "partir",
    "partícipes": "partícipe",
    "partículas": "partícula",
    "partíei": "partir",
    "partíeis": "partir",
    "partíramo": "partir",
    "partíramos": "partir",
    "partírei": "partir",
    "partíreis": "partir",
    "partísseis": "partir",
    "partíssemos": "partir",
    "partíveis": "partível",
    "parusíaca": "parusíaco",
    "parusíacas": "parusíaco",
    "parusíacos": "parusíaco",
    "parva": "parvo",
    "parvajolas": "parvajola",
    "parvajona": "parvajão",
    "parvajonas": "parvajão",
    "parvajões": "parvajão",
    "parvalheiras": "parvalheira",
    "parvalhices": "parvalhice",
    "parvalhona": "parvo",
    "parvalhonas": "parvo",
    "parvalhão": "parvo",
    "parvalhões": "parvo",
    "parvas": "parvo",
    "parvazinha": "parvo",
    "parvazinhas": "parvo",
    "parvazita": "parvo",
    "parvazitas": "parvo",
    "parvidades": "parvidade",
    "parvinha": "parvo",
    "parvinhas": "parvo",
    "parvinho": "parvo",
    "parvinhos": "parvo",
    "parvita": "parvo",
    "parvitas": "parvo",
    "parvito": "parvo",
    "parvitos": "parvo",
    "parvocirona": "parvocirão",
    "parvocironas": "parvocirão",
    "parvocirões": "parvocirão",
    "parvoeira": "parvoeirar",
    "parvoeirada": "parvoeirar",
    "parvoeiradas": "parvoeirar",
    "parvoeirado": "parvoeirar",
    "parvoeirados": "parvoeirar",
    "parvoeirai": "parvoeirar",
    "parvoeirais": "parvoeirar",
    "parvoeiram": "parvoeirar",
    "parvoeiramo": "parvoeirar",
    "parvoeiramos": "parvoeirar",
    "parvoeirando": "parvoeirar",
    "parvoeirara": "parvoeirar",
    "parvoeiraram": "parvoeirar",
    "parvoeiraras": "parvoeirar",
    "parvoeirardes": "parvoeirar",
    "parvoeirarei": "parvoeirar",
    "parvoeirareis": "parvoeirar",
    "parvoeirarem": "parvoeirar",
    "parvoeiraremos": "parvoeirar",
    "parvoeirares": "parvoeirar",
    "parvoeiraria": "parvoeirar",
    "parvoeirariam": "parvoeirar",
    "parvoeirarias": "parvoeirar",
    "parvoeirarmo": "parvoeirar",
    "parvoeirarmos": "parvoeirar",
    "parvoeirará": "parvoeirar",
    "parvoeirarás": "parvoeirar",
    "parvoeirarão": "parvoeirar",
    "parvoeiraríamos": "parvoeirar",
    "parvoeiraríeis": "parvoeirar",
    "parvoeiras": "parvoeirar",
    "parvoeirasse": "parvoeirar",
    "parvoeirassem": "parvoeirar",
    "parvoeirasses": "parvoeirar",
    "parvoeiraste": "parvoeirar",
    "parvoeirastes": "parvoeirar",
    "parvoeirava": "parvoeirar",
    "parvoeiravam": "parvoeirar",
    "parvoeiravas": "parvoeirar",
    "parvoeire": "parvoeirar",
    "parvoeirei": "parvoeirar",
    "parvoeireis": "parvoeirar",
    "parvoeirem": "parvoeirar",
    "parvoeiremo": "parvoeirar",
    "parvoeiremos": "parvoeirar",
    "parvoeires": "parvoeirar",
    "parvoeiro": "parvoeirar",
    "parvoeirona": "parvoeirão",
    "parvoeironas": "parvoeirão",
    "parvoeirou": "parvoeirar",
    "parvoeirámo": "parvoeirar",
    "parvoeirámos": "parvoeirar",
    "parvoeiráramo": "parvoeirar",
    "parvoeiráramos": "parvoeirar",
    "parvoeiráreis": "parvoeirar",
    "parvoeirásseis": "parvoeirar",
    "parvoeirássemos": "parvoeirar",
    "parvoeirávamo": "parvoeirar",
    "parvoeirávamos": "parvoeirar",
    "parvoeiráveis": "parvoeirar",
    "parvoeirões": "parvoeirão",
    "parvoeja": "parvoejar",
    "parvoejada": "parvoejar",
    "parvoejadas": "parvoejar",
    "parvoejado": "parvoejar",
    "parvoejados": "parvoejar",
    "parvoejai": "parvoejar",
    "parvoejais": "parvoejar",
    "parvoejam": "parvoejar",
    "parvoejamo": "parvoejar",
    "parvoejamos": "parvoejar",
    "parvoejando": "parvoejar",
    "parvoejara": "parvoejar",
    "parvoejaram": "parvoejar",
    "parvoejaras": "parvoejar",
    "parvoejardes": "parvoejar",
    "parvoejarei": "parvoejar",
    "parvoejareis": "parvoejar",
    "parvoejarem": "parvoejar",
    "parvoejaremos": "parvoejar",
    "parvoejares": "parvoejar",
    "parvoejaria": "parvoejar",
    "parvoejariam": "parvoejar",
    "parvoejarias": "parvoejar",
    "parvoejarmo": "parvoejar",
    "parvoejarmos": "parvoejar",
    "parvoejará": "parvoejar",
    "parvoejarás": "parvoejar",
    "parvoejarão": "parvoejar",
    "parvoejaríamos": "parvoejar",
    "parvoejaríeis": "parvoejar",
    "parvoejas": "parvoejar",
    "parvoejasse": "parvoejar",
    "parvoejassem": "parvoejar",
    "parvoejasses": "parvoejar",
    "parvoejaste": "parvoejar",
    "parvoejastes": "parvoejar",
    "parvoejava": "parvoejar",
    "parvoejavam": "parvoejar",
    "parvoejavas": "parvoejar",
    "parvoeje": "parvoejar",
    "parvoejei": "parvoejar",
    "parvoejeis": "parvoejar",
    "parvoejem": "parvoejar",
    "parvoejemo": "parvoejar",
    "parvoejemos": "parvoejar",
    "parvoejes": "parvoejar",
    "parvoejo": "parvoejar",
    "parvoejou": "parvoejar",
    "parvoejámo": "parvoejar",
    "parvoejámos": "parvoejar",
    "parvoejáramo": "parvoejar",
    "parvoejáramos": "parvoejar",
    "parvoejáreis": "parvoejar",
    "parvoejásseis": "parvoejar",
    "parvoejássemos": "parvoejar",
    "parvoejávamo": "parvoejar",
    "parvoejávamos": "parvoejar",
    "parvoejáveis": "parvoejar",
    "parvoidades": "parvoidade",
    "parvoinha": "parvoinho",
    "parvoinhas": "parvoinho",
    "parvoinhos": "parvoinho",
    "parvoiçadas": "parvoiçada",
    "parvos": "parvo",
    "parvozinho": "parvo",
    "parvozinhos": "parvo",
    "parvozito": "parvo",
    "parvozitos": "parvo",
    "parvoíces": "parvoíce",
    "parvulezas": "parvuleza",
    "parvulezes": "parvulez",
    "parvíssima": "parvo",
    "parvíssimas": "parvo",
    "parvíssimo": "parvo",
    "parvíssimos": "parvo",
    "parvóides": "parvóide",
    "parvónia": "parvónio",
    "parvónias": "parvónio",
    "parvónios": "parvónio",
    "parzinho": "par",
    "parzinhos": "par",
    "parzito": "par",
    "parzitos": "par",
    "pará": "parar",
    "parábases": "parábase",
    "parábolas": "parábola",
    "paráclases": "paráclase",
    "paráclitos": "paráclito",
    "paráfises": "paráfise",
    "paráfrases": "paráfrase",
    "parágrafos": "parágrafo",
    "parálica": "parálico",
    "parálicas": "parálico",
    "parálicos": "parálico",
    "parálises": "parálise",
    "parámo": "parar",
    "parámos": "parar",
    "parápodes": "parápode",
    "paráramo": "parar",
    "paráramos": "parar",
    "parárei": "parar",
    "paráreis": "parar",
    "parásseis": "parar",
    "parássemos": "parar",
    "parátipos": "parátipo",
    "parávamo": "parar",
    "parávamos": "parar",
    "parávei": "parar",
    "paráveis": "parável",
    "parâmetros": "parâmetro",
    "parçarias": "parçaria",
    "paréctases": "paréctase",
    "parélica": "parélico",
    "parélicas": "parélico",
    "parélicos": "parélico",
    "parélios": "parélio",
    "parémias": "parémia",
    "parémica": "parémico",
    "parémicas": "parémico",
    "parémicos": "parémico",
    "paréneses": "parénese",
    "parésica": "parésico",
    "parésicas": "parésico",
    "parésicos": "parésico",
    "parêeniores": "parêntese",
    "parênquimas": "parênquima",
    "paríamo": "parir",
    "paríamos": "parir",
    "parídeos": "parídeo",
    "paríei": "parir",
    "paríeis": "parir",
    "paríramo": "parir",
    "paríramos": "parir",
    "parírei": "parir",
    "paríreis": "parir",
    "parísea": "paríseo",
    "paríseas": "paríseo",
    "paríseos": "paríseo",
    "parísseis": "parir",
    "paríssemos": "parir",
    "paródias": "paródia",
    "paróis": "parol",
    "parónima": "parónimo",
    "parónimas": "parónimo",
    "parónimos": "parónimo",
    "parópsica": "parópsico",
    "parópsicas": "parópsico",
    "parópsicos": "parópsico",
    "paróquias": "paróquia",
    "parós": "paró",
    "parósmica": "parósmico",
    "parósmicas": "parósmico",
    "parósmicos": "parósmico",
    "parótica": "parótico",
    "paróticas": "parótico",
    "paróticos": "parótico",
    "parótida": "parótido",
    "parótidas": "parótido",
    "parótides": "parótide",
    "parótidos": "parótido",
    "parúsias": "parúsia",
    "parúsica": "parúsico",
    "parúsicas": "parúsico",
    "parúsicos": "parúsico",
    "pascacices": "pascacice",
    "pascais": "pascal",
    "pascalinas": "pascalina",
    "pasce": "pascer",
    "pascei": "pascer",
    "pasceis": "pascer",
    "pascem": "pascer",
    "pascemo": "pascer",
    "pascemos": "pascer",
    "pascendo": "pascer",
    "pascenta": "pascentar",
    "pascentada": "pascentar",
    "pascentadas": "pascentar",
    "pascentado": "pascentar",
    "pascentados": "pascentar",
    "pascentai": "pascentar",
    "pascentais": "pascentar",
    "pascentam": "pascentar",
    "pascentamo": "pascentar",
    "pascentamos": "pascentar",
    "pascentando": "pascentar",
    "pascentara": "pascentar",
    "pascentaram": "pascentar",
    "pascentaras": "pascentar",
    "pascentarde": "pascentar",
    "pascentardes": "pascentar",
    "pascentare": "pascentar",
    "pascentarei": "pascentar",
    "pascentareis": "pascentar",
    "pascentarem": "pascentar",
    "pascentaremos": "pascentar",
    "pascentares": "pascentar",
    "pascentaria": "pascentar",
    "pascentariam": "pascentar",
    "pascentarias": "pascentar",
    "pascentarmo": "pascentar",
    "pascentarmos": "pascentar",
    "pascentará": "pascentar",
    "pascentarás": "pascentar",
    "pascentarão": "pascentar",
    "pascentaríamos": "pascentar",
    "pascentaríeis": "pascentar",
    "pascentas": "pascentar",
    "pascentasse": "pascentar",
    "pascentassem": "pascentar",
    "pascentasses": "pascentar",
    "pascentaste": "pascentar",
    "pascentastes": "pascentar",
    "pascentava": "pascentar",
    "pascentavam": "pascentar",
    "pascentavas": "pascentar",
    "pascente": "pascentar",
    "pascentei": "pascentar",
    "pascenteis": "pascentar",
    "pascentem": "pascentar",
    "pascentemo": "pascentar",
    "pascentemos": "pascentar",
    "pascentes": "pascente",
    "pascento": "pascentar",
    "pascentou": "pascentar",
    "pascentá": "pascentar",
    "pascentámo": "pascentar",
    "pascentámos": "pascentar",
    "pascentáramo": "pascentar",
    "pascentáramos": "pascentar",
    "pascentárei": "pascentar",
    "pascentáreis": "pascentar",
    "pascentásseis": "pascentar",
    "pascentássemos": "pascentar",
    "pascentávamo": "pascentar",
    "pascentávamos": "pascentar",
    "pascentávei": "pascentar",
    "pascentáveis": "pascentar",
    "pascera": "pascer",
    "pasceram": "pascer",
    "pasceras": "pascer",
    "pascerde": "pascer",
    "pascerdes": "pascer",
    "pascere": "pascer",
    "pascerei": "pascer",
    "pascereis": "pascer",
    "pascerem": "pascer",
    "pasceremos": "pascer",
    "pasceres": "pascer",
    "pasceria": "pascer",
    "pasceriam": "pascer",
    "pascerias": "pascer",
    "pascermo": "pascer",
    "pascermos": "pascer",
    "pascerá": "pascer",
    "pascerás": "pascer",
    "pascerão": "pascer",
    "pasceríamos": "pascer",
    "pasceríeis": "pascer",
    "pasces": "pascer",
    "pascesse": "pascer",
    "pascessem": "pascer",
    "pascesses": "pascer",
    "pasceste": "pascer",
    "pascestes": "pascer",
    "pasceu": "pascer",
    "pasci": "pascer",
    "pascia": "pascer",
    "pasciam": "pascer",
    "pascias": "pascer",
    "pascida": "pascer",
    "pascidas": "pascer",
    "pascido": "pascer",
    "pascidos": "pascer",
    "pascigos": "pascigo",
    "pascigosa": "pascigoso",
    "pascigosas": "pascigoso",
    "pascigosos": "pascigoso",
    "pascoa": "pascoar",
    "pascoada": "pascoar",
    "pascoadas": "pascoar",
    "pascoado": "pascoar",
    "pascoados": "pascoar",
    "pascoai": "pascoar",
    "pascoais": "pascoar",
    "pascoam": "pascoar",
    "pascoamo": "pascoar",
    "pascoamos": "pascoar",
    "pascoando": "pascoar",
    "pascoara": "pascoar",
    "pascoaram": "pascoar",
    "pascoaras": "pascoar",
    "pascoardes": "pascoar",
    "pascoarei": "pascoar",
    "pascoareis": "pascoar",
    "pascoarem": "pascoar",
    "pascoaremos": "pascoar",
    "pascoares": "pascoar",
    "pascoaria": "pascoar",
    "pascoariam": "pascoar",
    "pascoarias": "pascoar",
    "pascoarmo": "pascoar",
    "pascoarmos": "pascoar",
    "pascoará": "pascoar",
    "pascoarás": "pascoar",
    "pascoarão": "pascoar",
    "pascoaríamos": "pascoar",
    "pascoaríeis": "pascoar",
    "pascoas": "pascoar",
    "pascoasse": "pascoar",
    "pascoassem": "pascoar",
    "pascoasses": "pascoar",
    "pascoaste": "pascoar",
    "pascoastes": "pascoar",
    "pascoava": "pascoar",
    "pascoavam": "pascoar",
    "pascoavas": "pascoar",
    "pascoe": "pascoar",
    "pascoei": "pascoar",
    "pascoeis": "pascoar",
    "pascoelas": "pascoela",
    "pascoem": "pascoar",
    "pascoemo": "pascoar",
    "pascoemos": "pascoar",
    "pascoes": "pascoar",
    "pascoinhas": "pascoinha",
    "pascoo": "pascoar",
    "pascoou": "pascoar",
    "pascoámo": "pascoar",
    "pascoámos": "pascoar",
    "pascoáramo": "pascoar",
    "pascoáramos": "pascoar",
    "pascoáreis": "pascoar",
    "pascoásseis": "pascoar",
    "pascoássemos": "pascoar",
    "pascoávamo": "pascoar",
    "pascoávamos": "pascoar",
    "pascoáveis": "pascoar",
    "pascácia": "pascácio",
    "pascácias": "pascácio",
    "pascácios": "pascácio",
    "pascê": "pascer",
    "pascêramo": "pascer",
    "pascêramos": "pascer",
    "pascêrei": "pascer",
    "pascêreis": "pascer",
    "pascêsseis": "pascer",
    "pascêssemos": "pascer",
    "pascíamo": "pascer",
    "pascíamos": "pascer",
    "pascíei": "pascer",
    "pascíeis": "pascer",
    "pasigrafias": "pasigrafia",
    "pasiráfica": "pasiráfico",
    "pasiráficas": "pasiráfico",
    "pasiráficos": "pasiráfico",
    "pasma": "pasmar",
    "pasmaceada": "pasmacear",
    "pasmaceadas": "pasmacear",
    "pasmaceado": "pasmacear",
    "pasmaceados": "pasmacear",
    "pasmaceai": "pasmacear",
    "pasmaceais": "pasmacear",
    "pasmaceamo": "pasmacear",
    "pasmaceamos": "pasmacear",
    "pasmaceando": "pasmacear",
    "pasmaceara": "pasmacear",
    "pasmacearam": "pasmacear",
    "pasmacearas": "pasmacear",
    "pasmaceardes": "pasmacear",
    "pasmacearei": "pasmacear",
    "pasmaceareis": "pasmacear",
    "pasmacearem": "pasmacear",
    "pasmacearemos": "pasmacear",
    "pasmaceares": "pasmacear",
    "pasmacearia": "pasmacear",
    "pasmaceariam": "pasmacear",
    "pasmacearias": "pasmacear",
    "pasmacearmo": "pasmacear",
    "pasmacearmos": "pasmacear",
    "pasmaceará": "pasmacear",
    "pasmacearás": "pasmacear",
    "pasmacearão": "pasmacear",
    "pasmacearíamos": "pasmacear",
    "pasmacearíeis": "pasmacear",
    "pasmaceasse": "pasmacear",
    "pasmaceassem": "pasmacear",
    "pasmaceasses": "pasmacear",
    "pasmaceaste": "pasmacear",
    "pasmaceastes": "pasmacear",
    "pasmaceava": "pasmacear",
    "pasmaceavam": "pasmacear",
    "pasmaceavas": "pasmacear",
    "pasmaceei": "pasmacear",
    "pasmaceeis": "pasmacear",
    "pasmaceemo": "pasmacear",
    "pasmaceemos": "pasmacear",
    "pasmaceia": "pasmacear",
    "pasmaceiam": "pasmacear",
    "pasmaceias": "pasmacear",
    "pasmaceie": "pasmacear",
    "pasmaceiem": "pasmacear",
    "pasmaceies": "pasmacear",
    "pasmaceio": "pasmacear",
    "pasmaceiras": "pasmaceira",
    "pasmaceou": "pasmacear",
    "pasmaceámo": "pasmacear",
    "pasmaceámos": "pasmacear",
    "pasmaceáramo": "pasmacear",
    "pasmaceáramos": "pasmacear",
    "pasmaceáreis": "pasmacear",
    "pasmaceásseis": "pasmacear",
    "pasmaceássemos": "pasmacear",
    "pasmaceávamo": "pasmacear",
    "pasmaceávamos": "pasmacear",
    "pasmaceáveis": "pasmacear",
    "pasmada": "pasmar",
    "pasmadas": "pasmar",
    "pasmadinha": "pasmado",
    "pasmadinhas": "pasmado",
    "pasmadinho": "pasmado",
    "pasmadinhos": "pasmado",
    "pasmadita": "pasmado",
    "pasmaditas": "pasmado",
    "pasmadito": "pasmado",
    "pasmaditos": "pasmado",
    "pasmado": "pasmar",
    "pasmados": "pasmar",
    "pasmadíssima": "pasmado",
    "pasmadíssimas": "pasmado",
    "pasmadíssimo": "pasmado",
    "pasmadíssimos": "pasmado",
    "pasmai": "pasmar",
    "pasmais": "pasmar",
    "pasmam": "pasmar",
    "pasmamo": "pasmar",
    "pasmamos": "pasmar",
    "pasmando": "pasmar",
    "pasmara": "pasmar",
    "pasmaram": "pasmar",
    "pasmaras": "pasmar",
    "pasmarde": "pasmar",
    "pasmardes": "pasmar",
    "pasmare": "pasmar",
    "pasmarei": "pasmar",
    "pasmareis": "pasmar",
    "pasmarem": "pasmar",
    "pasmaremos": "pasmar",
    "pasmares": "pasmar",
    "pasmaria": "pasmar",
    "pasmariam": "pasmar",
    "pasmarias": "pasmar",
    "pasmarmo": "pasmar",
    "pasmarmos": "pasmar",
    "pasmará": "pasmar",
    "pasmarás": "pasmar",
    "pasmarão": "pasmar",
    "pasmaríamos": "pasmar",
    "pasmaríeis": "pasmar",
    "pasmas": "pasmar",
    "pasmasse": "pasmar",
    "pasmassem": "pasmar",
    "pasmasses": "pasmar",
    "pasmaste": "pasmar",
    "pasmastes": "pasmar",
    "pasmatórios": "pasmatório",
    "pasmava": "pasmar",
    "pasmavam": "pasmar",
    "pasmavas": "pasmar",
    "pasme": "pasmar",
    "pasmei": "pasmar",
    "pasmeis": "pasmar",
    "pasmem": "pasmar",
    "pasmemo": "pasmar",
    "pasmemos": "pasmar",
    "pasmes": "pasmar",
    "pasmo": "pasmar",
    "pasmos": "pasmo",
    "pasmosa": "pasmoso",
    "pasmosas": "pasmoso",
    "pasmosos": "pasmoso",
    "pasmou": "pasmar",
    "pasmá": "pasmar",
    "pasmámo": "pasmar",
    "pasmámos": "pasmar",
    "pasmáramo": "pasmar",
    "pasmáramos": "pasmar",
    "pasmárei": "pasmar",
    "pasmáreis": "pasmar",
    "pasmásseis": "pasmar",
    "pasmássemos": "pasmar",
    "pasmávamo": "pasmar",
    "pasmávamos": "pasmar",
    "pasmávei": "pasmar",
    "pasmáveis": "pasmar",
    "paspalha": "paspalho",
    "paspalhas": "paspalho",
    "paspalhaças": "paspalhaça",
    "paspalhaços": "paspalhaço",
    "paspalhices": "paspalhice",
    "paspalhona": "paspalho",
    "paspalhonas": "paspalho",
    "paspalhos": "paspalho",
    "paspalhuças": "paspalhuça",
    "paspalháses": "paspalhás",
    "paspalhão": "paspalho",
    "paspalhóses": "paspalhós",
    "paspalhões": "paspalho",
    "pasquina": "pasquinar",
    "pasquinada": "pasquinar",
    "pasquinadas": "pasquinar",
    "pasquinado": "pasquinar",
    "pasquinados": "pasquinar",
    "pasquinagens": "pasquinagem",
    "pasquinai": "pasquinar",
    "pasquinais": "pasquinar",
    "pasquinam": "pasquinar",
    "pasquinamo": "pasquinar",
    "pasquinamos": "pasquinar",
    "pasquinando": "pasquinar",
    "pasquinara": "pasquinar",
    "pasquinaram": "pasquinar",
    "pasquinaras": "pasquinar",
    "pasquinarde": "pasquinar",
    "pasquinardes": "pasquinar",
    "pasquinare": "pasquinar",
    "pasquinarei": "pasquinar",
    "pasquinareis": "pasquinar",
    "pasquinarem": "pasquinar",
    "pasquinaremos": "pasquinar",
    "pasquinares": "pasquinar",
    "pasquinaria": "pasquinar",
    "pasquinariam": "pasquinar",
    "pasquinarias": "pasquinar",
    "pasquinarmo": "pasquinar",
    "pasquinarmos": "pasquinar",
    "pasquinará": "pasquinar",
    "pasquinarás": "pasquinar",
    "pasquinarão": "pasquinar",
    "pasquinaríamos": "pasquinar",
    "pasquinaríeis": "pasquinar",
    "pasquinas": "pasquinar",
    "pasquinasse": "pasquinar",
    "pasquinassem": "pasquinar",
    "pasquinasses": "pasquinar",
    "pasquinaste": "pasquinar",
    "pasquinastes": "pasquinar",
    "pasquinava": "pasquinar",
    "pasquinavam": "pasquinar",
    "pasquinavas": "pasquinar",
    "pasquine": "pasquinar",
    "pasquinei": "pasquinar",
    "pasquineira": "pasquineiro",
    "pasquineiras": "pasquineiro",
    "pasquineiros": "pasquineiro",
    "pasquineis": "pasquinar",
    "pasquinem": "pasquinar",
    "pasquinemo": "pasquinar",
    "pasquinemos": "pasquinar",
    "pasquines": "pasquinar",
    "pasquino": "pasquinar",
    "pasquinou": "pasquinar",
    "pasquins": "pasquim",
    "pasquiná": "pasquinar",
    "pasquinámo": "pasquinar",
    "pasquinámos": "pasquinar",
    "pasquináramo": "pasquinar",
    "pasquináramos": "pasquinar",
    "pasquinárei": "pasquinar",
    "pasquináreis": "pasquinar",
    "pasquinásseis": "pasquinar",
    "pasquinássemos": "pasquinar",
    "pasquinávamo": "pasquinar",
    "pasquinávamos": "pasquinar",
    "pasquinávei": "pasquinar",
    "pasquináveis": "pasquinar",
    "passa": "passar",
    "passada": "passar",
    "passadas": "passar",
    "passadeiras": "passadeira",
    "passadelas": "passadela",
    "passadinha": "passado",
    "passadinhas": "passado",
    "passadinho": "passado",
    "passadinhos": "passado",
    "passadios": "passadio",
    "passadismos": "passadismo",
    "passadistas": "passadista",
    "passadita": "passado",
    "passaditas": "passado",
    "passadito": "passado",
    "passaditos": "passado",
    "passadiça": "passadiço",
    "passadiças": "passadiço",
    "passadiços": "passadiço",
    "passado": "passar",
    "passadoiros": "passadoiro",
    "passadora": "passador",
    "passadoras": "passador",
    "passadores": "passador",
    "passados": "passar",
    "passadouros": "passadouro",
    "passadíssima": "passado",
    "passadíssimas": "passado",
    "passadíssimo": "passado",
    "passadíssimos": "passado",
    "passageada": "passagear",
    "passageadas": "passagear",
    "passageado": "passagear",
    "passageados": "passagear",
    "passageai": "passagear",
    "passageais": "passagear",
    "passageamo": "passagear",
    "passageamos": "passagear",
    "passageando": "passagear",
    "passageara": "passagear",
    "passagearam": "passagear",
    "passagearas": "passagear",
    "passagearde": "passagear",
    "passageardes": "passagear",
    "passageare": "passagear",
    "passagearei": "passagear",
    "passageareis": "passagear",
    "passagearem": "passagear",
    "passagearemos": "passagear",
    "passageares": "passagear",
    "passagearia": "passagear",
    "passageariam": "passagear",
    "passagearias": "passagear",
    "passagearmo": "passagear",
    "passagearmos": "passagear",
    "passageará": "passagear",
    "passagearás": "passagear",
    "passagearão": "passagear",
    "passagearíamos": "passagear",
    "passagearíeis": "passagear",
    "passageasse": "passagear",
    "passageassem": "passagear",
    "passageasses": "passagear",
    "passageaste": "passagear",
    "passageastes": "passagear",
    "passageava": "passagear",
    "passageavam": "passagear",
    "passageavas": "passagear",
    "passageei": "passagear",
    "passageeis": "passagear",
    "passageemo": "passagear",
    "passageemos": "passagear",
    "passageia": "passagear",
    "passageiam": "passagear",
    "passageias": "passagear",
    "passageie": "passagear",
    "passageiem": "passagear",
    "passageies": "passagear",
    "passageio": "passagear",
    "passageira": "passageiro",
    "passageiras": "passageiro",
    "passageiros": "passageiro",
    "passagens": "passagem",
    "passageou": "passagear",
    "passageá": "passagear",
    "passageámo": "passagear",
    "passageámos": "passagear",
    "passageáramo": "passagear",
    "passageáramos": "passagear",
    "passageárei": "passagear",
    "passageáreis": "passagear",
    "passageásseis": "passagear",
    "passageássemos": "passagear",
    "passageávamo": "passagear",
    "passageávamos": "passagear",
    "passageávei": "passagear",
    "passageáveis": "passagear",
    "passai": "passar",
    "passais": "passar",
    "passaja": "passajar",
    "passajada": "passajar",
    "passajadas": "passajar",
    "passajado": "passajar",
    "passajados": "passajar",
    "passajai": "passajar",
    "passajais": "passajar",
    "passajam": "passajar",
    "passajamo": "passajar",
    "passajamos": "passajar",
    "passajando": "passajar",
    "passajara": "passajar",
    "passajaram": "passajar",
    "passajaras": "passajar",
    "passajarde": "passajar",
    "passajardes": "passajar",
    "passajare": "passajar",
    "passajarei": "passajar",
    "passajareis": "passajar",
    "passajarem": "passajar",
    "passajaremos": "passajar",
    "passajares": "passajar",
    "passajaria": "passajar",
    "passajariam": "passajar",
    "passajarias": "passajar",
    "passajarmo": "passajar",
    "passajarmos": "passajar",
    "passajará": "passajar",
    "passajarás": "passajar",
    "passajarão": "passajar",
    "passajaríamos": "passajar",
    "passajaríeis": "passajar",
    "passajas": "passajar",
    "passajasse": "passajar",
    "passajassem": "passajar",
    "passajasses": "passajar",
    "passajaste": "passajar",
    "passajastes": "passajar",
    "passajava": "passajar",
    "passajavam": "passajar",
    "passajavas": "passajar",
    "passaje": "passajar",
    "passajei": "passajar",
    "passajeis": "passajar",
    "passajem": "passajar",
    "passajemo": "passajar",
    "passajemos": "passajar",
    "passajes": "passajar",
    "passajo": "passajar",
    "passajou": "passajar",
    "passajá": "passajar",
    "passajámo": "passajar",
    "passajámos": "passajar",
    "passajáramo": "passajar",
    "passajáramos": "passajar",
    "passajárei": "passajar",
    "passajáreis": "passajar",
    "passajásseis": "passajar",
    "passajássemos": "passajar",
    "passajávamo": "passajar",
    "passajávamos": "passajar",
    "passajávei": "passajar",
    "passajáveis": "passajar",
    "passam": "passar",
    "passamana": "passamanar",
    "passamanada": "passamanar",
    "passamanadas": "passamanar",
    "passamanado": "passamanar",
    "passamanados": "passamanar",
    "passamanai": "passamanar",
    "passamanais": "passamanar",
    "passamanam": "passamanar",
    "passamanamo": "passamanar",
    "passamanamos": "passamanar",
    "passamanando": "passamanar",
    "passamanara": "passamanar",
    "passamanaram": "passamanar",
    "passamanaras": "passamanar",
    "passamanarde": "passamanar",
    "passamanardes": "passamanar",
    "passamanare": "passamanar",
    "passamanarei": "passamanar",
    "passamanareis": "passamanar",
    "passamanarem": "passamanar",
    "passamanaremos": "passamanar",
    "passamanares": "passamanar",
    "passamanaria": "passamanar",
    "passamanariam": "passamanar",
    "passamanarias": "passamanaria",
    "passamanarmo": "passamanar",
    "passamanarmos": "passamanar",
    "passamanará": "passamanar",
    "passamanarás": "passamanar",
    "passamanarão": "passamanar",
    "passamanaríamos": "passamanar",
    "passamanaríeis": "passamanar",
    "passamanas": "passamanar",
    "passamanasse": "passamanar",
    "passamanassem": "passamanar",
    "passamanasses": "passamanar",
    "passamanaste": "passamanar",
    "passamanastes": "passamanar",
    "passamanava": "passamanar",
    "passamanavam": "passamanar",
    "passamanavas": "passamanar",
    "passamane": "passamanar",
    "passamanei": "passamanar",
    "passamaneira": "passamaneiro",
    "passamaneiras": "passamaneiro",
    "passamaneiros": "passamaneiro",
    "passamaneis": "passamanar",
    "passamanem": "passamanar",
    "passamanemo": "passamanar",
    "passamanemos": "passamanar",
    "passamanes": "passamanar",
    "passamano": "passamanar",
    "passamanou": "passamanar",
    "passamaná": "passamanar",
    "passamanámo": "passamanar",
    "passamanámos": "passamanar",
    "passamanáramo": "passamanar",
    "passamanáramos": "passamanar",
    "passamanárei": "passamanar",
    "passamanáreis": "passamanar",
    "passamanásseis": "passamanar",
    "passamanássemos": "passamanar",
    "passamanávamo": "passamanar",
    "passamanávamos": "passamanar",
    "passamanávei": "passamanar",
    "passamanáveis": "passamanar",
    "passamentos": "passamento",
    "passamo": "passar",
    "passamos": "passar",
    "passando": "passar",
    "passantes": "passante",
    "passaportes": "passaporte",
    "passara": "passar",
    "passaradas": "passarada",
    "passaram": "passar",
    "passaras": "passar",
    "passarde": "passar",
    "passardes": "passar",
    "passare": "passar",
    "passareda": "passaredo",
    "passaredas": "passaredo",
    "passaredos": "passaredo",
    "passarei": "passar",
    "passareira": "passareiro",
    "passareiras": "passareiro",
    "passareiros": "passareiro",
    "passareis": "passar",
    "passarelas": "passarela",
    "passarem": "passar",
    "passaremos": "passar",
    "passares": "passar",
    "passaria": "passar",
    "passariam": "passar",
    "passarias": "passar",
    "passarinha": "passarinhar",
    "passarinhada": "passarinhar",
    "passarinhadas": "passarinhar",
    "passarinhado": "passarinhar",
    "passarinhados": "passarinhar",
    "passarinhai": "passarinhar",
    "passarinhais": "passarinhar",
    "passarinham": "passarinhar",
    "passarinhamo": "passarinhar",
    "passarinhamos": "passarinhar",
    "passarinhando": "passarinhar",
    "passarinhara": "passarinhar",
    "passarinharam": "passarinhar",
    "passarinharas": "passarinhar",
    "passarinhardes": "passarinhar",
    "passarinharei": "passarinhar",
    "passarinhareis": "passarinhar",
    "passarinharem": "passarinhar",
    "passarinharemos": "passarinhar",
    "passarinhares": "passarinhar",
    "passarinharia": "passarinhar",
    "passarinhariam": "passarinhar",
    "passarinharias": "passarinhar",
    "passarinharmo": "passarinhar",
    "passarinharmos": "passarinhar",
    "passarinhará": "passarinhar",
    "passarinharás": "passarinhar",
    "passarinharão": "passarinhar",
    "passarinharíamos": "passarinhar",
    "passarinharíeis": "passarinhar",
    "passarinhas": "passarinhar",
    "passarinhasse": "passarinhar",
    "passarinhassem": "passarinhar",
    "passarinhasses": "passarinhar",
    "passarinhaste": "passarinhar",
    "passarinhastes": "passarinhar",
    "passarinhava": "passarinhar",
    "passarinhavam": "passarinhar",
    "passarinhavas": "passarinhar",
    "passarinhe": "passarinhar",
    "passarinhei": "passarinhar",
    "passarinheira": "passarinheiro",
    "passarinheiras": "passarinheiro",
    "passarinheiros": "passarinheiro",
    "passarinheis": "passarinhar",
    "passarinhem": "passarinhar",
    "passarinhemo": "passarinhar",
    "passarinhemos": "passarinhar",
    "passarinhes": "passarinhar",
    "passarinho": "pássaro",
    "passarinhos": "pássaro",
    "passarinhou": "passarinhar",
    "passarinhámo": "passarinhar",
    "passarinhámos": "passarinhar",
    "passarinháramo": "passarinhar",
    "passarinháramos": "passarinhar",
    "passarinháreis": "passarinhar",
    "passarinhásseis": "passarinhar",
    "passarinhássemos": "passarinhar",
    "passarinhávamo": "passarinhar",
    "passarinhávamos": "passarinhar",
    "passarinháveis": "passarinhar",
    "passarita": "passaritar",
    "passaritada": "passaritar",
    "passaritadas": "passaritar",
    "passaritado": "passaritar",
    "passaritados": "passaritar",
    "passaritai": "passaritar",
    "passaritais": "passaritar",
    "passaritam": "passaritar",
    "passaritamo": "passaritar",
    "passaritamos": "passaritar",
    "passaritando": "passaritar",
    "passaritara": "passaritar",
    "passaritaram": "passaritar",
    "passaritaras": "passaritar",
    "passaritardes": "passaritar",
    "passaritarei": "passaritar",
    "passaritareis": "passaritar",
    "passaritarem": "passaritar",
    "passaritaremos": "passaritar",
    "passaritares": "passaritar",
    "passaritaria": "passaritar",
    "passaritariam": "passaritar",
    "passaritarias": "passaritar",
    "passaritarmo": "passaritar",
    "passaritarmos": "passaritar",
    "passaritará": "passaritar",
    "passaritarás": "passaritar",
    "passaritarão": "passaritar",
    "passaritaríamos": "passaritar",
    "passaritaríeis": "passaritar",
    "passaritas": "passaritar",
    "passaritasse": "passaritar",
    "passaritassem": "passaritar",
    "passaritasses": "passaritar",
    "passaritaste": "passaritar",
    "passaritastes": "passaritar",
    "passaritava": "passaritar",
    "passaritavam": "passaritar",
    "passaritavas": "passaritar",
    "passarite": "passaritar",
    "passaritei": "passaritar",
    "passariteis": "passaritar",
    "passaritem": "passaritar",
    "passaritemo": "passaritar",
    "passaritemos": "passaritar",
    "passarites": "passaritar",
    "passarito": "pássaro",
    "passaritos": "pássaro",
    "passaritou": "passaritar",
    "passaritámo": "passaritar",
    "passaritámos": "passaritar",
    "passaritáramo": "passaritar",
    "passaritáramos": "passaritar",
    "passaritáreis": "passaritar",
    "passaritásseis": "passaritar",
    "passaritássemos": "passaritar",
    "passaritávamo": "passaritar",
    "passaritávamos": "passaritar",
    "passaritáveis": "passaritar",
    "passarmo": "passar",
    "passarmos": "passar",
    "passaroca": "passaroco",
    "passarocas": "passaroco",
    "passarocos": "passaroco",
    "passarola": "passarolo",
    "passarolas": "passarolo",
    "passarolos": "passarolo",
    "passarona": "passarão",
    "passaronas": "passarão",
    "passará": "passar",
    "passarás": "passar",
    "passarão": "passar",
    "passaríamos": "passar",
    "passaríeis": "passar",
    "passarões": "passarão",
    "passas": "passar",
    "passasse": "passar",
    "passassem": "passar",
    "passasses": "passar",
    "passaste": "passar",
    "passastes": "passar",
    "passatempismos": "passatempismo",
    "passatempistas": "passatempista",
    "passatempos": "passatempo",
    "passava": "passar",
    "passavam": "passar",
    "passavantes": "passavante",
    "passavas": "passar",
    "passe": "passar",
    "passeada": "passear",
    "passeadas": "passear",
    "passeado": "passear",
    "passeadoiros": "passeadoiro",
    "passeadora": "passeador",
    "passeadoras": "passeador",
    "passeadores": "passeador",
    "passeados": "passear",
    "passeadouros": "passeadouro",
    "passeai": "passear",
    "passeais": "passear",
    "passeamo": "passear",
    "passeamos": "passear",
    "passeando": "passear",
    "passeantes": "passeante",
    "passeara": "passear",
    "passearam": "passear",
    "passearas": "passear",
    "passearde": "passear",
    "passeardes": "passear",
    "passeare": "passear",
    "passearei": "passear",
    "passeareis": "passear",
    "passearem": "passear",
    "passearemos": "passear",
    "passeares": "passear",
    "passearia": "passear",
    "passeariam": "passear",
    "passearias": "passear",
    "passearmo": "passear",
    "passearmos": "passear",
    "passeará": "passear",
    "passearás": "passear",
    "passearão": "passear",
    "passearíamos": "passear",
    "passearíeis": "passear",
    "passeasse": "passear",
    "passeassem": "passear",
    "passeasses": "passear",
    "passeaste": "passear",
    "passeastes": "passear",
    "passeatas": "passeata",
    "passeava": "passear",
    "passeavam": "passear",
    "passeavas": "passear",
    "passeei": "passear",
    "passeeis": "passear",
    "passeemo": "passear",
    "passeemos": "passear",
    "passei": "passar",
    "passeia": "passear",
    "passeiam": "passear",
    "passeias": "passear",
    "passeie": "passear",
    "passeiem": "passear",
    "passeies": "passear",
    "passeio": "passear",
    "passeios": "passeio",
    "passeira": "passeiro",
    "passeiras": "passeiro",
    "passeiros": "passeiro",
    "passeis": "passar",
    "passem": "passar",
    "passemo": "passar",
    "passemos": "passar",
    "passenta": "passento",
    "passentas": "passento",
    "passentos": "passento",
    "passeou": "passear",
    "passerelles": "passerelle",
    "passeriformes": "passeriforme",
    "passes": "passe",
    "passeá": "passear",
    "passeámo": "passear",
    "passeámos": "passear",
    "passeáramo": "passear",
    "passeáramos": "passear",
    "passeárei": "passear",
    "passeáreis": "passear",
    "passeásseis": "passear",
    "passeássemos": "passear",
    "passeávamo": "passear",
    "passeávamos": "passear",
    "passeávei": "passear",
    "passeáveis": "passear",
    "passibilidades": "passibilidade",
    "passifloras": "passiflora",
    "passifloráceas": "passiflorácea",
    "passinha": "passinhar",
    "passinhada": "passinhar",
    "passinhadas": "passinhar",
    "passinhado": "passinhar",
    "passinhados": "passinhar",
    "passinhai": "passinhar",
    "passinhais": "passinhar",
    "passinham": "passinhar",
    "passinhamo": "passinhar",
    "passinhamos": "passinhar",
    "passinhando": "passinhar",
    "passinhara": "passinhar",
    "passinharam": "passinhar",
    "passinharas": "passinhar",
    "passinhardes": "passinhar",
    "passinharei": "passinhar",
    "passinhareis": "passinhar",
    "passinharem": "passinhar",
    "passinharemos": "passinhar",
    "passinhares": "passinhar",
    "passinharia": "passinhar",
    "passinhariam": "passinhar",
    "passinharias": "passinhar",
    "passinharmo": "passinhar",
    "passinharmos": "passinhar",
    "passinhará": "passinhar",
    "passinharás": "passinhar",
    "passinharão": "passinhar",
    "passinharíamos": "passinhar",
    "passinharíeis": "passinhar",
    "passinhas": "passinhar",
    "passinhasse": "passinhar",
    "passinhassem": "passinhar",
    "passinhasses": "passinhar",
    "passinhaste": "passinhar",
    "passinhastes": "passinhar",
    "passinhava": "passinhar",
    "passinhavam": "passinhar",
    "passinhavas": "passinhar",
    "passinhe": "passinhar",
    "passinhei": "passinhar",
    "passinheis": "passinhar",
    "passinhem": "passinhar",
    "passinhemo": "passinhar",
    "passinhemos": "passinhar",
    "passinhes": "passinhar",
    "passinho": "passo",
    "passinhos": "passo",
    "passinhou": "passinhar",
    "passinhámo": "passinhar",
    "passinhámos": "passinhar",
    "passinháramo": "passinhar",
    "passinháramos": "passinhar",
    "passinháreis": "passinhar",
    "passinhásseis": "passinhar",
    "passinhássemos": "passinhar",
    "passinhávamo": "passinhar",
    "passinhávamos": "passinhar",
    "passinháveis": "passinhar",
    "passionais": "passional",
    "passionalidades": "passionalidade",
    "passionários": "passionário",
    "passito": "passo",
    "passitos": "passo",
    "passiva": "passivo",
    "passivada": "passivar",
    "passivadas": "passivar",
    "passivado": "passivar",
    "passivados": "passivar",
    "passivai": "passivar",
    "passivais": "passivar",
    "passivam": "passivar",
    "passivamo": "passivar",
    "passivamos": "passivar",
    "passivando": "passivar",
    "passivara": "passivar",
    "passivaram": "passivar",
    "passivaras": "passivar",
    "passivarde": "passivar",
    "passivardes": "passivar",
    "passivare": "passivar",
    "passivarei": "passivar",
    "passivareis": "passivar",
    "passivarem": "passivar",
    "passivaremos": "passivar",
    "passivares": "passivar",
    "passivaria": "passivar",
    "passivariam": "passivar",
    "passivarias": "passivar",
    "passivarmo": "passivar",
    "passivarmos": "passivar",
    "passivará": "passivar",
    "passivarás": "passivar",
    "passivarão": "passivar",
    "passivaríamos": "passivar",
    "passivaríeis": "passivar",
    "passivas": "passivo",
    "passivasse": "passivar",
    "passivassem": "passivar",
    "passivasses": "passivar",
    "passivaste": "passivar",
    "passivastes": "passivar",
    "passivava": "passivar",
    "passivavam": "passivar",
    "passivavas": "passivar",
    "passivazinha": "passivo",
    "passivazinhas": "passivo",
    "passivazita": "passivo",
    "passivazitas": "passivo",
    "passive": "passivar",
    "passivei": "passivar",
    "passiveis": "passivar",
    "passivem": "passivar",
    "passivemo": "passivar",
    "passivemos": "passivar",
    "passives": "passivar",
    "passividades": "passividade",
    "passivo": "passivar",
    "passivos": "passivo",
    "passivou": "passivar",
    "passivozinho": "passivo",
    "passivozinhos": "passivo",
    "passivozito": "passivo",
    "passivozitos": "passivo",
    "passivá": "passivar",
    "passivámo": "passivar",
    "passivámos": "passivar",
    "passiváramo": "passivar",
    "passiváramos": "passivar",
    "passivárei": "passivar",
    "passiváreis": "passivar",
    "passivásseis": "passivar",
    "passivássemos": "passivar",
    "passivávamo": "passivar",
    "passivávamos": "passivar",
    "passivávei": "passivar",
    "passiváveis": "passivável",
    "passo": "passar",
    "passos": "passo",
    "passou": "passar",
    "passá": "passar",
    "passámo": "passar",
    "passámos": "passar",
    "passáramo": "passar",
    "passáramos": "passar",
    "passárei": "passar",
    "passáreis": "passar",
    "passásseis": "passar",
    "passássemos": "passar",
    "passávamo": "passar",
    "passávamos": "passar",
    "passávei": "passar",
    "passáveis": "passável",
    "passíveis": "passível",
    "pasta": "pastar",
    "pastada": "pastar",
    "pastadas": "pastar",
    "pastado": "pastar",
    "pastadoiros": "pastadoiro",
    "pastados": "pastar",
    "pastadouros": "pastadouro",
    "pastagens": "pastagem",
    "pastai": "pastar",
    "pastais": "pastar",
    "pastam": "pastar",
    "pastamo": "pastar",
    "pastamos": "pastar",
    "pastando": "pastar",
    "pastara": "pastar",
    "pastaram": "pastar",
    "pastaras": "pastar",
    "pastarde": "pastar",
    "pastardes": "pastar",
    "pastare": "pastar",
    "pastarei": "pastar",
    "pastareis": "pastar",
    "pastarem": "pastar",
    "pastaremos": "pastar",
    "pastares": "pastar",
    "pastaria": "pastar",
    "pastariam": "pastar",
    "pastarias": "pastar",
    "pastarmo": "pastar",
    "pastarmos": "pastar",
    "pastará": "pastar",
    "pastarás": "pastar",
    "pastarão": "pastar",
    "pastaríamos": "pastar",
    "pastaríeis": "pastar",
    "pastas": "pastar",
    "pastasse": "pastar",
    "pastassem": "pastar",
    "pastasses": "pastar",
    "pastaste": "pastar",
    "pastastes": "pastar",
    "pastava": "pastar",
    "pastavam": "pastar",
    "pastavas": "pastar",
    "paste": "pastar",
    "pastei": "pastar",
    "pasteis": "pastar",
    "pasteja": "pastejar",
    "pastejada": "pastejar",
    "pastejadas": "pastejar",
    "pastejado": "pastejar",
    "pastejados": "pastejar",
    "pastejai": "pastejar",
    "pastejais": "pastejar",
    "pastejam": "pastejar",
    "pastejamo": "pastejar",
    "pastejamos": "pastejar",
    "pastejando": "pastejar",
    "pastejara": "pastejar",
    "pastejaram": "pastejar",
    "pastejaras": "pastejar",
    "pastejardes": "pastejar",
    "pastejarei": "pastejar",
    "pastejareis": "pastejar",
    "pastejarem": "pastejar",
    "pastejaremos": "pastejar",
    "pastejares": "pastejar",
    "pastejaria": "pastejar",
    "pastejariam": "pastejar",
    "pastejarias": "pastejar",
    "pastejarmo": "pastejar",
    "pastejarmos": "pastejar",
    "pastejará": "pastejar",
    "pastejarás": "pastejar",
    "pastejarão": "pastejar",
    "pastejaríamos": "pastejar",
    "pastejaríeis": "pastejar",
    "pastejas": "pastejar",
    "pastejasse": "pastejar",
    "pastejassem": "pastejar",
    "pastejasses": "pastejar",
    "pastejaste": "pastejar",
    "pastejastes": "pastejar",
    "pastejava": "pastejar",
    "pastejavam": "pastejar",
    "pastejavas": "pastejar",
    "pasteje": "pastejar",
    "pastejei": "pastejar",
    "pastejeis": "pastejar",
    "pastejem": "pastejar",
    "pastejemo": "pastejar",
    "pastejemos": "pastejar",
    "pastejes": "pastejar",
    "pastejo": "pastejar",
    "pastejou": "pastejar",
    "pastejámo": "pastejar",
    "pastejámos": "pastejar",
    "pastejáramo": "pastejar",
    "pastejáramos": "pastejar",
    "pastejáreis": "pastejar",
    "pastejásseis": "pastejar",
    "pastejássemos": "pastejar",
    "pastejávamo": "pastejar",
    "pastejávamos": "pastejar",
    "pastejáveis": "pastejar",
    "pasteladas": "pastelada",
    "pastelarias": "pastelaria",
    "pasteleira": "pasteleiro",
    "pasteleiras": "pasteleiro",
    "pasteleiros": "pasteleiro",
    "pastelinhos": "pastelinho",
    "pastelistas": "pastelista",
    "pastelona": "pastelão",
    "pastelonas": "pastelão",
    "pastelões": "pastelão",
    "pastem": "pastar",
    "pastemo": "pastar",
    "pastemos": "pastar",
    "pastes": "pastar",
    "pasteuriana": "pasteuriano",
    "pasteurianas": "pasteuriano",
    "pasteurianos": "pasteuriano",
    "pasteuriza": "pasteurizar",
    "pasteurizada": "pasteurizar",
    "pasteurizadas": "pasteurizar",
    "pasteurizado": "pasteurizar",
    "pasteurizadora": "pasteurizador",
    "pasteurizadoras": "pasteurizador",
    "pasteurizadores": "pasteurizador",
    "pasteurizados": "pasteurizar",
    "pasteurizai": "pasteurizar",
    "pasteurizais": "pasteurizar",
    "pasteurizam": "pasteurizar",
    "pasteurizamo": "pasteurizar",
    "pasteurizamos": "pasteurizar",
    "pasteurizando": "pasteurizar",
    "pasteurizara": "pasteurizar",
    "pasteurizaram": "pasteurizar",
    "pasteurizaras": "pasteurizar",
    "pasteurizarde": "pasteurizar",
    "pasteurizardes": "pasteurizar",
    "pasteurizare": "pasteurizar",
    "pasteurizarei": "pasteurizar",
    "pasteurizareis": "pasteurizar",
    "pasteurizarem": "pasteurizar",
    "pasteurizaremos": "pasteurizar",
    "pasteurizares": "pasteurizar",
    "pasteurizaria": "pasteurizar",
    "pasteurizariam": "pasteurizar",
    "pasteurizarias": "pasteurizar",
    "pasteurizarmo": "pasteurizar",
    "pasteurizarmos": "pasteurizar",
    "pasteurizará": "pasteurizar",
    "pasteurizarás": "pasteurizar",
    "pasteurizarão": "pasteurizar",
    "pasteurizaríamos": "pasteurizar",
    "pasteurizaríeis": "pasteurizar",
    "pasteurizas": "pasteurizar",
    "pasteurizasse": "pasteurizar",
    "pasteurizassem": "pasteurizar",
    "pasteurizasses": "pasteurizar",
    "pasteurizaste": "pasteurizar",
    "pasteurizastes": "pasteurizar",
    "pasteurizava": "pasteurizar",
    "pasteurizavam": "pasteurizar",
    "pasteurizavas": "pasteurizar",
    "pasteurizações": "pasteurização",
    "pasteurize": "pasteurizar",
    "pasteurizei": "pasteurizar",
    "pasteurizeis": "pasteurizar",
    "pasteurizem": "pasteurizar",
    "pasteurizemo": "pasteurizar",
    "pasteurizemos": "pasteurizar",
    "pasteurizes": "pasteurizar",
    "pasteurizo": "pasteurizar",
    "pasteurizou": "pasteurizar",
    "pasteurizá": "pasteurizar",
    "pasteurizámo": "pasteurizar",
    "pasteurizámos": "pasteurizar",
    "pasteurizáramo": "pasteurizar",
    "pasteurizáramos": "pasteurizar",
    "pasteurizárei": "pasteurizar",
    "pasteurizáreis": "pasteurizar",
    "pasteurizásseis": "pasteurizar",
    "pasteurizássemos": "pasteurizar",
    "pasteurizávamo": "pasteurizar",
    "pasteurizávamos": "pasteurizar",
    "pasteurizávei": "pasteurizar",
    "pasteurizáveis": "pasteurizar",
    "pasticha": "pastichar",
    "pastichada": "pastichar",
    "pastichadas": "pastichar",
    "pastichado": "pastichar",
    "pastichados": "pastichar",
    "pastichai": "pastichar",
    "pastichais": "pastichar",
    "pasticham": "pastichar",
    "pastichamo": "pastichar",
    "pastichamos": "pastichar",
    "pastichando": "pastichar",
    "pastichara": "pastichar",
    "pasticharam": "pastichar",
    "pasticharas": "pastichar",
    "pasticharde": "pastichar",
    "pastichardes": "pastichar",
    "pastichare": "pastichar",
    "pasticharei": "pastichar",
    "pastichareis": "pastichar",
    "pasticharem": "pastichar",
    "pasticharemos": "pastichar",
    "pastichares": "pastichar",
    "pasticharia": "pastichar",
    "pastichariam": "pastichar",
    "pasticharias": "pastichar",
    "pasticharmo": "pastichar",
    "pasticharmos": "pastichar",
    "pastichará": "pastichar",
    "pasticharás": "pastichar",
    "pasticharão": "pastichar",
    "pasticharíamos": "pastichar",
    "pasticharíeis": "pastichar",
    "pastichas": "pastichar",
    "pastichasse": "pastichar",
    "pastichassem": "pastichar",
    "pastichasses": "pastichar",
    "pastichaste": "pastichar",
    "pastichastes": "pastichar",
    "pastichava": "pastichar",
    "pastichavam": "pastichar",
    "pastichavas": "pastichar",
    "pastiche": "pastichar",
    "pastichei": "pastichar",
    "pasticheis": "pastichar",
    "pastichem": "pastichar",
    "pastichemo": "pastichar",
    "pastichemos": "pastichar",
    "pastiches": "pastiche",
    "pasticho": "pastichar",
    "pastichos": "pasticho",
    "pastichou": "pastichar",
    "pastichá": "pastichar",
    "pastichámo": "pastichar",
    "pastichámos": "pastichar",
    "pasticháramo": "pastichar",
    "pasticháramos": "pastichar",
    "pastichárei": "pastichar",
    "pasticháreis": "pastichar",
    "pastichásseis": "pastichar",
    "pastichássemos": "pastichar",
    "pastichávamo": "pastichar",
    "pastichávamos": "pastichar",
    "pastichávei": "pastichar",
    "pasticháveis": "pastichar",
    "pastilhas": "pastilha",
    "pastilhinha": "pastilha",
    "pastilhinhas": "pastilha",
    "pastilhita": "pastilha",
    "pastilhitas": "pastilha",
    "pastinagas": "pastinaga",
    "pastinha": "pastinhar",
    "pastinhada": "pastinhar",
    "pastinhadas": "pastinhar",
    "pastinhado": "pastinhar",
    "pastinhados": "pastinhar",
    "pastinhai": "pastinhar",
    "pastinhais": "pastinhar",
    "pastinham": "pastinhar",
    "pastinhamo": "pastinhar",
    "pastinhamos": "pastinhar",
    "pastinhando": "pastinhar",
    "pastinhara": "pastinhar",
    "pastinharam": "pastinhar",
    "pastinharas": "pastinhar",
    "pastinhardes": "pastinhar",
    "pastinharei": "pastinhar",
    "pastinhareis": "pastinhar",
    "pastinharem": "pastinhar",
    "pastinharemos": "pastinhar",
    "pastinhares": "pastinhar",
    "pastinharia": "pastinhar",
    "pastinhariam": "pastinhar",
    "pastinharias": "pastinhar",
    "pastinharmo": "pastinhar",
    "pastinharmos": "pastinhar",
    "pastinhará": "pastinhar",
    "pastinharás": "pastinhar",
    "pastinharão": "pastinhar",
    "pastinharíamos": "pastinhar",
    "pastinharíeis": "pastinhar",
    "pastinhas": "pastinhar",
    "pastinhasse": "pastinhar",
    "pastinhassem": "pastinhar",
    "pastinhasses": "pastinhar",
    "pastinhaste": "pastinhar",
    "pastinhastes": "pastinhar",
    "pastinhava": "pastinhar",
    "pastinhavam": "pastinhar",
    "pastinhavas": "pastinhar",
    "pastinhe": "pastinhar",
    "pastinhei": "pastinhar",
    "pastinheira": "pastinheiro",
    "pastinheiras": "pastinheiro",
    "pastinheiros": "pastinheiro",
    "pastinheis": "pastinhar",
    "pastinhem": "pastinhar",
    "pastinhemo": "pastinhar",
    "pastinhemos": "pastinhar",
    "pastinhes": "pastinhar",
    "pastinho": "pastinhar",
    "pastinhou": "pastinhar",
    "pastinhámo": "pastinhar",
    "pastinhámos": "pastinhar",
    "pastinháramo": "pastinhar",
    "pastinháramos": "pastinhar",
    "pastinháreis": "pastinhar",
    "pastinhásseis": "pastinhar",
    "pastinhássemos": "pastinhar",
    "pastinhávamo": "pastinhar",
    "pastinhávamos": "pastinhar",
    "pastinháveis": "pastinhar",
    "pastios": "pastio",
    "pastita": "pasta",
    "pastitas": "pasta",
    "pasto": "pastar",
    "pastora": "pastorar",
    "pastorada": "pastorar",
    "pastoradas": "pastorar",
    "pastorado": "pastorar",
    "pastorados": "pastorar",
    "pastorai": "pastorar",
    "pastorais": "pastorar",
    "pastoram": "pastorar",
    "pastoramo": "pastorar",
    "pastoramos": "pastorar",
    "pastorando": "pastorar",
    "pastorara": "pastorar",
    "pastoraram": "pastorar",
    "pastoraras": "pastorar",
    "pastorarde": "pastorar",
    "pastorardes": "pastorar",
    "pastorare": "pastorar",
    "pastorarei": "pastorar",
    "pastorareis": "pastorar",
    "pastorarem": "pastorar",
    "pastoraremos": "pastorar",
    "pastorares": "pastorar",
    "pastoraria": "pastorar",
    "pastorariam": "pastorar",
    "pastorarias": "pastorar",
    "pastorarmo": "pastorar",
    "pastorarmos": "pastorar",
    "pastorará": "pastorar",
    "pastorarás": "pastorar",
    "pastorarão": "pastorar",
    "pastoraríamos": "pastorar",
    "pastoraríeis": "pastorar",
    "pastoras": "pastorar",
    "pastorasse": "pastorar",
    "pastorassem": "pastorar",
    "pastorasses": "pastorar",
    "pastoraste": "pastorar",
    "pastorastes": "pastorar",
    "pastorava": "pastorar",
    "pastoravam": "pastorar",
    "pastoravas": "pastorar",
    "pastore": "pastorar",
    "pastoreada": "pastorear",
    "pastoreadas": "pastorear",
    "pastoreado": "pastorear",
    "pastoreados": "pastorear",
    "pastoreai": "pastorear",
    "pastoreais": "pastorear",
    "pastoreamo": "pastorear",
    "pastoreamos": "pastorear",
    "pastoreando": "pastorear",
    "pastoreara": "pastorear",
    "pastorearam": "pastorear",
    "pastorearas": "pastorear",
    "pastorearde": "pastorear",
    "pastoreardes": "pastorear",
    "pastoreare": "pastorear",
    "pastorearei": "pastorear",
    "pastoreareis": "pastorear",
    "pastorearem": "pastorear",
    "pastorearemos": "pastorear",
    "pastoreares": "pastorear",
    "pastorearia": "pastorear",
    "pastoreariam": "pastorear",
    "pastorearias": "pastorear",
    "pastorearmo": "pastorear",
    "pastorearmos": "pastorear",
    "pastoreará": "pastorear",
    "pastorearás": "pastorear",
    "pastorearão": "pastorear",
    "pastorearíamos": "pastorear",
    "pastorearíeis": "pastorear",
    "pastoreasse": "pastorear",
    "pastoreassem": "pastorear",
    "pastoreasses": "pastorear",
    "pastoreaste": "pastorear",
    "pastoreastes": "pastorear",
    "pastoreava": "pastorear",
    "pastoreavam": "pastorear",
    "pastoreavas": "pastorear",
    "pastoreações": "pastoreação",
    "pastoreei": "pastorear",
    "pastoreeis": "pastorear",
    "pastoreemo": "pastorear",
    "pastoreemos": "pastorear",
    "pastorei": "pastorar",
    "pastoreia": "pastorear",
    "pastoreiam": "pastorear",
    "pastoreias": "pastorear",
    "pastoreie": "pastorear",
    "pastoreiem": "pastorear",
    "pastoreies": "pastorear",
    "pastoreio": "pastorear",
    "pastoreios": "pastoreio",
    "pastoreis": "pastorar",
    "pastoreja": "pastorejar",
    "pastorejada": "pastorejar",
    "pastorejadas": "pastorejar",
    "pastorejado": "pastorejar",
    "pastorejados": "pastorejar",
    "pastorejai": "pastorejar",
    "pastorejais": "pastorejar",
    "pastorejam": "pastorejar",
    "pastorejamo": "pastorejar",
    "pastorejamos": "pastorejar",
    "pastorejando": "pastorejar",
    "pastorejara": "pastorejar",
    "pastorejaram": "pastorejar",
    "pastorejaras": "pastorejar",
    "pastorejarde": "pastorejar",
    "pastorejardes": "pastorejar",
    "pastorejare": "pastorejar",
    "pastorejarei": "pastorejar",
    "pastorejareis": "pastorejar",
    "pastorejarem": "pastorejar",
    "pastorejaremos": "pastorejar",
    "pastorejares": "pastorejar",
    "pastorejaria": "pastorejar",
    "pastorejariam": "pastorejar",
    "pastorejarias": "pastorejar",
    "pastorejarmo": "pastorejar",
    "pastorejarmos": "pastorejar",
    "pastorejará": "pastorejar",
    "pastorejarás": "pastorejar",
    "pastorejarão": "pastorejar",
    "pastorejaríamos": "pastorejar",
    "pastorejaríeis": "pastorejar",
    "pastorejas": "pastorejar",
    "pastorejasse": "pastorejar",
    "pastorejassem": "pastorejar",
    "pastorejasses": "pastorejar",
    "pastorejaste": "pastorejar",
    "pastorejastes": "pastorejar",
    "pastorejava": "pastorejar",
    "pastorejavam": "pastorejar",
    "pastorejavas": "pastorejar",
    "pastoreje": "pastorejar",
    "pastorejei": "pastorejar",
    "pastorejeis": "pastorejar",
    "pastorejem": "pastorejar",
    "pastorejemo": "pastorejar",
    "pastorejemos": "pastorejar",
    "pastorejes": "pastorejar",
    "pastorejo": "pastorejar",
    "pastorejou": "pastorejar",
    "pastorejá": "pastorejar",
    "pastorejámo": "pastorejar",
    "pastorejámos": "pastorejar",
    "pastorejáramo": "pastorejar",
    "pastorejáramos": "pastorejar",
    "pastorejárei": "pastorejar",
    "pastorejáreis": "pastorejar",
    "pastorejásseis": "pastorejar",
    "pastorejássemos": "pastorejar",
    "pastorejávamo": "pastorejar",
    "pastorejávamos": "pastorejar",
    "pastorejávei": "pastorejar",
    "pastorejáveis": "pastorejar",
    "pastorelas": "pastorela",
    "pastorem": "pastorar",
    "pastoremo": "pastorar",
    "pastoremos": "pastorar",
    "pastoreou": "pastorear",
    "pastores": "pastorar",
    "pastoreá": "pastorear",
    "pastoreámo": "pastorear",
    "pastoreámos": "pastorear",
    "pastoreáramo": "pastorear",
    "pastoreáramos": "pastorear",
    "pastoreárei": "pastorear",
    "pastoreáreis": "pastorear",
    "pastoreásseis": "pastorear",
    "pastoreássemos": "pastorear",
    "pastoreávamo": "pastorear",
    "pastoreávamos": "pastorear",
    "pastoreávei": "pastorear",
    "pastoreáveis": "pastorear",
    "pastoricidas": "pastoricida",
    "pastorinha": "pastorinho",
    "pastorinhas": "pastorinho",
    "pastorinhos": "pastorinho",
    "pastoris": "pastoril",
    "pastoro": "pastorar",
    "pastorou": "pastorar",
    "pastorá": "pastorar",
    "pastorámo": "pastorar",
    "pastorámos": "pastorar",
    "pastoráramo": "pastorar",
    "pastoráramos": "pastorar",
    "pastorárei": "pastorar",
    "pastoráreis": "pastorar",
    "pastorásseis": "pastorar",
    "pastorássemos": "pastorar",
    "pastorávamo": "pastorar",
    "pastorávamos": "pastorar",
    "pastorávei": "pastorar",
    "pastoráveis": "pastorar",
    "pastorícia": "pastorício",
    "pastorícias": "pastorício",
    "pastorícios": "pastorício",
    "pastos": "pasto",
    "pastosa": "pastoso",
    "pastosas": "pastoso",
    "pastosidades": "pastosidade",
    "pastosos": "pastoso",
    "pastou": "pastar",
    "pastrana": "pastrano",
    "pastranas": "pastrano",
    "pastranos": "pastrano",
    "pastá": "pastar",
    "pastámo": "pastar",
    "pastámos": "pastar",
    "pastáramo": "pastar",
    "pastáramos": "pastar",
    "pastárei": "pastar",
    "pastáreis": "pastar",
    "pastásseis": "pastar",
    "pastássemos": "pastar",
    "pastávamo": "pastar",
    "pastávamos": "pastar",
    "pastávei": "pastar",
    "pastáveis": "pastar",
    "pastéis": "pastel",
    "pasça": "pascer",
    "pasçais": "pascer",
    "pasçam": "pascer",
    "pasçamo": "pascer",
    "pasçamos": "pascer",
    "pasças": "pascer",
    "pasço": "pascer",
    "pata": "pato",
    "patacarias": "patacaria",
    "patacas": "pataca",
    "patachins": "patachim",
    "patachos": "patacho",
    "patacoadas": "patacoada",
    "patacona": "patacão",
    "pataconas": "patacão",
    "patacos": "pataco",
    "patacões": "patacão",
    "patadas": "patada",
    "patafísica": "patafísico",
    "patafísicas": "patafísico",
    "patafísicos": "patafísico",
    "patagã": "patagão",
    "patagãos": "patagão",
    "patagãs": "patagão",
    "patagónia": "patagónio",
    "patagónias": "patagónio",
    "patagónios": "patagónio",
    "pataia": "patau",
    "pataias": "patau",
    "patamais": "patamal",
    "patamares": "patamar",
    "patamarins": "patamarim",
    "patamazes": "patamaz",
    "patameiras": "patameira",
    "patameiros": "patameiro",
    "pataniscas": "patanisca",
    "pataqueira": "pataqueiro",
    "pataqueiras": "pataqueiro",
    "pataqueiros": "pataqueiro",
    "patarata": "pataratar",
    "pataratada": "pataratar",
    "pataratadas": "pataratar",
    "pataratado": "pataratar",
    "pataratados": "pataratar",
    "pataratai": "pataratar",
    "pataratais": "pataratar",
    "pataratam": "pataratar",
    "pataratamo": "pataratar",
    "pataratamos": "pataratar",
    "pataratando": "pataratar",
    "pataratara": "pataratar",
    "patarataram": "pataratar",
    "patarataras": "pataratar",
    "pataratardes": "pataratar",
    "pataratarei": "pataratar",
    "pataratareis": "pataratar",
    "pataratarem": "pataratar",
    "patarataremos": "pataratar",
    "pataratares": "pataratar",
    "patarataria": "pataratar",
    "pataratariam": "pataratar",
    "pataratarias": "pataratar",
    "pataratarmo": "pataratar",
    "pataratarmos": "pataratar",
    "pataratará": "pataratar",
    "pataratarás": "pataratar",
    "pataratarão": "pataratar",
    "patarataríamos": "pataratar",
    "patarataríeis": "pataratar",
    "pataratas": "pataratar",
    "pataratasse": "pataratar",
    "pataratassem": "pataratar",
    "pataratasses": "pataratar",
    "patarataste": "pataratar",
    "pataratastes": "pataratar",
    "pataratava": "pataratar",
    "pataratavam": "pataratar",
    "pataratavas": "pataratar",
    "patarate": "pataratar",
    "patarateada": "pataratear",
    "patarateadas": "pataratear",
    "patarateado": "pataratear",
    "patarateados": "pataratear",
    "patarateai": "pataratear",
    "patarateais": "pataratear",
    "patarateamo": "pataratear",
    "patarateamos": "pataratear",
    "patarateando": "pataratear",
    "patarateara": "pataratear",
    "pataratearam": "pataratear",
    "pataratearas": "pataratear",
    "patarateardes": "pataratear",
    "pataratearei": "pataratear",
    "patarateareis": "pataratear",
    "pataratearem": "pataratear",
    "pataratearemos": "pataratear",
    "patarateares": "pataratear",
    "pataratearia": "pataratear",
    "patarateariam": "pataratear",
    "pataratearias": "pataratear",
    "pataratearmo": "pataratear",
    "pataratearmos": "pataratear",
    "patarateará": "pataratear",
    "pataratearás": "pataratear",
    "pataratearão": "pataratear",
    "pataratearíamos": "pataratear",
    "pataratearíeis": "pataratear",
    "patarateasse": "pataratear",
    "patarateassem": "pataratear",
    "patarateasses": "pataratear",
    "patarateaste": "pataratear",
    "patarateastes": "pataratear",
    "patarateava": "pataratear",
    "patarateavam": "pataratear",
    "patarateavas": "pataratear",
    "patarateei": "pataratear",
    "patarateeis": "pataratear",
    "patarateemo": "pataratear",
    "patarateemos": "pataratear",
    "pataratei": "pataratar",
    "patarateia": "pataratear",
    "patarateiam": "pataratear",
    "patarateias": "pataratear",
    "patarateie": "pataratear",
    "patarateiem": "pataratear",
    "patarateies": "pataratear",
    "patarateio": "pataratear",
    "patarateira": "patarateiro",
    "patarateiras": "patarateiro",
    "patarateiros": "patarateiro",
    "patarateis": "pataratar",
    "pataratem": "pataratar",
    "pataratemo": "pataratar",
    "pataratemos": "pataratar",
    "patarateou": "pataratear",
    "patarates": "pataratar",
    "patarateámo": "pataratear",
    "patarateámos": "pataratear",
    "patarateáramo": "pataratear",
    "patarateáramos": "pataratear",
    "patarateáreis": "pataratear",
    "patarateásseis": "pataratear",
    "patarateássemos": "pataratear",
    "patarateávamo": "pataratear",
    "patarateávamos": "pataratear",
    "patarateáveis": "pataratear",
    "pataratices": "pataratice",
    "pataratismos": "pataratismo",
    "patarato": "pataratar",
    "pataratou": "pataratar",
    "pataratámo": "pataratar",
    "pataratámos": "pataratar",
    "pataratáramo": "pataratar",
    "pataratáramos": "pataratar",
    "pataratáreis": "pataratar",
    "pataratásseis": "pataratar",
    "pataratássemos": "pataratar",
    "pataratávamo": "pataratar",
    "pataratávamos": "pataratar",
    "pataratáveis": "pataratar",
    "patarrais": "patarral",
    "patarrecas": "patarreca",
    "patarráses": "patarrás",
    "patas": "pato",
    "pataus": "patau",
    "patavina": "patavino",
    "patavinas": "patavino",
    "patavinices": "patavinice",
    "patavinidades": "patavinidade",
    "patavinismos": "patavinismo",
    "patavinos": "patavino",
    "patazes": "pataz",
    "pateada": "patear",
    "pateadas": "patear",
    "pateado": "patear",
    "pateados": "patear",
    "pateaduras": "pateadura",
    "pateai": "patear",
    "pateais": "patear",
    "pateamo": "patear",
    "pateamos": "patear",
    "pateando": "patear",
    "pateara": "patear",
    "patearam": "patear",
    "patearas": "patear",
    "patearde": "patear",
    "pateardes": "patear",
    "pateare": "patear",
    "patearei": "patear",
    "pateareis": "patear",
    "patearem": "patear",
    "patearemos": "patear",
    "pateares": "patear",
    "patearia": "patear",
    "pateariam": "patear",
    "patearias": "patear",
    "patearmo": "patear",
    "patearmos": "patear",
    "pateará": "patear",
    "patearás": "patear",
    "patearão": "patear",
    "patearíamos": "patear",
    "patearíeis": "patear",
    "pateasse": "patear",
    "pateassem": "patear",
    "pateasses": "patear",
    "pateaste": "patear",
    "pateastes": "patear",
    "pateava": "patear",
    "pateavam": "patear",
    "pateavas": "patear",
    "patecas": "pateca",
    "pateei": "patear",
    "pateeis": "patear",
    "pateemo": "patear",
    "pateemos": "patear",
    "patega": "patego",
    "pategada": "pategar",
    "pategadas": "pategar",
    "pategado": "pategar",
    "pategados": "pategar",
    "pategai": "pategar",
    "pategais": "pategar",
    "pategam": "pategar",
    "pategamo": "pategar",
    "pategamos": "pategar",
    "pategando": "pategar",
    "pategara": "pategar",
    "pategaram": "pategar",
    "pategaras": "pategar",
    "pategardes": "pategar",
    "pategarei": "pategar",
    "pategareis": "pategar",
    "pategarem": "pategar",
    "pategaremos": "pategar",
    "pategares": "pategar",
    "pategaria": "pategar",
    "pategariam": "pategar",
    "pategarias": "pategar",
    "pategarmo": "pategar",
    "pategarmos": "pategar",
    "pategará": "pategar",
    "pategarás": "pategar",
    "pategarão": "pategar",
    "pategaríamos": "pategar",
    "pategaríeis": "pategar",
    "pategas": "patego",
    "pategasse": "pategar",
    "pategassem": "pategar",
    "pategasses": "pategar",
    "pategaste": "pategar",
    "pategastes": "pategar",
    "pategava": "pategar",
    "pategavam": "pategar",
    "pategavas": "pategar",
    "pategazinha": "patego",
    "pategazinhas": "patego",
    "pategazita": "patego",
    "pategazitas": "patego",
    "patego": "pategar",
    "pategona": "patego",
    "pategonas": "patego",
    "pategos": "patego",
    "pategou": "pategar",
    "pategozinho": "patego",
    "pategozinhos": "patego",
    "pategozito": "patego",
    "pategozitos": "patego",
    "pategue": "pategar",
    "pateguei": "pategar",
    "pategueis": "pategar",
    "pateguem": "pategar",
    "pateguemo": "pategar",
    "pateguemos": "pategar",
    "pategues": "pategar",
    "pateguices": "pateguice",
    "pategámo": "pategar",
    "pategámos": "pategar",
    "pategáramo": "pategar",
    "pategáramos": "pategar",
    "pategáreis": "pategar",
    "pategásseis": "pategar",
    "pategássemos": "pategar",
    "pategávamo": "pategar",
    "pategávamos": "pategar",
    "pategáveis": "pategar",
    "pategão": "patego",
    "pategões": "patego",
    "pateia": "patear",
    "pateiam": "patear",
    "pateias": "patear",
    "pateie": "patear",
    "pateiem": "patear",
    "pateies": "patear",
    "pateio": "patear",
    "pateira": "pateiro",
    "pateiras": "pateiro",
    "pateiros": "pateiro",
    "patelares": "patelar",
    "patelas": "patela",
    "patelhas": "patelha",
    "pateliformes": "pateliforme",
    "patelos": "patelo",
    "patelídeos": "patelídeo",
    "patenas": "patena",
    "patenteabilidades": "patenteabilidade",
    "patenteada": "patentear",
    "patenteadas": "patentear",
    "patenteado": "patentear",
    "patenteados": "patentear",
    "patenteai": "patentear",
    "patenteais": "patentear",
    "patenteamo": "patentear",
    "patenteamos": "patentear",
    "patenteando": "patentear",
    "patenteara": "patentear",
    "patentearam": "patentear",
    "patentearas": "patentear",
    "patentearde": "patentear",
    "patenteardes": "patentear",
    "patenteare": "patentear",
    "patentearei": "patentear",
    "patenteareis": "patentear",
    "patentearem": "patentear",
    "patentearemos": "patentear",
    "patenteares": "patentear",
    "patentearia": "patentear",
    "patenteariam": "patentear",
    "patentearias": "patentear",
    "patentearmo": "patentear",
    "patentearmos": "patentear",
    "patenteará": "patentear",
    "patentearás": "patentear",
    "patentearão": "patentear",
    "patentearíamos": "patentear",
    "patentearíeis": "patentear",
    "patenteasse": "patentear",
    "patenteassem": "patentear",
    "patenteasses": "patentear",
    "patenteaste": "patentear",
    "patenteastes": "patentear",
    "patenteava": "patentear",
    "patenteavam": "patentear",
    "patenteavas": "patentear",
    "patenteações": "patenteação",
    "patenteei": "patentear",
    "patenteeis": "patentear",
    "patenteemo": "patentear",
    "patenteemos": "patentear",
    "patenteia": "patentear",
    "patenteiam": "patentear",
    "patenteias": "patentear",
    "patenteie": "patentear",
    "patenteiem": "patentear",
    "patenteies": "patentear",
    "patenteio": "patentear",
    "patenteou": "patentear",
    "patentes": "patente",
    "patenteá": "patentear",
    "patenteámo": "patentear",
    "patenteámos": "patentear",
    "patenteáramo": "patentear",
    "patenteáramos": "patentear",
    "patenteárei": "patentear",
    "patenteáreis": "patentear",
    "patenteásseis": "patentear",
    "patenteássemos": "patentear",
    "patenteávamo": "patentear",
    "patenteávamos": "patentear",
    "patenteávei": "patentear",
    "patenteáveis": "patenteável",
    "patentíssima": "patente",
    "patentíssimas": "patente",
    "patentíssimo": "patente",
    "patentíssimos": "patente",
    "patenças": "patença",
    "pateou": "patear",
    "pateras": "patera",
    "paterna": "paterno",
    "paternais": "paternal",
    "paternalidades": "paternalidade",
    "paternalismos": "paternalismo",
    "paternalistas": "paternalista",
    "paternalistazinha": "paternalista",
    "paternalistazinhas": "paternalista",
    "paternalistazinho": "paternalista",
    "paternalistazinhos": "paternalista",
    "paternalistazita": "paternalista",
    "paternalistazitas": "paternalista",
    "paternalistazito": "paternalista",
    "paternalistazitos": "paternalista",
    "paternas": "paterno",
    "paternidades": "paternidade",
    "paternos": "paterno",
    "pates": "pate",
    "pateta": "patetar",
    "patetada": "patetar",
    "patetadas": "patetar",
    "patetado": "patetar",
    "patetados": "patetar",
    "patetai": "patetar",
    "patetais": "patetar",
    "patetam": "patetar",
    "patetamo": "patetar",
    "patetamos": "patetar",
    "patetando": "patetar",
    "patetara": "patetar",
    "patetaram": "patetar",
    "patetaras": "patetar",
    "patetardes": "patetar",
    "patetarei": "patetar",
    "patetareis": "patetar",
    "patetarem": "patetar",
    "patetaremos": "patetar",
    "patetares": "patetar",
    "patetaria": "patetar",
    "patetariam": "patetar",
    "patetarias": "patetar",
    "patetarmo": "patetar",
    "patetarmos": "patetar",
    "patetará": "patetar",
    "patetarás": "patetar",
    "patetarão": "patetar",
    "patetaríamos": "patetar",
    "patetaríeis": "patetar",
    "patetas": "patetar",
    "patetasse": "patetar",
    "patetassem": "patetar",
    "patetasses": "patetar",
    "patetaste": "patetar",
    "patetastes": "patetar",
    "patetava": "patetar",
    "patetavam": "patetar",
    "patetavas": "patetar",
    "patetazinha": "pateta",
    "patetazinhas": "pateta",
    "patetazinho": "pateta",
    "patetazinhos": "pateta",
    "patetazita": "pateta",
    "patetazitas": "pateta",
    "patetazito": "pateta",
    "patetazitos": "pateta",
    "patete": "patetar",
    "pateteada": "patetear",
    "pateteadas": "patetear",
    "pateteado": "patetear",
    "pateteados": "patetear",
    "pateteai": "patetear",
    "pateteais": "patetear",
    "pateteamo": "patetear",
    "pateteamos": "patetear",
    "pateteando": "patetear",
    "pateteara": "patetear",
    "patetearam": "patetear",
    "patetearas": "patetear",
    "pateteardes": "patetear",
    "patetearei": "patetear",
    "pateteareis": "patetear",
    "patetearem": "patetear",
    "patetearemos": "patetear",
    "pateteares": "patetear",
    "patetearia": "patetear",
    "pateteariam": "patetear",
    "patetearias": "patetear",
    "patetearmo": "patetear",
    "patetearmos": "patetear",
    "pateteará": "patetear",
    "patetearás": "patetear",
    "patetearão": "patetear",
    "patetearíamos": "patetear",
    "patetearíeis": "patetear",
    "pateteasse": "patetear",
    "pateteassem": "patetear",
    "pateteasses": "patetear",
    "pateteaste": "patetear",
    "pateteastes": "patetear",
    "pateteava": "patetear",
    "pateteavam": "patetear",
    "pateteavas": "patetear",
    "pateteei": "patetear",
    "pateteeis": "patetear",
    "pateteemo": "patetear",
    "pateteemos": "patetear",
    "patetei": "patetar",
    "pateteia": "patetear",
    "pateteiam": "patetear",
    "pateteias": "patetear",
    "pateteie": "patetear",
    "pateteiem": "patetear",
    "pateteies": "patetear",
    "pateteio": "patetear",
    "pateteis": "patetar",
    "patetem": "patetar",
    "patetemo": "patetar",
    "patetemos": "patetar",
    "pateteou": "patetear",
    "patetes": "patetar",
    "pateteámo": "patetear",
    "pateteámos": "patetear",
    "pateteáramo": "patetear",
    "pateteáramos": "patetear",
    "pateteáreis": "patetear",
    "pateteásseis": "patetear",
    "pateteássemos": "patetear",
    "pateteávamo": "patetear",
    "pateteávamos": "patetear",
    "pateteáveis": "patetear",
    "pateticazinha": "patético",
    "pateticazinhas": "patético",
    "pateticazita": "patético",
    "pateticazitas": "patético",
    "patetices": "patetice",
    "pateticozinho": "patético",
    "pateticozinhos": "patético",
    "pateticozito": "patético",
    "pateticozitos": "patético",
    "patetinha": "pateta",
    "patetinhas": "pateta",
    "patetismos": "patetismo",
    "patetita": "pateta",
    "patetitas": "pateta",
    "pateto": "patetar",
    "patetou": "patetar",
    "patetámo": "patetar",
    "patetámos": "patetar",
    "patetáramo": "patetar",
    "patetáramos": "patetar",
    "patetáreis": "patetar",
    "patetásseis": "patetar",
    "patetássemos": "patetar",
    "patetávamo": "patetar",
    "patetávamos": "patetar",
    "patetáveis": "patetar",
    "patetíssima": "pateta",
    "patetíssimas": "pateta",
    "patetíssimo": "pateta",
    "patetíssimos": "pateta",
    "patetóides": "patetóide",
    "pateá": "patear",
    "pateámo": "patear",
    "pateámos": "patear",
    "pateáramo": "patear",
    "pateáramos": "patear",
    "pateárei": "patear",
    "pateáreis": "patear",
    "pateásseis": "patear",
    "pateássemos": "patear",
    "pateávamo": "patear",
    "pateávamos": "patear",
    "pateávei": "patear",
    "pateáveis": "patear",
    "patibulares": "patibular",
    "patifarias": "patifaria",
    "patifes": "patife",
    "patifezinha": "patife",
    "patifezinhas": "patife",
    "patifezinho": "patife",
    "patifezinhos": "patife",
    "patifezita": "patife",
    "patifezitas": "patife",
    "patifezito": "patife",
    "patifezitos": "patife",
    "patifona": "patifão",
    "patifonas": "patifão",
    "patifória": "patifório",
    "patifórias": "patifório",
    "patifórios": "patifório",
    "patifões": "patifão",
    "patiguás": "patiguá",
    "patigénica": "patigénico",
    "patigénicas": "patigénico",
    "patigénicos": "patigénico",
    "patilhas": "patilha",
    "patina": "patinar",
    "patinada": "patinar",
    "patinadas": "patinar",
    "patinado": "patinar",
    "patinadora": "patinador",
    "patinadoras": "patinador",
    "patinadores": "patinador",
    "patinados": "patinar",
    "patinagens": "patinagem",
    "patinai": "patinar",
    "patinais": "patinar",
    "patinam": "patinar",
    "patinamo": "patinar",
    "patinamos": "patinar",
    "patinando": "patinar",
    "patinara": "patinar",
    "patinaram": "patinar",
    "patinaras": "patinar",
    "patinardes": "patinar",
    "patinarei": "patinar",
    "patinareis": "patinar",
    "patinarem": "patinar",
    "patinaremos": "patinar",
    "patinares": "patinar",
    "patinaria": "patinar",
    "patinariam": "patinar",
    "patinarias": "patinar",
    "patinarmo": "patinar",
    "patinarmos": "patinar",
    "patinará": "patinar",
    "patinarás": "patinar",
    "patinarão": "patinar",
    "patinaríamos": "patinar",
    "patinaríeis": "patinar",
    "patinas": "patinar",
    "patinasse": "patinar",
    "patinassem": "patinar",
    "patinasses": "patinar",
    "patinaste": "patinar",
    "patinastes": "patinar",
    "patinava": "patinar",
    "patinavam": "patinar",
    "patinavas": "patinar",
    "patine": "patinar",
    "patinei": "patinar",
    "patineis": "patinar",
    "patinem": "patinar",
    "patinemo": "patinar",
    "patinemos": "patinar",
    "patines": "patine",
    "patinha": "pato",
    "patinhada": "patinhar",
    "patinhadas": "patinhar",
    "patinhado": "patinhar",
    "patinhados": "patinhar",
    "patinhai": "patinhar",
    "patinhais": "patinhar",
    "patinham": "patinhar",
    "patinhamo": "patinhar",
    "patinhamos": "patinhar",
    "patinhando": "patinhar",
    "patinhara": "patinhar",
    "patinharam": "patinhar",
    "patinharas": "patinhar",
    "patinharde": "patinhar",
    "patinhardes": "patinhar",
    "patinhare": "patinhar",
    "patinharei": "patinhar",
    "patinhareis": "patinhar",
    "patinharem": "patinhar",
    "patinharemos": "patinhar",
    "patinhares": "patinhar",
    "patinharia": "patinhar",
    "patinhariam": "patinhar",
    "patinharias": "patinhar",
    "patinharmo": "patinhar",
    "patinharmos": "patinhar",
    "patinhará": "patinhar",
    "patinharás": "patinhar",
    "patinharão": "patinhar",
    "patinharíamos": "patinhar",
    "patinharíeis": "patinhar",
    "patinhas": "pato",
    "patinhasse": "patinhar",
    "patinhassem": "patinhar",
    "patinhasses": "patinhar",
    "patinhaste": "patinhar",
    "patinhastes": "patinhar",
    "patinhava": "patinhar",
    "patinhavam": "patinhar",
    "patinhavas": "patinhar",
    "patinhe": "patinhar",
    "patinhei": "patinhar",
    "patinheiros": "patinheiro",
    "patinheis": "patinhar",
    "patinhem": "patinhar",
    "patinhemo": "patinhar",
    "patinhemos": "patinhar",
    "patinhes": "patinhar",
    "patinho": "pato",
    "patinhos": "pato",
    "patinhou": "patinhar",
    "patinhá": "patinhar",
    "patinhámo": "patinhar",
    "patinhámos": "patinhar",
    "patinháramo": "patinhar",
    "patinháramos": "patinhar",
    "patinhárei": "patinhar",
    "patinháreis": "patinhar",
    "patinhásseis": "patinhar",
    "patinhássemos": "patinhar",
    "patinhávamo": "patinhar",
    "patinhávamos": "patinhar",
    "patinhávei": "patinhar",
    "patinháveis": "patinhar",
    "patino": "patinar",
    "patinou": "patinar",
    "patins": "patim",
    "patinámo": "patinar",
    "patinámos": "patinar",
    "patináramo": "patinar",
    "patináramos": "patinar",
    "patináreis": "patinar",
    "patinásseis": "patinar",
    "patinássemos": "patinar",
    "patinávamo": "patinar",
    "patinávamos": "patinar",
    "patináveis": "patinar",
    "patita": "pato",
    "patitas": "pato",
    "patito": "pato",
    "patitos": "pato",
    "patofobias": "patofobia",
    "patofóbica": "patofóbico",
    "patofóbicas": "patofóbico",
    "patofóbicos": "patofóbico",
    "patogenias": "patogenia",
    "patogenésica": "patogenésico",
    "patogenésicas": "patogenésico",
    "patogenésicos": "patogenésico",
    "patognomónica": "patognomónico",
    "patognomónicas": "patognomónico",
    "patognomónicos": "patognomónico",
    "patogéneses": "patogénese",
    "patogénica": "patogénico",
    "patogénicas": "patogénico",
    "patogénicos": "patogénico",
    "patolas": "patola",
    "patologias": "patologia",
    "patologistas": "patologista",
    "patológica": "patológico",
    "patológicas": "patológico",
    "patológicos": "patológico",
    "patomanias": "patomania",
    "patomímica": "patomímico",
    "patomímicas": "patomímico",
    "patomímicos": "patomímico",
    "patorras": "patorra",
    "patos": "pato",
    "patoás": "patoá",
    "patranhadas": "patranhada",
    "patranhas": "patranha",
    "patranheira": "patranheiro",
    "patranheiras": "patranheiro",
    "patranheiros": "patranheiro",
    "patranhenta": "patranhento",
    "patranhentas": "patranhento",
    "patranhentos": "patranhento",
    "patranhosa": "patranhoso",
    "patranhosas": "patranhoso",
    "patranhosos": "patranhoso",
    "patrasanas": "patrasana",
    "patriarcados": "patriarcado",
    "patriarcais": "patriarcal",
    "patriarcas": "patriarca",
    "patriciados": "patriciado",
    "patriciatos": "patriciato",
    "patrimoniada": "patrimoniado",
    "patrimoniadas": "patrimoniado",
    "patrimoniados": "patrimoniado",
    "patrimoniais": "patrimonial",
    "patrimónios": "património",
    "patriofobias": "patriofobia",
    "patriofóbica": "patriofóbico",
    "patriofóbicas": "patriofóbico",
    "patriofóbicos": "patriofóbico",
    "patriotas": "patriota",
    "patrioteira": "patrioteiro",
    "patrioteiras": "patrioteiro",
    "patrioteirismos": "patrioteirismo",
    "patrioteiros": "patrioteiro",
    "patriotices": "patriotice",
    "patriotismos": "patriotismo",
    "patriotistas": "patriotista",
    "patriófoba": "patriófobo",
    "patriófobas": "patriófobo",
    "patriófobos": "patriófobo",
    "patriótica": "patriótico",
    "patrióticas": "patriótico",
    "patrióticos": "patriótico",
    "patroa": "patrão",
    "patroas": "patrão",
    "patroazinha": "patrão",
    "patroazinhas": "patrão",
    "patroazita": "patrão",
    "patroazitas": "patrão",
    "patrocina": "patrocinar",
    "patrocinada": "patrocinar",
    "patrocinadas": "patrocinar",
    "patrocinado": "patrocinar",
    "patrocinadora": "patrocinador",
    "patrocinadoras": "patrocinador",
    "patrocinadores": "patrocinador",
    "patrocinados": "patrocinar",
    "patrocinai": "patrocinar",
    "patrocinais": "patrocinar",
    "patrocinam": "patrocinar",
    "patrocinamo": "patrocinar",
    "patrocinamos": "patrocinar",
    "patrocinando": "patrocinar",
    "patrocinara": "patrocinar",
    "patrocinaram": "patrocinar",
    "patrocinaras": "patrocinar",
    "patrocinarde": "patrocinar",
    "patrocinardes": "patrocinar",
    "patrocinare": "patrocinar",
    "patrocinarei": "patrocinar",
    "patrocinareis": "patrocinar",
    "patrocinarem": "patrocinar",
    "patrocinaremos": "patrocinar",
    "patrocinares": "patrocinar",
    "patrocinaria": "patrocinar",
    "patrocinariam": "patrocinar",
    "patrocinarias": "patrocinar",
    "patrocinarmo": "patrocinar",
    "patrocinarmos": "patrocinar",
    "patrocinará": "patrocinar",
    "patrocinarás": "patrocinar",
    "patrocinarão": "patrocinar",
    "patrocinaríamos": "patrocinar",
    "patrocinaríeis": "patrocinar",
    "patrocinas": "patrocinar",
    "patrocinasse": "patrocinar",
    "patrocinassem": "patrocinar",
    "patrocinasses": "patrocinar",
    "patrocinaste": "patrocinar",
    "patrocinastes": "patrocinar",
    "patrocinatos": "patrocinato",
    "patrocinava": "patrocinar",
    "patrocinavam": "patrocinar",
    "patrocinavas": "patrocinar",
    "patrocine": "patrocinar",
    "patrocinei": "patrocinar",
    "patrocineis": "patrocinar",
    "patrocinem": "patrocinar",
    "patrocinemo": "patrocinar",
    "patrocinemos": "patrocinar",
    "patrocines": "patrocinar",
    "patrocino": "patrocinar",
    "patrocinou": "patrocinar",
    "patrociná": "patrocinar",
    "patrocinámo": "patrocinar",
    "patrocinámos": "patrocinar",
    "patrocináramo": "patrocinar",
    "patrocináramos": "patrocinar",
    "patrocinárei": "patrocinar",
    "patrocináreis": "patrocinar",
    "patrocinásseis": "patrocinar",
    "patrocinássemos": "patrocinar",
    "patrocinávamo": "patrocinar",
    "patrocinávamos": "patrocinar",
    "patrocinávei": "patrocinar",
    "patrocináveis": "patrocinável",
    "patrocínios": "patrocínio",
    "patrologias": "patrologia",
    "patrológica": "patrológico",
    "patrológicas": "patrológico",
    "patrológicos": "patrológico",
    "patrona": "patrono",
    "patronados": "patronado",
    "patronagens": "patronagem",
    "patronais": "patronal",
    "patronas": "patrono",
    "patronatos": "patronato",
    "patroneada": "patronear",
    "patroneadas": "patronear",
    "patroneado": "patronear",
    "patroneados": "patronear",
    "patroneai": "patronear",
    "patroneais": "patronear",
    "patroneamo": "patronear",
    "patroneamos": "patronear",
    "patroneando": "patronear",
    "patroneara": "patronear",
    "patronearam": "patronear",
    "patronearas": "patronear",
    "patronearde": "patronear",
    "patroneardes": "patronear",
    "patroneare": "patronear",
    "patronearei": "patronear",
    "patroneareis": "patronear",
    "patronearem": "patronear",
    "patronearemos": "patronear",
    "patroneares": "patronear",
    "patronearia": "patronear",
    "patroneariam": "patronear",
    "patronearias": "patronear",
    "patronearmo": "patronear",
    "patronearmos": "patronear",
    "patroneará": "patronear",
    "patronearás": "patronear",
    "patronearão": "patronear",
    "patronearíamos": "patronear",
    "patronearíeis": "patronear",
    "patroneasse": "patronear",
    "patroneassem": "patronear",
    "patroneasses": "patronear",
    "patroneaste": "patronear",
    "patroneastes": "patronear",
    "patroneava": "patronear",
    "patroneavam": "patronear",
    "patroneavas": "patronear",
    "patroneei": "patronear",
    "patroneeis": "patronear",
    "patroneemo": "patronear",
    "patroneemos": "patronear",
    "patroneia": "patronear",
    "patroneiam": "patronear",
    "patroneias": "patronear",
    "patroneie": "patronear",
    "patroneiem": "patronear",
    "patroneies": "patronear",
    "patroneio": "patronear",
    "patroneou": "patronear",
    "patroneá": "patronear",
    "patroneámo": "patronear",
    "patroneámos": "patronear",
    "patroneáramo": "patronear",
    "patroneáramos": "patronear",
    "patroneárei": "patronear",
    "patroneáreis": "patronear",
    "patroneásseis": "patronear",
    "patroneássemos": "patronear",
    "patroneávamo": "patronear",
    "patroneávamos": "patronear",
    "patroneávei": "patronear",
    "patroneáveis": "patronear",
    "patronos": "patrono",
    "patronímica": "patronímico",
    "patronímicas": "patronímico",
    "patronímicos": "patronímico",
    "patruicídios": "patruicídio",
    "patrulha": "patrulhar",
    "patrulhada": "patrulhar",
    "patrulhadas": "patrulhar",
    "patrulhado": "patrulhar",
    "patrulhadora": "patrulhador",
    "patrulhadoras": "patrulhador",
    "patrulhadores": "patrulhador",
    "patrulhados": "patrulhar",
    "patrulhai": "patrulhar",
    "patrulhais": "patrulhar",
    "patrulham": "patrulhar",
    "patrulhamentos": "patrulhamento",
    "patrulhamo": "patrulhar",
    "patrulhamos": "patrulhar",
    "patrulhando": "patrulhar",
    "patrulhara": "patrulhar",
    "patrulharam": "patrulhar",
    "patrulharas": "patrulhar",
    "patrulharde": "patrulhar",
    "patrulhardes": "patrulhar",
    "patrulhare": "patrulhar",
    "patrulharei": "patrulhar",
    "patrulhareis": "patrulhar",
    "patrulharem": "patrulhar",
    "patrulharemos": "patrulhar",
    "patrulhares": "patrulhar",
    "patrulharia": "patrulhar",
    "patrulhariam": "patrulhar",
    "patrulharias": "patrulhar",
    "patrulharmo": "patrulhar",
    "patrulharmos": "patrulhar",
    "patrulhará": "patrulhar",
    "patrulharás": "patrulhar",
    "patrulharão": "patrulhar",
    "patrulharíamos": "patrulhar",
    "patrulharíeis": "patrulhar",
    "patrulhas": "patrulhar",
    "patrulhasse": "patrulhar",
    "patrulhassem": "patrulhar",
    "patrulhasses": "patrulhar",
    "patrulhaste": "patrulhar",
    "patrulhastes": "patrulhar",
    "patrulhava": "patrulhar",
    "patrulhavam": "patrulhar",
    "patrulhavas": "patrulhar",
    "patrulhe": "patrulhar",
    "patrulhei": "patrulhar",
    "patrulheis": "patrulhar",
    "patrulhem": "patrulhar",
    "patrulhemo": "patrulhar",
    "patrulhemos": "patrulhar",
    "patrulhes": "patrulhar",
    "patrulho": "patrulhar",
    "patrulhou": "patrulhar",
    "patrulhá": "patrulhar",
    "patrulhámo": "patrulhar",
    "patrulhámos": "patrulhar",
    "patrulháramo": "patrulhar",
    "patrulháramos": "patrulhar",
    "patrulhárei": "patrulhar",
    "patrulháreis": "patrulhar",
    "patrulhásseis": "patrulhar",
    "patrulhássemos": "patrulhar",
    "patrulhávamo": "patrulhar",
    "patrulhávamos": "patrulhar",
    "patrulhávei": "patrulhar",
    "patrulháveis": "patrulhar",
    "patruças": "patruça",
    "patrãozinho": "patrão",
    "patrãozito": "patrão",
    "patrícia": "patrício",
    "patrícias": "patrício",
    "patrícios": "patrício",
    "patrística": "patrístico",
    "patrísticas": "patrístico",
    "patrísticos": "patrístico",
    "patróclina": "patróclino",
    "patróclinas": "patróclino",
    "patróclinos": "patróclino",
    "patrões": "patrão",
    "patrõezinhos": "patrão",
    "patrõezitos": "patrão",
    "patrúcias": "patrúcia",
    "patuda": "patudo",
    "patudas": "patudo",
    "patudazinha": "patudo",
    "patudazinhas": "patudo",
    "patudazita": "patudo",
    "patudazitas": "patudo",
    "patudinha": "patudo",
    "patudinhas": "patudo",
    "patudinho": "patudo",
    "patudinhos": "patudo",
    "patudita": "patudo",
    "patuditas": "patudo",
    "patudito": "patudo",
    "patuditos": "patudo",
    "patudos": "patudo",
    "patudozinho": "patudo",
    "patudozinhos": "patudo",
    "patudozito": "patudo",
    "patudozitos": "patudo",
    "patudíssima": "patudo",
    "patudíssimas": "patudo",
    "patudíssimo": "patudo",
    "patudíssimos": "patudo",
    "patuguás": "patuguá",
    "patuleias": "patuleia",
    "paturis": "paturi",
    "patusca": "patusco",
    "patuscada": "patuscar",
    "patuscadas": "patuscar",
    "patuscado": "patuscar",
    "patuscados": "patuscar",
    "patuscais": "patuscar",
    "patuscam": "patuscar",
    "patuscamo": "patuscar",
    "patuscamos": "patuscar",
    "patuscando": "patuscar",
    "patuscara": "patuscar",
    "patuscaram": "patuscar",
    "patuscaras": "patuscar",
    "patuscardes": "patuscar",
    "patuscarei": "patuscar",
    "patuscareis": "patuscar",
    "patuscarem": "patuscar",
    "patuscaremos": "patuscar",
    "patuscares": "patuscar",
    "patuscaria": "patuscar",
    "patuscariam": "patuscar",
    "patuscarias": "patuscar",
    "patuscarmo": "patuscar",
    "patuscarmos": "patuscar",
    "patuscará": "patuscar",
    "patuscarás": "patuscar",
    "patuscarão": "patuscar",
    "patuscaríamos": "patuscar",
    "patuscaríeis": "patuscar",
    "patuscas": "patusco",
    "patuscasse": "patuscar",
    "patuscassem": "patuscar",
    "patuscasses": "patuscar",
    "patuscaste": "patuscar",
    "patuscastes": "patuscar",
    "patuscava": "patuscar",
    "patuscavam": "patuscar",
    "patuscavas": "patuscar",
    "patuscazinha": "patusco",
    "patuscazinhas": "patusco",
    "patuscazita": "patusco",
    "patuscazitas": "patusco",
    "patusco": "patuscar",
    "patuscos": "patusco",
    "patuscou": "patuscar",
    "patuscozinho": "patusco",
    "patuscozinhos": "patusco",
    "patuscozito": "patusco",
    "patuscozitos": "patusco",
    "patuscámo": "patuscar",
    "patuscámos": "patuscar",
    "patuscáramo": "patuscar",
    "patuscáramos": "patuscar",
    "patuscáreis": "patuscar",
    "patuscásseis": "patuscar",
    "patuscássemos": "patuscar",
    "patuscávamo": "patuscar",
    "patuscávamos": "patuscar",
    "patuscáveis": "patuscar",
    "patusque": "patuscar",
    "patusquei": "patuscar",
    "patusqueira": "patusqueiro",
    "patusqueiras": "patusqueiro",
    "patusqueiros": "patusqueiro",
    "patusqueis": "patuscar",
    "patusquem": "patuscar",
    "patusquemos": "patuscar",
    "patusques": "patuscar",
    "patusquinha": "patusco",
    "patusquinhas": "patusco",
    "patusquinho": "patusco",
    "patusquinhos": "patusco",
    "patusquita": "patusco",
    "patusquitas": "patusco",
    "patusquito": "patusco",
    "patusquitos": "patusco",
    "patusquíssima": "patusco",
    "patusquíssimas": "patusco",
    "patusquíssimo": "patusco",
    "patusquíssimos": "patusco",
    "patuás": "patuá",
    "patágios": "patágio",
    "patélidas": "patélida",
    "patética": "patético",
    "patéticas": "patético",
    "patéticos": "patético",
    "patíbulos": "patíbulo",
    "patíveis": "patível",
    "patófoba": "patófobo",
    "patófobas": "patófobo",
    "patófobos": "patófobo",
    "patões": "patão",
    "pauis": "paul",
    "pauladas": "paulada",
    "paulatina": "paulatino",
    "paulatinas": "paulatino",
    "paulatinos": "paulatino",
    "paulismos": "paulismo",
    "paulistana": "paulistano",
    "paulistanas": "paulistano",
    "paulistanos": "paulistano",
    "paulistas": "paulista",
    "paulitadas": "paulitada",
    "pauliteira": "pauliteiro",
    "pauliteiras": "pauliteiro",
    "pauliteiros": "pauliteiro",
    "paulitos": "paulito",
    "pauperismos": "pauperismo",
    "pauperizações": "pauperização",
    "paupéries": "paupérie",
    "paupérrima": "pobre",
    "paupérrimas": "pobre",
    "paupérrimo": "pobre",
    "paupérrimos": "pobre",
    "paus": "pau",
    "pausa": "pausar",
    "pausada": "pausar",
    "pausadas": "pausar",
    "pausado": "pausar",
    "pausados": "pausar",
    "pausadíssima": "pausado",
    "pausadíssimas": "pausado",
    "pausadíssimo": "pausado",
    "pausadíssimos": "pausado",
    "pausai": "pausar",
    "pausais": "pausar",
    "pausam": "pausar",
    "pausamo": "pausar",
    "pausamos": "pausar",
    "pausando": "pausar",
    "pausara": "pausar",
    "pausaram": "pausar",
    "pausaras": "pausar",
    "pausarde": "pausar",
    "pausardes": "pausar",
    "pausare": "pausar",
    "pausarei": "pausar",
    "pausareis": "pausar",
    "pausarem": "pausar",
    "pausaremos": "pausar",
    "pausares": "pausar",
    "pausaria": "pausar",
    "pausariam": "pausar",
    "pausarias": "pausar",
    "pausarmo": "pausar",
    "pausarmos": "pausar",
    "pausará": "pausar",
    "pausarás": "pausar",
    "pausarão": "pausar",
    "pausaríamos": "pausar",
    "pausaríeis": "pausar",
    "pausas": "pausar",
    "pausasse": "pausar",
    "pausassem": "pausar",
    "pausasses": "pausar",
    "pausaste": "pausar",
    "pausastes": "pausar",
    "pausava": "pausar",
    "pausavam": "pausar",
    "pausavas": "pausar",
    "pause": "pausar",
    "pausei": "pausar",
    "pauseis": "pausar",
    "pausem": "pausar",
    "pausemo": "pausar",
    "pausemos": "pausar",
    "pauses": "pausar",
    "pauso": "pausar",
    "pausou": "pausar",
    "pausá": "pausar",
    "pausámo": "pausar",
    "pausámos": "pausar",
    "pausáramo": "pausar",
    "pausáramos": "pausar",
    "pausárei": "pausar",
    "pausáreis": "pausar",
    "pausásseis": "pausar",
    "pausássemos": "pausar",
    "pausávamo": "pausar",
    "pausávamos": "pausar",
    "pausávei": "pausar",
    "pausáveis": "pausar",
    "pauta": "pautar",
    "pautada": "pautar",
    "pautadas": "pautar",
    "pautadinha": "pautado",
    "pautadinhas": "pautado",
    "pautadinho": "pautado",
    "pautadinhos": "pautado",
    "pautadita": "pautado",
    "pautaditas": "pautado",
    "pautadito": "pautado",
    "pautaditos": "pautado",
    "pautado": "pautar",
    "pautados": "pautar",
    "pautai": "pautar",
    "pautais": "pautar",
    "pautam": "pautar",
    "pautamo": "pautar",
    "pautamos": "pautar",
    "pautando": "pautar",
    "pautara": "pautar",
    "pautaram": "pautar",
    "pautaras": "pautar",
    "pautarde": "pautar",
    "pautardes": "pautar",
    "pautare": "pautar",
    "pautarei": "pautar",
    "pautareis": "pautar",
    "pautarem": "pautar",
    "pautaremos": "pautar",
    "pautares": "pautar",
    "pautaria": "pautar",
    "pautariam": "pautar",
    "pautarias": "pautar",
    "pautarmo": "pautar",
    "pautarmos": "pautar",
    "pautará": "pautar",
    "pautarás": "pautar",
    "pautarão": "pautar",
    "pautaríamos": "pautar",
    "pautaríeis": "pautar",
    "pautas": "pautar",
    "pautasse": "pautar",
    "pautassem": "pautar",
    "pautasses": "pautar",
    "pautaste": "pautar",
    "pautastes": "pautar",
    "pautava": "pautar",
    "pautavam": "pautar",
    "pautavas": "pautar",
    "paute": "pautar",
    "pauteada": "pautear",
    "pauteadas": "pautear",
    "pauteado": "pautear",
    "pauteados": "pautear",
    "pauteai": "pautear",
    "pauteais": "pautear",
    "pauteamo": "pautear",
    "pauteamos": "pautear",
    "pauteando": "pautear",
    "pauteara": "pautear",
    "pautearam": "pautear",
    "pautearas": "pautear",
    "pautearde": "pautear",
    "pauteardes": "pautear",
    "pauteare": "pautear",
    "pautearei": "pautear",
    "pauteareis": "pautear",
    "pautearem": "pautear",
    "pautearemos": "pautear",
    "pauteares": "pautear",
    "pautearia": "pautear",
    "pauteariam": "pautear",
    "pautearias": "pautear",
    "pautearmo": "pautear",
    "pautearmos": "pautear",
    "pauteará": "pautear",
    "pautearás": "pautear",
    "pautearão": "pautear",
    "pautearíamos": "pautear",
    "pautearíeis": "pautear",
    "pauteasse": "pautear",
    "pauteassem": "pautear",
    "pauteasses": "pautear",
    "pauteaste": "pautear",
    "pauteastes": "pautear",
    "pauteava": "pautear",
    "pauteavam": "pautear",
    "pauteavas": "pautear",
    "pauteei": "pautear",
    "pauteeis": "pautear",
    "pauteemo": "pautear",
    "pauteemos": "pautear",
    "pautei": "pautar",
    "pauteia": "pautear",
    "pauteiam": "pautear",
    "pauteias": "pautear",
    "pauteie": "pautear",
    "pauteiem": "pautear",
    "pauteies": "pautear",
    "pauteio": "pautear",
    "pauteis": "pautar",
    "pautem": "pautar",
    "pautemo": "pautar",
    "pautemos": "pautar",
    "pauteou": "pautear",
    "pautes": "pautar",
    "pauteá": "pautear",
    "pauteámo": "pautear",
    "pauteámos": "pautear",
    "pauteáramo": "pautear",
    "pauteáramos": "pautear",
    "pauteárei": "pautear",
    "pauteáreis": "pautear",
    "pauteásseis": "pautear",
    "pauteássemos": "pautear",
    "pauteávamo": "pautear",
    "pauteávamos": "pautear",
    "pauteávei": "pautear",
    "pauteáveis": "pautear",
    "pauto": "pautar",
    "pautou": "pautar",
    "pautá": "pautar",
    "pautámo": "pautar",
    "pautámos": "pautar",
    "pautáramo": "pautar",
    "pautáramos": "pautar",
    "pautárei": "pautar",
    "pautáreis": "pautar",
    "pautásseis": "pautar",
    "pautássemos": "pautar",
    "pautávamo": "pautar",
    "pautávamos": "pautar",
    "pautávei": "pautar",
    "pautáveis": "pautável",
    "pauzeiros": "pauzeiro",
    "pauzinho": "pau",
    "pauzinhos": "pauzinho",
    "pauzito": "pau",
    "pauzitos": "pau",
    "pavanas": "pavana",
    "paveias": "paveia",
    "paveja": "pavejar",
    "pavejada": "pavejar",
    "pavejadas": "pavejar",
    "pavejado": "pavejar",
    "pavejados": "pavejar",
    "pavejai": "pavejar",
    "pavejais": "pavejar",
    "pavejam": "pavejar",
    "pavejamo": "pavejar",
    "pavejamos": "pavejar",
    "pavejando": "pavejar",
    "pavejara": "pavejar",
    "pavejaram": "pavejar",
    "pavejaras": "pavejar",
    "pavejarde": "pavejar",
    "pavejardes": "pavejar",
    "pavejare": "pavejar",
    "pavejarei": "pavejar",
    "pavejareis": "pavejar",
    "pavejarem": "pavejar",
    "pavejaremos": "pavejar",
    "pavejares": "pavejar",
    "pavejaria": "pavejar",
    "pavejariam": "pavejar",
    "pavejarias": "pavejar",
    "pavejarmo": "pavejar",
    "pavejarmos": "pavejar",
    "pavejará": "pavejar",
    "pavejarás": "pavejar",
    "pavejarão": "pavejar",
    "pavejaríamos": "pavejar",
    "pavejaríeis": "pavejar",
    "pavejas": "pavejar",
    "pavejasse": "pavejar",
    "pavejassem": "pavejar",
    "pavejasses": "pavejar",
    "pavejaste": "pavejar",
    "pavejastes": "pavejar",
    "pavejava": "pavejar",
    "pavejavam": "pavejar",
    "pavejavas": "pavejar",
    "paveje": "pavejar",
    "pavejei": "pavejar",
    "pavejeis": "pavejar",
    "pavejem": "pavejar",
    "pavejemo": "pavejar",
    "pavejemos": "pavejar",
    "pavejes": "pavejar",
    "pavejo": "pavejar",
    "pavejou": "pavejar",
    "pavejá": "pavejar",
    "pavejámo": "pavejar",
    "pavejámos": "pavejar",
    "pavejáramo": "pavejar",
    "pavejáramos": "pavejar",
    "pavejárei": "pavejar",
    "pavejáreis": "pavejar",
    "pavejásseis": "pavejar",
    "pavejássemos": "pavejar",
    "pavejávamo": "pavejar",
    "pavejávamos": "pavejar",
    "pavejávei": "pavejar",
    "pavejáveis": "pavejar",
    "pavesa": "pavesar",
    "pavesada": "pavesar",
    "pavesadas": "pavesar",
    "pavesado": "pavesar",
    "pavesados": "pavesar",
    "pavesaduras": "pavesadura",
    "pavesai": "pavesar",
    "pavesais": "pavesar",
    "pavesam": "pavesar",
    "pavesamo": "pavesar",
    "pavesamos": "pavesar",
    "pavesando": "pavesar",
    "pavesara": "pavesar",
    "pavesaram": "pavesar",
    "pavesaras": "pavesar",
    "pavesarde": "pavesar",
    "pavesardes": "pavesar",
    "pavesare": "pavesar",
    "pavesarei": "pavesar",
    "pavesareis": "pavesar",
    "pavesarem": "pavesar",
    "pavesaremos": "pavesar",
    "pavesares": "pavesar",
    "pavesaria": "pavesar",
    "pavesariam": "pavesar",
    "pavesarias": "pavesar",
    "pavesarmo": "pavesar",
    "pavesarmos": "pavesar",
    "pavesará": "pavesar",
    "pavesarás": "pavesar",
    "pavesarão": "pavesar",
    "pavesaríamos": "pavesar",
    "pavesaríeis": "pavesar",
    "pavesas": "pavesar",
    "pavesasse": "pavesar",
    "pavesassem": "pavesar",
    "pavesasses": "pavesar",
    "pavesaste": "pavesar",
    "pavesastes": "pavesar",
    "pavesava": "pavesar",
    "pavesavam": "pavesar",
    "pavesavas": "pavesar",
    "pavese": "pavesar",
    "pavesei": "pavesar",
    "paveseis": "pavesar",
    "pavesem": "pavesar",
    "pavesemo": "pavesar",
    "pavesemos": "pavesar",
    "paveses": "pavesar",
    "paveso": "pavesar",
    "pavesou": "pavesar",
    "pavesá": "pavesar",
    "pavesámo": "pavesar",
    "pavesámos": "pavesar",
    "pavesáramo": "pavesar",
    "pavesáramos": "pavesar",
    "pavesárei": "pavesar",
    "pavesáreis": "pavesar",
    "pavesásseis": "pavesar",
    "pavesássemos": "pavesar",
    "pavesávamo": "pavesar",
    "pavesávamos": "pavesar",
    "pavesávei": "pavesar",
    "pavesáveis": "pavesar",
    "pavias": "pavia",
    "pavilhões": "pavilhão",
    "pavimenta": "pavimentar",
    "pavimentada": "pavimentar",
    "pavimentadas": "pavimentar",
    "pavimentado": "pavimentar",
    "pavimentados": "pavimentar",
    "pavimentai": "pavimentar",
    "pavimentais": "pavimentar",
    "pavimentam": "pavimentar",
    "pavimentamo": "pavimentar",
    "pavimentamos": "pavimentar",
    "pavimentando": "pavimentar",
    "pavimentara": "pavimentar",
    "pavimentaram": "pavimentar",
    "pavimentaras": "pavimentar",
    "pavimentarde": "pavimentar",
    "pavimentardes": "pavimentar",
    "pavimentare": "pavimentar",
    "pavimentarei": "pavimentar",
    "pavimentareis": "pavimentar",
    "pavimentarem": "pavimentar",
    "pavimentaremos": "pavimentar",
    "pavimentares": "pavimentar",
    "pavimentaria": "pavimentar",
    "pavimentariam": "pavimentar",
    "pavimentarias": "pavimentar",
    "pavimentarmo": "pavimentar",
    "pavimentarmos": "pavimentar",
    "pavimentará": "pavimentar",
    "pavimentarás": "pavimentar",
    "pavimentarão": "pavimentar",
    "pavimentaríamos": "pavimentar",
    "pavimentaríeis": "pavimentar",
    "pavimentas": "pavimentar",
    "pavimentasse": "pavimentar",
    "pavimentassem": "pavimentar",
    "pavimentasses": "pavimentar",
    "pavimentaste": "pavimentar",
    "pavimentastes": "pavimentar",
    "pavimentava": "pavimentar",
    "pavimentavam": "pavimentar",
    "pavimentavas": "pavimentar",
    "pavimentações": "pavimentação",
    "pavimente": "pavimentar",
    "pavimentei": "pavimentar",
    "pavimenteis": "pavimentar",
    "pavimentem": "pavimentar",
    "pavimentemo": "pavimentar",
    "pavimentemos": "pavimentar",
    "pavimentes": "pavimentar",
    "pavimento": "pavimentar",
    "pavimentos": "pavimento",
    "pavimentou": "pavimentar",
    "pavimentá": "pavimentar",
    "pavimentámo": "pavimentar",
    "pavimentámos": "pavimentar",
    "pavimentáramo": "pavimentar",
    "pavimentáramos": "pavimentar",
    "pavimentárei": "pavimentar",
    "pavimentáreis": "pavimentar",
    "pavimentásseis": "pavimentar",
    "pavimentássemos": "pavimentar",
    "pavimentávamo": "pavimentar",
    "pavimentávamos": "pavimentar",
    "pavimentávei": "pavimentar",
    "pavimentáveis": "pavimentar",
    "paviolas": "paviola",
    "pavios": "pavio",
    "pavoa": "pavão",
    "pavoas": "pavão",
    "pavonada": "pavonado",
    "pavonadas": "pavonado",
    "pavonados": "pavonado",
    "pavoncinhos": "pavoncinho",
    "pavoncinos": "pavoncino",
    "pavoneada": "pavonear",
    "pavoneadas": "pavonear",
    "pavoneado": "pavonear",
    "pavoneados": "pavonear",
    "pavoneai": "pavonear",
    "pavoneais": "pavonear",
    "pavoneamo": "pavonear",
    "pavoneamos": "pavonear",
    "pavoneando": "pavonear",
    "pavoneara": "pavonear",
    "pavonearam": "pavonear",
    "pavonearas": "pavonear",
    "pavonearde": "pavonear",
    "pavoneardes": "pavonear",
    "pavoneare": "pavonear",
    "pavonearei": "pavonear",
    "pavoneareis": "pavonear",
    "pavonearem": "pavonear",
    "pavonearemos": "pavonear",
    "pavoneares": "pavonear",
    "pavonearia": "pavonear",
    "pavoneariam": "pavonear",
    "pavonearias": "pavonear",
    "pavonearmo": "pavonear",
    "pavonearmos": "pavonear",
    "pavoneará": "pavonear",
    "pavonearás": "pavonear",
    "pavonearão": "pavonear",
    "pavonearíamos": "pavonear",
    "pavonearíeis": "pavonear",
    "pavoneasse": "pavonear",
    "pavoneassem": "pavonear",
    "pavoneasses": "pavonear",
    "pavoneaste": "pavonear",
    "pavoneastes": "pavonear",
    "pavoneava": "pavonear",
    "pavoneavam": "pavonear",
    "pavoneavas": "pavonear",
    "pavoneei": "pavonear",
    "pavoneeis": "pavonear",
    "pavoneemo": "pavonear",
    "pavoneemos": "pavonear",
    "pavoneia": "pavonear",
    "pavoneiam": "pavonear",
    "pavoneias": "pavonear",
    "pavoneie": "pavonear",
    "pavoneiem": "pavonear",
    "pavoneies": "pavonear",
    "pavoneio": "pavonear",
    "pavoneios": "pavoneio",
    "pavoneou": "pavonear",
    "pavoneá": "pavonear",
    "pavoneámo": "pavonear",
    "pavoneámos": "pavonear",
    "pavoneáramo": "pavonear",
    "pavoneáramos": "pavonear",
    "pavoneárei": "pavonear",
    "pavoneáreis": "pavonear",
    "pavoneásseis": "pavonear",
    "pavoneássemos": "pavonear",
    "pavoneávamo": "pavonear",
    "pavoneávamos": "pavonear",
    "pavoneávei": "pavonear",
    "pavoneáveis": "pavonear",
    "pavonácea": "pavonáceo",
    "pavonáceas": "pavonáceo",
    "pavonáceos": "pavonáceo",
    "pavores": "pavor",
    "pavorosa": "pavoroso",
    "pavorosas": "pavoroso",
    "pavorosos": "pavoroso",
    "pavões": "pavão",
    "paxaliques": "paxalique",
    "paxás": "paxá",
    "pazadas": "pazada",
    "pazeada": "pazear",
    "pazeadas": "pazear",
    "pazeado": "pazear",
    "pazeados": "pazear",
    "pazeai": "pazear",
    "pazeais": "pazear",
    "pazeamo": "pazear",
    "pazeamos": "pazear",
    "pazeando": "pazear",
    "pazeara": "pazear",
    "pazearam": "pazear",
    "pazearas": "pazear",
    "pazeardes": "pazear",
    "pazearei": "pazear",
    "pazeareis": "pazear",
    "pazearem": "pazear",
    "pazearemos": "pazear",
    "pazeares": "pazear",
    "pazearia": "pazear",
    "pazeariam": "pazear",
    "pazearias": "pazear",
    "pazearmo": "pazear",
    "pazearmos": "pazear",
    "pazeará": "pazear",
    "pazearás": "pazear",
    "pazearão": "pazear",
    "pazearíamos": "pazear",
    "pazearíeis": "pazear",
    "pazeasse": "pazear",
    "pazeassem": "pazear",
    "pazeasses": "pazear",
    "pazeaste": "pazear",
    "pazeastes": "pazear",
    "pazeava": "pazear",
    "pazeavam": "pazear",
    "pazeavas": "pazear",
    "pazeei": "pazear",
    "pazeeis": "pazear",
    "pazeemo": "pazear",
    "pazeemos": "pazear",
    "pazeia": "pazear",
    "pazeiam": "pazear",
    "pazeias": "pazear",
    "pazeie": "pazear",
    "pazeiem": "pazear",
    "pazeies": "pazear",
    "pazeio": "pazear",
    "pazeou": "pazear",
    "pazes": "paz",
    "pazeámo": "pazear",
    "pazeámos": "pazear",
    "pazeáramo": "pazear",
    "pazeáramos": "pazear",
    "pazeáreis": "pazear",
    "pazeásseis": "pazear",
    "pazeássemos": "pazear",
    "pazeávamo": "pazear",
    "pazeávamos": "pazear",
    "pazeáveis": "pazear",
    "pazigua": "paziguar",
    "paziguada": "paziguar",
    "paziguadas": "paziguar",
    "paziguado": "paziguar",
    "paziguados": "paziguar",
    "paziguai": "paziguar",
    "paziguais": "paziguar",
    "paziguam": "paziguar",
    "paziguamo": "paziguar",
    "paziguamos": "paziguar",
    "paziguando": "paziguar",
    "paziguara": "paziguar",
    "paziguaram": "paziguar",
    "paziguaras": "paziguar",
    "paziguarde": "paziguar",
    "paziguardes": "paziguar",
    "paziguare": "paziguar",
    "paziguarei": "paziguar",
    "paziguareis": "paziguar",
    "paziguarem": "paziguar",
    "paziguaremos": "paziguar",
    "paziguares": "paziguar",
    "paziguaria": "paziguar",
    "paziguariam": "paziguar",
    "paziguarias": "paziguar",
    "paziguarmo": "paziguar",
    "paziguarmos": "paziguar",
    "paziguará": "paziguar",
    "paziguarás": "paziguar",
    "paziguarão": "paziguar",
    "paziguaríamos": "paziguar",
    "paziguaríeis": "paziguar",
    "paziguas": "paziguar",
    "paziguasse": "paziguar",
    "paziguassem": "paziguar",
    "paziguasses": "paziguar",
    "paziguaste": "paziguar",
    "paziguastes": "paziguar",
    "paziguava": "paziguar",
    "paziguavam": "paziguar",
    "paziguavas": "paziguar",
    "paziguei": "paziguar",
    "pazigueis": "paziguar",
    "paziguemo": "paziguar",
    "paziguemos": "paziguar",
    "pazigues": "paziguar",
    "paziguo": "paziguar",
    "paziguou": "paziguar",
    "paziguá": "paziguar",
    "paziguámo": "paziguar",
    "paziguámos": "paziguar",
    "paziguáramo": "paziguar",
    "paziguáramos": "paziguar",
    "paziguárei": "paziguar",
    "paziguáreis": "paziguar",
    "paziguásseis": "paziguar",
    "paziguássemos": "paziguar",
    "paziguávamo": "paziguar",
    "paziguávamos": "paziguar",
    "paziguávei": "paziguar",
    "paziguáveis": "paziguar",
    "pazigúe": "paziguar",
    "pazigúem": "paziguar",
    "pazigúes": "paziguar",
    "pazinha": "pá",
    "pazinhas": "pá",
    "pazita": "pá",
    "pazitas": "pá",
    "pazões": "pazão",
    "paços": "paço",
    "países": "país",
    "paúlica": "paúlico",
    "paúlicas": "paúlico",
    "paúlicos": "paúlico",
    "peada": "pear",
    "peadas": "pear",
    "peado": "pear",
    "peadoiros": "peadoiro",
    "peados": "pear",
    "peadouros": "peadouro",
    "peai": "pear",
    "peais": "pear",
    "peamo": "pear",
    "peamos": "pear",
    "peando": "pear",
    "peanhas": "peanha",
    "peanhos": "peanho",
    "peara": "pear",
    "pearam": "pear",
    "pearas": "pear",
    "pearde": "pear",
    "peardes": "pear",
    "peare": "pear",
    "pearei": "pear",
    "peareis": "pear",
    "pearem": "pear",
    "pearemos": "pear",
    "peares": "pear",
    "pearia": "pear",
    "peariam": "pear",
    "pearias": "pear",
    "pearmo": "pear",
    "pearmos": "pear",
    "peará": "pear",
    "pearás": "pear",
    "pearão": "pear",
    "pearíamos": "pear",
    "pearíeis": "pear",
    "peasse": "pear",
    "peassem": "pear",
    "peasses": "pear",
    "peaste": "pear",
    "peastes": "pear",
    "peava": "pear",
    "peavam": "pear",
    "peavas": "pear",
    "peaças": "peaça",
    "peca": "peco",
    "pecabilidades": "pecabilidade",
    "pecada": "pecar",
    "pecadas": "pecar",
    "pecadaços": "pecadaço",
    "pecadilhos": "pecadilho",
    "pecadinho": "pecado",
    "pecadinhos": "pecado",
    "pecadito": "pecado",
    "pecaditos": "pecado",
    "pecado": "pecar",
    "pecadora": "pecador",
    "pecadoras": "pecador",
    "pecadoraça": "pecadoraço",
    "pecadoraças": "pecadoraço",
    "pecadoraços": "pecadoraço",
    "pecadores": "pecador",
    "pecados": "pecar",
    "pecais": "pecar",
    "pecam": "pecar",
    "pecaminosa": "pecaminoso",
    "pecaminosas": "pecaminoso",
    "pecaminosos": "pecaminoso",
    "pecamo": "pecar",
    "pecamos": "pecar",
    "pecando": "pecar",
    "pecantes": "pecante",
    "pecara": "pecar",
    "pecaram": "pecar",
    "pecaras": "pecar",
    "pecardes": "pecar",
    "pecarei": "pecar",
    "pecareis": "pecar",
    "pecarem": "pecar",
    "pecaremos": "pecar",
    "pecares": "pecar",
    "pecaria": "pecar",
    "pecariam": "pecar",
    "pecarias": "pecar",
    "pecarmo": "pecar",
    "pecarmos": "pecar",
    "pecará": "pecar",
    "pecarás": "pecar",
    "pecarão": "pecar",
    "pecaríamos": "pecar",
    "pecaríeis": "pecar",
    "pecas": "peco",
    "pecasse": "pecar",
    "pecassem": "pecar",
    "pecasses": "pecar",
    "pecaste": "pecar",
    "pecastes": "pecar",
    "pecava": "pecar",
    "pecavam": "pecar",
    "pecavas": "pecar",
    "pechadas": "pechada",
    "pechas": "pecha",
    "pecheblendas": "pecheblenda",
    "pechelingues": "pechelingue",
    "pechilingues": "pechilingue",
    "pechincha": "pechincho",
    "pechinchada": "pechinchar",
    "pechinchadas": "pechinchar",
    "pechinchado": "pechinchar",
    "pechinchados": "pechinchar",
    "pechinchai": "pechinchar",
    "pechinchais": "pechinchar",
    "pechincham": "pechinchar",
    "pechinchamo": "pechinchar",
    "pechinchamos": "pechinchar",
    "pechinchando": "pechinchar",
    "pechinchara": "pechinchar",
    "pechincharam": "pechinchar",
    "pechincharas": "pechinchar",
    "pechincharde": "pechinchar",
    "pechinchardes": "pechinchar",
    "pechinchare": "pechinchar",
    "pechincharei": "pechinchar",
    "pechinchareis": "pechinchar",
    "pechincharem": "pechinchar",
    "pechincharemos": "pechinchar",
    "pechinchares": "pechinchar",
    "pechincharia": "pechinchar",
    "pechinchariam": "pechinchar",
    "pechincharias": "pechinchar",
    "pechincharmo": "pechinchar",
    "pechincharmos": "pechinchar",
    "pechinchará": "pechinchar",
    "pechincharás": "pechinchar",
    "pechincharão": "pechinchar",
    "pechincharíamos": "pechinchar",
    "pechincharíeis": "pechinchar",
    "pechinchas": "pechincho",
    "pechinchasse": "pechinchar",
    "pechinchassem": "pechinchar",
    "pechinchasses": "pechinchar",
    "pechinchaste": "pechinchar",
    "pechinchastes": "pechinchar",
    "pechinchava": "pechinchar",
    "pechinchavam": "pechinchar",
    "pechinchavas": "pechinchar",
    "pechinche": "pechinchar",
    "pechinchei": "pechinchar",
    "pechincheira": "pechincheiro",
    "pechincheiras": "pechincheiro",
    "pechincheiros": "pechincheiro",
    "pechincheis": "pechinchar",
    "pechinchem": "pechinchar",
    "pechinchemo": "pechinchar",
    "pechinchemos": "pechinchar",
    "pechinches": "pechinchar",
    "pechincho": "pechinchar",
    "pechinchos": "pechincho",
    "pechinchou": "pechinchar",
    "pechinchá": "pechinchar",
    "pechinchámo": "pechinchar",
    "pechinchámos": "pechinchar",
    "pechincháramo": "pechinchar",
    "pechincháramos": "pechinchar",
    "pechinchárei": "pechinchar",
    "pechincháreis": "pechinchar",
    "pechinchásseis": "pechinchar",
    "pechinchássemos": "pechinchar",
    "pechinchávamo": "pechinchar",
    "pechinchávamos": "pechinchar",
    "pechinchávei": "pechinchar",
    "pechincháveis": "pechinchar",
    "pechisbeques": "pechisbeque",
    "pechosa": "pechoso",
    "pechosas": "pechoso",
    "pechosos": "pechoso",
    "pecilotérmica": "pecilotérmico",
    "pecilotérmicas": "pecilotérmico",
    "pecilotérmicos": "pecilotérmico",
    "pecinha": "peça",
    "pecinhas": "peça",
    "peciolada": "peciolado",
    "pecioladas": "peciolado",
    "peciolados": "peciolado",
    "peciolares": "peciolar",
    "pecita": "peça",
    "pecitas": "peça",
    "peco": "pecar",
    "pecos": "peco",
    "pecou": "pecar",
    "pectinas": "pectina",
    "pectinibrânquia": "pectinibrânquio",
    "pectinibrânquias": "pectinibrânquio",
    "pectinibrânquios": "pectinibrânquio",
    "pectinicórnea": "pectinicórneo",
    "pectinicórneas": "pectinicórneo",
    "pectinicórneos": "pectinicórneo",
    "pectinídeos": "pectinídeo",
    "pectorais": "pectoral",
    "pectínea": "pectíneo",
    "pectíneas": "pectíneo",
    "pectíneos": "pectíneo",
    "pectínidas": "pectínida",
    "peculadora": "peculador",
    "peculadoras": "peculador",
    "peculadores": "peculador",
    "peculatos": "peculato",
    "peculiares": "peculiar",
    "peculiaridades": "peculiaridade",
    "peculiaríssima": "peculiar",
    "peculiaríssimas": "peculiar",
    "peculiaríssimo": "peculiar",
    "peculiaríssimos": "peculiar",
    "pecuniosa": "pecunioso",
    "pecuniosas": "pecunioso",
    "pecuniosos": "pecunioso",
    "pecuniária": "pecuniário",
    "pecuniárias": "pecuniário",
    "pecuniários": "pecuniário",
    "pecuária": "pecuário",
    "pecuárias": "pecuário",
    "pecuários": "pecuário",
    "pecámo": "pecar",
    "pecámos": "pecar",
    "pecáramo": "pecar",
    "pecáramos": "pecar",
    "pecáreis": "pecar",
    "pecásseis": "pecar",
    "pecássemos": "pecar",
    "pecávamo": "pecar",
    "pecávamos": "pecar",
    "pecáveis": "pecável",
    "pecíolos": "pecíolo",
    "pecúlios": "pecúlio",
    "pecúnias": "pecúnia",
    "pedacinho": "pedaço",
    "pedacinhos": "pedaço",
    "pedacito": "pedaço",
    "pedacitos": "pedaço",
    "pedagoga": "pedagogo",
    "pedagogas": "pedagogo",
    "pedagogias": "pedagogia",
    "pedagogices": "pedagogice",
    "pedagogismos": "pedagogismo",
    "pedagogistas": "pedagogista",
    "pedagogos": "pedagogo",
    "pedagógica": "pedagógico",
    "pedagógicas": "pedagógico",
    "pedagógicos": "pedagógico",
    "pedais": "pedal",
    "pedala": "pedalar",
    "pedalada": "pedalar",
    "pedaladas": "pedalar",
    "pedalado": "pedalar",
    "pedalados": "pedalar",
    "pedalagens": "pedalagem",
    "pedalai": "pedalar",
    "pedalais": "pedalar",
    "pedalam": "pedalar",
    "pedalamo": "pedalar",
    "pedalamos": "pedalar",
    "pedalando": "pedalar",
    "pedalara": "pedalar",
    "pedalaram": "pedalar",
    "pedalaras": "pedalar",
    "pedalardes": "pedalar",
    "pedalarei": "pedalar",
    "pedalareis": "pedalar",
    "pedalarem": "pedalar",
    "pedalaremos": "pedalar",
    "pedalares": "pedalar",
    "pedalaria": "pedalar",
    "pedalariam": "pedalar",
    "pedalarias": "pedalar",
    "pedalarmo": "pedalar",
    "pedalarmos": "pedalar",
    "pedalará": "pedalar",
    "pedalarás": "pedalar",
    "pedalarão": "pedalar",
    "pedalaríamos": "pedalar",
    "pedalaríeis": "pedalar",
    "pedalas": "pedalar",
    "pedalasse": "pedalar",
    "pedalassem": "pedalar",
    "pedalasses": "pedalar",
    "pedalaste": "pedalar",
    "pedalastes": "pedalar",
    "pedalava": "pedalar",
    "pedalavam": "pedalar",
    "pedalavas": "pedalar",
    "pedale": "pedalar",
    "pedalei": "pedalar",
    "pedaleira": "pedaleiro",
    "pedaleiras": "pedaleiro",
    "pedaleiros": "pedaleiro",
    "pedaleis": "pedalar",
    "pedalem": "pedalar",
    "pedalemo": "pedalar",
    "pedalemos": "pedalar",
    "pedales": "pedalar",
    "pedaliformes": "pedaliforme",
    "pedalistas": "pedalista",
    "pedaliáceas": "pedaliácea",
    "pedalo": "pedalar",
    "pedalou": "pedalar",
    "pedalámo": "pedalar",
    "pedalámos": "pedalar",
    "pedaláramo": "pedalar",
    "pedaláramos": "pedalar",
    "pedaláreis": "pedalar",
    "pedalásseis": "pedalar",
    "pedalássemos": "pedalar",
    "pedalávamo": "pedalar",
    "pedalávamos": "pedalar",
    "pedaláveis": "pedalar",
    "pedantarias": "pedantaria",
    "pedanteada": "pedantear",
    "pedanteadas": "pedantear",
    "pedanteado": "pedantear",
    "pedanteados": "pedantear",
    "pedanteai": "pedantear",
    "pedanteais": "pedantear",
    "pedanteamo": "pedantear",
    "pedanteamos": "pedantear",
    "pedanteando": "pedantear",
    "pedanteara": "pedantear",
    "pedantearam": "pedantear",
    "pedantearas": "pedantear",
    "pedanteardes": "pedantear",
    "pedantearei": "pedantear",
    "pedanteareis": "pedantear",
    "pedantearem": "pedantear",
    "pedantearemos": "pedantear",
    "pedanteares": "pedantear",
    "pedantearia": "pedantear",
    "pedanteariam": "pedantear",
    "pedantearias": "pedantear",
    "pedantearmo": "pedantear",
    "pedantearmos": "pedantear",
    "pedanteará": "pedantear",
    "pedantearás": "pedantear",
    "pedantearão": "pedantear",
    "pedantearíamos": "pedantear",
    "pedantearíeis": "pedantear",
    "pedanteasse": "pedantear",
    "pedanteassem": "pedantear",
    "pedanteasses": "pedantear",
    "pedanteaste": "pedantear",
    "pedanteastes": "pedantear",
    "pedanteava": "pedantear",
    "pedanteavam": "pedantear",
    "pedanteavas": "pedantear",
    "pedanteei": "pedantear",
    "pedanteeis": "pedantear",
    "pedanteemo": "pedantear",
    "pedanteemos": "pedantear",
    "pedanteia": "pedantear",
    "pedanteiam": "pedantear",
    "pedanteias": "pedantear",
    "pedanteie": "pedantear",
    "pedanteiem": "pedantear",
    "pedanteies": "pedantear",
    "pedanteio": "pedantear",
    "pedanteou": "pedantear",
    "pedantes": "pedante",
    "pedantesca": "pedantesco",
    "pedantescas": "pedantesco",
    "pedantescos": "pedantesco",
    "pedantezinha": "pedante",
    "pedantezinhas": "pedante",
    "pedantezinho": "pedante",
    "pedantezinhos": "pedante",
    "pedantezita": "pedante",
    "pedantezitas": "pedante",
    "pedantezito": "pedante",
    "pedantezitos": "pedante",
    "pedanteámo": "pedantear",
    "pedanteámos": "pedantear",
    "pedanteáramo": "pedantear",
    "pedanteáramos": "pedantear",
    "pedanteáreis": "pedantear",
    "pedanteásseis": "pedantear",
    "pedanteássemos": "pedantear",
    "pedanteávamo": "pedantear",
    "pedanteávamos": "pedantear",
    "pedanteáveis": "pedantear",
    "pedantices": "pedantice",
    "pedantismos": "pedantismo",
    "pedantocracias": "pedantocracia",
    "pedantocrática": "pedantocrático",
    "pedantocráticas": "pedantocrático",
    "pedantocráticos": "pedantocrático",
    "pedantíssima": "pedante",
    "pedantíssimas": "pedante",
    "pedantíssimo": "pedante",
    "pedantíssimos": "pedante",
    "pedantória": "pedantório",
    "pedantórias": "pedantório",
    "pedantórios": "pedantório",
    "pedarquias": "pedarquia",
    "pedaços": "pedaço",
    "pede": "pedir",
    "pedem": "pedir",
    "pederastas": "pederasta",
    "pederastias": "pederastia",
    "pedernais": "pedernal",
    "pederneiras": "pederneira",
    "pedes": "pedir",
    "pedestais": "pedestal",
    "pedestres": "pedestre",
    "pedestriana": "pedestriano",
    "pedestrianas": "pedestriano",
    "pedestrianismos": "pedestrianismo",
    "pedestrianistas": "pedestrianista",
    "pedestrianos": "pedestriano",
    "pedi": "pedir",
    "pedia": "pedir",
    "pedialgias": "pedialgia",
    "pediam": "pedir",
    "pedias": "pedir",
    "pediatra": "pediatro",
    "pediatras": "pediatro",
    "pediatrias": "pediatria",
    "pediatros": "pediatro",
    "pedicelada": "pedicelado",
    "pediceladas": "pedicelado",
    "pedicelados": "pedicelado",
    "pedicelos": "pedicelo",
    "pedicelários": "pedicelário",
    "pedichas": "pedicha",
    "pedichona": "pedichão",
    "pedichonas": "pedichão",
    "pedichão": "pedicha",
    "pedichões": "pedichão",
    "pediculada": "pediculado",
    "pediculadas": "pediculado",
    "pediculados": "pediculado",
    "pediculares": "pedicular",
    "pediculídeos": "pediculídeo",
    "pedicura": "pedicuro",
    "pedicuras": "pedicuro",
    "pedicuros": "pedicuro",
    "pedida": "pedir",
    "pedidas": "pedir",
    "pedido": "pedir",
    "pedidora": "pedidor",
    "pedidoras": "pedidor",
    "pedidores": "pedidor",
    "pedidos": "pedir",
    "pediformes": "pediforme",
    "pedigolha": "pedigolho",
    "pedigolhas": "pedigolho",
    "pedigolhos": "pedigolho",
    "pedigonha": "pedigonho",
    "pedigonhas": "pedigonho",
    "pedigonhos": "pedigonho",
    "pedigrees": "pedigree",
    "pedilúvios": "pedilúvio",
    "pedimentos": "pedimento",
    "pedimo": "pedir",
    "pedimos": "pedir",
    "pedimétrica": "pedimétrico",
    "pedimétricas": "pedimétrico",
    "pedimétricos": "pedimétrico",
    "pedincha": "pedinchar",
    "pedinchada": "pedinchar",
    "pedinchadas": "pedinchar",
    "pedinchado": "pedinchar",
    "pedinchados": "pedinchar",
    "pedinchai": "pedinchar",
    "pedinchais": "pedinchar",
    "pedincham": "pedinchar",
    "pedinchamo": "pedinchar",
    "pedinchamos": "pedinchar",
    "pedinchando": "pedinchar",
    "pedinchara": "pedinchar",
    "pedincharam": "pedinchar",
    "pedincharas": "pedinchar",
    "pedincharde": "pedinchar",
    "pedinchardes": "pedinchar",
    "pedinchare": "pedinchar",
    "pedincharei": "pedinchar",
    "pedinchareis": "pedinchar",
    "pedincharem": "pedinchar",
    "pedincharemos": "pedinchar",
    "pedinchares": "pedinchar",
    "pedincharia": "pedinchar",
    "pedinchariam": "pedinchar",
    "pedincharias": "pedinchar",
    "pedincharmo": "pedinchar",
    "pedincharmos": "pedinchar",
    "pedinchará": "pedinchar",
    "pedincharás": "pedinchar",
    "pedincharão": "pedinchar",
    "pedincharíamos": "pedinchar",
    "pedincharíeis": "pedinchar",
    "pedinchas": "pedinchar",
    "pedinchasse": "pedinchar",
    "pedinchassem": "pedinchar",
    "pedinchasses": "pedinchar",
    "pedinchaste": "pedinchar",
    "pedinchastes": "pedinchar",
    "pedinchava": "pedinchar",
    "pedinchavam": "pedinchar",
    "pedinchavas": "pedinchar",
    "pedinche": "pedinchar",
    "pedinchei": "pedinchar",
    "pedincheis": "pedinchar",
    "pedinchem": "pedinchar",
    "pedinchemo": "pedinchar",
    "pedinchemos": "pedinchar",
    "pedinches": "pedinchar",
    "pedinchices": "pedinchice",
    "pedincho": "pedinchar",
    "pedinchona": "pedinchão",
    "pedinchonas": "pedinchão",
    "pedinchou": "pedinchar",
    "pedinchá": "pedinchar",
    "pedinchámo": "pedinchar",
    "pedinchámos": "pedinchar",
    "pedincháramo": "pedinchar",
    "pedincháramos": "pedinchar",
    "pedinchárei": "pedinchar",
    "pedincháreis": "pedinchar",
    "pedinchásseis": "pedinchar",
    "pedinchássemos": "pedinchar",
    "pedinchávamo": "pedinchar",
    "pedinchávamos": "pedinchar",
    "pedinchávei": "pedinchar",
    "pedincháveis": "pedinchar",
    "pedinchões": "pedinchão",
    "pedindo": "pedir",
    "pedinta": "pedintar",
    "pedintada": "pedintar",
    "pedintadas": "pedintar",
    "pedintado": "pedintar",
    "pedintados": "pedintar",
    "pedintai": "pedintar",
    "pedintais": "pedintar",
    "pedintam": "pedintar",
    "pedintamo": "pedintar",
    "pedintamos": "pedintar",
    "pedintando": "pedintar",
    "pedintara": "pedintar",
    "pedintaram": "pedintar",
    "pedintaras": "pedintar",
    "pedintarde": "pedintar",
    "pedintardes": "pedintar",
    "pedintare": "pedintar",
    "pedintarei": "pedintar",
    "pedintareis": "pedintar",
    "pedintarem": "pedintar",
    "pedintaremos": "pedintar",
    "pedintares": "pedintar",
    "pedintaria": "pedintar",
    "pedintariam": "pedintar",
    "pedintarias": "pedintaria",
    "pedintarmo": "pedintar",
    "pedintarmos": "pedintar",
    "pedintará": "pedintar",
    "pedintarás": "pedintar",
    "pedintarão": "pedintar",
    "pedintaríamos": "pedintar",
    "pedintaríeis": "pedintar",
    "pedintas": "pedintar",
    "pedintasse": "pedintar",
    "pedintassem": "pedintar",
    "pedintasses": "pedintar",
    "pedintaste": "pedintar",
    "pedintastes": "pedintar",
    "pedintava": "pedintar",
    "pedintavam": "pedintar",
    "pedintavas": "pedintar",
    "pedinte": "pedintar",
    "pedintei": "pedintar",
    "pedinteis": "pedintar",
    "pedintem": "pedintar",
    "pedintemo": "pedintar",
    "pedintemos": "pedintar",
    "pedintes": "pedinte",
    "pedinto": "pedintar",
    "pedintona": "pedintão",
    "pedintonas": "pedintão",
    "pedintou": "pedintar",
    "pedintá": "pedintar",
    "pedintámo": "pedintar",
    "pedintámos": "pedintar",
    "pedintáramo": "pedintar",
    "pedintáramos": "pedintar",
    "pedintárei": "pedintar",
    "pedintáreis": "pedintar",
    "pedintásseis": "pedintar",
    "pedintássemos": "pedintar",
    "pedintávamo": "pedintar",
    "pedintávamos": "pedintar",
    "pedintávei": "pedintar",
    "pedintáveis": "pedintar",
    "pedintões": "pedintão",
    "pedipalpos": "pedipalpo",
    "pedira": "pedir",
    "pediram": "pedir",
    "pediras": "pedir",
    "pedirde": "pedir",
    "pedirdes": "pedir",
    "pedire": "pedir",
    "pedirei": "pedir",
    "pedireis": "pedir",
    "pedirem": "pedir",
    "pediremos": "pedir",
    "pedires": "pedir",
    "pediria": "pedir",
    "pediriam": "pedir",
    "pedirias": "pedir",
    "pedirmo": "pedir",
    "pedirmos": "pedir",
    "pedirá": "pedir",
    "pedirás": "pedir",
    "pedirão": "pedir",
    "pediríamos": "pedir",
    "pediríeis": "pedir",
    "pedis": "pedir",
    "pedisse": "pedir",
    "pedissem": "pedir",
    "pedisses": "pedir",
    "pediste": "pedir",
    "pedistes": "pedir",
    "peditórios": "peditório",
    "pediu": "pedir",
    "pediálgica": "pediálgico",
    "pediálgicas": "pediálgico",
    "pediálgicos": "pediálgico",
    "pediátrica": "pediátrico",
    "pediátricas": "pediátrico",
    "pediátricos": "pediátrico",
    "pedofilias": "pedofilia",
    "pedofílica": "pedofílico",
    "pedofílicas": "pedofílico",
    "pedofílicos": "pedofílico",
    "pedogamias": "pedogamia",
    "pedogenésica": "pedogenésico",
    "pedogenésicas": "pedogenésico",
    "pedogenésicos": "pedogenésico",
    "pedogenética": "pedogenético",
    "pedogenéticas": "pedogenético",
    "pedogenéticos": "pedogenético",
    "pedogâmica": "pedogâmico",
    "pedogâmicas": "pedogâmico",
    "pedogâmicos": "pedogâmico",
    "pedogéneses": "pedogénese",
    "pedogénica": "pedogénico",
    "pedogénicas": "pedogénico",
    "pedogénicos": "pedogénico",
    "pedoiros": "pedoiro",
    "pedologias": "pedologia",
    "pedológica": "pedológico",
    "pedológicas": "pedológico",
    "pedológicos": "pedológico",
    "pedométrica": "pedométrico",
    "pedométricas": "pedométrico",
    "pedométricos": "pedométrico",
    "pedonais": "pedonal",
    "pedonomias": "pedonomia",
    "pedonómica": "pedonómico",
    "pedonómicas": "pedonómico",
    "pedonómicos": "pedonómico",
    "pedopsiquiatras": "pedopsiquiatra",
    "pedopsiquiatrias": "pedopsiquiatria",
    "pedopsiquiátrica": "pedopsiquiátrico",
    "pedopsiquiátricas": "pedopsiquiátrico",
    "pedopsiquiátricos": "pedopsiquiátrico",
    "pedouros": "pedouro",
    "pedra": "pedrar",
    "pedrada": "pedrar",
    "pedradas": "pedrar",
    "pedradazinha": "pedrado",
    "pedradazinhas": "pedrado",
    "pedradazita": "pedrado",
    "pedradazitas": "pedrado",
    "pedradinha": "pedrado",
    "pedradinhas": "pedrado",
    "pedradinho": "pedrado",
    "pedradinhos": "pedrado",
    "pedradita": "pedrado",
    "pedraditas": "pedrado",
    "pedradito": "pedrado",
    "pedraditos": "pedrado",
    "pedrado": "pedrar",
    "pedrados": "pedrar",
    "pedradozinho": "pedrado",
    "pedradozinhos": "pedrado",
    "pedradozito": "pedrado",
    "pedradozitos": "pedrado",
    "pedradíssima": "pedrado",
    "pedradíssimas": "pedrado",
    "pedradíssimo": "pedrado",
    "pedradíssimos": "pedrado",
    "pedrai": "pedrar",
    "pedrais": "pedrar",
    "pedram": "pedrar",
    "pedramo": "pedrar",
    "pedramos": "pedrar",
    "pedranceiras": "pedranceira",
    "pedrando": "pedrar",
    "pedrara": "pedrar",
    "pedraram": "pedrar",
    "pedraras": "pedrar",
    "pedrarde": "pedrar",
    "pedrardes": "pedrar",
    "pedrare": "pedrar",
    "pedrarei": "pedrar",
    "pedrareis": "pedrar",
    "pedrarem": "pedrar",
    "pedraremos": "pedrar",
    "pedrares": "pedrar",
    "pedraria": "pedrar",
    "pedrariam": "pedrar",
    "pedrarias": "pedraria",
    "pedrarmo": "pedrar",
    "pedrarmos": "pedrar",
    "pedrará": "pedrar",
    "pedrarás": "pedrar",
    "pedrarão": "pedrar",
    "pedraríamos": "pedrar",
    "pedraríeis": "pedrar",
    "pedras": "pedrar",
    "pedrasse": "pedrar",
    "pedrassem": "pedrar",
    "pedrasses": "pedrar",
    "pedraste": "pedrar",
    "pedrastes": "pedrar",
    "pedrava": "pedrar",
    "pedravam": "pedrar",
    "pedravas": "pedrar",
    "pedre": "pedrar",
    "pedregais": "pedregal",
    "pedregosa": "pedregoso",
    "pedregosas": "pedregoso",
    "pedregosos": "pedregoso",
    "pedregulhenta": "pedregulhento",
    "pedregulhentas": "pedregulhento",
    "pedregulhentos": "pedregulhento",
    "pedregulhos": "pedregulho",
    "pedrei": "pedrar",
    "pedreira": "pedreiro",
    "pedreiras": "pedreiro",
    "pedreirinhos": "pedreirinho",
    "pedreiros": "pedreiro",
    "pedreis": "pedrar",
    "pedrem": "pedrar",
    "pedremo": "pedrar",
    "pedremos": "pedrar",
    "pedreneiras": "pedreneira",
    "pedres": "pedrar",
    "pedreses": "pedrês",
    "pedrinha": "pedra",
    "pedrinhas": "pedra",
    "pedriscos": "pedrisco",
    "pedristas": "pedrista",
    "pedrita": "pedra",
    "pedritas": "pedra",
    "pedro": "pedrar",
    "pedroiços": "pedroiço",
    "pedrosa": "pedroso",
    "pedrosas": "pedroso",
    "pedrosites": "pedrosite",
    "pedrositos": "pedrosito",
    "pedrosos": "pedroso",
    "pedrou": "pedrar",
    "pedrouços": "pedrouço",
    "pedrucas": "pedruca",
    "pedrucos": "pedruco",
    "pedrá": "pedrar",
    "pedrámo": "pedrar",
    "pedrámos": "pedrar",
    "pedráramo": "pedrar",
    "pedráramos": "pedrar",
    "pedrárei": "pedrar",
    "pedráreis": "pedrar",
    "pedrásseis": "pedrar",
    "pedrássemos": "pedrar",
    "pedrávamo": "pedrar",
    "pedrávamos": "pedrar",
    "pedrávei": "pedrar",
    "pedráveis": "pedrar",
    "pedrões": "pedrão",
    "pedunculada": "pedunculado",
    "pedunculadas": "pedunculado",
    "pedunculados": "pedunculado",
    "pedunculares": "peduncular",
    "pedunculosa": "pedunculoso",
    "pedunculosas": "pedunculoso",
    "pedunculosos": "pedunculoso",
    "pedálica": "pedálico",
    "pedálicas": "pedálico",
    "pedálicos": "pedálico",
    "pedárquica": "pedárquico",
    "pedárquicas": "pedárquico",
    "pedárquicos": "pedárquico",
    "pedânea": "pedâneo",
    "pedâneas": "pedâneo",
    "pedâneos": "pedâneo",
    "pedíamo": "pedir",
    "pedíamos": "pedir",
    "pedículos": "pedículo",
    "pedíei": "pedir",
    "pedíeis": "pedir",
    "pedífera": "pedífero",
    "pedíferas": "pedífero",
    "pedíferos": "pedífero",
    "pedímana": "pedímano",
    "pedímanas": "pedímano",
    "pedímanos": "pedímano",
    "pedímetros": "pedímetro",
    "pedíramo": "pedir",
    "pedíramos": "pedir",
    "pedírei": "pedir",
    "pedíreis": "pedir",
    "pedísseis": "pedir",
    "pedíssemos": "pedir",
    "pedófila": "pedófilo",
    "pedófilas": "pedófilo",
    "pedófilos": "pedófilo",
    "pedómetros": "pedómetro",
    "pedúnculos": "pedúnculo",
    "peei": "pear",
    "peeiras": "peeira",
    "peeis": "pear",
    "peemo": "pear",
    "peemos": "pear",
    "pega": "pego",
    "pegada": "pegar",
    "pegadas": "pegar",
    "pegadeiras": "pegadeira",
    "pegadilhas": "pegadilha",
    "pegadinha": "pegado",
    "pegadinhas": "pegado",
    "pegadinho": "pegado",
    "pegadinhos": "pegado",
    "pegadita": "pegado",
    "pegaditas": "pegado",
    "pegadito": "pegado",
    "pegaditos": "pegado",
    "pegadiça": "pegadiço",
    "pegadiças": "pegadiço",
    "pegadiços": "pegadiço",
    "pegado": "pegar",
    "pegadoiros": "pegadoiro",
    "pegadora": "pegador",
    "pegadoras": "pegador",
    "pegadores": "pegador",
    "pegados": "pegar",
    "pegadouros": "pegadouro",
    "pegaduras": "pegadura",
    "pegadíssima": "pegado",
    "pegadíssimas": "pegado",
    "pegadíssimo": "pegado",
    "pegadíssimos": "pegado",
    "pegai": "pegar",
    "pegais": "pegar",
    "pegajenta": "pegajento",
    "pegajentas": "pegajento",
    "pegajentos": "pegajento",
    "pegajentíssima": "pegajento",
    "pegajentíssimas": "pegajento",
    "pegajentíssimo": "pegajento",
    "pegajentíssimos": "pegajento",
    "pegajosa": "pegajoso",
    "pegajosas": "pegajoso",
    "pegajosos": "pegajoso",
    "pegajosíssima": "pegajoso",
    "pegajosíssimas": "pegajoso",
    "pegajosíssimo": "pegajoso",
    "pegajosíssimos": "pegajoso",
    "pegam": "pegar",
    "pegamassa": "pegamasso",
    "pegamassas": "pegamasso",
    "pegamassos": "pegamasso",
    "pegamentos": "pegamento",
    "pegamo": "pegar",
    "pegamos": "pegar",
    "pegando": "pegar",
    "peganha": "peganhar",
    "peganhada": "peganhar",
    "peganhadas": "peganhar",
    "peganhado": "peganhar",
    "peganhados": "peganhar",
    "peganhai": "peganhar",
    "peganhais": "peganhar",
    "peganham": "peganhar",
    "peganhamo": "peganhar",
    "peganhamos": "peganhar",
    "peganhando": "peganhar",
    "peganhara": "peganhar",
    "peganharam": "peganhar",
    "peganharas": "peganhar",
    "peganhardes": "peganhar",
    "peganharei": "peganhar",
    "peganhareis": "peganhar",
    "peganharem": "peganhar",
    "peganharemos": "peganhar",
    "peganhares": "peganhar",
    "peganharia": "peganhar",
    "peganhariam": "peganhar",
    "peganharias": "peganhar",
    "peganharmo": "peganhar",
    "peganharmos": "peganhar",
    "peganhará": "peganhar",
    "peganharás": "peganhar",
    "peganharão": "peganhar",
    "peganharíamos": "peganhar",
    "peganharíeis": "peganhar",
    "peganhas": "peganhar",
    "peganhasse": "peganhar",
    "peganhassem": "peganhar",
    "peganhasses": "peganhar",
    "peganhaste": "peganhar",
    "peganhastes": "peganhar",
    "peganhava": "peganhar",
    "peganhavam": "peganhar",
    "peganhavas": "peganhar",
    "peganhe": "peganhar",
    "peganhei": "peganhar",
    "peganheis": "peganhar",
    "peganhem": "peganhar",
    "peganhemo": "peganhar",
    "peganhemos": "peganhar",
    "peganhenta": "peganhento",
    "peganhentas": "peganhento",
    "peganhentos": "peganhento",
    "peganhentíssima": "peganhento",
    "peganhentíssimas": "peganhento",
    "peganhentíssimo": "peganhento",
    "peganhentíssimos": "peganhento",
    "peganhes": "peganhar",
    "peganho": "peganhar",
    "peganhosa": "peganhoso",
    "peganhosas": "peganhoso",
    "peganhosazinha": "peganhoso",
    "peganhosazinhas": "peganhoso",
    "peganhosazita": "peganhoso",
    "peganhosazitas": "peganhoso",
    "peganhosos": "peganhoso",
    "peganhosozinho": "peganhoso",
    "peganhosozinhos": "peganhoso",
    "peganhosozito": "peganhoso",
    "peganhosozitos": "peganhoso",
    "peganhosíssima": "peganhoso",
    "peganhosíssimas": "peganhoso",
    "peganhosíssimo": "peganhoso",
    "peganhosíssimos": "peganhoso",
    "peganhou": "peganhar",
    "peganhámo": "peganhar",
    "peganhámos": "peganhar",
    "peganháramo": "peganhar",
    "peganháramos": "peganhar",
    "peganháreis": "peganhar",
    "peganhásseis": "peganhar",
    "peganhássemos": "peganhar",
    "peganhávamo": "peganhar",
    "peganhávamos": "peganhar",
    "peganháveis": "peganhar",
    "pegara": "pegar",
    "pegaram": "pegar",
    "pegaras": "pegar",
    "pegarde": "pegar",
    "pegardes": "pegar",
    "pegare": "pegar",
    "pegarei": "pegar",
    "pegareis": "pegar",
    "pegarem": "pegar",
    "pegaremos": "pegar",
    "pegares": "pegar",
    "pegaria": "pegar",
    "pegariam": "pegar",
    "pegarias": "pegar",
    "pegarmo": "pegar",
    "pegarmos": "pegar",
    "pegará": "pegar",
    "pegarás": "pegar",
    "pegarão": "pegar",
    "pegaríamos": "pegar",
    "pegaríeis": "pegar",
    "pegas": "pego",
    "pegasse": "pegar",
    "pegassem": "pegar",
    "pegasses": "pegar",
    "pegaste": "pegar",
    "pegastes": "pegar",
    "pegava": "pegar",
    "pegavam": "pegar",
    "pegavas": "pegar",
    "pegmatitos": "pegmatito",
    "pegmatitóides": "pegmatitóide",
    "pegmática": "pegmático",
    "pegmáticas": "pegmático",
    "pegmáticos": "pegmático",
    "pego": "pegar",
    "pegos": "pego",
    "pegou": "pegar",
    "pegue": "pegar",
    "peguei": "pegar",
    "pegueira": "pegueiro",
    "pegueiras": "pegueiro",
    "pegueiros": "pegueiro",
    "pegueis": "pegar",
    "peguem": "pegar",
    "peguemo": "pegar",
    "peguemos": "pegar",
    "pegues": "pegar",
    "peguilha": "peguilhar",
    "peguilhada": "peguilhar",
    "peguilhadas": "peguilhar",
    "peguilhado": "peguilhar",
    "peguilhados": "peguilhar",
    "peguilhai": "peguilhar",
    "peguilhais": "peguilhar",
    "peguilham": "peguilhar",
    "peguilhamo": "peguilhar",
    "peguilhamos": "peguilhar",
    "peguilhando": "peguilhar",
    "peguilhara": "peguilhar",
    "peguilharam": "peguilhar",
    "peguilharas": "peguilhar",
    "peguilhardes": "peguilhar",
    "peguilharei": "peguilhar",
    "peguilhareis": "peguilhar",
    "peguilharem": "peguilhar",
    "peguilharemos": "peguilhar",
    "peguilhares": "peguilhar",
    "peguilharia": "peguilhar",
    "peguilhariam": "peguilhar",
    "peguilharias": "peguilhar",
    "peguilharmo": "peguilhar",
    "peguilharmos": "peguilhar",
    "peguilhará": "peguilhar",
    "peguilharás": "peguilhar",
    "peguilharão": "peguilhar",
    "peguilharíamos": "peguilhar",
    "peguilharíeis": "peguilhar",
    "peguilhas": "peguilhar",
    "peguilhasse": "peguilhar",
    "peguilhassem": "peguilhar",
    "peguilhasses": "peguilhar",
    "peguilhaste": "peguilhar",
    "peguilhastes": "peguilhar",
    "peguilhava": "peguilhar",
    "peguilhavam": "peguilhar",
    "peguilhavas": "peguilhar",
    "peguilhe": "peguilhar",
    "peguilhei": "peguilhar",
    "peguilheis": "peguilhar",
    "peguilhem": "peguilhar",
    "peguilhemo": "peguilhar",
    "peguilhemos": "peguilhar",
    "peguilhenta": "peguilhento",
    "peguilhentas": "peguilhento",
    "peguilhentos": "peguilhento",
    "peguilhes": "peguilhar",
    "peguilho": "peguilhar",
    "peguilhos": "peguilho",
    "peguilhou": "peguilhar",
    "peguilhámo": "peguilhar",
    "peguilhámos": "peguilhar",
    "peguilháramo": "peguilhar",
    "peguilháramos": "peguilhar",
    "peguilháreis": "peguilhar",
    "peguilhásseis": "peguilhar",
    "peguilhássemos": "peguilhar",
    "peguilhávamo": "peguilhar",
    "peguilhávamos": "peguilhar",
    "peguilháveis": "peguilhar",
    "peguinha": "peguinhar",
    "peguinhada": "peguinhar",
    "peguinhadas": "peguinhar",
    "peguinhado": "peguinhar",
    "peguinhados": "peguinhar",
    "peguinhai": "peguinhar",
    "peguinhais": "peguinhar",
    "peguinham": "peguinhar",
    "peguinhamo": "peguinhar",
    "peguinhamos": "peguinhar",
    "peguinhando": "peguinhar",
    "peguinhara": "peguinhar",
    "peguinharam": "peguinhar",
    "peguinharas": "peguinhar",
    "peguinharde": "peguinhar",
    "peguinhardes": "peguinhar",
    "peguinhare": "peguinhar",
    "peguinharei": "peguinhar",
    "peguinhareis": "peguinhar",
    "peguinharem": "peguinhar",
    "peguinharemos": "peguinhar",
    "peguinhares": "peguinhar",
    "peguinharia": "peguinhar",
    "peguinhariam": "peguinhar",
    "peguinharias": "peguinhar",
    "peguinharmo": "peguinhar",
    "peguinharmos": "peguinhar",
    "peguinhará": "peguinhar",
    "peguinharás": "peguinhar",
    "peguinharão": "peguinhar",
    "peguinharíamos": "peguinhar",
    "peguinharíeis": "peguinhar",
    "peguinhas": "peguinhar",
    "peguinhasse": "peguinhar",
    "peguinhassem": "peguinhar",
    "peguinhasses": "peguinhar",
    "peguinhaste": "peguinhar",
    "peguinhastes": "peguinhar",
    "peguinhava": "peguinhar",
    "peguinhavam": "peguinhar",
    "peguinhavas": "peguinhar",
    "peguinhe": "peguinhar",
    "peguinhei": "peguinhar",
    "peguinheis": "peguinhar",
    "peguinhem": "peguinhar",
    "peguinhemo": "peguinhar",
    "peguinhemos": "peguinhar",
    "peguinhes": "peguinhar",
    "peguinho": "peguinhar",
    "peguinhou": "peguinhar",
    "peguinhá": "peguinhar",
    "peguinhámo": "peguinhar",
    "peguinhámos": "peguinhar",
    "peguinháramo": "peguinhar",
    "peguinháramos": "peguinhar",
    "peguinhárei": "peguinhar",
    "peguinháreis": "peguinhar",
    "peguinhásseis": "peguinhar",
    "peguinhássemos": "peguinhar",
    "peguinhávamo": "peguinhar",
    "peguinhávamos": "peguinhar",
    "peguinhávei": "peguinhar",
    "peguinháveis": "peguinhar",
    "pegulhais": "pegulhal",
    "pegulhos": "pegulho",
    "pegurais": "pegural",
    "pegureira": "pegureiro",
    "pegureiras": "pegureiro",
    "pegureiros": "pegureiro",
    "pegá": "pegar",
    "pegámo": "pegar",
    "pegámos": "pegar",
    "pegáramo": "pegar",
    "pegáramos": "pegar",
    "pegárei": "pegar",
    "pegáreis": "pegar",
    "pegásseis": "pegar",
    "pegássemos": "pegar",
    "pegávamo": "pegar",
    "pegávamos": "pegar",
    "pegávei": "pegar",
    "pegáveis": "pegar",
    "pegões": "pegão",
    "peia": "pear",
    "peiam": "pear",
    "peias": "peia",
    "peida": "peidar",
    "peidada": "peidar",
    "peidadas": "peidar",
    "peidado": "peidar",
    "peidados": "peidar",
    "peidai": "peidar",
    "peidais": "peidar",
    "peidam": "peidar",
    "peidamo": "peidar",
    "peidamos": "peidar",
    "peidando": "peidar",
    "peidara": "peidar",
    "peidaram": "peidar",
    "peidaras": "peidar",
    "peidardes": "peidar",
    "peidarei": "peidar",
    "peidareis": "peidar",
    "peidarem": "peidar",
    "peidaremos": "peidar",
    "peidares": "peidar",
    "peidaria": "peidar",
    "peidariam": "peidar",
    "peidarias": "peidar",
    "peidarmo": "peidar",
    "peidarmos": "peidar",
    "peidará": "peidar",
    "peidarás": "peidar",
    "peidarão": "peidar",
    "peidaríamos": "peidar",
    "peidaríeis": "peidar",
    "peidas": "peidar",
    "peidasse": "peidar",
    "peidassem": "peidar",
    "peidasses": "peidar",
    "peidaste": "peidar",
    "peidastes": "peidar",
    "peidava": "peidar",
    "peidavam": "peidar",
    "peidavas": "peidar",
    "peide": "peidar",
    "peidei": "peidar",
    "peideis": "peidar",
    "peidem": "peidar",
    "peidemo": "peidar",
    "peidemos": "peidar",
    "peides": "peidar",
    "peido": "peidar",
    "peidos": "peido",
    "peidou": "peidar",
    "peidámo": "peidar",
    "peidámos": "peidar",
    "peidáramo": "peidar",
    "peidáramos": "peidar",
    "peidáreis": "peidar",
    "peidásseis": "peidar",
    "peidássemos": "peidar",
    "peidávamo": "peidar",
    "peidávamos": "peidar",
    "peidáveis": "peidar",
    "peie": "pear",
    "peiem": "pear",
    "peies": "pear",
    "peina": "peinar",
    "peinada": "peinar",
    "peinadas": "peinar",
    "peinado": "peinar",
    "peinados": "peinar",
    "peinai": "peinar",
    "peinais": "peinar",
    "peinam": "peinar",
    "peinamo": "peinar",
    "peinamos": "peinar",
    "peinando": "peinar",
    "peinara": "peinar",
    "peinaram": "peinar",
    "peinaras": "peinar",
    "peinarde": "peinar",
    "peinardes": "peinar",
    "peinare": "peinar",
    "peinarei": "peinar",
    "peinareis": "peinar",
    "peinarem": "peinar",
    "peinaremos": "peinar",
    "peinares": "peinar",
    "peinaria": "peinar",
    "peinariam": "peinar",
    "peinarias": "peinar",
    "peinarmo": "peinar",
    "peinarmos": "peinar",
    "peinará": "peinar",
    "peinarás": "peinar",
    "peinarão": "peinar",
    "peinaríamos": "peinar",
    "peinaríeis": "peinar",
    "peinas": "peinar",
    "peinasse": "peinar",
    "peinassem": "peinar",
    "peinasses": "peinar",
    "peinaste": "peinar",
    "peinastes": "peinar",
    "peinava": "peinar",
    "peinavam": "peinar",
    "peinavas": "peinar",
    "peine": "peinar",
    "peinei": "peinar",
    "peineis": "peinar",
    "peinem": "peinar",
    "peinemo": "peinar",
    "peinemos": "peinar",
    "peines": "peinar",
    "peino": "peinar",
    "peinou": "peinar",
    "peiná": "peinar",
    "peinámo": "peinar",
    "peinámos": "peinar",
    "peináramo": "peinar",
    "peináramos": "peinar",
    "peinárei": "peinar",
    "peináreis": "peinar",
    "peinásseis": "peinar",
    "peinássemos": "peinar",
    "peinávamo": "peinar",
    "peinávamos": "peinar",
    "peinávei": "peinar",
    "peináveis": "peinar",
    "peio": "pear",
    "peita": "peitar",
    "peitacas": "peitaca",
    "peitada": "peitar",
    "peitadas": "peitar",
    "peitado": "peitar",
    "peitados": "peitar",
    "peitai": "peitar",
    "peitais": "peitar",
    "peitam": "peitar",
    "peitamo": "peitar",
    "peitamos": "peitar",
    "peitando": "peitar",
    "peitara": "peitar",
    "peitaram": "peitar",
    "peitaras": "peitar",
    "peitarde": "peitar",
    "peitardes": "peitar",
    "peitare": "peitar",
    "peitarei": "peitar",
    "peitareis": "peitar",
    "peitarem": "peitar",
    "peitaremos": "peitar",
    "peitares": "peitar",
    "peitaria": "peitar",
    "peitariam": "peitar",
    "peitarias": "peitar",
    "peitarmo": "peitar",
    "peitarmos": "peitar",
    "peitará": "peitar",
    "peitarás": "peitar",
    "peitarão": "peitar",
    "peitaríamos": "peitar",
    "peitaríeis": "peitar",
    "peitas": "peitar",
    "peitasse": "peitar",
    "peitassem": "peitar",
    "peitasses": "peitar",
    "peitaste": "peitar",
    "peitastes": "peitar",
    "peitava": "peitar",
    "peitavam": "peitar",
    "peitavas": "peitar",
    "peitaças": "peitaça",
    "peitaços": "peitaço",
    "peite": "peitar",
    "peitei": "peitar",
    "peiteira": "peiteiro",
    "peiteiras": "peiteiro",
    "peiteiros": "peiteiro",
    "peiteis": "peitar",
    "peitem": "peitar",
    "peitemo": "peitar",
    "peitemos": "peitar",
    "peites": "peitar",
    "peitilhos": "peitilho",
    "peito": "peitar",
    "peitorais": "peitoral",
    "peitoris": "peitoril",
    "peitos": "peito",
    "peitou": "peitar",
    "peituda": "peitudo",
    "peitudas": "peitudo",
    "peitudazinha": "peitudo",
    "peitudazinhas": "peitudo",
    "peitudazita": "peitudo",
    "peitudazitas": "peitudo",
    "peitudinha": "peitudo",
    "peitudinhas": "peitudo",
    "peitudinho": "peitudo",
    "peitudinhos": "peitudo",
    "peitudita": "peitudo",
    "peituditas": "peitudo",
    "peitudito": "peitudo",
    "peituditos": "peitudo",
    "peitudos": "peitudo",
    "peitudozinho": "peitudo",
    "peitudozinhos": "peitudo",
    "peitudozito": "peitudo",
    "peitudozitos": "peitudo",
    "peitudíssima": "peitudo",
    "peitudíssimas": "peitudo",
    "peitudíssimo": "peitudo",
    "peitudíssimos": "peitudo",
    "peitugas": "peituga",
    "peitá": "peitar",
    "peitámo": "peitar",
    "peitámos": "peitar",
    "peitáramo": "peitar",
    "peitáramos": "peitar",
    "peitárei": "peitar",
    "peitáreis": "peitar",
    "peitásseis": "peitar",
    "peitássemos": "peitar",
    "peitávamo": "peitar",
    "peitávamos": "peitar",
    "peitávei": "peitar",
    "peitáveis": "peitar",
    "peixadas": "peixada",
    "peixarias": "peixaria",
    "peixeira": "peixeiro",
    "peixeiradas": "peixeirada",
    "peixeiras": "peixeiro",
    "peixeiros": "peixeiro",
    "peixelins": "peixelim",
    "peixes": "peixe",
    "peixinho": "peixe",
    "peixinhos": "peixe",
    "peixito": "peixe",
    "peixitos": "peixe",
    "peixotas": "peixota",
    "peixotes": "peixote",
    "peixões": "peixão",
    "peja": "pejar",
    "pejada": "pejar",
    "pejadas": "pejar",
    "pejadinha": "pejado",
    "pejadinhas": "pejado",
    "pejadinho": "pejado",
    "pejadinhos": "pejado",
    "pejadita": "pejado",
    "pejaditas": "pejado",
    "pejadito": "pejado",
    "pejaditos": "pejado",
    "pejado": "pejar",
    "pejadoiros": "pejadoiro",
    "pejados": "pejar",
    "pejadouros": "pejadouro",
    "pejadíssima": "pejado",
    "pejadíssimas": "pejado",
    "pejadíssimo": "pejado",
    "pejadíssimos": "pejado",
    "pejai": "pejar",
    "pejais": "pejar",
    "pejam": "pejar",
    "pejamentos": "pejamento",
    "pejamo": "pejar",
    "pejamos": "pejar",
    "pejando": "pejar",
    "pejara": "pejar",
    "pejaram": "pejar",
    "pejaras": "pejar",
    "pejarde": "pejar",
    "pejardes": "pejar",
    "pejare": "pejar",
    "pejarei": "pejar",
    "pejareis": "pejar",
    "pejarem": "pejar",
    "pejaremos": "pejar",
    "pejares": "pejar",
    "pejaria": "pejar",
    "pejariam": "pejar",
    "pejarias": "pejar",
    "pejarmo": "pejar",
    "pejarmos": "pejar",
    "pejará": "pejar",
    "pejarás": "pejar",
    "pejarão": "pejar",
    "pejaríamos": "pejar",
    "pejaríeis": "pejar",
    "pejas": "pejar",
    "pejasse": "pejar",
    "pejassem": "pejar",
    "pejasses": "pejar",
    "pejaste": "pejar",
    "pejastes": "pejar",
    "pejava": "pejar",
    "pejavam": "pejar",
    "pejavas": "pejar",
    "peje": "pejar",
    "pejei": "pejar",
    "pejeis": "pejar",
    "pejem": "pejar",
    "pejemo": "pejar",
    "pejemos": "pejar",
    "pejes": "pejar",
    "pejo": "pejar",
    "pejorativa": "pejorativo",
    "pejorativas": "pejorativo",
    "pejorativos": "pejorativo",
    "pejorativíssima": "pejorativo",
    "pejorativíssimas": "pejorativo",
    "pejorativíssimo": "pejorativo",
    "pejorativíssimos": "pejorativo",
    "pejos": "pejo",
    "pejou": "pejar",
    "pejá": "pejar",
    "pejámo": "pejar",
    "pejámos": "pejar",
    "pejáramo": "pejar",
    "pejáramos": "pejar",
    "pejárei": "pejar",
    "pejáreis": "pejar",
    "pejásseis": "pejar",
    "pejássemos": "pejar",
    "pejávamo": "pejar",
    "pejávamos": "pejar",
    "pejávei": "pejar",
    "pejáveis": "pejar",
    "pela": "pelar",
    "pelada": "pelar",
    "peladas": "pelar",
    "peladelas": "peladela",
    "peladinha": "pelado",
    "peladinhas": "pelado",
    "peladinho": "pelado",
    "peladinhos": "pelado",
    "peladita": "pelado",
    "peladitas": "pelado",
    "peladito": "pelado",
    "peladitos": "pelado",
    "pelado": "pelar",
    "peladora": "pelador",
    "peladoras": "pelador",
    "peladores": "pelador",
    "pelados": "pelar",
    "peladuras": "peladura",
    "peladíssima": "pelado",
    "peladíssimas": "pelado",
    "peladíssimo": "pelado",
    "peladíssimos": "pelado",
    "pelagens": "pelagem",
    "pelagiana": "pelagiano",
    "pelagianas": "pelagiano",
    "pelagianismos": "pelagianismo",
    "pelagianos": "pelagiano",
    "pelagoscopias": "pelagoscopia",
    "pelagoscópica": "pelagoscópico",
    "pelagoscópicas": "pelagoscópico",
    "pelagoscópicos": "pelagoscópico",
    "pelagoscópios": "pelagoscópio",
    "pelagras": "pelagra",
    "pelagrosa": "pelagroso",
    "pelagrosas": "pelagroso",
    "pelagrosos": "pelagroso",
    "pelai": "pelar",
    "pelais": "pelar",
    "pelam": "pelar",
    "pelames": "pelame",
    "pelamo": "pelar",
    "pelamos": "pelar",
    "pelancas": "pelanca",
    "pelando": "pelar",
    "pelanganas": "pelangana",
    "pelangas": "pelanga",
    "pelara": "pelar",
    "pelaram": "pelar",
    "pelaras": "pelar",
    "pelarde": "pelar",
    "pelardes": "pelar",
    "pelare": "pelar",
    "pelarei": "pelar",
    "pelareis": "pelar",
    "pelarem": "pelar",
    "pelaremos": "pelar",
    "pelares": "pelar",
    "pelargónios": "pelargónio",
    "pelaria": "pelar",
    "pelariam": "pelar",
    "pelarias": "pelaria",
    "pelarmo": "pelar",
    "pelarmos": "pelar",
    "pelará": "pelar",
    "pelarás": "pelar",
    "pelarão": "pelar",
    "pelaríamos": "pelar",
    "pelaríeis": "pelar",
    "pelas": "pelar",
    "pelasga": "pelasgo",
    "pelasgas": "pelasgo",
    "pelasgos": "pelasgo",
    "pelasse": "pelar",
    "pelassem": "pelar",
    "pelasses": "pelar",
    "pelaste": "pelar",
    "pelastes": "pelar",
    "pelava": "pelar",
    "pelavam": "pelar",
    "pelavas": "pelar",
    "pele": "pelar",
    "peleana": "peleano",
    "peleanas": "peleano",
    "peleanos": "peleano",
    "pelecípodes": "pelecípode",
    "pelega": "pelego",
    "pelegas": "pelego",
    "pelegos": "pelego",
    "pelei": "pelar",
    "peleira": "peleiro",
    "peleiras": "peleiro",
    "peleiros": "peleiro",
    "peleis": "pelar",
    "peleja": "pelejar",
    "pelejada": "pelejar",
    "pelejadas": "pelejar",
    "pelejado": "pelejar",
    "pelejadora": "pelejador",
    "pelejadoras": "pelejador",
    "pelejadores": "pelejador",
    "pelejados": "pelejar",
    "pelejai": "pelejar",
    "pelejais": "pelejar",
    "pelejam": "pelejar",
    "pelejamo": "pelejar",
    "pelejamos": "pelejar",
    "pelejando": "pelejar",
    "pelejantes": "pelejante",
    "pelejara": "pelejar",
    "pelejaram": "pelejar",
    "pelejaras": "pelejar",
    "pelejardes": "pelejar",
    "pelejarei": "pelejar",
    "pelejareis": "pelejar",
    "pelejarem": "pelejar",
    "pelejaremos": "pelejar",
    "pelejares": "pelejar",
    "pelejaria": "pelejar",
    "pelejariam": "pelejar",
    "pelejarias": "pelejar",
    "pelejarmo": "pelejar",
    "pelejarmos": "pelejar",
    "pelejará": "pelejar",
    "pelejarás": "pelejar",
    "pelejarão": "pelejar",
    "pelejaríamos": "pelejar",
    "pelejaríeis": "pelejar",
    "pelejas": "pelejar",
    "pelejasse": "pelejar",
    "pelejassem": "pelejar",
    "pelejasses": "pelejar",
    "pelejaste": "pelejar",
    "pelejastes": "pelejar",
    "pelejava": "pelejar",
    "pelejavam": "pelejar",
    "pelejavas": "pelejar",
    "peleje": "pelejar",
    "pelejei": "pelejar",
    "pelejeis": "pelejar",
    "pelejem": "pelejar",
    "pelejemo": "pelejar",
    "pelejemos": "pelejar",
    "pelejes": "pelejar",
    "pelejo": "pelejar",
    "pelejou": "pelejar",
    "pelejámo": "pelejar",
    "pelejámos": "pelejar",
    "pelejáramo": "pelejar",
    "pelejáramos": "pelejar",
    "pelejáreis": "pelejar",
    "pelejásseis": "pelejar",
    "pelejássemos": "pelejar",
    "pelejávamo": "pelejar",
    "pelejávamos": "pelejar",
    "pelejáveis": "pelejar",
    "pelem": "pelar",
    "pelemo": "pelar",
    "pelemos": "pelar",
    "peles": "pele",
    "pelhancarias": "pelhancaria",
    "pelhancas": "pelhanca",
    "pelharancarias": "pelharancaria",
    "pelharancas": "pelharanca",
    "pelicanos": "pelicano",
    "pelicas": "pelica",
    "pelicos": "pelico",
    "pelicula": "pelicular",
    "peliculada": "pelicular",
    "peliculadas": "pelicular",
    "peliculado": "pelicular",
    "peliculados": "pelicular",
    "peliculai": "pelicular",
    "peliculais": "pelicular",
    "peliculam": "pelicular",
    "peliculamo": "pelicular",
    "peliculamos": "pelicular",
    "peliculando": "pelicular",
    "peliculara": "pelicular",
    "pelicularam": "pelicular",
    "pelicularas": "pelicular",
    "pelicularde": "pelicular",
    "peliculardes": "pelicular",
    "peliculare": "pelicular",
    "pelicularei": "pelicular",
    "peliculareis": "pelicular",
    "pelicularem": "pelicular",
    "pelicularemos": "pelicular",
    "peliculares": "pelicular",
    "pelicularia": "pelicular",
    "peliculariam": "pelicular",
    "pelicularias": "pelicular",
    "pelicularmo": "pelicular",
    "pelicularmos": "pelicular",
    "peliculará": "pelicular",
    "pelicularás": "pelicular",
    "pelicularão": "pelicular",
    "pelicularíamos": "pelicular",
    "pelicularíeis": "pelicular",
    "peliculas": "pelicular",
    "peliculasse": "pelicular",
    "peliculassem": "pelicular",
    "peliculasses": "pelicular",
    "peliculaste": "pelicular",
    "peliculastes": "pelicular",
    "peliculava": "pelicular",
    "peliculavam": "pelicular",
    "peliculavas": "pelicular",
    "pelicule": "pelicular",
    "peliculei": "pelicular",
    "peliculeis": "pelicular",
    "peliculem": "pelicular",
    "peliculemo": "pelicular",
    "peliculemos": "pelicular",
    "pelicules": "pelicular",
    "peliculo": "pelicular",
    "peliculou": "pelicular",
    "peliculá": "pelicular",
    "peliculámo": "pelicular",
    "peliculámos": "pelicular",
    "peliculáramo": "pelicular",
    "peliculáramos": "pelicular",
    "peliculárei": "pelicular",
    "peliculáreis": "pelicular",
    "peliculásseis": "pelicular",
    "peliculássemos": "pelicular",
    "peliculávamo": "pelicular",
    "peliculávamos": "pelicular",
    "peliculávei": "pelicular",
    "peliculáveis": "pelicular",
    "pelida": "pelidar",
    "pelidada": "pelidar",
    "pelidadas": "pelidar",
    "pelidado": "pelidar",
    "pelidados": "pelidar",
    "pelidai": "pelidar",
    "pelidais": "pelidar",
    "pelidam": "pelidar",
    "pelidamo": "pelidar",
    "pelidamos": "pelidar",
    "pelidando": "pelidar",
    "pelidara": "pelidar",
    "pelidaram": "pelidar",
    "pelidaras": "pelidar",
    "pelidardes": "pelidar",
    "pelidarei": "pelidar",
    "pelidareis": "pelidar",
    "pelidarem": "pelidar",
    "pelidaremos": "pelidar",
    "pelidares": "pelidar",
    "pelidaria": "pelidar",
    "pelidariam": "pelidar",
    "pelidarias": "pelidar",
    "pelidarmo": "pelidar",
    "pelidarmos": "pelidar",
    "pelidará": "pelidar",
    "pelidarás": "pelidar",
    "pelidarão": "pelidar",
    "pelidaríamos": "pelidar",
    "pelidaríeis": "pelidar",
    "pelidas": "pelidar",
    "pelidasse": "pelidar",
    "pelidassem": "pelidar",
    "pelidasses": "pelidar",
    "pelidaste": "pelidar",
    "pelidastes": "pelidar",
    "pelidava": "pelidar",
    "pelidavam": "pelidar",
    "pelidavas": "pelidar",
    "pelide": "pelidar",
    "pelidei": "pelidar",
    "pelideis": "pelidar",
    "pelidem": "pelidar",
    "pelidemo": "pelidar",
    "pelidemos": "pelidar",
    "pelides": "pelidar",
    "pelido": "pelidar",
    "pelidou": "pelidar",
    "pelidámo": "pelidar",
    "pelidámos": "pelidar",
    "pelidáramo": "pelidar",
    "pelidáramos": "pelidar",
    "pelidáreis": "pelidar",
    "pelidásseis": "pelidar",
    "pelidássemos": "pelidar",
    "pelidávamo": "pelidar",
    "pelidávamos": "pelidar",
    "pelidáveis": "pelidar",
    "pelinho": "pêlo",
    "pelinhos": "pêlo",
    "pelintra": "pelintrar",
    "pelintrada": "pelintrar",
    "pelintradas": "pelintrar",
    "pelintrado": "pelintrar",
    "pelintrados": "pelintrar",
    "pelintragens": "pelintragem",
    "pelintrai": "pelintrar",
    "pelintrais": "pelintrar",
    "pelintram": "pelintrar",
    "pelintramo": "pelintrar",
    "pelintramos": "pelintrar",
    "pelintrando": "pelintrar",
    "pelintrara": "pelintrar",
    "pelintraram": "pelintrar",
    "pelintraras": "pelintrar",
    "pelintrarde": "pelintrar",
    "pelintrardes": "pelintrar",
    "pelintrare": "pelintrar",
    "pelintrarei": "pelintrar",
    "pelintrareis": "pelintrar",
    "pelintrarem": "pelintrar",
    "pelintraremos": "pelintrar",
    "pelintrares": "pelintrar",
    "pelintraria": "pelintrar",
    "pelintrariam": "pelintrar",
    "pelintrarias": "pelintraria",
    "pelintrarmo": "pelintrar",
    "pelintrarmos": "pelintrar",
    "pelintrará": "pelintrar",
    "pelintrarás": "pelintrar",
    "pelintrarão": "pelintrar",
    "pelintraríamos": "pelintrar",
    "pelintraríeis": "pelintrar",
    "pelintras": "pelintrar",
    "pelintrasse": "pelintrar",
    "pelintrassem": "pelintrar",
    "pelintrasses": "pelintrar",
    "pelintraste": "pelintrar",
    "pelintrastes": "pelintrar",
    "pelintrava": "pelintrar",
    "pelintravam": "pelintrar",
    "pelintravas": "pelintrar",
    "pelintrazinha": "pelintra",
    "pelintrazinhas": "pelintra",
    "pelintrazinho": "pelintra",
    "pelintrazinhos": "pelintra",
    "pelintrazita": "pelintra",
    "pelintrazitas": "pelintra",
    "pelintrazito": "pelintra",
    "pelintrazitos": "pelintra",
    "pelintre": "pelintrar",
    "pelintrei": "pelintrar",
    "pelintreis": "pelintrar",
    "pelintrem": "pelintrar",
    "pelintremo": "pelintrar",
    "pelintremos": "pelintrar",
    "pelintres": "pelintrar",
    "pelintrices": "pelintrice",
    "pelintrinha": "pelintra",
    "pelintrinhas": "pelintra",
    "pelintrismos": "pelintrismo",
    "pelintrita": "pelintra",
    "pelintritas": "pelintra",
    "pelintro": "pelintrar",
    "pelintrona": "pelintra",
    "pelintronas": "pelintra",
    "pelintrou": "pelintrar",
    "pelintrá": "pelintrar",
    "pelintrámo": "pelintrar",
    "pelintrámos": "pelintrar",
    "pelintráramo": "pelintrar",
    "pelintráramos": "pelintrar",
    "pelintrárei": "pelintrar",
    "pelintráreis": "pelintrar",
    "pelintrásseis": "pelintrar",
    "pelintrássemos": "pelintrar",
    "pelintrávamo": "pelintrar",
    "pelintrávamos": "pelintrar",
    "pelintrávei": "pelintrar",
    "pelintráveis": "pelintrar",
    "pelintrão": "pelintra",
    "pelintrões": "pelintra",
    "peliqueira": "peliqueiro",
    "peliqueiras": "peliqueiro",
    "peliqueiros": "peliqueiro",
    "pelito": "pêlo",
    "pelitos": "pêlo",
    "peliças": "peliça",
    "pelmatozoários": "pelmatozoário",
    "pelo": "pelar",
    "peloiradas": "peloirada",
    "peloirinhos": "peloirinho",
    "peloiros": "peloiro",
    "pelosa": "peloso",
    "pelosas": "peloso",
    "pelosos": "peloso",
    "pelotadas": "pelotada",
    "pelotas": "pelota",
    "pelotenses": "pelotense",
    "pelotes": "pelote",
    "peloticas": "pelotica",
    "pelotiqueira": "pelotiqueiro",
    "pelotiqueiras": "pelotiqueiro",
    "pelotiqueiros": "pelotiqueiro",
    "pelotiquices": "pelotiquice",
    "pelotões": "pelotão",
    "pelou": "pelar",
    "pelouradas": "pelourada",
    "pelourinhos": "pelourinho",
    "pelouros": "pelouro",
    "peltada": "peltado",
    "peltadas": "peltado",
    "peltados": "peltado",
    "peltas": "pelta",
    "peltastas": "peltasta",
    "peltiformes": "peltiforme",
    "peltocefálica": "peltocefálico",
    "peltocefálicas": "peltocefálico",
    "peltocefálicos": "peltocefálico",
    "peltocéfala": "peltocéfalo",
    "peltocéfalas": "peltocéfalo",
    "peltocéfalos": "peltocéfalo",
    "peluches": "peluche",
    "peluda": "peludo",
    "peludas": "peludo",
    "peludazinha": "peludo",
    "peludazinhas": "peludo",
    "peludazita": "peludo",
    "peludazitas": "peludo",
    "peludinha": "peludo",
    "peludinhas": "peludo",
    "peludinho": "peludo",
    "peludinhos": "peludo",
    "peludita": "peludo",
    "peluditas": "peludo",
    "peludito": "peludo",
    "peluditos": "peludo",
    "peludos": "peludo",
    "peludozinho": "peludo",
    "peludozinhos": "peludo",
    "peludozito": "peludo",
    "peludozitos": "peludo",
    "peludíssima": "peludo",
    "peludíssimas": "peludo",
    "peludíssimo": "peludo",
    "peludíssimos": "peludo",
    "pelugens": "pelugem",
    "peluginosa": "peluginoso",
    "peluginosas": "peluginoso",
    "peluginosos": "peluginoso",
    "pelves": "pelve",
    "pelviformes": "pelviforme",
    "pelvimétrica": "pelvimétrico",
    "pelvimétricas": "pelvimétrico",
    "pelvimétricos": "pelvimétrico",
    "pelvitomias": "pelvitomia",
    "pelvitómica": "pelvitómico",
    "pelvitómicas": "pelvitómico",
    "pelvitómicos": "pelvitómico",
    "pelvímetros": "pelvímetro",
    "pelá": "pelar",
    "pelágica": "pelágico",
    "pelágicas": "pelágico",
    "pelágicos": "pelágico",
    "pelámo": "pelar",
    "pelámos": "pelar",
    "peláramo": "pelar",
    "peláramos": "pelar",
    "pelárei": "pelar",
    "peláreis": "pelar",
    "pelásseis": "pelar",
    "pelássemos": "pelar",
    "pelávamo": "pelar",
    "pelávamos": "pelar",
    "pelávei": "pelar",
    "peláveis": "pelar",
    "peléns": "pelém",
    "películas": "película",
    "pelífera": "pelífero",
    "pelíferas": "pelífero",
    "pelíferos": "pelífero",
    "pelónias": "pelónia",
    "pelões": "pelão",
    "pelúcias": "pelúcia",
    "pena": "peno",
    "penacheira": "penacheiro",
    "penacheiras": "penacheiro",
    "penacheiros": "penacheiro",
    "penachos": "penacho",
    "penada": "penar",
    "penadas": "penar",
    "penadeiras": "penadeira",
    "penado": "penar",
    "penados": "penar",
    "penafidelenses": "penafidelense",
    "penagistas": "penagista",
    "penaguiotas": "penaguiota",
    "penai": "penar",
    "penais": "penar",
    "penalidades": "penalidade",
    "penalistas": "penalista",
    "penaliza": "penalizar",
    "penalizada": "penalizar",
    "penalizadas": "penalizar",
    "penalizado": "penalizar",
    "penalizadora": "penalizador",
    "penalizadoras": "penalizador",
    "penalizadores": "penalizador",
    "penalizados": "penalizar",
    "penalizadíssima": "penalizado",
    "penalizadíssimas": "penalizado",
    "penalizadíssimo": "penalizado",
    "penalizadíssimos": "penalizado",
    "penalizai": "penalizar",
    "penalizais": "penalizar",
    "penalizam": "penalizar",
    "penalizamo": "penalizar",
    "penalizamos": "penalizar",
    "penalizando": "penalizar",
    "penalizantes": "penalizante",
    "penalizara": "penalizar",
    "penalizaram": "penalizar",
    "penalizaras": "penalizar",
    "penalizarde": "penalizar",
    "penalizardes": "penalizar",
    "penalizare": "penalizar",
    "penalizarei": "penalizar",
    "penalizareis": "penalizar",
    "penalizarem": "penalizar",
    "penalizaremos": "penalizar",
    "penalizares": "penalizar",
    "penalizaria": "penalizar",
    "penalizariam": "penalizar",
    "penalizarias": "penalizar",
    "penalizarmo": "penalizar",
    "penalizarmos": "penalizar",
    "penalizará": "penalizar",
    "penalizarás": "penalizar",
    "penalizarão": "penalizar",
    "penalizaríamos": "penalizar",
    "penalizaríeis": "penalizar",
    "penalizas": "penalizar",
    "penalizasse": "penalizar",
    "penalizassem": "penalizar",
    "penalizasses": "penalizar",
    "penalizaste": "penalizar",
    "penalizastes": "penalizar",
    "penalizava": "penalizar",
    "penalizavam": "penalizar",
    "penalizavas": "penalizar",
    "penalizações": "penalização",
    "penalize": "penalizar",
    "penalizei": "penalizar",
    "penalizeis": "penalizar",
    "penalizem": "penalizar",
    "penalizemo": "penalizar",
    "penalizemos": "penalizar",
    "penalizes": "penalizar",
    "penalizo": "penalizar",
    "penalizou": "penalizar",
    "penalizá": "penalizar",
    "penalizámo": "penalizar",
    "penalizámos": "penalizar",
    "penalizáramo": "penalizar",
    "penalizáramos": "penalizar",
    "penalizárei": "penalizar",
    "penalizáreis": "penalizar",
    "penalizásseis": "penalizar",
    "penalizássemos": "penalizar",
    "penalizávamo": "penalizar",
    "penalizávamos": "penalizar",
    "penalizávei": "penalizar",
    "penalizáveis": "penalizável",
    "penaltis": "penalti",
    "penam": "penar",
    "penamacorenses": "penamacorense",
    "penamares": "penamar",
    "penamo": "penar",
    "penamos": "penar",
    "penando": "penar",
    "penantes": "penante",
    "penara": "penar",
    "penaram": "penar",
    "penaras": "penar",
    "penarde": "penar",
    "penardes": "penar",
    "penare": "penar",
    "penarei": "penar",
    "penareis": "penar",
    "penarem": "penar",
    "penaremos": "penar",
    "penares": "penar",
    "penaria": "penar",
    "penariam": "penar",
    "penarias": "penar",
    "penarmo": "penar",
    "penarmos": "penar",
    "penará": "penar",
    "penarás": "penar",
    "penarão": "penar",
    "penaríamos": "penar",
    "penaríeis": "penar",
    "penas": "peno",
    "penasse": "penar",
    "penassem": "penar",
    "penasses": "penar",
    "penaste": "penar",
    "penastes": "penar",
    "penatacheira": "penatacheiro",
    "penatacheiras": "penatacheiro",
    "penatacheiros": "penatacheiro",
    "penatifendida": "penatifendido",
    "penatifendidas": "penatifendido",
    "penatifendidos": "penatifendido",
    "penatilobada": "penatilobado",
    "penatilobadas": "penatilobado",
    "penatilobados": "penatilobado",
    "penatipartida": "penatipartido",
    "penatipartidas": "penatipartido",
    "penatipartidos": "penatipartido",
    "penatissecta": "penatissecto",
    "penatissectas": "penatissecto",
    "penatissectos": "penatissecto",
    "penava": "penar",
    "penavam": "penar",
    "penavas": "penar",
    "penações": "penação",
    "pencadas": "pencada",
    "pencas": "penca",
    "pence": "péni",
    "pencuda": "pencudo",
    "pencudas": "pencudo",
    "pencudazinha": "pencudo",
    "pencudazinhas": "pencudo",
    "pencudazita": "pencudo",
    "pencudazitas": "pencudo",
    "pencudinha": "pencudo",
    "pencudinhas": "pencudo",
    "pencudinho": "pencudo",
    "pencudinhos": "pencudo",
    "pencudita": "pencudo",
    "pencuditas": "pencudo",
    "pencudito": "pencudo",
    "pencuditos": "pencudo",
    "pencudos": "pencudo",
    "pencudozinho": "pencudo",
    "pencudozinhos": "pencudo",
    "pencudozito": "pencudo",
    "pencudozitos": "pencudo",
    "pencudíssima": "pencudo",
    "pencudíssimas": "pencudo",
    "pencudíssimo": "pencudo",
    "pencudíssimos": "pencudo",
    "penda": "pender",
    "pendais": "pender",
    "pendam": "pender",
    "pendamo": "pender",
    "pendamos": "pender",
    "pendas": "pender",
    "pende": "pender",
    "pendei": "pender",
    "pendeis": "pender",
    "pendem": "pender",
    "pendemo": "pender",
    "pendemos": "pender",
    "pendencia": "pendenciar",
    "pendenciada": "pendenciar",
    "pendenciadas": "pendenciar",
    "pendenciado": "pendenciar",
    "pendenciadora": "pendenciador",
    "pendenciadoras": "pendenciador",
    "pendenciadores": "pendenciador",
    "pendenciados": "pendenciar",
    "pendenciai": "pendenciar",
    "pendenciais": "pendenciar",
    "pendenciam": "pendenciar",
    "pendenciamo": "pendenciar",
    "pendenciamos": "pendenciar",
    "pendenciando": "pendenciar",
    "pendenciara": "pendenciar",
    "pendenciaram": "pendenciar",
    "pendenciaras": "pendenciar",
    "pendenciardes": "pendenciar",
    "pendenciarei": "pendenciar",
    "pendenciareis": "pendenciar",
    "pendenciarem": "pendenciar",
    "pendenciaremos": "pendenciar",
    "pendenciares": "pendenciar",
    "pendenciaria": "pendenciar",
    "pendenciariam": "pendenciar",
    "pendenciarias": "pendenciar",
    "pendenciarmo": "pendenciar",
    "pendenciarmos": "pendenciar",
    "pendenciará": "pendenciar",
    "pendenciarás": "pendenciar",
    "pendenciarão": "pendenciar",
    "pendenciaríamos": "pendenciar",
    "pendenciaríeis": "pendenciar",
    "pendencias": "pendenciar",
    "pendenciasse": "pendenciar",
    "pendenciassem": "pendenciar",
    "pendenciasses": "pendenciar",
    "pendenciaste": "pendenciar",
    "pendenciastes": "pendenciar",
    "pendenciava": "pendenciar",
    "pendenciavam": "pendenciar",
    "pendenciavas": "pendenciar",
    "pendencie": "pendenciar",
    "pendenciei": "pendenciar",
    "pendencieis": "pendenciar",
    "pendenciem": "pendenciar",
    "pendenciemo": "pendenciar",
    "pendenciemos": "pendenciar",
    "pendencies": "pendenciar",
    "pendencio": "pendenciar",
    "pendenciou": "pendenciar",
    "pendenciámo": "pendenciar",
    "pendenciámos": "pendenciar",
    "pendenciáramo": "pendenciar",
    "pendenciáramos": "pendenciar",
    "pendenciáreis": "pendenciar",
    "pendenciásseis": "pendenciar",
    "pendenciássemos": "pendenciar",
    "pendenciávamo": "pendenciar",
    "pendenciávamos": "pendenciar",
    "pendenciáveis": "pendenciar",
    "pendendo": "pender",
    "pendentes": "pendente",
    "pendera": "pender",
    "penderam": "pender",
    "penderas": "pender",
    "penderde": "pender",
    "penderdes": "pender",
    "pendere": "pender",
    "penderei": "pender",
    "pendereis": "pender",
    "penderem": "pender",
    "penderemos": "pender",
    "penderes": "pender",
    "penderia": "pender",
    "penderiam": "pender",
    "penderias": "pender",
    "pendericalhos": "pendericalho",
    "pendermo": "pender",
    "pendermos": "pender",
    "penderá": "pender",
    "penderás": "pender",
    "penderão": "pender",
    "penderíamos": "pender",
    "penderíeis": "pender",
    "pendes": "pender",
    "pendesse": "pender",
    "pendessem": "pender",
    "pendesses": "pender",
    "pendeste": "pender",
    "pendestes": "pender",
    "pendeu": "pender",
    "pendi": "pender",
    "pendia": "pender",
    "pendiam": "pender",
    "pendias": "pender",
    "pendida": "pendido",
    "pendidas": "pendido",
    "pendido": "pender",
    "pendidos": "pendido",
    "pendo": "pender",
    "pendoa": "pendoar",
    "pendoada": "pendoar",
    "pendoadas": "pendoar",
    "pendoado": "pendoar",
    "pendoados": "pendoar",
    "pendoai": "pendoar",
    "pendoais": "pendoar",
    "pendoam": "pendoar",
    "pendoamo": "pendoar",
    "pendoamos": "pendoar",
    "pendoando": "pendoar",
    "pendoara": "pendoar",
    "pendoaram": "pendoar",
    "pendoaras": "pendoar",
    "pendoardes": "pendoar",
    "pendoarei": "pendoar",
    "pendoareis": "pendoar",
    "pendoarem": "pendoar",
    "pendoaremos": "pendoar",
    "pendoares": "pendoar",
    "pendoaria": "pendoar",
    "pendoariam": "pendoar",
    "pendoarias": "pendoar",
    "pendoarmo": "pendoar",
    "pendoarmos": "pendoar",
    "pendoará": "pendoar",
    "pendoarás": "pendoar",
    "pendoarão": "pendoar",
    "pendoaríamos": "pendoar",
    "pendoaríeis": "pendoar",
    "pendoas": "pendoar",
    "pendoasse": "pendoar",
    "pendoassem": "pendoar",
    "pendoasses": "pendoar",
    "pendoaste": "pendoar",
    "pendoastes": "pendoar",
    "pendoava": "pendoar",
    "pendoavam": "pendoar",
    "pendoavas": "pendoar",
    "pendoe": "pendoar",
    "pendoei": "pendoar",
    "pendoeis": "pendoar",
    "pendoem": "pendoar",
    "pendoemo": "pendoar",
    "pendoemos": "pendoar",
    "pendoes": "pendoar",
    "pendoo": "pendoar",
    "pendoou": "pendoar",
    "pendoradas": "pendorada",
    "pendores": "pendor",
    "pendoámo": "pendoar",
    "pendoámos": "pendoar",
    "pendoáramo": "pendoar",
    "pendoáramos": "pendoar",
    "pendoáreis": "pendoar",
    "pendoásseis": "pendoar",
    "pendoássemos": "pendoar",
    "pendoávamo": "pendoar",
    "pendoávamos": "pendoar",
    "pendoáveis": "pendoar",
    "pendres": "pendre",
    "pendros": "pendro",
    "pendula": "pendular",
    "pendulada": "pendular",
    "penduladas": "pendular",
    "pendulado": "pendular",
    "pendulados": "pendular",
    "pendulai": "pendular",
    "pendulais": "pendular",
    "pendulam": "pendular",
    "pendulamo": "pendular",
    "pendulamos": "pendular",
    "pendulando": "pendular",
    "pendulara": "pendular",
    "pendularam": "pendular",
    "pendularas": "pendular",
    "pendulardes": "pendular",
    "pendularei": "pendular",
    "pendulareis": "pendular",
    "pendularem": "pendular",
    "pendularemos": "pendular",
    "pendulares": "pendular",
    "pendularia": "pendular",
    "pendulariam": "pendular",
    "pendularias": "pendular",
    "pendularmo": "pendular",
    "pendularmos": "pendular",
    "pendulará": "pendular",
    "pendularás": "pendular",
    "pendularão": "pendular",
    "pendularíamos": "pendular",
    "pendularíeis": "pendular",
    "pendulas": "pendular",
    "pendulasse": "pendular",
    "pendulassem": "pendular",
    "pendulasses": "pendular",
    "pendulaste": "pendular",
    "pendulastes": "pendular",
    "pendulava": "pendular",
    "pendulavam": "pendular",
    "pendulavas": "pendular",
    "pendule": "pendular",
    "pendulei": "pendular",
    "penduleis": "pendular",
    "pendulem": "pendular",
    "pendulemo": "pendular",
    "pendulemos": "pendular",
    "pendules": "pendular",
    "penduliflora": "pendulifloro",
    "pendulifloras": "pendulifloro",
    "pendulifloros": "pendulifloro",
    "pendulifoliada": "pendulifoliado",
    "pendulifoliadas": "pendulifoliado",
    "pendulifoliados": "pendulifoliado",
    "pendulo": "pendular",
    "pendulou": "pendular",
    "pendulámo": "pendular",
    "pendulámos": "pendular",
    "penduláramo": "pendular",
    "penduláramos": "pendular",
    "penduláreis": "pendular",
    "pendulásseis": "pendular",
    "pendulássemos": "pendular",
    "pendulávamo": "pendular",
    "pendulávamos": "pendular",
    "penduláveis": "pendular",
    "pendura": "pendurar",
    "pendurada": "pendurar",
    "penduradas": "pendurar",
    "pendurado": "pendurar",
    "pendurados": "pendurar",
    "pendurai": "pendurar",
    "pendurais": "pendurar",
    "penduram": "pendurar",
    "penduramo": "pendurar",
    "penduramos": "pendurar",
    "pendurando": "pendurar",
    "pendurara": "pendurar",
    "penduraram": "pendurar",
    "penduraras": "pendurar",
    "pendurarde": "pendurar",
    "pendurardes": "pendurar",
    "pendurare": "pendurar",
    "pendurarei": "pendurar",
    "pendurareis": "pendurar",
    "pendurarem": "pendurar",
    "penduraremos": "pendurar",
    "pendurares": "pendurar",
    "penduraria": "pendurar",
    "pendurariam": "pendurar",
    "pendurarias": "pendurar",
    "pendurarmo": "pendurar",
    "pendurarmos": "pendurar",
    "pendurará": "pendurar",
    "pendurarás": "pendurar",
    "pendurarão": "pendurar",
    "penduraríamos": "pendurar",
    "penduraríeis": "pendurar",
    "penduras": "pendurar",
    "pendurasse": "pendurar",
    "pendurassem": "pendurar",
    "pendurasses": "pendurar",
    "penduraste": "pendurar",
    "pendurastes": "pendurar",
    "pendurava": "pendurar",
    "penduravam": "pendurar",
    "penduravas": "pendurar",
    "pendure": "pendurar",
    "pendurei": "pendurar",
    "pendureis": "pendurar",
    "pendurem": "pendurar",
    "penduremo": "pendurar",
    "penduremos": "pendurar",
    "pendures": "pendurar",
    "penduricalhos": "penduricalho",
    "penduro": "pendurar",
    "pendurou": "pendurar",
    "pendurá": "pendurar",
    "pendurámo": "pendurar",
    "pendurámos": "pendurar",
    "penduráramo": "pendurar",
    "penduráramos": "pendurar",
    "pendurárei": "pendurar",
    "penduráreis": "pendurar",
    "pendurásseis": "pendurar",
    "pendurássemos": "pendurar",
    "pendurávamo": "pendurar",
    "pendurávamos": "pendurar",
    "pendurávei": "pendurar",
    "penduráveis": "pendurável",
    "pendê": "pender",
    "pendências": "pendência",
    "pendêramo": "pender",
    "pendêramos": "pender",
    "pendêrei": "pender",
    "pendêreis": "pender",
    "pendêsseis": "pender",
    "pendêssemos": "pender",
    "pendíamo": "pender",
    "pendíamos": "pender",
    "pendíei": "pender",
    "pendíeis": "pender",
    "pendões": "pendão",
    "pene": "penar",
    "penedias": "penedia",
    "penedos": "penedo",
    "penei": "penar",
    "peneira": "peneirar",
    "peneirada": "peneirar",
    "peneiradas": "peneirar",
    "peneirado": "peneirar",
    "peneiradora": "peneirador",
    "peneiradoras": "peneirador",
    "peneiradores": "peneirador",
    "peneirados": "peneirar",
    "peneirai": "peneirar",
    "peneirais": "peneirar",
    "peneiram": "peneirar",
    "peneiramo": "peneirar",
    "peneiramos": "peneirar",
    "peneirando": "peneirar",
    "peneirara": "peneirar",
    "peneiraram": "peneirar",
    "peneiraras": "peneirar",
    "peneirarde": "peneirar",
    "peneirardes": "peneirar",
    "peneirare": "peneirar",
    "peneirarei": "peneirar",
    "peneirareis": "peneirar",
    "peneirarem": "peneirar",
    "peneiraremos": "peneirar",
    "peneirares": "peneirar",
    "peneiraria": "peneirar",
    "peneirariam": "peneirar",
    "peneirarias": "peneirar",
    "peneirarmo": "peneirar",
    "peneirarmos": "peneirar",
    "peneirará": "peneirar",
    "peneirarás": "peneirar",
    "peneirarão": "peneirar",
    "peneiraríamos": "peneirar",
    "peneiraríeis": "peneirar",
    "peneiras": "peneirar",
    "peneirasse": "peneirar",
    "peneirassem": "peneirar",
    "peneirasses": "peneirar",
    "peneiraste": "peneirar",
    "peneirastes": "peneirar",
    "peneirava": "peneirar",
    "peneiravam": "peneirar",
    "peneiravas": "peneirar",
    "peneirações": "peneiração",
    "peneire": "peneirar",
    "peneirei": "peneirar",
    "peneireira": "peneireiro",
    "peneireiras": "peneireiro",
    "peneireiros": "peneireiro",
    "peneireis": "peneirar",
    "peneirem": "peneirar",
    "peneiremo": "peneirar",
    "peneiremos": "peneirar",
    "peneirenta": "peneirento",
    "peneirentas": "peneirento",
    "peneirentos": "peneirento",
    "peneires": "peneirar",
    "peneiro": "peneirar",
    "peneiros": "peneiro",
    "peneirou": "peneirar",
    "peneirá": "peneirar",
    "peneirámo": "peneirar",
    "peneirámos": "peneirar",
    "peneiráramo": "peneirar",
    "peneiráramos": "peneirar",
    "peneirárei": "peneirar",
    "peneiráreis": "peneirar",
    "peneirásseis": "peneirar",
    "peneirássemos": "peneirar",
    "peneirávamo": "peneirar",
    "peneirávamos": "peneirar",
    "peneirávei": "peneirar",
    "peneiráveis": "peneirar",
    "peneis": "penar",
    "peneja": "penejar",
    "penejada": "penejar",
    "penejadas": "penejar",
    "penejado": "penejar",
    "penejados": "penejar",
    "penejai": "penejar",
    "penejais": "penejar",
    "penejam": "penejar",
    "penejamo": "penejar",
    "penejamos": "penejar",
    "penejando": "penejar",
    "penejara": "penejar",
    "penejaram": "penejar",
    "penejaras": "penejar",
    "penejarde": "penejar",
    "penejardes": "penejar",
    "penejare": "penejar",
    "penejarei": "penejar",
    "penejareis": "penejar",
    "penejarem": "penejar",
    "penejaremos": "penejar",
    "penejares": "penejar",
    "penejaria": "penejar",
    "penejariam": "penejar",
    "penejarias": "penejar",
    "penejarmo": "penejar",
    "penejarmos": "penejar",
    "penejará": "penejar",
    "penejarás": "penejar",
    "penejarão": "penejar",
    "penejaríamos": "penejar",
    "penejaríeis": "penejar",
    "penejas": "penejar",
    "penejasse": "penejar",
    "penejassem": "penejar",
    "penejasses": "penejar",
    "penejaste": "penejar",
    "penejastes": "penejar",
    "penejava": "penejar",
    "penejavam": "penejar",
    "penejavas": "penejar",
    "peneje": "penejar",
    "penejei": "penejar",
    "penejeis": "penejar",
    "penejem": "penejar",
    "penejemo": "penejar",
    "penejemos": "penejar",
    "penejes": "penejar",
    "penejo": "penejar",
    "penejou": "penejar",
    "penejá": "penejar",
    "penejámo": "penejar",
    "penejámos": "penejar",
    "penejáramo": "penejar",
    "penejáramos": "penejar",
    "penejárei": "penejar",
    "penejáreis": "penejar",
    "penejásseis": "penejar",
    "penejássemos": "penejar",
    "penejávamo": "penejar",
    "penejávamos": "penejar",
    "penejávei": "penejar",
    "penejáveis": "penejar",
    "penelas": "penela",
    "penem": "penar",
    "penemo": "penar",
    "penemos": "penar",
    "peneplanícies": "peneplanície",
    "penes": "pene",
    "penetra": "penetrar",
    "penetrabilidades": "penetrabilidade",
    "penetrada": "penetrar",
    "penetradas": "penetrar",
    "penetrado": "penetrar",
    "penetradora": "penetrador",
    "penetradoras": "penetrador",
    "penetradores": "penetrador",
    "penetrados": "penetrar",
    "penetrai": "penetrar",
    "penetrais": "penetrar",
    "penetram": "penetrar",
    "penetramo": "penetrar",
    "penetramos": "penetrar",
    "penetramétrica": "penetramétrico",
    "penetramétricas": "penetramétrico",
    "penetramétricos": "penetramétrico",
    "penetrando": "penetrar",
    "penetrantes": "penetrante",
    "penetrara": "penetrar",
    "penetraram": "penetrar",
    "penetraras": "penetrar",
    "penetrarde": "penetrar",
    "penetrardes": "penetrar",
    "penetrare": "penetrar",
    "penetrarei": "penetrar",
    "penetrareis": "penetrar",
    "penetrarem": "penetrar",
    "penetraremos": "penetrar",
    "penetrares": "penetrar",
    "penetraria": "penetrar",
    "penetrariam": "penetrar",
    "penetrarias": "penetrar",
    "penetrarmo": "penetrar",
    "penetrarmos": "penetrar",
    "penetrará": "penetrar",
    "penetrarás": "penetrar",
    "penetrarão": "penetrar",
    "penetraríamos": "penetrar",
    "penetraríeis": "penetrar",
    "penetras": "penetrar",
    "penetrasse": "penetrar",
    "penetrassem": "penetrar",
    "penetrasses": "penetrar",
    "penetraste": "penetrar",
    "penetrastes": "penetrar",
    "penetrativa": "penetrativo",
    "penetrativas": "penetrativo",
    "penetrativos": "penetrativo",
    "penetrava": "penetrar",
    "penetravam": "penetrar",
    "penetravas": "penetrar",
    "penetrações": "penetração",
    "penetre": "penetrar",
    "penetrei": "penetrar",
    "penetreis": "penetrar",
    "penetrem": "penetrar",
    "penetremo": "penetrar",
    "penetremos": "penetrar",
    "penetres": "penetrar",
    "penetro": "penetrar",
    "penetrou": "penetrar",
    "penetrá": "penetrar",
    "penetrámo": "penetrar",
    "penetrámos": "penetrar",
    "penetráramo": "penetrar",
    "penetráramos": "penetrar",
    "penetrárei": "penetrar",
    "penetráreis": "penetrar",
    "penetrásseis": "penetrar",
    "penetrássemos": "penetrar",
    "penetrávamo": "penetrar",
    "penetrávamos": "penetrar",
    "penetrávei": "penetrar",
    "penetráveis": "penetrável",
    "penetrâmetros": "penetrâmetro",
    "peneídea": "peneídeo",
    "peneídeas": "peneídeo",
    "peneídeos": "peneídeo",
    "penhas": "penha",
    "penhascais": "penhascal",
    "penhascos": "penhasco",
    "penhascosa": "penhascoso",
    "penhascosas": "penhascoso",
    "penhascosos": "penhascoso",
    "penhasqueiras": "penhasqueira",
    "penhora": "penhorar",
    "penhorada": "penhorar",
    "penhoradas": "penhorar",
    "penhorado": "penhorar",
    "penhorados": "penhorar",
    "penhoradíssima": "penhorado",
    "penhoradíssimas": "penhorado",
    "penhoradíssimo": "penhorado",
    "penhoradíssimos": "penhorado",
    "penhorai": "penhorar",
    "penhorais": "penhorar",
    "penhoram": "penhorar",
    "penhoramo": "penhorar",
    "penhoramos": "penhorar",
    "penhorando": "penhorar",
    "penhorantes": "penhorante",
    "penhorara": "penhorar",
    "penhoraram": "penhorar",
    "penhoraras": "penhorar",
    "penhorarde": "penhorar",
    "penhorardes": "penhorar",
    "penhorare": "penhorar",
    "penhorarei": "penhorar",
    "penhorareis": "penhorar",
    "penhorarem": "penhorar",
    "penhoraremos": "penhorar",
    "penhorares": "penhorar",
    "penhoraria": "penhorar",
    "penhorariam": "penhorar",
    "penhorarias": "penhorar",
    "penhorarmo": "penhorar",
    "penhorarmos": "penhorar",
    "penhorará": "penhorar",
    "penhorarás": "penhorar",
    "penhorarão": "penhorar",
    "penhoraríamos": "penhorar",
    "penhoraríeis": "penhorar",
    "penhoras": "penhorar",
    "penhorasse": "penhorar",
    "penhorassem": "penhorar",
    "penhorasses": "penhorar",
    "penhoraste": "penhorar",
    "penhorastes": "penhorar",
    "penhorava": "penhorar",
    "penhoravam": "penhorar",
    "penhoravas": "penhorar",
    "penhore": "penhorar",
    "penhorei": "penhorar",
    "penhoreis": "penhorar",
    "penhorem": "penhorar",
    "penhoremo": "penhorar",
    "penhoremos": "penhorar",
    "penhores": "penhorar",
    "penhoristas": "penhorista",
    "penhoro": "penhorar",
    "penhorou": "penhorar",
    "penhorá": "penhorar",
    "penhorámo": "penhorar",
    "penhorámos": "penhorar",
    "penhoráramo": "penhorar",
    "penhoráramos": "penhorar",
    "penhorárei": "penhorar",
    "penhoráreis": "penhorar",
    "penhorásseis": "penhorar",
    "penhorássemos": "penhorar",
    "penhorávamo": "penhorar",
    "penhorávamos": "penhorar",
    "penhorávei": "penhorar",
    "penhoráveis": "penhorável",
    "penica": "penicar",
    "penicada": "penicar",
    "penicadas": "penicar",
    "penicado": "penicar",
    "penicados": "penicar",
    "penicai": "penicar",
    "penicais": "penicar",
    "penicam": "penicar",
    "penicamo": "penicar",
    "penicamos": "penicar",
    "penicando": "penicar",
    "penicara": "penicar",
    "penicaram": "penicar",
    "penicaras": "penicar",
    "penicarde": "penicar",
    "penicardes": "penicar",
    "penicare": "penicar",
    "penicarei": "penicar",
    "penicareis": "penicar",
    "penicarem": "penicar",
    "penicaremos": "penicar",
    "penicares": "penicar",
    "penicaria": "penicar",
    "penicariam": "penicar",
    "penicarias": "penicar",
    "penicarmo": "penicar",
    "penicarmos": "penicar",
    "penicará": "penicar",
    "penicarás": "penicar",
    "penicarão": "penicar",
    "penicaríamos": "penicar",
    "penicaríeis": "penicar",
    "penicas": "penicar",
    "penicasse": "penicar",
    "penicassem": "penicar",
    "penicasses": "penicar",
    "penicaste": "penicar",
    "penicastes": "penicar",
    "penicava": "penicar",
    "penicavam": "penicar",
    "penicavas": "penicar",
    "penicheira": "penicheiro",
    "penicheiras": "penicheiro",
    "penicheiros": "penicheiro",
    "penichenses": "penichense",
    "penicilinas": "penicilina",
    "penico": "penicar",
    "penicos": "penico",
    "penicou": "penicar",
    "penicozinho": "penico",
    "penicozinhos": "penico",
    "penicozito": "penico",
    "penicozitos": "penico",
    "penicá": "penicar",
    "penicámo": "penicar",
    "penicámos": "penicar",
    "penicáramo": "penicar",
    "penicáramos": "penicar",
    "penicárei": "penicar",
    "penicáreis": "penicar",
    "penicásseis": "penicar",
    "penicássemos": "penicar",
    "penicávamo": "penicar",
    "penicávamos": "penicar",
    "penicávei": "penicar",
    "penicáveis": "penicar",
    "penicílios": "penicílio",
    "peniformes": "peniforme",
    "peninas": "penina",
    "peninervada": "peninervado",
    "peninervadas": "peninervado",
    "peninervados": "peninervado",
    "peninha": "pena",
    "peninhas": "pena",
    "peninites": "peninite",
    "peninsulares": "peninsular",
    "peninérvea": "peninérveo",
    "peninérveas": "peninérveo",
    "peninérveos": "peninérveo",
    "peniores": "perluí",
    "penipotentes": "penipotente",
    "penique": "penicar",
    "peniquei": "penicar",
    "peniqueiras": "peniqueira",
    "peniqueis": "penicar",
    "peniquem": "penicar",
    "peniquemo": "penicar",
    "peniquemos": "penicar",
    "peniques": "penicar",
    "peniquinho": "penico",
    "peniquinhos": "penico",
    "peniquito": "penico",
    "peniquitos": "penico",
    "penisca": "peniscar",
    "peniscada": "peniscar",
    "peniscadas": "peniscar",
    "peniscado": "peniscar",
    "peniscados": "peniscar",
    "peniscai": "peniscar",
    "peniscais": "peniscar",
    "peniscam": "peniscar",
    "peniscamo": "peniscar",
    "peniscamos": "peniscar",
    "peniscando": "peniscar",
    "peniscara": "peniscar",
    "peniscaram": "peniscar",
    "peniscaras": "peniscar",
    "peniscarde": "peniscar",
    "peniscardes": "peniscar",
    "peniscare": "peniscar",
    "peniscarei": "peniscar",
    "peniscareis": "peniscar",
    "peniscarem": "peniscar",
    "peniscaremos": "peniscar",
    "peniscares": "peniscar",
    "peniscaria": "peniscar",
    "peniscariam": "peniscar",
    "peniscarias": "peniscar",
    "peniscarmo": "peniscar",
    "peniscarmos": "peniscar",
    "peniscará": "peniscar",
    "peniscarás": "peniscar",
    "peniscarão": "peniscar",
    "peniscaríamos": "peniscar",
    "peniscaríeis": "peniscar",
    "peniscas": "peniscar",
    "peniscasse": "peniscar",
    "peniscassem": "peniscar",
    "peniscasses": "peniscar",
    "peniscaste": "peniscar",
    "peniscastes": "peniscar",
    "peniscava": "peniscar",
    "peniscavam": "peniscar",
    "peniscavas": "peniscar",
    "penisco": "peniscar",
    "peniscos": "penisco",
    "peniscou": "peniscar",
    "peniscá": "peniscar",
    "peniscámo": "peniscar",
    "peniscámos": "peniscar",
    "peniscáramo": "peniscar",
    "peniscáramos": "peniscar",
    "peniscárei": "peniscar",
    "peniscáreis": "peniscar",
    "peniscásseis": "peniscar",
    "peniscássemos": "peniscar",
    "peniscávamo": "peniscar",
    "peniscávamos": "peniscar",
    "peniscávei": "peniscar",
    "peniscáveis": "peniscar",
    "penisque": "peniscar",
    "penisquei": "peniscar",
    "penisqueira": "penisqueiro",
    "penisqueiras": "penisqueiro",
    "penisqueiros": "penisqueiro",
    "penisqueis": "peniscar",
    "penisquem": "peniscar",
    "penisquemo": "peniscar",
    "penisquemos": "peniscar",
    "penisques": "peniscar",
    "penita": "pena",
    "penitas": "pena",
    "penitencia": "penitenciar",
    "penitenciada": "penitenciar",
    "penitenciadas": "penitenciar",
    "penitenciado": "penitenciar",
    "penitenciados": "penitenciar",
    "penitenciai": "penitenciar",
    "penitenciais": "penitenciar",
    "penitenciam": "penitenciar",
    "penitenciamo": "penitenciar",
    "penitenciamos": "penitenciar",
    "penitenciando": "penitenciar",
    "penitenciara": "penitenciar",
    "penitenciaram": "penitenciar",
    "penitenciaras": "penitenciar",
    "penitenciarde": "penitenciar",
    "penitenciardes": "penitenciar",
    "penitenciare": "penitenciar",
    "penitenciarei": "penitenciar",
    "penitenciareis": "penitenciar",
    "penitenciarem": "penitenciar",
    "penitenciaremos": "penitenciar",
    "penitenciares": "penitenciar",
    "penitenciaria": "penitenciar",
    "penitenciariam": "penitenciar",
    "penitenciarias": "penitenciaria",
    "penitenciarmo": "penitenciar",
    "penitenciarmos": "penitenciar",
    "penitenciará": "penitenciar",
    "penitenciarás": "penitenciar",
    "penitenciarão": "penitenciar",
    "penitenciaríamos": "penitenciar",
    "penitenciaríeis": "penitenciar",
    "penitencias": "penitenciar",
    "penitenciasse": "penitenciar",
    "penitenciassem": "penitenciar",
    "penitenciasses": "penitenciar",
    "penitenciaste": "penitenciar",
    "penitenciastes": "penitenciar",
    "penitenciava": "penitenciar",
    "penitenciavam": "penitenciar",
    "penitenciavas": "penitenciar",
    "penitencie": "penitenciar",
    "penitenciei": "penitenciar",
    "penitencieis": "penitenciar",
    "penitenciem": "penitenciar",
    "penitenciemo": "penitenciar",
    "penitenciemos": "penitenciar",
    "penitencies": "penitenciar",
    "penitencio": "penitenciar",
    "penitenciou": "penitenciar",
    "penitenciá": "penitenciar",
    "penitenciámo": "penitenciar",
    "penitenciámos": "penitenciar",
    "penitenciáramo": "penitenciar",
    "penitenciáramos": "penitenciar",
    "penitenciárei": "penitenciar",
    "penitenciáreis": "penitenciar",
    "penitenciária": "penitenciário",
    "penitenciárias": "penitenciário",
    "penitenciários": "penitenciário",
    "penitenciásseis": "penitenciar",
    "penitenciássemos": "penitenciar",
    "penitenciávamo": "penitenciar",
    "penitenciávamos": "penitenciar",
    "penitenciávei": "penitenciar",
    "penitenciáveis": "penitenciar",
    "penitentes": "penitente",
    "penitências": "penitência",
    "peno": "penar",
    "penologias": "penologia",
    "penologistas": "penologista",
    "penos": "peno",
    "penosa": "penoso",
    "penosas": "penoso",
    "penosidades": "penosidade",
    "penosos": "penoso",
    "penou": "penar",
    "pensa": "pensar",
    "pensada": "pensar",
    "pensadas": "pensar",
    "pensado": "pensar",
    "pensadoira": "pensadoiro",
    "pensadoiras": "pensadoiro",
    "pensadoiros": "pensadoiro",
    "pensadora": "pensador",
    "pensadoras": "pensador",
    "pensadores": "pensador",
    "pensados": "pensar",
    "pensaduras": "pensadura",
    "pensadíssima": "pensado",
    "pensadíssimas": "pensado",
    "pensadíssimo": "pensado",
    "pensadíssimos": "pensado",
    "pensai": "pensar",
    "pensais": "pensar",
    "pensam": "pensar",
    "pensamentos": "pensamento",
    "pensamo": "pensar",
    "pensamos": "pensar",
    "pensando": "pensar",
    "pensantes": "pensante",
    "pensara": "pensar",
    "pensaram": "pensar",
    "pensaras": "pensar",
    "pensarde": "pensar",
    "pensardes": "pensar",
    "pensare": "pensar",
    "pensarei": "pensar",
    "pensareis": "pensar",
    "pensarem": "pensar",
    "pensaremos": "pensar",
    "pensares": "pensar",
    "pensaria": "pensar",
    "pensariam": "pensar",
    "pensarias": "pensar",
    "pensarmo": "pensar",
    "pensarmos": "pensar",
    "pensará": "pensar",
    "pensarás": "pensar",
    "pensarão": "pensar",
    "pensaríamos": "pensar",
    "pensaríeis": "pensar",
    "pensas": "pensar",
    "pensasse": "pensar",
    "pensassem": "pensar",
    "pensasses": "pensar",
    "pensaste": "pensar",
    "pensastes": "pensar",
    "pensativa": "pensativo",
    "pensativas": "pensativo",
    "pensativos": "pensativo",
    "pensava": "pensar",
    "pensavam": "pensar",
    "pensavas": "pensar",
    "pense": "pensar",
    "pensei": "pensar",
    "penseis": "pensar",
    "pensem": "pensar",
    "pensemo": "pensar",
    "pensemos": "pensar",
    "penses": "pensar",
    "pensiona": "pensionar",
    "pensionada": "pensionar",
    "pensionadas": "pensionar",
    "pensionado": "pensionar",
    "pensionados": "pensionar",
    "pensionai": "pensionar",
    "pensionais": "pensionar",
    "pensionam": "pensionar",
    "pensionamo": "pensionar",
    "pensionamos": "pensionar",
    "pensionando": "pensionar",
    "pensionara": "pensionar",
    "pensionaram": "pensionar",
    "pensionaras": "pensionar",
    "pensionarde": "pensionar",
    "pensionardes": "pensionar",
    "pensionare": "pensionar",
    "pensionarei": "pensionar",
    "pensionareis": "pensionar",
    "pensionarem": "pensionar",
    "pensionaremos": "pensionar",
    "pensionares": "pensionar",
    "pensionaria": "pensionar",
    "pensionariam": "pensionar",
    "pensionarias": "pensionar",
    "pensionarmo": "pensionar",
    "pensionarmos": "pensionar",
    "pensionará": "pensionar",
    "pensionarás": "pensionar",
    "pensionarão": "pensionar",
    "pensionaríamos": "pensionar",
    "pensionaríeis": "pensionar",
    "pensionas": "pensionar",
    "pensionasse": "pensionar",
    "pensionassem": "pensionar",
    "pensionasses": "pensionar",
    "pensionaste": "pensionar",
    "pensionastes": "pensionar",
    "pensionatos": "pensionato",
    "pensionava": "pensionar",
    "pensionavam": "pensionar",
    "pensionavas": "pensionar",
    "pensione": "pensionar",
    "pensionei": "pensionar",
    "pensioneira": "pensioneiro",
    "pensioneiras": "pensioneiro",
    "pensioneiros": "pensioneiro",
    "pensioneis": "pensionar",
    "pensionem": "pensionar",
    "pensionemo": "pensionar",
    "pensionemos": "pensionar",
    "pensiones": "pensionar",
    "pensionistas": "pensionista",
    "pensiono": "pensionar",
    "pensionou": "pensionar",
    "pensioná": "pensionar",
    "pensionámo": "pensionar",
    "pensionámos": "pensionar",
    "pensionáramo": "pensionar",
    "pensionáramos": "pensionar",
    "pensionárei": "pensionar",
    "pensionáreis": "pensionar",
    "pensionária": "pensionário",
    "pensionárias": "pensionário",
    "pensionários": "pensionário",
    "pensionásseis": "pensionar",
    "pensionássemos": "pensionar",
    "pensionávamo": "pensionar",
    "pensionávamos": "pensionar",
    "pensionávei": "pensionar",
    "pensionáveis": "pensionar",
    "penso": "pensar",
    "pensos": "penso",
    "pensou": "pensar",
    "pensá": "pensar",
    "pensámo": "pensar",
    "pensámos": "pensar",
    "pensáramo": "pensar",
    "pensáramos": "pensar",
    "pensárei": "pensar",
    "pensáreis": "pensar",
    "pensásseis": "pensar",
    "pensássemos": "pensar",
    "pensávamo": "pensar",
    "pensávamos": "pensar",
    "pensávei": "pensar",
    "pensáveis": "pensável",
    "pensões": "pensão",
    "pentacampeã": "pentacampeão",
    "pentacampeãos": "pentacampeão",
    "pentacampeãs": "pentacampeão",
    "pentacarpa": "pentacarpo",
    "pentacarpas": "pentacarpo",
    "pentacarpos": "pentacarpo",
    "pentacordos": "pentacordo",
    "pentacórdios": "pentacórdio",
    "pentadecagonais": "pentadecagonal",
    "pentadecágonos": "pentadecágono",
    "pentadelética": "pentadelético",
    "pentadeléticas": "pentadelético",
    "pentadeléticos": "pentadelético",
    "pentadáctila": "pentadáctilo",
    "pentadáctilas": "pentadáctilo",
    "pentadáctilos": "pentadáctilo",
    "pentaedros": "pentaedro",
    "pentagonais": "pentagonal",
    "pentagramas": "pentagrama",
    "pentamétrica": "pentamétrico",
    "pentamétricas": "pentamétrico",
    "pentamétricos": "pentamétrico",
    "pentandlites": "pentandlite",
    "pentandra": "pentandro",
    "pentandras": "pentandro",
    "pentandros": "pentandro",
    "pentanos": "pentano",
    "pentapétala": "pentapétalo",
    "pentapétalas": "pentapétalo",
    "pentapétalos": "pentapétalo",
    "pentarcas": "pentarca",
    "pentarquias": "pentarquia",
    "pentarremes": "pentarreme",
    "pentassilábica": "pentassilábico",
    "pentassilábicas": "pentassilábico",
    "pentassilábicos": "pentassilábico",
    "pentassépala": "pentassépalo",
    "pentassépalas": "pentassépalo",
    "pentassépalos": "pentassépalo",
    "pentassílaba": "pentassílabo",
    "pentassílabas": "pentassílabo",
    "pentassílabos": "pentassílabo",
    "pentateucos": "pentateuco",
    "pentatlistas": "pentatlista",
    "pentatlos": "pentatlo",
    "pentatomídeos": "pentatomídeo",
    "pentatómica": "pentatómico",
    "pentatómicas": "pentatómico",
    "pentatómicos": "pentatómico",
    "pentatómidas": "pentatómida",
    "pentavalentes": "pentavalente",
    "penteada": "pentear",
    "penteadas": "pentear",
    "penteadelas": "penteadela",
    "penteadinha": "penteado",
    "penteadinhas": "penteado",
    "penteadinho": "penteado",
    "penteadinhos": "penteado",
    "penteadita": "penteado",
    "penteaditas": "penteado",
    "penteadito": "penteado",
    "penteaditos": "penteado",
    "penteado": "pentear",
    "penteadora": "penteador",
    "penteadoras": "penteador",
    "penteadores": "penteador",
    "penteados": "pentear",
    "penteaduras": "penteadura",
    "penteadíssima": "penteado",
    "penteadíssimas": "penteado",
    "penteadíssimo": "penteado",
    "penteadíssimos": "penteado",
    "penteai": "pentear",
    "penteais": "pentear",
    "penteamo": "pentear",
    "penteamos": "pentear",
    "penteando": "pentear",
    "penteara": "pentear",
    "pentearam": "pentear",
    "pentearas": "pentear",
    "pentearde": "pentear",
    "penteardes": "pentear",
    "penteare": "pentear",
    "pentearei": "pentear",
    "penteareis": "pentear",
    "pentearem": "pentear",
    "pentearemos": "pentear",
    "penteares": "pentear",
    "pentearia": "pentear",
    "penteariam": "pentear",
    "pentearias": "pentearia",
    "pentearmo": "pentear",
    "pentearmos": "pentear",
    "penteará": "pentear",
    "pentearás": "pentear",
    "pentearão": "pentear",
    "pentearíamos": "pentear",
    "pentearíeis": "pentear",
    "penteasse": "pentear",
    "penteassem": "pentear",
    "penteasses": "pentear",
    "penteaste": "pentear",
    "penteastes": "pentear",
    "penteava": "pentear",
    "penteavam": "pentear",
    "penteavas": "pentear",
    "penteações": "penteação",
    "penteei": "pentear",
    "penteeiros": "penteeiro",
    "penteeis": "pentear",
    "penteemo": "pentear",
    "penteemos": "pentear",
    "penteia": "pentear",
    "penteiam": "pentear",
    "penteias": "pentear",
    "penteie": "pentear",
    "penteiem": "pentear",
    "penteies": "pentear",
    "penteio": "pentear",
    "penteiros": "penteiro",
    "pentemímeres": "pentemímere",
    "penteou": "pentear",
    "pentes": "pente",
    "penteá": "pentear",
    "penteámo": "pentear",
    "penteámos": "pentear",
    "penteáramo": "pentear",
    "penteáramos": "pentear",
    "penteárei": "pentear",
    "penteáreis": "pentear",
    "penteásseis": "pentear",
    "penteássemos": "pentear",
    "penteávamo": "pentear",
    "penteávamos": "pentear",
    "penteávei": "pentear",
    "penteáveis": "pentear",
    "pentlandites": "pentlandite",
    "pentoses": "pentose",
    "pentáculos": "pentáculo",
    "pentágonos": "pentágono",
    "pentápoles": "pentápole",
    "pentáptera": "pentáptero",
    "pentápteras": "pentáptero",
    "pentápteros": "pentáptero",
    "pentárquica": "pentárquico",
    "pentárquicas": "pentárquico",
    "pentárquicos": "pentárquico",
    "pentâmera": "pentâmero",
    "pentâmeras": "pentâmero",
    "pentâmeros": "pentâmero",
    "pentâmetros": "pentâmetro",
    "pentândrica": "pentândrico",
    "pentândricas": "pentândrico",
    "pentândricos": "pentândrico",
    "pentânica": "pentânico",
    "pentânicas": "pentânico",
    "pentânicos": "pentânico",
    "penuda": "penudo",
    "penudas": "penudo",
    "penudos": "penudo",
    "penudíssima": "penudo",
    "penudíssimas": "penudo",
    "penudíssimo": "penudo",
    "penudíssimos": "penudo",
    "penugens": "penugem",
    "penugenta": "penugento",
    "penugentas": "penugento",
    "penugentos": "penugento",
    "penugentíssima": "penugento",
    "penugentíssimas": "penugento",
    "penugentíssimo": "penugento",
    "penugentíssimos": "penugento",
    "penuja": "penujar",
    "penujada": "penujar",
    "penujadas": "penujar",
    "penujado": "penujar",
    "penujados": "penujar",
    "penujai": "penujar",
    "penujais": "penujar",
    "penujam": "penujar",
    "penujamo": "penujar",
    "penujamos": "penujar",
    "penujando": "penujar",
    "penujara": "penujar",
    "penujaram": "penujar",
    "penujaras": "penujar",
    "penujarde": "penujar",
    "penujardes": "penujar",
    "penujare": "penujar",
    "penujarei": "penujar",
    "penujareis": "penujar",
    "penujarem": "penujar",
    "penujaremos": "penujar",
    "penujares": "penujar",
    "penujaria": "penujar",
    "penujariam": "penujar",
    "penujarias": "penujar",
    "penujarmo": "penujar",
    "penujarmos": "penujar",
    "penujará": "penujar",
    "penujarás": "penujar",
    "penujarão": "penujar",
    "penujaríamos": "penujar",
    "penujaríeis": "penujar",
    "penujas": "penujar",
    "penujasse": "penujar",
    "penujassem": "penujar",
    "penujasses": "penujar",
    "penujaste": "penujar",
    "penujastes": "penujar",
    "penujava": "penujar",
    "penujavam": "penujar",
    "penujavas": "penujar",
    "penuje": "penujar",
    "penujei": "penujar",
    "penujeis": "penujar",
    "penujem": "penujar",
    "penujemo": "penujar",
    "penujemos": "penujar",
    "penujes": "penujar",
    "penujo": "penujar",
    "penujosa": "penujoso",
    "penujosas": "penujoso",
    "penujosos": "penujoso",
    "penujou": "penujar",
    "penujá": "penujar",
    "penujámo": "penujar",
    "penujámos": "penujar",
    "penujáramo": "penujar",
    "penujáramos": "penujar",
    "penujárei": "penujar",
    "penujáreis": "penujar",
    "penujásseis": "penujar",
    "penujássemos": "penujar",
    "penujávamo": "penujar",
    "penujávamos": "penujar",
    "penujávei": "penujar",
    "penujáveis": "penujar",
    "penumbra": "penumbrar",
    "penumbrada": "penumbrar",
    "penumbradas": "penumbrar",
    "penumbrado": "penumbrar",
    "penumbrados": "penumbrar",
    "penumbrai": "penumbrar",
    "penumbrais": "penumbrar",
    "penumbram": "penumbrar",
    "penumbramo": "penumbrar",
    "penumbramos": "penumbrar",
    "penumbrando": "penumbrar",
    "penumbrara": "penumbrar",
    "penumbraram": "penumbrar",
    "penumbraras": "penumbrar",
    "penumbrarde": "penumbrar",
    "penumbrardes": "penumbrar",
    "penumbrare": "penumbrar",
    "penumbrarei": "penumbrar",
    "penumbrareis": "penumbrar",
    "penumbrarem": "penumbrar",
    "penumbraremos": "penumbrar",
    "penumbrares": "penumbrar",
    "penumbraria": "penumbrar",
    "penumbrariam": "penumbrar",
    "penumbrarias": "penumbrar",
    "penumbrarmo": "penumbrar",
    "penumbrarmos": "penumbrar",
    "penumbrará": "penumbrar",
    "penumbrarás": "penumbrar",
    "penumbrarão": "penumbrar",
    "penumbraríamos": "penumbrar",
    "penumbraríeis": "penumbrar",
    "penumbras": "penumbrar",
    "penumbrasse": "penumbrar",
    "penumbrassem": "penumbrar",
    "penumbrasses": "penumbrar",
    "penumbraste": "penumbrar",
    "penumbrastes": "penumbrar",
    "penumbrava": "penumbrar",
    "penumbravam": "penumbrar",
    "penumbravas": "penumbrar",
    "penumbre": "penumbrar",
    "penumbrei": "penumbrar",
    "penumbreis": "penumbrar",
    "penumbrem": "penumbrar",
    "penumbremo": "penumbrar",
    "penumbremos": "penumbrar",
    "penumbres": "penumbrar",
    "penumbro": "penumbrar",
    "penumbrosa": "penumbroso",
    "penumbrosas": "penumbroso",
    "penumbrosos": "penumbroso",
    "penumbrou": "penumbrar",
    "penumbrá": "penumbrar",
    "penumbrámo": "penumbrar",
    "penumbrámos": "penumbrar",
    "penumbráramo": "penumbrar",
    "penumbráramos": "penumbrar",
    "penumbrárei": "penumbrar",
    "penumbráreis": "penumbrar",
    "penumbrásseis": "penumbrar",
    "penumbrássemos": "penumbrar",
    "penumbrávamo": "penumbrar",
    "penumbrávamos": "penumbrar",
    "penumbrávei": "penumbrar",
    "penumbráveis": "penumbrar",
    "penuriosa": "penurioso",
    "penuriosas": "penurioso",
    "penuriosos": "penurioso",
    "pená": "penar",
    "penácea": "penáceo",
    "penáceas": "penáceo",
    "penáceos": "penáceo",
    "penámo": "penar",
    "penámos": "penar",
    "penáramo": "penar",
    "penáramos": "penar",
    "penárei": "penar",
    "penáreis": "penar",
    "penásseis": "penar",
    "penássemos": "penar",
    "penávamo": "penar",
    "penávamos": "penar",
    "penávei": "penar",
    "penáveis": "penar",
    "penélopes": "penélope",
    "penífera": "penífero",
    "peníferas": "penífero",
    "peníferos": "penífero",
    "penígera": "penígero",
    "penígeras": "penígero",
    "penígeros": "penígero",
    "penínsulas": "península",
    "peníveis": "penível",
    "penóis": "penol",
    "penões": "penão",
    "penúltima": "penúltimo",
    "penúltimas": "penúltimo",
    "penúltimos": "penúltimo",
    "penúrias": "penúria",
    "peonagens": "peonagem",
    "peou": "pear",
    "peperites": "peperite",
    "peperitos": "peperito",
    "pepinais": "pepinal",
    "pepineiras": "pepineira",
    "pepineiros": "pepineiro",
    "pepinos": "pepino",
    "pepitas": "pepita",
    "peplos": "peplo",
    "pepsias": "pepsia",
    "pepsinas": "pepsina",
    "peptizações": "peptização",
    "peptonas": "peptona",
    "peptoniza": "peptonizar",
    "peptonizada": "peptonizar",
    "peptonizadas": "peptonizar",
    "peptonizado": "peptonizar",
    "peptonizados": "peptonizar",
    "peptonizai": "peptonizar",
    "peptonizais": "peptonizar",
    "peptonizam": "peptonizar",
    "peptonizamo": "peptonizar",
    "peptonizamos": "peptonizar",
    "peptonizando": "peptonizar",
    "peptonizara": "peptonizar",
    "peptonizaram": "peptonizar",
    "peptonizaras": "peptonizar",
    "peptonizarde": "peptonizar",
    "peptonizardes": "peptonizar",
    "peptonizare": "peptonizar",
    "peptonizarei": "peptonizar",
    "peptonizareis": "peptonizar",
    "peptonizarem": "peptonizar",
    "peptonizaremos": "peptonizar",
    "peptonizares": "peptonizar",
    "peptonizaria": "peptonizar",
    "peptonizariam": "peptonizar",
    "peptonizarias": "peptonizar",
    "peptonizarmo": "peptonizar",
    "peptonizarmos": "peptonizar",
    "peptonizará": "peptonizar",
    "peptonizarás": "peptonizar",
    "peptonizarão": "peptonizar",
    "peptonizaríamos": "peptonizar",
    "peptonizaríeis": "peptonizar",
    "peptonizas": "peptonizar",
    "peptonizasse": "peptonizar",
    "peptonizassem": "peptonizar",
    "peptonizasses": "peptonizar",
    "peptonizaste": "peptonizar",
    "peptonizastes": "peptonizar",
    "peptonizava": "peptonizar",
    "peptonizavam": "peptonizar",
    "peptonizavas": "peptonizar",
    "peptonizações": "peptonização",
    "peptonize": "peptonizar",
    "peptonizei": "peptonizar",
    "peptonizeis": "peptonizar",
    "peptonizem": "peptonizar",
    "peptonizemo": "peptonizar",
    "peptonizemos": "peptonizar",
    "peptonizes": "peptonizar",
    "peptonizo": "peptonizar",
    "peptonizou": "peptonizar",
    "peptonizá": "peptonizar",
    "peptonizámo": "peptonizar",
    "peptonizámos": "peptonizar",
    "peptonizáramo": "peptonizar",
    "peptonizáramos": "peptonizar",
    "peptonizárei": "peptonizar",
    "peptonizáreis": "peptonizar",
    "peptonizásseis": "peptonizar",
    "peptonizássemos": "peptonizar",
    "peptonizávamo": "peptonizar",
    "peptonizávamos": "peptonizar",
    "peptonizávei": "peptonizar",
    "peptonizáveis": "peptonizar",
    "pepónides": "pepónide",
    "pepónios": "pepónio",
    "peque": "pecar",
    "pequei": "pecar",
    "pequeis": "pecar",
    "pequem": "pecar",
    "pequemos": "pecar",
    "pequena": "pequeno",
    "pequenadas": "pequenada",
    "pequenames": "pequename",
    "pequenas": "pequeno",
    "pequenezas": "pequeneza",
    "pequenezes": "pequenez",
    "pequenina": "pequenino",
    "pequeninas": "pequenino",
    "pequeninha": "pequeno",
    "pequeninhas": "pequeno",
    "pequeninho": "pequeno",
    "pequeninhos": "pequeno",
    "pequenininha": "pequenino",
    "pequenininhas": "pequenino",
    "pequenininho": "pequenino",
    "pequenininhos": "pequenino",
    "pequeninita": "pequenino",
    "pequeninitas": "pequenino",
    "pequeninito": "pequenino",
    "pequeninitos": "pequenino",
    "pequeninos": "pequenino",
    "pequenita": "pequeno",
    "pequenitas": "pequeno",
    "pequenito": "pequeno",
    "pequenitos": "pequeno",
    "pequenitotes": "pequenitote",
    "pequenos": "pequeno",
    "pequenota": "pequenote",
    "pequenotas": "pequenote",
    "pequenotes": "pequenote",
    "pequeníssima": "pequeno",
    "pequeníssimas": "pequeno",
    "pequeníssimo": "pequeno",
    "pequeníssimos": "pequeno",
    "pequerrucha": "pequerrucho",
    "pequerruchadas": "pequerruchada",
    "pequerruchas": "pequerrucho",
    "pequerruchinha": "pequerrucho",
    "pequerruchinhas": "pequerrucho",
    "pequerruchinho": "pequerrucho",
    "pequerruchinhos": "pequerrucho",
    "pequerruchita": "pequerrucho",
    "pequerruchitas": "pequerrucho",
    "pequerruchito": "pequerrucho",
    "pequerruchitos": "pequerrucho",
    "pequerruchos": "pequerrucho",
    "pequerruchíssima": "pequerrucho",
    "pequerruchíssimas": "pequerrucho",
    "pequerruchíssimo": "pequerrucho",
    "pequerruchíssimos": "pequerrucho",
    "peques": "pecar",
    "pequices": "pequice",
    "pequinenses": "pequinense",
    "pequinesa": "pequinês",
    "pequinesas": "pequinês",
    "pequineses": "pequinês",
    "pequinhenta": "pequinhento",
    "pequinhentas": "pequinhento",
    "pequinhentos": "pequinhento",
    "peraboratos": "peraborato",
    "peradas": "perada",
    "perados": "perado",
    "perafitas": "perafita",
    "perafíctica": "perafíctico",
    "perafícticas": "perafíctico",
    "perafícticos": "perafíctico",
    "perais": "peral",
    "peraltada": "peraltado",
    "peraltadas": "peraltado",
    "peraltados": "peraltado",
    "peraltas": "peralta",
    "peralteada": "peraltear",
    "peralteadas": "peraltear",
    "peralteado": "peraltear",
    "peralteados": "peraltear",
    "peralteai": "peraltear",
    "peralteais": "peraltear",
    "peralteamo": "peraltear",
    "peralteamos": "peraltear",
    "peralteando": "peraltear",
    "peralteara": "peraltear",
    "peraltearam": "peraltear",
    "peraltearas": "peraltear",
    "peralteardes": "peraltear",
    "peraltearei": "peraltear",
    "peralteareis": "peraltear",
    "peraltearem": "peraltear",
    "peraltearemos": "peraltear",
    "peralteares": "peraltear",
    "peraltearia": "peraltear",
    "peralteariam": "peraltear",
    "peraltearias": "peraltear",
    "peraltearmo": "peraltear",
    "peraltearmos": "peraltear",
    "peralteará": "peraltear",
    "peraltearás": "peraltear",
    "peraltearão": "peraltear",
    "peraltearíamos": "peraltear",
    "peraltearíeis": "peraltear",
    "peralteasse": "peraltear",
    "peralteassem": "peraltear",
    "peralteasses": "peraltear",
    "peralteaste": "peraltear",
    "peralteastes": "peraltear",
    "peralteava": "peraltear",
    "peralteavam": "peraltear",
    "peralteavas": "peraltear",
    "peralteei": "peraltear",
    "peralteeis": "peraltear",
    "peralteemo": "peraltear",
    "peralteemos": "peraltear",
    "peralteia": "peraltear",
    "peralteiam": "peraltear",
    "peralteias": "peraltear",
    "peralteie": "peraltear",
    "peralteiem": "peraltear",
    "peralteies": "peraltear",
    "peralteio": "peraltear",
    "peralteou": "peraltear",
    "peralteámo": "peraltear",
    "peralteámos": "peraltear",
    "peralteáramo": "peraltear",
    "peralteáramos": "peraltear",
    "peralteáreis": "peraltear",
    "peralteásseis": "peraltear",
    "peralteássemos": "peraltear",
    "peralteávamo": "peraltear",
    "peralteávamos": "peraltear",
    "peralteáveis": "peraltear",
    "peraltices": "peraltice",
    "peraltismos": "peraltismo",
    "peralvilha": "peralvilho",
    "peralvilhada": "peralvilhar",
    "peralvilhadas": "peralvilhar",
    "peralvilhado": "peralvilhar",
    "peralvilhados": "peralvilhar",
    "peralvilhai": "peralvilhar",
    "peralvilhais": "peralvilhar",
    "peralvilham": "peralvilhar",
    "peralvilhamo": "peralvilhar",
    "peralvilhamos": "peralvilhar",
    "peralvilhando": "peralvilhar",
    "peralvilhara": "peralvilhar",
    "peralvilharam": "peralvilhar",
    "peralvilharas": "peralvilhar",
    "peralvilhardes": "peralvilhar",
    "peralvilharei": "peralvilhar",
    "peralvilhareis": "peralvilhar",
    "peralvilharem": "peralvilhar",
    "peralvilharemos": "peralvilhar",
    "peralvilhares": "peralvilhar",
    "peralvilharia": "peralvilhar",
    "peralvilhariam": "peralvilhar",
    "peralvilharias": "peralvilhar",
    "peralvilharmo": "peralvilhar",
    "peralvilharmos": "peralvilhar",
    "peralvilhará": "peralvilhar",
    "peralvilharás": "peralvilhar",
    "peralvilharão": "peralvilhar",
    "peralvilharíamos": "peralvilhar",
    "peralvilharíeis": "peralvilhar",
    "peralvilhas": "peralvilho",
    "peralvilhasse": "peralvilhar",
    "peralvilhassem": "peralvilhar",
    "peralvilhasses": "peralvilhar",
    "peralvilhaste": "peralvilhar",
    "peralvilhastes": "peralvilhar",
    "peralvilhava": "peralvilhar",
    "peralvilhavam": "peralvilhar",
    "peralvilhavas": "peralvilhar",
    "peralvilhe": "peralvilhar",
    "peralvilhei": "peralvilhar",
    "peralvilheis": "peralvilhar",
    "peralvilhem": "peralvilhar",
    "peralvilhemo": "peralvilhar",
    "peralvilhemos": "peralvilhar",
    "peralvilhes": "peralvilhar",
    "peralvilhices": "peralvilhice",
    "peralvilho": "peralvilhar",
    "peralvilhos": "peralvilho",
    "peralvilhou": "peralvilhar",
    "peralvilhámo": "peralvilhar",
    "peralvilhámos": "peralvilhar",
    "peralvilháramo": "peralvilhar",
    "peralvilháramos": "peralvilhar",
    "peralvilháreis": "peralvilhar",
    "peralvilhásseis": "peralvilhar",
    "peralvilhássemos": "peralvilhar",
    "peralvilhávamo": "peralvilhar",
    "peralvilhávamos": "peralvilhar",
    "peralvilháveis": "peralvilhar",
    "perambula": "perambular",
    "perambulada": "perambular",
    "perambuladas": "perambular",
    "perambulado": "perambular",
    "perambulados": "perambular",
    "perambulai": "perambular",
    "perambulais": "perambular",
    "perambulam": "perambular",
    "perambulamo": "perambular",
    "perambulamos": "perambular",
    "perambulando": "perambular",
    "perambulara": "perambular",
    "perambularam": "perambular",
    "perambularas": "perambular",
    "perambulardes": "perambular",
    "perambularei": "perambular",
    "perambulareis": "perambular",
    "perambularem": "perambular",
    "perambularemos": "perambular",
    "perambulares": "perambular",
    "perambularia": "perambular",
    "perambulariam": "perambular",
    "perambularias": "perambular",
    "perambularmo": "perambular",
    "perambularmos": "perambular",
    "perambulará": "perambular",
    "perambularás": "perambular",
    "perambularão": "perambular",
    "perambularíamos": "perambular",
    "perambularíeis": "perambular",
    "perambulas": "perambular",
    "perambulasse": "perambular",
    "perambulassem": "perambular",
    "perambulasses": "perambular",
    "perambulaste": "perambular",
    "perambulastes": "perambular",
    "perambulatória": "perambulatório",
    "perambulatórias": "perambulatório",
    "perambulatórios": "perambulatório",
    "perambulava": "perambular",
    "perambulavam": "perambular",
    "perambulavas": "perambular",
    "perambulações": "perambulação",
    "perambule": "perambular",
    "perambulei": "perambular",
    "perambuleis": "perambular",
    "perambulem": "perambular",
    "perambulemo": "perambular",
    "perambulemos": "perambular",
    "perambules": "perambular",
    "perambulo": "perambular",
    "perambulou": "perambular",
    "perambulámo": "perambular",
    "perambulámos": "perambular",
    "perambuláramo": "perambular",
    "perambuláramos": "perambular",
    "perambuláreis": "perambular",
    "perambulásseis": "perambular",
    "perambulássemos": "perambular",
    "perambulávamo": "perambular",
    "perambulávamos": "perambular",
    "perambuláveis": "perambular",
    "peraus": "perau",
    "perca": "perder",
    "percais": "perder",
    "percalinas": "percalina",
    "percalços": "percalço",
    "percam": "perder",
    "percamo": "perder",
    "percamos": "perder",
    "percas": "perder",
    "perceba": "perceber",
    "percebais": "perceber",
    "percebam": "perceber",
    "percebamo": "perceber",
    "percebamos": "perceber",
    "percebas": "perceber",
    "percebe": "perceber",
    "percebei": "perceber",
    "percebeis": "perceber",
    "percebelhos": "percebelho",
    "percebem": "perceber",
    "percebemo": "perceber",
    "percebemos": "perceber",
    "percebendo": "perceber",
    "percebera": "perceber",
    "perceberam": "perceber",
    "perceberas": "perceber",
    "perceberde": "perceber",
    "perceberdes": "perceber",
    "percebere": "perceber",
    "perceberei": "perceber",
    "percebereis": "perceber",
    "perceberem": "perceber",
    "perceberemos": "perceber",
    "perceberes": "perceber",
    "perceberia": "perceber",
    "perceberiam": "perceber",
    "perceberias": "perceber",
    "percebermo": "perceber",
    "percebermos": "perceber",
    "perceberá": "perceber",
    "perceberás": "perceber",
    "perceberão": "perceber",
    "perceberíamos": "perceber",
    "perceberíeis": "perceber",
    "percebes": "perceber",
    "percebesse": "perceber",
    "percebessem": "perceber",
    "percebesses": "perceber",
    "percebeste": "perceber",
    "percebestes": "perceber",
    "percebeu": "perceber",
    "percebi": "perceber",
    "percebia": "perceber",
    "percebiam": "perceber",
    "percebias": "perceber",
    "percebida": "percebido",
    "percebidas": "percebido",
    "percebido": "perceber",
    "percebidos": "percebido",
    "percebimentos": "percebimento",
    "percebo": "perceber",
    "percebê": "perceber",
    "percebêramo": "perceber",
    "percebêramos": "perceber",
    "percebêrei": "perceber",
    "percebêreis": "perceber",
    "percebêsseis": "perceber",
    "percebêssemos": "perceber",
    "percebíamo": "perceber",
    "percebíamos": "perceber",
    "percebíei": "perceber",
    "percebíeis": "perceber",
    "percebíveis": "percebível",
    "percentagens": "percentagem",
    "percentagistas": "percentagista",
    "percentis": "percentil",
    "percentuais": "percentual",
    "percepcionismos": "percepcionismo",
    "percepcionistas": "percepcionista",
    "percepta": "percepto",
    "perceptas": "percepto",
    "perceptibilidades": "perceptibilidade",
    "perceptiva": "perceptivo",
    "perceptivas": "perceptivo",
    "perceptivos": "perceptivo",
    "perceptos": "percepto",
    "perceptuais": "perceptual",
    "perceptíveis": "perceptível",
    "percepções": "percepção",
    "percevejadas": "percevejada",
    "percevejos": "percevejo",
    "percevelhos": "percevelho",
    "perceves": "perceve",
    "perchas": "percha",
    "percinta": "percintar",
    "percintada": "percintar",
    "percintadas": "percintar",
    "percintado": "percintar",
    "percintados": "percintar",
    "percintai": "percintar",
    "percintais": "percintar",
    "percintam": "percintar",
    "percintamo": "percintar",
    "percintamos": "percintar",
    "percintando": "percintar",
    "percintara": "percintar",
    "percintaram": "percintar",
    "percintaras": "percintar",
    "percintarde": "percintar",
    "percintardes": "percintar",
    "percintare": "percintar",
    "percintarei": "percintar",
    "percintareis": "percintar",
    "percintarem": "percintar",
    "percintaremos": "percintar",
    "percintares": "percintar",
    "percintaria": "percintar",
    "percintariam": "percintar",
    "percintarias": "percintar",
    "percintarmo": "percintar",
    "percintarmos": "percintar",
    "percintará": "percintar",
    "percintarás": "percintar",
    "percintarão": "percintar",
    "percintaríamos": "percintar",
    "percintaríeis": "percintar",
    "percintas": "percintar",
    "percintasse": "percintar",
    "percintassem": "percintar",
    "percintasses": "percintar",
    "percintaste": "percintar",
    "percintastes": "percintar",
    "percintava": "percintar",
    "percintavam": "percintar",
    "percintavas": "percintar",
    "percinte": "percintar",
    "percintei": "percintar",
    "percinteis": "percintar",
    "percintem": "percintar",
    "percintemo": "percintar",
    "percintemos": "percintar",
    "percintes": "percintar",
    "percinto": "percintar",
    "percintou": "percintar",
    "percintá": "percintar",
    "percintámo": "percintar",
    "percintámos": "percintar",
    "percintáramo": "percintar",
    "percintáramos": "percintar",
    "percintárei": "percintar",
    "percintáreis": "percintar",
    "percintásseis": "percintar",
    "percintássemos": "percintar",
    "percintávamo": "percintar",
    "percintávamos": "percintar",
    "percintávei": "percintar",
    "percintáveis": "percintar",
    "percloratos": "perclorato",
    "perclusa": "percluso",
    "perclusas": "percluso",
    "perclusos": "percluso",
    "perclórica": "perclórico",
    "perclóricas": "perclórico",
    "perclóricos": "perclórico",
    "perco": "perder",
    "percolações": "percolação",
    "percorra": "percorrer",
    "percorrais": "percorrer",
    "percorram": "percorrer",
    "percorramo": "percorrer",
    "percorramos": "percorrer",
    "percorras": "percorrer",
    "percorre": "percorrer",
    "percorrei": "percorrer",
    "percorreis": "percorrer",
    "percorrem": "percorrer",
    "percorremo": "percorrer",
    "percorremos": "percorrer",
    "percorrendo": "percorrer",
    "percorrera": "percorrer",
    "percorreram": "percorrer",
    "percorreras": "percorrer",
    "percorrerde": "percorrer",
    "percorrerdes": "percorrer",
    "percorrere": "percorrer",
    "percorrerei": "percorrer",
    "percorrereis": "percorrer",
    "percorrerem": "percorrer",
    "percorreremos": "percorrer",
    "percorreres": "percorrer",
    "percorreria": "percorrer",
    "percorreriam": "percorrer",
    "percorrerias": "percorrer",
    "percorrermo": "percorrer",
    "percorrermos": "percorrer",
    "percorrerá": "percorrer",
    "percorrerás": "percorrer",
    "percorrerão": "percorrer",
    "percorreríamos": "percorrer",
    "percorreríeis": "percorrer",
    "percorres": "percorrer",
    "percorresse": "percorrer",
    "percorressem": "percorrer",
    "percorresses": "percorrer",
    "percorreste": "percorrer",
    "percorrestes": "percorrer",
    "percorreu": "percorrer",
    "percorri": "percorrer",
    "percorria": "percorrer",
    "percorriam": "percorrer",
    "percorrias": "percorrer",
    "percorrida": "percorrido",
    "percorridas": "percorrido",
    "percorrido": "percorrer",
    "percorridos": "percorrido",
    "percorro": "percorrer",
    "percorrê": "percorrer",
    "percorrêramo": "percorrer",
    "percorrêramos": "percorrer",
    "percorrêrei": "percorrer",
    "percorrêreis": "percorrer",
    "percorrêsseis": "percorrer",
    "percorrêssemos": "percorrer",
    "percorríamo": "percorrer",
    "percorríamos": "percorrer",
    "percorríei": "percorrer",
    "percorríeis": "percorrer",
    "percucientes": "percuciente",
    "percucientíssima": "percuciente",
    "percucientíssimas": "percuciente",
    "percucientíssimo": "percuciente",
    "percucientíssimos": "percuciente",
    "perculsa": "perculso",
    "perculsas": "perculso",
    "perculsos": "perculso",
    "percursora": "percursor",
    "percursoras": "percursor",
    "percursores": "percursor",
    "percursos": "percurso",
    "percussionistas": "percussionista",
    "percussora": "percussor",
    "percussoras": "percussor",
    "percussores": "percussor",
    "percussões": "percussão",
    "percuta": "percutir",
    "percutais": "percutir",
    "percutam": "percutir",
    "percutamo": "percutir",
    "percutamos": "percutir",
    "percutas": "percutir",
    "percute": "percutir",
    "percutem": "percutir",
    "percutes": "percutir",
    "percuti": "percutir",
    "percutia": "percutir",
    "percutiam": "percutir",
    "percutias": "percutir",
    "percutida": "percutir",
    "percutidas": "percutir",
    "percutido": "percutir",
    "percutidora": "percutidor",
    "percutidoras": "percutidor",
    "percutidores": "percutidor",
    "percutidos": "percutir",
    "percutimo": "percutir",
    "percutimos": "percutir",
    "percutindo": "percutir",
    "percutira": "percutir",
    "percutiram": "percutir",
    "percutiras": "percutir",
    "percutirde": "percutir",
    "percutirdes": "percutir",
    "percutire": "percutir",
    "percutirei": "percutir",
    "percutireis": "percutir",
    "percutirem": "percutir",
    "percutiremos": "percutir",
    "percutires": "percutir",
    "percutiria": "percutir",
    "percutiriam": "percutir",
    "percutirias": "percutir",
    "percutirmo": "percutir",
    "percutirmos": "percutir",
    "percutirá": "percutir",
    "percutirás": "percutir",
    "percutirão": "percutir",
    "percutiríamos": "percutir",
    "percutiríeis": "percutir",
    "percutis": "percutir",
    "percutisse": "percutir",
    "percutissem": "percutir",
    "percutisses": "percutir",
    "percutiste": "percutir",
    "percutistes": "percutir",
    "percutiu": "percutir",
    "percuto": "percutir",
    "percutores": "percutor",
    "percutíamo": "percutir",
    "percutíamos": "percutir",
    "percutíei": "percutir",
    "percutíeis": "percutir",
    "percutíramo": "percutir",
    "percutíramos": "percutir",
    "percutírei": "percutir",
    "percutíreis": "percutir",
    "percutísseis": "percutir",
    "percutíssemos": "percutir",
    "percídeos": "percídeo",
    "perdas": "perda",
    "perde": "perder",
    "perdedora": "perdedor",
    "perdedoras": "perdedor",
    "perdedores": "perdedor",
    "perdei": "perder",
    "perdeis": "perder",
    "perdem": "perder",
    "perdemo": "perder",
    "perdemos": "perder",
    "perdendo": "perder",
    "perdera": "perder",
    "perderam": "perder",
    "perderas": "perder",
    "perderde": "perder",
    "perderdes": "perder",
    "perdere": "perder",
    "perderei": "perder",
    "perdereis": "perder",
    "perderem": "perder",
    "perderemos": "perder",
    "perderes": "perder",
    "perderia": "perder",
    "perderiam": "perder",
    "perderias": "perder",
    "perdermo": "perder",
    "perdermos": "perder",
    "perderá": "perder",
    "perderás": "perder",
    "perderão": "perder",
    "perderíamos": "perder",
    "perderíeis": "perder",
    "perdes": "perder",
    "perdesse": "perder",
    "perdessem": "perder",
    "perdesses": "perder",
    "perdeste": "perder",
    "perdestes": "perder",
    "perdeu": "perder",
    "perdi": "perder",
    "perdia": "perder",
    "perdiam": "perder",
    "perdias": "perder",
    "perdida": "perdido",
    "perdidas": "perdido",
    "perdidazinha": "perdido",
    "perdidazinhas": "perdido",
    "perdidazita": "perdido",
    "perdidazitas": "perdido",
    "perdidinha": "perdido",
    "perdidinhas": "perdido",
    "perdidinho": "perdido",
    "perdidinhos": "perdido",
    "perdidita": "perdido",
    "perdiditas": "perdido",
    "perdidito": "perdido",
    "perdiditos": "perdido",
    "perdidiça": "perdidiço",
    "perdidiças": "perdidiço",
    "perdidiços": "perdidiço",
    "perdido": "perder",
    "perdidos": "perdido",
    "perdidozinho": "perdido",
    "perdidozinhos": "perdido",
    "perdidozito": "perdido",
    "perdidozitos": "perdido",
    "perdidíssima": "perdido",
    "perdidíssimas": "perdido",
    "perdidíssimo": "perdido",
    "perdidíssimos": "perdido",
    "perdigota": "perdigotar",
    "perdigotada": "perdigotar",
    "perdigotadas": "perdigotar",
    "perdigotado": "perdigotar",
    "perdigotados": "perdigotar",
    "perdigotai": "perdigotar",
    "perdigotais": "perdigotar",
    "perdigotam": "perdigotar",
    "perdigotamo": "perdigotar",
    "perdigotamos": "perdigotar",
    "perdigotando": "perdigotar",
    "perdigotara": "perdigotar",
    "perdigotaram": "perdigotar",
    "perdigotaras": "perdigotar",
    "perdigotardes": "perdigotar",
    "perdigotarei": "perdigotar",
    "perdigotareis": "perdigotar",
    "perdigotarem": "perdigotar",
    "perdigotaremos": "perdigotar",
    "perdigotares": "perdigotar",
    "perdigotaria": "perdigotar",
    "perdigotariam": "perdigotar",
    "perdigotarias": "perdigotar",
    "perdigotarmo": "perdigotar",
    "perdigotarmos": "perdigotar",
    "perdigotará": "perdigotar",
    "perdigotarás": "perdigotar",
    "perdigotarão": "perdigotar",
    "perdigotaríamos": "perdigotar",
    "perdigotaríeis": "perdigotar",
    "perdigotas": "perdigotar",
    "perdigotasse": "perdigotar",
    "perdigotassem": "perdigotar",
    "perdigotasses": "perdigotar",
    "perdigotaste": "perdigotar",
    "perdigotastes": "perdigotar",
    "perdigotava": "perdigotar",
    "perdigotavam": "perdigotar",
    "perdigotavas": "perdigotar",
    "perdigote": "perdigotar",
    "perdigotei": "perdigotar",
    "perdigoteis": "perdigotar",
    "perdigotem": "perdigotar",
    "perdigotemo": "perdigotar",
    "perdigotemos": "perdigotar",
    "perdigotes": "perdigotar",
    "perdigoto": "perdigotar",
    "perdigotos": "perdigoto",
    "perdigotou": "perdigotar",
    "perdigotámo": "perdigotar",
    "perdigotámos": "perdigotar",
    "perdigotáramo": "perdigotar",
    "perdigotáramos": "perdigotar",
    "perdigotáreis": "perdigotar",
    "perdigotásseis": "perdigotar",
    "perdigotássemos": "perdigotar",
    "perdigotávamo": "perdigotar",
    "perdigotávamos": "perdigotar",
    "perdigotáveis": "perdigotar",
    "perdigueira": "perdigueiro",
    "perdigueiras": "perdigueiro",
    "perdigueiros": "perdigueiro",
    "perdigão": "perdiz",
    "perdigãozinho": "perdiz",
    "perdigãozito": "perdiz",
    "perdigões": "perdiz",
    "perdigõezinhos": "perdiz",
    "perdigõezitos": "perdiz",
    "perdimentos": "perdimento",
    "perdizadas": "perdizada",
    "perdizes": "perdiz",
    "perdizezinha": "perdiz",
    "perdizezinhas": "perdiz",
    "perdizezita": "perdiz",
    "perdizezitas": "perdiz",
    "perdizinhas": "perdizinha",
    "perdições": "perdição",
    "perdoa": "perdoar",
    "perdoada": "perdoar",
    "perdoadas": "perdoar",
    "perdoado": "perdoar",
    "perdoadora": "perdoador",
    "perdoadoras": "perdoador",
    "perdoadores": "perdoador",
    "perdoados": "perdoar",
    "perdoai": "perdoar",
    "perdoais": "perdoar",
    "perdoam": "perdoar",
    "perdoamo": "perdoar",
    "perdoamos": "perdoar",
    "perdoando": "perdoar",
    "perdoara": "perdoar",
    "perdoaram": "perdoar",
    "perdoaras": "perdoar",
    "perdoarde": "perdoar",
    "perdoardes": "perdoar",
    "perdoare": "perdoar",
    "perdoarei": "perdoar",
    "perdoareis": "perdoar",
    "perdoarem": "perdoar",
    "perdoaremos": "perdoar",
    "perdoares": "perdoar",
    "perdoaria": "perdoar",
    "perdoariam": "perdoar",
    "perdoarias": "perdoar",
    "perdoarmo": "perdoar",
    "perdoarmos": "perdoar",
    "perdoará": "perdoar",
    "perdoarás": "perdoar",
    "perdoarão": "perdoar",
    "perdoaríamos": "perdoar",
    "perdoaríeis": "perdoar",
    "perdoas": "perdoar",
    "perdoasse": "perdoar",
    "perdoassem": "perdoar",
    "perdoasses": "perdoar",
    "perdoaste": "perdoar",
    "perdoastes": "perdoar",
    "perdoava": "perdoar",
    "perdoavam": "perdoar",
    "perdoavas": "perdoar",
    "perdoe": "perdoar",
    "perdoei": "perdoar",
    "perdoeis": "perdoar",
    "perdoem": "perdoar",
    "perdoemo": "perdoar",
    "perdoemos": "perdoar",
    "perdoes": "perdoe",
    "perdoo": "perdoar",
    "perdoou": "perdoar",
    "perdoá": "perdoar",
    "perdoámo": "perdoar",
    "perdoámos": "perdoar",
    "perdoáramo": "perdoar",
    "perdoáramos": "perdoar",
    "perdoárei": "perdoar",
    "perdoáreis": "perdoar",
    "perdoásseis": "perdoar",
    "perdoássemos": "perdoar",
    "perdoávamo": "perdoar",
    "perdoávamos": "perdoar",
    "perdoávei": "perdoar",
    "perdoáveis": "perdoável",
    "perdularia": "perdulariar",
    "perdulariada": "perdulariar",
    "perdulariadas": "perdulariar",
    "perdulariado": "perdulariar",
    "perdulariados": "perdulariar",
    "perdulariai": "perdulariar",
    "perdulariais": "perdulariar",
    "perdulariam": "perdulariar",
    "perdulariamo": "perdulariar",
    "perdulariamos": "perdulariar",
    "perdulariando": "perdulariar",
    "perdulariara": "perdulariar",
    "perdulariaram": "perdulariar",
    "perdulariaras": "perdulariar",
    "perdulariarde": "perdulariar",
    "perdulariardes": "perdulariar",
    "perdulariare": "perdulariar",
    "perdulariarei": "perdulariar",
    "perdulariareis": "perdulariar",
    "perdulariarem": "perdulariar",
    "perdulariaremos": "perdulariar",
    "perdulariares": "perdulariar",
    "perdulariaria": "perdulariar",
    "perdulariariam": "perdulariar",
    "perdulariarias": "perdulariar",
    "perdulariarmo": "perdulariar",
    "perdulariarmos": "perdulariar",
    "perdulariará": "perdulariar",
    "perdulariarás": "perdulariar",
    "perdulariarão": "perdulariar",
    "perdulariaríamos": "perdulariar",
    "perdulariaríeis": "perdulariar",
    "perdularias": "perdulariar",
    "perdulariasse": "perdulariar",
    "perdulariassem": "perdulariar",
    "perdulariasses": "perdulariar",
    "perdulariaste": "perdulariar",
    "perdulariastes": "perdulariar",
    "perdulariava": "perdulariar",
    "perdulariavam": "perdulariar",
    "perdulariavas": "perdulariar",
    "perdularie": "perdulariar",
    "perdulariei": "perdulariar",
    "perdularieis": "perdulariar",
    "perdulariem": "perdulariar",
    "perdulariemo": "perdulariar",
    "perdulariemos": "perdulariar",
    "perdularies": "perdulariar",
    "perdulario": "perdulariar",
    "perdulariou": "perdulariar",
    "perdulariá": "perdulariar",
    "perdulariámo": "perdulariar",
    "perdulariámos": "perdulariar",
    "perdulariáramo": "perdulariar",
    "perdulariáramos": "perdulariar",
    "perdulariárei": "perdulariar",
    "perdulariáreis": "perdulariar",
    "perdulariásseis": "perdulariar",
    "perdulariássemos": "perdulariar",
    "perdulariávamo": "perdulariar",
    "perdulariávamos": "perdulariar",
    "perdulariávei": "perdulariar",
    "perdulariáveis": "perdulariar",
    "perdulária": "perdulário",
    "perdulárias": "perdulário",
    "perdulários": "perdulário",
    "perdura": "perdurar",
    "perdurabilidades": "perdurabilidade",
    "perdurada": "perdurar",
    "perduradas": "perdurar",
    "perdurado": "perdurar",
    "perdurados": "perdurar",
    "perdurai": "perdurar",
    "perdurais": "perdurar",
    "perduram": "perdurar",
    "perduramo": "perdurar",
    "perduramos": "perdurar",
    "perdurando": "perdurar",
    "perdurantes": "perdurante",
    "perdurara": "perdurar",
    "perduraram": "perdurar",
    "perduraras": "perdurar",
    "perdurardes": "perdurar",
    "perdurarei": "perdurar",
    "perdurareis": "perdurar",
    "perdurarem": "perdurar",
    "perduraremos": "perdurar",
    "perdurares": "perdurar",
    "perduraria": "perdurar",
    "perdurariam": "perdurar",
    "perdurarias": "perdurar",
    "perdurarmo": "perdurar",
    "perdurarmos": "perdurar",
    "perdurará": "perdurar",
    "perdurarás": "perdurar",
    "perdurarão": "perdurar",
    "perduraríamos": "perdurar",
    "perduraríeis": "perdurar",
    "perduras": "perdurar",
    "perdurasse": "perdurar",
    "perdurassem": "perdurar",
    "perdurasses": "perdurar",
    "perduraste": "perdurar",
    "perdurastes": "perdurar",
    "perdurava": "perdurar",
    "perduravam": "perdurar",
    "perduravas": "perdurar",
    "perdurações": "perduração",
    "perdure": "perdurar",
    "perdurei": "perdurar",
    "perdureis": "perdurar",
    "perdurem": "perdurar",
    "perduremo": "perdurar",
    "perduremos": "perdurar",
    "perdures": "perdurar",
    "perduro": "perdurar",
    "perdurou": "perdurar",
    "perdurámo": "perdurar",
    "perdurámos": "perdurar",
    "perduráramo": "perdurar",
    "perduráramos": "perdurar",
    "perduráreis": "perdurar",
    "perdurásseis": "perdurar",
    "perdurássemos": "perdurar",
    "perdurávamo": "perdurar",
    "perdurávamos": "perdurar",
    "perduráveis": "perdurável",
    "perdê": "perder",
    "perdêramo": "perder",
    "perdêramos": "perder",
    "perdêrei": "perder",
    "perdêreis": "perder",
    "perdêsseis": "perder",
    "perdêssemos": "perder",
    "perdíamo": "perder",
    "perdíamos": "perder",
    "perdíei": "perder",
    "perdíeis": "perder",
    "perdíveis": "perdível",
    "perdões": "perdão",
    "perebagens": "perebagem",
    "perece": "perecer",
    "perecedoira": "perecedoiro",
    "perecedoiras": "perecedoiro",
    "perecedoiros": "perecedoiro",
    "perecedoura": "perecedouro",
    "perecedouras": "perecedouro",
    "perecedouros": "perecedouro",
    "perecei": "perecer",
    "pereceis": "perecer",
    "perecem": "perecer",
    "perecemo": "perecer",
    "perecemos": "perecer",
    "perecendo": "perecer",
    "perecera": "perecer",
    "pereceram": "perecer",
    "pereceras": "perecer",
    "perecerdes": "perecer",
    "perecerei": "perecer",
    "perecereis": "perecer",
    "perecerem": "perecer",
    "pereceremos": "perecer",
    "pereceres": "perecer",
    "pereceria": "perecer",
    "pereceriam": "perecer",
    "perecerias": "perecer",
    "perecermo": "perecer",
    "perecermos": "perecer",
    "perecerá": "perecer",
    "perecerás": "perecer",
    "perecerão": "perecer",
    "pereceríamos": "perecer",
    "pereceríeis": "perecer",
    "pereces": "perecer",
    "perecesse": "perecer",
    "perecessem": "perecer",
    "perecesses": "perecer",
    "pereceste": "perecer",
    "perecestes": "perecer",
    "pereceu": "perecer",
    "pereci": "perecer",
    "perecia": "perecer",
    "pereciam": "perecer",
    "perecias": "perecer",
    "perecida": "perecer",
    "perecidas": "perecer",
    "perecido": "perecer",
    "perecidos": "perecer",
    "perecimentos": "perecimento",
    "perecêramo": "perecer",
    "perecêramos": "perecer",
    "perecêreis": "perecer",
    "perecêsseis": "perecer",
    "perecêssemos": "perecer",
    "perecíamo": "perecer",
    "perecíamos": "perecer",
    "perecíeis": "perecer",
    "perecíveis": "perecível",
    "peregrina": "peregrino",
    "peregrinada": "peregrinar",
    "peregrinadas": "peregrinar",
    "peregrinado": "peregrinar",
    "peregrinadora": "peregrinador",
    "peregrinadoras": "peregrinador",
    "peregrinadores": "peregrinador",
    "peregrinados": "peregrinar",
    "peregrinai": "peregrinar",
    "peregrinais": "peregrinar",
    "peregrinam": "peregrinar",
    "peregrinamo": "peregrinar",
    "peregrinamos": "peregrinar",
    "peregrinando": "peregrinar",
    "peregrinantes": "peregrinante",
    "peregrinara": "peregrinar",
    "peregrinaram": "peregrinar",
    "peregrinaras": "peregrinar",
    "peregrinarde": "peregrinar",
    "peregrinardes": "peregrinar",
    "peregrinare": "peregrinar",
    "peregrinarei": "peregrinar",
    "peregrinareis": "peregrinar",
    "peregrinarem": "peregrinar",
    "peregrinaremos": "peregrinar",
    "peregrinares": "peregrinar",
    "peregrinaria": "peregrinar",
    "peregrinariam": "peregrinar",
    "peregrinarias": "peregrinar",
    "peregrinarmo": "peregrinar",
    "peregrinarmos": "peregrinar",
    "peregrinará": "peregrinar",
    "peregrinarás": "peregrinar",
    "peregrinarão": "peregrinar",
    "peregrinaríamos": "peregrinar",
    "peregrinaríeis": "peregrinar",
    "peregrinas": "peregrino",
    "peregrinasse": "peregrinar",
    "peregrinassem": "peregrinar",
    "peregrinasses": "peregrinar",
    "peregrinaste": "peregrinar",
    "peregrinastes": "peregrinar",
    "peregrinava": "peregrinar",
    "peregrinavam": "peregrinar",
    "peregrinavas": "peregrinar",
    "peregrinações": "peregrinação",
    "peregrine": "peregrinar",
    "peregrinei": "peregrinar",
    "peregrineis": "peregrinar",
    "peregrinem": "peregrinar",
    "peregrinemo": "peregrinar",
    "peregrinemos": "peregrinar",
    "peregrines": "peregrinar",
    "peregrinismos": "peregrinismo",
    "peregrino": "peregrinar",
    "peregrinos": "peregrino",
    "peregrinou": "peregrinar",
    "peregriná": "peregrinar",
    "peregrinámo": "peregrinar",
    "peregrinámos": "peregrinar",
    "peregrináramo": "peregrinar",
    "peregrináramos": "peregrinar",
    "peregrinárei": "peregrinar",
    "peregrináreis": "peregrinar",
    "peregrinásseis": "peregrinar",
    "peregrinássemos": "peregrinar",
    "peregrinávamo": "peregrinar",
    "peregrinávamos": "peregrinar",
    "peregrinávei": "peregrinar",
    "peregrináveis": "peregrinar",
    "pereirais": "pereiral",
    "pereiras": "pereira",
    "pereiros": "pereiro",
    "pereiópodes": "pereiópode",
    "perempta": "perempto",
    "peremptas": "perempto",
    "peremptos": "perempto",
    "peremptória": "peremptório",
    "peremptórias": "peremptório",
    "peremptórios": "peremptório",
    "perempções": "perempção",
    "perenais": "perenal",
    "perenes": "perene",
    "perenibrânquios": "perenibrânquio",
    "perenidades": "perenidade",
    "pereniza": "perenizar",
    "perenizada": "perenizar",
    "perenizadas": "perenizar",
    "perenizado": "perenizar",
    "perenizados": "perenizar",
    "perenizai": "perenizar",
    "perenizais": "perenizar",
    "perenizam": "perenizar",
    "perenizamo": "perenizar",
    "perenizamos": "perenizar",
    "perenizando": "perenizar",
    "perenizara": "perenizar",
    "perenizaram": "perenizar",
    "perenizaras": "perenizar",
    "perenizarde": "perenizar",
    "perenizardes": "perenizar",
    "perenizare": "perenizar",
    "perenizarei": "perenizar",
    "perenizareis": "perenizar",
    "perenizarem": "perenizar",
    "perenizaremos": "perenizar",
    "perenizares": "perenizar",
    "perenizaria": "perenizar",
    "perenizariam": "perenizar",
    "perenizarias": "perenizar",
    "perenizarmo": "perenizar",
    "perenizarmos": "perenizar",
    "perenizará": "perenizar",
    "perenizarás": "perenizar",
    "perenizarão": "perenizar",
    "perenizaríamos": "perenizar",
    "perenizaríeis": "perenizar",
    "perenizas": "perenizar",
    "perenizasse": "perenizar",
    "perenizassem": "perenizar",
    "perenizasses": "perenizar",
    "perenizaste": "perenizar",
    "perenizastes": "perenizar",
    "perenizava": "perenizar",
    "perenizavam": "perenizar",
    "perenizavas": "perenizar",
    "perenize": "perenizar",
    "perenizei": "perenizar",
    "perenizeis": "perenizar",
    "perenizem": "perenizar",
    "perenizemo": "perenizar",
    "perenizemos": "perenizar",
    "perenizes": "perenizar",
    "perenizo": "perenizar",
    "perenizou": "perenizar",
    "perenizá": "perenizar",
    "perenizámo": "perenizar",
    "perenizámos": "perenizar",
    "perenizáramo": "perenizar",
    "perenizáramos": "perenizar",
    "perenizárei": "perenizar",
    "perenizáreis": "perenizar",
    "perenizásseis": "perenizar",
    "perenizássemos": "perenizar",
    "perenizávamo": "perenizar",
    "perenizávamos": "perenizar",
    "perenizávei": "perenizar",
    "perenizáveis": "perenizar",
    "pereníssima": "perene",
    "pereníssimas": "perene",
    "pereníssimo": "perene",
    "pereníssimos": "perene",
    "perequações": "perequação",
    "pereça": "perecer",
    "pereçais": "perecer",
    "pereçam": "perecer",
    "pereçamo": "perecer",
    "pereçamos": "perecer",
    "pereças": "perecer",
    "pereço": "perecer",
    "perfarei": "perfazer",
    "perfareis": "perfazer",
    "perfaremos": "perfazer",
    "perfaria": "perfazer",
    "perfariam": "perfazer",
    "perfarias": "perfazer",
    "perfará": "perfazer",
    "perfarás": "perfazer",
    "perfarão": "perfazer",
    "perfaríamos": "perfazer",
    "perfaríeis": "perfazer",
    "perfaz": "perfazer",
    "perfaze": "perfazer",
    "perfazei": "perfazer",
    "perfazeis": "perfazer",
    "perfazem": "perfazer",
    "perfazemo": "perfazer",
    "perfazemos": "perfazer",
    "perfazendo": "perfazer",
    "perfazerde": "perfazer",
    "perfazerdes": "perfazer",
    "perfazere": "perfazer",
    "perfazerem": "perfazer",
    "perfazeres": "perfazer",
    "perfazermo": "perfazer",
    "perfazermos": "perfazer",
    "perfazes": "perfazer",
    "perfazia": "perfazer",
    "perfaziam": "perfazer",
    "perfazias": "perfazer",
    "perfazimentos": "perfazimento",
    "perfazê": "perfazer",
    "perfazíamo": "perfazer",
    "perfazíamos": "perfazer",
    "perfazíei": "perfazer",
    "perfazíeis": "perfazer",
    "perfaça": "perfazer",
    "perfaçais": "perfazer",
    "perfaçam": "perfazer",
    "perfaçamo": "perfazer",
    "perfaçamos": "perfazer",
    "perfaças": "perfazer",
    "perfaço": "perfazer",
    "perfeccionais": "perfeccional",
    "perfeccionismos": "perfeccionismo",
    "perfeccionistas": "perfeccionista",
    "perfectibilidades": "perfectibilidade",
    "perfectibiliza": "perfectibilizar",
    "perfectibilizada": "perfectibilizar",
    "perfectibilizadas": "perfectibilizar",
    "perfectibilizado": "perfectibilizar",
    "perfectibilizados": "perfectibilizar",
    "perfectibilizai": "perfectibilizar",
    "perfectibilizais": "perfectibilizar",
    "perfectibilizam": "perfectibilizar",
    "perfectibilizamo": "perfectibilizar",
    "perfectibilizamos": "perfectibilizar",
    "perfectibilizando": "perfectibilizar",
    "perfectibilizara": "perfectibilizar",
    "perfectibilizaram": "perfectibilizar",
    "perfectibilizaras": "perfectibilizar",
    "perfectibilizarde": "perfectibilizar",
    "perfectibilizardes": "perfectibilizar",
    "perfectibilizare": "perfectibilizar",
    "perfectibilizarei": "perfectibilizar",
    "perfectibilizareis": "perfectibilizar",
    "perfectibilizarem": "perfectibilizar",
    "perfectibilizaremos": "perfectibilizar",
    "perfectibilizares": "perfectibilizar",
    "perfectibilizaria": "perfectibilizar",
    "perfectibilizariam": "perfectibilizar",
    "perfectibilizarias": "perfectibilizar",
    "perfectibilizarmo": "perfectibilizar",
    "perfectibilizarmos": "perfectibilizar",
    "perfectibilizará": "perfectibilizar",
    "perfectibilizarás": "perfectibilizar",
    "perfectibilizarão": "perfectibilizar",
    "perfectibilizaríamos": "perfectibilizar",
    "perfectibilizaríeis": "perfectibilizar",
    "perfectibilizas": "perfectibilizar",
    "perfectibilizasse": "perfectibilizar",
    "perfectibilizassem": "perfectibilizar",
    "perfectibilizasses": "perfectibilizar",
    "perfectibilizaste": "perfectibilizar",
    "perfectibilizastes": "perfectibilizar",
    "perfectibilizava": "perfectibilizar",
    "perfectibilizavam": "perfectibilizar",
    "perfectibilizavas": "perfectibilizar",
    "perfectibilize": "perfectibilizar",
    "perfectibilizei": "perfectibilizar",
    "perfectibilizeis": "perfectibilizar",
    "perfectibilizem": "perfectibilizar",
    "perfectibilizemo": "perfectibilizar",
    "perfectibilizemos": "perfectibilizar",
    "perfectibilizes": "perfectibilizar",
    "perfectibilizo": "perfectibilizar",
    "perfectibilizou": "perfectibilizar",
    "perfectibilizá": "perfectibilizar",
    "perfectibilizámo": "perfectibilizar",
    "perfectibilizámos": "perfectibilizar",
    "perfectibilizáramo": "perfectibilizar",
    "perfectibilizáramos": "perfectibilizar",
    "perfectibilizárei": "perfectibilizar",
    "perfectibilizáreis": "perfectibilizar",
    "perfectibilizásseis": "perfectibilizar",
    "perfectibilizássemos": "perfectibilizar",
    "perfectibilizávamo": "perfectibilizar",
    "perfectibilizávamos": "perfectibilizar",
    "perfectibilizávei": "perfectibilizar",
    "perfectibilizáveis": "perfectibilizar",
    "perfectiva": "perfectivo",
    "perfectivas": "perfectivo",
    "perfectivos": "perfectivo",
    "perfectíveis": "perfectível",
    "perfeita": "perfeito",
    "perfeitas": "perfeito",
    "perfeito": "perfazer",
    "perfeitos": "perfeito",
    "perfeitíssima": "perfeito",
    "perfeitíssimas": "perfeito",
    "perfeitíssimo": "perfeito",
    "perfeitíssimos": "perfeito",
    "perfeiçoa": "perfeiçoar",
    "perfeiçoada": "perfeiçoar",
    "perfeiçoadas": "perfeiçoar",
    "perfeiçoado": "perfeiçoar",
    "perfeiçoados": "perfeiçoar",
    "perfeiçoai": "perfeiçoar",
    "perfeiçoais": "perfeiçoar",
    "perfeiçoam": "perfeiçoar",
    "perfeiçoamo": "perfeiçoar",
    "perfeiçoamos": "perfeiçoar",
    "perfeiçoando": "perfeiçoar",
    "perfeiçoara": "perfeiçoar",
    "perfeiçoaram": "perfeiçoar",
    "perfeiçoaras": "perfeiçoar",
    "perfeiçoarde": "perfeiçoar",
    "perfeiçoardes": "perfeiçoar",
    "perfeiçoare": "perfeiçoar",
    "perfeiçoarei": "perfeiçoar",
    "perfeiçoareis": "perfeiçoar",
    "perfeiçoarem": "perfeiçoar",
    "perfeiçoaremos": "perfeiçoar",
    "perfeiçoares": "perfeiçoar",
    "perfeiçoaria": "perfeiçoar",
    "perfeiçoariam": "perfeiçoar",
    "perfeiçoarias": "perfeiçoar",
    "perfeiçoarmo": "perfeiçoar",
    "perfeiçoarmos": "perfeiçoar",
    "perfeiçoará": "perfeiçoar",
    "perfeiçoarás": "perfeiçoar",
    "perfeiçoarão": "perfeiçoar",
    "perfeiçoaríamos": "perfeiçoar",
    "perfeiçoaríeis": "perfeiçoar",
    "perfeiçoas": "perfeiçoar",
    "perfeiçoasse": "perfeiçoar",
    "perfeiçoassem": "perfeiçoar",
    "perfeiçoasses": "perfeiçoar",
    "perfeiçoaste": "perfeiçoar",
    "perfeiçoastes": "perfeiçoar",
    "perfeiçoava": "perfeiçoar",
    "perfeiçoavam": "perfeiçoar",
    "perfeiçoavas": "perfeiçoar",
    "perfeiçoe": "perfeiçoar",
    "perfeiçoei": "perfeiçoar",
    "perfeiçoeis": "perfeiçoar",
    "perfeiçoem": "perfeiçoar",
    "perfeiçoemo": "perfeiçoar",
    "perfeiçoemos": "perfeiçoar",
    "perfeiçoes": "perfeiçoar",
    "perfeiçoo": "perfeiçoar",
    "perfeiçoou": "perfeiçoar",
    "perfeiçoá": "perfeiçoar",
    "perfeiçoámo": "perfeiçoar",
    "perfeiçoámos": "perfeiçoar",
    "perfeiçoáramo": "perfeiçoar",
    "perfeiçoáramos": "perfeiçoar",
    "perfeiçoárei": "perfeiçoar",
    "perfeiçoáreis": "perfeiçoar",
    "perfeiçoásseis": "perfeiçoar",
    "perfeiçoássemos": "perfeiçoar",
    "perfeiçoávamo": "perfeiçoar",
    "perfeiçoávamos": "perfeiçoar",
    "perfeiçoávei": "perfeiçoar",
    "perfeiçoáveis": "perfeiçoar",
    "perfeições": "perfeição",
    "perfez": "perfazer",
    "perfi": "perfazer",
    "perficientes": "perficiente",
    "perficientíssima": "perficiente",
    "perficientíssimas": "perficiente",
    "perficientíssimo": "perficiente",
    "perficientíssimos": "perficiente",
    "perfila": "perfilar",
    "perfilada": "perfilar",
    "perfiladas": "perfilar",
    "perfilado": "perfilar",
    "perfilados": "perfilar",
    "perfiladíssima": "perfilado",
    "perfiladíssimas": "perfilado",
    "perfiladíssimo": "perfilado",
    "perfiladíssimos": "perfilado",
    "perfilai": "perfilar",
    "perfilais": "perfilar",
    "perfilam": "perfilar",
    "perfilamo": "perfilar",
    "perfilamos": "perfilar",
    "perfilando": "perfilar",
    "perfilara": "perfilar",
    "perfilaram": "perfilar",
    "perfilaras": "perfilar",
    "perfilarde": "perfilar",
    "perfilardes": "perfilar",
    "perfilare": "perfilar",
    "perfilarei": "perfilar",
    "perfilareis": "perfilar",
    "perfilarem": "perfilar",
    "perfilaremos": "perfilar",
    "perfilares": "perfilar",
    "perfilaria": "perfilar",
    "perfilariam": "perfilar",
    "perfilarias": "perfilar",
    "perfilarmo": "perfilar",
    "perfilarmos": "perfilar",
    "perfilará": "perfilar",
    "perfilarás": "perfilar",
    "perfilarão": "perfilar",
    "perfilaríamos": "perfilar",
    "perfilaríeis": "perfilar",
    "perfilas": "perfilar",
    "perfilasse": "perfilar",
    "perfilassem": "perfilar",
    "perfilasses": "perfilar",
    "perfilaste": "perfilar",
    "perfilastes": "perfilar",
    "perfilava": "perfilar",
    "perfilavam": "perfilar",
    "perfilavas": "perfilar",
    "perfile": "perfilar",
    "perfilei": "perfilar",
    "perfileis": "perfilar",
    "perfilem": "perfilar",
    "perfilemo": "perfilar",
    "perfilemos": "perfilar",
    "perfiles": "perfilar",
    "perfilha": "perfilhar",
    "perfilhada": "perfilhar",
    "perfilhadas": "perfilhar",
    "perfilhado": "perfilhar",
    "perfilhadora": "perfilhador",
    "perfilhadoras": "perfilhador",
    "perfilhadores": "perfilhador",
    "perfilhados": "perfilhar",
    "perfilhai": "perfilhar",
    "perfilhais": "perfilhar",
    "perfilham": "perfilhar",
    "perfilhamentos": "perfilhamento",
    "perfilhamo": "perfilhar",
    "perfilhamos": "perfilhar",
    "perfilhando": "perfilhar",
    "perfilhantes": "perfilhante",
    "perfilhara": "perfilhar",
    "perfilharam": "perfilhar",
    "perfilharas": "perfilhar",
    "perfilharde": "perfilhar",
    "perfilhardes": "perfilhar",
    "perfilhare": "perfilhar",
    "perfilharei": "perfilhar",
    "perfilhareis": "perfilhar",
    "perfilharem": "perfilhar",
    "perfilharemos": "perfilhar",
    "perfilhares": "perfilhar",
    "perfilharia": "perfilhar",
    "perfilhariam": "perfilhar",
    "perfilharias": "perfilhar",
    "perfilharmo": "perfilhar",
    "perfilharmos": "perfilhar",
    "perfilhará": "perfilhar",
    "perfilharás": "perfilhar",
    "perfilharão": "perfilhar",
    "perfilharíamos": "perfilhar",
    "perfilharíeis": "perfilhar",
    "perfilhas": "perfilhar",
    "perfilhasse": "perfilhar",
    "perfilhassem": "perfilhar",
    "perfilhasses": "perfilhar",
    "perfilhaste": "perfilhar",
    "perfilhastes": "perfilhar",
    "perfilhava": "perfilhar",
    "perfilhavam": "perfilhar",
    "perfilhavas": "perfilhar",
    "perfilhações": "perfilhação",
    "perfilhe": "perfilhar",
    "perfilhei": "perfilhar",
    "perfilheis": "perfilhar",
    "perfilhem": "perfilhar",
    "perfilhemo": "perfilhar",
    "perfilhemos": "perfilhar",
    "perfilhes": "perfilhar",
    "perfilho": "perfilhar",
    "perfilhou": "perfilhar",
    "perfilhá": "perfilhar",
    "perfilhámo": "perfilhar",
    "perfilhámos": "perfilhar",
    "perfilháramo": "perfilhar",
    "perfilháramos": "perfilhar",
    "perfilhárei": "perfilhar",
    "perfilháreis": "perfilhar",
    "perfilhásseis": "perfilhar",
    "perfilhássemos": "perfilhar",
    "perfilhávamo": "perfilhar",
    "perfilhávamos": "perfilhar",
    "perfilhávei": "perfilhar",
    "perfilháveis": "perfilhável",
    "perfilo": "perfilar",
    "perfilou": "perfilar",
    "perfilá": "perfilar",
    "perfilámo": "perfilar",
    "perfilámos": "perfilar",
    "perfiláramo": "perfilar",
    "perfiláramos": "perfilar",
    "perfilárei": "perfilar",
    "perfiláreis": "perfilar",
    "perfilásseis": "perfilar",
    "perfilássemos": "perfilar",
    "perfilávamo": "perfilar",
    "perfilávamos": "perfilar",
    "perfilávei": "perfilar",
    "perfiláveis": "perfilar",
    "perfis": "perfil",
    "perfiz": "perfazer",
    "perfizemo": "perfazer",
    "perfizemos": "perfazer",
    "perfizer": "perfazer",
    "perfizera": "perfazer",
    "perfizeram": "perfazer",
    "perfizeras": "perfazer",
    "perfizerdes": "perfazer",
    "perfizerem": "perfazer",
    "perfizeres": "perfazer",
    "perfizermos": "perfazer",
    "perfizesse": "perfazer",
    "perfizessem": "perfazer",
    "perfizesses": "perfazer",
    "perfizeste": "perfazer",
    "perfizestes": "perfazer",
    "perfizéramo": "perfazer",
    "perfizéramos": "perfazer",
    "perfizérei": "perfazer",
    "perfizéreis": "perfazer",
    "perfizésseis": "perfazer",
    "perfizéssemos": "perfazer",
    "perflorações": "perfloração",
    "perfolhada": "perfolhado",
    "perfolhadas": "perfolhado",
    "perfolhados": "perfolhado",
    "performances": "performance",
    "performativa": "performativo",
    "performativas": "performativo",
    "performativos": "performativo",
    "perfulgentes": "perfulgente",
    "perfulgências": "perfulgência",
    "perfuma": "perfumar",
    "perfumada": "perfumar",
    "perfumadas": "perfumar",
    "perfumadazinha": "perfumado",
    "perfumadazinhas": "perfumado",
    "perfumadazita": "perfumado",
    "perfumadazitas": "perfumado",
    "perfumadinha": "perfumado",
    "perfumadinhas": "perfumado",
    "perfumadinho": "perfumado",
    "perfumadinhos": "perfumado",
    "perfumadita": "perfumado",
    "perfumaditas": "perfumado",
    "perfumadito": "perfumado",
    "perfumaditos": "perfumado",
    "perfumado": "perfumar",
    "perfumadora": "perfumador",
    "perfumadoras": "perfumador",
    "perfumadores": "perfumador",
    "perfumados": "perfumar",
    "perfumadozinho": "perfumado",
    "perfumadozinhos": "perfumado",
    "perfumadozito": "perfumado",
    "perfumadozitos": "perfumado",
    "perfumaduras": "perfumadura",
    "perfumadíssima": "perfumado",
    "perfumadíssimas": "perfumado",
    "perfumadíssimo": "perfumado",
    "perfumadíssimos": "perfumado",
    "perfumai": "perfumar",
    "perfumais": "perfumar",
    "perfumam": "perfumar",
    "perfumamo": "perfumar",
    "perfumamos": "perfumar",
    "perfumando": "perfumar",
    "perfumantes": "perfumante",
    "perfumara": "perfumar",
    "perfumaram": "perfumar",
    "perfumaras": "perfumar",
    "perfumarde": "perfumar",
    "perfumardes": "perfumar",
    "perfumare": "perfumar",
    "perfumarei": "perfumar",
    "perfumareis": "perfumar",
    "perfumarem": "perfumar",
    "perfumaremos": "perfumar",
    "perfumares": "perfumar",
    "perfumaria": "perfumar",
    "perfumariam": "perfumar",
    "perfumarias": "perfumaria",
    "perfumarmo": "perfumar",
    "perfumarmos": "perfumar",
    "perfumará": "perfumar",
    "perfumarás": "perfumar",
    "perfumarão": "perfumar",
    "perfumaríamos": "perfumar",
    "perfumaríeis": "perfumar",
    "perfumas": "perfumar",
    "perfumasse": "perfumar",
    "perfumassem": "perfumar",
    "perfumasses": "perfumar",
    "perfumaste": "perfumar",
    "perfumastes": "perfumar",
    "perfumava": "perfumar",
    "perfumavam": "perfumar",
    "perfumavas": "perfumar",
    "perfume": "perfumar",
    "perfumei": "perfumar",
    "perfumeis": "perfumar",
    "perfumem": "perfumar",
    "perfumemo": "perfumar",
    "perfumemos": "perfumar",
    "perfumes": "perfume",
    "perfumismos": "perfumismo",
    "perfumistas": "perfumista",
    "perfumo": "perfumar",
    "perfumosa": "perfumoso",
    "perfumosas": "perfumoso",
    "perfumosos": "perfumoso",
    "perfumou": "perfumar",
    "perfumá": "perfumar",
    "perfumámo": "perfumar",
    "perfumámos": "perfumar",
    "perfumáramo": "perfumar",
    "perfumáramos": "perfumar",
    "perfumárei": "perfumar",
    "perfumáreis": "perfumar",
    "perfumásseis": "perfumar",
    "perfumássemos": "perfumar",
    "perfumávamo": "perfumar",
    "perfumávamos": "perfumar",
    "perfumávei": "perfumar",
    "perfumáveis": "perfumável",
    "perfunctória": "perfunctório",
    "perfunctórias": "perfunctório",
    "perfunctórios": "perfunctório",
    "perfura": "perfurar",
    "perfurada": "perfurar",
    "perfuradas": "perfurar",
    "perfurado": "perfurar",
    "perfuradora": "perfurador",
    "perfuradoras": "perfuradora",
    "perfuradores": "perfurador",
    "perfurados": "perfurar",
    "perfurai": "perfurar",
    "perfurais": "perfurar",
    "perfuram": "perfurar",
    "perfuramo": "perfurar",
    "perfuramos": "perfurar",
    "perfurando": "perfurar",
    "perfurantes": "perfurante",
    "perfurara": "perfurar",
    "perfuraram": "perfurar",
    "perfuraras": "perfurar",
    "perfurarde": "perfurar",
    "perfurardes": "perfurar",
    "perfurare": "perfurar",
    "perfurarei": "perfurar",
    "perfurareis": "perfurar",
    "perfurarem": "perfurar",
    "perfuraremos": "perfurar",
    "perfurares": "perfurar",
    "perfuraria": "perfurar",
    "perfurariam": "perfurar",
    "perfurarias": "perfurar",
    "perfurarmo": "perfurar",
    "perfurarmos": "perfurar",
    "perfurará": "perfurar",
    "perfurarás": "perfurar",
    "perfurarão": "perfurar",
    "perfuraríamos": "perfurar",
    "perfuraríeis": "perfurar",
    "perfuras": "perfurar",
    "perfurasse": "perfurar",
    "perfurassem": "perfurar",
    "perfurasses": "perfurar",
    "perfuraste": "perfurar",
    "perfurastes": "perfurar",
    "perfurativa": "perfurativo",
    "perfurativas": "perfurativo",
    "perfurativos": "perfurativo",
    "perfurava": "perfurar",
    "perfuravam": "perfurar",
    "perfuravas": "perfurar",
    "perfurações": "perfuração",
    "perfure": "perfurar",
    "perfurei": "perfurar",
    "perfureis": "perfurar",
    "perfurem": "perfurar",
    "perfuremo": "perfurar",
    "perfuremos": "perfurar",
    "perfures": "perfurar",
    "perfuro": "perfurar",
    "perfurou": "perfurar",
    "perfurá": "perfurar",
    "perfurámo": "perfurar",
    "perfurámos": "perfurar",
    "perfuráramo": "perfurar",
    "perfuráramos": "perfurar",
    "perfurárei": "perfurar",
    "perfuráreis": "perfurar",
    "perfurásseis": "perfurar",
    "perfurássemos": "perfurar",
    "perfurávamo": "perfurar",
    "perfurávamos": "perfurar",
    "perfurávei": "perfurar",
    "perfuráveis": "perfurável",
    "perfusões": "perfusão",
    "perfá": "perfazer",
    "perfê": "perfazer",
    "perfídias": "perfídia",
    "pergaminharias": "pergaminharia",
    "pergaminheira": "pergaminheiro",
    "pergaminheiras": "pergaminheiro",
    "pergaminheiros": "pergaminheiro",
    "pergaminhos": "pergaminho",
    "pergaminácea": "pergamináceo",
    "pergamináceas": "pergamináceo",
    "pergamináceos": "pergamináceo",
    "pergamóides": "pergamóide",
    "pergelícolas": "pergelícola",
    "pergunta": "perguntar",
    "perguntada": "perguntar",
    "perguntadas": "perguntar",
    "perguntado": "perguntar",
    "perguntadora": "perguntador",
    "perguntadoras": "perguntador",
    "perguntadores": "perguntador",
    "perguntados": "perguntar",
    "perguntai": "perguntar",
    "perguntais": "perguntar",
    "perguntam": "perguntar",
    "perguntamo": "perguntar",
    "perguntamos": "perguntar",
    "perguntando": "perguntar",
    "perguntantes": "perguntante",
    "perguntara": "perguntar",
    "perguntaram": "perguntar",
    "perguntaras": "perguntar",
    "perguntarde": "perguntar",
    "perguntardes": "perguntar",
    "perguntare": "perguntar",
    "perguntarei": "perguntar",
    "perguntareis": "perguntar",
    "perguntarem": "perguntar",
    "perguntaremos": "perguntar",
    "perguntares": "perguntar",
    "perguntaria": "perguntar",
    "perguntariam": "perguntar",
    "perguntarias": "perguntar",
    "perguntarmo": "perguntar",
    "perguntarmos": "perguntar",
    "perguntará": "perguntar",
    "perguntarás": "perguntar",
    "perguntarão": "perguntar",
    "perguntaríamos": "perguntar",
    "perguntaríeis": "perguntar",
    "perguntas": "perguntar",
    "perguntasse": "perguntar",
    "perguntassem": "perguntar",
    "perguntasses": "perguntar",
    "perguntaste": "perguntar",
    "perguntastes": "perguntar",
    "perguntava": "perguntar",
    "perguntavam": "perguntar",
    "perguntavas": "perguntar",
    "pergunte": "perguntar",
    "perguntei": "perguntar",
    "pergunteis": "perguntar",
    "perguntem": "perguntar",
    "perguntemo": "perguntar",
    "perguntemos": "perguntar",
    "perguntes": "perguntar",
    "perguntinha": "pergunta",
    "perguntinhas": "pergunta",
    "perguntita": "pergunta",
    "perguntitas": "pergunta",
    "pergunto": "perguntar",
    "perguntona": "perguntão",
    "perguntonas": "perguntão",
    "perguntou": "perguntar",
    "perguntá": "perguntar",
    "perguntámo": "perguntar",
    "perguntámos": "perguntar",
    "perguntáramo": "perguntar",
    "perguntáramos": "perguntar",
    "perguntárei": "perguntar",
    "perguntáreis": "perguntar",
    "perguntásseis": "perguntar",
    "perguntássemos": "perguntar",
    "perguntávamo": "perguntar",
    "perguntávamos": "perguntar",
    "perguntávei": "perguntar",
    "perguntáveis": "perguntar",
    "perguntões": "perguntão",
    "periactos": "periacto",
    "periadenites": "periadenite",
    "periadenítica": "periadenítico",
    "periadeníticas": "periadenítico",
    "periadeníticos": "periadenítico",
    "periambos": "periambo",
    "perianais": "perianal",
    "periantos": "perianto",
    "pericardites": "pericardite",
    "pericardética": "pericardético",
    "pericardéticas": "pericardético",
    "pericardéticos": "pericardético",
    "pericarpiais": "pericarpial",
    "pericarpos": "pericarpo",
    "periciais": "pericial",
    "periciclos": "periciclo",
    "periclinas": "periclina",
    "periclita": "periclitar",
    "periclitada": "periclitar",
    "periclitadas": "periclitar",
    "periclitado": "periclitar",
    "periclitados": "periclitar",
    "periclitai": "periclitar",
    "periclitais": "periclitar",
    "periclitam": "periclitar",
    "periclitamo": "periclitar",
    "periclitamos": "periclitar",
    "periclitando": "periclitar",
    "periclitantes": "periclitante",
    "periclitara": "periclitar",
    "periclitaram": "periclitar",
    "periclitaras": "periclitar",
    "periclitarde": "periclitar",
    "periclitardes": "periclitar",
    "periclitare": "periclitar",
    "periclitarei": "periclitar",
    "periclitareis": "periclitar",
    "periclitarem": "periclitar",
    "periclitaremos": "periclitar",
    "periclitares": "periclitar",
    "periclitaria": "periclitar",
    "periclitariam": "periclitar",
    "periclitarias": "periclitar",
    "periclitarmo": "periclitar",
    "periclitarmos": "periclitar",
    "periclitará": "periclitar",
    "periclitarás": "periclitar",
    "periclitarão": "periclitar",
    "periclitaríamos": "periclitar",
    "periclitaríeis": "periclitar",
    "periclitas": "periclitar",
    "periclitasse": "periclitar",
    "periclitassem": "periclitar",
    "periclitasses": "periclitar",
    "periclitaste": "periclitar",
    "periclitastes": "periclitar",
    "periclitava": "periclitar",
    "periclitavam": "periclitar",
    "periclitavas": "periclitar",
    "periclite": "periclitar",
    "periclitei": "periclitar",
    "pericliteis": "periclitar",
    "periclitem": "periclitar",
    "periclitemo": "periclitar",
    "periclitemos": "periclitar",
    "periclites": "periclitar",
    "periclito": "periclitar",
    "periclitou": "periclitar",
    "periclitá": "periclitar",
    "periclitámo": "periclitar",
    "periclitámos": "periclitar",
    "periclitáramo": "periclitar",
    "periclitáramos": "periclitar",
    "periclitárei": "periclitar",
    "periclitáreis": "periclitar",
    "periclitásseis": "periclitar",
    "periclitássemos": "periclitar",
    "periclitávamo": "periclitar",
    "periclitávamos": "periclitar",
    "periclitávei": "periclitar",
    "periclitáveis": "periclitar",
    "periclástica": "periclástico",
    "periclásticas": "periclástico",
    "periclásticos": "periclástico",
    "pericondrites": "pericondrite",
    "pericondros": "pericondro",
    "pericondrítica": "pericondrítico",
    "pericondríticas": "pericondrítico",
    "pericondríticos": "pericondrítico",
    "pericraniais": "pericranial",
    "pericrânios": "pericrânio",
    "periculosidades": "periculosidade",
    "pericárdica": "pericárdico",
    "pericárdicas": "pericárdico",
    "pericárdicos": "pericárdico",
    "pericárdios": "pericárdio",
    "pericárpica": "pericárpico",
    "pericárpicas": "pericárpico",
    "pericárpicos": "pericárpico",
    "pericárpios": "pericárpio",
    "pericíclica": "pericíclico",
    "pericíclicas": "pericíclico",
    "pericíclicos": "pericíclico",
    "pericôndrica": "pericôndrico",
    "pericôndricas": "pericôndrico",
    "pericôndricos": "pericôndrico",
    "pericôndrios": "pericôndrio",
    "peridentais": "peridental",
    "peridentária": "peridentário",
    "peridentárias": "peridentário",
    "peridentários": "peridentário",
    "peridotites": "peridotite",
    "peridotitos": "peridotito",
    "peridotos": "peridoto",
    "peridotosa": "peridotoso",
    "peridotosas": "peridotoso",
    "peridotosos": "peridotoso",
    "peridotítica": "peridotítico",
    "peridotíticas": "peridotítico",
    "peridotíticos": "peridotítico",
    "periecos": "perieco",
    "periencefalites": "periencefalite",
    "periencefalítica": "periencefalítico",
    "periencefalíticas": "periencefalítico",
    "periencefalíticos": "periencefalítico",
    "periencefálica": "periencefálico",
    "periencefálicas": "periencefálico",
    "periencefálicos": "periencefálico",
    "periergias": "periergia",
    "periferias": "periferia",
    "periformes": "periforme",
    "perifrástica": "perifrástico",
    "perifrásticas": "perifrástico",
    "perifrásticos": "perifrástico",
    "periférica": "periférico",
    "periféricas": "periférico",
    "periféricos": "periférico",
    "periga": "perigar",
    "perigada": "perigar",
    "perigadas": "perigar",
    "perigado": "perigar",
    "perigados": "perigar",
    "perigai": "perigar",
    "perigais": "perigar",
    "perigalhos": "perigalho",
    "perigam": "perigar",
    "perigamo": "perigar",
    "perigamos": "perigar",
    "perigando": "perigar",
    "perigara": "perigar",
    "perigaram": "perigar",
    "perigaras": "perigar",
    "perigardes": "perigar",
    "perigarei": "perigar",
    "perigareis": "perigar",
    "perigarem": "perigar",
    "perigaremos": "perigar",
    "perigares": "perigar",
    "perigaria": "perigar",
    "perigariam": "perigar",
    "perigarias": "perigar",
    "perigarmo": "perigar",
    "perigarmos": "perigar",
    "perigará": "perigar",
    "perigarás": "perigar",
    "perigarão": "perigar",
    "perigaríamos": "perigar",
    "perigaríeis": "perigar",
    "perigas": "perigar",
    "perigasse": "perigar",
    "perigassem": "perigar",
    "perigasses": "perigar",
    "perigaste": "perigar",
    "perigastes": "perigar",
    "perigava": "perigar",
    "perigavam": "perigar",
    "perigavas": "perigar",
    "perigeus": "perigeu",
    "periglaciais": "periglacial",
    "periglaciares": "periglaciar",
    "perigo": "perigar",
    "perigos": "perigo",
    "perigosa": "perigoso",
    "perigosas": "perigoso",
    "perigosidades": "perigosidade",
    "perigosos": "perigoso",
    "perigosíssima": "perigoso",
    "perigosíssimas": "perigoso",
    "perigosíssimo": "perigoso",
    "perigosíssimos": "perigoso",
    "perigou": "perigar",
    "perigue": "perigar",
    "periguei": "perigar",
    "perigueis": "perigar",
    "periguem": "perigar",
    "periguemo": "perigar",
    "periguemos": "perigar",
    "perigues": "perigar",
    "perigámo": "perigar",
    "perigámos": "perigar",
    "perigáramo": "perigar",
    "perigáramos": "perigar",
    "perigáreis": "perigar",
    "perigásseis": "perigar",
    "perigássemos": "perigar",
    "perigávamo": "perigar",
    "perigávamos": "perigar",
    "perigáveis": "perigar",
    "perigínica": "perigínico",
    "perigínicas": "perigínico",
    "perigínicos": "perigínico",
    "perilhas": "perilha",
    "perima": "perimir",
    "perimais": "perimir",
    "perimam": "perimir",
    "perimamo": "perimir",
    "perimamos": "perimir",
    "perimas": "perimir",
    "perime": "perimir",
    "perimem": "perimir",
    "perimes": "perimir",
    "perimetrias": "perimetria",
    "perimi": "perimir",
    "perimia": "perimir",
    "perimiam": "perimir",
    "perimias": "perimir",
    "perimida": "perimir",
    "perimidas": "perimir",
    "perimido": "perimir",
    "perimidos": "perimir",
    "perimimo": "perimir",
    "perimimos": "perimir",
    "perimindo": "perimir",
    "perimira": "perimir",
    "perimiram": "perimir",
    "perimiras": "perimir",
    "perimirde": "perimir",
    "perimirdes": "perimir",
    "perimire": "perimir",
    "perimirei": "perimir",
    "perimireis": "perimir",
    "perimirem": "perimir",
    "perimiremos": "perimir",
    "perimires": "perimir",
    "perimiria": "perimir",
    "perimiriam": "perimir",
    "perimirias": "perimir",
    "perimirmo": "perimir",
    "perimirmos": "perimir",
    "perimirá": "perimir",
    "perimirás": "perimir",
    "perimirão": "perimir",
    "perimiríamos": "perimir",
    "perimiríeis": "perimir",
    "perimis": "perimir",
    "perimisse": "perimir",
    "perimissem": "perimir",
    "perimisses": "perimir",
    "perimiste": "perimir",
    "perimistes": "perimir",
    "perimiu": "perimir",
    "perimo": "perimir",
    "perimorfoses": "perimorfose",
    "perimorfósica": "perimorfósico",
    "perimorfósicas": "perimorfósico",
    "perimorfósicos": "perimorfósico",
    "perimorfótica": "perimorfótico",
    "perimorfóticas": "perimorfótico",
    "perimorfóticos": "perimorfótico",
    "perimétrica": "perimétrico",
    "perimétricas": "perimétrico",
    "perimétricos": "perimétrico",
    "perimíamo": "perimir",
    "perimíamos": "perimir",
    "perimíei": "perimir",
    "perimíeis": "perimir",
    "perimíramo": "perimir",
    "perimíramos": "perimir",
    "perimírei": "perimir",
    "perimíreis": "perimir",
    "perimísios": "perimísio",
    "perimísseis": "perimir",
    "perimíssemos": "perimir",
    "perinatais": "perinatal",
    "perineais": "perineal",
    "perineus": "perineu",
    "perinha": "pêra",
    "perinhas": "pêra",
    "periodais": "periodal",
    "periodatos": "periodato",
    "periodicais": "periodical",
    "periodicidades": "periodicidade",
    "periodicistas": "periodicista",
    "periodiqueira": "periodiqueiro",
    "periodiqueiras": "periodiqueiro",
    "periodiqueiros": "periodiqueiro",
    "periodiquistas": "periodiquista",
    "periodismos": "periodismo",
    "periodistas": "periodista",
    "periodiza": "periodizar",
    "periodizada": "periodizar",
    "periodizadas": "periodizar",
    "periodizado": "periodizar",
    "periodizados": "periodizar",
    "periodizai": "periodizar",
    "periodizais": "periodizar",
    "periodizam": "periodizar",
    "periodizamo": "periodizar",
    "periodizamos": "periodizar",
    "periodizando": "periodizar",
    "periodizara": "periodizar",
    "periodizaram": "periodizar",
    "periodizaras": "periodizar",
    "periodizarde": "periodizar",
    "periodizardes": "periodizar",
    "periodizare": "periodizar",
    "periodizarei": "periodizar",
    "periodizareis": "periodizar",
    "periodizarem": "periodizar",
    "periodizaremos": "periodizar",
    "periodizares": "periodizar",
    "periodizaria": "periodizar",
    "periodizariam": "periodizar",
    "periodizarias": "periodizar",
    "periodizarmo": "periodizar",
    "periodizarmos": "periodizar",
    "periodizará": "periodizar",
    "periodizarás": "periodizar",
    "periodizarão": "periodizar",
    "periodizaríamos": "periodizar",
    "periodizaríeis": "periodizar",
    "periodizas": "periodizar",
    "periodizasse": "periodizar",
    "periodizassem": "periodizar",
    "periodizasses": "periodizar",
    "periodizaste": "periodizar",
    "periodizastes": "periodizar",
    "periodizava": "periodizar",
    "periodizavam": "periodizar",
    "periodizavas": "periodizar",
    "periodizações": "periodização",
    "periodize": "periodizar",
    "periodizei": "periodizar",
    "periodizeis": "periodizar",
    "periodizem": "periodizar",
    "periodizemo": "periodizar",
    "periodizemos": "periodizar",
    "periodizes": "periodizar",
    "periodizo": "periodizar",
    "periodizou": "periodizar",
    "periodizá": "periodizar",
    "periodizámo": "periodizar",
    "periodizámos": "periodizar",
    "periodizáramo": "periodizar",
    "periodizáramos": "periodizar",
    "periodizárei": "periodizar",
    "periodizáreis": "periodizar",
    "periodizásseis": "periodizar",
    "periodizássemos": "periodizar",
    "periodizávamo": "periodizar",
    "periodizávamos": "periodizar",
    "periodizávei": "periodizar",
    "periodizáveis": "periodizar",
    "perioftalmias": "perioftalmia",
    "perioftálmica": "perioftálmico",
    "perioftálmicas": "perioftálmico",
    "perioftálmicos": "perioftálmico",
    "periostais": "periostal",
    "periosteais": "periosteal",
    "periostegenésica": "periostegenésico",
    "periostegenésicas": "periostegenésico",
    "periostegenésicos": "periostegenésico",
    "periostegenética": "periostegenético",
    "periostegenéticas": "periostegenético",
    "periostegenéticos": "periostegenético",
    "periostegénica": "periostegénico",
    "periostegénicas": "periostegénico",
    "periostegénicos": "periostegénico",
    "periosteogéneses": "periosteogénese",
    "periosteítes": "periosteíte",
    "periosteítica": "periosteítico",
    "periosteíticas": "periosteítico",
    "periosteíticos": "periosteítico",
    "periostites": "periostite",
    "periostítica": "periostítico",
    "periostíticas": "periostítico",
    "periostíticos": "periostítico",
    "peripatetismos": "peripatetismo",
    "peripatetiza": "peripatetizar",
    "peripatetizada": "peripatetizar",
    "peripatetizadas": "peripatetizar",
    "peripatetizado": "peripatetizar",
    "peripatetizados": "peripatetizar",
    "peripatetizai": "peripatetizar",
    "peripatetizais": "peripatetizar",
    "peripatetizam": "peripatetizar",
    "peripatetizamo": "peripatetizar",
    "peripatetizamos": "peripatetizar",
    "peripatetizando": "peripatetizar",
    "peripatetizara": "peripatetizar",
    "peripatetizaram": "peripatetizar",
    "peripatetizaras": "peripatetizar",
    "peripatetizardes": "peripatetizar",
    "peripatetizarei": "peripatetizar",
    "peripatetizareis": "peripatetizar",
    "peripatetizarem": "peripatetizar",
    "peripatetizaremos": "peripatetizar",
    "peripatetizares": "peripatetizar",
    "peripatetizaria": "peripatetizar",
    "peripatetizariam": "peripatetizar",
    "peripatetizarias": "peripatetizar",
    "peripatetizarmo": "peripatetizar",
    "peripatetizarmos": "peripatetizar",
    "peripatetizará": "peripatetizar",
    "peripatetizarás": "peripatetizar",
    "peripatetizarão": "peripatetizar",
    "peripatetizaríamos": "peripatetizar",
    "peripatetizaríeis": "peripatetizar",
    "peripatetizas": "peripatetizar",
    "peripatetizasse": "peripatetizar",
    "peripatetizassem": "peripatetizar",
    "peripatetizasses": "peripatetizar",
    "peripatetizaste": "peripatetizar",
    "peripatetizastes": "peripatetizar",
    "peripatetizava": "peripatetizar",
    "peripatetizavam": "peripatetizar",
    "peripatetizavas": "peripatetizar",
    "peripatetize": "peripatetizar",
    "peripatetizei": "peripatetizar",
    "peripatetizeis": "peripatetizar",
    "peripatetizem": "peripatetizar",
    "peripatetizemo": "peripatetizar",
    "peripatetizemos": "peripatetizar",
    "peripatetizes": "peripatetizar",
    "peripatetizo": "peripatetizar",
    "peripatetizou": "peripatetizar",
    "peripatetizámo": "peripatetizar",
    "peripatetizámos": "peripatetizar",
    "peripatetizáramo": "peripatetizar",
    "peripatetizáramos": "peripatetizar",
    "peripatetizáreis": "peripatetizar",
    "peripatetizásseis": "peripatetizar",
    "peripatetizássemos": "peripatetizar",
    "peripatetizávamo": "peripatetizar",
    "peripatetizávamos": "peripatetizar",
    "peripatetizáveis": "peripatetizar",
    "peripatética": "peripatético",
    "peripatéticas": "peripatético",
    "peripatéticos": "peripatético",
    "peripneumonias": "peripneumonia",
    "peripneumónica": "peripneumónico",
    "peripneumónicas": "peripneumónico",
    "peripneumónicos": "peripneumónico",
    "periprocta": "periprocto",
    "periproctais": "periproctal",
    "periproctas": "periprocto",
    "periproctites": "periproctite",
    "periproctos": "periprocto",
    "periptéria": "periptério",
    "periptérias": "periptério",
    "periptérios": "periptério",
    "peripécias": "peripécia",
    "peripétala": "peripétalo",
    "peripétalas": "peripétalo",
    "peripétalos": "peripétalo",
    "periquita": "periquito",
    "periquitas": "periquito",
    "periquitos": "periquito",
    "periscópica": "periscópico",
    "periscópicas": "periscópico",
    "periscópicos": "periscópico",
    "periscópios": "periscópio",
    "perispermas": "perisperma",
    "perispérmica": "perispérmico",
    "perispérmicas": "perispérmico",
    "perispérmicos": "perispérmico",
    "perissarcos": "perissarco",
    "perissodáctila": "perissodáctilo",
    "perissodáctilas": "perissodáctilo",
    "perissodáctilos": "perissodáctilo",
    "perissologias": "perissologia",
    "perissárquica": "perissárquico",
    "perissárquicas": "perissárquico",
    "perissárquicos": "perissárquico",
    "peristaltismos": "peristaltismo",
    "peristerídeos": "peristerídeo",
    "peristilos": "peristilo",
    "peristáltica": "peristáltico",
    "peristálticas": "peristáltico",
    "peristálticos": "peristáltico",
    "peristásica": "peristásico",
    "peristásicas": "peristásico",
    "peristásicos": "peristásico",
    "peristéridas": "peristérida",
    "peristílica": "peristílico",
    "peristílicas": "peristílico",
    "peristílicos": "peristílico",
    "peristómica": "peristómico",
    "peristómicas": "peristómico",
    "peristómicos": "peristómico",
    "perita": "perito",
    "peritagens": "peritagem",
    "peritais": "perital",
    "peritas": "perito",
    "peritoneais": "peritoneal",
    "peritoneia": "peritoneu",
    "peritoneias": "peritoneu",
    "peritoneus": "peritoneu",
    "peritonites": "peritonite",
    "peritos": "perito",
    "peritónios": "peritónio",
    "periâmbica": "periâmbico",
    "periâmbicas": "periâmbico",
    "periâmbicos": "periâmbico",
    "periândrica": "periândrico",
    "periândricas": "periândrico",
    "periândricos": "periândrico",
    "periântios": "periântio",
    "periélica": "periélico",
    "periélicas": "periélico",
    "periélicos": "periélico",
    "periélios": "periélio",
    "periérgica": "periérgico",
    "periérgicas": "periérgico",
    "periérgicos": "periérgico",
    "periódica": "periódico",
    "periódicas": "periódico",
    "periódicos": "periódico",
    "periósteos": "periósteo",
    "perióstracos": "perióstraco",
    "perjura": "perjuro",
    "perjurada": "perjurar",
    "perjuradas": "perjurar",
    "perjurado": "perjurar",
    "perjurados": "perjurar",
    "perjurai": "perjurar",
    "perjurais": "perjurar",
    "perjuram": "perjurar",
    "perjuramo": "perjurar",
    "perjuramos": "perjurar",
    "perjurando": "perjurar",
    "perjurara": "perjurar",
    "perjuraram": "perjurar",
    "perjuraras": "perjurar",
    "perjurarde": "perjurar",
    "perjurardes": "perjurar",
    "perjurare": "perjurar",
    "perjurarei": "perjurar",
    "perjurareis": "perjurar",
    "perjurarem": "perjurar",
    "perjuraremos": "perjurar",
    "perjurares": "perjurar",
    "perjuraria": "perjurar",
    "perjurariam": "perjurar",
    "perjurarias": "perjurar",
    "perjurarmo": "perjurar",
    "perjurarmos": "perjurar",
    "perjurará": "perjurar",
    "perjurarás": "perjurar",
    "perjurarão": "perjurar",
    "perjuraríamos": "perjurar",
    "perjuraríeis": "perjurar",
    "perjuras": "perjuro",
    "perjurasse": "perjurar",
    "perjurassem": "perjurar",
    "perjurasses": "perjurar",
    "perjuraste": "perjurar",
    "perjurastes": "perjurar",
    "perjurava": "perjurar",
    "perjuravam": "perjurar",
    "perjuravas": "perjurar",
    "perjure": "perjurar",
    "perjurei": "perjurar",
    "perjureis": "perjurar",
    "perjurem": "perjurar",
    "perjuremo": "perjurar",
    "perjuremos": "perjurar",
    "perjures": "perjurar",
    "perjuro": "perjurar",
    "perjuros": "perjuro",
    "perjurou": "perjurar",
    "perjurá": "perjurar",
    "perjurámo": "perjurar",
    "perjurámos": "perjurar",
    "perjuráramo": "perjurar",
    "perjuráramos": "perjurar",
    "perjurárei": "perjurar",
    "perjuráreis": "perjurar",
    "perjurásseis": "perjurar",
    "perjurássemos": "perjurar",
    "perjurávamo": "perjurar",
    "perjurávamos": "perjurar",
    "perjurávei": "perjurar",
    "perjuráveis": "perjurar",
    "perjúrios": "perjúrio",
    "perla": "perlar",
    "perlada": "perlar",
    "perladas": "perlar",
    "perlado": "perlar",
    "perlados": "perlar",
    "perlai": "perlar",
    "perlais": "perlar",
    "perlam": "perlar",
    "perlamo": "perlar",
    "perlamos": "perlar",
    "perlando": "perlar",
    "perlara": "perlar",
    "perlaram": "perlar",
    "perlaras": "perlar",
    "perlarde": "perlar",
    "perlardes": "perlar",
    "perlare": "perlar",
    "perlarei": "perlar",
    "perlareis": "perlar",
    "perlarem": "perlar",
    "perlaremos": "perlar",
    "perlares": "perlar",
    "perlaria": "perlar",
    "perlariam": "perlar",
    "perlarias": "perlar",
    "perlarmo": "perlar",
    "perlarmos": "perlar",
    "perlará": "perlar",
    "perlarás": "perlar",
    "perlarão": "perlar",
    "perlaríamos": "perlar",
    "perlaríeis": "perlar",
    "perlas": "perlar",
    "perlassa": "perlasso",
    "perlassas": "perlasso",
    "perlasse": "perlar",
    "perlassem": "perlar",
    "perlasses": "perlar",
    "perlassos": "perlasso",
    "perlaste": "perlar",
    "perlastes": "perlar",
    "perlava": "perlavar",
    "perlavada": "perlavar",
    "perlavadas": "perlavar",
    "perlavado": "perlavar",
    "perlavados": "perlavar",
    "perlavai": "perlavar",
    "perlavais": "perlavar",
    "perlavam": "perlavar",
    "perlavamo": "perlavar",
    "perlavamos": "perlavar",
    "perlavando": "perlavar",
    "perlavara": "perlavar",
    "perlavaram": "perlavar",
    "perlavaras": "perlavar",
    "perlavarde": "perlavar",
    "perlavardes": "perlavar",
    "perlavare": "perlavar",
    "perlavarei": "perlavar",
    "perlavareis": "perlavar",
    "perlavarem": "perlavar",
    "perlavaremos": "perlavar",
    "perlavares": "perlavar",
    "perlavaria": "perlavar",
    "perlavariam": "perlavar",
    "perlavarias": "perlavar",
    "perlavarmo": "perlavar",
    "perlavarmos": "perlavar",
    "perlavará": "perlavar",
    "perlavarás": "perlavar",
    "perlavarão": "perlavar",
    "perlavaríamos": "perlavar",
    "perlavaríeis": "perlavar",
    "perlavas": "perlavar",
    "perlavasse": "perlavar",
    "perlavassem": "perlavar",
    "perlavasses": "perlavar",
    "perlavaste": "perlavar",
    "perlavastes": "perlavar",
    "perlavava": "perlavar",
    "perlavavam": "perlavar",
    "perlavavas": "perlavar",
    "perlave": "perlavar",
    "perlavei": "perlavar",
    "perlaveis": "perlavar",
    "perlavem": "perlavar",
    "perlavemo": "perlavar",
    "perlavemos": "perlavar",
    "perlaves": "perlavar",
    "perlavo": "perlavar",
    "perlavou": "perlavar",
    "perlavá": "perlavar",
    "perlavámo": "perlavar",
    "perlavámos": "perlavar",
    "perlaváramo": "perlavar",
    "perlaváramos": "perlavar",
    "perlavárei": "perlavar",
    "perlaváreis": "perlavar",
    "perlavásseis": "perlavar",
    "perlavássemos": "perlavar",
    "perlavávamo": "perlavar",
    "perlavávamos": "perlavar",
    "perlavávei": "perlavar",
    "perlaváveis": "perlavar",
    "perle": "perlar",
    "perlei": "perlar",
    "perleis": "perlar",
    "perlem": "perlar",
    "perlemo": "perlar",
    "perlemos": "perlar",
    "perlendas": "perlenda",
    "perlengadas": "perlengada",
    "perlengas": "perlenga",
    "perles": "perlar",
    "perleúda": "perleúdo",
    "perleúdas": "perleúdo",
    "perleúdos": "perleúdo",
    "perlimpimpins": "perlimpimpim",
    "perlinfas": "perlinfa",
    "perliquiteta": "perliquiteto",
    "perliquitetas": "perliquiteto",
    "perliquitetos": "perliquiteto",
    "perlo": "perlar",
    "perlonga": "perlongar",
    "perlongada": "perlongar",
    "perlongadas": "perlongar",
    "perlongado": "perlongar",
    "perlongados": "perlongar",
    "perlongai": "perlongar",
    "perlongais": "perlongar",
    "perlongam": "perlongar",
    "perlongamo": "perlongar",
    "perlongamos": "perlongar",
    "perlongando": "perlongar",
    "perlongara": "perlongar",
    "perlongaram": "perlongar",
    "perlongaras": "perlongar",
    "perlongarde": "perlongar",
    "perlongardes": "perlongar",
    "perlongare": "perlongar",
    "perlongarei": "perlongar",
    "perlongareis": "perlongar",
    "perlongarem": "perlongar",
    "perlongaremos": "perlongar",
    "perlongares": "perlongar",
    "perlongaria": "perlongar",
    "perlongariam": "perlongar",
    "perlongarias": "perlongar",
    "perlongarmo": "perlongar",
    "perlongarmos": "perlongar",
    "perlongará": "perlongar",
    "perlongarás": "perlongar",
    "perlongarão": "perlongar",
    "perlongaríamos": "perlongar",
    "perlongaríeis": "perlongar",
    "perlongas": "perlongar",
    "perlongasse": "perlongar",
    "perlongassem": "perlongar",
    "perlongasses": "perlongar",
    "perlongaste": "perlongar",
    "perlongastes": "perlongar",
    "perlongava": "perlongar",
    "perlongavam": "perlongar",
    "perlongavas": "perlongar",
    "perlongo": "perlongar",
    "perlongou": "perlongar",
    "perlongue": "perlongar",
    "perlonguei": "perlongar",
    "perlongueis": "perlongar",
    "perlonguem": "perlongar",
    "perlonguemo": "perlongar",
    "perlonguemos": "perlongar",
    "perlongues": "perlongar",
    "perlongá": "perlongar",
    "perlongámo": "perlongar",
    "perlongámos": "perlongar",
    "perlongáramo": "perlongar",
    "perlongáramos": "perlongar",
    "perlongárei": "perlongar",
    "perlongáreis": "perlongar",
    "perlongásseis": "perlongar",
    "perlongássemos": "perlongar",
    "perlongávamo": "perlongar",
    "perlongávamos": "perlongar",
    "perlongávei": "perlongar",
    "perlongáveis": "perlongável",
    "perlou": "perlar",
    "perlustra": "perlustrar",
    "perlustrada": "perlustrar",
    "perlustradas": "perlustrar",
    "perlustrado": "perlustrar",
    "perlustradora": "perlustrador",
    "perlustradoras": "perlustrador",
    "perlustradores": "perlustrador",
    "perlustrados": "perlustrar",
    "perlustrai": "perlustrar",
    "perlustrais": "perlustrar",
    "perlustram": "perlustrar",
    "perlustramo": "perlustrar",
    "perlustramos": "perlustrar",
    "perlustrando": "perlustrar",
    "perlustrara": "perlustrar",
    "perlustraram": "perlustrar",
    "perlustraras": "perlustrar",
    "perlustrarde": "perlustrar",
    "perlustrardes": "perlustrar",
    "perlustrare": "perlustrar",
    "perlustrarei": "perlustrar",
    "perlustrareis": "perlustrar",
    "perlustrarem": "perlustrar",
    "perlustraremos": "perlustrar",
    "perlustrares": "perlustrar",
    "perlustraria": "perlustrar",
    "perlustrariam": "perlustrar",
    "perlustrarias": "perlustrar",
    "perlustrarmo": "perlustrar",
    "perlustrarmos": "perlustrar",
    "perlustrará": "perlustrar",
    "perlustrarás": "perlustrar",
    "perlustrarão": "perlustrar",
    "perlustraríamos": "perlustrar",
    "perlustraríeis": "perlustrar",
    "perlustras": "perlustrar",
    "perlustrasse": "perlustrar",
    "perlustrassem": "perlustrar",
    "perlustrasses": "perlustrar",
    "perlustraste": "perlustrar",
    "perlustrastes": "perlustrar",
    "perlustrava": "perlustrar",
    "perlustravam": "perlustrar",
    "perlustravas": "perlustrar",
    "perlustrações": "perlustração",
    "perlustre": "perlustrar",
    "perlustrei": "perlustrar",
    "perlustreis": "perlustrar",
    "perlustrem": "perlustrar",
    "perlustremo": "perlustrar",
    "perlustremos": "perlustrar",
    "perlustres": "perlustrar",
    "perlustro": "perlustrar",
    "perlustrou": "perlustrar",
    "perlustrá": "perlustrar",
    "perlustrámo": "perlustrar",
    "perlustrámos": "perlustrar",
    "perlustráramo": "perlustrar",
    "perlustráramos": "perlustrar",
    "perlustrárei": "perlustrar",
    "perlustráreis": "perlustrar",
    "perlustrásseis": "perlustrar",
    "perlustrássemos": "perlustrar",
    "perlustrávamo": "perlustrar",
    "perlustrávamos": "perlustrar",
    "perlustrávei": "perlustrar",
    "perlustráveis": "perlustrar",
    "perluxa": "perluxo",
    "perluxas": "perluxo",
    "perluxos": "perluxo",
    "perluxosa": "perluxoso",
    "perluxosas": "perluxoso",
    "perluxosos": "perluxoso",
    "perlá": "perlar",
    "perlámo": "perlar",
    "perlámos": "perlar",
    "perláramo": "perlar",
    "perláramos": "perlar",
    "perlárei": "perlar",
    "perláreis": "perlar",
    "perlásseis": "perlar",
    "perlássemos": "perlar",
    "perlávamo": "perlar",
    "perlávamos": "perlar",
    "perlávei": "perlar",
    "perláveis": "perlar",
    "perlífera": "perlífero",
    "perlíferas": "perlífero",
    "perlíferos": "perlífero",
    "permanece": "permanecer",
    "permanecei": "permanecer",
    "permaneceis": "permanecer",
    "permanecem": "permanecer",
    "permanecemo": "permanecer",
    "permanecemos": "permanecer",
    "permanecendo": "permanecer",
    "permanecentes": "permanecente",
    "permanecera": "permanecer",
    "permaneceram": "permanecer",
    "permaneceras": "permanecer",
    "permanecerdes": "permanecer",
    "permanecerei": "permanecer",
    "permanecereis": "permanecer",
    "permanecerem": "permanecer",
    "permaneceremos": "permanecer",
    "permaneceres": "permanecer",
    "permaneceria": "permanecer",
    "permaneceriam": "permanecer",
    "permanecerias": "permanecer",
    "permanecermo": "permanecer",
    "permanecermos": "permanecer",
    "permanecerá": "permanecer",
    "permanecerás": "permanecer",
    "permanecerão": "permanecer",
    "permaneceríamos": "permanecer",
    "permaneceríeis": "permanecer",
    "permaneces": "permanecer",
    "permanecesse": "permanecer",
    "permanecessem": "permanecer",
    "permanecesses": "permanecer",
    "permaneceste": "permanecer",
    "permanecestes": "permanecer",
    "permaneceu": "permanecer",
    "permaneci": "permanecer",
    "permanecia": "permanecer",
    "permaneciam": "permanecer",
    "permanecias": "permanecer",
    "permanecida": "permanecer",
    "permanecidas": "permanecer",
    "permanecido": "permanecer",
    "permanecidos": "permanecer",
    "permanecêramo": "permanecer",
    "permanecêramos": "permanecer",
    "permanecêreis": "permanecer",
    "permanecêsseis": "permanecer",
    "permanecêssemos": "permanecer",
    "permanecíamo": "permanecer",
    "permanecíamos": "permanecer",
    "permanecíeis": "permanecer",
    "permanentes": "permanente",
    "permaneça": "permanecer",
    "permaneçais": "permanecer",
    "permaneçam": "permanecer",
    "permaneçamo": "permanecer",
    "permaneçamos": "permanecer",
    "permaneças": "permanecer",
    "permaneço": "permanecer",
    "permanganatos": "permanganato",
    "permanganiza": "permanganizar",
    "permanganizada": "permanganizar",
    "permanganizadas": "permanganizar",
    "permanganizado": "permanganizar",
    "permanganizados": "permanganizar",
    "permanganizai": "permanganizar",
    "permanganizais": "permanganizar",
    "permanganizam": "permanganizar",
    "permanganizamo": "permanganizar",
    "permanganizamos": "permanganizar",
    "permanganizando": "permanganizar",
    "permanganizara": "permanganizar",
    "permanganizaram": "permanganizar",
    "permanganizaras": "permanganizar",
    "permanganizarde": "permanganizar",
    "permanganizardes": "permanganizar",
    "permanganizare": "permanganizar",
    "permanganizarei": "permanganizar",
    "permanganizareis": "permanganizar",
    "permanganizarem": "permanganizar",
    "permanganizaremos": "permanganizar",
    "permanganizares": "permanganizar",
    "permanganizaria": "permanganizar",
    "permanganizariam": "permanganizar",
    "permanganizarias": "permanganizar",
    "permanganizarmo": "permanganizar",
    "permanganizarmos": "permanganizar",
    "permanganizará": "permanganizar",
    "permanganizarás": "permanganizar",
    "permanganizarão": "permanganizar",
    "permanganizaríamos": "permanganizar",
    "permanganizaríeis": "permanganizar",
    "permanganizas": "permanganizar",
    "permanganizasse": "permanganizar",
    "permanganizassem": "permanganizar",
    "permanganizasses": "permanganizar",
    "permanganizaste": "permanganizar",
    "permanganizastes": "permanganizar",
    "permanganizava": "permanganizar",
    "permanganizavam": "permanganizar",
    "permanganizavas": "permanganizar",
    "permanganizações": "permanganização",
    "permanganize": "permanganizar",
    "permanganizei": "permanganizar",
    "permanganizeis": "permanganizar",
    "permanganizem": "permanganizar",
    "permanganizemo": "permanganizar",
    "permanganizemos": "permanganizar",
    "permanganizes": "permanganizar",
    "permanganizo": "permanganizar",
    "permanganizou": "permanganizar",
    "permanganizá": "permanganizar",
    "permanganizámo": "permanganizar",
    "permanganizámos": "permanganizar",
    "permanganizáramo": "permanganizar",
    "permanganizáramos": "permanganizar",
    "permanganizárei": "permanganizar",
    "permanganizáreis": "permanganizar",
    "permanganizásseis": "permanganizar",
    "permanganizássemos": "permanganizar",
    "permanganizávamo": "permanganizar",
    "permanganizávamos": "permanganizar",
    "permanganizávei": "permanganizar",
    "permanganizáveis": "permanganizar",
    "permangânica": "permangânico",
    "permangânicas": "permangânico",
    "permangânicos": "permangânico",
    "permanências": "permanência",
    "permeabilidades": "permeabilidade",
    "permeabiliza": "permeabilizar",
    "permeabilizada": "permeabilizar",
    "permeabilizadas": "permeabilizar",
    "permeabilizado": "permeabilizar",
    "permeabilizados": "permeabilizar",
    "permeabilizai": "permeabilizar",
    "permeabilizais": "permeabilizar",
    "permeabilizam": "permeabilizar",
    "permeabilizamo": "permeabilizar",
    "permeabilizamos": "permeabilizar",
    "permeabilizando": "permeabilizar",
    "permeabilizara": "permeabilizar",
    "permeabilizaram": "permeabilizar",
    "permeabilizaras": "permeabilizar",
    "permeabilizarde": "permeabilizar",
    "permeabilizardes": "permeabilizar",
    "permeabilizare": "permeabilizar",
    "permeabilizarei": "permeabilizar",
    "permeabilizareis": "permeabilizar",
    "permeabilizarem": "permeabilizar",
    "permeabilizaremos": "permeabilizar",
    "permeabilizares": "permeabilizar",
    "permeabilizaria": "permeabilizar",
    "permeabilizariam": "permeabilizar",
    "permeabilizarias": "permeabilizar",
    "permeabilizarmo": "permeabilizar",
    "permeabilizarmos": "permeabilizar",
    "permeabilizará": "permeabilizar",
    "permeabilizarás": "permeabilizar",
    "permeabilizarão": "permeabilizar",
    "permeabilizaríamos": "permeabilizar",
    "permeabilizaríeis": "permeabilizar",
    "permeabilizas": "permeabilizar",
    "permeabilizasse": "permeabilizar",
    "permeabilizassem": "permeabilizar",
    "permeabilizasses": "permeabilizar",
    "permeabilizaste": "permeabilizar",
    "permeabilizastes": "permeabilizar",
    "permeabilizava": "permeabilizar",
    "permeabilizavam": "permeabilizar",
    "permeabilizavas": "permeabilizar",
    "permeabilizações": "permeabilização",
    "permeabilize": "permeabilizar",
    "permeabilizei": "permeabilizar",
    "permeabilizeis": "permeabilizar",
    "permeabilizem": "permeabilizar",
    "permeabilizemo": "permeabilizar",
    "permeabilizemos": "permeabilizar",
    "permeabilizes": "permeabilizar",
    "permeabilizo": "permeabilizar",
    "permeabilizou": "permeabilizar",
    "permeabilizá": "permeabilizar",
    "permeabilizámo": "permeabilizar",
    "permeabilizámos": "permeabilizar",
    "permeabilizáramo": "permeabilizar",
    "permeabilizáramos": "permeabilizar",
    "permeabilizárei": "permeabilizar",
    "permeabilizáreis": "permeabilizar",
    "permeabilizásseis": "permeabilizar",
    "permeabilizássemos": "permeabilizar",
    "permeabilizávamo": "permeabilizar",
    "permeabilizávamos": "permeabilizar",
    "permeabilizávei": "permeabilizar",
    "permeabilizáveis": "permeabilizar",
    "permeabilíssima": "permeável",
    "permeabilíssimas": "permeável",
    "permeabilíssimo": "permeável",
    "permeabilíssimos": "permeável",
    "permeada": "permear",
    "permeadas": "permear",
    "permeado": "permear",
    "permeados": "permear",
    "permeai": "permear",
    "permeais": "permear",
    "permeamo": "permear",
    "permeamos": "permear",
    "permeando": "permear",
    "permeara": "permear",
    "permearam": "permear",
    "permearas": "permear",
    "permearde": "permear",
    "permeardes": "permear",
    "permeare": "permear",
    "permearei": "permear",
    "permeareis": "permear",
    "permearem": "permear",
    "permearemos": "permear",
    "permeares": "permear",
    "permearia": "permear",
    "permeariam": "permear",
    "permearias": "permear",
    "permearmo": "permear",
    "permearmos": "permear",
    "permeará": "permear",
    "permearás": "permear",
    "permearão": "permear",
    "permearíamos": "permear",
    "permearíeis": "permear",
    "permeasse": "permear",
    "permeassem": "permear",
    "permeasses": "permear",
    "permeaste": "permear",
    "permeastes": "permear",
    "permeava": "permear",
    "permeavam": "permear",
    "permeavas": "permear",
    "permeações": "permeação",
    "permeei": "permear",
    "permeeis": "permear",
    "permeemo": "permear",
    "permeemos": "permear",
    "permeia": "permear",
    "permeiam": "permear",
    "permeias": "permear",
    "permeie": "permear",
    "permeiem": "permear",
    "permeies": "permear",
    "permeio": "permear",
    "permeou": "permear",
    "permeá": "permear",
    "permeámo": "permear",
    "permeámos": "permear",
    "permeáramo": "permear",
    "permeáramos": "permear",
    "permeárei": "permear",
    "permeáreis": "permear",
    "permeásseis": "permear",
    "permeássemos": "permear",
    "permeávamo": "permear",
    "permeávamos": "permear",
    "permeávei": "permear",
    "permeáveis": "permeável",
    "permeâmetros": "permeâmetro",
    "permeâncias": "permeância",
    "permilagens": "permilagem",
    "permissibilidades": "permissibilidade",
    "permissiva": "permissivo",
    "permissivas": "permissivo",
    "permissividades": "permissividade",
    "permissivos": "permissivo",
    "permissora": "permissor",
    "permissoras": "permissor",
    "permissores": "permissor",
    "permissíveis": "permissível",
    "permissória": "permissório",
    "permissórias": "permissório",
    "permissórios": "permissório",
    "permissões": "permissão",
    "permista": "permisto",
    "permistas": "permisto",
    "permistos": "permisto",
    "permita": "permitir",
    "permitais": "permitir",
    "permitam": "permitir",
    "permitamo": "permitir",
    "permitamos": "permitir",
    "permitas": "permitir",
    "permite": "permitir",
    "permitem": "permitir",
    "permites": "permitir",
    "permiti": "permitir",
    "permitia": "permitir",
    "permitiam": "permitir",
    "permitias": "permitir",
    "permitida": "permitir",
    "permitidas": "permitir",
    "permitido": "permitir",
    "permitidos": "permitir",
    "permitimo": "permitir",
    "permitimos": "permitir",
    "permitindo": "permitir",
    "permitira": "permitir",
    "permitiram": "permitir",
    "permitiras": "permitir",
    "permitirde": "permitir",
    "permitirdes": "permitir",
    "permitire": "permitir",
    "permitirei": "permitir",
    "permitireis": "permitir",
    "permitirem": "permitir",
    "permitiremos": "permitir",
    "permitires": "permitir",
    "permitiria": "permitir",
    "permitiriam": "permitir",
    "permitirias": "permitir",
    "permitirmo": "permitir",
    "permitirmos": "permitir",
    "permitirá": "permitir",
    "permitirás": "permitir",
    "permitirão": "permitir",
    "permitiríamos": "permitir",
    "permitiríeis": "permitir",
    "permitis": "permitir",
    "permitisse": "permitir",
    "permitissem": "permitir",
    "permitisses": "permitir",
    "permitiste": "permitir",
    "permitistes": "permitir",
    "permitiu": "permitir",
    "permitiva": "permitivo",
    "permitivas": "permitivo",
    "permitividades": "permitividade",
    "permitivos": "permitivo",
    "permito": "permitir",
    "permitíamo": "permitir",
    "permitíamos": "permitir",
    "permitíei": "permitir",
    "permitíeis": "permitir",
    "permitíramo": "permitir",
    "permitíramos": "permitir",
    "permitírei": "permitir",
    "permitíreis": "permitir",
    "permitísseis": "permitir",
    "permitíssemos": "permitir",
    "permocarbónica": "permocarbónico",
    "permocarbónicas": "permocarbónico",
    "permocarbónicos": "permocarbónico",
    "permuta": "permutar",
    "permutabilidades": "permutabilidade",
    "permutada": "permutar",
    "permutadas": "permutar",
    "permutado": "permutar",
    "permutadora": "permutador",
    "permutadoras": "permutador",
    "permutadores": "permutador",
    "permutados": "permutar",
    "permutai": "permutar",
    "permutais": "permutar",
    "permutam": "permutar",
    "permutamo": "permutar",
    "permutamos": "permutar",
    "permutando": "permutar",
    "permutara": "permutar",
    "permutaram": "permutar",
    "permutaras": "permutar",
    "permutarde": "permutar",
    "permutardes": "permutar",
    "permutare": "permutar",
    "permutarei": "permutar",
    "permutareis": "permutar",
    "permutarem": "permutar",
    "permutaremos": "permutar",
    "permutares": "permutar",
    "permutaria": "permutar",
    "permutariam": "permutar",
    "permutarias": "permutar",
    "permutarmo": "permutar",
    "permutarmos": "permutar",
    "permutará": "permutar",
    "permutarás": "permutar",
    "permutarão": "permutar",
    "permutaríamos": "permutar",
    "permutaríeis": "permutar",
    "permutas": "permutar",
    "permutasse": "permutar",
    "permutassem": "permutar",
    "permutasses": "permutar",
    "permutaste": "permutar",
    "permutastes": "permutar",
    "permutava": "permutar",
    "permutavam": "permutar",
    "permutavas": "permutar",
    "permutações": "permutação",
    "permute": "permutar",
    "permutei": "permutar",
    "permuteis": "permutar",
    "permutem": "permutar",
    "permutemo": "permutar",
    "permutemos": "permutar",
    "permutes": "permutar",
    "permuto": "permutar",
    "permutou": "permutar",
    "permutá": "permutar",
    "permutámo": "permutar",
    "permutámos": "permutar",
    "permutáramo": "permutar",
    "permutáramos": "permutar",
    "permutárei": "permutar",
    "permutáreis": "permutar",
    "permutásseis": "permutar",
    "permutássemos": "permutar",
    "permutávamo": "permutar",
    "permutávamos": "permutar",
    "permutávei": "permutar",
    "permutáveis": "permutável",
    "pernadas": "pernada",
    "pernalta": "pernalto",
    "pernaltas": "pernalto",
    "pernaltos": "pernalto",
    "pernambucana": "pernambucano",
    "pernambucanas": "pernambucano",
    "pernambucanos": "pernambucano",
    "pernas": "perna",
    "pernaças": "pernaça",
    "perneada": "pernear",
    "perneadas": "pernear",
    "perneado": "pernear",
    "perneados": "pernear",
    "perneai": "pernear",
    "perneais": "pernear",
    "perneamo": "pernear",
    "perneamos": "pernear",
    "perneando": "pernear",
    "perneara": "pernear",
    "pernearam": "pernear",
    "pernearas": "pernear",
    "perneardes": "pernear",
    "pernearei": "pernear",
    "perneareis": "pernear",
    "pernearem": "pernear",
    "pernearemos": "pernear",
    "perneares": "pernear",
    "pernearia": "pernear",
    "perneariam": "pernear",
    "pernearias": "pernear",
    "pernearmo": "pernear",
    "pernearmos": "pernear",
    "perneará": "pernear",
    "pernearás": "pernear",
    "pernearão": "pernear",
    "pernearíamos": "pernear",
    "pernearíeis": "pernear",
    "perneasse": "pernear",
    "perneassem": "pernear",
    "perneasses": "pernear",
    "perneaste": "pernear",
    "perneastes": "pernear",
    "perneava": "pernear",
    "perneavam": "pernear",
    "perneavas": "pernear",
    "perneei": "pernear",
    "perneeis": "pernear",
    "perneemo": "pernear",
    "perneemos": "pernear",
    "perneguda": "pernegudo",
    "pernegudas": "pernegudo",
    "pernegudos": "pernegudo",
    "perneia": "pernear",
    "perneiam": "pernear",
    "perneias": "pernear",
    "perneie": "pernear",
    "perneiem": "pernear",
    "perneies": "pernear",
    "perneio": "pernear",
    "perneiras": "perneira",
    "perneou": "pernear",
    "pernetas": "perneta",
    "perneámo": "pernear",
    "perneámos": "pernear",
    "perneáramo": "pernear",
    "perneáramos": "pernear",
    "perneáreis": "pernear",
    "perneásseis": "pernear",
    "perneássemos": "pernear",
    "perneávamo": "pernear",
    "perneávamos": "pernear",
    "perneáveis": "pernear",
    "perniciosa": "pernicioso",
    "perniciosas": "pernicioso",
    "perniciosidades": "perniciosidade",
    "perniciosos": "pernicioso",
    "perniciosíssima": "pernicioso",
    "perniciosíssimas": "pernicioso",
    "perniciosíssimo": "pernicioso",
    "perniciosíssimos": "pernicioso",
    "pernicurta": "pernicurto",
    "pernicurtas": "pernicurto",
    "pernicurtos": "pernicurto",
    "pernilonga": "pernilongo",
    "pernilongas": "pernilongo",
    "pernilongos": "pernilongo",
    "perningaus": "perningau",
    "perninha": "perna",
    "perninhas": "perna",
    "pernis": "pernil",
    "pernita": "perna",
    "pernitas": "perna",
    "pernitratos": "pernitrato",
    "pernocas": "pernoca",
    "pernoita": "pernoitar",
    "pernoitada": "pernoitar",
    "pernoitadas": "pernoitar",
    "pernoitado": "pernoitar",
    "pernoitados": "pernoitar",
    "pernoitai": "pernoitar",
    "pernoitais": "pernoitar",
    "pernoitam": "pernoitar",
    "pernoitamentos": "pernoitamento",
    "pernoitamo": "pernoitar",
    "pernoitamos": "pernoitar",
    "pernoitando": "pernoitar",
    "pernoitara": "pernoitar",
    "pernoitaram": "pernoitar",
    "pernoitaras": "pernoitar",
    "pernoitardes": "pernoitar",
    "pernoitarei": "pernoitar",
    "pernoitareis": "pernoitar",
    "pernoitarem": "pernoitar",
    "pernoitaremos": "pernoitar",
    "pernoitares": "pernoitar",
    "pernoitaria": "pernoitar",
    "pernoitariam": "pernoitar",
    "pernoitarias": "pernoitar",
    "pernoitarmo": "pernoitar",
    "pernoitarmos": "pernoitar",
    "pernoitará": "pernoitar",
    "pernoitarás": "pernoitar",
    "pernoitarão": "pernoitar",
    "pernoitaríamos": "pernoitar",
    "pernoitaríeis": "pernoitar",
    "pernoitas": "pernoitar",
    "pernoitasse": "pernoitar",
    "pernoitassem": "pernoitar",
    "pernoitasses": "pernoitar",
    "pernoitaste": "pernoitar",
    "pernoitastes": "pernoitar",
    "pernoitava": "pernoitar",
    "pernoitavam": "pernoitar",
    "pernoitavas": "pernoitar",
    "pernoite": "pernoitar",
    "pernoitei": "pernoitar",
    "pernoiteis": "pernoitar",
    "pernoitem": "pernoitar",
    "pernoitemo": "pernoitar",
    "pernoitemos": "pernoitar",
    "pernoites": "pernoite",
    "pernoito": "pernoitar",
    "pernoitou": "pernoitar",
    "pernoitámo": "pernoitar",
    "pernoitámos": "pernoitar",
    "pernoitáramo": "pernoitar",
    "pernoitáramos": "pernoitar",
    "pernoitáreis": "pernoitar",
    "pernoitásseis": "pernoitar",
    "pernoitássemos": "pernoitar",
    "pernoitávamo": "pernoitar",
    "pernoitávamos": "pernoitar",
    "pernoitáveis": "pernoitar",
    "pernona": "pernão",
    "pernonas": "pernão",
    "pernos": "perno",
    "pernouta": "pernoutar",
    "pernoutada": "pernoutar",
    "pernoutadas": "pernoutar",
    "pernoutado": "pernoutar",
    "pernoutados": "pernoutar",
    "pernoutai": "pernoutar",
    "pernoutais": "pernoutar",
    "pernoutam": "pernoutar",
    "pernoutamo": "pernoutar",
    "pernoutamos": "pernoutar",
    "pernoutando": "pernoutar",
    "pernoutara": "pernoutar",
    "pernoutaram": "pernoutar",
    "pernoutaras": "pernoutar",
    "pernoutardes": "pernoutar",
    "pernoutarei": "pernoutar",
    "pernoutareis": "pernoutar",
    "pernoutarem": "pernoutar",
    "pernoutaremos": "pernoutar",
    "pernoutares": "pernoutar",
    "pernoutaria": "pernoutar",
    "pernoutariam": "pernoutar",
    "pernoutarias": "pernoutar",
    "pernoutarmo": "pernoutar",
    "pernoutarmos": "pernoutar",
    "pernoutará": "pernoutar",
    "pernoutarás": "pernoutar",
    "pernoutarão": "pernoutar",
    "pernoutaríamos": "pernoutar",
    "pernoutaríeis": "pernoutar",
    "pernoutas": "pernoutar",
    "pernoutasse": "pernoutar",
    "pernoutassem": "pernoutar",
    "pernoutasses": "pernoutar",
    "pernoutaste": "pernoutar",
    "pernoutastes": "pernoutar",
    "pernoutava": "pernoutar",
    "pernoutavam": "pernoutar",
    "pernoutavas": "pernoutar",
    "pernoute": "pernoutar",
    "pernoutei": "pernoutar",
    "pernouteis": "pernoutar",
    "pernoutem": "pernoutar",
    "pernoutemo": "pernoutar",
    "pernoutemos": "pernoutar",
    "pernoutes": "pernoutar",
    "pernouto": "pernoutar",
    "pernoutou": "pernoutar",
    "pernoutámo": "pernoutar",
    "pernoutámos": "pernoutar",
    "pernoutáramo": "pernoutar",
    "pernoutáramos": "pernoutar",
    "pernoutáreis": "pernoutar",
    "pernoutásseis": "pernoutar",
    "pernoutássemos": "pernoutar",
    "pernoutávamo": "pernoutar",
    "pernoutávamos": "pernoutar",
    "pernoutáveis": "pernoutar",
    "pernuda": "pernudo",
    "pernudas": "pernudo",
    "pernudos": "pernudo",
    "pernícies": "pernície",
    "pernítrica": "pernítrico",
    "pernítricas": "pernítrico",
    "pernítricos": "pernítrico",
    "pernóstica": "pernóstico",
    "pernósticas": "pernóstico",
    "pernósticos": "pernóstico",
    "pernões": "pernão",
    "perobas": "peroba",
    "perola": "perolar",
    "perolada": "perolar",
    "peroladas": "perolar",
    "perolado": "perolar",
    "perolados": "perolar",
    "perolai": "perolar",
    "perolais": "perolar",
    "perolam": "perolar",
    "perolamo": "perolar",
    "perolamos": "perolar",
    "perolando": "perolar",
    "perolara": "perolar",
    "perolaram": "perolar",
    "perolaras": "perolar",
    "perolarde": "perolar",
    "perolardes": "perolar",
    "perolare": "perolar",
    "perolarei": "perolar",
    "perolareis": "perolar",
    "perolarem": "perolar",
    "perolaremos": "perolar",
    "perolares": "perolar",
    "perolaria": "perolar",
    "perolariam": "perolar",
    "perolarias": "perolar",
    "perolarmo": "perolar",
    "perolarmos": "perolar",
    "perolará": "perolar",
    "perolarás": "perolar",
    "perolarão": "perolar",
    "perolaríamos": "perolar",
    "perolaríeis": "perolar",
    "perolas": "perolar",
    "perolasse": "perolar",
    "perolassem": "perolar",
    "perolasses": "perolar",
    "perolaste": "perolar",
    "perolastes": "perolar",
    "perolava": "perolar",
    "perolavam": "perolar",
    "perolavas": "perolar",
    "perole": "perolar",
    "perolei": "perolar",
    "peroleiras": "peroleira",
    "peroleis": "perolar",
    "perolem": "perolar",
    "perolemo": "perolar",
    "perolemos": "perolar",
    "peroles": "perolar",
    "peroliferíssima": "perolífero",
    "peroliferíssimas": "perolífero",
    "peroliferíssimo": "perolífero",
    "peroliferíssimos": "perolífero",
    "perolina": "perolino",
    "perolinas": "perolino",
    "perolinos": "perolino",
    "peroliza": "perolizar",
    "perolizada": "perolizar",
    "perolizadas": "perolizar",
    "perolizado": "perolizar",
    "perolizados": "perolizar",
    "perolizai": "perolizar",
    "perolizais": "perolizar",
    "perolizam": "perolizar",
    "perolizamo": "perolizar",
    "perolizamos": "perolizar",
    "perolizando": "perolizar",
    "perolizara": "perolizar",
    "perolizaram": "perolizar",
    "perolizaras": "perolizar",
    "perolizarde": "perolizar",
    "perolizardes": "perolizar",
    "perolizare": "perolizar",
    "perolizarei": "perolizar",
    "perolizareis": "perolizar",
    "perolizarem": "perolizar",
    "perolizaremos": "perolizar",
    "perolizares": "perolizar",
    "perolizaria": "perolizar",
    "perolizariam": "perolizar",
    "perolizarias": "perolizar",
    "perolizarmo": "perolizar",
    "perolizarmos": "perolizar",
    "perolizará": "perolizar",
    "perolizarás": "perolizar",
    "perolizarão": "perolizar",
    "perolizaríamos": "perolizar",
    "perolizaríeis": "perolizar",
    "perolizas": "perolizar",
    "perolizasse": "perolizar",
    "perolizassem": "perolizar",
    "perolizasses": "perolizar",
    "perolizaste": "perolizar",
    "perolizastes": "perolizar",
    "perolizava": "perolizar",
    "perolizavam": "perolizar",
    "perolizavas": "perolizar",
    "perolize": "perolizar",
    "perolizei": "perolizar",
    "perolizeis": "perolizar",
    "perolizem": "perolizar",
    "perolizemo": "perolizar",
    "perolizemos": "perolizar",
    "perolizes": "perolizar",
    "perolizo": "perolizar",
    "perolizou": "perolizar",
    "perolizá": "perolizar",
    "perolizámo": "perolizar",
    "perolizámos": "perolizar",
    "perolizáramo": "perolizar",
    "perolizáramos": "perolizar",
    "perolizárei": "perolizar",
    "perolizáreis": "perolizar",
    "perolizásseis": "perolizar",
    "perolizássemos": "perolizar",
    "perolizávamo": "perolizar",
    "perolizávamos": "perolizar",
    "perolizávei": "perolizar",
    "perolizáveis": "perolizar",
    "perolo": "perolar",
    "perolou": "perolar",
    "perolá": "perolar",
    "perolámo": "perolar",
    "perolámos": "perolar",
    "peroláramo": "perolar",
    "peroláramos": "perolar",
    "perolárei": "perolar",
    "peroláreis": "perolar",
    "perolásseis": "perolar",
    "perolássemos": "perolar",
    "perolávamo": "perolar",
    "perolávamos": "perolar",
    "perolávei": "perolar",
    "peroláveis": "perolar",
    "perolífera": "perolífero",
    "perolíferas": "perolífero",
    "perolíferos": "perolífero",
    "peroniais": "peronial",
    "peronismos": "peronismo",
    "peronistas": "peronista",
    "peronosporáceas": "peronosporácea",
    "perora": "perorar",
    "perorada": "perorar",
    "peroradas": "perorar",
    "perorado": "perorar",
    "peroradora": "perorador",
    "peroradoras": "perorador",
    "peroradores": "perorador",
    "perorados": "perorar",
    "perorai": "perorar",
    "perorais": "perorar",
    "peroram": "perorar",
    "peroramo": "perorar",
    "peroramos": "perorar",
    "perorando": "perorar",
    "perorara": "perorar",
    "peroraram": "perorar",
    "peroraras": "perorar",
    "perorardes": "perorar",
    "perorarei": "perorar",
    "perorareis": "perorar",
    "perorarem": "perorar",
    "peroraremos": "perorar",
    "perorares": "perorar",
    "peroraria": "perorar",
    "perorariam": "perorar",
    "perorarias": "perorar",
    "perorarmo": "perorar",
    "perorarmos": "perorar",
    "perorará": "perorar",
    "perorarás": "perorar",
    "perorarão": "perorar",
    "peroraríamos": "perorar",
    "peroraríeis": "perorar",
    "peroras": "perorar",
    "perorasse": "perorar",
    "perorassem": "perorar",
    "perorasses": "perorar",
    "peroraste": "perorar",
    "perorastes": "perorar",
    "perorava": "perorar",
    "peroravam": "perorar",
    "peroravas": "perorar",
    "perorações": "peroração",
    "perore": "perorar",
    "perorei": "perorar",
    "peroreis": "perorar",
    "perorem": "perorar",
    "peroremo": "perorar",
    "peroremos": "perorar",
    "perores": "perorar",
    "peroro": "perorar",
    "perorou": "perorar",
    "perorámo": "perorar",
    "perorámos": "perorar",
    "peroráramo": "perorar",
    "peroráramos": "perorar",
    "peroráreis": "perorar",
    "perorásseis": "perorar",
    "perorássemos": "perorar",
    "perorávamo": "perorar",
    "perorávamos": "perorar",
    "peroráveis": "perorar",
    "peroxida": "peroxidar",
    "peroxidada": "peroxidar",
    "peroxidadas": "peroxidar",
    "peroxidado": "peroxidar",
    "peroxidados": "peroxidar",
    "peroxidai": "peroxidar",
    "peroxidais": "peroxidar",
    "peroxidam": "peroxidar",
    "peroxidamo": "peroxidar",
    "peroxidamos": "peroxidar",
    "peroxidando": "peroxidar",
    "peroxidara": "peroxidar",
    "peroxidaram": "peroxidar",
    "peroxidaras": "peroxidar",
    "peroxidarde": "peroxidar",
    "peroxidardes": "peroxidar",
    "peroxidare": "peroxidar",
    "peroxidarei": "peroxidar",
    "peroxidareis": "peroxidar",
    "peroxidarem": "peroxidar",
    "peroxidaremos": "peroxidar",
    "peroxidares": "peroxidar",
    "peroxidaria": "peroxidar",
    "peroxidariam": "peroxidar",
    "peroxidarias": "peroxidar",
    "peroxidarmo": "peroxidar",
    "peroxidarmos": "peroxidar",
    "peroxidará": "peroxidar",
    "peroxidarás": "peroxidar",
    "peroxidarão": "peroxidar",
    "peroxidaríamos": "peroxidar",
    "peroxidaríeis": "peroxidar",
    "peroxidas": "peroxidar",
    "peroxidasse": "peroxidar",
    "peroxidassem": "peroxidar",
    "peroxidasses": "peroxidar",
    "peroxidaste": "peroxidar",
    "peroxidastes": "peroxidar",
    "peroxidava": "peroxidar",
    "peroxidavam": "peroxidar",
    "peroxidavas": "peroxidar",
    "peroxidações": "peroxidação",
    "peroxide": "peroxidar",
    "peroxidei": "peroxidar",
    "peroxideis": "peroxidar",
    "peroxidem": "peroxidar",
    "peroxidemo": "peroxidar",
    "peroxidemos": "peroxidar",
    "peroxides": "peroxidar",
    "peroxido": "peroxidar",
    "peroxidou": "peroxidar",
    "peroxidá": "peroxidar",
    "peroxidámo": "peroxidar",
    "peroxidámos": "peroxidar",
    "peroxidáramo": "peroxidar",
    "peroxidáramos": "peroxidar",
    "peroxidárei": "peroxidar",
    "peroxidáreis": "peroxidar",
    "peroxidásseis": "peroxidar",
    "peroxidássemos": "peroxidar",
    "peroxidávamo": "peroxidar",
    "peroxidávamos": "peroxidar",
    "peroxidávei": "peroxidar",
    "peroxidáveis": "peroxidar",
    "peroxoaniões": "peroxoanião",
    "peroxoboratos": "peroxoborato",
    "peroxodissulfatos": "peroxodissulfato",
    "peroxonitratos": "peroxonitrato",
    "perpassa": "perpassar",
    "perpassada": "perpassar",
    "perpassadas": "perpassar",
    "perpassado": "perpassar",
    "perpassados": "perpassar",
    "perpassai": "perpassar",
    "perpassais": "perpassar",
    "perpassam": "perpassar",
    "perpassamo": "perpassar",
    "perpassamos": "perpassar",
    "perpassando": "perpassar",
    "perpassara": "perpassar",
    "perpassaram": "perpassar",
    "perpassaras": "perpassar",
    "perpassardes": "perpassar",
    "perpassarei": "perpassar",
    "perpassareis": "perpassar",
    "perpassarem": "perpassar",
    "perpassaremos": "perpassar",
    "perpassares": "perpassar",
    "perpassaria": "perpassar",
    "perpassariam": "perpassar",
    "perpassarias": "perpassar",
    "perpassarmo": "perpassar",
    "perpassarmos": "perpassar",
    "perpassará": "perpassar",
    "perpassarás": "perpassar",
    "perpassarão": "perpassar",
    "perpassaríamos": "perpassar",
    "perpassaríeis": "perpassar",
    "perpassas": "perpassar",
    "perpassasse": "perpassar",
    "perpassassem": "perpassar",
    "perpassasses": "perpassar",
    "perpassaste": "perpassar",
    "perpassastes": "perpassar",
    "perpassava": "perpassar",
    "perpassavam": "perpassar",
    "perpassavas": "perpassar",
    "perpasse": "perpassar",
    "perpassei": "perpassar",
    "perpasseis": "perpassar",
    "perpassem": "perpassar",
    "perpassemo": "perpassar",
    "perpassemos": "perpassar",
    "perpasses": "perpassar",
    "perpasso": "perpassar",
    "perpassou": "perpassar",
    "perpassámo": "perpassar",
    "perpassámos": "perpassar",
    "perpassáramo": "perpassar",
    "perpassáramos": "perpassar",
    "perpassáreis": "perpassar",
    "perpassásseis": "perpassar",
    "perpassássemos": "perpassar",
    "perpassávamo": "perpassar",
    "perpassávamos": "perpassar",
    "perpassáveis": "perpassável",
    "perpendiculares": "perpendicular",
    "perpendicularidades": "perpendicularidade",
    "perpendículos": "perpendículo",
    "perpetra": "perpetrar",
    "perpetrada": "perpetrar",
    "perpetradas": "perpetrar",
    "perpetrado": "perpetrar",
    "perpetradora": "perpetrador",
    "perpetradoras": "perpetrador",
    "perpetradores": "perpetrador",
    "perpetrados": "perpetrar",
    "perpetrai": "perpetrar",
    "perpetrais": "perpetrar",
    "perpetram": "perpetrar",
    "perpetramo": "perpetrar",
    "perpetramos": "perpetrar",
    "perpetrando": "perpetrar",
    "perpetrara": "perpetrar",
    "perpetraram": "perpetrar",
    "perpetraras": "perpetrar",
    "perpetrarde": "perpetrar",
    "perpetrardes": "perpetrar",
    "perpetrare": "perpetrar",
    "perpetrarei": "perpetrar",
    "perpetrareis": "perpetrar",
    "perpetrarem": "perpetrar",
    "perpetraremos": "perpetrar",
    "perpetrares": "perpetrar",
    "perpetraria": "perpetrar",
    "perpetrariam": "perpetrar",
    "perpetrarias": "perpetrar",
    "perpetrarmo": "perpetrar",
    "perpetrarmos": "perpetrar",
    "perpetrará": "perpetrar",
    "perpetrarás": "perpetrar",
    "perpetrarão": "perpetrar",
    "perpetraríamos": "perpetrar",
    "perpetraríeis": "perpetrar",
    "perpetras": "perpetrar",
    "perpetrasse": "perpetrar",
    "perpetrassem": "perpetrar",
    "perpetrasses": "perpetrar",
    "perpetraste": "perpetrar",
    "perpetrastes": "perpetrar",
    "perpetrava": "perpetrar",
    "perpetravam": "perpetrar",
    "perpetravas": "perpetrar",
    "perpetrações": "perpetração",
    "perpetre": "perpetrar",
    "perpetrei": "perpetrar",
    "perpetreis": "perpetrar",
    "perpetrem": "perpetrar",
    "perpetremo": "perpetrar",
    "perpetremos": "perpetrar",
    "perpetres": "perpetrar",
    "perpetro": "perpetrar",
    "perpetrou": "perpetrar",
    "perpetrá": "perpetrar",
    "perpetrámo": "perpetrar",
    "perpetrámos": "perpetrar",
    "perpetráramo": "perpetrar",
    "perpetráramos": "perpetrar",
    "perpetrárei": "perpetrar",
    "perpetráreis": "perpetrar",
    "perpetrásseis": "perpetrar",
    "perpetrássemos": "perpetrar",
    "perpetrávamo": "perpetrar",
    "perpetrávamos": "perpetrar",
    "perpetrávei": "perpetrar",
    "perpetráveis": "perpetrável",
    "perpetua": "perpetuar",
    "perpetuada": "perpetuar",
    "perpetuadas": "perpetuar",
    "perpetuado": "perpetuar",
    "perpetuadora": "perpetuador",
    "perpetuadoras": "perpetuador",
    "perpetuadores": "perpetuador",
    "perpetuados": "perpetuar",
    "perpetuai": "perpetuar",
    "perpetuais": "perpetuar",
    "perpetuam": "perpetuar",
    "perpetuamo": "perpetuar",
    "perpetuamos": "perpetuar",
    "perpetuando": "perpetuar",
    "perpetuara": "perpetuar",
    "perpetuaram": "perpetuar",
    "perpetuaras": "perpetuar",
    "perpetuarde": "perpetuar",
    "perpetuardes": "perpetuar",
    "perpetuare": "perpetuar",
    "perpetuarei": "perpetuar",
    "perpetuareis": "perpetuar",
    "perpetuarem": "perpetuar",
    "perpetuaremos": "perpetuar",
    "perpetuares": "perpetuar",
    "perpetuaria": "perpetuar",
    "perpetuariam": "perpetuar",
    "perpetuarias": "perpetuar",
    "perpetuarmo": "perpetuar",
    "perpetuarmos": "perpetuar",
    "perpetuará": "perpetuar",
    "perpetuarás": "perpetuar",
    "perpetuarão": "perpetuar",
    "perpetuaríamos": "perpetuar",
    "perpetuaríeis": "perpetuar",
    "perpetuas": "perpetuar",
    "perpetuasse": "perpetuar",
    "perpetuassem": "perpetuar",
    "perpetuasses": "perpetuar",
    "perpetuaste": "perpetuar",
    "perpetuastes": "perpetuar",
    "perpetuava": "perpetuar",
    "perpetuavam": "perpetuar",
    "perpetuavas": "perpetuar",
    "perpetuações": "perpetuação",
    "perpetue": "perpetuar",
    "perpetuei": "perpetuar",
    "perpetueis": "perpetuar",
    "perpetuem": "perpetuar",
    "perpetuemo": "perpetuar",
    "perpetuemos": "perpetuar",
    "perpetues": "perpetuar",
    "perpetuidades": "perpetuidade",
    "perpetuo": "perpetuar",
    "perpetuou": "perpetuar",
    "perpetuá": "perpetuar",
    "perpetuámo": "perpetuar",
    "perpetuámos": "perpetuar",
    "perpetuáramo": "perpetuar",
    "perpetuáramos": "perpetuar",
    "perpetuárei": "perpetuar",
    "perpetuáreis": "perpetuar",
    "perpetuásseis": "perpetuar",
    "perpetuássemos": "perpetuar",
    "perpetuávamo": "perpetuar",
    "perpetuávamos": "perpetuar",
    "perpetuávei": "perpetuar",
    "perpetuáveis": "perpetuável",
    "perpianhos": "perpianho",
    "perplexa": "perplexo",
    "perplexas": "perplexo",
    "perplexidades": "perplexidade",
    "perplexos": "perplexo",
    "perplexíssima": "perplexo",
    "perplexíssimas": "perplexo",
    "perplexíssimo": "perplexo",
    "perplexíssimos": "perplexo",
    "perplexões": "perplexão",
    "perpontes": "perponte",
    "perpontos": "perponto",
    "perpétua": "perpétuo",
    "perpétuas": "perpétuo",
    "perpétuos": "perpétuo",
    "perquira": "perquirir",
    "perquirais": "perquirir",
    "perquiram": "perquirir",
    "perquiramo": "perquirir",
    "perquiramos": "perquirir",
    "perquiras": "perquirir",
    "perquire": "perquirir",
    "perquirem": "perquirir",
    "perquires": "perquirir",
    "perquiri": "perquirir",
    "perquiria": "perquirir",
    "perquiriam": "perquirir",
    "perquirias": "perquirir",
    "perquirida": "perquirir",
    "perquiridas": "perquirir",
    "perquirido": "perquirir",
    "perquiridos": "perquirir",
    "perquirimo": "perquirir",
    "perquirimos": "perquirir",
    "perquirindo": "perquirir",
    "perquirira": "perquirir",
    "perquiriram": "perquirir",
    "perquiriras": "perquirir",
    "perquirirde": "perquirir",
    "perquirirdes": "perquirir",
    "perquirire": "perquirir",
    "perquirirei": "perquirir",
    "perquirireis": "perquirir",
    "perquirirem": "perquirir",
    "perquiriremos": "perquirir",
    "perquirires": "perquirir",
    "perquiriria": "perquirir",
    "perquiririam": "perquirir",
    "perquiririas": "perquirir",
    "perquirirmo": "perquirir",
    "perquirirmos": "perquirir",
    "perquirirá": "perquirir",
    "perquirirás": "perquirir",
    "perquirirão": "perquirir",
    "perquiriríamos": "perquirir",
    "perquiriríeis": "perquirir",
    "perquiris": "perquirir",
    "perquirisse": "perquirir",
    "perquirissem": "perquirir",
    "perquirisses": "perquirir",
    "perquiriste": "perquirir",
    "perquiristes": "perquirir",
    "perquiriu": "perquirir",
    "perquirições": "perquirição",
    "perquiro": "perquirir",
    "perquiríamo": "perquirir",
    "perquiríamos": "perquirir",
    "perquiríei": "perquirir",
    "perquiríeis": "perquirir",
    "perquiríramo": "perquirir",
    "perquiríramos": "perquirir",
    "perquirírei": "perquirir",
    "perquiríreis": "perquirir",
    "perquirísseis": "perquirir",
    "perquiríssemos": "perquirir",
    "perquisições": "perquisição",
    "perra": "perro",
    "perrarias": "perraria",
    "perras": "perro",
    "perreada": "perrear",
    "perreadas": "perrear",
    "perreado": "perrear",
    "perreados": "perrear",
    "perreai": "perrear",
    "perreais": "perrear",
    "perreamo": "perrear",
    "perreamos": "perrear",
    "perreando": "perrear",
    "perreara": "perrear",
    "perrearam": "perrear",
    "perrearas": "perrear",
    "perrearde": "perrear",
    "perreardes": "perrear",
    "perreare": "perrear",
    "perrearei": "perrear",
    "perreareis": "perrear",
    "perrearem": "perrear",
    "perrearemos": "perrear",
    "perreares": "perrear",
    "perrearia": "perrear",
    "perreariam": "perrear",
    "perrearias": "perrear",
    "perrearmo": "perrear",
    "perrearmos": "perrear",
    "perreará": "perrear",
    "perrearás": "perrear",
    "perrearão": "perrear",
    "perrearíamos": "perrear",
    "perrearíeis": "perrear",
    "perreasse": "perrear",
    "perreassem": "perrear",
    "perreasses": "perrear",
    "perreaste": "perrear",
    "perreastes": "perrear",
    "perreava": "perrear",
    "perreavam": "perrear",
    "perreavas": "perrear",
    "perreei": "perrear",
    "perreeis": "perrear",
    "perreemo": "perrear",
    "perreemos": "perrear",
    "perreia": "perrear",
    "perreiam": "perrear",
    "perreias": "perrear",
    "perreie": "perrear",
    "perreiem": "perrear",
    "perreies": "perrear",
    "perreio": "perrear",
    "perreiros": "perreiro",
    "perreou": "perrear",
    "perrexis": "perrexil",
    "perreá": "perrear",
    "perreámo": "perrear",
    "perreámos": "perrear",
    "perreáramo": "perrear",
    "perreáramos": "perrear",
    "perreárei": "perrear",
    "perreáreis": "perrear",
    "perreásseis": "perrear",
    "perreássemos": "perrear",
    "perreávamo": "perrear",
    "perreávamos": "perrear",
    "perreávei": "perrear",
    "perreáveis": "perrear",
    "perrices": "perrice",
    "perricha": "perricho",
    "perrichas": "perricho",
    "perrichos": "perricho",
    "perros": "perro",
    "perrumas": "perruma",
    "perruns": "perrum",
    "perrês": "perrê",
    "persadona": "persadão",
    "persadonas": "persadão",
    "persadões": "persadão",
    "persas": "persa",
    "perscruta": "perscrutar",
    "perscrutada": "perscrutar",
    "perscrutadas": "perscrutar",
    "perscrutado": "perscrutar",
    "perscrutadora": "perscrutador",
    "perscrutadoras": "perscrutador",
    "perscrutadores": "perscrutador",
    "perscrutados": "perscrutar",
    "perscrutai": "perscrutar",
    "perscrutais": "perscrutar",
    "perscrutam": "perscrutar",
    "perscrutamo": "perscrutar",
    "perscrutamos": "perscrutar",
    "perscrutando": "perscrutar",
    "perscrutara": "perscrutar",
    "perscrutaram": "perscrutar",
    "perscrutaras": "perscrutar",
    "perscrutarde": "perscrutar",
    "perscrutardes": "perscrutar",
    "perscrutare": "perscrutar",
    "perscrutarei": "perscrutar",
    "perscrutareis": "perscrutar",
    "perscrutarem": "perscrutar",
    "perscrutaremos": "perscrutar",
    "perscrutares": "perscrutar",
    "perscrutaria": "perscrutar",
    "perscrutariam": "perscrutar",
    "perscrutarias": "perscrutar",
    "perscrutarmo": "perscrutar",
    "perscrutarmos": "perscrutar",
    "perscrutará": "perscrutar",
    "perscrutarás": "perscrutar",
    "perscrutarão": "perscrutar",
    "perscrutaríamos": "perscrutar",
    "perscrutaríeis": "perscrutar",
    "perscrutas": "perscrutar",
    "perscrutasse": "perscrutar",
    "perscrutassem": "perscrutar",
    "perscrutasses": "perscrutar",
    "perscrutaste": "perscrutar",
    "perscrutastes": "perscrutar",
    "perscrutava": "perscrutar",
    "perscrutavam": "perscrutar",
    "perscrutavas": "perscrutar",
    "perscrutações": "perscrutação",
    "perscrute": "perscrutar",
    "perscrutei": "perscrutar",
    "perscruteis": "perscrutar",
    "perscrutem": "perscrutar",
    "perscrutemo": "perscrutar",
    "perscrutemos": "perscrutar",
    "perscrutes": "perscrutar",
    "perscruto": "perscrutar",
    "perscrutou": "perscrutar",
    "perscrutá": "perscrutar",
    "perscrutámo": "perscrutar",
    "perscrutámos": "perscrutar",
    "perscrutáramo": "perscrutar",
    "perscrutáramos": "perscrutar",
    "perscrutárei": "perscrutar",
    "perscrutáreis": "perscrutar",
    "perscrutásseis": "perscrutar",
    "perscrutássemos": "perscrutar",
    "perscrutávamo": "perscrutar",
    "perscrutávamos": "perscrutar",
    "perscrutávei": "perscrutar",
    "perscrutáveis": "perscrutável",
    "persecutória": "persecutório",
    "persecutórias": "persecutório",
    "persecutórios": "persecutório",
    "persecuções": "persecução",
    "persegue": "perseguir",
    "perseguem": "perseguir",
    "persegues": "perseguir",
    "persegui": "perseguir",
    "perseguia": "perseguir",
    "perseguiam": "perseguir",
    "perseguias": "perseguir",
    "perseguida": "perseguir",
    "perseguidas": "perseguir",
    "perseguido": "perseguir",
    "perseguidora": "perseguidor",
    "perseguidoras": "perseguidor",
    "perseguidores": "perseguidor",
    "perseguidos": "perseguir",
    "perseguidíssima": "perseguido",
    "perseguidíssimas": "perseguido",
    "perseguidíssimo": "perseguido",
    "perseguidíssimos": "perseguido",
    "perseguimo": "perseguir",
    "perseguimos": "perseguir",
    "perseguindo": "perseguir",
    "perseguira": "perseguir",
    "perseguiram": "perseguir",
    "perseguiras": "perseguir",
    "perseguirde": "perseguir",
    "perseguirdes": "perseguir",
    "perseguire": "perseguir",
    "perseguirei": "perseguir",
    "perseguireis": "perseguir",
    "perseguirem": "perseguir",
    "perseguiremos": "perseguir",
    "perseguires": "perseguir",
    "perseguiria": "perseguir",
    "perseguiriam": "perseguir",
    "perseguirias": "perseguir",
    "perseguirmo": "perseguir",
    "perseguirmos": "perseguir",
    "perseguirá": "perseguir",
    "perseguirás": "perseguir",
    "perseguirão": "perseguir",
    "perseguiríamos": "perseguir",
    "perseguiríeis": "perseguir",
    "perseguis": "perseguir",
    "perseguisse": "perseguir",
    "perseguissem": "perseguir",
    "perseguisses": "perseguir",
    "perseguiste": "perseguir",
    "perseguistes": "perseguir",
    "perseguiu": "perseguir",
    "perseguições": "perseguição",
    "perseguíamo": "perseguir",
    "perseguíamos": "perseguir",
    "perseguíei": "perseguir",
    "perseguíeis": "perseguir",
    "perseguíramo": "perseguir",
    "perseguíramos": "perseguir",
    "perseguírei": "perseguir",
    "perseguíreis": "perseguir",
    "perseguísseis": "perseguir",
    "perseguíssemos": "perseguir",
    "persentimentos": "persentimento",
    "persevera": "perseverar",
    "perseverada": "perseverar",
    "perseveradas": "perseverar",
    "perseverado": "perseverar",
    "perseverados": "perseverar",
    "perseverai": "perseverar",
    "perseverais": "perseverar",
    "perseveram": "perseverar",
    "perseveramo": "perseverar",
    "perseveramos": "perseverar",
    "perseverando": "perseverar",
    "perseverantes": "perseverante",
    "perseverantíssima": "perseverante",
    "perseverantíssimas": "perseverante",
    "perseverantíssimo": "perseverante",
    "perseverantíssimos": "perseverante",
    "perseveranças": "perseverança",
    "perseverara": "perseverar",
    "perseveraram": "perseverar",
    "perseveraras": "perseverar",
    "perseverardes": "perseverar",
    "perseverarei": "perseverar",
    "perseverareis": "perseverar",
    "perseverarem": "perseverar",
    "perseveraremos": "perseverar",
    "perseverares": "perseverar",
    "perseveraria": "perseverar",
    "perseverariam": "perseverar",
    "perseverarias": "perseverar",
    "perseverarmo": "perseverar",
    "perseverarmos": "perseverar",
    "perseverará": "perseverar",
    "perseverarás": "perseverar",
    "perseverarão": "perseverar",
    "perseveraríamos": "perseverar",
    "perseveraríeis": "perseverar",
    "perseveras": "perseverar",
    "perseverasse": "perseverar",
    "perseverassem": "perseverar",
    "perseverasses": "perseverar",
    "perseveraste": "perseverar",
    "perseverastes": "perseverar",
    "perseverava": "perseverar",
    "perseveravam": "perseverar",
    "perseveravas": "perseverar",
    "perseverações": "perseveração",
    "persevere": "perseverar",
    "perseverei": "perseverar",
    "persevereis": "perseverar",
    "perseverem": "perseverar",
    "perseveremo": "perseverar",
    "perseveremos": "perseverar",
    "perseveres": "perseverar",
    "persevero": "perseverar",
    "perseverou": "perseverar",
    "perseverámo": "perseverar",
    "perseverámos": "perseverar",
    "perseveráramo": "perseverar",
    "perseveráramos": "perseverar",
    "perseveráreis": "perseverar",
    "perseverásseis": "perseverar",
    "perseverássemos": "perseverar",
    "perseverávamo": "perseverar",
    "perseverávamos": "perseverar",
    "perseveráveis": "perseverar",
    "persevões": "persevão",
    "persiana": "persiano",
    "persianas": "persiano",
    "persianos": "persiano",
    "persicárias": "persicária",
    "persiga": "perseguir",
    "persigais": "persigal",
    "persigam": "perseguir",
    "persigamo": "perseguir",
    "persigamos": "perseguir",
    "persigas": "perseguir",
    "persigna": "persignar",
    "persignada": "persignar",
    "persignadas": "persignar",
    "persignado": "persignar",
    "persignados": "persignar",
    "persignai": "persignar",
    "persignais": "persignar",
    "persignam": "persignar",
    "persignamo": "persignar",
    "persignamos": "persignar",
    "persignando": "persignar",
    "persignara": "persignar",
    "persignaram": "persignar",
    "persignaras": "persignar",
    "persignarde": "persignar",
    "persignardes": "persignar",
    "persignare": "persignar",
    "persignarei": "persignar",
    "persignareis": "persignar",
    "persignarem": "persignar",
    "persignaremos": "persignar",
    "persignares": "persignar",
    "persignaria": "persignar",
    "persignariam": "persignar",
    "persignarias": "persignar",
    "persignarmo": "persignar",
    "persignarmos": "persignar",
    "persignará": "persignar",
    "persignarás": "persignar",
    "persignarão": "persignar",
    "persignaríamos": "persignar",
    "persignaríeis": "persignar",
    "persignas": "persignar",
    "persignasse": "persignar",
    "persignassem": "persignar",
    "persignasses": "persignar",
    "persignaste": "persignar",
    "persignastes": "persignar",
    "persignava": "persignar",
    "persignavam": "persignar",
    "persignavas": "persignar",
    "persignações": "persignação",
    "persigne": "persignar",
    "persignei": "persignar",
    "persigneis": "persignar",
    "persignem": "persignar",
    "persignemo": "persignar",
    "persignemos": "persignar",
    "persignes": "persignar",
    "persigno": "persignar",
    "persignou": "persignar",
    "persigná": "persignar",
    "persignámo": "persignar",
    "persignámos": "persignar",
    "persignáramo": "persignar",
    "persignáramos": "persignar",
    "persignárei": "persignar",
    "persignáreis": "persignar",
    "persignásseis": "persignar",
    "persignássemos": "persignar",
    "persignávamo": "persignar",
    "persignávamos": "persignar",
    "persignávei": "persignar",
    "persignáveis": "persignar",
    "persigo": "perseguir",
    "persista": "persistir",
    "persistais": "persistir",
    "persistam": "persistir",
    "persistamo": "persistir",
    "persistamos": "persistir",
    "persistas": "persistir",
    "persiste": "persistir",
    "persistem": "persistir",
    "persistentes": "persistente",
    "persistentíssima": "persistente",
    "persistentíssimas": "persistente",
    "persistentíssimo": "persistente",
    "persistentíssimos": "persistente",
    "persistes": "persistir",
    "persisti": "persistir",
    "persistia": "persistir",
    "persistiam": "persistir",
    "persistias": "persistir",
    "persistida": "persistir",
    "persistidas": "persistir",
    "persistido": "persistir",
    "persistidos": "persistir",
    "persistimo": "persistir",
    "persistimos": "persistir",
    "persistindo": "persistir",
    "persistira": "persistir",
    "persistiram": "persistir",
    "persistiras": "persistir",
    "persistirdes": "persistir",
    "persistirei": "persistir",
    "persistireis": "persistir",
    "persistirem": "persistir",
    "persistiremos": "persistir",
    "persistires": "persistir",
    "persistiria": "persistir",
    "persistiriam": "persistir",
    "persistirias": "persistir",
    "persistirmo": "persistir",
    "persistirmos": "persistir",
    "persistirá": "persistir",
    "persistirás": "persistir",
    "persistirão": "persistir",
    "persistiríamos": "persistir",
    "persistiríeis": "persistir",
    "persistis": "persistir",
    "persistisse": "persistir",
    "persistissem": "persistir",
    "persistisses": "persistir",
    "persististe": "persistir",
    "persististes": "persistir",
    "persistiu": "persistir",
    "persisto": "persistir",
    "persistências": "persistência",
    "persistíamo": "persistir",
    "persistíamos": "persistir",
    "persistíeis": "persistir",
    "persistíramo": "persistir",
    "persistíramos": "persistir",
    "persistíreis": "persistir",
    "persistísseis": "persistir",
    "persistíssemos": "persistir",
    "personada": "personado",
    "personadas": "personado",
    "personados": "personado",
    "personagens": "personagem",
    "personalidades": "personalidade",
    "personalismos": "personalismo",
    "personalistas": "personalista",
    "personaliza": "personalizar",
    "personalizada": "personalizar",
    "personalizadas": "personalizar",
    "personalizado": "personalizar",
    "personalizados": "personalizar",
    "personalizai": "personalizar",
    "personalizais": "personalizar",
    "personalizam": "personalizar",
    "personalizamo": "personalizar",
    "personalizamos": "personalizar",
    "personalizando": "personalizar",
    "personalizara": "personalizar",
    "personalizaram": "personalizar",
    "personalizaras": "personalizar",
    "personalizarde": "personalizar",
    "personalizardes": "personalizar",
    "personalizare": "personalizar",
    "personalizarei": "personalizar",
    "personalizareis": "personalizar",
    "personalizarem": "personalizar",
    "personalizaremos": "personalizar",
    "personalizares": "personalizar",
    "personalizaria": "personalizar",
    "personalizariam": "personalizar",
    "personalizarias": "personalizar",
    "personalizarmo": "personalizar",
    "personalizarmos": "personalizar",
    "personalizará": "personalizar",
    "personalizarás": "personalizar",
    "personalizarão": "personalizar",
    "personalizaríamos": "personalizar",
    "personalizaríeis": "personalizar",
    "personalizas": "personalizar",
    "personalizasse": "personalizar",
    "personalizassem": "personalizar",
    "personalizasses": "personalizar",
    "personalizaste": "personalizar",
    "personalizastes": "personalizar",
    "personalizava": "personalizar",
    "personalizavam": "personalizar",
    "personalizavas": "personalizar",
    "personalizações": "personalização",
    "personalize": "personalizar",
    "personalizei": "personalizar",
    "personalizeis": "personalizar",
    "personalizem": "personalizar",
    "personalizemo": "personalizar",
    "personalizemos": "personalizar",
    "personalizes": "personalizar",
    "personalizo": "personalizar",
    "personalizou": "personalizar",
    "personalizá": "personalizar",
    "personalizámo": "personalizar",
    "personalizámos": "personalizar",
    "personalizáramo": "personalizar",
    "personalizáramos": "personalizar",
    "personalizárei": "personalizar",
    "personalizáreis": "personalizar",
    "personalizásseis": "personalizar",
    "personalizássemos": "personalizar",
    "personalizávamo": "personalizar",
    "personalizávamos": "personalizar",
    "personalizávei": "personalizar",
    "personalizáveis": "personalizável",
    "personifica": "personificar",
    "personificada": "personificar",
    "personificadas": "personificar",
    "personificado": "personificar",
    "personificados": "personificar",
    "personificai": "personificar",
    "personificais": "personificar",
    "personificam": "personificar",
    "personificamo": "personificar",
    "personificamos": "personificar",
    "personificando": "personificar",
    "personificara": "personificar",
    "personificaram": "personificar",
    "personificaras": "personificar",
    "personificarde": "personificar",
    "personificardes": "personificar",
    "personificare": "personificar",
    "personificarei": "personificar",
    "personificareis": "personificar",
    "personificarem": "personificar",
    "personificaremos": "personificar",
    "personificares": "personificar",
    "personificaria": "personificar",
    "personificariam": "personificar",
    "personificarias": "personificar",
    "personificarmo": "personificar",
    "personificarmos": "personificar",
    "personificará": "personificar",
    "personificarás": "personificar",
    "personificarão": "personificar",
    "personificaríamos": "personificar",
    "personificaríeis": "personificar",
    "personificas": "personificar",
    "personificasse": "personificar",
    "personificassem": "personificar",
    "personificasses": "personificar",
    "personificaste": "personificar",
    "personificastes": "personificar",
    "personificava": "personificar",
    "personificavam": "personificar",
    "personificavas": "personificar",
    "personificações": "personificação",
    "personifico": "personificar",
    "personificou": "personificar",
    "personificá": "personificar",
    "personificámo": "personificar",
    "personificámos": "personificar",
    "personificáramo": "personificar",
    "personificáramos": "personificar",
    "personificárei": "personificar",
    "personificáreis": "personificar",
    "personificásseis": "personificar",
    "personificássemos": "personificar",
    "personificávamo": "personificar",
    "personificávamos": "personificar",
    "personificávei": "personificar",
    "personificáveis": "personificável",
    "personifique": "personificar",
    "personifiquei": "personificar",
    "personifiqueis": "personificar",
    "personifiquem": "personificar",
    "personifiquemo": "personificar",
    "personifiquemos": "personificar",
    "personifiques": "personificar",
    "personologias": "personologia",
    "personologistas": "personologista",
    "personológica": "personológico",
    "personológicas": "personológico",
    "personológicos": "personológico",
    "perspectiva": "perspectivo",
    "perspectivada": "perspectivar",
    "perspectivadas": "perspectivar",
    "perspectivado": "perspectivar",
    "perspectivados": "perspectivar",
    "perspectivai": "perspectivar",
    "perspectivais": "perspectivar",
    "perspectivam": "perspectivar",
    "perspectivamo": "perspectivar",
    "perspectivamos": "perspectivar",
    "perspectivando": "perspectivar",
    "perspectivara": "perspectivar",
    "perspectivaram": "perspectivar",
    "perspectivaras": "perspectivar",
    "perspectivarde": "perspectivar",
    "perspectivardes": "perspectivar",
    "perspectivare": "perspectivar",
    "perspectivarei": "perspectivar",
    "perspectivareis": "perspectivar",
    "perspectivarem": "perspectivar",
    "perspectivaremos": "perspectivar",
    "perspectivares": "perspectivar",
    "perspectivaria": "perspectivar",
    "perspectivariam": "perspectivar",
    "perspectivarias": "perspectivar",
    "perspectivarmo": "perspectivar",
    "perspectivarmos": "perspectivar",
    "perspectivará": "perspectivar",
    "perspectivarás": "perspectivar",
    "perspectivarão": "perspectivar",
    "perspectivaríamos": "perspectivar",
    "perspectivaríeis": "perspectivar",
    "perspectivas": "perspectivo",
    "perspectivasse": "perspectivar",
    "perspectivassem": "perspectivar",
    "perspectivasses": "perspectivar",
    "perspectivaste": "perspectivar",
    "perspectivastes": "perspectivar",
    "perspectivava": "perspectivar",
    "perspectivavam": "perspectivar",
    "perspectivavas": "perspectivar",
    "perspectivações": "perspectivação",
    "perspective": "perspectivar",
    "perspectivei": "perspectivar",
    "perspectiveis": "perspectivar",
    "perspectivem": "perspectivar",
    "perspectivemo": "perspectivar",
    "perspectivemos": "perspectivar",
    "perspectives": "perspectivar",
    "perspectividades": "perspectividade",
    "perspectivismos": "perspectivismo",
    "perspectivistas": "perspectivista",
    "perspectivo": "perspectivar",
    "perspectivos": "perspectivo",
    "perspectivou": "perspectivar",
    "perspectivá": "perspectivar",
    "perspectivámo": "perspectivar",
    "perspectivámos": "perspectivar",
    "perspectiváramo": "perspectivar",
    "perspectiváramos": "perspectivar",
    "perspectivárei": "perspectivar",
    "perspectiváreis": "perspectivar",
    "perspectivásseis": "perspectivar",
    "perspectivássemos": "perspectivar",
    "perspectivávamo": "perspectivar",
    "perspectivávamos": "perspectivar",
    "perspectivávei": "perspectivar",
    "perspectiváveis": "perspectivável",
    "perspectógrafos": "perspectógrafo",
    "perspicacíssima": "perspicaz",
    "perspicacíssimas": "perspicaz",
    "perspicacíssimo": "perspicaz",
    "perspicacíssimos": "perspicaz",
    "perspicazes": "perspicaz",
    "perspicuidades": "perspicuidade",
    "perspicácias": "perspicácia",
    "perspira": "perspirar",
    "perspirada": "perspirar",
    "perspiradas": "perspirar",
    "perspirado": "perspirar",
    "perspirados": "perspirar",
    "perspirai": "perspirar",
    "perspirais": "perspirar",
    "perspiram": "perspirar",
    "perspiramo": "perspirar",
    "perspiramos": "perspirar",
    "perspirando": "perspirar",
    "perspirara": "perspirar",
    "perspiraram": "perspirar",
    "perspiraras": "perspirar",
    "perspirardes": "perspirar",
    "perspirarei": "perspirar",
    "perspirareis": "perspirar",
    "perspirarem": "perspirar",
    "perspiraremos": "perspirar",
    "perspirares": "perspirar",
    "perspiraria": "perspirar",
    "perspirariam": "perspirar",
    "perspirarias": "perspirar",
    "perspirarmo": "perspirar",
    "perspirarmos": "perspirar",
    "perspirará": "perspirar",
    "perspirarás": "perspirar",
    "perspirarão": "perspirar",
    "perspiraríamos": "perspirar",
    "perspiraríeis": "perspirar",
    "perspiras": "perspirar",
    "perspirasse": "perspirar",
    "perspirassem": "perspirar",
    "perspirasses": "perspirar",
    "perspiraste": "perspirar",
    "perspirastes": "perspirar",
    "perspiratória": "perspiratório",
    "perspiratórias": "perspiratório",
    "perspiratórios": "perspiratório",
    "perspirava": "perspirar",
    "perspiravam": "perspirar",
    "perspiravas": "perspirar",
    "perspirações": "perspiração",
    "perspire": "perspirar",
    "perspirei": "perspirar",
    "perspireis": "perspirar",
    "perspirem": "perspirar",
    "perspiremo": "perspirar",
    "perspiremos": "perspirar",
    "perspires": "perspirar",
    "perspiro": "perspirar",
    "perspirou": "perspirar",
    "perspirámo": "perspirar",
    "perspirámos": "perspirar",
    "perspiráramo": "perspirar",
    "perspiráramos": "perspirar",
    "perspiráreis": "perspirar",
    "perspirásseis": "perspirar",
    "perspirássemos": "perspirar",
    "perspirávamo": "perspirar",
    "perspirávamos": "perspirar",
    "perspiráveis": "perspirar",
    "perspéctica": "perspéctico",
    "perspécticas": "perspéctico",
    "perspécticos": "perspéctico",
    "perspícua": "perspícuo",
    "perspícuas": "perspícuo",
    "perspícuos": "perspícuo",
    "persuada": "persuadir",
    "persuadais": "persuadir",
    "persuadam": "persuadir",
    "persuadamo": "persuadir",
    "persuadamos": "persuadir",
    "persuadas": "persuadir",
    "persuade": "persuadir",
    "persuadem": "persuadir",
    "persuades": "persuadir",
    "persuadi": "persuadir",
    "persuadia": "persuadir",
    "persuadiam": "persuadir",
    "persuadias": "persuadir",
    "persuadida": "persuadir",
    "persuadidas": "persuadir",
    "persuadido": "persuadir",
    "persuadidos": "persuadir",
    "persuadimentos": "persuadimento",
    "persuadimo": "persuadir",
    "persuadimos": "persuadir",
    "persuadindo": "persuadir",
    "persuadira": "persuadir",
    "persuadiram": "persuadir",
    "persuadiras": "persuadir",
    "persuadirde": "persuadir",
    "persuadirdes": "persuadir",
    "persuadire": "persuadir",
    "persuadirei": "persuadir",
    "persuadireis": "persuadir",
    "persuadirem": "persuadir",
    "persuadiremos": "persuadir",
    "persuadires": "persuadir",
    "persuadiria": "persuadir",
    "persuadiriam": "persuadir",
    "persuadirias": "persuadir",
    "persuadirmo": "persuadir",
    "persuadirmos": "persuadir",
    "persuadirá": "persuadir",
    "persuadirás": "persuadir",
    "persuadirão": "persuadir",
    "persuadiríamos": "persuadir",
    "persuadiríeis": "persuadir",
    "persuadis": "persuadir",
    "persuadisse": "persuadir",
    "persuadissem": "persuadir",
    "persuadisses": "persuadir",
    "persuadiste": "persuadir",
    "persuadistes": "persuadir",
    "persuadiu": "persuadir",
    "persuadições": "persuadição",
    "persuado": "persuadir",
    "persuadíamo": "persuadir",
    "persuadíamos": "persuadir",
    "persuadíei": "persuadir",
    "persuadíeis": "persuadir",
    "persuadíramo": "persuadir",
    "persuadíramos": "persuadir",
    "persuadírei": "persuadir",
    "persuadíreis": "persuadir",
    "persuadísseis": "persuadir",
    "persuadíssemos": "persuadir",
    "persuadíveis": "persuadível",
    "persuasiva": "persuasivo",
    "persuasivas": "persuasivo",
    "persuasivos": "persuasivo",
    "persuasora": "persuasor",
    "persuasoras": "persuasor",
    "persuasores": "persuasor",
    "persuasória": "persuasório",
    "persuasórias": "persuasório",
    "persuasórios": "persuasório",
    "persuasões": "persuasão",
    "pertence": "pertencer",
    "pertencei": "pertencer",
    "pertenceis": "pertencer",
    "pertencem": "pertencer",
    "pertencemo": "pertencer",
    "pertencemos": "pertencer",
    "pertencendo": "pertencer",
    "pertencentes": "pertencente",
    "pertencera": "pertencer",
    "pertenceram": "pertencer",
    "pertenceras": "pertencer",
    "pertencerde": "pertencer",
    "pertencerdes": "pertencer",
    "pertencere": "pertencer",
    "pertencerei": "pertencer",
    "pertencereis": "pertencer",
    "pertencerem": "pertencer",
    "pertenceremos": "pertencer",
    "pertenceres": "pertencer",
    "pertenceria": "pertencer",
    "pertenceriam": "pertencer",
    "pertencerias": "pertencer",
    "pertencermo": "pertencer",
    "pertencermos": "pertencer",
    "pertencerá": "pertencer",
    "pertencerás": "pertencer",
    "pertencerão": "pertencer",
    "pertenceríamos": "pertencer",
    "pertenceríeis": "pertencer",
    "pertences": "pertencer",
    "pertencesse": "pertencer",
    "pertencessem": "pertencer",
    "pertencesses": "pertencer",
    "pertenceste": "pertencer",
    "pertencestes": "pertencer",
    "pertenceu": "pertencer",
    "pertenci": "pertencer",
    "pertencia": "pertencer",
    "pertenciam": "pertencer",
    "pertencias": "pertencer",
    "pertencida": "pertencer",
    "pertencidas": "pertencer",
    "pertencido": "pertencer",
    "pertencidos": "pertencer",
    "pertencê": "pertencer",
    "pertencêramo": "pertencer",
    "pertencêramos": "pertencer",
    "pertencêrei": "pertencer",
    "pertencêreis": "pertencer",
    "pertencêsseis": "pertencer",
    "pertencêssemos": "pertencer",
    "pertencíamo": "pertencer",
    "pertencíamos": "pertencer",
    "pertencíei": "pertencer",
    "pertencíeis": "pertencer",
    "pertenta": "pertentar",
    "pertentada": "pertentar",
    "pertentadas": "pertentar",
    "pertentado": "pertentar",
    "pertentados": "pertentar",
    "pertentai": "pertentar",
    "pertentais": "pertentar",
    "pertentam": "pertentar",
    "pertentamo": "pertentar",
    "pertentamos": "pertentar",
    "pertentando": "pertentar",
    "pertentara": "pertentar",
    "pertentaram": "pertentar",
    "pertentaras": "pertentar",
    "pertentarde": "pertentar",
    "pertentardes": "pertentar",
    "pertentare": "pertentar",
    "pertentarei": "pertentar",
    "pertentareis": "pertentar",
    "pertentarem": "pertentar",
    "pertentaremos": "pertentar",
    "pertentares": "pertentar",
    "pertentaria": "pertentar",
    "pertentariam": "pertentar",
    "pertentarias": "pertentar",
    "pertentarmo": "pertentar",
    "pertentarmos": "pertentar",
    "pertentará": "pertentar",
    "pertentarás": "pertentar",
    "pertentarão": "pertentar",
    "pertentaríamos": "pertentar",
    "pertentaríeis": "pertentar",
    "pertentas": "pertentar",
    "pertentasse": "pertentar",
    "pertentassem": "pertentar",
    "pertentasses": "pertentar",
    "pertentaste": "pertentar",
    "pertentastes": "pertentar",
    "pertentava": "pertentar",
    "pertentavam": "pertentar",
    "pertentavas": "pertentar",
    "pertente": "pertentar",
    "pertentei": "pertentar",
    "pertenteis": "pertentar",
    "pertentem": "pertentar",
    "pertentemo": "pertentar",
    "pertentemos": "pertentar",
    "pertentes": "pertentar",
    "pertento": "pertentar",
    "pertentou": "pertentar",
    "pertentá": "pertentar",
    "pertentámo": "pertentar",
    "pertentámos": "pertentar",
    "pertentáramo": "pertentar",
    "pertentáramos": "pertentar",
    "pertentárei": "pertentar",
    "pertentáreis": "pertentar",
    "pertentásseis": "pertentar",
    "pertentássemos": "pertentar",
    "pertentávamo": "pertentar",
    "pertentávamos": "pertentar",
    "pertentávei": "pertentar",
    "pertentáveis": "pertentar",
    "pertença": "pertencer",
    "pertençais": "pertencer",
    "pertençam": "pertencer",
    "pertençamo": "pertencer",
    "pertençamos": "pertencer",
    "pertenças": "pertencer",
    "pertenço": "pertencer",
    "pertinacíssima": "pertinaz",
    "pertinacíssimas": "pertinaz",
    "pertinacíssimo": "pertinaz",
    "pertinacíssimos": "pertinaz",
    "pertinazes": "pertinaz",
    "pertinentes": "pertinente",
    "pertinentíssima": "pertinente",
    "pertinentíssimas": "pertinente",
    "pertinentíssimo": "pertinente",
    "pertinentíssimos": "pertinente",
    "pertinho": "perto",
    "pertinácias": "pertinácia",
    "pertinências": "pertinência",
    "pertites": "pertite",
    "pertito": "perto",
    "pertransa": "pertransir",
    "pertransais": "pertransir",
    "pertransam": "pertransir",
    "pertransamo": "pertransir",
    "pertransamos": "pertransir",
    "pertransas": "pertransir",
    "pertranse": "pertransir",
    "pertransem": "pertransir",
    "pertranses": "pertransir",
    "pertransi": "pertransir",
    "pertransia": "pertransir",
    "pertransiam": "pertransir",
    "pertransias": "pertransir",
    "pertransida": "pertransir",
    "pertransidas": "pertransir",
    "pertransido": "pertransir",
    "pertransidos": "pertransir",
    "pertransimo": "pertransir",
    "pertransimos": "pertransir",
    "pertransindo": "pertransir",
    "pertransira": "pertransir",
    "pertransiram": "pertransir",
    "pertransiras": "pertransir",
    "pertransirde": "pertransir",
    "pertransirdes": "pertransir",
    "pertransire": "pertransir",
    "pertransirei": "pertransir",
    "pertransireis": "pertransir",
    "pertransirem": "pertransir",
    "pertransiremos": "pertransir",
    "pertransires": "pertransir",
    "pertransiria": "pertransir",
    "pertransiriam": "pertransir",
    "pertransirias": "pertransir",
    "pertransirmo": "pertransir",
    "pertransirmos": "pertransir",
    "pertransirá": "pertransir",
    "pertransirás": "pertransir",
    "pertransirão": "pertransir",
    "pertransiríamos": "pertransir",
    "pertransiríeis": "pertransir",
    "pertransis": "pertransir",
    "pertransisse": "pertransir",
    "pertransissem": "pertransir",
    "pertransisses": "pertransir",
    "pertransiste": "pertransir",
    "pertransistes": "pertransir",
    "pertransiu": "pertransir",
    "pertranso": "pertransir",
    "pertransíamo": "pertransir",
    "pertransíamos": "pertransir",
    "pertransíei": "pertransir",
    "pertransíeis": "pertransir",
    "pertransíramo": "pertransir",
    "pertransíramos": "pertransir",
    "pertransírei": "pertransir",
    "pertransíreis": "pertransir",
    "pertransísseis": "pertransir",
    "pertransíssemos": "pertransir",
    "perturba": "perturbar",
    "perturbabilidades": "perturbabilidade",
    "perturbada": "perturbar",
    "perturbadas": "perturbar",
    "perturbadinha": "perturbado",
    "perturbadinhas": "perturbado",
    "perturbadinho": "perturbado",
    "perturbadinhos": "perturbado",
    "perturbadita": "perturbado",
    "perturbaditas": "perturbado",
    "perturbadito": "perturbado",
    "perturbaditos": "perturbado",
    "perturbado": "perturbar",
    "perturbadora": "perturbador",
    "perturbadoras": "perturbador",
    "perturbadores": "perturbador",
    "perturbados": "perturbar",
    "perturbadíssima": "perturbado",
    "perturbadíssimas": "perturbado",
    "perturbadíssimo": "perturbado",
    "perturbadíssimos": "perturbado",
    "perturbai": "perturbar",
    "perturbais": "perturbar",
    "perturbam": "perturbar",
    "perturbamo": "perturbar",
    "perturbamos": "perturbar",
    "perturbando": "perturbar",
    "perturbantes": "perturbante",
    "perturbantíssima": "perturbante",
    "perturbantíssimas": "perturbante",
    "perturbantíssimo": "perturbante",
    "perturbantíssimos": "perturbante",
    "perturbara": "perturbar",
    "perturbaram": "perturbar",
    "perturbaras": "perturbar",
    "perturbarde": "perturbar",
    "perturbardes": "perturbar",
    "perturbare": "perturbar",
    "perturbarei": "perturbar",
    "perturbareis": "perturbar",
    "perturbarem": "perturbar",
    "perturbaremos": "perturbar",
    "perturbares": "perturbar",
    "perturbaria": "perturbar",
    "perturbariam": "perturbar",
    "perturbarias": "perturbar",
    "perturbarmo": "perturbar",
    "perturbarmos": "perturbar",
    "perturbará": "perturbar",
    "perturbarás": "perturbar",
    "perturbarão": "perturbar",
    "perturbaríamos": "perturbar",
    "perturbaríeis": "perturbar",
    "perturbas": "perturbar",
    "perturbasse": "perturbar",
    "perturbassem": "perturbar",
    "perturbasses": "perturbar",
    "perturbaste": "perturbar",
    "perturbastes": "perturbar",
    "perturbativa": "perturbativo",
    "perturbativas": "perturbativo",
    "perturbativos": "perturbativo",
    "perturbatória": "perturbatório",
    "perturbatórias": "perturbatório",
    "perturbatórios": "perturbatório",
    "perturbava": "perturbar",
    "perturbavam": "perturbar",
    "perturbavas": "perturbar",
    "perturbações": "perturbação",
    "perturbe": "perturbar",
    "perturbei": "perturbar",
    "perturbeis": "perturbar",
    "perturbem": "perturbar",
    "perturbemo": "perturbar",
    "perturbemos": "perturbar",
    "perturbes": "perturbar",
    "perturbo": "perturbar",
    "perturbou": "perturbar",
    "perturbá": "perturbar",
    "perturbámo": "perturbar",
    "perturbámos": "perturbar",
    "perturbáramo": "perturbar",
    "perturbáramos": "perturbar",
    "perturbárei": "perturbar",
    "perturbáreis": "perturbar",
    "perturbásseis": "perturbar",
    "perturbássemos": "perturbar",
    "perturbávamo": "perturbar",
    "perturbávamos": "perturbar",
    "perturbávei": "perturbar",
    "perturbáveis": "perturbável",
    "pertíssimo": "perto",
    "perua": "peru",
    "peruana": "peruano",
    "peruanas": "peruano",
    "peruanos": "peruano",
    "peruas": "peru",
    "perucas": "peruca",
    "perueira": "perueiro",
    "perueiras": "perueiro",
    "perueiros": "perueiro",
    "perulada": "perulado",
    "peruladas": "perulado",
    "perulados": "perulado",
    "perus": "peru",
    "peruviana": "peruviano",
    "peruvianas": "peruviano",
    "peruvianos": "peruviano",
    "pervaga": "pervagar",
    "pervagada": "pervagar",
    "pervagadas": "pervagar",
    "pervagado": "pervagar",
    "pervagados": "pervagar",
    "pervagai": "pervagar",
    "pervagais": "pervagar",
    "pervagam": "pervagar",
    "pervagamo": "pervagar",
    "pervagamos": "pervagar",
    "pervagando": "pervagar",
    "pervagara": "pervagar",
    "pervagaram": "pervagar",
    "pervagaras": "pervagar",
    "pervagarde": "pervagar",
    "pervagardes": "pervagar",
    "pervagare": "pervagar",
    "pervagarei": "pervagar",
    "pervagareis": "pervagar",
    "pervagarem": "pervagar",
    "pervagaremos": "pervagar",
    "pervagares": "pervagar",
    "pervagaria": "pervagar",
    "pervagariam": "pervagar",
    "pervagarias": "pervagar",
    "pervagarmo": "pervagar",
    "pervagarmos": "pervagar",
    "pervagará": "pervagar",
    "pervagarás": "pervagar",
    "pervagarão": "pervagar",
    "pervagaríamos": "pervagar",
    "pervagaríeis": "pervagar",
    "pervagas": "pervagar",
    "pervagasse": "pervagar",
    "pervagassem": "pervagar",
    "pervagasses": "pervagar",
    "pervagaste": "pervagar",
    "pervagastes": "pervagar",
    "pervagava": "pervagar",
    "pervagavam": "pervagar",
    "pervagavas": "pervagar",
    "pervago": "pervagar",
    "pervagou": "pervagar",
    "pervague": "pervagar",
    "pervaguei": "pervagar",
    "pervagueis": "pervagar",
    "pervaguem": "pervagar",
    "pervaguemo": "pervagar",
    "pervaguemos": "pervagar",
    "pervagues": "pervagar",
    "pervagá": "pervagar",
    "pervagámo": "pervagar",
    "pervagámos": "pervagar",
    "pervagáramo": "pervagar",
    "pervagáramos": "pervagar",
    "pervagárei": "pervagar",
    "pervagáreis": "pervagar",
    "pervagásseis": "pervagar",
    "pervagássemos": "pervagar",
    "pervagávamo": "pervagar",
    "pervagávamos": "pervagar",
    "pervagávei": "pervagar",
    "pervagáveis": "pervagar",
    "perversa": "perverso",
    "perversas": "perverso",
    "perversidades": "perversidade",
    "perversora": "perversor",
    "perversoras": "perversor",
    "perversores": "perversor",
    "perversos": "perverso",
    "perversíssima": "perverso",
    "perversíssimas": "perverso",
    "perversíssimo": "perverso",
    "perversíssimos": "perverso",
    "perversões": "perversão",
    "perverta": "perverter",
    "pervertais": "perverter",
    "pervertam": "perverter",
    "pervertamo": "perverter",
    "pervertamos": "perverter",
    "pervertas": "perverter",
    "perverte": "perverter",
    "pervertedora": "pervertedor",
    "pervertedoras": "pervertedor",
    "pervertedores": "pervertedor",
    "pervertei": "perverter",
    "perverteis": "perverter",
    "pervertem": "perverter",
    "pervertemo": "perverter",
    "pervertemos": "perverter",
    "pervertendo": "perverter",
    "pervertera": "perverter",
    "perverteram": "perverter",
    "perverteras": "perverter",
    "perverterde": "perverter",
    "perverterdes": "perverter",
    "pervertere": "perverter",
    "perverterei": "perverter",
    "pervertereis": "perverter",
    "perverterem": "perverter",
    "perverteremos": "perverter",
    "perverteres": "perverter",
    "perverteria": "perverter",
    "perverteriam": "perverter",
    "perverterias": "perverter",
    "pervertermo": "perverter",
    "pervertermos": "perverter",
    "perverterá": "perverter",
    "perverterás": "perverter",
    "perverterão": "perverter",
    "perverteríamos": "perverter",
    "perverteríeis": "perverter",
    "pervertes": "perverter",
    "pervertesse": "perverter",
    "pervertessem": "perverter",
    "pervertesses": "perverter",
    "perverteste": "perverter",
    "pervertestes": "perverter",
    "perverteu": "perverter",
    "perverti": "perverter",
    "pervertia": "perverter",
    "pervertiam": "perverter",
    "pervertias": "perverter",
    "pervertida": "pervertido",
    "pervertidas": "pervertido",
    "pervertido": "perverter",
    "pervertidoes": "pervertido",
    "pervertidos": "pervertido",
    "perverto": "perverter",
    "pervertê": "perverter",
    "pervertêramo": "perverter",
    "pervertêramos": "perverter",
    "pervertêrei": "perverter",
    "pervertêreis": "perverter",
    "pervertêsseis": "perverter",
    "pervertêssemos": "perverter",
    "pervertíamo": "perverter",
    "pervertíamos": "perverter",
    "pervertíei": "perverter",
    "pervertíeis": "perverter",
    "pervicazes": "pervicaz",
    "pervicácias": "pervicácia",
    "pervigílias": "pervigília",
    "pervincas": "pervinca",
    "pervincos": "pervinco",
    "pervígis": "pervígil",
    "perxinas": "perxina",
    "períbolos": "períbolo",
    "perícias": "perícia",
    "períclases": "períclase",
    "perídromos": "perídromo",
    "perífrases": "perífrase",
    "perímetros": "perímetro",
    "perínea": "períneo",
    "períneas": "períneo",
    "períneos": "períneo",
    "períodos": "período",
    "perípatos": "perípato",
    "períptera": "períptero",
    "perípteras": "períptero",
    "perípteros": "períptero",
    "períscios": "períscio",
    "perístases": "perístase",
    "perístomas": "perístoma",
    "perónios": "perónio",
    "peróxidos": "peróxido",
    "pesa": "pesar",
    "pesada": "pesar",
    "pesadas": "pesar",
    "pesadelos": "pesadelo",
    "pesadinha": "pesado",
    "pesadinhas": "pesado",
    "pesadinho": "pesado",
    "pesadinhos": "pesado",
    "pesadita": "pesado",
    "pesaditas": "pesado",
    "pesadito": "pesado",
    "pesaditos": "pesado",
    "pesado": "pesar",
    "pesadora": "pesador",
    "pesadoras": "pesadora",
    "pesadores": "pesador",
    "pesados": "pesar",
    "pesadota": "pesadote",
    "pesadotas": "pesadote",
    "pesadotes": "pesadote",
    "pesadumes": "pesadume",
    "pesadíssima": "pesado",
    "pesadíssimas": "pesado",
    "pesadíssimo": "pesado",
    "pesadíssimos": "pesado",
    "pesagens": "pesagem",
    "pesai": "pesar",
    "pesais": "pesar",
    "pesam": "pesar",
    "pesamo": "pesar",
    "pesamos": "pesar",
    "pesando": "pesar",
    "pesara": "pesar",
    "pesaram": "pesar",
    "pesaras": "pesar",
    "pesarde": "pesar",
    "pesardes": "pesar",
    "pesare": "pesar",
    "pesarei": "pesar",
    "pesareis": "pesar",
    "pesarem": "pesar",
    "pesaremos": "pesar",
    "pesares": "pesar",
    "pesaria": "pesar",
    "pesariam": "pesar",
    "pesarias": "pesar",
    "pesarmo": "pesar",
    "pesarmos": "pesar",
    "pesarosa": "pesaroso",
    "pesarosas": "pesaroso",
    "pesarosos": "pesaroso",
    "pesarosíssima": "pesaroso",
    "pesarosíssimas": "pesaroso",
    "pesarosíssimo": "pesaroso",
    "pesarosíssimos": "pesaroso",
    "pesará": "pesar",
    "pesarás": "pesar",
    "pesarão": "pesar",
    "pesaríamos": "pesar",
    "pesaríeis": "pesar",
    "pesas": "pesar",
    "pesasse": "pesar",
    "pesassem": "pesar",
    "pesasses": "pesar",
    "pesaste": "pesar",
    "pesastes": "pesar",
    "pesava": "pesar",
    "pesavam": "pesar",
    "pesavas": "pesar",
    "pesca": "pescar",
    "pescada": "pescar",
    "pescadarias": "pescadaria",
    "pescadas": "pescar",
    "pescadinha": "pescada",
    "pescadinhas": "pescadinha",
    "pescadita": "pescada",
    "pescaditas": "pescada",
    "pescado": "pescar",
    "pescadora": "pescador",
    "pescadoras": "pescador",
    "pescadores": "pescador",
    "pescados": "pescar",
    "pescai": "pescar",
    "pescais": "pescar",
    "pescam": "pescar",
    "pescamo": "pescar",
    "pescamos": "pescar",
    "pescando": "pescar",
    "pescanços": "pescanço",
    "pescara": "pescar",
    "pescaram": "pescar",
    "pescaras": "pescar",
    "pescarde": "pescar",
    "pescardes": "pescar",
    "pescare": "pescar",
    "pescarei": "pescar",
    "pescareis": "pescar",
    "pescarem": "pescar",
    "pescaremos": "pescar",
    "pescares": "pescar",
    "pescaria": "pescar",
    "pescariam": "pescar",
    "pescarias": "pescaria",
    "pescarmo": "pescar",
    "pescarmos": "pescar",
    "pescará": "pescar",
    "pescarás": "pescar",
    "pescarão": "pescar",
    "pescaríamos": "pescar",
    "pescaríeis": "pescar",
    "pescas": "pescar",
    "pescasse": "pescar",
    "pescassem": "pescar",
    "pescasses": "pescar",
    "pescaste": "pescar",
    "pescastes": "pescar",
    "pescava": "pescar",
    "pescavam": "pescar",
    "pescavas": "pescar",
    "pescazes": "pescaz",
    "pesco": "pescar",
    "pescoceiras": "pescoceira",
    "pescocinho": "pescoço",
    "pescocinhos": "pescoço",
    "pescocito": "pescoço",
    "pescocitos": "pescoço",
    "pescou": "pescar",
    "pescoçadas": "pescoçada",
    "pescoços": "pescoço",
    "pescoçuda": "pescoçudo",
    "pescoçudas": "pescoçudo",
    "pescoçudos": "pescoçudo",
    "pescoções": "pescoção",
    "pescá": "pescar",
    "pescámo": "pescar",
    "pescámos": "pescar",
    "pescáramo": "pescar",
    "pescáramos": "pescar",
    "pescárei": "pescar",
    "pescáreis": "pescar",
    "pescásseis": "pescar",
    "pescássemos": "pescar",
    "pescávamo": "pescar",
    "pescávamos": "pescar",
    "pescávei": "pescar",
    "pescáveis": "pescar",
    "pescócias": "pescócia",
    "pese": "pesar",
    "pesebres": "pesebre",
    "pesei": "pesar",
    "peseis": "pesar",
    "pesem": "pesar",
    "pesemo": "pesar",
    "pesemos": "pesar",
    "peses": "pesar",
    "pesetas": "peseta",
    "pesga": "pesgar",
    "pesgada": "pesgar",
    "pesgadas": "pesgar",
    "pesgado": "pesgar",
    "pesgados": "pesgar",
    "pesgai": "pesgar",
    "pesgais": "pesgar",
    "pesgam": "pesgar",
    "pesgamo": "pesgar",
    "pesgamos": "pesgar",
    "pesgando": "pesgar",
    "pesgara": "pesgar",
    "pesgaram": "pesgar",
    "pesgaras": "pesgar",
    "pesgarde": "pesgar",
    "pesgardes": "pesgar",
    "pesgare": "pesgar",
    "pesgarei": "pesgar",
    "pesgareis": "pesgar",
    "pesgarem": "pesgar",
    "pesgaremos": "pesgar",
    "pesgares": "pesgar",
    "pesgaria": "pesgar",
    "pesgariam": "pesgar",
    "pesgarias": "pesgar",
    "pesgarmo": "pesgar",
    "pesgarmos": "pesgar",
    "pesgará": "pesgar",
    "pesgarás": "pesgar",
    "pesgarão": "pesgar",
    "pesgaríamos": "pesgar",
    "pesgaríeis": "pesgar",
    "pesgas": "pesgar",
    "pesgasse": "pesgar",
    "pesgassem": "pesgar",
    "pesgasses": "pesgar",
    "pesgaste": "pesgar",
    "pesgastes": "pesgar",
    "pesgava": "pesgar",
    "pesgavam": "pesgar",
    "pesgavas": "pesgar",
    "pesgo": "pesgar",
    "pesgou": "pesgar",
    "pesgue": "pesgar",
    "pesguei": "pesgar",
    "pesgueis": "pesgar",
    "pesguem": "pesgar",
    "pesguemo": "pesgar",
    "pesguemos": "pesgar",
    "pesgues": "pesgar",
    "pesgá": "pesgar",
    "pesgámo": "pesgar",
    "pesgámos": "pesgar",
    "pesgáramo": "pesgar",
    "pesgáramos": "pesgar",
    "pesgárei": "pesgar",
    "pesgáreis": "pesgar",
    "pesgásseis": "pesgar",
    "pesgássemos": "pesgar",
    "pesgávamo": "pesgar",
    "pesgávamos": "pesgar",
    "pesgávei": "pesgar",
    "pesgáveis": "pesgar",
    "peso": "pesar",
    "pesos": "peso",
    "pesou": "pesar",
    "pespega": "pespegar",
    "pespegada": "pespegar",
    "pespegadas": "pespegar",
    "pespegado": "pespegar",
    "pespegados": "pespegar",
    "pespegai": "pespegar",
    "pespegais": "pespegar",
    "pespegam": "pespegar",
    "pespegamo": "pespegar",
    "pespegamos": "pespegar",
    "pespegando": "pespegar",
    "pespegara": "pespegar",
    "pespegaram": "pespegar",
    "pespegaras": "pespegar",
    "pespegarde": "pespegar",
    "pespegardes": "pespegar",
    "pespegare": "pespegar",
    "pespegarei": "pespegar",
    "pespegareis": "pespegar",
    "pespegarem": "pespegar",
    "pespegaremos": "pespegar",
    "pespegares": "pespegar",
    "pespegaria": "pespegar",
    "pespegariam": "pespegar",
    "pespegarias": "pespegar",
    "pespegarmo": "pespegar",
    "pespegarmos": "pespegar",
    "pespegará": "pespegar",
    "pespegarás": "pespegar",
    "pespegarão": "pespegar",
    "pespegaríamos": "pespegar",
    "pespegaríeis": "pespegar",
    "pespegas": "pespegar",
    "pespegasse": "pespegar",
    "pespegassem": "pespegar",
    "pespegasses": "pespegar",
    "pespegaste": "pespegar",
    "pespegastes": "pespegar",
    "pespegava": "pespegar",
    "pespegavam": "pespegar",
    "pespegavas": "pespegar",
    "pespego": "pespegar",
    "pespegos": "pespego",
    "pespegou": "pespegar",
    "pespegue": "pespegar",
    "pespeguei": "pespegar",
    "pespegueis": "pespegar",
    "pespeguem": "pespegar",
    "pespeguemo": "pespegar",
    "pespeguemos": "pespegar",
    "pespegues": "pespegar",
    "pespegá": "pespegar",
    "pespegámo": "pespegar",
    "pespegámos": "pespegar",
    "pespegáramo": "pespegar",
    "pespegáramos": "pespegar",
    "pespegárei": "pespegar",
    "pespegáreis": "pespegar",
    "pespegásseis": "pespegar",
    "pespegássemos": "pespegar",
    "pespegávamo": "pespegar",
    "pespegávamos": "pespegar",
    "pespegávei": "pespegar",
    "pespegáveis": "pespegar",
    "pespitas": "pespita",
    "pesponta": "pespontar",
    "pespontada": "pespontar",
    "pespontadas": "pespontar",
    "pespontado": "pespontar",
    "pespontados": "pespontar",
    "pespontai": "pespontar",
    "pespontais": "pespontar",
    "pespontam": "pespontar",
    "pespontamo": "pespontar",
    "pespontamos": "pespontar",
    "pespontando": "pespontar",
    "pespontara": "pespontar",
    "pespontaram": "pespontar",
    "pespontaras": "pespontar",
    "pespontarde": "pespontar",
    "pespontardes": "pespontar",
    "pespontare": "pespontar",
    "pespontarei": "pespontar",
    "pespontareis": "pespontar",
    "pespontarem": "pespontar",
    "pespontaremos": "pespontar",
    "pespontares": "pespontar",
    "pespontaria": "pespontar",
    "pespontariam": "pespontar",
    "pespontarias": "pespontar",
    "pespontarmo": "pespontar",
    "pespontarmos": "pespontar",
    "pespontará": "pespontar",
    "pespontarás": "pespontar",
    "pespontarão": "pespontar",
    "pespontaríamos": "pespontar",
    "pespontaríeis": "pespontar",
    "pespontas": "pespontar",
    "pespontasse": "pespontar",
    "pespontassem": "pespontar",
    "pespontasses": "pespontar",
    "pespontaste": "pespontar",
    "pespontastes": "pespontar",
    "pespontava": "pespontar",
    "pespontavam": "pespontar",
    "pespontavas": "pespontar",
    "pesponte": "pespontar",
    "pesponteada": "pespontear",
    "pesponteadas": "pespontear",
    "pesponteado": "pespontear",
    "pesponteados": "pespontear",
    "pesponteai": "pespontear",
    "pesponteais": "pespontear",
    "pesponteamo": "pespontear",
    "pesponteamos": "pespontear",
    "pesponteando": "pespontear",
    "pesponteara": "pespontear",
    "pespontearam": "pespontear",
    "pespontearas": "pespontear",
    "pespontearde": "pespontear",
    "pesponteardes": "pespontear",
    "pesponteare": "pespontear",
    "pespontearei": "pespontear",
    "pesponteareis": "pespontear",
    "pespontearem": "pespontear",
    "pespontearemos": "pespontear",
    "pesponteares": "pespontear",
    "pespontearia": "pespontear",
    "pesponteariam": "pespontear",
    "pespontearias": "pespontear",
    "pespontearmo": "pespontear",
    "pespontearmos": "pespontear",
    "pesponteará": "pespontear",
    "pespontearás": "pespontear",
    "pespontearão": "pespontear",
    "pespontearíamos": "pespontear",
    "pespontearíeis": "pespontear",
    "pesponteasse": "pespontear",
    "pesponteassem": "pespontear",
    "pesponteasses": "pespontear",
    "pesponteaste": "pespontear",
    "pesponteastes": "pespontear",
    "pesponteava": "pespontear",
    "pesponteavam": "pespontear",
    "pesponteavas": "pespontear",
    "pesponteei": "pespontear",
    "pesponteeis": "pespontear",
    "pesponteemo": "pespontear",
    "pesponteemos": "pespontear",
    "pespontei": "pespontar",
    "pesponteia": "pespontear",
    "pesponteiam": "pespontear",
    "pesponteias": "pespontear",
    "pesponteie": "pespontear",
    "pesponteiem": "pespontear",
    "pesponteies": "pespontear",
    "pesponteio": "pespontear",
    "pesponteis": "pespontar",
    "pespontem": "pespontar",
    "pespontemo": "pespontar",
    "pespontemos": "pespontar",
    "pesponteou": "pespontear",
    "pespontes": "pespontar",
    "pesponteá": "pespontear",
    "pesponteámo": "pespontear",
    "pesponteámos": "pespontear",
    "pesponteáramo": "pespontear",
    "pesponteáramos": "pespontear",
    "pesponteárei": "pespontear",
    "pesponteáreis": "pespontear",
    "pesponteásseis": "pespontear",
    "pesponteássemos": "pespontear",
    "pesponteávamo": "pespontear",
    "pesponteávamos": "pespontear",
    "pesponteávei": "pespontear",
    "pesponteáveis": "pespontear",
    "pesponto": "pespontar",
    "pespontos": "pesponto",
    "pespontou": "pespontar",
    "pespontá": "pespontar",
    "pespontámo": "pespontar",
    "pespontámos": "pespontar",
    "pespontáramo": "pespontar",
    "pespontáramos": "pespontar",
    "pespontárei": "pespontar",
    "pespontáreis": "pespontar",
    "pespontásseis": "pespontar",
    "pespontássemos": "pespontar",
    "pespontávamo": "pespontar",
    "pespontávamos": "pespontar",
    "pespontávei": "pespontar",
    "pespontáveis": "pespontar",
    "pesporrentes": "pesporrente",
    "pesporrências": "pesporrência",
    "pesque": "pescar",
    "pesquei": "pescar",
    "pesqueira": "pesqueiro",
    "pesqueiras": "pesqueiro",
    "pesqueiros": "pesqueiro",
    "pesqueis": "pescar",
    "pesquem": "pescar",
    "pesquemo": "pescar",
    "pesquemos": "pescar",
    "pesques": "pescar",
    "pesquisa": "pesquisar",
    "pesquisada": "pesquisar",
    "pesquisadas": "pesquisar",
    "pesquisado": "pesquisar",
    "pesquisadora": "pesquisador",
    "pesquisadoras": "pesquisador",
    "pesquisadores": "pesquisador",
    "pesquisados": "pesquisar",
    "pesquisai": "pesquisar",
    "pesquisais": "pesquisar",
    "pesquisam": "pesquisar",
    "pesquisamo": "pesquisar",
    "pesquisamos": "pesquisar",
    "pesquisando": "pesquisar",
    "pesquisara": "pesquisar",
    "pesquisaram": "pesquisar",
    "pesquisaras": "pesquisar",
    "pesquisarde": "pesquisar",
    "pesquisardes": "pesquisar",
    "pesquisare": "pesquisar",
    "pesquisarei": "pesquisar",
    "pesquisareis": "pesquisar",
    "pesquisarem": "pesquisar",
    "pesquisaremos": "pesquisar",
    "pesquisares": "pesquisar",
    "pesquisaria": "pesquisar",
    "pesquisariam": "pesquisar",
    "pesquisarias": "pesquisar",
    "pesquisarmo": "pesquisar",
    "pesquisarmos": "pesquisar",
    "pesquisará": "pesquisar",
    "pesquisarás": "pesquisar",
    "pesquisarão": "pesquisar",
    "pesquisaríamos": "pesquisar",
    "pesquisaríeis": "pesquisar",
    "pesquisas": "pesquisar",
    "pesquisasse": "pesquisar",
    "pesquisassem": "pesquisar",
    "pesquisasses": "pesquisar",
    "pesquisaste": "pesquisar",
    "pesquisastes": "pesquisar",
    "pesquisava": "pesquisar",
    "pesquisavam": "pesquisar",
    "pesquisavas": "pesquisar",
    "pesquise": "pesquisar",
    "pesquisei": "pesquisar",
    "pesquiseis": "pesquisar",
    "pesquisem": "pesquisar",
    "pesquisemo": "pesquisar",
    "pesquisemos": "pesquisar",
    "pesquises": "pesquisar",
    "pesquiso": "pesquisar",
    "pesquisou": "pesquisar",
    "pesquisá": "pesquisar",
    "pesquisámo": "pesquisar",
    "pesquisámos": "pesquisar",
    "pesquisáramo": "pesquisar",
    "pesquisáramos": "pesquisar",
    "pesquisárei": "pesquisar",
    "pesquisáreis": "pesquisar",
    "pesquisásseis": "pesquisar",
    "pesquisássemos": "pesquisar",
    "pesquisávamo": "pesquisar",
    "pesquisávamos": "pesquisar",
    "pesquisávei": "pesquisar",
    "pesquisáveis": "pesquisável",
    "pessegadas": "pessegada",
    "pessegais": "pessegal",
    "pessegueiros": "pessegueiro",
    "pessimismos": "pessimismo",
    "pessimistas": "pessimista",
    "pessoais": "pessoal",
    "pessoales": "pessoal",
    "pessoalidades": "pessoalidade",
    "pessoalismos": "pessoalismo",
    "pessoalistas": "pessoalista",
    "pessoalizada": "pessoalizado",
    "pessoalizadas": "pessoalizado",
    "pessoalizados": "pessoalizado",
    "pessoalizações": "pessoalização",
    "pessoana": "pessoano",
    "pessoanas": "pessoano",
    "pessoanos": "pessoano",
    "pessoas": "pessoa",
    "pessoeiros": "pessoeiro",
    "pessários": "pessário",
    "pestanas": "pestana",
    "pestaneada": "pestanear",
    "pestaneadas": "pestanear",
    "pestaneado": "pestanear",
    "pestaneados": "pestanear",
    "pestaneai": "pestanear",
    "pestaneais": "pestanear",
    "pestaneamo": "pestanear",
    "pestaneamos": "pestanear",
    "pestaneando": "pestanear",
    "pestaneara": "pestanear",
    "pestanearam": "pestanear",
    "pestanearas": "pestanear",
    "pestaneardes": "pestanear",
    "pestanearei": "pestanear",
    "pestaneareis": "pestanear",
    "pestanearem": "pestanear",
    "pestanearemos": "pestanear",
    "pestaneares": "pestanear",
    "pestanearia": "pestanear",
    "pestaneariam": "pestanear",
    "pestanearias": "pestanear",
    "pestanearmo": "pestanear",
    "pestanearmos": "pestanear",
    "pestaneará": "pestanear",
    "pestanearás": "pestanear",
    "pestanearão": "pestanear",
    "pestanearíamos": "pestanear",
    "pestanearíeis": "pestanear",
    "pestaneasse": "pestanear",
    "pestaneassem": "pestanear",
    "pestaneasses": "pestanear",
    "pestaneaste": "pestanear",
    "pestaneastes": "pestanear",
    "pestaneava": "pestanear",
    "pestaneavam": "pestanear",
    "pestaneavas": "pestanear",
    "pestaneei": "pestanear",
    "pestaneeis": "pestanear",
    "pestaneemo": "pestanear",
    "pestaneemos": "pestanear",
    "pestaneia": "pestanear",
    "pestaneiam": "pestanear",
    "pestaneias": "pestanear",
    "pestaneie": "pestanear",
    "pestaneiem": "pestanear",
    "pestaneies": "pestanear",
    "pestaneio": "pestanear",
    "pestaneja": "pestanejar",
    "pestanejada": "pestanejar",
    "pestanejadas": "pestanejar",
    "pestanejado": "pestanejar",
    "pestanejados": "pestanejar",
    "pestanejai": "pestanejar",
    "pestanejais": "pestanejar",
    "pestanejam": "pestanejar",
    "pestanejamo": "pestanejar",
    "pestanejamos": "pestanejar",
    "pestanejando": "pestanejar",
    "pestanejantes": "pestanejante",
    "pestanejara": "pestanejar",
    "pestanejaram": "pestanejar",
    "pestanejaras": "pestanejar",
    "pestanejardes": "pestanejar",
    "pestanejarei": "pestanejar",
    "pestanejareis": "pestanejar",
    "pestanejarem": "pestanejar",
    "pestanejaremos": "pestanejar",
    "pestanejares": "pestanejar",
    "pestanejaria": "pestanejar",
    "pestanejariam": "pestanejar",
    "pestanejarias": "pestanejar",
    "pestanejarmo": "pestanejar",
    "pestanejarmos": "pestanejar",
    "pestanejará": "pestanejar",
    "pestanejarás": "pestanejar",
    "pestanejarão": "pestanejar",
    "pestanejaríamos": "pestanejar",
    "pestanejaríeis": "pestanejar",
    "pestanejas": "pestanejar",
    "pestanejasse": "pestanejar",
    "pestanejassem": "pestanejar",
    "pestanejasses": "pestanejar",
    "pestanejaste": "pestanejar",
    "pestanejastes": "pestanejar",
    "pestanejava": "pestanejar",
    "pestanejavam": "pestanejar",
    "pestanejavas": "pestanejar",
    "pestaneje": "pestanejar",
    "pestanejei": "pestanejar",
    "pestanejeis": "pestanejar",
    "pestanejem": "pestanejar",
    "pestanejemo": "pestanejar",
    "pestanejemos": "pestanejar",
    "pestanejes": "pestanejar",
    "pestanejo": "pestanejar",
    "pestanejos": "pestanejo",
    "pestanejou": "pestanejar",
    "pestanejámo": "pestanejar",
    "pestanejámos": "pestanejar",
    "pestanejáramo": "pestanejar",
    "pestanejáramos": "pestanejar",
    "pestanejáreis": "pestanejar",
    "pestanejásseis": "pestanejar",
    "pestanejássemos": "pestanejar",
    "pestanejávamo": "pestanejar",
    "pestanejávamos": "pestanejar",
    "pestanejáveis": "pestanejar",
    "pestaneou": "pestanear",
    "pestaneámo": "pestanear",
    "pestaneámos": "pestanear",
    "pestaneáramo": "pestanear",
    "pestaneáramos": "pestanear",
    "pestaneáreis": "pestanear",
    "pestaneásseis": "pestanear",
    "pestaneássemos": "pestanear",
    "pestaneávamo": "pestanear",
    "pestaneávamos": "pestanear",
    "pestaneáveis": "pestanear",
    "pestanuda": "pestanudo",
    "pestanudas": "pestanudo",
    "pestanudazinha": "pestanudo",
    "pestanudazinhas": "pestanudo",
    "pestanudazita": "pestanudo",
    "pestanudazitas": "pestanudo",
    "pestanudinha": "pestanudo",
    "pestanudinhas": "pestanudo",
    "pestanudinho": "pestanudo",
    "pestanudinhos": "pestanudo",
    "pestanudita": "pestanudo",
    "pestanuditas": "pestanudo",
    "pestanudito": "pestanudo",
    "pestanuditos": "pestanudo",
    "pestanudos": "pestanudo",
    "pestanudozinho": "pestanudo",
    "pestanudozinhos": "pestanudo",
    "pestanudozito": "pestanudo",
    "pestanudozitos": "pestanudo",
    "pestes": "peste",
    "pesticidas": "pesticida",
    "pestifera": "pestiferar",
    "pestiferada": "pestiferar",
    "pestiferadas": "pestiferar",
    "pestiferado": "pestiferar",
    "pestiferados": "pestiferar",
    "pestiferai": "pestiferar",
    "pestiferais": "pestiferar",
    "pestiferam": "pestiferar",
    "pestiferamo": "pestiferar",
    "pestiferamos": "pestiferar",
    "pestiferando": "pestiferar",
    "pestiferara": "pestiferar",
    "pestiferaram": "pestiferar",
    "pestiferaras": "pestiferar",
    "pestiferarde": "pestiferar",
    "pestiferardes": "pestiferar",
    "pestiferare": "pestiferar",
    "pestiferarei": "pestiferar",
    "pestiferareis": "pestiferar",
    "pestiferarem": "pestiferar",
    "pestiferaremos": "pestiferar",
    "pestiferares": "pestiferar",
    "pestiferaria": "pestiferar",
    "pestiferariam": "pestiferar",
    "pestiferarias": "pestiferar",
    "pestiferarmo": "pestiferar",
    "pestiferarmos": "pestiferar",
    "pestiferará": "pestiferar",
    "pestiferarás": "pestiferar",
    "pestiferarão": "pestiferar",
    "pestiferaríamos": "pestiferar",
    "pestiferaríeis": "pestiferar",
    "pestiferas": "pestiferar",
    "pestiferasse": "pestiferar",
    "pestiferassem": "pestiferar",
    "pestiferasses": "pestiferar",
    "pestiferaste": "pestiferar",
    "pestiferastes": "pestiferar",
    "pestiferava": "pestiferar",
    "pestiferavam": "pestiferar",
    "pestiferavas": "pestiferar",
    "pestifere": "pestiferar",
    "pestiferei": "pestiferar",
    "pestifereis": "pestiferar",
    "pestiferem": "pestiferar",
    "pestiferemo": "pestiferar",
    "pestiferemos": "pestiferar",
    "pestiferes": "pestiferar",
    "pestifero": "pestiferar",
    "pestiferou": "pestiferar",
    "pestiferá": "pestiferar",
    "pestiferámo": "pestiferar",
    "pestiferámos": "pestiferar",
    "pestiferáramo": "pestiferar",
    "pestiferáramos": "pestiferar",
    "pestiferárei": "pestiferar",
    "pestiferáreis": "pestiferar",
    "pestiferásseis": "pestiferar",
    "pestiferássemos": "pestiferar",
    "pestiferávamo": "pestiferar",
    "pestiferávamos": "pestiferar",
    "pestiferávei": "pestiferar",
    "pestiferáveis": "pestiferar",
    "pestilenciais": "pestilencial",
    "pestilenciosa": "pestilencioso",
    "pestilenciosas": "pestilencioso",
    "pestilenciosos": "pestilencioso",
    "pestilenta": "pestilento",
    "pestilentas": "pestilento",
    "pestilentos": "pestilento",
    "pestilos": "pestilo",
    "pestilências": "pestilência",
    "pestosa": "pestoso",
    "pestosas": "pestoso",
    "pestosos": "pestoso",
    "pestífera": "pestífero",
    "pestíferas": "pestífero",
    "pestíferos": "pestífero",
    "pesá": "pesar",
    "pesámo": "pesar",
    "pesámos": "pesar",
    "pesáramo": "pesar",
    "pesáramos": "pesar",
    "pesárei": "pesar",
    "pesáreis": "pesar",
    "pesásseis": "pesar",
    "pesássemos": "pesar",
    "pesávamo": "pesar",
    "pesávamos": "pesar",
    "pesávei": "pesar",
    "pesáveis": "pesar",
    "peta": "peto",
    "petada": "petar",
    "petadas": "petar",
    "petado": "petar",
    "petados": "petar",
    "petai": "petar",
    "petais": "petar",
    "petalada": "petalado",
    "petaladas": "petalado",
    "petalados": "petalado",
    "petaliformes": "petaliforme",
    "petalites": "petalite",
    "petalítica": "petalítico",
    "petalíticas": "petalítico",
    "petalíticos": "petalítico",
    "petalóides": "petalóide",
    "petam": "petar",
    "petamo": "petar",
    "petamos": "petar",
    "petando": "petar",
    "petara": "petar",
    "petaradas": "petarada",
    "petaram": "petar",
    "petaras": "petar",
    "petarda": "petardar",
    "petardada": "petardar",
    "petardadas": "petardar",
    "petardado": "petardar",
    "petardados": "petardar",
    "petardai": "petardar",
    "petardais": "petardar",
    "petardam": "petardar",
    "petardamo": "petardar",
    "petardamos": "petardar",
    "petardando": "petardar",
    "petardara": "petardar",
    "petardaram": "petardar",
    "petardaras": "petardar",
    "petardarde": "petardar",
    "petardardes": "petardar",
    "petardare": "petardar",
    "petardarei": "petardar",
    "petardareis": "petardar",
    "petardarem": "petardar",
    "petardaremos": "petardar",
    "petardares": "petardar",
    "petardaria": "petardar",
    "petardariam": "petardar",
    "petardarias": "petardar",
    "petardarmo": "petardar",
    "petardarmos": "petardar",
    "petardará": "petardar",
    "petardarás": "petardar",
    "petardarão": "petardar",
    "petardaríamos": "petardar",
    "petardaríeis": "petardar",
    "petardas": "petardar",
    "petardasse": "petardar",
    "petardassem": "petardar",
    "petardasses": "petardar",
    "petardaste": "petardar",
    "petardastes": "petardar",
    "petardava": "petardar",
    "petardavam": "petardar",
    "petardavas": "petardar",
    "petarde": "petardar",
    "petardeada": "petardear",
    "petardeadas": "petardear",
    "petardeado": "petardear",
    "petardeados": "petardear",
    "petardeai": "petardear",
    "petardeais": "petardear",
    "petardeamo": "petardear",
    "petardeamos": "petardear",
    "petardeando": "petardear",
    "petardeara": "petardear",
    "petardearam": "petardear",
    "petardearas": "petardear",
    "petardearde": "petardear",
    "petardeardes": "petardear",
    "petardeare": "petardear",
    "petardearei": "petardear",
    "petardeareis": "petardear",
    "petardearem": "petardear",
    "petardearemos": "petardear",
    "petardeares": "petardear",
    "petardearia": "petardear",
    "petardeariam": "petardear",
    "petardearias": "petardear",
    "petardearmo": "petardear",
    "petardearmos": "petardear",
    "petardeará": "petardear",
    "petardearás": "petardear",
    "petardearão": "petardear",
    "petardearíamos": "petardear",
    "petardearíeis": "petardear",
    "petardeasse": "petardear",
    "petardeassem": "petardear",
    "petardeasses": "petardear",
    "petardeaste": "petardear",
    "petardeastes": "petardear",
    "petardeava": "petardear",
    "petardeavam": "petardear",
    "petardeavas": "petardear",
    "petardeei": "petardear",
    "petardeeis": "petardear",
    "petardeemo": "petardear",
    "petardeemos": "petardear",
    "petardei": "petardar",
    "petardeia": "petardear",
    "petardeiam": "petardear",
    "petardeias": "petardear",
    "petardeie": "petardear",
    "petardeiem": "petardear",
    "petardeies": "petardear",
    "petardeio": "petardear",
    "petardeiros": "petardeiro",
    "petardeis": "petardar",
    "petardem": "petardar",
    "petardemo": "petardar",
    "petardemos": "petardar",
    "petardeou": "petardear",
    "petardes": "petardar",
    "petardeá": "petardear",
    "petardeámo": "petardear",
    "petardeámos": "petardear",
    "petardeáramo": "petardear",
    "petardeáramos": "petardear",
    "petardeárei": "petardear",
    "petardeáreis": "petardear",
    "petardeásseis": "petardear",
    "petardeássemos": "petardear",
    "petardeávamo": "petardear",
    "petardeávamos": "petardear",
    "petardeávei": "petardear",
    "petardeáveis": "petardear",
    "petardo": "petardar",
    "petardos": "petardo",
    "petardou": "petardar",
    "petardá": "petardar",
    "petardámo": "petardar",
    "petardámos": "petardar",
    "petardáramo": "petardar",
    "petardáramos": "petardar",
    "petardárei": "petardar",
    "petardáreis": "petardar",
    "petardásseis": "petardar",
    "petardássemos": "petardar",
    "petardávamo": "petardar",
    "petardávamos": "petardar",
    "petardávei": "petardar",
    "petardáveis": "petardar",
    "petare": "petar",
    "petarei": "petar",
    "petareis": "petar",
    "petarem": "petar",
    "petaremos": "petar",
    "petares": "petar",
    "petaria": "petar",
    "petariam": "petar",
    "petarias": "petar",
    "petarmo": "petar",
    "petarmos": "petar",
    "petarola": "petarolar",
    "petarolada": "petarolar",
    "petaroladas": "petarolar",
    "petarolado": "petarolar",
    "petarolados": "petarolar",
    "petarolai": "petarolar",
    "petarolais": "petarolar",
    "petarolam": "petarolar",
    "petarolamo": "petarolar",
    "petarolamos": "petarolar",
    "petarolando": "petarolar",
    "petarolara": "petarolar",
    "petarolaram": "petarolar",
    "petarolaras": "petarolar",
    "petarolardes": "petarolar",
    "petarolarei": "petarolar",
    "petarolareis": "petarolar",
    "petarolarem": "petarolar",
    "petarolaremos": "petarolar",
    "petarolares": "petarolar",
    "petarolaria": "petarolar",
    "petarolariam": "petarolar",
    "petarolarias": "petarolar",
    "petarolarmo": "petarolar",
    "petarolarmos": "petarolar",
    "petarolará": "petarolar",
    "petarolarás": "petarolar",
    "petarolarão": "petarolar",
    "petarolaríamos": "petarolar",
    "petarolaríeis": "petarolar",
    "petarolas": "petarolar",
    "petarolasse": "petarolar",
    "petarolassem": "petarolar",
    "petarolasses": "petarolar",
    "petarolaste": "petarolar",
    "petarolastes": "petarolar",
    "petarolava": "petarolar",
    "petarolavam": "petarolar",
    "petarolavas": "petarolar",
    "petarole": "petarolar",
    "petarolei": "petarolar",
    "petaroleis": "petarolar",
    "petarolem": "petarolar",
    "petarolemo": "petarolar",
    "petarolemos": "petarolar",
    "petaroles": "petarolar",
    "petarolo": "petarolar",
    "petarolou": "petarolar",
    "petarolámo": "petarolar",
    "petarolámos": "petarolar",
    "petaroláramo": "petarolar",
    "petaroláramos": "petarolar",
    "petaroláreis": "petarolar",
    "petarolásseis": "petarolar",
    "petarolássemos": "petarolar",
    "petarolávamo": "petarolar",
    "petarolávamos": "petarolar",
    "petaroláveis": "petarolar",
    "petará": "petar",
    "petarás": "petar",
    "petarão": "petar",
    "petaríamos": "petar",
    "petaríeis": "petar",
    "petas": "peto",
    "petasse": "petar",
    "petassem": "petar",
    "petasses": "petar",
    "petaste": "petar",
    "petastes": "petar",
    "petava": "petar",
    "petavam": "petar",
    "petavas": "petar",
    "pete": "petar",
    "peteada": "petear",
    "peteadas": "petear",
    "peteado": "petear",
    "peteados": "petear",
    "peteai": "petear",
    "peteais": "petear",
    "peteamo": "petear",
    "peteamos": "petear",
    "peteando": "petear",
    "peteara": "petear",
    "petearam": "petear",
    "petearas": "petear",
    "peteardes": "petear",
    "petearei": "petear",
    "peteareis": "petear",
    "petearem": "petear",
    "petearemos": "petear",
    "peteares": "petear",
    "petearia": "petear",
    "peteariam": "petear",
    "petearias": "petear",
    "petearmo": "petear",
    "petearmos": "petear",
    "peteará": "petear",
    "petearás": "petear",
    "petearão": "petear",
    "petearíamos": "petear",
    "petearíeis": "petear",
    "peteasse": "petear",
    "peteassem": "petear",
    "peteasses": "petear",
    "peteaste": "petear",
    "peteastes": "petear",
    "peteava": "petear",
    "peteavam": "petear",
    "peteavas": "petear",
    "peteei": "petear",
    "peteeis": "petear",
    "peteemo": "petear",
    "peteemos": "petear",
    "petega": "petegar",
    "petegada": "petegar",
    "petegadas": "petegar",
    "petegado": "petegar",
    "petegados": "petegar",
    "petegai": "petegar",
    "petegais": "petegar",
    "petegam": "petegar",
    "petegamo": "petegar",
    "petegamos": "petegar",
    "petegando": "petegar",
    "petegara": "petegar",
    "petegaram": "petegar",
    "petegaras": "petegar",
    "petegarde": "petegar",
    "petegardes": "petegar",
    "petegare": "petegar",
    "petegarei": "petegar",
    "petegareis": "petegar",
    "petegarem": "petegar",
    "petegaremos": "petegar",
    "petegares": "petegar",
    "petegaria": "petegar",
    "petegariam": "petegar",
    "petegarias": "petegar",
    "petegarmo": "petegar",
    "petegarmos": "petegar",
    "petegará": "petegar",
    "petegarás": "petegar",
    "petegarão": "petegar",
    "petegaríamos": "petegar",
    "petegaríeis": "petegar",
    "petegas": "petegar",
    "petegasse": "petegar",
    "petegassem": "petegar",
    "petegasses": "petegar",
    "petegaste": "petegar",
    "petegastes": "petegar",
    "petegava": "petegar",
    "petegavam": "petegar",
    "petegavas": "petegar",
    "petego": "petegar",
    "petegou": "petegar",
    "petegue": "petegar",
    "peteguei": "petegar",
    "petegueis": "petegar",
    "peteguem": "petegar",
    "peteguemo": "petegar",
    "peteguemos": "petegar",
    "petegues": "petegar",
    "petegá": "petegar",
    "petegámo": "petegar",
    "petegámos": "petegar",
    "petegáramo": "petegar",
    "petegáramos": "petegar",
    "petegárei": "petegar",
    "petegáreis": "petegar",
    "petegásseis": "petegar",
    "petegássemos": "petegar",
    "petegávamo": "petegar",
    "petegávamos": "petegar",
    "petegávei": "petegar",
    "petegáveis": "petegar",
    "petei": "petar",
    "peteia": "petear",
    "peteiam": "petear",
    "peteias": "petear",
    "peteie": "petear",
    "peteiem": "petear",
    "peteies": "petear",
    "peteio": "petear",
    "peteira": "peteiro",
    "peteiras": "peteiro",
    "peteiros": "peteiro",
    "peteis": "petar",
    "petem": "petar",
    "petemo": "petar",
    "petemos": "petar",
    "peteou": "petear",
    "petequiais": "petequial",
    "petes": "petar",
    "peteámo": "petear",
    "peteámos": "petear",
    "peteáramo": "petear",
    "peteáramos": "petear",
    "peteáreis": "petear",
    "peteásseis": "petear",
    "peteássemos": "petear",
    "peteávamo": "petear",
    "peteávamos": "petear",
    "peteáveis": "petear",
    "petica": "peticar",
    "peticada": "peticar",
    "peticadas": "peticar",
    "peticado": "peticar",
    "peticados": "peticar",
    "peticais": "peticar",
    "peticam": "peticar",
    "peticamo": "peticar",
    "peticamos": "peticar",
    "peticando": "peticar",
    "peticara": "peticar",
    "peticaram": "peticar",
    "peticaras": "peticar",
    "peticardes": "peticar",
    "peticarei": "peticar",
    "peticareis": "peticar",
    "peticarem": "peticar",
    "peticaremos": "peticar",
    "peticares": "peticar",
    "peticaria": "peticar",
    "peticariam": "peticar",
    "peticarias": "peticar",
    "peticarmo": "peticar",
    "peticarmos": "peticar",
    "peticará": "peticar",
    "peticarás": "peticar",
    "peticarão": "peticar",
    "peticaríamos": "peticar",
    "peticaríeis": "peticar",
    "peticas": "peticar",
    "peticasse": "peticar",
    "peticassem": "peticar",
    "peticasses": "peticar",
    "peticaste": "peticar",
    "peticastes": "peticar",
    "peticava": "peticar",
    "peticavam": "peticar",
    "peticavas": "peticar",
    "peticega": "peticego",
    "peticegas": "peticego",
    "peticegos": "peticego",
    "peticiona": "peticionar",
    "peticionada": "peticionar",
    "peticionadas": "peticionar",
    "peticionado": "peticionar",
    "peticionados": "peticionar",
    "peticionai": "peticionar",
    "peticionais": "peticionar",
    "peticionam": "peticionar",
    "peticionamo": "peticionar",
    "peticionamos": "peticionar",
    "peticionando": "peticionar",
    "peticionara": "peticionar",
    "peticionaram": "peticionar",
    "peticionaras": "peticionar",
    "peticionarde": "peticionar",
    "peticionardes": "peticionar",
    "peticionare": "peticionar",
    "peticionarei": "peticionar",
    "peticionareis": "peticionar",
    "peticionarem": "peticionar",
    "peticionaremos": "peticionar",
    "peticionares": "peticionar",
    "peticionaria": "peticionar",
    "peticionariam": "peticionar",
    "peticionarias": "peticionar",
    "peticionarmo": "peticionar",
    "peticionarmos": "peticionar",
    "peticionará": "peticionar",
    "peticionarás": "peticionar",
    "peticionarão": "peticionar",
    "peticionaríamos": "peticionar",
    "peticionaríeis": "peticionar",
    "peticionas": "peticionar",
    "peticionasse": "peticionar",
    "peticionassem": "peticionar",
    "peticionasses": "peticionar",
    "peticionaste": "peticionar",
    "peticionastes": "peticionar",
    "peticionava": "peticionar",
    "peticionavam": "peticionar",
    "peticionavas": "peticionar",
    "peticione": "peticionar",
    "peticionei": "peticionar",
    "peticioneis": "peticionar",
    "peticionem": "peticionar",
    "peticionemo": "peticionar",
    "peticionemos": "peticionar",
    "peticiones": "peticionar",
    "peticiono": "peticionar",
    "peticionou": "peticionar",
    "peticioná": "peticionar",
    "peticionámo": "peticionar",
    "peticionámos": "peticionar",
    "peticionáramo": "peticionar",
    "peticionáramos": "peticionar",
    "peticionárei": "peticionar",
    "peticionáreis": "peticionar",
    "peticionária": "peticionário",
    "peticionárias": "peticionário",
    "peticionários": "peticionário",
    "peticionásseis": "peticionar",
    "peticionássemos": "peticionar",
    "peticionávamo": "peticionar",
    "peticionávamos": "peticionar",
    "peticionávei": "peticionar",
    "peticionáveis": "peticionar",
    "petico": "peticar",
    "peticou": "peticar",
    "peticámo": "peticar",
    "peticámos": "peticar",
    "peticáramo": "peticar",
    "peticáramos": "peticar",
    "peticáreis": "peticar",
    "peticásseis": "peticar",
    "peticássemos": "peticar",
    "peticávamo": "peticar",
    "peticávamos": "peticar",
    "peticáveis": "peticar",
    "petidinas": "petidina",
    "petimetra": "petimetre",
    "petimetras": "petimetre",
    "petimetres": "petimetre",
    "petingas": "petinga",
    "petinhas": "petinha",
    "petintais": "petintal",
    "petipés": "petipé",
    "petique": "peticar",
    "petiquei": "peticar",
    "petiqueis": "peticar",
    "petiquem": "peticar",
    "petiquemos": "peticar",
    "petiques": "peticar",
    "petisca": "petiscar",
    "petiscada": "petiscar",
    "petiscadas": "petiscar",
    "petiscado": "petiscar",
    "petiscadora": "petiscador",
    "petiscadoras": "petiscador",
    "petiscadores": "petiscador",
    "petiscados": "petiscar",
    "petiscai": "petiscar",
    "petiscais": "petiscar",
    "petiscam": "petiscar",
    "petiscamo": "petiscar",
    "petiscamos": "petiscar",
    "petiscando": "petiscar",
    "petiscara": "petiscar",
    "petiscaram": "petiscar",
    "petiscaras": "petiscar",
    "petiscarde": "petiscar",
    "petiscardes": "petiscar",
    "petiscare": "petiscar",
    "petiscarei": "petiscar",
    "petiscareis": "petiscar",
    "petiscarem": "petiscar",
    "petiscaremos": "petiscar",
    "petiscares": "petiscar",
    "petiscaria": "petiscar",
    "petiscariam": "petiscar",
    "petiscarias": "petiscar",
    "petiscarmo": "petiscar",
    "petiscarmos": "petiscar",
    "petiscará": "petiscar",
    "petiscarás": "petiscar",
    "petiscarão": "petiscar",
    "petiscaríamos": "petiscar",
    "petiscaríeis": "petiscar",
    "petiscas": "petiscar",
    "petiscasse": "petiscar",
    "petiscassem": "petiscar",
    "petiscasses": "petiscar",
    "petiscaste": "petiscar",
    "petiscastes": "petiscar",
    "petiscava": "petiscar",
    "petiscavam": "petiscar",
    "petiscavas": "petiscar",
    "petisco": "petiscar",
    "petiscos": "petisco",
    "petiscou": "petiscar",
    "petiscozinho": "petisco",
    "petiscozinhos": "petisco",
    "petiscozito": "petisco",
    "petiscozitos": "petisco",
    "petiscá": "petiscar",
    "petiscámo": "petiscar",
    "petiscámos": "petiscar",
    "petiscáramo": "petiscar",
    "petiscáramos": "petiscar",
    "petiscárei": "petiscar",
    "petiscáreis": "petiscar",
    "petiscásseis": "petiscar",
    "petiscássemos": "petiscar",
    "petiscávamo": "petiscar",
    "petiscávamos": "petiscar",
    "petiscávei": "petiscar",
    "petiscáveis": "petiscar",
    "petisque": "petiscar",
    "petisquei": "petiscar",
    "petisqueiras": "petisqueira",
    "petisqueis": "petiscar",
    "petisquem": "petiscar",
    "petisquemo": "petiscar",
    "petisquemos": "petiscar",
    "petisques": "petiscar",
    "petisquinho": "petisco",
    "petisquinhos": "petisco",
    "petisquito": "petisco",
    "petisquitos": "petisco",
    "petisseca": "petisseco",
    "petissecas": "petisseco",
    "petissecos": "petisseco",
    "petita": "petitar",
    "petitada": "petitar",
    "petitadas": "petitar",
    "petitado": "petitar",
    "petitados": "petitar",
    "petitai": "petitar",
    "petitais": "petitar",
    "petitam": "petitar",
    "petitamo": "petitar",
    "petitamos": "petitar",
    "petitando": "petitar",
    "petitara": "petitar",
    "petitaram": "petitar",
    "petitaras": "petitar",
    "petitardes": "petitar",
    "petitarei": "petitar",
    "petitareis": "petitar",
    "petitarem": "petitar",
    "petitaremos": "petitar",
    "petitares": "petitar",
    "petitaria": "petitar",
    "petitariam": "petitar",
    "petitarias": "petitar",
    "petitarmo": "petitar",
    "petitarmos": "petitar",
    "petitará": "petitar",
    "petitarás": "petitar",
    "petitarão": "petitar",
    "petitaríamos": "petitar",
    "petitaríeis": "petitar",
    "petitas": "petitar",
    "petitasse": "petitar",
    "petitassem": "petitar",
    "petitasses": "petitar",
    "petitaste": "petitar",
    "petitastes": "petitar",
    "petitava": "petitar",
    "petitavam": "petitar",
    "petitavas": "petitar",
    "petite": "petitar",
    "petitei": "petitar",
    "petiteis": "petitar",
    "petitem": "petitar",
    "petitemo": "petitar",
    "petitemos": "petitar",
    "petites": "petitar",
    "petito": "petitar",
    "petitou": "petitar",
    "petitámo": "petitar",
    "petitámos": "petitar",
    "petitáramo": "petitar",
    "petitáramos": "petitar",
    "petitáreis": "petitar",
    "petitásseis": "petitar",
    "petitássemos": "petitar",
    "petitávamo": "petitar",
    "petitávamos": "petitar",
    "petitáveis": "petitar",
    "petitória": "petitório",
    "petitórias": "petitório",
    "petitórios": "petitório",
    "petiza": "petiz",
    "petizadas": "petizada",
    "petizas": "petiz",
    "petizes": "petiz",
    "petições": "petição",
    "peto": "petar",
    "petos": "peto",
    "petou": "petar",
    "petrarquesca": "petrarquesco",
    "petrarquescas": "petrarquesco",
    "petrarquescos": "petrarquesco",
    "petrarquiana": "petrarquiano",
    "petrarquianas": "petrarquiano",
    "petrarquianos": "petrarquiano",
    "petrarquismos": "petrarquismo",
    "petrarquistas": "petrarquista",
    "petrecha": "petrechar",
    "petrechada": "petrechar",
    "petrechadas": "petrechar",
    "petrechado": "petrechar",
    "petrechados": "petrechar",
    "petrechai": "petrechar",
    "petrechais": "petrechar",
    "petrecham": "petrechar",
    "petrechamentos": "petrechamento",
    "petrechamo": "petrechar",
    "petrechamos": "petrechar",
    "petrechando": "petrechar",
    "petrechara": "petrechar",
    "petrecharam": "petrechar",
    "petrecharas": "petrechar",
    "petrecharde": "petrechar",
    "petrechardes": "petrechar",
    "petrechare": "petrechar",
    "petrecharei": "petrechar",
    "petrechareis": "petrechar",
    "petrecharem": "petrechar",
    "petrecharemos": "petrechar",
    "petrechares": "petrechar",
    "petrecharia": "petrechar",
    "petrechariam": "petrechar",
    "petrecharias": "petrechar",
    "petrecharmo": "petrechar",
    "petrecharmos": "petrechar",
    "petrechará": "petrechar",
    "petrecharás": "petrechar",
    "petrecharão": "petrechar",
    "petrecharíamos": "petrechar",
    "petrecharíeis": "petrechar",
    "petrechas": "petrechar",
    "petrechasse": "petrechar",
    "petrechassem": "petrechar",
    "petrechasses": "petrechar",
    "petrechaste": "petrechar",
    "petrechastes": "petrechar",
    "petrechava": "petrechar",
    "petrechavam": "petrechar",
    "petrechavas": "petrechar",
    "petreche": "petrechar",
    "petrechei": "petrechar",
    "petrecheis": "petrechar",
    "petrechem": "petrechar",
    "petrechemo": "petrechar",
    "petrechemos": "petrechar",
    "petreches": "petrechar",
    "petrecho": "petrechar",
    "petrechos": "petrecho",
    "petrechou": "petrechar",
    "petrechá": "petrechar",
    "petrechámo": "petrechar",
    "petrechámos": "petrechar",
    "petrecháramo": "petrechar",
    "petrecháramos": "petrechar",
    "petrechárei": "petrechar",
    "petrecháreis": "petrechar",
    "petrechásseis": "petrechar",
    "petrechássemos": "petrechar",
    "petrechávamo": "petrechar",
    "petrechávamos": "petrechar",
    "petrechávei": "petrechar",
    "petrecháveis": "petrechar",
    "petrifica": "petrificar",
    "petrificada": "petrificar",
    "petrificadas": "petrificar",
    "petrificado": "petrificar",
    "petrificadora": "petrificador",
    "petrificadoras": "petrificador",
    "petrificadores": "petrificador",
    "petrificados": "petrificar",
    "petrificadíssima": "petrificado",
    "petrificadíssimas": "petrificado",
    "petrificadíssimo": "petrificado",
    "petrificadíssimos": "petrificado",
    "petrificai": "petrificar",
    "petrificais": "petrificar",
    "petrificam": "petrificar",
    "petrificamo": "petrificar",
    "petrificamos": "petrificar",
    "petrificando": "petrificar",
    "petrificantes": "petrificante",
    "petrificara": "petrificar",
    "petrificaram": "petrificar",
    "petrificaras": "petrificar",
    "petrificarde": "petrificar",
    "petrificardes": "petrificar",
    "petrificare": "petrificar",
    "petrificarei": "petrificar",
    "petrificareis": "petrificar",
    "petrificarem": "petrificar",
    "petrificaremos": "petrificar",
    "petrificares": "petrificar",
    "petrificaria": "petrificar",
    "petrificariam": "petrificar",
    "petrificarias": "petrificar",
    "petrificarmo": "petrificar",
    "petrificarmos": "petrificar",
    "petrificará": "petrificar",
    "petrificarás": "petrificar",
    "petrificarão": "petrificar",
    "petrificaríamos": "petrificar",
    "petrificaríeis": "petrificar",
    "petrificas": "petrificar",
    "petrificasse": "petrificar",
    "petrificassem": "petrificar",
    "petrificasses": "petrificar",
    "petrificaste": "petrificar",
    "petrificastes": "petrificar",
    "petrificava": "petrificar",
    "petrificavam": "petrificar",
    "petrificavas": "petrificar",
    "petrificações": "petrificação",
    "petrifico": "petrificar",
    "petrificou": "petrificar",
    "petrificá": "petrificar",
    "petrificámo": "petrificar",
    "petrificámos": "petrificar",
    "petrificáramo": "petrificar",
    "petrificáramos": "petrificar",
    "petrificárei": "petrificar",
    "petrificáreis": "petrificar",
    "petrificásseis": "petrificar",
    "petrificássemos": "petrificar",
    "petrificávamo": "petrificar",
    "petrificávamos": "petrificar",
    "petrificávei": "petrificar",
    "petrificáveis": "petrificável",
    "petrifique": "petrificar",
    "petrifiquei": "petrificar",
    "petrifiqueis": "petrificar",
    "petrifiquem": "petrificar",
    "petrifiquemo": "petrificar",
    "petrifiquemos": "petrificar",
    "petrifiques": "petrificar",
    "petrinas": "petrina",
    "petrodólares": "petrodólar",
    "petrogenias": "petrogenia",
    "petrogenésica": "petrogenésico",
    "petrogenésicas": "petrogenésico",
    "petrogenésicos": "petrogenésico",
    "petrogenética": "petrogenético",
    "petrogenéticas": "petrogenético",
    "petrogenéticos": "petrogenético",
    "petrografias": "petrografia",
    "petrografistas": "petrografista",
    "petrográfica": "petrográfico",
    "petrográficas": "petrográfico",
    "petrográficos": "petrográfico",
    "petrogéneses": "petrogénese",
    "petrogénica": "petrogénico",
    "petrogénicas": "petrogénico",
    "petrogénicos": "petrogénico",
    "petrolarias": "petrolaria",
    "petroleira": "petroleiro",
    "petroleiras": "petroleiro",
    "petroleiros": "petroleiro",
    "petroleínas": "petroleína",
    "petrolistas": "petrolista",
    "petrologias": "petrologia",
    "petrologistas": "petrologista",
    "petrolífera": "petrolífero",
    "petrolíferas": "petrolífero",
    "petrolíferos": "petrolífero",
    "petrológica": "petrológico",
    "petrológicas": "petrológico",
    "petrológicos": "petrológico",
    "petroquímica": "petroquímico",
    "petroquímicas": "petroquímico",
    "petroquímicos": "petroquímico",
    "petrosa": "petroso",
    "petrosas": "petroso",
    "petrosos": "petroso",
    "petrossílexes": "petrossílex",
    "petrossílices": "petrossílice",
    "petrárquica": "petrárquico",
    "petrárquicas": "petrárquico",
    "petrárquicos": "petrárquico",
    "petrícolas": "petrícola",
    "petrífica": "petrífico",
    "petríficas": "petrífico",
    "petríficos": "petrífico",
    "petrógrafos": "petrógrafo",
    "petróleos": "petróleo",
    "petrónios": "petrónio",
    "petulantes": "petulante",
    "petulantíssima": "petulante",
    "petulantíssimas": "petulante",
    "petulantíssimo": "petulante",
    "petulantíssimos": "petulante",
    "petulâncias": "petulância",
    "petá": "petar",
    "petámo": "petar",
    "petámos": "petar",
    "petáramo": "petar",
    "petáramos": "petar",
    "petárei": "petar",
    "petáreis": "petar",
    "petásseis": "petar",
    "petássemos": "petar",
    "petávamo": "petar",
    "petávamos": "petar",
    "petávei": "petar",
    "petáveis": "petar",
    "petéquias": "petéquia",
    "petúnias": "petúnia",
    "peugadas": "peugada",
    "pevas": "peva",
    "pevides": "pevide",
    "pevidosa": "pevidoso",
    "pevidosas": "pevidoso",
    "pevidosos": "pevidoso",
    "pevitadas": "pevitada",
    "pexes": "pexe",
    "pexotadas": "pexotada",
    "pexotes": "pexote",
    "pexões": "pexão",
    "pezenha": "pezenho",
    "pezenhas": "pezenho",
    "pezenhos": "pezenho",
    "pezes": "pez",
    "pezinho": "pé",
    "pezinhos": "pé",
    "pezito": "pé",
    "pezitos": "pé",
    "pezorros": "pezorro",
    "pezuda": "pezudo",
    "pezudas": "pezudo",
    "pezudinha": "pezudo",
    "pezudinhas": "pezudo",
    "pezudinho": "pezudo",
    "pezudinhos": "pezudo",
    "pezudita": "pezudo",
    "pezuditas": "pezudo",
    "pezudito": "pezudo",
    "pezuditos": "pezudo",
    "pezudos": "pezudo",
    "pezudíssima": "pezudo",
    "pezudíssimas": "pezudo",
    "pezudíssimo": "pezudo",
    "pezudíssimos": "pezudo",
    "pezunhos": "pezunho",
    "peá": "pear",
    "peámo": "pear",
    "peámos": "pear",
    "peáramo": "pear",
    "peáramos": "pear",
    "peárei": "pear",
    "peáreis": "pear",
    "peásseis": "pear",
    "peássemos": "pear",
    "peávamo": "pear",
    "peávamos": "pear",
    "peávei": "pear",
    "peáveis": "pear",
    "peça": "pedir",
    "peçais": "pedir",
    "peçam": "pedir",
    "peçamo": "pedir",
    "peçamos": "pedir",
    "peças": "pedir",
    "peçazinha": "peça",
    "peçazinhas": "peça",
    "peçazita": "peça",
    "peçazitas": "peça",
    "peço": "pedir",
    "peçonhas": "peçonha",
    "peçonhenta": "peçonhento",
    "peçonhentada": "peçonhentar",
    "peçonhentadas": "peçonhentar",
    "peçonhentado": "peçonhentar",
    "peçonhentados": "peçonhentar",
    "peçonhentai": "peçonhentar",
    "peçonhentais": "peçonhentar",
    "peçonhentam": "peçonhentar",
    "peçonhentamo": "peçonhentar",
    "peçonhentamos": "peçonhentar",
    "peçonhentando": "peçonhentar",
    "peçonhentar": "onhentar",
    "peçonhentara": "peçonhentar",
    "peçonhentaram": "peçonhentar",
    "peçonhentaras": "peçonhentar",
    "peçonhentarde": "peçonhentar",
    "peçonhentardes": "peçonhentar",
    "peçonhentare": "peçonhentar",
    "peçonhentarei": "peçonhentar",
    "peçonhentareis": "peçonhentar",
    "peçonhentarem": "peçonhentar",
    "peçonhentaremos": "peçonhentar",
    "peçonhentares": "peçonhentar",
    "peçonhentaria": "peçonhentar",
    "peçonhentariam": "peçonhentar",
    "peçonhentarias": "peçonhentar",
    "peçonhentarmo": "peçonhentar",
    "peçonhentarmos": "peçonhentar",
    "peçonhentará": "peçonhentar",
    "peçonhentarás": "peçonhentar",
    "peçonhentarão": "peçonhentar",
    "peçonhentaríamos": "peçonhentar",
    "peçonhentaríeis": "peçonhentar",
    "peçonhentas": "peçonhento",
    "peçonhentasse": "peçonhentar",
    "peçonhentassem": "peçonhentar",
    "peçonhentasses": "peçonhentar",
    "peçonhentaste": "peçonhentar",
    "peçonhentastes": "peçonhentar",
    "peçonhentava": "peçonhentar",
    "peçonhentavam": "peçonhentar",
    "peçonhentavas": "peçonhentar",
    "peçonhente": "peçonhentar",
    "peçonhentei": "peçonhentar",
    "peçonhenteis": "peçonhentar",
    "peçonhentem": "peçonhentar",
    "peçonhentemo": "peçonhentar",
    "peçonhentemos": "peçonhentar",
    "peçonhentes": "peçonhentar",
    "peçonhento": "peçonhentar",
    "peçonhentos": "peçonhento",
    "peçonhentou": "peçonhentar",
    "peçonhentá": "peçonhentar",
    "peçonhentámo": "peçonhentar",
    "peçonhentámos": "peçonhentar",
    "peçonhentáramo": "peçonhentar",
    "peçonhentáramos": "peçonhentar",
    "peçonhentárei": "peçonhentar",
    "peçonhentáreis": "peçonhentar",
    "peçonhentásseis": "peçonhentar",
    "peçonhentássemos": "peçonhentar",
    "peçonhentávamo": "peçonhentar",
    "peçonhentávamos": "peçonhentar",
    "peçonhentávei": "peçonhentar",
    "peçonhentáveis": "peçonhentar",
    "peónias": "peónia",
    "peões": "peão",
    "peúgas": "peúga",
    "peúvas": "peúva",
    "pia": "pio",
    "piabas": "piaba",
    "piacas": "piaca",
    "piada": "piar",
    "piadas": "piar",
    "piadeiras": "piadeira",
    "piadeiros": "piadeiro",
    "piadinha": "piada",
    "piadinhas": "piada",
    "piadistas": "piadista",
    "piadita": "piada",
    "piaditas": "piada",
    "piado": "piar",
    "piadoiros": "piadoiro",
    "piadora": "piador",
    "piadoras": "piador",
    "piadores": "piador",
    "piados": "piar",
    "piadouros": "piadouro",
    "piadética": "piadético",
    "piadéticas": "piadético",
    "piadéticos": "piadético",
    "piafa": "piafar",
    "piafada": "piafar",
    "piafadas": "piafar",
    "piafado": "piafar",
    "piafados": "piafar",
    "piafai": "piafar",
    "piafais": "piafar",
    "piafam": "piafar",
    "piafamo": "piafar",
    "piafamos": "piafar",
    "piafando": "piafar",
    "piafara": "piafar",
    "piafaram": "piafar",
    "piafaras": "piafar",
    "piafardes": "piafar",
    "piafarei": "piafar",
    "piafareis": "piafar",
    "piafarem": "piafar",
    "piafaremos": "piafar",
    "piafares": "piafar",
    "piafaria": "piafar",
    "piafariam": "piafar",
    "piafarias": "piafar",
    "piafarmo": "piafar",
    "piafarmos": "piafar",
    "piafará": "piafar",
    "piafarás": "piafar",
    "piafarão": "piafar",
    "piafaríamos": "piafar",
    "piafaríeis": "piafar",
    "piafas": "piafar",
    "piafasse": "piafar",
    "piafassem": "piafar",
    "piafasses": "piafar",
    "piafaste": "piafar",
    "piafastes": "piafar",
    "piafava": "piafar",
    "piafavam": "piafar",
    "piafavas": "piafar",
    "piafe": "piafar",
    "piafei": "piafar",
    "piafeis": "piafar",
    "piafem": "piafar",
    "piafemo": "piafar",
    "piafemos": "piafar",
    "piafes": "piafar",
    "piafo": "piafar",
    "piafou": "piafar",
    "piafámo": "piafar",
    "piafámos": "piafar",
    "piafáramo": "piafar",
    "piafáramos": "piafar",
    "piafáreis": "piafar",
    "piafásseis": "piafar",
    "piafássemos": "piafar",
    "piafávamo": "piafar",
    "piafávamos": "piafar",
    "piafáveis": "piafar",
    "piafés": "piafé",
    "piai": "piar",
    "piais": "piar",
    "piam": "piar",
    "piamo": "piar",
    "piamos": "piar",
    "piando": "piar",
    "pianinha": "pianinho",
    "pianinhas": "pianinho",
    "pianinho": "piano",
    "pianinhos": "piano",
    "pianistas": "pianista",
    "pianito": "piano",
    "pianitos": "piano",
    "pianiza": "pianizar",
    "pianizada": "pianizar",
    "pianizadas": "pianizar",
    "pianizado": "pianizar",
    "pianizados": "pianizar",
    "pianizai": "pianizar",
    "pianizais": "pianizar",
    "pianizam": "pianizar",
    "pianizamo": "pianizar",
    "pianizamos": "pianizar",
    "pianizando": "pianizar",
    "pianizara": "pianizar",
    "pianizaram": "pianizar",
    "pianizaras": "pianizar",
    "pianizarde": "pianizar",
    "pianizardes": "pianizar",
    "pianizare": "pianizar",
    "pianizarei": "pianizar",
    "pianizareis": "pianizar",
    "pianizarem": "pianizar",
    "pianizaremos": "pianizar",
    "pianizares": "pianizar",
    "pianizaria": "pianizar",
    "pianizariam": "pianizar",
    "pianizarias": "pianizar",
    "pianizarmo": "pianizar",
    "pianizarmos": "pianizar",
    "pianizará": "pianizar",
    "pianizarás": "pianizar",
    "pianizarão": "pianizar",
    "pianizaríamos": "pianizar",
    "pianizaríeis": "pianizar",
    "pianizas": "pianizar",
    "pianizasse": "pianizar",
    "pianizassem": "pianizar",
    "pianizasses": "pianizar",
    "pianizaste": "pianizar",
    "pianizastes": "pianizar",
    "pianizava": "pianizar",
    "pianizavam": "pianizar",
    "pianizavas": "pianizar",
    "pianize": "pianizar",
    "pianizei": "pianizar",
    "pianizeis": "pianizar",
    "pianizem": "pianizar",
    "pianizemo": "pianizar",
    "pianizemos": "pianizar",
    "pianizes": "pianizar",
    "pianizo": "pianizar",
    "pianizou": "pianizar",
    "pianizá": "pianizar",
    "pianizámo": "pianizar",
    "pianizámos": "pianizar",
    "pianizáramo": "pianizar",
    "pianizáramos": "pianizar",
    "pianizárei": "pianizar",
    "pianizáreis": "pianizar",
    "pianizásseis": "pianizar",
    "pianizássemos": "pianizar",
    "pianizávamo": "pianizar",
    "pianizávamos": "pianizar",
    "pianizávei": "pianizar",
    "pianizáveis": "pianizar",
    "pianolas": "pianola",
    "pianos": "piano",
    "pianíssima": "pianíssimo",
    "pianíssimas": "pianíssimo",
    "pianíssimo": "piano",
    "pianíssimos": "pianíssimo",
    "piara": "piar",
    "piaram": "piar",
    "piaras": "piara",
    "piardas": "piarda",
    "piardes": "piar",
    "piarei": "piar",
    "piareis": "piar",
    "piarem": "piar",
    "piaremos": "piar",
    "piares": "piar",
    "piaria": "piar",
    "piariam": "piar",
    "piarias": "piar",
    "piarmo": "piar",
    "piarmos": "piar",
    "piartroses": "piartrose",
    "piará": "piar",
    "piarás": "piar",
    "piarão": "piar",
    "piaríamos": "piar",
    "piaríeis": "piar",
    "pias": "pio",
    "piascas": "piasca",
    "piasse": "piar",
    "piassem": "piar",
    "piasses": "piar",
    "piaste": "piar",
    "piastes": "piar",
    "piastras": "piastra",
    "piastrões": "piastrão",
    "piauienses": "piauiense",
    "piava": "piar",
    "piavam": "piar",
    "piavas": "piava",
    "piaçabas": "piaçaba",
    "piaçavas": "piaçava",
    "piaçás": "piaçá",
    "pibós": "pibó",
    "pica": "picar",
    "picada": "picar",
    "picadas": "picar",
    "picadeiras": "picadeira",
    "picadeiros": "picadeiro",
    "picadelas": "picadela",
    "picadeta": "picadete",
    "picadetas": "picadete",
    "picadetes": "picadete",
    "picadilhos": "picadilho",
    "picadinha": "picado",
    "picadinhas": "picado",
    "picadinho": "picado",
    "picadinhos": "picado",
    "picadita": "picado",
    "picaditas": "picado",
    "picadito": "picado",
    "picaditos": "picado",
    "picado": "picar",
    "picadora": "picador",
    "picadoras": "picador",
    "picadores": "picador",
    "picados": "picar",
    "picaduras": "picadura",
    "picadíssima": "picado",
    "picadíssimas": "picado",
    "picadíssimo": "picado",
    "picadíssimos": "picado",
    "picai": "picar",
    "picais": "picar",
    "picam": "picar",
    "picamo": "picar",
    "picamos": "picar",
    "picando": "picar",
    "picantes": "picante",
    "picantezinha": "picante",
    "picantezinhas": "picante",
    "picantezinho": "picante",
    "picantezinhos": "picante",
    "picantezita": "picante",
    "picantezitas": "picante",
    "picantezito": "picante",
    "picantezitos": "picante",
    "picantinha": "picante",
    "picantinhas": "picante",
    "picantinho": "picante",
    "picantinhos": "picante",
    "picantita": "picante",
    "picantitas": "picante",
    "picantito": "picante",
    "picantitos": "picante",
    "picantíssima": "picante",
    "picantíssimas": "picante",
    "picantíssimo": "picante",
    "picantíssimos": "picante",
    "picança": "picanço",
    "picanças": "picanço",
    "picanços": "picanço",
    "picara": "picar",
    "picaram": "picar",
    "picaras": "picar",
    "picarda": "picardo",
    "picardas": "picardo",
    "picarde": "picar",
    "picardes": "picar",
    "picardias": "picardia",
    "picardos": "picardo",
    "picare": "picar",
    "picarei": "picar",
    "picareis": "picar",
    "picarem": "picar",
    "picaremos": "picar",
    "picares": "picar",
    "picaresca": "picaresco",
    "picarescas": "picaresco",
    "picarescos": "picaresco",
    "picaretas": "picareta",
    "picaria": "picar",
    "picariam": "picar",
    "picarias": "picaria",
    "picarmo": "picar",
    "picarmos": "picar",
    "picarotos": "picaroto",
    "picará": "picar",
    "picarás": "picar",
    "picarão": "picar",
    "picarços": "picarço",
    "picaríamos": "picar",
    "picaríeis": "picar",
    "picas": "picar",
    "picasse": "picar",
    "picassem": "picar",
    "picasses": "picar",
    "picaste": "picar",
    "picastes": "picar",
    "picatostes": "picatoste",
    "picava": "picar",
    "picavam": "picar",
    "picavas": "picar",
    "picaça": "picaço",
    "picaças": "picaço",
    "picaços": "picaço",
    "pichas": "picha",
    "picheiras": "picheira",
    "picheiros": "picheiro",
    "pichelarias": "pichelaria",
    "pichelas": "pichela",
    "picheleira": "picheleiro",
    "picheleiras": "picheleiro",
    "picheleiros": "picheleiro",
    "pichelins": "pichelim",
    "piches": "piche",
    "pichorras": "pichorra",
    "pichorros": "pichorro",
    "pichos": "picho",
    "pichotes": "pichote",
    "pichéis": "pichel",
    "picnogodídeos": "picnogodídeo",
    "picnometrias": "picnometria",
    "picnométrica": "picnométrico",
    "picnométricas": "picnométrico",
    "picnométricos": "picnométrico",
    "picnoscopias": "picnoscopia",
    "picnoscópica": "picnoscópico",
    "picnoscópicas": "picnoscópico",
    "picnoscópicos": "picnoscópico",
    "picnoses": "picnose",
    "picnostilos": "picnostilo",
    "picnómetros": "picnómetro",
    "picnósica": "picnósico",
    "picnósicas": "picnósico",
    "picnósicos": "picnósico",
    "picnótica": "picnótico",
    "picnóticas": "picnótico",
    "picnóticos": "picnótico",
    "pico": "picar",
    "picolas": "picola",
    "picos": "pico",
    "picosa": "picoso",
    "picosas": "picoso",
    "picosos": "picoso",
    "picota": "picotar",
    "picotada": "picotar",
    "picotadas": "picotar",
    "picotadinha": "picotado",
    "picotadinhas": "picotado",
    "picotadinho": "picotado",
    "picotadinhos": "picotado",
    "picotadita": "picotado",
    "picotaditas": "picotado",
    "picotadito": "picotado",
    "picotaditos": "picotado",
    "picotado": "picotar",
    "picotados": "picotar",
    "picotadíssima": "picotado",
    "picotadíssimas": "picotado",
    "picotadíssimo": "picotado",
    "picotadíssimos": "picotado",
    "picotagens": "picotagem",
    "picotai": "picotar",
    "picotais": "picotar",
    "picotam": "picotar",
    "picotamo": "picotar",
    "picotamos": "picotar",
    "picotando": "picotar",
    "picotara": "picotar",
    "picotaram": "picotar",
    "picotaras": "picotar",
    "picotarde": "picotar",
    "picotardes": "picotar",
    "picotare": "picotar",
    "picotarei": "picotar",
    "picotareis": "picotar",
    "picotarem": "picotar",
    "picotaremos": "picotar",
    "picotares": "picotar",
    "picotaria": "picotar",
    "picotariam": "picotar",
    "picotarias": "picotar",
    "picotarmo": "picotar",
    "picotarmos": "picotar",
    "picotará": "picotar",
    "picotarás": "picotar",
    "picotarão": "picotar",
    "picotaríamos": "picotar",
    "picotaríeis": "picotar",
    "picotas": "picotar",
    "picotasse": "picotar",
    "picotassem": "picotar",
    "picotasses": "picotar",
    "picotaste": "picotar",
    "picotastes": "picotar",
    "picotava": "picotar",
    "picotavam": "picotar",
    "picotavas": "picotar",
    "picote": "picotar",
    "picotei": "picotar",
    "picoteis": "picotar",
    "picotem": "picotar",
    "picotemo": "picotar",
    "picotemos": "picotar",
    "picotes": "picote",
    "picotilhos": "picotilho",
    "picoto": "picotar",
    "picotos": "picoto",
    "picotou": "picotar",
    "picotá": "picotar",
    "picotámo": "picotar",
    "picotámos": "picotar",
    "picotáramo": "picotar",
    "picotáramos": "picotar",
    "picotárei": "picotar",
    "picotáreis": "picotar",
    "picotásseis": "picotar",
    "picotássemos": "picotar",
    "picotávamo": "picotar",
    "picotávamos": "picotar",
    "picotávei": "picotar",
    "picotáveis": "picotar",
    "picou": "picar",
    "picratos": "picrato",
    "picrinas": "picrina",
    "picrocarmins": "picrocarmim",
    "picroeritrinas": "picroeritrina",
    "picrolites": "picrolite",
    "pictografias": "pictografia",
    "pictogramas": "pictograma",
    "pictográfica": "pictográfico",
    "pictográficas": "pictográfico",
    "pictográficos": "pictográfico",
    "picturais": "pictural",
    "pictórica": "pictórico",
    "pictóricas": "pictórico",
    "pictóricos": "pictórico",
    "picuenses": "picuense",
    "picuinhas": "picuinha",
    "picá": "picar",
    "picámo": "picar",
    "picámos": "picar",
    "picáramo": "picar",
    "picáramos": "picar",
    "picárei": "picar",
    "picáreis": "picar",
    "picásseis": "picar",
    "picássemos": "picar",
    "picávamo": "picar",
    "picávamos": "picar",
    "picávei": "picar",
    "picáveis": "picar",
    "picídea": "picídeo",
    "picídeas": "picídeo",
    "picídeos": "picídeo",
    "picões": "picão",
    "pidesca": "pidesco",
    "pidescas": "pidesco",
    "pidescos": "pidesco",
    "pidgins": "pidgin",
    "pie": "piar",
    "piedades": "piedade",
    "piedosa": "piedoso",
    "piedosas": "piedoso",
    "piedosos": "piedoso",
    "pieguices": "pieguice",
    "piei": "piar",
    "pieiras": "pieira",
    "pieis": "piar",
    "pielas": "piela",
    "pielites": "pielite",
    "pielonefrites": "pielonefrite",
    "pielonefrítica": "pielonefrítico",
    "pielonefríticas": "pielonefrítico",
    "pielonefríticos": "pielonefrítico",
    "pielítica": "pielítico",
    "pielíticas": "pielítico",
    "pielíticos": "pielítico",
    "piem": "piar",
    "piemo": "piar",
    "piemontesa": "piemontês",
    "piemontesas": "piemontês",
    "piemonteses": "piemontês",
    "piemos": "piar",
    "pientíssima": "pio",
    "pientíssimas": "pio",
    "pientíssimo": "pio",
    "pientíssimos": "pio",
    "pies": "piar",
    "pietonais": "pietonal",
    "piezelectricidades": "piezelectricidade",
    "piezeléctrica": "piezeléctrico",
    "piezeléctricas": "piezeléctrico",
    "piezeléctricos": "piezeléctrico",
    "piezoelectricidades": "piezoelectricidade",
    "piezometrias": "piezometria",
    "piezométrica": "piezométrico",
    "piezométricas": "piezométrico",
    "piezométricos": "piezométrico",
    "piezómetros": "piezómetro",
    "pifa": "pifar",
    "pifada": "pifar",
    "pifadas": "pifar",
    "pifado": "pifar",
    "pifados": "pifar",
    "pifai": "pifar",
    "pifais": "pifar",
    "pifam": "pifar",
    "pifamo": "pifar",
    "pifamos": "pifar",
    "pifando": "pifar",
    "pifara": "pifar",
    "pifaram": "pifar",
    "pifaras": "pifar",
    "pifarde": "pifar",
    "pifardes": "pifar",
    "pifare": "pifar",
    "pifarei": "pifar",
    "pifareis": "pifar",
    "pifarem": "pifar",
    "pifaremos": "pifar",
    "pifares": "pifar",
    "pifaria": "pifar",
    "pifariam": "pifar",
    "pifarias": "pifar",
    "pifarinho": "pífaro",
    "pifarinhos": "pífaro",
    "pifarito": "pífaro",
    "pifaritos": "pífaro",
    "pifarmo": "pifar",
    "pifarmos": "pifar",
    "pifará": "pifar",
    "pifarás": "pifar",
    "pifarão": "pifar",
    "pifaríamos": "pifar",
    "pifaríeis": "pifar",
    "pifas": "pifar",
    "pifasse": "pifar",
    "pifassem": "pifar",
    "pifasses": "pifar",
    "pifaste": "pifar",
    "pifastes": "pifar",
    "pifava": "pifar",
    "pifavam": "pifar",
    "pifavas": "pifar",
    "pife": "pifar",
    "pifei": "pifar",
    "pifeis": "pifar",
    "pifem": "pifar",
    "pifemo": "pifar",
    "pifemos": "pifar",
    "pifes": "pifar",
    "pifo": "pifar",
    "pifos": "pifo",
    "pifou": "pifar",
    "pifá": "pifar",
    "pifámo": "pifar",
    "pifámos": "pifar",
    "pifáramo": "pifar",
    "pifáramos": "pifar",
    "pifárei": "pifar",
    "pifáreis": "pifar",
    "pifásseis": "pifar",
    "pifássemos": "pifar",
    "pifávamo": "pifar",
    "pifávamos": "pifar",
    "pifávei": "pifar",
    "pifáveis": "pifar",
    "pifões": "pifão",
    "pigarra": "pigarrar",
    "pigarrada": "pigarrar",
    "pigarradas": "pigarrar",
    "pigarrado": "pigarrar",
    "pigarrados": "pigarrar",
    "pigarrai": "pigarrar",
    "pigarrais": "pigarrar",
    "pigarram": "pigarrar",
    "pigarramo": "pigarrar",
    "pigarramos": "pigarrar",
    "pigarrando": "pigarrar",
    "pigarrara": "pigarrar",
    "pigarraram": "pigarrar",
    "pigarraras": "pigarrar",
    "pigarrardes": "pigarrar",
    "pigarrarei": "pigarrar",
    "pigarrareis": "pigarrar",
    "pigarrarem": "pigarrar",
    "pigarraremos": "pigarrar",
    "pigarrares": "pigarrar",
    "pigarraria": "pigarrar",
    "pigarrariam": "pigarrar",
    "pigarrarias": "pigarrar",
    "pigarrarmo": "pigarrar",
    "pigarrarmos": "pigarrar",
    "pigarrará": "pigarrar",
    "pigarrarás": "pigarrar",
    "pigarrarão": "pigarrar",
    "pigarraríamos": "pigarrar",
    "pigarraríeis": "pigarrar",
    "pigarras": "pigarrar",
    "pigarrasse": "pigarrar",
    "pigarrassem": "pigarrar",
    "pigarrasses": "pigarrar",
    "pigarraste": "pigarrar",
    "pigarrastes": "pigarrar",
    "pigarrava": "pigarrar",
    "pigarravam": "pigarrar",
    "pigarravas": "pigarrar",
    "pigarre": "pigarrar",
    "pigarreada": "pigarrear",
    "pigarreadas": "pigarrear",
    "pigarreado": "pigarrear",
    "pigarreados": "pigarrear",
    "pigarreai": "pigarrear",
    "pigarreais": "pigarrear",
    "pigarreamo": "pigarrear",
    "pigarreamos": "pigarrear",
    "pigarreando": "pigarrear",
    "pigarreara": "pigarrear",
    "pigarrearam": "pigarrear",
    "pigarrearas": "pigarrear",
    "pigarreardes": "pigarrear",
    "pigarrearei": "pigarrear",
    "pigarreareis": "pigarrear",
    "pigarrearem": "pigarrear",
    "pigarrearemos": "pigarrear",
    "pigarreares": "pigarrear",
    "pigarrearia": "pigarrear",
    "pigarreariam": "pigarrear",
    "pigarrearias": "pigarrear",
    "pigarrearmo": "pigarrear",
    "pigarrearmos": "pigarrear",
    "pigarreará": "pigarrear",
    "pigarrearás": "pigarrear",
    "pigarrearão": "pigarrear",
    "pigarrearíamos": "pigarrear",
    "pigarrearíeis": "pigarrear",
    "pigarreasse": "pigarrear",
    "pigarreassem": "pigarrear",
    "pigarreasses": "pigarrear",
    "pigarreaste": "pigarrear",
    "pigarreastes": "pigarrear",
    "pigarreava": "pigarrear",
    "pigarreavam": "pigarrear",
    "pigarreavas": "pigarrear",
    "pigarreei": "pigarrear",
    "pigarreeis": "pigarrear",
    "pigarreemo": "pigarrear",
    "pigarreemos": "pigarrear",
    "pigarrei": "pigarrar",
    "pigarreia": "pigarrear",
    "pigarreiam": "pigarrear",
    "pigarreias": "pigarrear",
    "pigarreie": "pigarrear",
    "pigarreiem": "pigarrear",
    "pigarreies": "pigarrear",
    "pigarreio": "pigarrear",
    "pigarreiras": "pigarreira",
    "pigarreis": "pigarrar",
    "pigarrem": "pigarrar",
    "pigarremo": "pigarrar",
    "pigarremos": "pigarrar",
    "pigarrenta": "pigarrento",
    "pigarrentas": "pigarrento",
    "pigarrentos": "pigarrento",
    "pigarreou": "pigarrear",
    "pigarres": "pigarrar",
    "pigarreámo": "pigarrear",
    "pigarreámos": "pigarrear",
    "pigarreáramo": "pigarrear",
    "pigarreáramos": "pigarrear",
    "pigarreáreis": "pigarrear",
    "pigarreásseis": "pigarrear",
    "pigarreássemos": "pigarrear",
    "pigarreávamo": "pigarrear",
    "pigarreávamos": "pigarrear",
    "pigarreáveis": "pigarrear",
    "pigarro": "pigarrar",
    "pigarros": "pigarro",
    "pigarrosa": "pigarroso",
    "pigarrosas": "pigarroso",
    "pigarrosos": "pigarroso",
    "pigarrou": "pigarrar",
    "pigarrámo": "pigarrar",
    "pigarrámos": "pigarrar",
    "pigarráramo": "pigarrar",
    "pigarráramos": "pigarrar",
    "pigarráreis": "pigarrar",
    "pigarrásseis": "pigarrar",
    "pigarrássemos": "pigarrar",
    "pigarrávamo": "pigarrar",
    "pigarrávamos": "pigarrar",
    "pigarráveis": "pigarrar",
    "pigarça": "pigarço",
    "pigarças": "pigarço",
    "pigarços": "pigarço",
    "pigeonites": "pigeonite",
    "pigeonítica": "pigeonítico",
    "pigeoníticas": "pigeonítico",
    "pigeoníticos": "pigeonítico",
    "pigmeia": "pigmeu",
    "pigmeias": "pigmeu",
    "pigmenta": "pigmentar",
    "pigmentada": "pigmentar",
    "pigmentadas": "pigmentar",
    "pigmentado": "pigmentar",
    "pigmentados": "pigmentar",
    "pigmentai": "pigmentar",
    "pigmentais": "pigmentar",
    "pigmentam": "pigmentar",
    "pigmentamo": "pigmentar",
    "pigmentamos": "pigmentar",
    "pigmentando": "pigmentar",
    "pigmentara": "pigmentar",
    "pigmentaram": "pigmentar",
    "pigmentaras": "pigmentar",
    "pigmentarde": "pigmentar",
    "pigmentardes": "pigmentar",
    "pigmentare": "pigmentar",
    "pigmentarei": "pigmentar",
    "pigmentareis": "pigmentar",
    "pigmentarem": "pigmentar",
    "pigmentaremos": "pigmentar",
    "pigmentares": "pigmentar",
    "pigmentaria": "pigmentar",
    "pigmentariam": "pigmentar",
    "pigmentarias": "pigmentar",
    "pigmentarmo": "pigmentar",
    "pigmentarmos": "pigmentar",
    "pigmentará": "pigmentar",
    "pigmentarás": "pigmentar",
    "pigmentarão": "pigmentar",
    "pigmentaríamos": "pigmentar",
    "pigmentaríeis": "pigmentar",
    "pigmentas": "pigmentar",
    "pigmentasse": "pigmentar",
    "pigmentassem": "pigmentar",
    "pigmentasses": "pigmentar",
    "pigmentaste": "pigmentar",
    "pigmentastes": "pigmentar",
    "pigmentava": "pigmentar",
    "pigmentavam": "pigmentar",
    "pigmentavas": "pigmentar",
    "pigmentações": "pigmentação",
    "pigmente": "pigmentar",
    "pigmentei": "pigmentar",
    "pigmenteis": "pigmentar",
    "pigmentem": "pigmentar",
    "pigmentemo": "pigmentar",
    "pigmentemos": "pigmentar",
    "pigmentes": "pigmentar",
    "pigmento": "pigmentar",
    "pigmentos": "pigmento",
    "pigmentou": "pigmentar",
    "pigmentá": "pigmentar",
    "pigmentámo": "pigmentar",
    "pigmentámos": "pigmentar",
    "pigmentáramo": "pigmentar",
    "pigmentáramos": "pigmentar",
    "pigmentárei": "pigmentar",
    "pigmentáreis": "pigmentar",
    "pigmentária": "pigmentário",
    "pigmentárias": "pigmentário",
    "pigmentários": "pigmentário",
    "pigmentásseis": "pigmentar",
    "pigmentássemos": "pigmentar",
    "pigmentávamo": "pigmentar",
    "pigmentávamos": "pigmentar",
    "pigmentávei": "pigmentar",
    "pigmentáveis": "pigmentável",
    "pigmeus": "pigmeu",
    "pignoratícia": "pignoratício",
    "pignoratícias": "pignoratício",
    "pignoratícios": "pignoratício",
    "pigostilos": "pigostilo",
    "pigostílica": "pigostílico",
    "pigostílicas": "pigostílico",
    "pigostílicos": "pigostílico",
    "pigostílios": "pigostílio",
    "pigídios": "pigídio",
    "pijamas": "pijama",
    "pila": "pilar",
    "pilada": "pilar",
    "piladas": "pilar",
    "pilado": "pilar",
    "piladora": "pilador",
    "piladoras": "pilador",
    "piladores": "pilador",
    "pilados": "pilar",
    "pilai": "pilar",
    "pilais": "pilar",
    "pilam": "pilar",
    "pilamo": "pilar",
    "pilamos": "pilar",
    "pilando": "pilar",
    "pilara": "pilar",
    "pilaram": "pilar",
    "pilaras": "pilar",
    "pilarde": "pilar",
    "pilardes": "pilar",
    "pilare": "pilar",
    "pilarei": "pilar",
    "pilareis": "pilar",
    "pilarem": "pilar",
    "pilaremos": "pilar",
    "pilares": "pilar",
    "pilaretes": "pilarete",
    "pilaria": "pilar",
    "pilariam": "pilar",
    "pilarias": "pilar",
    "pilarmo": "pilar",
    "pilarmos": "pilar",
    "pilartes": "pilarte",
    "pilará": "pilar",
    "pilarás": "pilar",
    "pilarão": "pilar",
    "pilaríamos": "pilar",
    "pilaríeis": "pilar",
    "pilas": "pilar",
    "pilasse": "pilar",
    "pilassem": "pilar",
    "pilasses": "pilar",
    "pilaste": "pilar",
    "pilastes": "pilar",
    "pilastras": "pilastra",
    "pilava": "pilar",
    "pilavam": "pilar",
    "pilavas": "pilar",
    "pilda": "pildar",
    "pildada": "pildar",
    "pildadas": "pildar",
    "pildado": "pildar",
    "pildados": "pildar",
    "pildai": "pildar",
    "pildais": "pildar",
    "pildam": "pildar",
    "pildamo": "pildar",
    "pildamos": "pildar",
    "pildando": "pildar",
    "pildara": "pildar",
    "pildaram": "pildar",
    "pildaras": "pildar",
    "pildardes": "pildar",
    "pildarei": "pildar",
    "pildareis": "pildar",
    "pildarem": "pildar",
    "pildaremos": "pildar",
    "pildares": "pildar",
    "pildaria": "pildar",
    "pildariam": "pildar",
    "pildarias": "pildar",
    "pildarmo": "pildar",
    "pildarmos": "pildar",
    "pildará": "pildar",
    "pildarás": "pildar",
    "pildarão": "pildar",
    "pildaríamos": "pildar",
    "pildaríeis": "pildar",
    "pildas": "pildar",
    "pildasse": "pildar",
    "pildassem": "pildar",
    "pildasses": "pildar",
    "pildaste": "pildar",
    "pildastes": "pildar",
    "pildava": "pildar",
    "pildavam": "pildar",
    "pildavas": "pildar",
    "pilde": "pildar",
    "pildei": "pildar",
    "pildeis": "pildar",
    "pildem": "pildar",
    "pildemo": "pildar",
    "pildemos": "pildar",
    "pildes": "pildar",
    "pildo": "pildar",
    "pildou": "pildar",
    "pildras": "pildra",
    "pildámo": "pildar",
    "pildámos": "pildar",
    "pildáramo": "pildar",
    "pildáramos": "pildar",
    "pildáreis": "pildar",
    "pildásseis": "pildar",
    "pildássemos": "pildar",
    "pildávamo": "pildar",
    "pildávamos": "pildar",
    "pildáveis": "pildar",
    "pile": "pilar",
    "pilecas": "pileca",
    "pilei": "pilar",
    "pileis": "pilar",
    "pilem": "pilar",
    "pilemo": "pilar",
    "pilemos": "pilar",
    "pileorrizas": "pileorriza",
    "pileques": "pileque",
    "piles": "pilar",
    "pilha": "pilho",
    "pilhada": "pilhar",
    "pilhadas": "pilhar",
    "pilhado": "pilhar",
    "pilhados": "pilhar",
    "pilhagens": "pilhagem",
    "pilhai": "pilhar",
    "pilhais": "pilhar",
    "pilham": "pilhar",
    "pilhamo": "pilhar",
    "pilhamos": "pilhar",
    "pilhando": "pilhar",
    "pilhantes": "pilhante",
    "pilhanços": "pilhanço",
    "pilhara": "pilhar",
    "pilharam": "pilhar",
    "pilharas": "pilhar",
    "pilharde": "pilhar",
    "pilhardes": "pilhar",
    "pilhare": "pilhar",
    "pilharei": "pilhar",
    "pilhareis": "pilhar",
    "pilharem": "pilhar",
    "pilharemos": "pilhar",
    "pilharenga": "pilharengo",
    "pilharengas": "pilharengo",
    "pilharengos": "pilharengo",
    "pilhares": "pilhar",
    "pilhareta": "pilharete",
    "pilharetas": "pilharete",
    "pilharetes": "pilharete",
    "pilharia": "pilhar",
    "pilhariam": "pilhar",
    "pilharias": "pilhar",
    "pilharmo": "pilhar",
    "pilharmos": "pilhar",
    "pilhará": "pilhar",
    "pilharás": "pilhar",
    "pilharão": "pilhar",
    "pilharíamos": "pilhar",
    "pilharíeis": "pilhar",
    "pilhas": "pilho",
    "pilhasse": "pilhar",
    "pilhassem": "pilhar",
    "pilhasses": "pilhar",
    "pilhaste": "pilhar",
    "pilhastes": "pilhar",
    "pilhava": "pilhar",
    "pilhavam": "pilhar",
    "pilhavas": "pilhar",
    "pilhe": "pilhar",
    "pilhei": "pilhar",
    "pilheiras": "pilheira",
    "pilheiros": "pilheiro",
    "pilheis": "pilhar",
    "pilhem": "pilhar",
    "pilhemo": "pilhar",
    "pilhemos": "pilhar",
    "pilhes": "pilhar",
    "pilhetas": "pilheta",
    "pilho": "pilhar",
    "pilhos": "pilho",
    "pilhou": "pilhar",
    "pilhá": "pilhar",
    "pilhámo": "pilhar",
    "pilhámos": "pilhar",
    "pilháramo": "pilhar",
    "pilháramos": "pilhar",
    "pilhárei": "pilhar",
    "pilháreis": "pilhar",
    "pilhásseis": "pilhar",
    "pilhássemos": "pilhar",
    "pilhávamo": "pilhar",
    "pilhávamos": "pilhar",
    "pilhávei": "pilhar",
    "pilháveis": "pilhar",
    "pilhérias": "pilhéria",
    "pilhérica": "pilhérico",
    "pilhéricas": "pilhérico",
    "pilhéricos": "pilhérico",
    "piliformes": "piliforme",
    "pilinha": "pila",
    "pilinhas": "pila",
    "pilins": "pilim",
    "pilita": "pila",
    "pilitas": "pila",
    "pilo": "pilar",
    "piloadas": "piloada",
    "pilocarpinas": "pilocarpina",
    "pilocarpínica": "pilocarpínico",
    "pilocarpínicas": "pilocarpínico",
    "pilocarpínicos": "pilocarpínico",
    "pilones": "pilone",
    "piloros": "piloro",
    "pilos": "pilo",
    "pilosa": "piloso",
    "pilosas": "piloso",
    "piloselas": "pilosela",
    "pilosidades": "pilosidade",
    "pilosos": "piloso",
    "pilota": "piloto",
    "pilotada": "pilotar",
    "pilotadas": "pilotar",
    "pilotado": "pilotar",
    "pilotados": "pilotar",
    "pilotagens": "pilotagem",
    "pilotai": "pilotar",
    "pilotais": "pilotar",
    "pilotam": "pilotar",
    "pilotamo": "pilotar",
    "pilotamos": "pilotar",
    "pilotando": "pilotar",
    "pilotara": "pilotar",
    "pilotaram": "pilotar",
    "pilotaras": "pilotar",
    "pilotarde": "pilotar",
    "pilotardes": "pilotar",
    "pilotare": "pilotar",
    "pilotarei": "pilotar",
    "pilotareis": "pilotar",
    "pilotarem": "pilotar",
    "pilotaremos": "pilotar",
    "pilotares": "pilotar",
    "pilotaria": "pilotar",
    "pilotariam": "pilotar",
    "pilotarias": "pilotar",
    "pilotarmo": "pilotar",
    "pilotarmos": "pilotar",
    "pilotará": "pilotar",
    "pilotarás": "pilotar",
    "pilotarão": "pilotar",
    "pilotaríamos": "pilotar",
    "pilotaríeis": "pilotar",
    "pilotas": "piloto",
    "pilotasse": "pilotar",
    "pilotassem": "pilotar",
    "pilotasses": "pilotar",
    "pilotaste": "pilotar",
    "pilotastes": "pilotar",
    "pilotava": "pilotar",
    "pilotavam": "pilotar",
    "pilotavas": "pilotar",
    "pilote": "pilotar",
    "piloteada": "pilotear",
    "piloteadas": "pilotear",
    "piloteado": "pilotear",
    "piloteados": "pilotear",
    "piloteai": "pilotear",
    "piloteais": "pilotear",
    "piloteamo": "pilotear",
    "piloteamos": "pilotear",
    "piloteando": "pilotear",
    "piloteara": "pilotear",
    "pilotearam": "pilotear",
    "pilotearas": "pilotear",
    "pilotearde": "pilotear",
    "piloteardes": "pilotear",
    "piloteare": "pilotear",
    "pilotearei": "pilotear",
    "piloteareis": "pilotear",
    "pilotearem": "pilotear",
    "pilotearemos": "pilotear",
    "piloteares": "pilotear",
    "pilotearia": "pilotear",
    "piloteariam": "pilotear",
    "pilotearias": "pilotear",
    "pilotearmo": "pilotear",
    "pilotearmos": "pilotear",
    "piloteará": "pilotear",
    "pilotearás": "pilotear",
    "pilotearão": "pilotear",
    "pilotearíamos": "pilotear",
    "pilotearíeis": "pilotear",
    "piloteasse": "pilotear",
    "piloteassem": "pilotear",
    "piloteasses": "pilotear",
    "piloteaste": "pilotear",
    "piloteastes": "pilotear",
    "piloteava": "pilotear",
    "piloteavam": "pilotear",
    "piloteavas": "pilotear",
    "piloteei": "pilotear",
    "piloteeis": "pilotear",
    "piloteemo": "pilotear",
    "piloteemos": "pilotear",
    "pilotei": "pilotar",
    "piloteia": "pilotear",
    "piloteiam": "pilotear",
    "piloteias": "pilotear",
    "piloteie": "pilotear",
    "piloteiem": "pilotear",
    "piloteies": "pilotear",
    "piloteio": "pilotear",
    "piloteis": "pilotar",
    "pilotem": "pilotar",
    "pilotemo": "pilotar",
    "pilotemos": "pilotar",
    "piloteou": "pilotear",
    "pilotes": "pilotar",
    "piloteá": "pilotear",
    "piloteámo": "pilotear",
    "piloteámos": "pilotear",
    "piloteáramo": "pilotear",
    "piloteáramos": "pilotear",
    "piloteárei": "pilotear",
    "piloteáreis": "pilotear",
    "piloteásseis": "pilotear",
    "piloteássemos": "pilotear",
    "piloteávamo": "pilotear",
    "piloteávamos": "pilotear",
    "piloteávei": "pilotear",
    "piloteáveis": "pilotear",
    "piloto": "pilotar",
    "pilotos": "piloto",
    "pilotou": "pilotar",
    "pilotá": "pilotar",
    "pilotámo": "pilotar",
    "pilotámos": "pilotar",
    "pilotáramo": "pilotar",
    "pilotáramos": "pilotar",
    "pilotárei": "pilotar",
    "pilotáreis": "pilotar",
    "pilotásseis": "pilotar",
    "pilotássemos": "pilotar",
    "pilotávamo": "pilotar",
    "pilotávamos": "pilotar",
    "pilotávei": "pilotar",
    "pilotáveis": "pilotável",
    "pilou": "pilar",
    "pilouradas": "pilourada",
    "pilouras": "piloura",
    "pilretes": "pilrete",
    "pilriteiros": "pilriteiro",
    "pilritos": "pilrito",
    "pilula": "pilular",
    "pilulada": "pilular",
    "piluladas": "pilular",
    "pilulado": "pilular",
    "piluladores": "pilulador",
    "pilulados": "pilular",
    "pilulai": "pilular",
    "pilulais": "pilular",
    "pilulam": "pilular",
    "pilulamo": "pilular",
    "pilulamos": "pilular",
    "pilulando": "pilular",
    "pilulara": "pilular",
    "pilularam": "pilular",
    "pilularas": "pilular",
    "pilularde": "pilular",
    "pilulardes": "pilular",
    "pilulare": "pilular",
    "pilularei": "pilular",
    "pilulareis": "pilular",
    "pilularem": "pilular",
    "pilularemos": "pilular",
    "pilulares": "pilular",
    "pilularia": "pilular",
    "pilulariam": "pilular",
    "pilularias": "pilular",
    "pilularmo": "pilular",
    "pilularmos": "pilular",
    "pilulará": "pilular",
    "pilularás": "pilular",
    "pilularão": "pilular",
    "pilularíamos": "pilular",
    "pilularíeis": "pilular",
    "pilulas": "pilular",
    "pilulasse": "pilular",
    "pilulassem": "pilular",
    "pilulasses": "pilular",
    "pilulaste": "pilular",
    "pilulastes": "pilular",
    "pilulava": "pilular",
    "pilulavam": "pilular",
    "pilulavas": "pilular",
    "pilule": "pilular",
    "pilulei": "pilular",
    "piluleiros": "piluleiro",
    "piluleis": "pilular",
    "pilulem": "pilular",
    "pilulemo": "pilular",
    "pilulemos": "pilular",
    "pilules": "pilular",
    "pilulo": "pilular",
    "pilulou": "pilular",
    "pilulá": "pilular",
    "pilulámo": "pilular",
    "pilulámos": "pilular",
    "piluláramo": "pilular",
    "piluláramos": "pilular",
    "pilulárei": "pilular",
    "piluláreis": "pilular",
    "pilulásseis": "pilular",
    "pilulássemos": "pilular",
    "pilulávamo": "pilular",
    "pilulávamos": "pilular",
    "pilulávei": "pilular",
    "piluláveis": "pilular",
    "pilá": "pilar",
    "pilámo": "pilar",
    "pilámos": "pilar",
    "piláramo": "pilar",
    "piláramos": "pilar",
    "pilárei": "pilar",
    "piláreis": "pilar",
    "pilásseis": "pilar",
    "pilássemos": "pilar",
    "pilávamo": "pilar",
    "pilávamos": "pilar",
    "pilávei": "pilar",
    "piláveis": "pilar",
    "pilés": "pilé",
    "pilífera": "pilífero",
    "pilíferas": "pilífero",
    "pilíferos": "pilífero",
    "pilípedes": "pilípede",
    "pilões": "pilão",
    "pimbas": "pimba",
    "pimelodídeos": "pimelodídeo",
    "pimelódidas": "pimelódida",
    "pimentais": "pimental",
    "pimentas": "pimenta",
    "pimenteiras": "pimenteira",
    "pimenteiros": "pimenteiro",
    "pimentinha": "pimenta",
    "pimentinhas": "pimentinha",
    "pimentinho": "pimento",
    "pimentinhos": "pimento",
    "pimentita": "pimenta",
    "pimentitas": "pimenta",
    "pimentito": "pimento",
    "pimentitos": "pimento",
    "pimentos": "pimento",
    "pimentões": "pimentão",
    "pimpa": "pimpar",
    "pimpada": "pimpar",
    "pimpadas": "pimpar",
    "pimpado": "pimpar",
    "pimpados": "pimpar",
    "pimpai": "pimpar",
    "pimpais": "pimpar",
    "pimpalhões": "pimpalhão",
    "pimpam": "pimpar",
    "pimpamo": "pimpar",
    "pimpamos": "pimpar",
    "pimpampuns": "pimpampum",
    "pimpando": "pimpar",
    "pimpantas": "pimpanta",
    "pimpantes": "pimpante",
    "pimpara": "pimpar",
    "pimparam": "pimpar",
    "pimparas": "pimpar",
    "pimpardes": "pimpar",
    "pimparei": "pimpar",
    "pimpareis": "pimpar",
    "pimparem": "pimpar",
    "pimparemos": "pimpar",
    "pimpares": "pimpar",
    "pimparia": "pimpar",
    "pimpariam": "pimpar",
    "pimparias": "pimpar",
    "pimparmo": "pimpar",
    "pimparmos": "pimpar",
    "pimpará": "pimpar",
    "pimparás": "pimpar",
    "pimparão": "pimpar",
    "pimparíamos": "pimpar",
    "pimparíeis": "pimpar",
    "pimpas": "pimpar",
    "pimpasse": "pimpar",
    "pimpassem": "pimpar",
    "pimpasses": "pimpar",
    "pimpaste": "pimpar",
    "pimpastes": "pimpar",
    "pimpava": "pimpar",
    "pimpavam": "pimpar",
    "pimpavas": "pimpar",
    "pimpe": "pimpar",
    "pimpei": "pimpar",
    "pimpeis": "pimpar",
    "pimpem": "pimpar",
    "pimpemo": "pimpar",
    "pimpemos": "pimpar",
    "pimpes": "pimpar",
    "pimpinelas": "pimpinela",
    "pimpins": "pimpim",
    "pimpla": "pimplar",
    "pimplada": "pimplar",
    "pimpladas": "pimplar",
    "pimplado": "pimplar",
    "pimplados": "pimplar",
    "pimplai": "pimplar",
    "pimplais": "pimplar",
    "pimplam": "pimplar",
    "pimplamo": "pimplar",
    "pimplamos": "pimplar",
    "pimplando": "pimplar",
    "pimplara": "pimplar",
    "pimplaram": "pimplar",
    "pimplaras": "pimplar",
    "pimplardes": "pimplar",
    "pimplarei": "pimplar",
    "pimplareis": "pimplar",
    "pimplarem": "pimplar",
    "pimplaremos": "pimplar",
    "pimplares": "pimplar",
    "pimplaria": "pimplar",
    "pimplariam": "pimplar",
    "pimplarias": "pimplar",
    "pimplarmo": "pimplar",
    "pimplarmos": "pimplar",
    "pimplará": "pimplar",
    "pimplarás": "pimplar",
    "pimplarão": "pimplar",
    "pimplaríamos": "pimplar",
    "pimplaríeis": "pimplar",
    "pimplas": "pimplar",
    "pimplasse": "pimplar",
    "pimplassem": "pimplar",
    "pimplasses": "pimplar",
    "pimplaste": "pimplar",
    "pimplastes": "pimplar",
    "pimplava": "pimplar",
    "pimplavam": "pimplar",
    "pimplavas": "pimplar",
    "pimple": "pimplar",
    "pimplei": "pimplar",
    "pimpleis": "pimplar",
    "pimplem": "pimplar",
    "pimplemo": "pimplar",
    "pimplemos": "pimplar",
    "pimples": "pimplar",
    "pimpleus": "pimpleu",
    "pimplo": "pimplar",
    "pimplou": "pimplar",
    "pimplámo": "pimplar",
    "pimplámos": "pimplar",
    "pimpláramo": "pimplar",
    "pimpláramos": "pimplar",
    "pimpláreis": "pimplar",
    "pimplásseis": "pimplar",
    "pimplássemos": "pimplar",
    "pimplávamo": "pimplar",
    "pimplávamos": "pimplar",
    "pimpláveis": "pimplar",
    "pimpo": "pimpar",
    "pimpolha": "pimpolho",
    "pimpolhada": "pimpolhar",
    "pimpolhadas": "pimpolhar",
    "pimpolhado": "pimpolhar",
    "pimpolhados": "pimpolhar",
    "pimpolhai": "pimpolhar",
    "pimpolhais": "pimpolhar",
    "pimpolham": "pimpolhar",
    "pimpolhamo": "pimpolhar",
    "pimpolhamos": "pimpolhar",
    "pimpolhando": "pimpolhar",
    "pimpolhara": "pimpolhar",
    "pimpolharam": "pimpolhar",
    "pimpolharas": "pimpolhar",
    "pimpolhardes": "pimpolhar",
    "pimpolharei": "pimpolhar",
    "pimpolhareis": "pimpolhar",
    "pimpolharem": "pimpolhar",
    "pimpolharemos": "pimpolhar",
    "pimpolhares": "pimpolhar",
    "pimpolharia": "pimpolhar",
    "pimpolhariam": "pimpolhar",
    "pimpolharias": "pimpolhar",
    "pimpolharmo": "pimpolhar",
    "pimpolharmos": "pimpolhar",
    "pimpolhará": "pimpolhar",
    "pimpolharás": "pimpolhar",
    "pimpolharão": "pimpolhar",
    "pimpolharíamos": "pimpolhar",
    "pimpolharíeis": "pimpolhar",
    "pimpolhas": "pimpolho",
    "pimpolhasse": "pimpolhar",
    "pimpolhassem": "pimpolhar",
    "pimpolhasses": "pimpolhar",
    "pimpolhaste": "pimpolhar",
    "pimpolhastes": "pimpolhar",
    "pimpolhava": "pimpolhar",
    "pimpolhavam": "pimpolhar",
    "pimpolhavas": "pimpolhar",
    "pimpolhe": "pimpolhar",
    "pimpolhei": "pimpolhar",
    "pimpolheis": "pimpolhar",
    "pimpolhem": "pimpolhar",
    "pimpolhemo": "pimpolhar",
    "pimpolhemos": "pimpolhar",
    "pimpolhes": "pimpolhar",
    "pimpolho": "pimpolhar",
    "pimpolhos": "pimpolho",
    "pimpolhou": "pimpolhar",
    "pimpolhámo": "pimpolhar",
    "pimpolhámos": "pimpolhar",
    "pimpolháramo": "pimpolhar",
    "pimpolháramos": "pimpolhar",
    "pimpolháreis": "pimpolhar",
    "pimpolhásseis": "pimpolhar",
    "pimpolhássemos": "pimpolhar",
    "pimpolhávamo": "pimpolhar",
    "pimpolhávamos": "pimpolhar",
    "pimpolháveis": "pimpolhar",
    "pimpona": "pimponar",
    "pimponada": "pimponar",
    "pimponadas": "pimponar",
    "pimponado": "pimponar",
    "pimponados": "pimponar",
    "pimponai": "pimponar",
    "pimponais": "pimponar",
    "pimponam": "pimponar",
    "pimponamo": "pimponar",
    "pimponamos": "pimponar",
    "pimponando": "pimponar",
    "pimponara": "pimponar",
    "pimponaram": "pimponar",
    "pimponaras": "pimponar",
    "pimponardes": "pimponar",
    "pimponarei": "pimponar",
    "pimponareis": "pimponar",
    "pimponarem": "pimponar",
    "pimponaremos": "pimponar",
    "pimponares": "pimponar",
    "pimponaria": "pimponar",
    "pimponariam": "pimponar",
    "pimponarias": "pimponar",
    "pimponarmo": "pimponar",
    "pimponarmos": "pimponar",
    "pimponará": "pimponar",
    "pimponarás": "pimponar",
    "pimponarão": "pimponar",
    "pimponaríamos": "pimponar",
    "pimponaríeis": "pimponar",
    "pimponas": "pimponar",
    "pimponasse": "pimponar",
    "pimponassem": "pimponar",
    "pimponasses": "pimponar",
    "pimponaste": "pimponar",
    "pimponastes": "pimponar",
    "pimponava": "pimponar",
    "pimponavam": "pimponar",
    "pimponavas": "pimponar",
    "pimpone": "pimponar",
    "pimponeada": "pimponear",
    "pimponeadas": "pimponear",
    "pimponeado": "pimponear",
    "pimponeados": "pimponear",
    "pimponeai": "pimponear",
    "pimponeais": "pimponear",
    "pimponeamo": "pimponear",
    "pimponeamos": "pimponear",
    "pimponeando": "pimponear",
    "pimponeara": "pimponear",
    "pimponearam": "pimponear",
    "pimponearas": "pimponear",
    "pimponeardes": "pimponear",
    "pimponearei": "pimponear",
    "pimponeareis": "pimponear",
    "pimponearem": "pimponear",
    "pimponearemos": "pimponear",
    "pimponeares": "pimponear",
    "pimponearia": "pimponear",
    "pimponeariam": "pimponear",
    "pimponearias": "pimponear",
    "pimponearmo": "pimponear",
    "pimponearmos": "pimponear",
    "pimponeará": "pimponear",
    "pimponearás": "pimponear",
    "pimponearão": "pimponear",
    "pimponearíamos": "pimponear",
    "pimponearíeis": "pimponear",
    "pimponeasse": "pimponear",
    "pimponeassem": "pimponear",
    "pimponeasses": "pimponear",
    "pimponeaste": "pimponear",
    "pimponeastes": "pimponear",
    "pimponeava": "pimponear",
    "pimponeavam": "pimponear",
    "pimponeavas": "pimponear",
    "pimponeei": "pimponear",
    "pimponeeis": "pimponear",
    "pimponeemo": "pimponear",
    "pimponeemos": "pimponear",
    "pimponei": "pimponar",
    "pimponeia": "pimponear",
    "pimponeiam": "pimponear",
    "pimponeias": "pimponear",
    "pimponeie": "pimponear",
    "pimponeiem": "pimponear",
    "pimponeies": "pimponear",
    "pimponeio": "pimponear",
    "pimponeis": "pimponar",
    "pimponem": "pimponar",
    "pimponemo": "pimponar",
    "pimponemos": "pimponar",
    "pimponeou": "pimponear",
    "pimpones": "pimponar",
    "pimponeámo": "pimponear",
    "pimponeámos": "pimponear",
    "pimponeáramo": "pimponear",
    "pimponeáramos": "pimponear",
    "pimponeáreis": "pimponear",
    "pimponeásseis": "pimponear",
    "pimponeássemos": "pimponear",
    "pimponeávamo": "pimponear",
    "pimponeávamos": "pimponear",
    "pimponeáveis": "pimponear",
    "pimponices": "pimponice",
    "pimpono": "pimponar",
    "pimponou": "pimponar",
    "pimponámo": "pimponar",
    "pimponámos": "pimponar",
    "pimponáramo": "pimponar",
    "pimponáramos": "pimponar",
    "pimponáreis": "pimponar",
    "pimponásseis": "pimponar",
    "pimponássemos": "pimponar",
    "pimponávamo": "pimponar",
    "pimponávamos": "pimponar",
    "pimponáveis": "pimponar",
    "pimpou": "pimpar",
    "pimpámo": "pimpar",
    "pimpámos": "pimpar",
    "pimpáramo": "pimpar",
    "pimpáramos": "pimpar",
    "pimpáreis": "pimpar",
    "pimpásseis": "pimpar",
    "pimpássemos": "pimpar",
    "pimpávamo": "pimpar",
    "pimpávamos": "pimpar",
    "pimpáveis": "pimpar",
    "pimpóis": "pimpol",
    "pimpões": "pimpão",
    "pina": "pinar",
    "pinacoidais": "pinacoidal",
    "pinacotecas": "pinacoteca",
    "pinacotecária": "pinacotecário",
    "pinacotecárias": "pinacotecário",
    "pinacotecários": "pinacotecário",
    "pinacóides": "pinacóide",
    "pinada": "pinar",
    "pinadas": "pinar",
    "pinado": "pinar",
    "pinadores": "pinador",
    "pinados": "pinar",
    "pinai": "pinar",
    "pinais": "pinar",
    "pinam": "pinar",
    "pinamo": "pinar",
    "pinamos": "pinar",
    "pinando": "pinar",
    "pinara": "pinar",
    "pinaram": "pinar",
    "pinaras": "pinar",
    "pinarde": "pinar",
    "pinardes": "pinar",
    "pinare": "pinar",
    "pinarei": "pinar",
    "pinareis": "pinar",
    "pinarem": "pinar",
    "pinaremos": "pinar",
    "pinares": "pinar",
    "pinaria": "pinar",
    "pinariam": "pinar",
    "pinarias": "pinar",
    "pinarmo": "pinar",
    "pinarmos": "pinar",
    "pinará": "pinar",
    "pinarás": "pinar",
    "pinarão": "pinar",
    "pinaríamos": "pinar",
    "pinaríeis": "pinar",
    "pinas": "pinar",
    "pinasse": "pinar",
    "pinassem": "pinar",
    "pinasses": "pinar",
    "pinaste": "pinar",
    "pinastes": "pinar",
    "pinatífida": "pinatífido",
    "pinatífidas": "pinatífido",
    "pinatífidos": "pinatífido",
    "pinava": "pinar",
    "pinavam": "pinar",
    "pinavas": "pinar",
    "pince": "pinçar",
    "pincei": "pinçar",
    "pinceis": "pinçar",
    "pinceizinhos": "pincel",
    "pinceizitos": "pincel",
    "pincela": "pincelar",
    "pincelada": "pincelar",
    "pinceladas": "pincelar",
    "pincelado": "pincelar",
    "pincelados": "pincelar",
    "pincelagens": "pincelagem",
    "pincelai": "pincelar",
    "pincelais": "pincelar",
    "pincelam": "pincelar",
    "pincelamo": "pincelar",
    "pincelamos": "pincelar",
    "pincelando": "pincelar",
    "pincelara": "pincelar",
    "pincelaram": "pincelar",
    "pincelaras": "pincelar",
    "pincelarde": "pincelar",
    "pincelardes": "pincelar",
    "pincelare": "pincelar",
    "pincelarei": "pincelar",
    "pincelareis": "pincelar",
    "pincelarem": "pincelar",
    "pincelaremos": "pincelar",
    "pincelares": "pincelar",
    "pincelaria": "pincelar",
    "pincelariam": "pincelar",
    "pincelarias": "pincelar",
    "pincelarmo": "pincelar",
    "pincelarmos": "pincelar",
    "pincelará": "pincelar",
    "pincelarás": "pincelar",
    "pincelarão": "pincelar",
    "pincelaríamos": "pincelar",
    "pincelaríeis": "pincelar",
    "pincelas": "pincelar",
    "pincelasse": "pincelar",
    "pincelassem": "pincelar",
    "pincelasses": "pincelar",
    "pincelaste": "pincelar",
    "pincelastes": "pincelar",
    "pincelava": "pincelar",
    "pincelavam": "pincelar",
    "pincelavas": "pincelar",
    "pincele": "pincelar",
    "pincelei": "pincelar",
    "pinceleira": "pinceleiro",
    "pinceleiras": "pinceleiro",
    "pinceleiros": "pinceleiro",
    "pinceleis": "pincelar",
    "pincelem": "pincelar",
    "pincelemo": "pincelar",
    "pincelemos": "pincelar",
    "pinceles": "pincelar",
    "pincelinho": "pincel",
    "pincelinhos": "pincel",
    "pincelito": "pincel",
    "pincelitos": "pincel",
    "pincelo": "pincelar",
    "pincelou": "pincelar",
    "pincelzinho": "pincel",
    "pincelzito": "pincel",
    "pincelá": "pincelar",
    "pincelámo": "pincelar",
    "pincelámos": "pincelar",
    "pinceláramo": "pincelar",
    "pinceláramos": "pincelar",
    "pincelárei": "pincelar",
    "pinceláreis": "pincelar",
    "pincelásseis": "pincelar",
    "pincelássemos": "pincelar",
    "pincelávamo": "pincelar",
    "pincelávamos": "pincelar",
    "pincelávei": "pincelar",
    "pinceláveis": "pincelar",
    "pincem": "pinçar",
    "pincemo": "pinçar",
    "pincemos": "pinçar",
    "pinces": "pinçar",
    "pincha": "pinchar",
    "pinchada": "pinchar",
    "pinchadas": "pinchar",
    "pinchado": "pinchar",
    "pinchados": "pinchar",
    "pinchai": "pinchar",
    "pinchais": "pinchar",
    "pincham": "pinchar",
    "pinchamo": "pinchar",
    "pinchamos": "pinchar",
    "pinchando": "pinchar",
    "pinchara": "pinchar",
    "pincharam": "pinchar",
    "pincharas": "pinchar",
    "pincharde": "pinchar",
    "pinchardes": "pinchar",
    "pinchare": "pinchar",
    "pincharei": "pinchar",
    "pinchareis": "pinchar",
    "pincharem": "pinchar",
    "pincharemos": "pinchar",
    "pinchares": "pinchar",
    "pincharia": "pinchar",
    "pinchariam": "pinchar",
    "pincharias": "pinchar",
    "pincharmo": "pinchar",
    "pincharmos": "pinchar",
    "pinchará": "pinchar",
    "pincharás": "pinchar",
    "pincharão": "pinchar",
    "pincharíamos": "pinchar",
    "pincharíeis": "pinchar",
    "pinchas": "pinchar",
    "pinchasse": "pinchar",
    "pinchassem": "pinchar",
    "pinchasses": "pinchar",
    "pinchaste": "pinchar",
    "pinchastes": "pinchar",
    "pinchava": "pinchar",
    "pinchavam": "pinchar",
    "pinchavas": "pinchar",
    "pinche": "pinchar",
    "pinchei": "pinchar",
    "pincheis": "pinchar",
    "pinchem": "pinchar",
    "pinchemo": "pinchar",
    "pinchemos": "pinchar",
    "pinches": "pinchar",
    "pincho": "pinchar",
    "pinchona": "pinchão",
    "pinchonas": "pinchão",
    "pinchos": "pincho",
    "pinchou": "pinchar",
    "pinchá": "pinchar",
    "pinchámo": "pinchar",
    "pinchámos": "pinchar",
    "pincháramo": "pinchar",
    "pincháramos": "pinchar",
    "pinchárei": "pinchar",
    "pincháreis": "pinchar",
    "pinchásseis": "pinchar",
    "pinchássemos": "pinchar",
    "pinchávamo": "pinchar",
    "pinchávamos": "pinchar",
    "pinchávei": "pinchar",
    "pincháveis": "pinchar",
    "pinchões": "pinchão",
    "pincéis": "pincel",
    "pindarismos": "pindarismo",
    "pindaristas": "pindarista",
    "pindariza": "pindarizar",
    "pindarizada": "pindarizar",
    "pindarizadas": "pindarizar",
    "pindarizado": "pindarizar",
    "pindarizados": "pindarizar",
    "pindarizai": "pindarizar",
    "pindarizais": "pindarizar",
    "pindarizam": "pindarizar",
    "pindarizamo": "pindarizar",
    "pindarizamos": "pindarizar",
    "pindarizando": "pindarizar",
    "pindarizara": "pindarizar",
    "pindarizaram": "pindarizar",
    "pindarizaras": "pindarizar",
    "pindarizarde": "pindarizar",
    "pindarizardes": "pindarizar",
    "pindarizare": "pindarizar",
    "pindarizarei": "pindarizar",
    "pindarizareis": "pindarizar",
    "pindarizarem": "pindarizar",
    "pindarizaremos": "pindarizar",
    "pindarizares": "pindarizar",
    "pindarizaria": "pindarizar",
    "pindarizariam": "pindarizar",
    "pindarizarias": "pindarizar",
    "pindarizarmo": "pindarizar",
    "pindarizarmos": "pindarizar",
    "pindarizará": "pindarizar",
    "pindarizarás": "pindarizar",
    "pindarizarão": "pindarizar",
    "pindarizaríamos": "pindarizar",
    "pindarizaríeis": "pindarizar",
    "pindarizas": "pindarizar",
    "pindarizasse": "pindarizar",
    "pindarizassem": "pindarizar",
    "pindarizasses": "pindarizar",
    "pindarizaste": "pindarizar",
    "pindarizastes": "pindarizar",
    "pindarizava": "pindarizar",
    "pindarizavam": "pindarizar",
    "pindarizavas": "pindarizar",
    "pindarize": "pindarizar",
    "pindarizei": "pindarizar",
    "pindarizeis": "pindarizar",
    "pindarizem": "pindarizar",
    "pindarizemo": "pindarizar",
    "pindarizemos": "pindarizar",
    "pindarizes": "pindarizar",
    "pindarizo": "pindarizar",
    "pindarizou": "pindarizar",
    "pindarizá": "pindarizar",
    "pindarizámo": "pindarizar",
    "pindarizámos": "pindarizar",
    "pindarizáramo": "pindarizar",
    "pindarizáramos": "pindarizar",
    "pindarizárei": "pindarizar",
    "pindarizáreis": "pindarizar",
    "pindarizásseis": "pindarizar",
    "pindarizássemos": "pindarizar",
    "pindarizávamo": "pindarizar",
    "pindarizávamos": "pindarizar",
    "pindarizávei": "pindarizar",
    "pindarizáveis": "pindarizar",
    "pindas": "pinda",
    "pindaíbas": "pindaíba",
    "pindaívas": "pindaíva",
    "pinderiquismos": "pinderiquismo",
    "pindobas": "pindoba",
    "pindárica": "pindárico",
    "pindáricas": "pindárico",
    "pindáricos": "pindárico",
    "pindérica": "pindérico",
    "pindéricas": "pindérico",
    "pindéricos": "pindérico",
    "pine": "pinar",
    "pineais": "pineal",
    "pinei": "pinar",
    "pineis": "pinar",
    "pinem": "pinar",
    "pinemo": "pinar",
    "pinemos": "pinar",
    "pinenos": "pineno",
    "pines": "pinar",
    "pinga": "pingar",
    "pingada": "pingar",
    "pingadas": "pingar",
    "pingadeiras": "pingadeira",
    "pingadinha": "pingado",
    "pingadinhas": "pingado",
    "pingadinho": "pingado",
    "pingadinhos": "pingado",
    "pingadita": "pingado",
    "pingaditas": "pingado",
    "pingadito": "pingado",
    "pingaditos": "pingado",
    "pingado": "pingar",
    "pingadoiros": "pingadoiro",
    "pingados": "pingar",
    "pingadouros": "pingadouro",
    "pingadíssima": "pingado",
    "pingadíssimas": "pingado",
    "pingadíssimo": "pingado",
    "pingadíssimos": "pingado",
    "pingai": "pingar",
    "pingais": "pingar",
    "pingaletes": "pingalete",
    "pingalha": "pingalho",
    "pingalhas": "pingalho",
    "pingalhetes": "pingalhete",
    "pingalhos": "pingalho",
    "pingalins": "pingalim",
    "pingam": "pingar",
    "pingamo": "pingar",
    "pingamos": "pingar",
    "pingando": "pingar",
    "pinganelos": "pinganelo",
    "pingantes": "pingante",
    "pinganéis": "pinganel",
    "pingara": "pingar",
    "pingaram": "pingar",
    "pingaras": "pingar",
    "pingarde": "pingar",
    "pingardes": "pingar",
    "pingare": "pingar",
    "pingarei": "pingar",
    "pingareis": "pingar",
    "pingarelha": "pingarelho",
    "pingarelhas": "pingarelho",
    "pingarelhos": "pingarelho",
    "pingarem": "pingar",
    "pingaremos": "pingar",
    "pingares": "pingar",
    "pingaria": "pingar",
    "pingariam": "pingar",
    "pingarias": "pingar",
    "pingarmo": "pingar",
    "pingarmos": "pingar",
    "pingará": "pingar",
    "pingarás": "pingar",
    "pingarão": "pingar",
    "pingaríamos": "pingar",
    "pingaríeis": "pingar",
    "pingas": "pingar",
    "pingasse": "pingar",
    "pingassem": "pingar",
    "pingasses": "pingar",
    "pingaste": "pingar",
    "pingastes": "pingar",
    "pingatos": "pingato",
    "pingava": "pingar",
    "pingavam": "pingar",
    "pingavas": "pingar",
    "pingaços": "pingaço",
    "pingentes": "pingente",
    "pinginha": "pinga",
    "pinginhas": "pinga",
    "pinginho": "pingo",
    "pinginhos": "pingo",
    "pingita": "pinga",
    "pingitas": "pinga",
    "pingito": "pingo",
    "pingitos": "pingo",
    "pingo": "pingar",
    "pingola": "pingolar",
    "pingolada": "pingolar",
    "pingoladas": "pingolar",
    "pingolado": "pingolar",
    "pingolados": "pingolar",
    "pingolai": "pingolar",
    "pingolais": "pingolar",
    "pingolam": "pingolar",
    "pingolamo": "pingolar",
    "pingolamos": "pingolar",
    "pingolando": "pingolar",
    "pingolara": "pingolar",
    "pingolaram": "pingolar",
    "pingolaras": "pingolar",
    "pingolardes": "pingolar",
    "pingolarei": "pingolar",
    "pingolareis": "pingolar",
    "pingolarem": "pingolar",
    "pingolaremos": "pingolar",
    "pingolares": "pingolar",
    "pingolaria": "pingolar",
    "pingolariam": "pingolar",
    "pingolarias": "pingolar",
    "pingolarmo": "pingolar",
    "pingolarmos": "pingolar",
    "pingolará": "pingolar",
    "pingolarás": "pingolar",
    "pingolarão": "pingolar",
    "pingolaríamos": "pingolar",
    "pingolaríeis": "pingolar",
    "pingolas": "pingolar",
    "pingolasse": "pingolar",
    "pingolassem": "pingolar",
    "pingolasses": "pingolar",
    "pingolaste": "pingolar",
    "pingolastes": "pingolar",
    "pingolava": "pingolar",
    "pingolavam": "pingolar",
    "pingolavas": "pingolar",
    "pingole": "pingolar",
    "pingolei": "pingolar",
    "pingoleis": "pingolar",
    "pingolem": "pingolar",
    "pingolemo": "pingolar",
    "pingolemos": "pingolar",
    "pingoles": "pingolar",
    "pingoletas": "pingoleta",
    "pingolo": "pingolar",
    "pingolou": "pingolar",
    "pingolsa": "pingolso",
    "pingolsas": "pingolso",
    "pingolsos": "pingolso",
    "pingolámo": "pingolar",
    "pingolámos": "pingolar",
    "pingoláramo": "pingolar",
    "pingoláramos": "pingolar",
    "pingoláreis": "pingolar",
    "pingolásseis": "pingolar",
    "pingolássemos": "pingolar",
    "pingolávamo": "pingolar",
    "pingolávamos": "pingolar",
    "pingoláveis": "pingolar",
    "pingona": "pingão",
    "pingonas": "pingão",
    "pingos": "pingo",
    "pingotas": "pingota",
    "pingou": "pingar",
    "pingue": "pingar",
    "pinguei": "pingar",
    "pingueira": "pingueiro",
    "pingueiras": "pingueiro",
    "pingueiros": "pingueiro",
    "pingueis": "pingar",
    "pinguelas": "pinguela",
    "pingueletes": "pinguelete",
    "pinguelins": "pinguelim",
    "pinguelos": "pinguelo",
    "pinguem": "pingar",
    "pinguemo": "pingar",
    "pinguemos": "pingar",
    "pingues": "pingue",
    "pinguichos": "pinguicho",
    "pinguins": "pinguim",
    "pinguça": "pinguço",
    "pinguças": "pinguço",
    "pinguços": "pinguço",
    "pingá": "pingar",
    "pingámo": "pingar",
    "pingámos": "pingar",
    "pingáramo": "pingar",
    "pingáramos": "pingar",
    "pingárei": "pingar",
    "pingáreis": "pingar",
    "pingásseis": "pingar",
    "pingássemos": "pingar",
    "pingávamo": "pingar",
    "pingávamos": "pingar",
    "pingávei": "pingar",
    "pingáveis": "pingar",
    "pingões": "pingão",
    "pinhais": "pinhal",
    "pinhas": "pinha",
    "pinhatas": "pinhata",
    "pinheirais": "pinheiral",
    "pinheirames": "pinheirame",
    "pinheiras": "pinheira",
    "pinheirinho": "pinheiro",
    "pinheirinhos": "pinheiro",
    "pinheirito": "pinheiro",
    "pinheiritos": "pinheiro",
    "pinheiros": "pinheiro",
    "pinhoadas": "pinhoada",
    "pinhocas": "pinhoca",
    "pinholas": "pinhola",
    "pinhos": "pinho",
    "pinhotas": "pinhota",
    "pinhões": "pinhão",
    "piniculturas": "pinicultura",
    "piniformes": "piniforme",
    "pininas": "pinina",
    "pino": "pinar",
    "pinocas": "pinoca",
    "pinocazinha": "pinoca",
    "pinocazinhas": "pinoca",
    "pinocazinho": "pinoca",
    "pinocazinhos": "pinoca",
    "pinocazita": "pinoca",
    "pinocazitas": "pinoca",
    "pinocazito": "pinoca",
    "pinocazitos": "pinoca",
    "pinocos": "pinoco",
    "pinoquinha": "pinoca",
    "pinoquinhas": "pinoca",
    "pinos": "pino",
    "pinoteada": "pinotear",
    "pinoteadas": "pinotear",
    "pinoteado": "pinotear",
    "pinoteados": "pinotear",
    "pinoteai": "pinotear",
    "pinoteais": "pinotear",
    "pinoteamo": "pinotear",
    "pinoteamos": "pinotear",
    "pinoteando": "pinotear",
    "pinoteara": "pinotear",
    "pinotearam": "pinotear",
    "pinotearas": "pinotear",
    "pinoteardes": "pinotear",
    "pinotearei": "pinotear",
    "pinoteareis": "pinotear",
    "pinotearem": "pinotear",
    "pinotearemos": "pinotear",
    "pinoteares": "pinotear",
    "pinotearia": "pinotear",
    "pinoteariam": "pinotear",
    "pinotearias": "pinotear",
    "pinotearmo": "pinotear",
    "pinotearmos": "pinotear",
    "pinoteará": "pinotear",
    "pinotearás": "pinotear",
    "pinotearão": "pinotear",
    "pinotearíamos": "pinotear",
    "pinotearíeis": "pinotear",
    "pinoteasse": "pinotear",
    "pinoteassem": "pinotear",
    "pinoteasses": "pinotear",
    "pinoteaste": "pinotear",
    "pinoteastes": "pinotear",
    "pinoteava": "pinotear",
    "pinoteavam": "pinotear",
    "pinoteavas": "pinotear",
    "pinoteei": "pinotear",
    "pinoteeis": "pinotear",
    "pinoteemo": "pinotear",
    "pinoteemos": "pinotear",
    "pinoteia": "pinotear",
    "pinoteiam": "pinotear",
    "pinoteias": "pinotear",
    "pinoteie": "pinotear",
    "pinoteiem": "pinotear",
    "pinoteies": "pinotear",
    "pinoteio": "pinotear",
    "pinoteou": "pinotear",
    "pinotes": "pinote",
    "pinoteámo": "pinotear",
    "pinoteámos": "pinotear",
    "pinoteáramo": "pinotear",
    "pinoteáramos": "pinotear",
    "pinoteáreis": "pinotear",
    "pinoteásseis": "pinotear",
    "pinoteássemos": "pinotear",
    "pinoteávamo": "pinotear",
    "pinoteávamos": "pinotear",
    "pinoteáveis": "pinotear",
    "pinou": "pinar",
    "pins": "pim",
    "pinta": "pinto",
    "pintada": "pintar",
    "pintadas": "pintar",
    "pintadelas": "pintadela",
    "pintadinha": "pintado",
    "pintadinhas": "pintado",
    "pintadinho": "pintado",
    "pintadinhos": "pintado",
    "pintadita": "pintado",
    "pintaditas": "pintado",
    "pintadito": "pintado",
    "pintaditos": "pintado",
    "pintado": "pintar",
    "pintados": "pintar",
    "pintai": "pintar",
    "pintainha": "pintainhar",
    "pintainhada": "pintainhar",
    "pintainhadas": "pintainhar",
    "pintainhado": "pintainhar",
    "pintainhados": "pintainhar",
    "pintainhai": "pintainhar",
    "pintainhais": "pintainhar",
    "pintainham": "pintainhar",
    "pintainhamo": "pintainhar",
    "pintainhamos": "pintainhar",
    "pintainhando": "pintainhar",
    "pintainhara": "pintainhar",
    "pintainharam": "pintainhar",
    "pintainharas": "pintainhar",
    "pintainhardes": "pintainhar",
    "pintainharei": "pintainhar",
    "pintainhareis": "pintainhar",
    "pintainharem": "pintainhar",
    "pintainharemos": "pintainhar",
    "pintainhares": "pintainhar",
    "pintainharia": "pintainhar",
    "pintainhariam": "pintainhar",
    "pintainharias": "pintainhar",
    "pintainharmo": "pintainhar",
    "pintainharmos": "pintainhar",
    "pintainhará": "pintainhar",
    "pintainharás": "pintainhar",
    "pintainharão": "pintainhar",
    "pintainharíamos": "pintainhar",
    "pintainharíeis": "pintainhar",
    "pintainhas": "pintainhar",
    "pintainhasse": "pintainhar",
    "pintainhassem": "pintainhar",
    "pintainhasses": "pintainhar",
    "pintainhaste": "pintainhar",
    "pintainhastes": "pintainhar",
    "pintainhava": "pintainhar",
    "pintainhavam": "pintainhar",
    "pintainhavas": "pintainhar",
    "pintainhe": "pintainhar",
    "pintainhei": "pintainhar",
    "pintainheis": "pintainhar",
    "pintainhem": "pintainhar",
    "pintainhemo": "pintainhar",
    "pintainhemos": "pintainhar",
    "pintainhes": "pintainhar",
    "pintainho": "pintainhar",
    "pintainhos": "pintainho",
    "pintainhou": "pintainhar",
    "pintainhámo": "pintainhar",
    "pintainhámos": "pintainhar",
    "pintainháramo": "pintainhar",
    "pintainháramos": "pintainhar",
    "pintainháreis": "pintainhar",
    "pintainhásseis": "pintainhar",
    "pintainhássemos": "pintainhar",
    "pintainhávamo": "pintainhar",
    "pintainhávamos": "pintainhar",
    "pintainháveis": "pintainhar",
    "pintais": "pintar",
    "pintalegretes": "pintalegrete",
    "pintalga": "pintalgar",
    "pintalgada": "pintalgar",
    "pintalgadas": "pintalgar",
    "pintalgado": "pintalgar",
    "pintalgados": "pintalgar",
    "pintalgai": "pintalgar",
    "pintalgais": "pintalgar",
    "pintalgam": "pintalgar",
    "pintalgamo": "pintalgar",
    "pintalgamos": "pintalgar",
    "pintalgando": "pintalgar",
    "pintalgara": "pintalgar",
    "pintalgaram": "pintalgar",
    "pintalgaras": "pintalgar",
    "pintalgarde": "pintalgar",
    "pintalgardes": "pintalgar",
    "pintalgare": "pintalgar",
    "pintalgarei": "pintalgar",
    "pintalgareis": "pintalgar",
    "pintalgarem": "pintalgar",
    "pintalgaremos": "pintalgar",
    "pintalgares": "pintalgar",
    "pintalgaria": "pintalgar",
    "pintalgariam": "pintalgar",
    "pintalgarias": "pintalgar",
    "pintalgarmo": "pintalgar",
    "pintalgarmos": "pintalgar",
    "pintalgará": "pintalgar",
    "pintalgarás": "pintalgar",
    "pintalgarão": "pintalgar",
    "pintalgaríamos": "pintalgar",
    "pintalgaríeis": "pintalgar",
    "pintalgas": "pintalgar",
    "pintalgasse": "pintalgar",
    "pintalgassem": "pintalgar",
    "pintalgasses": "pintalgar",
    "pintalgaste": "pintalgar",
    "pintalgastes": "pintalgar",
    "pintalgava": "pintalgar",
    "pintalgavam": "pintalgar",
    "pintalgavas": "pintalgar",
    "pintalgo": "pintalgar",
    "pintalgou": "pintalgar",
    "pintalgue": "pintalgar",
    "pintalguei": "pintalgar",
    "pintalgueis": "pintalgar",
    "pintalguem": "pintalgar",
    "pintalguemo": "pintalgar",
    "pintalguemos": "pintalgar",
    "pintalgues": "pintalgar",
    "pintalgá": "pintalgar",
    "pintalgámo": "pintalgar",
    "pintalgámos": "pintalgar",
    "pintalgáramo": "pintalgar",
    "pintalgáramos": "pintalgar",
    "pintalgárei": "pintalgar",
    "pintalgáreis": "pintalgar",
    "pintalgásseis": "pintalgar",
    "pintalgássemos": "pintalgar",
    "pintalgávamo": "pintalgar",
    "pintalgávamos": "pintalgar",
    "pintalgávei": "pintalgar",
    "pintalgáveis": "pintalgar",
    "pintalhas": "pintalha",
    "pintalhões": "pintalhão",
    "pintaloporcos": "pintaloporco",
    "pintam": "pintar",
    "pintamo": "pintar",
    "pintamos": "pintar",
    "pintando": "pintar",
    "pintara": "pintar",
    "pintaram": "pintar",
    "pintaras": "pintar",
    "pintarde": "pintar",
    "pintardes": "pintar",
    "pintare": "pintar",
    "pintarei": "pintar",
    "pintareis": "pintar",
    "pintarem": "pintar",
    "pintaremos": "pintar",
    "pintares": "pintar",
    "pintaria": "pintar",
    "pintariam": "pintar",
    "pintarias": "pintar",
    "pintarmo": "pintar",
    "pintarmos": "pintar",
    "pintarroxas": "pintarroxa",
    "pintarroxos": "pintarroxo",
    "pintará": "pintar",
    "pintarás": "pintar",
    "pintarão": "pintar",
    "pintaríamos": "pintar",
    "pintaríeis": "pintar",
    "pintas": "pinto",
    "pintasse": "pintar",
    "pintassem": "pintar",
    "pintasses": "pintar",
    "pintassilgos": "pintassilgo",
    "pintassilvos": "pintassilvo",
    "pintassirgos": "pintassirgo",
    "pintaste": "pintar",
    "pintastes": "pintar",
    "pintava": "pintar",
    "pintavam": "pintar",
    "pintavas": "pintar",
    "pinte": "pintar",
    "pintei": "pintar",
    "pinteis": "pintar",
    "pintem": "pintar",
    "pintemo": "pintar",
    "pintemos": "pintar",
    "pintes": "pintar",
    "pintinha": "pinto",
    "pintinhas": "pinto",
    "pintinho": "pinto",
    "pintinhos": "pinto",
    "pintita": "pinto",
    "pintitas": "pinto",
    "pintito": "pinto",
    "pintitos": "pinto",
    "pinto": "pintar",
    "pintona": "pintão",
    "pintonas": "pintão",
    "pintora": "pintor",
    "pintoras": "pintor",
    "pintores": "pintor",
    "pintoresca": "pintoresco",
    "pintorescas": "pintoresco",
    "pintorescos": "pintoresco",
    "pintos": "pinto",
    "pintou": "pintar",
    "pinturais": "pintural",
    "pinturas": "pintura",
    "pinturescos": "pinturesco",
    "pintá": "pintar",
    "pintámo": "pintar",
    "pintámos": "pintar",
    "pintáramo": "pintar",
    "pintáramos": "pintar",
    "pintárei": "pintar",
    "pintáreis": "pintar",
    "pintásseis": "pintar",
    "pintássemos": "pintar",
    "pintávamo": "pintar",
    "pintávamos": "pintar",
    "pintávei": "pintar",
    "pintáveis": "pintável",
    "pintões": "pintão",
    "pinulada": "pinulado",
    "pinuladas": "pinulado",
    "pinulados": "pinulado",
    "piná": "pinar",
    "pináceas": "pinácea",
    "pináculos": "pináculo",
    "pinámo": "pinar",
    "pinámos": "pinar",
    "pináramo": "pinar",
    "pináramos": "pinar",
    "pinárei": "pinar",
    "pináreis": "pinar",
    "pinásseis": "pinar",
    "pinássemos": "pinar",
    "pinávamo": "pinar",
    "pinávamos": "pinar",
    "pinávei": "pinar",
    "pináveis": "pinar",
    "pinázios": "pinázio",
    "pinça": "pinçar",
    "pinçada": "pinçar",
    "pinçadas": "pinçar",
    "pinçado": "pinçar",
    "pinçados": "pinçar",
    "pinçai": "pinçar",
    "pinçais": "pinçar",
    "pinçam": "pinçar",
    "pinçamo": "pinçar",
    "pinçamos": "pinçar",
    "pinçando": "pinçar",
    "pinçara": "pinçar",
    "pinçaram": "pinçar",
    "pinçaras": "pinçar",
    "pinçarde": "pinçar",
    "pinçardes": "pinçar",
    "pinçare": "pinçar",
    "pinçarei": "pinçar",
    "pinçareis": "pinçar",
    "pinçarem": "pinçar",
    "pinçaremos": "pinçar",
    "pinçares": "pinçar",
    "pinçaria": "pinçar",
    "pinçariam": "pinçar",
    "pinçarias": "pinçar",
    "pinçarmo": "pinçar",
    "pinçarmos": "pinçar",
    "pinçará": "pinçar",
    "pinçarás": "pinçar",
    "pinçarão": "pinçar",
    "pinçaríamos": "pinçar",
    "pinçaríeis": "pinçar",
    "pinças": "pinçar",
    "pinçasse": "pinçar",
    "pinçassem": "pinçar",
    "pinçasses": "pinçar",
    "pinçaste": "pinçar",
    "pinçastes": "pinçar",
    "pinçava": "pinçar",
    "pinçavam": "pinçar",
    "pinçavas": "pinçar",
    "pinço": "pinçar",
    "pinçotes": "pinçote",
    "pinçou": "pinçar",
    "pinçá": "pinçar",
    "pinçámo": "pinçar",
    "pinçámos": "pinçar",
    "pinçáramo": "pinçar",
    "pinçáramos": "pinçar",
    "pinçárei": "pinçar",
    "pinçáreis": "pinçar",
    "pinçásseis": "pinçar",
    "pinçássemos": "pinçar",
    "pinçávamo": "pinçar",
    "pinçávamos": "pinçar",
    "pinçávei": "pinçar",
    "pinçáveis": "pinçar",
    "pinções": "pinção",
    "pinéus": "pinéu",
    "pinícolas": "pinícola",
    "pinífera": "pinífero",
    "piníferas": "pinífero",
    "piníferos": "pinífero",
    "pinígera": "pinígero",
    "pinígeras": "pinígero",
    "pinígeros": "pinígero",
    "pinípedes": "pinípede",
    "pio": "piar",
    "piobeiros": "piobeiro",
    "piogenias": "piogenia",
    "piogenésica": "piogenésico",
    "piogenésicas": "piogenésico",
    "piogenésicos": "piogenésico",
    "piogenética": "piogenético",
    "piogenéticas": "piogenético",
    "piogenéticos": "piogenético",
    "piogéneses": "piogénese",
    "piogénica": "piogénico",
    "piogénicas": "piogénico",
    "piogénicos": "piogénico",
    "piolhadas": "piolhada",
    "piolharias": "piolharia",
    "piolheira": "piolheiro",
    "piolheiras": "piolheiro",
    "piolheiros": "piolheiro",
    "piolhenta": "piolhento",
    "piolhentas": "piolhento",
    "piolhentos": "piolhento",
    "piolhices": "piolhice",
    "piolhos": "piolho",
    "piolhosa": "piolhoso",
    "piolhosas": "piolhoso",
    "piolhosos": "piolhoso",
    "pioneira": "pioneiro",
    "pioneiras": "pioneiro",
    "pioneirismos": "pioneirismo",
    "pioneiros": "pioneiro",
    "pioneiríssima": "pioneiro",
    "pioneiríssimas": "pioneiro",
    "pioneiríssimo": "pioneiro",
    "pioneiríssimos": "pioneiro",
    "pioninhas": "pioninha",
    "pior": "mal",
    "piora": "piorar",
    "piorada": "piorar",
    "pioradas": "piorar",
    "piorado": "piorar",
    "piorados": "piorar",
    "piorai": "piorar",
    "piorais": "piorar",
    "pioram": "piorar",
    "pioramo": "piorar",
    "pioramos": "piorar",
    "piorando": "piorar",
    "piorara": "piorar",
    "pioraram": "piorar",
    "pioraras": "piorar",
    "piorardes": "piorar",
    "piorarei": "piorar",
    "piorareis": "piorar",
    "piorarem": "piorar",
    "pioraremos": "piorar",
    "piorares": "piorar",
    "pioraria": "piorar",
    "piorariam": "piorar",
    "piorarias": "piorar",
    "piorarmo": "piorar",
    "piorarmos": "piorar",
    "piorará": "piorar",
    "piorarás": "piorar",
    "piorarão": "piorar",
    "pioraríamos": "piorar",
    "pioraríeis": "piorar",
    "pioras": "piorar",
    "piorasse": "piorar",
    "piorassem": "piorar",
    "piorasses": "piorar",
    "pioraste": "piorar",
    "piorastes": "piorar",
    "piorava": "piorar",
    "pioravam": "piorar",
    "pioravas": "piorar",
    "piore": "piorar",
    "piorei": "piorar",
    "pioreis": "piorar",
    "piorem": "piorar",
    "pioremo": "piorar",
    "pioremos": "piorar",
    "piores": "piorar",
    "piorias": "pioria",
    "piorios": "piorio",
    "piornais": "piornal",
    "piornos": "piorno",
    "pioro": "piorar",
    "piorou": "piorar",
    "piorras": "piorra",
    "piorreias": "piorreia",
    "piorreica": "piorreico",
    "piorreicas": "piorreico",
    "piorreicos": "piorreico",
    "piorrinha": "piorra",
    "piorrinhas": "piorra",
    "piorrita": "piorra",
    "piorritas": "piorra",
    "piorámo": "piorar",
    "piorámos": "piorar",
    "pioráramo": "piorar",
    "pioráramos": "piorar",
    "pioráreis": "piorar",
    "piorásseis": "piorar",
    "piorássemos": "piorar",
    "piorávamo": "piorar",
    "piorávamos": "piorar",
    "pioráveis": "piorar",
    "pios": "pio",
    "piou": "piar",
    "piparota": "piparotar",
    "piparotada": "piparotar",
    "piparotadas": "piparotar",
    "piparotado": "piparotar",
    "piparotados": "piparotar",
    "piparotai": "piparotar",
    "piparotais": "piparotar",
    "piparotam": "piparotar",
    "piparotamo": "piparotar",
    "piparotamos": "piparotar",
    "piparotando": "piparotar",
    "piparotara": "piparotar",
    "piparotaram": "piparotar",
    "piparotaras": "piparotar",
    "piparotarde": "piparotar",
    "piparotardes": "piparotar",
    "piparotare": "piparotar",
    "piparotarei": "piparotar",
    "piparotareis": "piparotar",
    "piparotarem": "piparotar",
    "piparotaremos": "piparotar",
    "piparotares": "piparotar",
    "piparotaria": "piparotar",
    "piparotariam": "piparotar",
    "piparotarias": "piparotar",
    "piparotarmo": "piparotar",
    "piparotarmos": "piparotar",
    "piparotará": "piparotar",
    "piparotarás": "piparotar",
    "piparotarão": "piparotar",
    "piparotaríamos": "piparotar",
    "piparotaríeis": "piparotar",
    "piparotas": "piparotar",
    "piparotasse": "piparotar",
    "piparotassem": "piparotar",
    "piparotasses": "piparotar",
    "piparotaste": "piparotar",
    "piparotastes": "piparotar",
    "piparotava": "piparotar",
    "piparotavam": "piparotar",
    "piparotavas": "piparotar",
    "piparote": "piparotar",
    "piparotei": "piparotar",
    "piparoteis": "piparotar",
    "piparotem": "piparotar",
    "piparotemo": "piparotar",
    "piparotemos": "piparotar",
    "piparotes": "piparote",
    "piparoto": "piparotar",
    "piparotou": "piparotar",
    "piparotá": "piparotar",
    "piparotámo": "piparotar",
    "piparotámos": "piparotar",
    "piparotáramo": "piparotar",
    "piparotáramos": "piparotar",
    "piparotárei": "piparotar",
    "piparotáreis": "piparotar",
    "piparotásseis": "piparotar",
    "piparotássemos": "piparotar",
    "piparotávamo": "piparotar",
    "piparotávamos": "piparotar",
    "piparotávei": "piparotar",
    "piparotáveis": "piparotar",
    "pipas": "pipa",
    "pipelines": "pipeline",
    "piperinas": "piperina",
    "piperácea": "piperáceo",
    "piperáceas": "piperáceo",
    "piperáceos": "piperáceo",
    "piperínica": "piperínico",
    "piperínicas": "piperínico",
    "piperínicos": "piperínico",
    "pipetas": "pipeta",
    "pipia": "pipiar",
    "pipiada": "pipiar",
    "pipiadas": "pipiar",
    "pipiado": "pipiar",
    "pipiados": "pipiar",
    "pipiai": "pipiar",
    "pipiais": "pipiar",
    "pipiam": "pipiar",
    "pipiamo": "pipiar",
    "pipiamos": "pipiar",
    "pipiando": "pipiar",
    "pipiara": "pipiar",
    "pipiaram": "pipiar",
    "pipiaras": "pipiar",
    "pipiardes": "pipiar",
    "pipiarei": "pipiar",
    "pipiareis": "pipiar",
    "pipiarem": "pipiar",
    "pipiaremos": "pipiar",
    "pipiares": "pipiar",
    "pipiaria": "pipiar",
    "pipiariam": "pipiar",
    "pipiarias": "pipiar",
    "pipiarmo": "pipiar",
    "pipiarmos": "pipiar",
    "pipiará": "pipiar",
    "pipiarás": "pipiar",
    "pipiarão": "pipiar",
    "pipiaríamos": "pipiar",
    "pipiaríeis": "pipiar",
    "pipias": "pipiar",
    "pipiasse": "pipiar",
    "pipiassem": "pipiar",
    "pipiasses": "pipiar",
    "pipiaste": "pipiar",
    "pipiastes": "pipiar",
    "pipiava": "pipiar",
    "pipiavam": "pipiar",
    "pipiavas": "pipiar",
    "pipie": "pipiar",
    "pipiei": "pipiar",
    "pipieis": "pipiar",
    "pipiem": "pipiar",
    "pipiemo": "pipiar",
    "pipiemos": "pipiar",
    "pipies": "pipiar",
    "pipila": "pipilar",
    "pipilada": "pipilar",
    "pipiladas": "pipilar",
    "pipilado": "pipilar",
    "pipilados": "pipilar",
    "pipilai": "pipilar",
    "pipilais": "pipilar",
    "pipilam": "pipilar",
    "pipilamo": "pipilar",
    "pipilamos": "pipilar",
    "pipilando": "pipilar",
    "pipilantes": "pipilante",
    "pipilara": "pipilar",
    "pipilaram": "pipilar",
    "pipilaras": "pipilar",
    "pipilardes": "pipilar",
    "pipilarei": "pipilar",
    "pipilareis": "pipilar",
    "pipilarem": "pipilar",
    "pipilaremos": "pipilar",
    "pipilares": "pipilar",
    "pipilaria": "pipilar",
    "pipilariam": "pipilar",
    "pipilarias": "pipilar",
    "pipilarmo": "pipilar",
    "pipilarmos": "pipilar",
    "pipilará": "pipilar",
    "pipilarás": "pipilar",
    "pipilarão": "pipilar",
    "pipilaríamos": "pipilar",
    "pipilaríeis": "pipilar",
    "pipilas": "pipilar",
    "pipilasse": "pipilar",
    "pipilassem": "pipilar",
    "pipilasses": "pipilar",
    "pipilaste": "pipilar",
    "pipilastes": "pipilar",
    "pipilava": "pipilar",
    "pipilavam": "pipilar",
    "pipilavas": "pipilar",
    "pipile": "pipilar",
    "pipilei": "pipilar",
    "pipileis": "pipilar",
    "pipilem": "pipilar",
    "pipilemo": "pipilar",
    "pipilemos": "pipilar",
    "pipiles": "pipilar",
    "pipilo": "pipilar",
    "pipilos": "pipilo",
    "pipilou": "pipilar",
    "pipilámo": "pipilar",
    "pipilámos": "pipilar",
    "pipiláramo": "pipilar",
    "pipiláramos": "pipilar",
    "pipiláreis": "pipilar",
    "pipilásseis": "pipilar",
    "pipilássemos": "pipilar",
    "pipilávamo": "pipilar",
    "pipilávamos": "pipilar",
    "pipiláveis": "pipilar",
    "pipio": "pipiar",
    "pipios": "pipio",
    "pipiou": "pipiar",
    "pipis": "pipi",
    "pipita": "pipitar",
    "pipitada": "pipitar",
    "pipitadas": "pipitar",
    "pipitado": "pipitar",
    "pipitados": "pipitar",
    "pipitai": "pipitar",
    "pipitais": "pipitar",
    "pipitam": "pipitar",
    "pipitamo": "pipitar",
    "pipitamos": "pipitar",
    "pipitando": "pipitar",
    "pipitara": "pipitar",
    "pipitaram": "pipitar",
    "pipitaras": "pipitar",
    "pipitardes": "pipitar",
    "pipitarei": "pipitar",
    "pipitareis": "pipitar",
    "pipitarem": "pipitar",
    "pipitaremos": "pipitar",
    "pipitares": "pipitar",
    "pipitaria": "pipitar",
    "pipitariam": "pipitar",
    "pipitarias": "pipitar",
    "pipitarmo": "pipitar",
    "pipitarmos": "pipitar",
    "pipitará": "pipitar",
    "pipitarás": "pipitar",
    "pipitarão": "pipitar",
    "pipitaríamos": "pipitar",
    "pipitaríeis": "pipitar",
    "pipitas": "pipitar",
    "pipitasse": "pipitar",
    "pipitassem": "pipitar",
    "pipitasses": "pipitar",
    "pipitaste": "pipitar",
    "pipitastes": "pipitar",
    "pipitava": "pipitar",
    "pipitavam": "pipitar",
    "pipitavas": "pipitar",
    "pipite": "pipitar",
    "pipitei": "pipitar",
    "pipiteis": "pipitar",
    "pipitem": "pipitar",
    "pipitemo": "pipitar",
    "pipitemos": "pipitar",
    "pipites": "pipitar",
    "pipito": "pipitar",
    "pipitou": "pipitar",
    "pipitámo": "pipitar",
    "pipitámos": "pipitar",
    "pipitáramo": "pipitar",
    "pipitáramos": "pipitar",
    "pipitáreis": "pipitar",
    "pipitásseis": "pipitar",
    "pipitássemos": "pipitar",
    "pipitávamo": "pipitar",
    "pipitávamos": "pipitar",
    "pipitáveis": "pipitar",
    "pipiámo": "pipiar",
    "pipiámos": "pipiar",
    "pipiáramo": "pipiar",
    "pipiáramos": "pipiar",
    "pipiáreis": "pipiar",
    "pipiásseis": "pipiar",
    "pipiássemos": "pipiar",
    "pipiávamo": "pipiar",
    "pipiávamos": "pipiar",
    "pipiáveis": "pipiar",
    "pipoca": "pipocar",
    "pipocada": "pipocar",
    "pipocadas": "pipocar",
    "pipocado": "pipocar",
    "pipocados": "pipocar",
    "pipocais": "pipocar",
    "pipocam": "pipocar",
    "pipocamo": "pipocar",
    "pipocamos": "pipocar",
    "pipocando": "pipocar",
    "pipocara": "pipocar",
    "pipocaram": "pipocar",
    "pipocaras": "pipocar",
    "pipocardes": "pipocar",
    "pipocarei": "pipocar",
    "pipocareis": "pipocar",
    "pipocarem": "pipocar",
    "pipocaremos": "pipocar",
    "pipocares": "pipocar",
    "pipocaria": "pipocar",
    "pipocariam": "pipocar",
    "pipocarias": "pipocar",
    "pipocarmo": "pipocar",
    "pipocarmos": "pipocar",
    "pipocará": "pipocar",
    "pipocarás": "pipocar",
    "pipocarão": "pipocar",
    "pipocaríamos": "pipocar",
    "pipocaríeis": "pipocar",
    "pipocas": "pipocar",
    "pipocasse": "pipocar",
    "pipocassem": "pipocar",
    "pipocasses": "pipocar",
    "pipocaste": "pipocar",
    "pipocastes": "pipocar",
    "pipocava": "pipocar",
    "pipocavam": "pipocar",
    "pipocavas": "pipocar",
    "pipoco": "pipocar",
    "pipocos": "pipoco",
    "pipocou": "pipocar",
    "pipocámo": "pipocar",
    "pipocámos": "pipocar",
    "pipocáramo": "pipocar",
    "pipocáramos": "pipocar",
    "pipocáreis": "pipocar",
    "pipocásseis": "pipocar",
    "pipocássemos": "pipocar",
    "pipocávamo": "pipocar",
    "pipocávamos": "pipocar",
    "pipocáveis": "pipocar",
    "pipoque": "pipocar",
    "pipoquei": "pipocar",
    "pipoqueis": "pipocar",
    "pipoquem": "pipocar",
    "pipoquemos": "pipocar",
    "pipoques": "pipocar",
    "pipos": "pipo",
    "pipotes": "pipote",
    "pipras": "pipra",
    "piprídeos": "piprídeo",
    "pique": "picar",
    "piqueeada": "piqueear",
    "piqueeadas": "piqueear",
    "piqueeado": "piqueear",
    "piqueeados": "piqueear",
    "piqueeai": "piqueear",
    "piqueeais": "piqueear",
    "piqueeamo": "piqueear",
    "piqueeamos": "piqueear",
    "piqueeando": "piqueear",
    "piqueeara": "piqueear",
    "piqueearam": "piqueear",
    "piqueearas": "piqueear",
    "piqueeardes": "piqueear",
    "piqueearei": "piqueear",
    "piqueeareis": "piqueear",
    "piqueearem": "piqueear",
    "piqueearemos": "piqueear",
    "piqueeares": "piqueear",
    "piqueearia": "piqueear",
    "piqueeariam": "piqueear",
    "piqueearias": "piqueear",
    "piqueearmo": "piqueear",
    "piqueearmos": "piqueear",
    "piqueeará": "piqueear",
    "piqueearás": "piqueear",
    "piqueearão": "piqueear",
    "piqueearíamos": "piqueear",
    "piqueearíeis": "piqueear",
    "piqueeasse": "piqueear",
    "piqueeassem": "piqueear",
    "piqueeasses": "piqueear",
    "piqueeaste": "piqueear",
    "piqueeastes": "piqueear",
    "piqueeava": "piqueear",
    "piqueeavam": "piqueear",
    "piqueeavas": "piqueear",
    "piqueeei": "piqueear",
    "piqueeeis": "piqueear",
    "piqueeemo": "piqueear",
    "piqueeemos": "piqueear",
    "piqueeia": "piqueear",
    "piqueeiam": "piqueear",
    "piqueeias": "piqueear",
    "piqueeie": "piqueear",
    "piqueeiem": "piqueear",
    "piqueeies": "piqueear",
    "piqueeio": "piqueear",
    "piqueeou": "piqueear",
    "piqueeámo": "piqueear",
    "piqueeámos": "piqueear",
    "piqueeáramo": "piqueear",
    "piqueeáramos": "piqueear",
    "piqueeáreis": "piqueear",
    "piqueeásseis": "piqueear",
    "piqueeássemos": "piqueear",
    "piqueeávamo": "piqueear",
    "piqueeávamos": "piqueear",
    "piqueeáveis": "piqueear",
    "piquei": "picar",
    "piqueis": "picar",
    "piquem": "picar",
    "piquemo": "picar",
    "piquemos": "picar",
    "piquenica": "piquenicar",
    "piquenicada": "piquenicar",
    "piquenicadas": "piquenicar",
    "piquenicado": "piquenicar",
    "piquenicados": "piquenicar",
    "piquenicais": "piquenicar",
    "piquenicam": "piquenicar",
    "piquenicamo": "piquenicar",
    "piquenicamos": "piquenicar",
    "piquenicando": "piquenicar",
    "piquenicara": "piquenicar",
    "piquenicaram": "piquenicar",
    "piquenicaras": "piquenicar",
    "piquenicardes": "piquenicar",
    "piquenicarei": "piquenicar",
    "piquenicareis": "piquenicar",
    "piquenicarem": "piquenicar",
    "piquenicaremos": "piquenicar",
    "piquenicares": "piquenicar",
    "piquenicaria": "piquenicar",
    "piquenicariam": "piquenicar",
    "piquenicarias": "piquenicar",
    "piquenicarmo": "piquenicar",
    "piquenicarmos": "piquenicar",
    "piquenicará": "piquenicar",
    "piquenicarás": "piquenicar",
    "piquenicarão": "piquenicar",
    "piquenicaríamos": "piquenicar",
    "piquenicaríeis": "piquenicar",
    "piquenicas": "piquenicar",
    "piquenicasse": "piquenicar",
    "piquenicassem": "piquenicar",
    "piquenicasses": "piquenicar",
    "piquenicaste": "piquenicar",
    "piquenicastes": "piquenicar",
    "piquenicava": "piquenicar",
    "piquenicavam": "piquenicar",
    "piquenicavas": "piquenicar",
    "piquenico": "piquenicar",
    "piquenicou": "piquenicar",
    "piquenicámo": "piquenicar",
    "piquenicámos": "piquenicar",
    "piquenicáramo": "piquenicar",
    "piquenicáramos": "piquenicar",
    "piquenicáreis": "piquenicar",
    "piquenicásseis": "piquenicar",
    "piquenicássemos": "piquenicar",
    "piquenicávamo": "piquenicar",
    "piquenicávamos": "piquenicar",
    "piquenicáveis": "piquenicar",
    "piquenique": "piquenicar",
    "piqueniquei": "piquenicar",
    "piqueniqueis": "piquenicar",
    "piqueniquem": "piquenicar",
    "piqueniquemos": "piquenicar",
    "piqueniques": "piquenique",
    "piques": "pique",
    "piqueta": "piquetar",
    "piquetada": "piquetar",
    "piquetadas": "piquetar",
    "piquetado": "piquetar",
    "piquetados": "piquetar",
    "piquetagens": "piquetagem",
    "piquetai": "piquetar",
    "piquetais": "piquetar",
    "piquetam": "piquetar",
    "piquetamo": "piquetar",
    "piquetamos": "piquetar",
    "piquetando": "piquetar",
    "piquetara": "piquetar",
    "piquetaram": "piquetar",
    "piquetaras": "piquetar",
    "piquetarde": "piquetar",
    "piquetardes": "piquetar",
    "piquetare": "piquetar",
    "piquetarei": "piquetar",
    "piquetareis": "piquetar",
    "piquetarem": "piquetar",
    "piquetaremos": "piquetar",
    "piquetares": "piquetar",
    "piquetaria": "piquetar",
    "piquetariam": "piquetar",
    "piquetarias": "piquetar",
    "piquetarmo": "piquetar",
    "piquetarmos": "piquetar",
    "piquetará": "piquetar",
    "piquetarás": "piquetar",
    "piquetarão": "piquetar",
    "piquetaríamos": "piquetar",
    "piquetaríeis": "piquetar",
    "piquetas": "piquetar",
    "piquetasse": "piquetar",
    "piquetassem": "piquetar",
    "piquetasses": "piquetar",
    "piquetaste": "piquetar",
    "piquetastes": "piquetar",
    "piquetava": "piquetar",
    "piquetavam": "piquetar",
    "piquetavas": "piquetar",
    "piquete": "piquetar",
    "piquetei": "piquetar",
    "piqueteis": "piquetar",
    "piquetem": "piquetar",
    "piquetemo": "piquetar",
    "piquetemos": "piquetar",
    "piquetes": "piquete",
    "piqueto": "piquetar",
    "piquetou": "piquetar",
    "piquetá": "piquetar",
    "piquetámo": "piquetar",
    "piquetámos": "piquetar",
    "piquetáramo": "piquetar",
    "piquetáramos": "piquetar",
    "piquetárei": "piquetar",
    "piquetáreis": "piquetar",
    "piquetásseis": "piquetar",
    "piquetássemos": "piquetar",
    "piquetávamo": "piquetar",
    "piquetávamos": "piquetar",
    "piquetávei": "piquetar",
    "piquetáveis": "piquetar",
    "piquinho": "pico",
    "piquinhos": "pico",
    "piquito": "pico",
    "piquitos": "pico",
    "piqués": "piqué",
    "pira": "pirar",
    "pirada": "pirar",
    "piradas": "pirar",
    "piradinha": "pirado",
    "piradinhas": "pirado",
    "piradinho": "pirado",
    "piradinhos": "pirado",
    "piradita": "pirado",
    "piraditas": "pirado",
    "piradito": "pirado",
    "piraditos": "pirado",
    "pirado": "pirar",
    "pirados": "pirar",
    "piradíssima": "pirado",
    "piradíssimas": "pirado",
    "piradíssimo": "pirado",
    "piradíssimos": "pirado",
    "pirai": "pirar",
    "pirais": "pirar",
    "pirajás": "pirajá",
    "piralídeos": "piralídeo",
    "piram": "pirar",
    "piramidais": "piramidal",
    "piramidonas": "piramidona",
    "piramidões": "piramidão",
    "piramo": "pirar",
    "piramos": "pirar",
    "pirando": "pirar",
    "piranga": "pirangar",
    "pirangada": "pirangar",
    "pirangadas": "pirangar",
    "pirangado": "pirangar",
    "pirangados": "pirangar",
    "pirangai": "pirangar",
    "pirangais": "pirangar",
    "pirangam": "pirangar",
    "pirangamo": "pirangar",
    "pirangamos": "pirangar",
    "pirangando": "pirangar",
    "pirangara": "pirangar",
    "pirangaram": "pirangar",
    "pirangaras": "pirangar",
    "pirangardes": "pirangar",
    "pirangarei": "pirangar",
    "pirangareis": "pirangar",
    "pirangarem": "pirangar",
    "pirangaremos": "pirangar",
    "pirangares": "pirangar",
    "pirangaria": "pirangar",
    "pirangariam": "pirangar",
    "pirangarias": "pirangaria",
    "pirangarmo": "pirangar",
    "pirangarmos": "pirangar",
    "pirangará": "pirangar",
    "pirangarás": "pirangar",
    "pirangarão": "pirangar",
    "pirangaríamos": "pirangar",
    "pirangaríeis": "pirangar",
    "pirangas": "pirangar",
    "pirangasse": "pirangar",
    "pirangassem": "pirangar",
    "pirangasses": "pirangar",
    "pirangaste": "pirangar",
    "pirangastes": "pirangar",
    "pirangava": "pirangar",
    "pirangavam": "pirangar",
    "pirangavas": "pirangar",
    "piranges": "pirange",
    "pirango": "pirangar",
    "pirangou": "pirangar",
    "pirangue": "pirangar",
    "piranguei": "pirangar",
    "pirangueira": "pirangueiro",
    "pirangueiras": "pirangueiro",
    "pirangueiros": "pirangueiro",
    "pirangueis": "pirangar",
    "piranguem": "pirangar",
    "piranguemo": "pirangar",
    "piranguemos": "pirangar",
    "pirangues": "pirangar",
    "piranguices": "piranguice",
    "pirangámo": "pirangar",
    "pirangámos": "pirangar",
    "pirangáramo": "pirangar",
    "pirangáramos": "pirangar",
    "pirangáreis": "pirangar",
    "pirangásseis": "pirangar",
    "pirangássemos": "pirangar",
    "pirangávamo": "pirangar",
    "pirangávamos": "pirangar",
    "pirangáveis": "pirangar",
    "piranhas": "piranha",
    "piranométrica": "piranométrico",
    "piranométricas": "piranométrico",
    "piranométricos": "piranométrico",
    "piranómetros": "piranómetro",
    "pirara": "pirar",
    "piraram": "pirar",
    "piraras": "pirar",
    "pirarde": "pirar",
    "pirardes": "pirar",
    "pirare": "pirar",
    "pirarei": "pirar",
    "pirareis": "pirar",
    "pirarem": "pirar",
    "piraremos": "pirar",
    "pirares": "pirar",
    "pirargirites": "pirargirite",
    "pirargirítica": "pirargirítico",
    "pirargiríticas": "pirargirítico",
    "pirargiríticos": "pirargirítico",
    "piraria": "pirar",
    "pirariam": "pirar",
    "pirarias": "pirar",
    "pirarmo": "pirar",
    "pirarmos": "pirar",
    "pirará": "pirar",
    "pirarás": "pirar",
    "pirarão": "pirar",
    "piraríamos": "pirar",
    "piraríeis": "pirar",
    "piras": "pirar",
    "pirasse": "pirar",
    "pirassem": "pirar",
    "pirasses": "pirar",
    "piraste": "pirar",
    "pirastes": "pirar",
    "piratagens": "piratagem",
    "piratarias": "pirataria",
    "piratas": "pirata",
    "piratazinha": "pirata",
    "piratazinhas": "pirata",
    "piratazinho": "pirata",
    "piratazinhos": "pirata",
    "piratazita": "pirata",
    "piratazitas": "pirata",
    "piratazito": "pirata",
    "piratazitos": "pirata",
    "pirateada": "piratear",
    "pirateadas": "piratear",
    "pirateado": "piratear",
    "pirateados": "piratear",
    "pirateai": "piratear",
    "pirateais": "piratear",
    "pirateamo": "piratear",
    "pirateamos": "piratear",
    "pirateando": "piratear",
    "pirateara": "piratear",
    "piratearam": "piratear",
    "piratearas": "piratear",
    "piratearde": "piratear",
    "pirateardes": "piratear",
    "pirateare": "piratear",
    "piratearei": "piratear",
    "pirateareis": "piratear",
    "piratearem": "piratear",
    "piratearemos": "piratear",
    "pirateares": "piratear",
    "piratearia": "piratear",
    "pirateariam": "piratear",
    "piratearias": "piratear",
    "piratearmo": "piratear",
    "piratearmos": "piratear",
    "pirateará": "piratear",
    "piratearás": "piratear",
    "piratearão": "piratear",
    "piratearíamos": "piratear",
    "piratearíeis": "piratear",
    "pirateasse": "piratear",
    "pirateassem": "piratear",
    "pirateasses": "piratear",
    "pirateaste": "piratear",
    "pirateastes": "piratear",
    "pirateava": "piratear",
    "pirateavam": "piratear",
    "pirateavas": "piratear",
    "pirateei": "piratear",
    "pirateeis": "piratear",
    "pirateemo": "piratear",
    "pirateemos": "piratear",
    "pirateia": "piratear",
    "pirateiam": "piratear",
    "pirateias": "piratear",
    "pirateie": "piratear",
    "pirateiem": "piratear",
    "pirateies": "piratear",
    "pirateio": "piratear",
    "pirateou": "piratear",
    "pirateá": "piratear",
    "pirateámo": "piratear",
    "pirateámos": "piratear",
    "pirateáramo": "piratear",
    "pirateáramos": "piratear",
    "pirateárei": "piratear",
    "pirateáreis": "piratear",
    "pirateásseis": "piratear",
    "pirateássemos": "piratear",
    "pirateávamo": "piratear",
    "pirateávamos": "piratear",
    "pirateávei": "piratear",
    "pirateáveis": "piratear",
    "piratinha": "pirata",
    "piratinhas": "pirata",
    "piratita": "pirata",
    "piratitas": "pirata",
    "pirava": "pirar",
    "piravam": "pirar",
    "piravas": "pirar",
    "piraís": "piraí",
    "pirbologias": "pirbologia",
    "pire": "pirar",
    "pirei": "pirar",
    "pireis": "pirar",
    "pirelectricidades": "pirelectricidade",
    "pireliométrica": "pireliométrico",
    "pireliométricas": "pireliométrico",
    "pireliométricos": "pireliométrico",
    "pirelióforos": "pirelióforo",
    "pireliómetros": "pireliómetro",
    "pireléctrica": "pireléctrico",
    "pireléctricas": "pireléctrico",
    "pireléctricos": "pireléctrico",
    "pirem": "pirar",
    "piremo": "pirar",
    "piremos": "pirar",
    "pirenaica": "pirenaico",
    "pirenaicas": "pirenaico",
    "pirenaicos": "pirenaico",
    "pireneia": "pireneu",
    "pireneias": "pireneu",
    "pireneus": "pireneu",
    "pireneítes": "pireneíte",
    "pireneítica": "pireneítico",
    "pireneíticas": "pireneítico",
    "pireneíticos": "pireneítico",
    "pirenos": "pireno",
    "pirenóides": "pirenóide",
    "pires": "pirar",
    "piretogenésica": "piretogenésico",
    "piretogenésicas": "piretogenésico",
    "piretogenésicos": "piretogenésico",
    "piretogenética": "piretogenético",
    "piretogenéticas": "piretogenético",
    "piretogenéticos": "piretogenético",
    "piretogénica": "piretogénico",
    "piretogénicas": "piretogénico",
    "piretogénicos": "piretogénico",
    "piretologias": "piretologia",
    "piretologistas": "piretologista",
    "piretológica": "piretológico",
    "piretológicas": "piretológico",
    "piretológicos": "piretológico",
    "piretros": "piretro",
    "pireus": "pireu",
    "pirexias": "pirexia",
    "pirezas": "pireza",
    "pirezinhos": "pirezinho",
    "pirezitos": "pirezito",
    "pirgeométrica": "pirgeométrico",
    "pirgeométricas": "pirgeométrico",
    "pirgeométricos": "pirgeométrico",
    "pirgeómetros": "pirgeómetro",
    "piridinas": "piridina",
    "piridixónica": "piridixónico",
    "piridixónicas": "piridixónico",
    "piridixónicos": "piridixónico",
    "piridoxinas": "piridoxina",
    "piridínica": "piridínico",
    "piridínicas": "piridínico",
    "piridínicos": "piridínico",
    "piriformes": "piriforme",
    "pirilampeja": "pirilampejar",
    "pirilampejada": "pirilampejar",
    "pirilampejadas": "pirilampejar",
    "pirilampejado": "pirilampejar",
    "pirilampejados": "pirilampejar",
    "pirilampejai": "pirilampejar",
    "pirilampejais": "pirilampejar",
    "pirilampejam": "pirilampejar",
    "pirilampejamo": "pirilampejar",
    "pirilampejamos": "pirilampejar",
    "pirilampejando": "pirilampejar",
    "pirilampejara": "pirilampejar",
    "pirilampejaram": "pirilampejar",
    "pirilampejaras": "pirilampejar",
    "pirilampejardes": "pirilampejar",
    "pirilampejarei": "pirilampejar",
    "pirilampejareis": "pirilampejar",
    "pirilampejarem": "pirilampejar",
    "pirilampejaremos": "pirilampejar",
    "pirilampejares": "pirilampejar",
    "pirilampejaria": "pirilampejar",
    "pirilampejariam": "pirilampejar",
    "pirilampejarias": "pirilampejar",
    "pirilampejarmo": "pirilampejar",
    "pirilampejarmos": "pirilampejar",
    "pirilampejará": "pirilampejar",
    "pirilampejarás": "pirilampejar",
    "pirilampejarão": "pirilampejar",
    "pirilampejaríamos": "pirilampejar",
    "pirilampejaríeis": "pirilampejar",
    "pirilampejas": "pirilampejar",
    "pirilampejasse": "pirilampejar",
    "pirilampejassem": "pirilampejar",
    "pirilampejasses": "pirilampejar",
    "pirilampejaste": "pirilampejar",
    "pirilampejastes": "pirilampejar",
    "pirilampejava": "pirilampejar",
    "pirilampejavam": "pirilampejar",
    "pirilampejavas": "pirilampejar",
    "pirilampeje": "pirilampejar",
    "pirilampejei": "pirilampejar",
    "pirilampejeis": "pirilampejar",
    "pirilampejem": "pirilampejar",
    "pirilampejemo": "pirilampejar",
    "pirilampejemos": "pirilampejar",
    "pirilampejes": "pirilampejar",
    "pirilampejo": "pirilampejar",
    "pirilampejou": "pirilampejar",
    "pirilampejámo": "pirilampejar",
    "pirilampejámos": "pirilampejar",
    "pirilampejáramo": "pirilampejar",
    "pirilampejáramos": "pirilampejar",
    "pirilampejáreis": "pirilampejar",
    "pirilampejásseis": "pirilampejar",
    "pirilampejássemos": "pirilampejar",
    "pirilampejávamo": "pirilampejar",
    "pirilampejávamos": "pirilampejar",
    "pirilampejáveis": "pirilampejar",
    "pirilampos": "pirilampo",
    "pirilâmpica": "pirilâmpico",
    "pirilâmpicas": "pirilâmpico",
    "pirilâmpicos": "pirilâmpico",
    "piripiris": "piripiri",
    "piriricas": "piririca",
    "piris": "piri",
    "pirites": "pirite",
    "piritiformes": "piritiforme",
    "piritosa": "piritoso",
    "piritosas": "piritoso",
    "piritosos": "piritoso",
    "piritífera": "piritífero",
    "piritíferas": "piritífero",
    "piritíferos": "piritífero",
    "piritóides": "piritóide",
    "pirizes": "piriz",
    "pirliteiros": "pirliteiro",
    "pirlitos": "pirlito",
    "piro": "pirar",
    "pirobalística": "pirobalístico",
    "pirobalísticas": "pirobalístico",
    "pirobalísticos": "pirobalístico",
    "pirobetumes": "pirobetume",
    "pirobetúmica": "pirobetúmico",
    "pirobetúmicas": "pirobetúmico",
    "pirobetúmicos": "pirobetúmico",
    "pirobologistas": "pirobologista",
    "pirobológica": "pirobológico",
    "pirobológicas": "pirobológico",
    "pirobológicos": "pirobológico",
    "pirocloros": "pirocloro",
    "piroclástica": "piroclástico",
    "piroclásticas": "piroclástico",
    "piroclásticos": "piroclástico",
    "piroclórica": "piroclórico",
    "piroclóricas": "piroclórico",
    "piroclóricos": "piroclórico",
    "piroelectricidades": "piroelectricidade",
    "piroeléctrica": "piroeléctrico",
    "piroeléctricas": "piroeléctrico",
    "piroeléctricos": "piroeléctrico",
    "pirofilites": "pirofilite",
    "pirofilítica": "pirofilítico",
    "pirofilíticas": "pirofilítico",
    "pirofilíticos": "pirofilítico",
    "pirofobias": "pirofobia",
    "pirofosfatos": "pirofosfato",
    "pirofosfática": "pirofosfático",
    "pirofosfáticas": "pirofosfático",
    "pirofosfáticos": "pirofosfático",
    "pirofosfórica": "pirofosfórico",
    "pirofosfóricas": "pirofosfórico",
    "pirofosfóricos": "pirofosfórico",
    "pirofóbica": "pirofóbico",
    "pirofóbicas": "pirofóbico",
    "pirofóbicos": "pirofóbico",
    "pirofórica": "pirofórico",
    "pirofóricas": "pirofórico",
    "pirofóricos": "pirofórico",
    "pirogalatos": "pirogalato",
    "pirogalhóis": "pirogalhol",
    "pirogalóis": "pirogalol",
    "pirogas": "piroga",
    "pirogenações": "pirogenação",
    "pirogenética": "pirogenético",
    "pirogenéticas": "pirogenético",
    "pirogenéticos": "pirogenético",
    "pirogeométrica": "pirogeométrico",
    "pirogeométricas": "pirogeométrico",
    "pirogeométricos": "pirogeométrico",
    "pirogeómetros": "pirogeómetro",
    "pirografias": "pirografia",
    "pirogranitos": "pirogranito",
    "pirograva": "pirogravar",
    "pirogravada": "pirogravar",
    "pirogravadas": "pirogravar",
    "pirogravado": "pirogravar",
    "pirogravadora": "pirogravador",
    "pirogravadoras": "pirogravador",
    "pirogravadores": "pirogravador",
    "pirogravados": "pirogravar",
    "pirogravai": "pirogravar",
    "pirogravais": "pirogravar",
    "pirogravam": "pirogravar",
    "pirogravamo": "pirogravar",
    "pirogravamos": "pirogravar",
    "pirogravando": "pirogravar",
    "pirogravara": "pirogravar",
    "pirogravaram": "pirogravar",
    "pirogravaras": "pirogravar",
    "pirogravarde": "pirogravar",
    "pirogravardes": "pirogravar",
    "pirogravare": "pirogravar",
    "pirogravarei": "pirogravar",
    "pirogravareis": "pirogravar",
    "pirogravarem": "pirogravar",
    "pirogravaremos": "pirogravar",
    "pirogravares": "pirogravar",
    "pirogravaria": "pirogravar",
    "pirogravariam": "pirogravar",
    "pirogravarias": "pirogravar",
    "pirogravarmo": "pirogravar",
    "pirogravarmos": "pirogravar",
    "pirogravará": "pirogravar",
    "pirogravarás": "pirogravar",
    "pirogravarão": "pirogravar",
    "pirogravaríamos": "pirogravar",
    "pirogravaríeis": "pirogravar",
    "pirogravas": "pirogravar",
    "pirogravasse": "pirogravar",
    "pirogravassem": "pirogravar",
    "pirogravasses": "pirogravar",
    "pirogravaste": "pirogravar",
    "pirogravastes": "pirogravar",
    "pirogravava": "pirogravar",
    "pirogravavam": "pirogravar",
    "pirogravavas": "pirogravar",
    "pirogravações": "pirogravação",
    "pirograve": "pirogravar",
    "pirogravei": "pirogravar",
    "pirograveis": "pirogravar",
    "pirogravem": "pirogravar",
    "pirogravemo": "pirogravar",
    "pirogravemos": "pirogravar",
    "pirograves": "pirogravar",
    "pirogravo": "pirogravar",
    "pirogravou": "pirogravar",
    "pirogravuras": "pirogravura",
    "pirogravá": "pirogravar",
    "pirogravámo": "pirogravar",
    "pirogravámos": "pirogravar",
    "pirograváramo": "pirogravar",
    "pirograváramos": "pirogravar",
    "pirogravárei": "pirogravar",
    "pirograváreis": "pirogravar",
    "pirogravásseis": "pirogravar",
    "pirogravássemos": "pirogravar",
    "pirogravávamo": "pirogravar",
    "pirogravávamos": "pirogravar",
    "pirogravávei": "pirogravar",
    "pirograváveis": "pirogravável",
    "pirográfica": "pirográfico",
    "pirográficas": "pirográfico",
    "pirográficos": "pirográfico",
    "pirogálhica": "pirogálhico",
    "pirogálhicas": "pirogálhico",
    "pirogálhicos": "pirogálhico",
    "pirogálica": "pirogálico",
    "pirogálicas": "pirogálico",
    "pirogálicos": "pirogálico",
    "pirogéneses": "pirogénese",
    "pirogénica": "pirogénico",
    "pirogénicas": "pirogénico",
    "pirogénicos": "pirogénico",
    "pirolatrias": "pirolatria",
    "pirolenhosa": "pirolenhoso",
    "pirolenhosas": "pirolenhoso",
    "pirolenhosos": "pirolenhoso",
    "pirolitos": "pirolito",
    "pirolizes": "piroliz",
    "pirolusites": "pirolusite",
    "pirolusítica": "pirolusítico",
    "pirolusíticas": "pirolusítico",
    "pirolusíticos": "pirolusítico",
    "pirolátrica": "pirolátrico",
    "pirolátricas": "pirolátrico",
    "pirolátricos": "pirolátrico",
    "pirolés": "pirolé",
    "piromancias": "piromancia",
    "piromanias": "piromania",
    "piromantes": "piromante",
    "piromaníaca": "piromaníaco",
    "piromaníacas": "piromaníaco",
    "piromaníacos": "piromaníaco",
    "pirometamorfismos": "pirometamorfismo",
    "pirometamórfica": "pirometamórfico",
    "pirometamórficas": "pirometamórfico",
    "pirometamórficos": "pirometamórfico",
    "pirometrias": "pirometria",
    "piromorfites": "piromorfite",
    "piromorfítica": "piromorfítico",
    "piromorfíticas": "piromorfítico",
    "piromorfíticos": "piromorfítico",
    "piromotores": "piromotor",
    "piromântica": "piromântico",
    "piromânticas": "piromântico",
    "piromânticos": "piromântico",
    "pirométrica": "pirométrico",
    "pirométricas": "pirométrico",
    "pirométricos": "pirométrico",
    "piropinas": "piropina",
    "piropincéis": "piropincel",
    "piroplasmoses": "piroplasmose",
    "piropneumática": "piropneumático",
    "piropneumáticas": "piropneumático",
    "piropneumáticos": "piropneumático",
    "piropos": "piropo",
    "piropínica": "piropínico",
    "piropínicas": "piropínico",
    "piropínicos": "piropínico",
    "piros": "piro",
    "pirosa": "piroso",
    "pirosas": "piroso",
    "piroscopias": "piroscopia",
    "piroscáfica": "piroscáfico",
    "piroscáficas": "piroscáfico",
    "piroscáficos": "piroscáfico",
    "piroscópica": "piroscópico",
    "piroscópicas": "piroscópico",
    "piroscópicos": "piroscópico",
    "piroscópios": "piroscópio",
    "piroses": "pirose",
    "pirosferas": "pirosfera",
    "pirosférica": "pirosférico",
    "pirosféricas": "pirosférico",
    "pirosféricos": "pirosférico",
    "pirosices": "pirosice",
    "pirosos": "piroso",
    "pirotecnias": "pirotecnia",
    "pirotecniza": "pirotecnizar",
    "pirotecnizada": "pirotecnizar",
    "pirotecnizadas": "pirotecnizar",
    "pirotecnizado": "pirotecnizar",
    "pirotecnizados": "pirotecnizar",
    "pirotecnizai": "pirotecnizar",
    "pirotecnizais": "pirotecnizar",
    "pirotecnizam": "pirotecnizar",
    "pirotecnizamo": "pirotecnizar",
    "pirotecnizamos": "pirotecnizar",
    "pirotecnizando": "pirotecnizar",
    "pirotecnizara": "pirotecnizar",
    "pirotecnizaram": "pirotecnizar",
    "pirotecnizaras": "pirotecnizar",
    "pirotecnizarde": "pirotecnizar",
    "pirotecnizardes": "pirotecnizar",
    "pirotecnizare": "pirotecnizar",
    "pirotecnizarei": "pirotecnizar",
    "pirotecnizareis": "pirotecnizar",
    "pirotecnizarem": "pirotecnizar",
    "pirotecnizaremos": "pirotecnizar",
    "pirotecnizares": "pirotecnizar",
    "pirotecnizaria": "pirotecnizar",
    "pirotecnizariam": "pirotecnizar",
    "pirotecnizarias": "pirotecnizar",
    "pirotecnizarmo": "pirotecnizar",
    "pirotecnizarmos": "pirotecnizar",
    "pirotecnizará": "pirotecnizar",
    "pirotecnizarás": "pirotecnizar",
    "pirotecnizarão": "pirotecnizar",
    "pirotecnizaríamos": "pirotecnizar",
    "pirotecnizaríeis": "pirotecnizar",
    "pirotecnizas": "pirotecnizar",
    "pirotecnizasse": "pirotecnizar",
    "pirotecnizassem": "pirotecnizar",
    "pirotecnizasses": "pirotecnizar",
    "pirotecnizaste": "pirotecnizar",
    "pirotecnizastes": "pirotecnizar",
    "pirotecnizava": "pirotecnizar",
    "pirotecnizavam": "pirotecnizar",
    "pirotecnizavas": "pirotecnizar",
    "pirotecnize": "pirotecnizar",
    "pirotecnizei": "pirotecnizar",
    "pirotecnizeis": "pirotecnizar",
    "pirotecnizem": "pirotecnizar",
    "pirotecnizemo": "pirotecnizar",
    "pirotecnizemos": "pirotecnizar",
    "pirotecnizes": "pirotecnizar",
    "pirotecnizo": "pirotecnizar",
    "pirotecnizou": "pirotecnizar",
    "pirotecnizá": "pirotecnizar",
    "pirotecnizámo": "pirotecnizar",
    "pirotecnizámos": "pirotecnizar",
    "pirotecnizáramo": "pirotecnizar",
    "pirotecnizáramos": "pirotecnizar",
    "pirotecnizárei": "pirotecnizar",
    "pirotecnizáreis": "pirotecnizar",
    "pirotecnizásseis": "pirotecnizar",
    "pirotecnizássemos": "pirotecnizar",
    "pirotecnizávamo": "pirotecnizar",
    "pirotecnizávamos": "pirotecnizar",
    "pirotecnizávei": "pirotecnizar",
    "pirotecnizáveis": "pirotecnizável",
    "pirotécnica": "pirotécnico",
    "pirotécnicas": "pirotécnico",
    "pirotécnicos": "pirotécnico",
    "pirou": "pirar",
    "piroxenas": "piroxena",
    "piroxilas": "piroxila",
    "piroxilinas": "piroxilina",
    "piroxilínica": "piroxilínico",
    "piroxilínicas": "piroxilínico",
    "piroxilínicos": "piroxilínico",
    "piroxénica": "piroxénico",
    "piroxénicas": "piroxénico",
    "piroxénicos": "piroxénico",
    "piroxílica": "piroxílico",
    "piroxílicas": "piroxílico",
    "piroxílicos": "piroxílico",
    "pirozones": "pirozone",
    "pirozónica": "pirozónico",
    "pirozónicas": "pirozónico",
    "pirozónicos": "pirozónico",
    "pirozónios": "pirozónio",
    "pirrace": "pirraçar",
    "pirracei": "pirraçar",
    "pirraceira": "pirraceiro",
    "pirraceiras": "pirraceiro",
    "pirraceiros": "pirraceiro",
    "pirraceis": "pirraçar",
    "pirracem": "pirraçar",
    "pirracemo": "pirraçar",
    "pirracemos": "pirraçar",
    "pirraces": "pirraçar",
    "pirralha": "pirralho",
    "pirralhas": "pirralho",
    "pirralhos": "pirralho",
    "pirraça": "pirraçar",
    "pirraçada": "pirraçar",
    "pirraçadas": "pirraçar",
    "pirraçado": "pirraçar",
    "pirraçados": "pirraçar",
    "pirraçai": "pirraçar",
    "pirraçais": "pirraçar",
    "pirraçam": "pirraçar",
    "pirraçamo": "pirraçar",
    "pirraçamos": "pirraçar",
    "pirraçando": "pirraçar",
    "pirraçara": "pirraçar",
    "pirraçaram": "pirraçar",
    "pirraçaras": "pirraçar",
    "pirraçarde": "pirraçar",
    "pirraçardes": "pirraçar",
    "pirraçare": "pirraçar",
    "pirraçarei": "pirraçar",
    "pirraçareis": "pirraçar",
    "pirraçarem": "pirraçar",
    "pirraçaremos": "pirraçar",
    "pirraçares": "pirraçar",
    "pirraçaria": "pirraçar",
    "pirraçariam": "pirraçar",
    "pirraçarias": "pirraçar",
    "pirraçarmo": "pirraçar",
    "pirraçarmos": "pirraçar",
    "pirraçará": "pirraçar",
    "pirraçarás": "pirraçar",
    "pirraçarão": "pirraçar",
    "pirraçaríamos": "pirraçar",
    "pirraçaríeis": "pirraçar",
    "pirraças": "pirraçar",
    "pirraçasse": "pirraçar",
    "pirraçassem": "pirraçar",
    "pirraçasses": "pirraçar",
    "pirraçaste": "pirraçar",
    "pirraçastes": "pirraçar",
    "pirraçava": "pirraçar",
    "pirraçavam": "pirraçar",
    "pirraçavas": "pirraçar",
    "pirraço": "pirraçar",
    "pirraçou": "pirraçar",
    "pirraçá": "pirraçar",
    "pirraçámo": "pirraçar",
    "pirraçámos": "pirraçar",
    "pirraçáramo": "pirraçar",
    "pirraçáramos": "pirraçar",
    "pirraçárei": "pirraçar",
    "pirraçáreis": "pirraçar",
    "pirraçásseis": "pirraçar",
    "pirraçássemos": "pirraçar",
    "pirraçávamo": "pirraçar",
    "pirraçávamos": "pirraçar",
    "pirraçávei": "pirraçar",
    "pirraçáveis": "pirraçar",
    "pirronices": "pirronice",
    "pirronismos": "pirronismo",
    "pirronistas": "pirronista",
    "pirrotinas": "pirrotina",
    "pirrotites": "pirrotite",
    "pirrotínica": "pirrotínico",
    "pirrotínicas": "pirrotínico",
    "pirrotínicos": "pirrotínico",
    "pirrotítica": "pirrotítico",
    "pirrotíticas": "pirrotítico",
    "pirrotíticos": "pirrotítico",
    "pirríquia": "pirríquio",
    "pirríquias": "pirríquio",
    "pirríquios": "pirríquio",
    "pirrónica": "pirrónico",
    "pirrónicas": "pirrónico",
    "pirrónicos": "pirrónico",
    "pirueta": "piruetar",
    "piruetada": "piruetar",
    "piruetadas": "piruetar",
    "piruetado": "piruetar",
    "piruetados": "piruetar",
    "piruetai": "piruetar",
    "piruetais": "piruetar",
    "piruetam": "piruetar",
    "piruetamo": "piruetar",
    "piruetamos": "piruetar",
    "piruetando": "piruetar",
    "piruetara": "piruetar",
    "piruetaram": "piruetar",
    "piruetaras": "piruetar",
    "piruetardes": "piruetar",
    "piruetarei": "piruetar",
    "piruetareis": "piruetar",
    "piruetarem": "piruetar",
    "piruetaremos": "piruetar",
    "piruetares": "piruetar",
    "piruetaria": "piruetar",
    "piruetariam": "piruetar",
    "piruetarias": "piruetar",
    "piruetarmo": "piruetar",
    "piruetarmos": "piruetar",
    "piruetará": "piruetar",
    "piruetarás": "piruetar",
    "piruetarão": "piruetar",
    "piruetaríamos": "piruetar",
    "piruetaríeis": "piruetar",
    "piruetas": "piruetar",
    "piruetasse": "piruetar",
    "piruetassem": "piruetar",
    "piruetasses": "piruetar",
    "piruetaste": "piruetar",
    "piruetastes": "piruetar",
    "piruetava": "piruetar",
    "piruetavam": "piruetar",
    "piruetavas": "piruetar",
    "piruete": "piruetar",
    "piruetei": "piruetar",
    "pirueteis": "piruetar",
    "piruetem": "piruetar",
    "piruetemo": "piruetar",
    "piruetemos": "piruetar",
    "piruetes": "piruetar",
    "pirueto": "piruetar",
    "piruetou": "piruetar",
    "piruetámo": "piruetar",
    "piruetámos": "piruetar",
    "piruetáramo": "piruetar",
    "piruetáramos": "piruetar",
    "piruetáreis": "piruetar",
    "piruetásseis": "piruetar",
    "piruetássemos": "piruetar",
    "piruetávamo": "piruetar",
    "piruetávamos": "piruetar",
    "piruetáveis": "piruetar",
    "pirá": "pirar",
    "pirálidas": "pirálida",
    "pirálides": "pirálide",
    "pirámo": "pirar",
    "pirámos": "pirar",
    "piráramo": "pirar",
    "piráramos": "pirar",
    "pirárei": "pirar",
    "piráreis": "pirar",
    "pirásseis": "pirar",
    "pirássemos": "pirar",
    "pirática": "pirático",
    "piráticas": "pirático",
    "piráticos": "pirático",
    "pirávamo": "pirar",
    "pirávamos": "pirar",
    "pirávei": "pirar",
    "piráveis": "pirar",
    "pirâmides": "pirâmide",
    "pirénica": "pirénico",
    "pirénicas": "pirénico",
    "pirénicos": "pirénico",
    "pirética": "pirético",
    "piréticas": "pirético",
    "piréticos": "pirético",
    "piréxica": "piréxico",
    "piréxicas": "piréxico",
    "piréxicos": "piréxico",
    "pirítica": "pirítico",
    "piríticas": "pirítico",
    "piríticos": "pirítico",
    "pirófoba": "pirófobo",
    "pirófobas": "pirófobo",
    "pirófobos": "pirófobo",
    "piróforos": "piróforo",
    "pirógrafos": "pirógrafo",
    "pirólatras": "pirólatra",
    "pirólises": "pirólise",
    "pirómaca": "pirómaco",
    "pirómacas": "pirómaco",
    "pirómacos": "pirómaco",
    "pirómana": "pirómano",
    "pirómanas": "pirómano",
    "pirómanos": "pirómano",
    "pirómetros": "pirómetro",
    "piróscafos": "piróscafo",
    "pirótica": "pirótico",
    "piróticas": "pirótico",
    "piróticos": "pirótico",
    "piróxilos": "piróxilo",
    "pirões": "pirão",
    "pis": "pi",
    "pisa": "pisar",
    "pisada": "pisar",
    "pisadas": "pisar",
    "pisadelas": "pisadela",
    "pisado": "pisar",
    "pisadora": "pisador",
    "pisadoras": "pisador",
    "pisadores": "pisador",
    "pisados": "pisar",
    "pisaduras": "pisadura",
    "pisai": "pisar",
    "pisais": "pisar",
    "pisam": "pisar",
    "pisamentos": "pisamento",
    "pisamo": "pisar",
    "pisamos": "pisar",
    "pisando": "pisar",
    "pisara": "pisar",
    "pisaram": "pisar",
    "pisaras": "pisar",
    "pisarde": "pisar",
    "pisardes": "pisar",
    "pisare": "pisar",
    "pisarei": "pisar",
    "pisareis": "pisar",
    "pisarem": "pisar",
    "pisaremos": "pisar",
    "pisares": "pisar",
    "pisaria": "pisar",
    "pisariam": "pisar",
    "pisarias": "pisar",
    "pisarmo": "pisar",
    "pisarmos": "pisar",
    "pisará": "pisar",
    "pisarás": "pisar",
    "pisarão": "pisar",
    "pisaríamos": "pisar",
    "pisaríeis": "pisar",
    "pisas": "pisar",
    "pisasse": "pisar",
    "pisassem": "pisar",
    "pisasses": "pisar",
    "pisaste": "pisar",
    "pisastes": "pisar",
    "pisava": "pisar",
    "pisavam": "pisar",
    "pisavas": "pisar",
    "pisca": "pisco",
    "piscada": "piscar",
    "piscadas": "piscar",
    "piscadelas": "piscadela",
    "piscado": "piscar",
    "piscados": "piscar",
    "piscai": "piscar",
    "piscais": "piscar",
    "piscam": "piscar",
    "piscamo": "piscar",
    "piscamos": "piscar",
    "piscando": "piscar",
    "piscara": "piscar",
    "piscaram": "piscar",
    "piscaras": "piscar",
    "piscarde": "piscar",
    "piscardes": "piscar",
    "piscare": "piscar",
    "piscarei": "piscar",
    "piscareis": "piscar",
    "piscarem": "piscar",
    "piscaremos": "piscar",
    "piscares": "piscar",
    "piscaria": "piscar",
    "piscariam": "piscar",
    "piscarias": "piscar",
    "piscarmo": "piscar",
    "piscarmos": "piscar",
    "piscará": "piscar",
    "piscarás": "piscar",
    "piscarão": "piscar",
    "piscaríamos": "piscar",
    "piscaríeis": "piscar",
    "piscas": "pisco",
    "piscasse": "piscar",
    "piscassem": "piscar",
    "piscasses": "piscar",
    "piscaste": "piscar",
    "piscastes": "piscar",
    "piscatória": "piscatório",
    "piscatórias": "piscatório",
    "piscatórios": "piscatório",
    "piscava": "piscar",
    "piscavam": "piscar",
    "piscavas": "piscar",
    "piscicultora": "piscicultor",
    "piscicultoras": "piscicultor",
    "piscicultores": "piscicultor",
    "pisciculturas": "piscicultura",
    "pisciformes": "pisciforme",
    "piscinais": "piscinal",
    "piscinas": "piscina",
    "pisco": "piscar",
    "piscos": "pisco",
    "piscosa": "piscoso",
    "piscosas": "piscoso",
    "piscosos": "piscoso",
    "piscou": "piscar",
    "piscá": "piscar",
    "piscámo": "piscar",
    "piscámos": "piscar",
    "piscáramo": "piscar",
    "piscáramos": "piscar",
    "piscárei": "piscar",
    "piscáreis": "piscar",
    "piscásseis": "piscar",
    "piscássemos": "piscar",
    "piscávamo": "piscar",
    "piscávamos": "piscar",
    "piscávei": "piscar",
    "piscáveis": "piscar",
    "piscícolas": "piscícola",
    "piscículos": "piscículo",
    "piscívora": "piscívoro",
    "piscívoras": "piscívoro",
    "piscívoros": "piscívoro",
    "pise": "pisar",
    "pisei": "pisar",
    "piseis": "pisar",
    "pisem": "pisar",
    "pisemo": "pisar",
    "pisemos": "pisar",
    "pises": "pisar",
    "pisga": "pisgar",
    "pisgada": "pisgar",
    "pisgadas": "pisgar",
    "pisgado": "pisgar",
    "pisgados": "pisgar",
    "pisgai": "pisgar",
    "pisgais": "pisgar",
    "pisgam": "pisgar",
    "pisgamo": "pisgar",
    "pisgamos": "pisgar",
    "pisgando": "pisgar",
    "pisgara": "pisgar",
    "pisgaram": "pisgar",
    "pisgaras": "pisgar",
    "pisgarde": "pisgar",
    "pisgardes": "pisgar",
    "pisgare": "pisgar",
    "pisgarei": "pisgar",
    "pisgareis": "pisgar",
    "pisgarem": "pisgar",
    "pisgaremos": "pisgar",
    "pisgares": "pisgar",
    "pisgaria": "pisgar",
    "pisgariam": "pisgar",
    "pisgarias": "pisgar",
    "pisgarmo": "pisgar",
    "pisgarmos": "pisgar",
    "pisgará": "pisgar",
    "pisgarás": "pisgar",
    "pisgarão": "pisgar",
    "pisgaríamos": "pisgar",
    "pisgaríeis": "pisgar",
    "pisgas": "pisgar",
    "pisgasse": "pisgar",
    "pisgassem": "pisgar",
    "pisgasses": "pisgar",
    "pisgaste": "pisgar",
    "pisgastes": "pisgar",
    "pisgava": "pisgar",
    "pisgavam": "pisgar",
    "pisgavas": "pisgar",
    "pisgo": "pisgar",
    "pisgou": "pisgar",
    "pisgue": "pisgar",
    "pisguei": "pisgar",
    "pisgueis": "pisgar",
    "pisguem": "pisgar",
    "pisguemo": "pisgar",
    "pisguemos": "pisgar",
    "pisgues": "pisgar",
    "pisgá": "pisgar",
    "pisgámo": "pisgar",
    "pisgámos": "pisgar",
    "pisgáramo": "pisgar",
    "pisgáramos": "pisgar",
    "pisgárei": "pisgar",
    "pisgáreis": "pisgar",
    "pisgásseis": "pisgar",
    "pisgássemos": "pisgar",
    "pisgávamo": "pisgar",
    "pisgávamos": "pisgar",
    "pisgávei": "pisgar",
    "pisgáveis": "pisgar",
    "pisiformes": "pisiforme",
    "piso": "pisar",
    "pisoa": "pisoar",
    "pisoada": "pisoar",
    "pisoadas": "pisoar",
    "pisoado": "pisoar",
    "pisoadora": "pisoador",
    "pisoadoras": "pisoador",
    "pisoadores": "pisoador",
    "pisoados": "pisoar",
    "pisoagens": "pisoagem",
    "pisoai": "pisoar",
    "pisoais": "pisoar",
    "pisoam": "pisoar",
    "pisoamentos": "pisoamento",
    "pisoamo": "pisoar",
    "pisoamos": "pisoar",
    "pisoando": "pisoar",
    "pisoara": "pisoar",
    "pisoaram": "pisoar",
    "pisoaras": "pisoar",
    "pisoardes": "pisoar",
    "pisoarei": "pisoar",
    "pisoareis": "pisoar",
    "pisoarem": "pisoar",
    "pisoaremos": "pisoar",
    "pisoares": "pisoar",
    "pisoaria": "pisoar",
    "pisoariam": "pisoar",
    "pisoarias": "pisoar",
    "pisoarmo": "pisoar",
    "pisoarmos": "pisoar",
    "pisoará": "pisoar",
    "pisoarás": "pisoar",
    "pisoarão": "pisoar",
    "pisoaríamos": "pisoar",
    "pisoaríeis": "pisoar",
    "pisoas": "pisoar",
    "pisoasse": "pisoar",
    "pisoassem": "pisoar",
    "pisoasses": "pisoar",
    "pisoaste": "pisoar",
    "pisoastes": "pisoar",
    "pisoava": "pisoar",
    "pisoavam": "pisoar",
    "pisoavas": "pisoar",
    "pisoe": "pisoar",
    "pisoei": "pisoar",
    "pisoeira": "pisoeiro",
    "pisoeiras": "pisoeiro",
    "pisoeiros": "pisoeiro",
    "pisoeis": "pisoar",
    "pisoem": "pisoar",
    "pisoemo": "pisoar",
    "pisoemos": "pisoar",
    "pisoes": "pisoar",
    "pisolítica": "pisolítico",
    "pisolíticas": "pisolítico",
    "pisolíticos": "pisolítico",
    "pisoo": "pisoar",
    "pisoou": "pisoar",
    "pisos": "piso",
    "pisoteada": "pisoteado",
    "pisoteadas": "pisoteado",
    "pisoteados": "pisoteado",
    "pisou": "pisar",
    "pisoámo": "pisoar",
    "pisoámos": "pisoar",
    "pisoáramo": "pisoar",
    "pisoáramos": "pisoar",
    "pisoáreis": "pisoar",
    "pisoásseis": "pisoar",
    "pisoássemos": "pisoar",
    "pisoávamo": "pisoar",
    "pisoávamos": "pisoar",
    "pisoáveis": "pisoar",
    "pispirretas": "pispirreta",
    "pisque": "piscar",
    "pisquei": "piscar",
    "pisqueira": "pisqueiro",
    "pisqueiras": "pisqueiro",
    "pisqueiros": "pisqueiro",
    "pisqueis": "piscar",
    "pisquem": "piscar",
    "pisquemo": "piscar",
    "pisquemos": "piscar",
    "pisques": "piscar",
    "pisseleus": "pisseleu",
    "pissita": "pissitar",
    "pissitada": "pissitar",
    "pissitadas": "pissitar",
    "pissitado": "pissitar",
    "pissitados": "pissitar",
    "pissitai": "pissitar",
    "pissitais": "pissitar",
    "pissitam": "pissitar",
    "pissitamo": "pissitar",
    "pissitamos": "pissitar",
    "pissitando": "pissitar",
    "pissitara": "pissitar",
    "pissitaram": "pissitar",
    "pissitaras": "pissitar",
    "pissitardes": "pissitar",
    "pissitarei": "pissitar",
    "pissitareis": "pissitar",
    "pissitarem": "pissitar",
    "pissitaremos": "pissitar",
    "pissitares": "pissitar",
    "pissitaria": "pissitar",
    "pissitariam": "pissitar",
    "pissitarias": "pissitar",
    "pissitarmo": "pissitar",
    "pissitarmos": "pissitar",
    "pissitará": "pissitar",
    "pissitarás": "pissitar",
    "pissitarão": "pissitar",
    "pissitaríamos": "pissitar",
    "pissitaríeis": "pissitar",
    "pissitas": "pissitar",
    "pissitasse": "pissitar",
    "pissitassem": "pissitar",
    "pissitasses": "pissitar",
    "pissitaste": "pissitar",
    "pissitastes": "pissitar",
    "pissitava": "pissitar",
    "pissitavam": "pissitar",
    "pissitavas": "pissitar",
    "pissite": "pissitar",
    "pissitei": "pissitar",
    "pissiteis": "pissitar",
    "pissitem": "pissitar",
    "pissitemo": "pissitar",
    "pissitemos": "pissitar",
    "pissites": "pissitar",
    "pissito": "pissitar",
    "pissitou": "pissitar",
    "pissitámo": "pissitar",
    "pissitámos": "pissitar",
    "pissitáramo": "pissitar",
    "pissitáramos": "pissitar",
    "pissitáreis": "pissitar",
    "pissitásseis": "pissitar",
    "pissitássemos": "pissitar",
    "pissitávamo": "pissitar",
    "pissitávamos": "pissitar",
    "pissitáveis": "pissitar",
    "pista": "pistar",
    "pistacites": "pistacite",
    "pistacética": "pistacético",
    "pistacéticas": "pistacético",
    "pistacéticos": "pistacético",
    "pistada": "pistar",
    "pistadas": "pistar",
    "pistado": "pistar",
    "pistados": "pistar",
    "pistai": "pistar",
    "pistais": "pistar",
    "pistam": "pistar",
    "pistamo": "pistar",
    "pistamos": "pistar",
    "pistando": "pistar",
    "pistara": "pistar",
    "pistaram": "pistar",
    "pistaras": "pistar",
    "pistardes": "pistar",
    "pistarei": "pistar",
    "pistareis": "pistar",
    "pistarem": "pistar",
    "pistaremos": "pistar",
    "pistares": "pistar",
    "pistaria": "pistar",
    "pistariam": "pistar",
    "pistarias": "pistar",
    "pistarmo": "pistar",
    "pistarmos": "pistar",
    "pistará": "pistar",
    "pistarás": "pistar",
    "pistarão": "pistar",
    "pistaríamos": "pistar",
    "pistaríeis": "pistar",
    "pistas": "pistar",
    "pistasse": "pistar",
    "pistassem": "pistar",
    "pistasses": "pistar",
    "pistaste": "pistar",
    "pistastes": "pistar",
    "pistava": "pistar",
    "pistavam": "pistar",
    "pistavas": "pistar",
    "piste": "pistar",
    "pistei": "pistar",
    "pisteis": "pistar",
    "pistem": "pistar",
    "pistemo": "pistar",
    "pistemos": "pistar",
    "pistes": "pistar",
    "pistilares": "pistilar",
    "pistilos": "pistilo",
    "pistilosa": "pistiloso",
    "pistilosas": "pistiloso",
    "pistilosos": "pistiloso",
    "pistilácea": "pistiláceo",
    "pistiláceas": "pistiláceo",
    "pistiláceos": "pistiláceo",
    "pisto": "pistar",
    "pistoladas": "pistolada",
    "pistolas": "pistola",
    "pistoleira": "pistoleiro",
    "pistoleiras": "pistoleiro",
    "pistoleiros": "pistoleiro",
    "pistoletas": "pistoleta",
    "pistoletes": "pistolete",
    "pistolinha": "pistola",
    "pistolinhas": "pistola",
    "pistolita": "pistola",
    "pistolitas": "pistola",
    "pistolóquias": "pistolóquia",
    "pistolões": "pistolão",
    "pistora": "pistor",
    "pistoras": "pistor",
    "pistores": "pistor",
    "pistou": "pistar",
    "pistrinas": "pistrina",
    "pistáchios": "pistáchio",
    "pistácias": "pistácia",
    "pistácios": "pistácio",
    "pistámo": "pistar",
    "pistámos": "pistar",
    "pistáramo": "pistar",
    "pistáramos": "pistar",
    "pistáreis": "pistar",
    "pistásseis": "pistar",
    "pistássemos": "pistar",
    "pistávamo": "pistar",
    "pistávamos": "pistar",
    "pistáveis": "pistar",
    "pistões": "pistão",
    "pisá": "pisar",
    "pisámo": "pisar",
    "pisámos": "pisar",
    "pisáramo": "pisar",
    "pisáramos": "pisar",
    "pisárei": "pisar",
    "pisáreis": "pisar",
    "pisásseis": "pisar",
    "pisássemos": "pisar",
    "pisávamo": "pisar",
    "pisávamos": "pisar",
    "pisávei": "pisar",
    "pisáveis": "pisar",
    "pisólitos": "pisólito",
    "pisões": "pisão",
    "pita": "pito",
    "pitada": "pitar",
    "pitadas": "pitar",
    "pitadinha": "pitada",
    "pitadinhas": "pitada",
    "pitadita": "pitada",
    "pitaditas": "pitada",
    "pitado": "pitar",
    "pitados": "pitar",
    "pitagorismos": "pitagorismo",
    "pitagoristas": "pitagorista",
    "pitagórica": "pitagórico",
    "pitagóricas": "pitagórico",
    "pitagóricos": "pitagórico",
    "pitai": "pitar",
    "pitais": "pitar",
    "pitam": "pitar",
    "pitamo": "pitar",
    "pitamos": "pitar",
    "pitanceiros": "pitanceiro",
    "pitando": "pitar",
    "pitangas": "pitanga",
    "pitangueiras": "pitangueira",
    "pitanças": "pitança",
    "pitara": "pitar",
    "pitaram": "pitar",
    "pitaras": "pitar",
    "pitarde": "pitar",
    "pitardes": "pitar",
    "pitare": "pitar",
    "pitarei": "pitar",
    "pitareis": "pitar",
    "pitarem": "pitar",
    "pitaremos": "pitar",
    "pitares": "pitar",
    "pitaria": "pitar",
    "pitariam": "pitar",
    "pitarias": "pitar",
    "pitarmo": "pitar",
    "pitarmos": "pitar",
    "pitará": "pitar",
    "pitarás": "pitar",
    "pitarão": "pitar",
    "pitaríamos": "pitar",
    "pitaríeis": "pitar",
    "pitas": "pito",
    "pitasse": "pitar",
    "pitassem": "pitar",
    "pitasses": "pitar",
    "pitaste": "pitar",
    "pitastes": "pitar",
    "pitava": "pitar",
    "pitavam": "pitar",
    "pitavas": "pitar",
    "pite": "pitar",
    "pitecantropos": "pitecantropo",
    "pitecantropídea": "pitecantropídeo",
    "pitecantropídeas": "pitecantropídeo",
    "pitecantropídeos": "pitecantropídeo",
    "pitecantrópica": "pitecantrópico",
    "pitecantrópicas": "pitecantrópico",
    "pitecantrópicos": "pitecantrópico",
    "pitecos": "piteco",
    "pitecóides": "pitecóide",
    "pitei": "pitar",
    "piteiras": "piteira",
    "piteireira": "piteireiro",
    "piteireiras": "piteireiro",
    "piteireiros": "piteireiro",
    "piteirices": "piteirice",
    "piteis": "pitar",
    "pitem": "pitar",
    "pitemo": "pitar",
    "pitemos": "pitar",
    "pites": "pitar",
    "pitiática": "pitiático",
    "pitiáticas": "pitiático",
    "pitiáticos": "pitiático",
    "pito": "pitar",
    "pitonisas": "pitonisa",
    "pitonissas": "pitonissa",
    "pitonísica": "pitonísico",
    "pitonísicas": "pitonísico",
    "pitonísicos": "pitonísico",
    "pitoras": "pitora",
    "pitoresca": "pitoresco",
    "pitorescas": "pitoresco",
    "pitorescos": "pitoresco",
    "pitorras": "pitorra",
    "pitos": "pito",
    "pitoscas": "pitosca",
    "pitosgas": "pitosga",
    "pitosporáceas": "pitosporácea",
    "pitou": "pitar",
    "pituitosa": "pituitoso",
    "pituitosas": "pituitoso",
    "pituitosos": "pituitoso",
    "pituitária": "pituitário",
    "pituitárias": "pituitário",
    "pituitários": "pituitário",
    "pituítas": "pituíta",
    "pitá": "pitar",
    "pitámo": "pitar",
    "pitámos": "pitar",
    "pitáramo": "pitar",
    "pitáramos": "pitar",
    "pitárei": "pitar",
    "pitáreis": "pitar",
    "pitásseis": "pitar",
    "pitássemos": "pitar",
    "pitávamo": "pitar",
    "pitávamos": "pitar",
    "pitávei": "pitar",
    "pitáveis": "pitar",
    "pitéus": "pitéu",
    "pitónica": "pitónico",
    "pitónicas": "pitónico",
    "pitónicos": "pitónico",
    "pitósporos": "pitósporo",
    "pitões": "pitão",
    "piuns": "pium",
    "piveradas": "piverada",
    "piveteiros": "piveteiro",
    "pivetes": "pivete",
    "pivots": "pivot",
    "pivôs": "pivô",
    "pixas": "pixa",
    "pixídios": "pixídio",
    "pizarias": "pizaria",
    "pizas": "piza",
    "pizzarias": "pizzaria",
    "pizzas": "pizza",
    "piámo": "piar",
    "piámos": "piar",
    "piáramo": "piar",
    "piáramos": "piar",
    "piáreis": "piar",
    "piásseis": "piar",
    "piássemos": "piar",
    "piávamo": "piar",
    "piávamos": "piar",
    "piáveis": "piar",
    "piãozinho": "pião",
    "piãozito": "pião",
    "piçarrais": "piçarral",
    "piçarras": "piçarra",
    "piçarrosa": "piçarroso",
    "piçarrosas": "piçarroso",
    "piçarrosos": "piçarroso",
    "piçorelhos": "piçorelho",
    "piéria": "piério",
    "piérias": "piério",
    "piérios": "piério",
    "piíssima": "pio",
    "piíssimas": "pio",
    "piíssimo": "pio",
    "piíssimos": "pio",
    "piões": "pião",
    "piõezinhos": "pião",
    "piõezitos": "pião",
    "placa": "placar",
    "placabilidades": "placabilidade",
    "placada": "placar",
    "placadas": "placar",
    "placado": "placar",
    "placados": "placar",
    "placagens": "placagem",
    "placai": "placar",
    "placais": "placar",
    "placam": "placar",
    "placamo": "placar",
    "placamos": "placar",
    "placando": "placar",
    "placara": "placar",
    "placaram": "placar",
    "placaras": "placar",
    "placarde": "placar",
    "placardes": "placar",
    "placards": "placard",
    "placare": "placar",
    "placarei": "placar",
    "placareis": "placar",
    "placarem": "placar",
    "placaremos": "placar",
    "placares": "placar",
    "placaria": "placar",
    "placariam": "placar",
    "placarias": "placar",
    "placarmo": "placar",
    "placarmos": "placar",
    "placará": "placar",
    "placarás": "placar",
    "placarão": "placar",
    "placaríamos": "placar",
    "placaríeis": "placar",
    "placas": "placar",
    "placasse": "placar",
    "placassem": "placar",
    "placasses": "placar",
    "placaste": "placar",
    "placastes": "placar",
    "placava": "placar",
    "placavam": "placar",
    "placavas": "placar",
    "placazinha": "placa",
    "placazinhas": "placa",
    "placazita": "placa",
    "placazitas": "placa",
    "placebos": "placebo",
    "placencianos": "placenciano",
    "placentas": "placenta",
    "placentações": "placentação",
    "placentina": "placentino",
    "placentinas": "placentino",
    "placentinos": "placentino",
    "placentites": "placentite",
    "placentária": "placentário",
    "placentárias": "placentário",
    "placentários": "placentário",
    "placentítica": "placentítico",
    "placentíticas": "placentítico",
    "placentíticos": "placentítico",
    "placidezes": "placidez",
    "placitudes": "placitude",
    "placo": "placar",
    "placodermes": "placoderme",
    "placodontes": "placodonte",
    "placou": "placar",
    "placá": "placar",
    "placámo": "placar",
    "placámos": "placar",
    "placáramo": "placar",
    "placáramos": "placar",
    "placárei": "placar",
    "placáreis": "placar",
    "placásseis": "placar",
    "placássemos": "placar",
    "placávamo": "placar",
    "placávamos": "placar",
    "placávei": "placar",
    "placáveis": "placável",
    "plafonamentos": "plafonamento",
    "plafonds": "plafond",
    "plagas": "plaga",
    "plagia": "plagiar",
    "plagiada": "plagiar",
    "plagiadas": "plagiar",
    "plagiado": "plagiar",
    "plagiadora": "plagiador",
    "plagiadoras": "plagiador",
    "plagiadores": "plagiador",
    "plagiados": "plagiar",
    "plagiai": "plagiar",
    "plagiais": "plagiar",
    "plagiam": "plagiar",
    "plagiamo": "plagiar",
    "plagiamos": "plagiar",
    "plagiando": "plagiar",
    "plagiara": "plagiar",
    "plagiaram": "plagiar",
    "plagiaras": "plagiar",
    "plagiarde": "plagiar",
    "plagiardes": "plagiar",
    "plagiare": "plagiar",
    "plagiarei": "plagiar",
    "plagiareis": "plagiar",
    "plagiarem": "plagiar",
    "plagiaremos": "plagiar",
    "plagiares": "plagiar",
    "plagiaria": "plagiar",
    "plagiariam": "plagiar",
    "plagiarias": "plagiar",
    "plagiarmo": "plagiar",
    "plagiarmos": "plagiar",
    "plagiará": "plagiar",
    "plagiarás": "plagiar",
    "plagiarão": "plagiar",
    "plagiaríamos": "plagiar",
    "plagiaríeis": "plagiar",
    "plagias": "plagiar",
    "plagiasse": "plagiar",
    "plagiassem": "plagiar",
    "plagiasses": "plagiar",
    "plagiaste": "plagiar",
    "plagiastes": "plagiar",
    "plagiatos": "plagiato",
    "plagiava": "plagiar",
    "plagiavam": "plagiar",
    "plagiavas": "plagiar",
    "plagie": "plagiar",
    "plagiedra": "plagiedro",
    "plagiedras": "plagiedro",
    "plagiedrias": "plagiedria",
    "plagiedros": "plagiedro",
    "plagiei": "plagiar",
    "plagieis": "plagiar",
    "plagiem": "plagiar",
    "plagiemo": "plagiar",
    "plagiemos": "plagiar",
    "plagies": "plagiar",
    "plagio": "plagiar",
    "plagioclasitos": "plagioclasito",
    "plagioclasítica": "plagioclasítico",
    "plagioclasíticas": "plagioclasítico",
    "plagioclasíticos": "plagioclasítico",
    "plagioclástica": "plagioclástico",
    "plagioclásticas": "plagioclástico",
    "plagioclásticos": "plagioclástico",
    "plagiomorfias": "plagiomorfia",
    "plagiomórfica": "plagiomórfico",
    "plagiomórficas": "plagiomórfico",
    "plagiomórficos": "plagiomórfico",
    "plagiostómica": "plagiostómico",
    "plagiostómicas": "plagiostómico",
    "plagiostómicos": "plagiostómico",
    "plagiou": "plagiar",
    "plagiá": "plagiar",
    "plagiámo": "plagiar",
    "plagiámos": "plagiar",
    "plagiáramo": "plagiar",
    "plagiáramos": "plagiar",
    "plagiárei": "plagiar",
    "plagiáreis": "plagiar",
    "plagiária": "plagiário",
    "plagiárias": "plagiário",
    "plagiários": "plagiário",
    "plagiásseis": "plagiar",
    "plagiássemos": "plagiar",
    "plagiávamo": "plagiar",
    "plagiávamos": "plagiar",
    "plagiávei": "plagiar",
    "plagiáveis": "plagiável",
    "plagiédrica": "plagiédrico",
    "plagiédricas": "plagiédrico",
    "plagiédricos": "plagiédrico",
    "plagiócleses": "plagióclese",
    "plagióstoma": "plagióstomo",
    "plagióstomas": "plagióstomo",
    "plagióstomos": "plagióstomo",
    "plaina": "plaino",
    "plainas": "plaino",
    "plainetes": "plainete",
    "plainos": "plaino",
    "plana": "plano",
    "planada": "planar",
    "planadas": "planar",
    "planado": "planar",
    "planadora": "planador",
    "planadoras": "planador",
    "planadores": "planador",
    "planados": "planar",
    "planai": "planar",
    "planais": "planar",
    "planaltos": "planalto",
    "planam": "planar",
    "planamo": "planar",
    "planamos": "planar",
    "planando": "planar",
    "planara": "planar",
    "planaram": "planar",
    "planaras": "planar",
    "planardes": "planar",
    "planarei": "planar",
    "planareis": "planar",
    "planarem": "planar",
    "planaremos": "planar",
    "planares": "planar",
    "planaria": "planar",
    "planariam": "planar",
    "planarias": "planar",
    "planarmo": "planar",
    "planarmos": "planar",
    "planará": "planar",
    "planarás": "planar",
    "planarão": "planar",
    "planaríamos": "planar",
    "planaríeis": "planar",
    "planas": "plano",
    "planasse": "planar",
    "planassem": "planar",
    "planasses": "planar",
    "planaste": "planar",
    "planastes": "planar",
    "planava": "planar",
    "planavam": "planar",
    "planavas": "planar",
    "plancto": "plâncton",
    "planctos": "plâncton",
    "planctónica": "planctónico",
    "planctónicas": "planctónico",
    "planctónicos": "planctónico",
    "plane": "planar",
    "planeada": "planear",
    "planeadas": "planear",
    "planeado": "planear",
    "planeados": "planear",
    "planeai": "planear",
    "planeais": "planear",
    "planeamentos": "planeamento",
    "planeamo": "planear",
    "planeamos": "planear",
    "planeando": "planear",
    "planeara": "planear",
    "planearam": "planear",
    "planearas": "planear",
    "planearde": "planear",
    "planeardes": "planear",
    "planeare": "planear",
    "planearei": "planear",
    "planeareis": "planear",
    "planearem": "planear",
    "planearemos": "planear",
    "planeares": "planear",
    "planearia": "planear",
    "planeariam": "planear",
    "planearias": "planear",
    "planearmo": "planear",
    "planearmos": "planear",
    "planeará": "planear",
    "planearás": "planear",
    "planearão": "planear",
    "planearíamos": "planear",
    "planearíeis": "planear",
    "planeasse": "planear",
    "planeassem": "planear",
    "planeasses": "planear",
    "planeaste": "planear",
    "planeastes": "planear",
    "planeava": "planear",
    "planeavam": "planear",
    "planeavas": "planear",
    "planeei": "planear",
    "planeeis": "planear",
    "planeemo": "planear",
    "planeemos": "planear",
    "planei": "planar",
    "planeia": "planear",
    "planeiam": "planear",
    "planeias": "planear",
    "planeie": "planear",
    "planeiem": "planear",
    "planeies": "planear",
    "planeio": "planear",
    "planeis": "planar",
    "planem": "planar",
    "planemo": "planar",
    "planemos": "planar",
    "planeou": "planear",
    "planes": "planar",
    "planetas": "planeta",
    "planetes": "planete",
    "planetária": "planetário",
    "planetárias": "planetário",
    "planetários": "planetário",
    "planetóides": "planetóide",
    "planezas": "planeza",
    "planeá": "planear",
    "planeámo": "planear",
    "planeámos": "planear",
    "planeáramo": "planear",
    "planeáramos": "planear",
    "planeárei": "planear",
    "planeáreis": "planear",
    "planeásseis": "planear",
    "planeássemos": "planear",
    "planeávamo": "planear",
    "planeávamos": "planear",
    "planeávei": "planear",
    "planeáveis": "planeável",
    "planganas": "plangana",
    "plange": "planger",
    "plangei": "planger",
    "plangeis": "planger",
    "plangem": "planger",
    "plangemo": "planger",
    "plangemos": "planger",
    "plangendo": "planger",
    "plangentes": "plangente",
    "plangera": "planger",
    "plangeram": "planger",
    "plangeras": "planger",
    "plangerde": "planger",
    "plangerdes": "planger",
    "plangere": "planger",
    "plangerei": "planger",
    "plangereis": "planger",
    "plangerem": "planger",
    "plangeremos": "planger",
    "plangeres": "planger",
    "plangeria": "planger",
    "plangeriam": "planger",
    "plangerias": "planger",
    "plangermo": "planger",
    "plangermos": "planger",
    "plangerá": "planger",
    "plangerás": "planger",
    "plangerão": "planger",
    "plangeríamos": "planger",
    "plangeríeis": "planger",
    "planges": "planger",
    "plangesse": "planger",
    "plangessem": "planger",
    "plangesses": "planger",
    "plangeste": "planger",
    "plangestes": "planger",
    "plangeu": "planger",
    "plangi": "planger",
    "plangia": "planger",
    "plangiam": "planger",
    "plangias": "planger",
    "plangida": "planger",
    "plangidas": "planger",
    "plangido": "planger",
    "plangidos": "planger",
    "plangores": "plangor",
    "plangê": "planger",
    "plangências": "plangência",
    "plangêramo": "planger",
    "plangêramos": "planger",
    "plangêrei": "planger",
    "plangêreis": "planger",
    "plangêsseis": "planger",
    "plangêssemos": "planger",
    "plangíamo": "planger",
    "plangíamos": "planger",
    "plangíei": "planger",
    "plangíeis": "planger",
    "planifica": "planificar",
    "planificada": "planificar",
    "planificadas": "planificar",
    "planificado": "planificar",
    "planificadora": "planificador",
    "planificadoras": "planificador",
    "planificadores": "planificador",
    "planificados": "planificar",
    "planificai": "planificar",
    "planificais": "planificar",
    "planificam": "planificar",
    "planificamo": "planificar",
    "planificamos": "planificar",
    "planificando": "planificar",
    "planificara": "planificar",
    "planificaram": "planificar",
    "planificaras": "planificar",
    "planificarde": "planificar",
    "planificardes": "planificar",
    "planificare": "planificar",
    "planificarei": "planificar",
    "planificareis": "planificar",
    "planificarem": "planificar",
    "planificaremos": "planificar",
    "planificares": "planificar",
    "planificaria": "planificar",
    "planificariam": "planificar",
    "planificarias": "planificar",
    "planificarmo": "planificar",
    "planificarmos": "planificar",
    "planificará": "planificar",
    "planificarás": "planificar",
    "planificarão": "planificar",
    "planificaríamos": "planificar",
    "planificaríeis": "planificar",
    "planificas": "planificar",
    "planificasse": "planificar",
    "planificassem": "planificar",
    "planificasses": "planificar",
    "planificaste": "planificar",
    "planificastes": "planificar",
    "planificava": "planificar",
    "planificavam": "planificar",
    "planificavas": "planificar",
    "planificações": "planificação",
    "planifico": "planificar",
    "planificou": "planificar",
    "planificá": "planificar",
    "planificámo": "planificar",
    "planificámos": "planificar",
    "planificáramo": "planificar",
    "planificáramos": "planificar",
    "planificárei": "planificar",
    "planificáreis": "planificar",
    "planificásseis": "planificar",
    "planificássemos": "planificar",
    "planificávamo": "planificar",
    "planificávamos": "planificar",
    "planificávei": "planificar",
    "planificáveis": "planificável",
    "planifique": "planificar",
    "planifiquei": "planificar",
    "planifiqueis": "planificar",
    "planifiquem": "planificar",
    "planifiquemo": "planificar",
    "planifiquemos": "planificar",
    "planifiques": "planificar",
    "planiformes": "planiforme",
    "planiglobos": "planiglobo",
    "planimetrias": "planimetria",
    "planimétrica": "planimétrico",
    "planimétricas": "planimétrico",
    "planimétricos": "planimétrico",
    "planipenes": "planipene",
    "planirrostra": "planirrostro",
    "planirrostras": "planirrostro",
    "planirrostros": "planirrostro",
    "planisférica": "planisférico",
    "planisféricas": "planisférico",
    "planisféricos": "planisférico",
    "planisférios": "planisfério",
    "planiza": "planizar",
    "planizada": "planizar",
    "planizadas": "planizar",
    "planizado": "planizar",
    "planizados": "planizar",
    "planizai": "planizar",
    "planizais": "planizar",
    "planizam": "planizar",
    "planizamo": "planizar",
    "planizamos": "planizar",
    "planizando": "planizar",
    "planizara": "planizar",
    "planizaram": "planizar",
    "planizaras": "planizar",
    "planizarde": "planizar",
    "planizardes": "planizar",
    "planizare": "planizar",
    "planizarei": "planizar",
    "planizareis": "planizar",
    "planizarem": "planizar",
    "planizaremos": "planizar",
    "planizares": "planizar",
    "planizaria": "planizar",
    "planizariam": "planizar",
    "planizarias": "planizar",
    "planizarmo": "planizar",
    "planizarmos": "planizar",
    "planizará": "planizar",
    "planizarás": "planizar",
    "planizarão": "planizar",
    "planizaríamos": "planizar",
    "planizaríeis": "planizar",
    "planizas": "planizar",
    "planizasse": "planizar",
    "planizassem": "planizar",
    "planizasses": "planizar",
    "planizaste": "planizar",
    "planizastes": "planizar",
    "planizava": "planizar",
    "planizavam": "planizar",
    "planizavas": "planizar",
    "planize": "planizar",
    "planizei": "planizar",
    "planizeis": "planizar",
    "planizem": "planizar",
    "planizemo": "planizar",
    "planizemos": "planizar",
    "planizes": "planizar",
    "planizo": "planizar",
    "planizou": "planizar",
    "planizá": "planizar",
    "planizámo": "planizar",
    "planizámos": "planizar",
    "planizáramo": "planizar",
    "planizáramos": "planizar",
    "planizárei": "planizar",
    "planizáreis": "planizar",
    "planizásseis": "planizar",
    "planizássemos": "planizar",
    "planizávamo": "planizar",
    "planizávamos": "planizar",
    "planizávei": "planizar",
    "planizáveis": "planizar",
    "planja": "planger",
    "planjais": "planger",
    "planjam": "planger",
    "planjamo": "planger",
    "planjamos": "planger",
    "planjas": "planger",
    "planjo": "planger",
    "plano": "planar",
    "planogâmetas": "planogâmeta",
    "planos": "plano",
    "planou": "planar",
    "planta": "plantar",
    "plantada": "plantar",
    "plantadas": "plantar",
    "plantado": "plantar",
    "plantadora": "plantador",
    "plantadoras": "plantador",
    "plantadores": "plantador",
    "plantados": "plantar",
    "plantagináceas": "plantaginácea",
    "plantai": "plantar",
    "plantais": "plantar",
    "plantam": "plantar",
    "plantamo": "plantar",
    "plantamos": "plantar",
    "plantando": "plantar",
    "plantara": "plantar",
    "plantaram": "plantar",
    "plantaras": "plantar",
    "plantarde": "plantar",
    "plantardes": "plantar",
    "plantare": "plantar",
    "plantarei": "plantar",
    "plantareis": "plantar",
    "plantarem": "plantar",
    "plantaremos": "plantar",
    "plantares": "plantar",
    "plantaria": "plantar",
    "plantariam": "plantar",
    "plantarias": "plantar",
    "plantarmo": "plantar",
    "plantarmos": "plantar",
    "plantará": "plantar",
    "plantarás": "plantar",
    "plantarão": "plantar",
    "plantaríamos": "plantar",
    "plantaríeis": "plantar",
    "plantas": "plantar",
    "plantasse": "plantar",
    "plantassem": "plantar",
    "plantasses": "plantar",
    "plantaste": "plantar",
    "plantastes": "plantar",
    "plantava": "plantar",
    "plantavam": "plantar",
    "plantavas": "plantar",
    "plantações": "plantação",
    "plante": "plantar",
    "plantei": "plantar",
    "planteis": "plantar",
    "plantem": "plantar",
    "plantemo": "plantar",
    "plantemos": "plantar",
    "plantes": "plantar",
    "plantinha": "planta",
    "plantinhas": "planta",
    "plantios": "plantio",
    "plantita": "planta",
    "plantitas": "planta",
    "planto": "plantar",
    "plantou": "plantar",
    "plantulações": "plantulação",
    "planturosa": "planturoso",
    "planturosas": "planturoso",
    "planturosos": "planturoso",
    "plantá": "plantar",
    "plantámo": "plantar",
    "plantámos": "plantar",
    "plantáramo": "plantar",
    "plantáramos": "plantar",
    "plantárei": "plantar",
    "plantáreis": "plantar",
    "plantásseis": "plantar",
    "plantássemos": "plantar",
    "plantávamo": "plantar",
    "plantávamos": "plantar",
    "plantávei": "plantar",
    "plantáveis": "plantar",
    "plantéis": "plantel",
    "plantígrada": "plantígrado",
    "plantígradas": "plantígrado",
    "plantígrados": "plantígrado",
    "plantões": "plantão",
    "planuras": "planura",
    "planáltica": "planáltico",
    "planálticas": "planáltico",
    "planálticos": "planáltico",
    "planámo": "planar",
    "planámos": "planar",
    "planáramo": "planar",
    "planáramos": "planar",
    "planáreis": "planar",
    "planárias": "planária",
    "planásseis": "planar",
    "planássemos": "planar",
    "planávamo": "planar",
    "planávamos": "planar",
    "planáveis": "planar",
    "planícies": "planície",
    "planímetros": "planímetro",
    "planíssima": "plano",
    "planíssimas": "plano",
    "planíssimo": "plano",
    "planíssimos": "plano",
    "plaque": "placar",
    "plaquei": "placar",
    "plaqueis": "placar",
    "plaquem": "placar",
    "plaquemo": "placar",
    "plaquemos": "placar",
    "plaques": "placar",
    "plaquetas": "plaqueta",
    "plaquinha": "placa",
    "plaquinhas": "placa",
    "plaquita": "placa",
    "plaquitas": "placa",
    "plaqués": "plaqué",
    "plasma": "plasmar",
    "plasmada": "plasmar",
    "plasmadas": "plasmar",
    "plasmado": "plasmar",
    "plasmados": "plasmar",
    "plasmai": "plasmar",
    "plasmais": "plasmar",
    "plasmam": "plasmar",
    "plasmamo": "plasmar",
    "plasmamos": "plasmar",
    "plasmando": "plasmar",
    "plasmara": "plasmar",
    "plasmaram": "plasmar",
    "plasmaras": "plasmar",
    "plasmarde": "plasmar",
    "plasmardes": "plasmar",
    "plasmare": "plasmar",
    "plasmarei": "plasmar",
    "plasmareis": "plasmar",
    "plasmarem": "plasmar",
    "plasmaremos": "plasmar",
    "plasmares": "plasmar",
    "plasmaria": "plasmar",
    "plasmariam": "plasmar",
    "plasmarias": "plasmar",
    "plasmarmo": "plasmar",
    "plasmarmos": "plasmar",
    "plasmará": "plasmar",
    "plasmarás": "plasmar",
    "plasmarão": "plasmar",
    "plasmaríamos": "plasmar",
    "plasmaríeis": "plasmar",
    "plasmas": "plasmar",
    "plasmasse": "plasmar",
    "plasmassem": "plasmar",
    "plasmasses": "plasmar",
    "plasmaste": "plasmar",
    "plasmastes": "plasmar",
    "plasmava": "plasmar",
    "plasmavam": "plasmar",
    "plasmavas": "plasmar",
    "plasme": "plasmar",
    "plasmei": "plasmar",
    "plasmeis": "plasmar",
    "plasmem": "plasmar",
    "plasmemo": "plasmar",
    "plasmemos": "plasmar",
    "plasmes": "plasmar",
    "plasmo": "plasmar",
    "plasmodiais": "plasmodial",
    "plasmodierética": "plasmodierético",
    "plasmodieréticas": "plasmodierético",
    "plasmodieréticos": "plasmodierético",
    "plasmodiéreses": "plasmodiérese",
    "plasmodiófora": "plasmodióforo",
    "plasmodióforas": "plasmodióforo",
    "plasmodióforos": "plasmodióforo",
    "plasmolítica": "plasmolítico",
    "plasmolíticas": "plasmolítico",
    "plasmolíticos": "plasmolítico",
    "plasmou": "plasmar",
    "plasmá": "plasmar",
    "plasmámo": "plasmar",
    "plasmámos": "plasmar",
    "plasmáramo": "plasmar",
    "plasmáramos": "plasmar",
    "plasmárei": "plasmar",
    "plasmáreis": "plasmar",
    "plasmásseis": "plasmar",
    "plasmássemos": "plasmar",
    "plasmática": "plasmático",
    "plasmáticas": "plasmático",
    "plasmáticos": "plasmático",
    "plasmávamo": "plasmar",
    "plasmávamos": "plasmar",
    "plasmávei": "plasmar",
    "plasmáveis": "plasmar",
    "plasmódios": "plasmódio",
    "plasmólises": "plasmólise",
    "plastas": "plasta",
    "plastias": "plastia",
    "plasticidades": "plasticidade",
    "plasticinas": "plasticina",
    "plasticiza": "plasticizar",
    "plasticizada": "plasticizar",
    "plasticizadas": "plasticizar",
    "plasticizado": "plasticizar",
    "plasticizados": "plasticizar",
    "plasticizai": "plasticizar",
    "plasticizais": "plasticizar",
    "plasticizam": "plasticizar",
    "plasticizamo": "plasticizar",
    "plasticizamos": "plasticizar",
    "plasticizando": "plasticizar",
    "plasticizantes": "plasticizante",
    "plasticizara": "plasticizar",
    "plasticizaram": "plasticizar",
    "plasticizaras": "plasticizar",
    "plasticizarde": "plasticizar",
    "plasticizardes": "plasticizar",
    "plasticizare": "plasticizar",
    "plasticizarei": "plasticizar",
    "plasticizareis": "plasticizar",
    "plasticizarem": "plasticizar",
    "plasticizaremos": "plasticizar",
    "plasticizares": "plasticizar",
    "plasticizaria": "plasticizar",
    "plasticizariam": "plasticizar",
    "plasticizarias": "plasticizar",
    "plasticizarmo": "plasticizar",
    "plasticizarmos": "plasticizar",
    "plasticizará": "plasticizar",
    "plasticizarás": "plasticizar",
    "plasticizarão": "plasticizar",
    "plasticizaríamos": "plasticizar",
    "plasticizaríeis": "plasticizar",
    "plasticizas": "plasticizar",
    "plasticizasse": "plasticizar",
    "plasticizassem": "plasticizar",
    "plasticizasses": "plasticizar",
    "plasticizaste": "plasticizar",
    "plasticizastes": "plasticizar",
    "plasticizava": "plasticizar",
    "plasticizavam": "plasticizar",
    "plasticizavas": "plasticizar",
    "plasticizações": "plasticização",
    "plasticize": "plasticizar",
    "plasticizei": "plasticizar",
    "plasticizeis": "plasticizar",
    "plasticizem": "plasticizar",
    "plasticizemo": "plasticizar",
    "plasticizemos": "plasticizar",
    "plasticizes": "plasticizar",
    "plasticizo": "plasticizar",
    "plasticizou": "plasticizar",
    "plasticizá": "plasticizar",
    "plasticizámo": "plasticizar",
    "plasticizámos": "plasticizar",
    "plasticizáramo": "plasticizar",
    "plasticizáramos": "plasticizar",
    "plasticizárei": "plasticizar",
    "plasticizáreis": "plasticizar",
    "plasticizásseis": "plasticizar",
    "plasticizássemos": "plasticizar",
    "plasticizávamo": "plasticizar",
    "plasticizávamos": "plasticizar",
    "plasticizávei": "plasticizar",
    "plasticizáveis": "plasticizar",
    "plastidomas": "plastidoma",
    "plastifica": "plastificar",
    "plastificada": "plastificar",
    "plastificadas": "plastificar",
    "plastificado": "plastificar",
    "plastificados": "plastificar",
    "plastificai": "plastificar",
    "plastificais": "plastificar",
    "plastificam": "plastificar",
    "plastificamo": "plastificar",
    "plastificamos": "plastificar",
    "plastificando": "plastificar",
    "plastificantes": "plastificante",
    "plastificara": "plastificar",
    "plastificaram": "plastificar",
    "plastificaras": "plastificar",
    "plastificarde": "plastificar",
    "plastificardes": "plastificar",
    "plastificare": "plastificar",
    "plastificarei": "plastificar",
    "plastificareis": "plastificar",
    "plastificarem": "plastificar",
    "plastificaremos": "plastificar",
    "plastificares": "plastificar",
    "plastificaria": "plastificar",
    "plastificariam": "plastificar",
    "plastificarias": "plastificar",
    "plastificarmo": "plastificar",
    "plastificarmos": "plastificar",
    "plastificará": "plastificar",
    "plastificarás": "plastificar",
    "plastificarão": "plastificar",
    "plastificaríamos": "plastificar",
    "plastificaríeis": "plastificar",
    "plastificas": "plastificar",
    "plastificasse": "plastificar",
    "plastificassem": "plastificar",
    "plastificasses": "plastificar",
    "plastificaste": "plastificar",
    "plastificastes": "plastificar",
    "plastificava": "plastificar",
    "plastificavam": "plastificar",
    "plastificavas": "plastificar",
    "plastifico": "plastificar",
    "plastificou": "plastificar",
    "plastificá": "plastificar",
    "plastificámo": "plastificar",
    "plastificámos": "plastificar",
    "plastificáramo": "plastificar",
    "plastificáramos": "plastificar",
    "plastificárei": "plastificar",
    "plastificáreis": "plastificar",
    "plastificásseis": "plastificar",
    "plastificássemos": "plastificar",
    "plastificávamo": "plastificar",
    "plastificávamos": "plastificar",
    "plastificávei": "plastificar",
    "plastificáveis": "plastificável",
    "plastifique": "plastificar",
    "plastifiquei": "plastificar",
    "plastifiqueis": "plastificar",
    "plastifiquem": "plastificar",
    "plastifiquemo": "plastificar",
    "plastifiquemos": "plastificar",
    "plastifiques": "plastificar",
    "plastilinas": "plastilina",
    "plastométrica": "plastométrico",
    "plastométricas": "plastométrico",
    "plastométricos": "plastométrico",
    "plastrões": "plastrão",
    "plastídios": "plastídio",
    "plastómetros": "plastómetro",
    "platabandas": "platabanda",
    "plataformas": "plataforma",
    "plataleidas": "plataleida",
    "plataleídeos": "plataleídeo",
    "platanáceas": "platanácea",
    "plateias": "plateia",
    "platelmintes": "platelminte",
    "platenses": "platense",
    "plateresca": "plateresco",
    "platerescas": "plateresco",
    "platerescos": "plateresco",
    "platibandas": "platibanda",
    "platicéfala": "platicéfalo",
    "platicéfalas": "platicéfalo",
    "platicéfalos": "platicéfalo",
    "platina": "platino",
    "platinada": "platinar",
    "platinadas": "platinar",
    "platinado": "platinar",
    "platinadora": "platinador",
    "platinadoras": "platinador",
    "platinadores": "platinador",
    "platinados": "platinar",
    "platinagens": "platinagem",
    "platinai": "platinar",
    "platinais": "platinar",
    "platinam": "platinar",
    "platinamo": "platinar",
    "platinamos": "platinar",
    "platinando": "platinar",
    "platinara": "platinar",
    "platinaram": "platinar",
    "platinaras": "platinar",
    "platinarde": "platinar",
    "platinardes": "platinar",
    "platinare": "platinar",
    "platinarei": "platinar",
    "platinareis": "platinar",
    "platinarem": "platinar",
    "platinaremos": "platinar",
    "platinares": "platinar",
    "platinaria": "platinar",
    "platinariam": "platinar",
    "platinarias": "platinar",
    "platinarmo": "platinar",
    "platinarmos": "platinar",
    "platinará": "platinar",
    "platinarás": "platinar",
    "platinarão": "platinar",
    "platinaríamos": "platinar",
    "platinaríeis": "platinar",
    "platinas": "platino",
    "platinasse": "platinar",
    "platinassem": "platinar",
    "platinasses": "platinar",
    "platinaste": "platinar",
    "platinastes": "platinar",
    "platinava": "platinar",
    "platinavam": "platinar",
    "platinavas": "platinar",
    "platine": "platinar",
    "platinei": "platinar",
    "platineis": "platinar",
    "platinem": "platinar",
    "platinemo": "platinar",
    "platinemos": "platinar",
    "platines": "platinar",
    "platino": "platinar",
    "platinos": "platino",
    "platinosa": "platinoso",
    "platinosas": "platinoso",
    "platinosos": "platinoso",
    "platinotipias": "platinotipia",
    "platinotipos": "platinotipo",
    "platinotípica": "platinotípico",
    "platinotípicas": "platinotípico",
    "platinotípicos": "platinotípico",
    "platinou": "platinar",
    "platiná": "platinar",
    "platinámo": "platinar",
    "platinámos": "platinar",
    "platináramo": "platinar",
    "platináramos": "platinar",
    "platinárei": "platinar",
    "platináreis": "platinar",
    "platinásseis": "platinar",
    "platinássemos": "platinar",
    "platinávamo": "platinar",
    "platinávamos": "platinar",
    "platinávei": "platinar",
    "platináveis": "platinável",
    "platinífera": "platinífero",
    "platiníferas": "platinífero",
    "platiníferos": "platinífero",
    "platirrinos": "platirrino",
    "platirrostra": "platirrostro",
    "platirrostras": "platirrostro",
    "platirrostros": "platirrostro",
    "platirrínios": "platirrínio",
    "platonismos": "platonismo",
    "platonistas": "platonista",
    "platónica": "platónico",
    "platónicas": "platónico",
    "platónicos": "platónico",
    "plausibilidades": "plausibilidade",
    "plaustros": "plaustro",
    "plausíveis": "plausível",
    "playbacks": "playback",
    "plebeados": "plebeado",
    "plebeia": "plebeu",
    "plebeias": "plebeu",
    "plebeidades": "plebeidade",
    "plebeistas": "plebeista",
    "plebeiza": "plebeizar",
    "plebeizada": "plebeizar",
    "plebeizadas": "plebeizar",
    "plebeizado": "plebeizar",
    "plebeizados": "plebeizar",
    "plebeizai": "plebeizar",
    "plebeizais": "plebeizar",
    "plebeizam": "plebeizar",
    "plebeizamo": "plebeizar",
    "plebeizamos": "plebeizar",
    "plebeizando": "plebeizar",
    "plebeizara": "plebeizar",
    "plebeizaram": "plebeizar",
    "plebeizaras": "plebeizar",
    "plebeizarde": "plebeizar",
    "plebeizardes": "plebeizar",
    "plebeizare": "plebeizar",
    "plebeizarei": "plebeizar",
    "plebeizareis": "plebeizar",
    "plebeizarem": "plebeizar",
    "plebeizaremos": "plebeizar",
    "plebeizares": "plebeizar",
    "plebeizaria": "plebeizar",
    "plebeizariam": "plebeizar",
    "plebeizarias": "plebeizar",
    "plebeizarmo": "plebeizar",
    "plebeizarmos": "plebeizar",
    "plebeizará": "plebeizar",
    "plebeizarás": "plebeizar",
    "plebeizarão": "plebeizar",
    "plebeizaríamos": "plebeizar",
    "plebeizaríeis": "plebeizar",
    "plebeizas": "plebeizar",
    "plebeizasse": "plebeizar",
    "plebeizassem": "plebeizar",
    "plebeizasses": "plebeizar",
    "plebeizaste": "plebeizar",
    "plebeizastes": "plebeizar",
    "plebeizava": "plebeizar",
    "plebeizavam": "plebeizar",
    "plebeizavas": "plebeizar",
    "plebeizações": "plebeização",
    "plebeize": "plebeizar",
    "plebeizei": "plebeizar",
    "plebeizeis": "plebeizar",
    "plebeizem": "plebeizar",
    "plebeizemo": "plebeizar",
    "plebeizemos": "plebeizar",
    "plebeizes": "plebeizar",
    "plebeizo": "plebeizar",
    "plebeizou": "plebeizar",
    "plebeizá": "plebeizar",
    "plebeizámo": "plebeizar",
    "plebeizámos": "plebeizar",
    "plebeizáramo": "plebeizar",
    "plebeizáramos": "plebeizar",
    "plebeizárei": "plebeizar",
    "plebeizáreis": "plebeizar",
    "plebeizásseis": "plebeizar",
    "plebeizássemos": "plebeizar",
    "plebeizávamo": "plebeizar",
    "plebeizávamos": "plebeizar",
    "plebeizávei": "plebeizar",
    "plebeizáveis": "plebeizar",
    "plebes": "plebe",
    "plebeus": "plebeu",
    "plebeísmos": "plebeísmo",
    "plebiscita": "plebiscitar",
    "plebiscitada": "plebiscitar",
    "plebiscitadas": "plebiscitar",
    "plebiscitado": "plebiscitar",
    "plebiscitados": "plebiscitar",
    "plebiscitai": "plebiscitar",
    "plebiscitais": "plebiscitar",
    "plebiscitam": "plebiscitar",
    "plebiscitamo": "plebiscitar",
    "plebiscitamos": "plebiscitar",
    "plebiscitando": "plebiscitar",
    "plebiscitara": "plebiscitar",
    "plebiscitaram": "plebiscitar",
    "plebiscitaras": "plebiscitar",
    "plebiscitarde": "plebiscitar",
    "plebiscitardes": "plebiscitar",
    "plebiscitare": "plebiscitar",
    "plebiscitarei": "plebiscitar",
    "plebiscitareis": "plebiscitar",
    "plebiscitarem": "plebiscitar",
    "plebiscitaremos": "plebiscitar",
    "plebiscitares": "plebiscitar",
    "plebiscitaria": "plebiscitar",
    "plebiscitariam": "plebiscitar",
    "plebiscitarias": "plebiscitar",
    "plebiscitarmo": "plebiscitar",
    "plebiscitarmos": "plebiscitar",
    "plebiscitará": "plebiscitar",
    "plebiscitarás": "plebiscitar",
    "plebiscitarão": "plebiscitar",
    "plebiscitaríamos": "plebiscitar",
    "plebiscitaríeis": "plebiscitar",
    "plebiscitas": "plebiscitar",
    "plebiscitasse": "plebiscitar",
    "plebiscitassem": "plebiscitar",
    "plebiscitasses": "plebiscitar",
    "plebiscitaste": "plebiscitar",
    "plebiscitastes": "plebiscitar",
    "plebiscitava": "plebiscitar",
    "plebiscitavam": "plebiscitar",
    "plebiscitavas": "plebiscitar",
    "plebiscite": "plebiscitar",
    "plebiscitei": "plebiscitar",
    "plebisciteis": "plebiscitar",
    "plebiscitem": "plebiscitar",
    "plebiscitemo": "plebiscitar",
    "plebiscitemos": "plebiscitar",
    "plebiscites": "plebiscitar",
    "plebiscito": "plebiscitar",
    "plebiscitos": "plebiscito",
    "plebiscitou": "plebiscitar",
    "plebiscitá": "plebiscitar",
    "plebiscitámo": "plebiscitar",
    "plebiscitámos": "plebiscitar",
    "plebiscitáramo": "plebiscitar",
    "plebiscitáramos": "plebiscitar",
    "plebiscitárei": "plebiscitar",
    "plebiscitáreis": "plebiscitar",
    "plebiscitária": "plebiscitário",
    "plebiscitárias": "plebiscitário",
    "plebiscitários": "plebiscitário",
    "plebiscitásseis": "plebiscitar",
    "plebiscitássemos": "plebiscitar",
    "plebiscitávamo": "plebiscitar",
    "plebiscitávamos": "plebiscitar",
    "plebiscitávei": "plebiscitar",
    "plebiscitáveis": "plebiscitar",
    "plectros": "plectro",
    "plectógnatos": "plectógnato",
    "pleiocena": "pleioceno",
    "pleiocenas": "pleioceno",
    "pleiocenos": "pleioceno",
    "pleiocénica": "pleiocénico",
    "pleiocénicas": "pleiocénico",
    "pleiocénicos": "pleiocénico",
    "pleiotropias": "pleiotropia",
    "pleiotropismos": "pleiotropismo",
    "pleiotrópica": "pleiotrópico",
    "pleiotrópicas": "pleiotrópico",
    "pleiotrópicos": "pleiotrópico",
    "pleistocena": "pleistoceno",
    "pleistocenas": "pleistoceno",
    "pleistocenos": "pleistoceno",
    "pleistocénica": "pleistocénico",
    "pleistocénicas": "pleistocénico",
    "pleistocénicos": "pleistocénico",
    "pleiteada": "pleitear",
    "pleiteadas": "pleitear",
    "pleiteado": "pleitear",
    "pleiteadora": "pleiteador",
    "pleiteadoras": "pleiteador",
    "pleiteadores": "pleiteador",
    "pleiteados": "pleitear",
    "pleiteai": "pleitear",
    "pleiteais": "pleitear",
    "pleiteamo": "pleitear",
    "pleiteamos": "pleitear",
    "pleiteando": "pleitear",
    "pleiteantes": "pleiteante",
    "pleiteara": "pleitear",
    "pleitearam": "pleitear",
    "pleitearas": "pleitear",
    "pleitearde": "pleitear",
    "pleiteardes": "pleitear",
    "pleiteare": "pleitear",
    "pleitearei": "pleitear",
    "pleiteareis": "pleitear",
    "pleitearem": "pleitear",
    "pleitearemos": "pleitear",
    "pleiteares": "pleitear",
    "pleitearia": "pleitear",
    "pleiteariam": "pleitear",
    "pleitearias": "pleitear",
    "pleitearmo": "pleitear",
    "pleitearmos": "pleitear",
    "pleiteará": "pleitear",
    "pleitearás": "pleitear",
    "pleitearão": "pleitear",
    "pleitearíamos": "pleitear",
    "pleitearíeis": "pleitear",
    "pleiteasse": "pleitear",
    "pleiteassem": "pleitear",
    "pleiteasses": "pleitear",
    "pleiteaste": "pleitear",
    "pleiteastes": "pleitear",
    "pleiteava": "pleitear",
    "pleiteavam": "pleitear",
    "pleiteavas": "pleitear",
    "pleiteei": "pleitear",
    "pleiteeis": "pleitear",
    "pleiteemo": "pleitear",
    "pleiteemos": "pleitear",
    "pleiteia": "pleitear",
    "pleiteiam": "pleitear",
    "pleiteias": "pleitear",
    "pleiteie": "pleitear",
    "pleiteiem": "pleitear",
    "pleiteies": "pleitear",
    "pleiteio": "pleitear",
    "pleiteou": "pleitear",
    "pleiteá": "pleitear",
    "pleiteámo": "pleitear",
    "pleiteámos": "pleitear",
    "pleiteáramo": "pleitear",
    "pleiteáramos": "pleitear",
    "pleiteárei": "pleitear",
    "pleiteáreis": "pleitear",
    "pleiteásseis": "pleitear",
    "pleiteássemos": "pleitear",
    "pleiteávamo": "pleitear",
    "pleiteávamos": "pleitear",
    "pleiteávei": "pleitear",
    "pleiteáveis": "pleitear",
    "pleitos": "pleito",
    "plena": "pleno",
    "plenas": "pleno",
    "plenidões": "plenidão",
    "plenifica": "plenificar",
    "plenificada": "plenificar",
    "plenificadas": "plenificar",
    "plenificado": "plenificar",
    "plenificados": "plenificar",
    "plenificai": "plenificar",
    "plenificais": "plenificar",
    "plenificam": "plenificar",
    "plenificamo": "plenificar",
    "plenificamos": "plenificar",
    "plenificando": "plenificar",
    "plenificara": "plenificar",
    "plenificaram": "plenificar",
    "plenificaras": "plenificar",
    "plenificarde": "plenificar",
    "plenificardes": "plenificar",
    "plenificare": "plenificar",
    "plenificarei": "plenificar",
    "plenificareis": "plenificar",
    "plenificarem": "plenificar",
    "plenificaremos": "plenificar",
    "plenificares": "plenificar",
    "plenificaria": "plenificar",
    "plenificariam": "plenificar",
    "plenificarias": "plenificar",
    "plenificarmo": "plenificar",
    "plenificarmos": "plenificar",
    "plenificará": "plenificar",
    "plenificarás": "plenificar",
    "plenificarão": "plenificar",
    "plenificaríamos": "plenificar",
    "plenificaríeis": "plenificar",
    "plenificas": "plenificar",
    "plenificasse": "plenificar",
    "plenificassem": "plenificar",
    "plenificasses": "plenificar",
    "plenificaste": "plenificar",
    "plenificastes": "plenificar",
    "plenificava": "plenificar",
    "plenificavam": "plenificar",
    "plenificavas": "plenificar",
    "plenifico": "plenificar",
    "plenificou": "plenificar",
    "plenificá": "plenificar",
    "plenificámo": "plenificar",
    "plenificámos": "plenificar",
    "plenificáramo": "plenificar",
    "plenificáramos": "plenificar",
    "plenificárei": "plenificar",
    "plenificáreis": "plenificar",
    "plenificásseis": "plenificar",
    "plenificássemos": "plenificar",
    "plenificávamo": "plenificar",
    "plenificávamos": "plenificar",
    "plenificávei": "plenificar",
    "plenificáveis": "plenificar",
    "plenifique": "plenificar",
    "plenifiquei": "plenificar",
    "plenifiqueis": "plenificar",
    "plenifiquem": "plenificar",
    "plenifiquemo": "plenificar",
    "plenifiquemos": "plenificar",
    "plenifiques": "plenificar",
    "plenilunares": "plenilunar",
    "plenilúnios": "plenilúnio",
    "plenipotenciária": "plenipotenciário",
    "plenipotenciárias": "plenipotenciário",
    "plenipotenciários": "plenipotenciário",
    "plenipotências": "plenipotência",
    "plenirrostra": "plenirrostro",
    "plenirrostras": "plenirrostro",
    "plenirrostros": "plenirrostro",
    "plenismos": "plenismo",
    "plenistas": "plenista",
    "plenitudes": "plenitude",
    "plenos": "pleno",
    "plenária": "plenário",
    "plenárias": "plenário",
    "plenários": "plenário",
    "pleníssima": "pleno",
    "pleníssimas": "pleno",
    "pleníssimo": "pleno",
    "pleníssimos": "pleno",
    "pleocroísmos": "pleocroísmo",
    "pleomorfa": "pleomorfo",
    "pleomorfas": "pleomorfo",
    "pleomorfismos": "pleomorfismo",
    "pleomorfos": "pleomorfo",
    "pleonasmos": "pleonasmo",
    "pleonástica": "pleonástico",
    "pleonásticas": "pleonástico",
    "pleonásticos": "pleonástico",
    "pleromas": "pleroma",
    "plesiossauros": "plesiossauro",
    "plessimétrica": "plessimétrico",
    "plessimétricas": "plessimétrico",
    "plessimétricos": "plessimétrico",
    "plessímetros": "plessímetro",
    "plessómetros": "plessómetro",
    "pletoras": "pletora",
    "pletoriza": "pletorizar",
    "pletorizada": "pletorizar",
    "pletorizadas": "pletorizar",
    "pletorizado": "pletorizar",
    "pletorizados": "pletorizar",
    "pletorizai": "pletorizar",
    "pletorizais": "pletorizar",
    "pletorizam": "pletorizar",
    "pletorizamo": "pletorizar",
    "pletorizamos": "pletorizar",
    "pletorizando": "pletorizar",
    "pletorizara": "pletorizar",
    "pletorizaram": "pletorizar",
    "pletorizaras": "pletorizar",
    "pletorizarde": "pletorizar",
    "pletorizardes": "pletorizar",
    "pletorizare": "pletorizar",
    "pletorizarei": "pletorizar",
    "pletorizareis": "pletorizar",
    "pletorizarem": "pletorizar",
    "pletorizaremos": "pletorizar",
    "pletorizares": "pletorizar",
    "pletorizaria": "pletorizar",
    "pletorizariam": "pletorizar",
    "pletorizarias": "pletorizar",
    "pletorizarmo": "pletorizar",
    "pletorizarmos": "pletorizar",
    "pletorizará": "pletorizar",
    "pletorizarás": "pletorizar",
    "pletorizarão": "pletorizar",
    "pletorizaríamos": "pletorizar",
    "pletorizaríeis": "pletorizar",
    "pletorizas": "pletorizar",
    "pletorizasse": "pletorizar",
    "pletorizassem": "pletorizar",
    "pletorizasses": "pletorizar",
    "pletorizaste": "pletorizar",
    "pletorizastes": "pletorizar",
    "pletorizava": "pletorizar",
    "pletorizavam": "pletorizar",
    "pletorizavas": "pletorizar",
    "pletorize": "pletorizar",
    "pletorizei": "pletorizar",
    "pletorizeis": "pletorizar",
    "pletorizem": "pletorizar",
    "pletorizemo": "pletorizar",
    "pletorizemos": "pletorizar",
    "pletorizes": "pletorizar",
    "pletorizo": "pletorizar",
    "pletorizou": "pletorizar",
    "pletorizá": "pletorizar",
    "pletorizámo": "pletorizar",
    "pletorizámos": "pletorizar",
    "pletorizáramo": "pletorizar",
    "pletorizáramos": "pletorizar",
    "pletorizárei": "pletorizar",
    "pletorizáreis": "pletorizar",
    "pletorizásseis": "pletorizar",
    "pletorizássemos": "pletorizar",
    "pletorizávamo": "pletorizar",
    "pletorizávamos": "pletorizar",
    "pletorizávei": "pletorizar",
    "pletorizáveis": "pletorizar",
    "pletórica": "pletórico",
    "pletóricas": "pletórico",
    "pletóricos": "pletórico",
    "pleurais": "pleural",
    "pleuras": "pleura",
    "pleurisias": "pleurisia",
    "pleurites": "pleurite",
    "pleurobrânquias": "pleurobrânquia",
    "pleurobrânquica": "pleurobrânquico",
    "pleurobrânquicas": "pleurobrânquico",
    "pleurobrânquicos": "pleurobrânquico",
    "pleurodinias": "pleurodinia",
    "pleurodímica": "pleurodímico",
    "pleurodímicas": "pleurodímico",
    "pleurodímicos": "pleurodímico",
    "pleuromeiáceas": "pleuromeiácea",
    "pleuronectídeos": "pleuronectídeo",
    "pleuronéctidas": "pleuronéctida",
    "pleuropatias": "pleuropatia",
    "pleuropneumonias": "pleuropneumonia",
    "pleuropneumónica": "pleuropneumónico",
    "pleuropneumónicas": "pleuropneumónico",
    "pleuropneumónicos": "pleuropneumónico",
    "pleuropática": "pleuropático",
    "pleuropáticas": "pleuropático",
    "pleuropáticos": "pleuropático",
    "pleurorragias": "pleurorragia",
    "pleurorreias": "pleurorreia",
    "pleurorreica": "pleurorreico",
    "pleurorreicas": "pleurorreico",
    "pleurorreicos": "pleurorreico",
    "pleurorrágica": "pleurorrágico",
    "pleurorrágicas": "pleurorrágico",
    "pleurorrágicos": "pleurorrágico",
    "pleurotomias": "pleurotomia",
    "pleurotómica": "pleurotómico",
    "pleurotómicas": "pleurotómico",
    "pleurotómicos": "pleurotómico",
    "pleurítica": "pleurítico",
    "pleuríticas": "pleurítico",
    "pleuríticos": "pleurítico",
    "plexiformes": "plexiforme",
    "plexos": "plexo",
    "pleópodes": "pleópode",
    "plica": "plicar",
    "plicada": "plicar",
    "plicadas": "plicar",
    "plicado": "plicar",
    "plicados": "plicar",
    "plicai": "plicar",
    "plicais": "plicar",
    "plicam": "plicar",
    "plicamo": "plicar",
    "plicamos": "plicar",
    "plicando": "plicar",
    "plicara": "plicar",
    "plicaram": "plicar",
    "plicaras": "plicar",
    "plicarde": "plicar",
    "plicardes": "plicar",
    "plicare": "plicar",
    "plicarei": "plicar",
    "plicareis": "plicar",
    "plicarem": "plicar",
    "plicaremos": "plicar",
    "plicares": "plicar",
    "plicaria": "plicar",
    "plicariam": "plicar",
    "plicarias": "plicar",
    "plicarmo": "plicar",
    "plicarmos": "plicar",
    "plicará": "plicar",
    "plicarás": "plicar",
    "plicarão": "plicar",
    "plicaríamos": "plicar",
    "plicaríeis": "plicar",
    "plicas": "plicar",
    "plicasse": "plicar",
    "plicassem": "plicar",
    "plicasses": "plicar",
    "plicaste": "plicar",
    "plicastes": "plicar",
    "plicativa": "plicativo",
    "plicativas": "plicativo",
    "plicativos": "plicativo",
    "plicaturas": "plicatura",
    "plicava": "plicar",
    "plicavam": "plicar",
    "plicavas": "plicar",
    "plico": "plicar",
    "plicou": "plicar",
    "plicá": "plicar",
    "plicámo": "plicar",
    "plicámos": "plicar",
    "plicáramo": "plicar",
    "plicáramos": "plicar",
    "plicárei": "plicar",
    "plicáreis": "plicar",
    "plicásseis": "plicar",
    "plicássemos": "plicar",
    "plicávamo": "plicar",
    "plicávamos": "plicar",
    "plicávei": "plicar",
    "plicáveis": "plicar",
    "pliensbachianos": "pliensbachiano",
    "plintos": "plinto",
    "pliocena": "plioceno",
    "pliocenas": "plioceno",
    "pliocenos": "plioceno",
    "pliocénica": "pliocénico",
    "pliocénicas": "pliocénico",
    "pliocénicos": "pliocénico",
    "pliotropias": "pliotropia",
    "pliotropismos": "pliotropismo",
    "pliotrópica": "pliotrópico",
    "pliotrópicas": "pliotrópico",
    "pliotrópicos": "pliotrópico",
    "plique": "plicar",
    "pliquei": "plicar",
    "pliqueis": "plicar",
    "pliquem": "plicar",
    "pliquemo": "plicar",
    "pliquemos": "plicar",
    "pliques": "plicar",
    "plissa": "plissar",
    "plissada": "plissar",
    "plissadas": "plissar",
    "plissado": "plissar",
    "plissadores": "plissador",
    "plissados": "plissar",
    "plissai": "plissar",
    "plissais": "plissar",
    "plissam": "plissar",
    "plissamo": "plissar",
    "plissamos": "plissar",
    "plissando": "plissar",
    "plissara": "plissar",
    "plissaram": "plissar",
    "plissaras": "plissar",
    "plissarde": "plissar",
    "plissardes": "plissar",
    "plissare": "plissar",
    "plissarei": "plissar",
    "plissareis": "plissar",
    "plissarem": "plissar",
    "plissaremos": "plissar",
    "plissares": "plissar",
    "plissaria": "plissar",
    "plissariam": "plissar",
    "plissarias": "plissar",
    "plissarmo": "plissar",
    "plissarmos": "plissar",
    "plissará": "plissar",
    "plissarás": "plissar",
    "plissarão": "plissar",
    "plissaríamos": "plissar",
    "plissaríeis": "plissar",
    "plissas": "plissar",
    "plissasse": "plissar",
    "plissassem": "plissar",
    "plissasses": "plissar",
    "plissaste": "plissar",
    "plissastes": "plissar",
    "plissava": "plissar",
    "plissavam": "plissar",
    "plissavas": "plissar",
    "plisse": "plissar",
    "plissei": "plissar",
    "plisseis": "plissar",
    "plissem": "plissar",
    "plissemo": "plissar",
    "plissemos": "plissar",
    "plisses": "plissar",
    "plisso": "plissar",
    "plissou": "plissar",
    "plissá": "plissar",
    "plissámo": "plissar",
    "plissámos": "plissar",
    "plissáramo": "plissar",
    "plissáramos": "plissar",
    "plissárei": "plissar",
    "plissáreis": "plissar",
    "plissásseis": "plissar",
    "plissássemos": "plissar",
    "plissávamo": "plissar",
    "plissávamos": "plissar",
    "plissávei": "plissar",
    "plissáveis": "plissar",
    "plistocena": "plistoceno",
    "plistocenas": "plistoceno",
    "plistocenos": "plistoceno",
    "plistocénica": "plistocénico",
    "plistocénicas": "plistocénico",
    "plistocénicos": "plistocénico",
    "pliópodes": "pliópode",
    "ploces": "ploce",
    "plombaginas": "plombagina",
    "plumaceira": "plumaceiro",
    "plumaceiras": "plumaceiro",
    "plumaceiros": "plumaceiro",
    "plumachos": "plumacho",
    "plumagens": "plumagem",
    "plumas": "pluma",
    "plumaços": "plumaço",
    "plumbagens": "plumbagem",
    "plumbaginas": "plumbagina",
    "plumbaginosa": "plumbaginoso",
    "plumbaginosas": "plumbaginoso",
    "plumbaginosos": "plumbaginoso",
    "plumbagináceas": "plumbaginácea",
    "plumbagos": "plumbago",
    "plumbagínea": "plumbagíneo",
    "plumbagíneas": "plumbagíneo",
    "plumbagíneos": "plumbagíneo",
    "plumbarias": "plumbaria",
    "plumbeada": "plumbear",
    "plumbeadas": "plumbear",
    "plumbeado": "plumbear",
    "plumbeados": "plumbear",
    "plumbeai": "plumbear",
    "plumbeais": "plumbear",
    "plumbeamo": "plumbear",
    "plumbeamos": "plumbear",
    "plumbeando": "plumbear",
    "plumbeara": "plumbear",
    "plumbearam": "plumbear",
    "plumbearas": "plumbear",
    "plumbearde": "plumbear",
    "plumbeardes": "plumbear",
    "plumbeare": "plumbear",
    "plumbearei": "plumbear",
    "plumbeareis": "plumbear",
    "plumbearem": "plumbear",
    "plumbearemos": "plumbear",
    "plumbeares": "plumbear",
    "plumbearia": "plumbear",
    "plumbeariam": "plumbear",
    "plumbearias": "plumbear",
    "plumbearmo": "plumbear",
    "plumbearmos": "plumbear",
    "plumbeará": "plumbear",
    "plumbearás": "plumbear",
    "plumbearão": "plumbear",
    "plumbearíamos": "plumbear",
    "plumbearíeis": "plumbear",
    "plumbeasse": "plumbear",
    "plumbeassem": "plumbear",
    "plumbeasses": "plumbear",
    "plumbeaste": "plumbear",
    "plumbeastes": "plumbear",
    "plumbeava": "plumbear",
    "plumbeavam": "plumbear",
    "plumbeavas": "plumbear",
    "plumbeei": "plumbear",
    "plumbeeis": "plumbear",
    "plumbeemo": "plumbear",
    "plumbeemos": "plumbear",
    "plumbeia": "plumbear",
    "plumbeiam": "plumbear",
    "plumbeias": "plumbear",
    "plumbeie": "plumbear",
    "plumbeiem": "plumbear",
    "plumbeies": "plumbear",
    "plumbeio": "plumbear",
    "plumbeou": "plumbear",
    "plumbetas": "plumbeta",
    "plumbeá": "plumbear",
    "plumbeámo": "plumbear",
    "plumbeámos": "plumbear",
    "plumbeáramo": "plumbear",
    "plumbeáramos": "plumbear",
    "plumbeárei": "plumbear",
    "plumbeáreis": "plumbear",
    "plumbeásseis": "plumbear",
    "plumbeássemos": "plumbear",
    "plumbeávamo": "plumbear",
    "plumbeávamos": "plumbear",
    "plumbeávei": "plumbear",
    "plumbeáveis": "plumbear",
    "plumbosa": "plumboso",
    "plumbosas": "plumboso",
    "plumbosos": "plumboso",
    "plumbífera": "plumbífero",
    "plumbíferas": "plumbífero",
    "plumbíferos": "plumbífero",
    "plumiformes": "plumiforme",
    "plumilhas": "plumilha",
    "plumistas": "plumista",
    "plumitiva": "plumitivo",
    "plumitivas": "plumitivo",
    "plumitivos": "plumitivo",
    "plumosa": "plumoso",
    "plumosas": "plumoso",
    "plumosos": "plumoso",
    "plumuliformes": "plumuliforme",
    "plumípedes": "plumípede",
    "plumões": "plumão",
    "plurais": "plural",
    "pluralidades": "pluralidade",
    "pluralismos": "pluralismo",
    "pluralistas": "pluralista",
    "pluraliza": "pluralizar",
    "pluralizada": "pluralizar",
    "pluralizadas": "pluralizar",
    "pluralizado": "pluralizar",
    "pluralizados": "pluralizar",
    "pluralizai": "pluralizar",
    "pluralizais": "pluralizar",
    "pluralizam": "pluralizar",
    "pluralizamo": "pluralizar",
    "pluralizamos": "pluralizar",
    "pluralizando": "pluralizar",
    "pluralizara": "pluralizar",
    "pluralizaram": "pluralizar",
    "pluralizaras": "pluralizar",
    "pluralizarde": "pluralizar",
    "pluralizardes": "pluralizar",
    "pluralizare": "pluralizar",
    "pluralizarei": "pluralizar",
    "pluralizareis": "pluralizar",
    "pluralizarem": "pluralizar",
    "pluralizaremos": "pluralizar",
    "pluralizares": "pluralizar",
    "pluralizaria": "pluralizar",
    "pluralizariam": "pluralizar",
    "pluralizarias": "pluralizar",
    "pluralizarmo": "pluralizar",
    "pluralizarmos": "pluralizar",
    "pluralizará": "pluralizar",
    "pluralizarás": "pluralizar",
    "pluralizarão": "pluralizar",
    "pluralizaríamos": "pluralizar",
    "pluralizaríeis": "pluralizar",
    "pluralizas": "pluralizar",
    "pluralizasse": "pluralizar",
    "pluralizassem": "pluralizar",
    "pluralizasses": "pluralizar",
    "pluralizaste": "pluralizar",
    "pluralizastes": "pluralizar",
    "pluralizava": "pluralizar",
    "pluralizavam": "pluralizar",
    "pluralizavas": "pluralizar",
    "pluralizações": "pluralização",
    "pluralize": "pluralizar",
    "pluralizei": "pluralizar",
    "pluralizeis": "pluralizar",
    "pluralizem": "pluralizar",
    "pluralizemo": "pluralizar",
    "pluralizemos": "pluralizar",
    "pluralizes": "pluralizar",
    "pluralizo": "pluralizar",
    "pluralizou": "pluralizar",
    "pluralizá": "pluralizar",
    "pluralizámo": "pluralizar",
    "pluralizámos": "pluralizar",
    "pluralizáramo": "pluralizar",
    "pluralizáramos": "pluralizar",
    "pluralizárei": "pluralizar",
    "pluralizáreis": "pluralizar",
    "pluralizásseis": "pluralizar",
    "pluralizássemos": "pluralizar",
    "pluralizávamo": "pluralizar",
    "pluralizávamos": "pluralizar",
    "pluralizávei": "pluralizar",
    "pluralizáveis": "pluralizável",
    "pluraridades": "pluraridade",
    "plurianuais": "plurianual",
    "pluricarpelares": "pluricarpelar",
    "pluricelulares": "pluricelular",
    "pluricontinentais": "pluricontinental",
    "pluricontinentalidades": "pluricontinentalidade",
    "pluricêntrica": "pluricêntrico",
    "pluricêntricas": "pluricêntrico",
    "pluricêntricos": "pluricêntrico",
    "pluridentada": "pluridentado",
    "pluridentadas": "pluridentado",
    "pluridentados": "pluridentado",
    "pluridisciplinares": "pluridisciplinar",
    "pluriflora": "plurifloro",
    "plurifloras": "plurifloro",
    "plurifloros": "plurifloro",
    "pluriformes": "pluriforme",
    "plurigamias": "plurigamia",
    "plurilingues": "plurilingue",
    "plurilinguística": "plurilinguístico",
    "plurilinguísticas": "plurilinguístico",
    "plurilinguísticos": "plurilinguístico",
    "plurilobulada": "plurilobulado",
    "plurilobuladas": "plurilobulado",
    "plurilobulados": "plurilobulado",
    "pluriloculares": "plurilocular",
    "pluripartidarismos": "pluripartidarismo",
    "pluripétala": "pluripétalo",
    "pluripétalas": "pluripétalo",
    "pluripétalos": "pluripétalo",
    "plurirreligiosa": "plurirreligioso",
    "plurirreligiosas": "plurirreligioso",
    "plurirreligiosos": "plurirreligioso",
    "plurisseculares": "plurissecular",
    "plurisseriada": "plurisseriado",
    "plurisseriadas": "plurisseriado",
    "plurisseriados": "plurisseriado",
    "plurivalentes": "plurivalente",
    "plurivocidades": "plurivocidade",
    "plurígama": "plurígamo",
    "plurígamas": "plurígamo",
    "plurígamos": "plurígamo",
    "plurívoca": "plurívoco",
    "plurívocas": "plurívoco",
    "plurívocos": "plurívoco",
    "plutarca": "plutarco",
    "plutarcas": "plutarco",
    "plutarcos": "plutarco",
    "plutarquiza": "plutarquizar",
    "plutarquizada": "plutarquizar",
    "plutarquizadas": "plutarquizar",
    "plutarquizado": "plutarquizar",
    "plutarquizados": "plutarquizar",
    "plutarquizai": "plutarquizar",
    "plutarquizais": "plutarquizar",
    "plutarquizam": "plutarquizar",
    "plutarquizamo": "plutarquizar",
    "plutarquizamos": "plutarquizar",
    "plutarquizando": "plutarquizar",
    "plutarquizara": "plutarquizar",
    "plutarquizaram": "plutarquizar",
    "plutarquizaras": "plutarquizar",
    "plutarquizardes": "plutarquizar",
    "plutarquizarei": "plutarquizar",
    "plutarquizareis": "plutarquizar",
    "plutarquizarem": "plutarquizar",
    "plutarquizaremos": "plutarquizar",
    "plutarquizares": "plutarquizar",
    "plutarquizaria": "plutarquizar",
    "plutarquizariam": "plutarquizar",
    "plutarquizarias": "plutarquizar",
    "plutarquizarmo": "plutarquizar",
    "plutarquizarmos": "plutarquizar",
    "plutarquizará": "plutarquizar",
    "plutarquizarás": "plutarquizar",
    "plutarquizarão": "plutarquizar",
    "plutarquizaríamos": "plutarquizar",
    "plutarquizaríeis": "plutarquizar",
    "plutarquizas": "plutarquizar",
    "plutarquizasse": "plutarquizar",
    "plutarquizassem": "plutarquizar",
    "plutarquizasses": "plutarquizar",
    "plutarquizaste": "plutarquizar",
    "plutarquizastes": "plutarquizar",
    "plutarquizava": "plutarquizar",
    "plutarquizavam": "plutarquizar",
    "plutarquizavas": "plutarquizar",
    "plutarquize": "plutarquizar",
    "plutarquizei": "plutarquizar",
    "plutarquizeis": "plutarquizar",
    "plutarquizem": "plutarquizar",
    "plutarquizemo": "plutarquizar",
    "plutarquizemos": "plutarquizar",
    "plutarquizes": "plutarquizar",
    "plutarquizo": "plutarquizar",
    "plutarquizou": "plutarquizar",
    "plutarquizámo": "plutarquizar",
    "plutarquizámos": "plutarquizar",
    "plutarquizáramo": "plutarquizar",
    "plutarquizáramos": "plutarquizar",
    "plutarquizáreis": "plutarquizar",
    "plutarquizásseis": "plutarquizar",
    "plutarquizássemos": "plutarquizar",
    "plutarquizávamo": "plutarquizar",
    "plutarquizávamos": "plutarquizar",
    "plutarquizáveis": "plutarquizar",
    "plutocracias": "plutocracia",
    "plutocratas": "plutocrata",
    "plutocrática": "plutocrático",
    "plutocráticas": "plutocrático",
    "plutocráticos": "plutocrático",
    "plutomanias": "plutomania",
    "plutomaníaca": "plutomaníaco",
    "plutomaníacas": "plutomaníaco",
    "plutomaníacos": "plutomaníaco",
    "plutonismos": "plutonismo",
    "plutonomias": "plutonomia",
    "plutómaa": "plutómao",
    "plutómaas": "plutómao",
    "plutómana": "plutómano",
    "plutómanas": "plutómano",
    "plutómanos": "plutómano",
    "plutómaos": "plutómao",
    "plutónica": "plutónico",
    "plutónicas": "plutónico",
    "plutónicos": "plutónico",
    "plutónios": "plutónio",
    "plutões": "plutão",
    "pluviais": "pluvial",
    "pluviografias": "pluviografia",
    "pluviográfica": "pluviográfico",
    "pluviográficas": "pluviográfico",
    "pluviográficos": "pluviográfico",
    "pluviometrias": "pluviometria",
    "pluviométrica": "pluviométrico",
    "pluviométricas": "pluviométrico",
    "pluviométricos": "pluviométrico",
    "pluviosa": "pluvioso",
    "pluviosas": "pluvioso",
    "pluvioscopias": "pluvioscopia",
    "pluvioscópica": "pluvioscópico",
    "pluvioscópicas": "pluvioscópico",
    "pluvioscópicos": "pluvioscópico",
    "pluvioscópios": "pluvioscópio",
    "pluviosidades": "pluviosidade",
    "pluviosos": "pluvioso",
    "pluviáteis": "pluviátil",
    "pluviógrafos": "pluviógrafo",
    "pluviómetros": "pluviómetro",
    "plácida": "plácido",
    "plácidas": "plácido",
    "plácidos": "plácido",
    "plácitos": "plácito",
    "plágios": "plágio",
    "plástica": "plástico",
    "plásticas": "plástico",
    "plásticos": "plástico",
    "plátanos": "plátano",
    "plânctones": "plâncton",
    "plânctons": "plâncton",
    "plântulas": "plântula",
    "plêiada": "plêiade",
    "plêiadas": "plêiade",
    "plêiades": "plêiade",
    "plúmbea": "plúmbeo",
    "plúmbeas": "plúmbeo",
    "plúmbeos": "plúmbeo",
    "plúmbica": "plúmbico",
    "plúmbicas": "plúmbico",
    "plúmbicos": "plúmbico",
    "plúmea": "plúmeo",
    "plúmeas": "plúmeo",
    "plúmeos": "plúmeo",
    "plúmulas": "plúmula",
    "plúteos": "plúteo",
    "pneometrias": "pneometria",
    "pneumas": "pneuma",
    "pneumatismos": "pneumatismo",
    "pneumatistas": "pneumatista",
    "pneumatolítica": "pneumatolítico",
    "pneumatolíticas": "pneumatolítico",
    "pneumatolíticos": "pneumatolítico",
    "pneumatófora": "pneumatóforo",
    "pneumatóforas": "pneumatóforo",
    "pneumatóforos": "pneumatóforo",
    "pneumatólises": "pneumatólise",
    "pneumectomias": "pneumectomia",
    "pneumectómica": "pneumectómico",
    "pneumectómicas": "pneumectómico",
    "pneumectómicos": "pneumectómico",
    "pneumobrânquia": "pneumobrânquio",
    "pneumobrânquias": "pneumobrânquio",
    "pneumobrânquios": "pneumobrânquio",
    "pneumoceles": "pneumocele",
    "pneumococos": "pneumococo",
    "pneumoconioses": "pneumoconiose",
    "pneumoconiónica": "pneumoconiónico",
    "pneumoconiónicas": "pneumoconiónico",
    "pneumoconiónicos": "pneumoconiónico",
    "pneumocélica": "pneumocélico",
    "pneumocélicas": "pneumocélico",
    "pneumocélicos": "pneumocélico",
    "pneumografias": "pneumografia",
    "pneumográfica": "pneumográfico",
    "pneumográficas": "pneumográfico",
    "pneumográficos": "pneumográfico",
    "pneumogástrica": "pneumogástrico",
    "pneumogástricas": "pneumogástrico",
    "pneumogástricos": "pneumogástrico",
    "pneumologias": "pneumologia",
    "pneumologistas": "pneumologista",
    "pneumológica": "pneumológico",
    "pneumológicas": "pneumológico",
    "pneumológicos": "pneumológico",
    "pneumonias": "pneumonia",
    "pneumopatias": "pneumopatia",
    "pneumoplegias": "pneumoplegia",
    "pneumopleurisias": "pneumopleurisia",
    "pneumopleurítica": "pneumopleurítico",
    "pneumopleuríticas": "pneumopleurítico",
    "pneumopleuríticos": "pneumopleurítico",
    "pneumoplégica": "pneumoplégico",
    "pneumoplégicas": "pneumoplégico",
    "pneumoplégicos": "pneumoplégico",
    "pneumopítica": "pneumopítico",
    "pneumopíticas": "pneumopítico",
    "pneumopíticos": "pneumopítico",
    "pneumorragias": "pneumorragia",
    "pneumorrágica": "pneumorrágico",
    "pneumorrágicas": "pneumorrágico",
    "pneumorrágicos": "pneumorrágico",
    "pneumoscopias": "pneumoscopia",
    "pneumoscópica": "pneumoscópico",
    "pneumoscópicas": "pneumoscópico",
    "pneumoscópicos": "pneumoscópico",
    "pneumoscópios": "pneumoscópio",
    "pneumostómica": "pneumostómico",
    "pneumostómicas": "pneumostómico",
    "pneumostómicos": "pneumostómico",
    "pneumostómios": "pneumostómio",
    "pneumoterapias": "pneumoterapia",
    "pneumoterápica": "pneumoterápico",
    "pneumoterápicas": "pneumoterápico",
    "pneumoterápicos": "pneumoterápico",
    "pneumotomias": "pneumotomia",
    "pneumotoráxica": "pneumotoráxico",
    "pneumotoráxicas": "pneumotoráxico",
    "pneumotoráxicos": "pneumotoráxico",
    "pneumotómica": "pneumotómico",
    "pneumotómicas": "pneumotómico",
    "pneumotómicos": "pneumotómico",
    "pneumotóraxes": "pneumotórax",
    "pneumática": "pneumático",
    "pneumáticas": "pneumático",
    "pneumáticos": "pneumático",
    "pneumétrica": "pneumétrico",
    "pneumétricas": "pneumétrico",
    "pneumétricos": "pneumétrico",
    "pneumónica": "pneumónico",
    "pneumónicas": "pneumónico",
    "pneumónicos": "pneumónico",
    "pneumóstomas": "pneumóstoma",
    "pneus": "pneu",
    "pneuzinho": "pneu",
    "pneuzinhos": "pneu",
    "pneuzito": "pneu",
    "pneuzitos": "pneu",
    "pneómetros": "pneómetro",
    "poa": "poer",
    "poais": "poer",
    "poalhas": "poalha",
    "poalhos": "poalho",
    "poam": "poer",
    "poamo": "poer",
    "poamos": "poer",
    "poas": "poer",
    "pobres": "pobre",
    "pobretanas": "pobretana",
    "pobretas": "pobreta",
    "pobretes": "pobrete",
    "pobretona": "pobretão",
    "pobretonas": "pobretão",
    "pobretões": "pobretão",
    "pobrezas": "pobreza",
    "pobrezinha": "pobre",
    "pobrezinhas": "pobre",
    "pobrezinho": "pobre",
    "pobrezinhos": "pobre",
    "pobrezita": "pobre",
    "pobrezitas": "pobre",
    "pobrezito": "pobre",
    "pobrezitos": "pobre",
    "pobríssima": "pobre",
    "pobríssimas": "pobre",
    "pobríssimo": "pobre",
    "pobríssimos": "pobre",
    "poceira": "poceiro",
    "poceiras": "poceiro",
    "poceiros": "poceiro",
    "poceirões": "poceirão",
    "pocemas": "pocema",
    "pochas": "pocha",
    "pocilgas": "pocilga",
    "pocilgos": "pocilgo",
    "pocilgões": "pocilgão",
    "pocinhas": "pocinha",
    "pocinhos": "pocinho",
    "poculiformes": "poculiforme",
    "poda": "podar",
    "podada": "podar",
    "podadas": "podar",
    "podadeira": "podador",
    "podadeiras": "podador",
    "podado": "podar",
    "podadora": "podador",
    "podadoras": "podador",
    "podadores": "podador",
    "podados": "podar",
    "podaduras": "podadura",
    "podagras": "podagra",
    "podai": "podar",
    "podais": "podar",
    "podaliros": "podaliro",
    "podalírias": "podalíria",
    "podalírios": "podalírio",
    "podam": "podar",
    "podamo": "podar",
    "podamos": "podar",
    "podando": "podar",
    "podara": "podar",
    "podaram": "podar",
    "podaras": "podar",
    "podarde": "podar",
    "podardes": "podar",
    "podare": "podar",
    "podarei": "podar",
    "podareis": "podar",
    "podarem": "podar",
    "podaremos": "podar",
    "podares": "podar",
    "podaria": "podar",
    "podariam": "podar",
    "podarias": "podar",
    "podarmo": "podar",
    "podarmos": "podar",
    "podará": "podar",
    "podarás": "podar",
    "podarão": "podar",
    "podaríamos": "podar",
    "podaríeis": "podar",
    "podas": "podar",
    "podasse": "podar",
    "podassem": "podar",
    "podasses": "podar",
    "podaste": "podar",
    "podastes": "podar",
    "podava": "podar",
    "podavam": "podar",
    "podavas": "podar",
    "pode": "poder",
    "podei": "poder",
    "podeis": "poder",
    "podem": "poder",
    "podemo": "poder",
    "podemos": "poder",
    "podendo": "poder",
    "podenga": "podengo",
    "podengas": "podengo",
    "podengos": "podengo",
    "poderde": "poder",
    "poderdes": "poder",
    "podere": "poder",
    "poderei": "poder",
    "podereis": "poder",
    "poderem": "poder",
    "poderemos": "poder",
    "poderes": "poder",
    "poderia": "poder",
    "poderiam": "poder",
    "poderias": "poder",
    "poderios": "poderio",
    "podermo": "poder",
    "podermos": "poder",
    "poderosa": "poderoso",
    "poderosas": "poderoso",
    "poderosos": "poderoso",
    "poderosíssima": "poderoso",
    "poderosíssimas": "poderoso",
    "poderosíssimo": "poderoso",
    "poderosíssimos": "poderoso",
    "poderá": "poder",
    "poderás": "poder",
    "poderão": "poder",
    "poderíamos": "poder",
    "poderíeis": "poder",
    "podes": "poder",
    "podia": "poder",
    "podiam": "poder",
    "podias": "poder",
    "podicipedídeos": "podicipedídeo",
    "podicipédidas": "podicipédida",
    "podida": "poder",
    "podidas": "poder",
    "podido": "poder",
    "podidos": "poder",
    "podo": "podar",
    "podoas": "podoa",
    "podobrânquia": "podobrânquio",
    "podobrânquias": "podobrânquio",
    "podobrânquios": "podobrânquio",
    "podoftalma": "podoftalmo",
    "podoftalmas": "podoftalmo",
    "podoftalmos": "podoftalmo",
    "podoftálmica": "podoftálmico",
    "podoftálmicas": "podoftálmico",
    "podoftálmicos": "podoftálmico",
    "podologias": "podologia",
    "podologistas": "podologista",
    "podológica": "podológico",
    "podológicas": "podológico",
    "podológicos": "podológico",
    "podometra": "podometrar",
    "podometrada": "podometrar",
    "podometradas": "podometrar",
    "podometrado": "podometrar",
    "podometrados": "podometrar",
    "podometrai": "podometrar",
    "podometrais": "podometrar",
    "podometram": "podometrar",
    "podometramo": "podometrar",
    "podometramos": "podometrar",
    "podometrando": "podometrar",
    "podometrara": "podometrar",
    "podometraram": "podometrar",
    "podometraras": "podometrar",
    "podometrarde": "podometrar",
    "podometrardes": "podometrar",
    "podometrare": "podometrar",
    "podometrarei": "podometrar",
    "podometrareis": "podometrar",
    "podometrarem": "podometrar",
    "podometraremos": "podometrar",
    "podometrares": "podometrar",
    "podometraria": "podometrar",
    "podometrariam": "podometrar",
    "podometrarias": "podometrar",
    "podometrarmo": "podometrar",
    "podometrarmos": "podometrar",
    "podometrará": "podometrar",
    "podometrarás": "podometrar",
    "podometrarão": "podometrar",
    "podometraríamos": "podometrar",
    "podometraríeis": "podometrar",
    "podometras": "podometrar",
    "podometrasse": "podometrar",
    "podometrassem": "podometrar",
    "podometrasses": "podometrar",
    "podometraste": "podometrar",
    "podometrastes": "podometrar",
    "podometrava": "podometrar",
    "podometravam": "podometrar",
    "podometravas": "podometrar",
    "podometre": "podometrar",
    "podometrei": "podometrar",
    "podometreis": "podometrar",
    "podometrem": "podometrar",
    "podometremo": "podometrar",
    "podometremos": "podometrar",
    "podometres": "podometrar",
    "podometro": "podometrar",
    "podometrou": "podometrar",
    "podometrá": "podometrar",
    "podometrámo": "podometrar",
    "podometrámos": "podometrar",
    "podometráramo": "podometrar",
    "podometráramos": "podometrar",
    "podometrárei": "podometrar",
    "podometráreis": "podometrar",
    "podometrásseis": "podometrar",
    "podometrássemos": "podometrar",
    "podometrávamo": "podometrar",
    "podometrávamos": "podometrar",
    "podometrávei": "podometrar",
    "podometráveis": "podometrar",
    "podométrica": "podométrico",
    "podométricas": "podométrico",
    "podométricos": "podométrico",
    "podou": "podar",
    "podredoiros": "podredoiro",
    "podredouros": "podredouro",
    "podres": "podre",
    "podrezinha": "podre",
    "podrezinhas": "podre",
    "podrezinho": "podre",
    "podrezinhos": "podre",
    "podrezita": "podre",
    "podrezitas": "podre",
    "podrezito": "podre",
    "podrezitos": "podre",
    "podricalha": "podricalho",
    "podricalhas": "podricalho",
    "podricalhos": "podricalho",
    "podrida": "podrido",
    "podridas": "podrido",
    "podridos": "podrido",
    "podridões": "podridão",
    "podriqueira": "podriqueiro",
    "podriqueiras": "podriqueiro",
    "podriqueiros": "podriqueiro",
    "podá": "podar",
    "podágrica": "podágrico",
    "podágricas": "podágrico",
    "podágricos": "podágrico",
    "podámo": "podar",
    "podámos": "podar",
    "podáramo": "podar",
    "podáramos": "podar",
    "podárei": "podar",
    "podáreis": "podar",
    "podásseis": "podar",
    "podássemos": "podar",
    "podávamo": "podar",
    "podávamos": "podar",
    "podávei": "podar",
    "podáveis": "podar",
    "podê": "poder",
    "podíamo": "poder",
    "podíamos": "poder",
    "podíei": "poder",
    "podíeis": "poder",
    "podómetros": "podómetro",
    "podões": "podão",
    "poedeiras": "poedeira",
    "poedouros": "poedouro",
    "poei": "poer",
    "poeiradas": "poeirada",
    "poeiras": "poeira",
    "poeirenta": "poeirento",
    "poeirentas": "poeirento",
    "poeirentos": "poeirento",
    "poeirinha": "poeira",
    "poeirinhas": "poeirinha",
    "poeirita": "poeira",
    "poeiritas": "poeira",
    "poeiros": "poeiro",
    "poeis": "poer",
    "poejos": "poejo",
    "poem": "poer",
    "poemas": "poema",
    "poemetos": "poemeto",
    "poemo": "poer",
    "poemos": "poer",
    "poendo": "poer",
    "poenta": "poento",
    "poentas": "poento",
    "poentes": "poente",
    "poentos": "poento",
    "poera": "poer",
    "poeram": "poer",
    "poeras": "poer",
    "poerde": "poer",
    "poerdes": "poer",
    "poere": "poer",
    "poerei": "poer",
    "poereis": "poer",
    "poerem": "poer",
    "poeremos": "poer",
    "poeres": "poer",
    "poeria": "poer",
    "poeriam": "poer",
    "poerias": "poer",
    "poermo": "poer",
    "poermos": "poer",
    "poerá": "poer",
    "poerás": "poer",
    "poerão": "poer",
    "poeríamos": "poer",
    "poeríeis": "poer",
    "poesias": "poesia",
    "poesse": "poer",
    "poessem": "poer",
    "poesses": "poer",
    "poeste": "poer",
    "poestes": "poer",
    "poeta": "poetar",
    "poetada": "poetar",
    "poetadas": "poetar",
    "poetado": "poetar",
    "poetados": "poetar",
    "poetai": "poetar",
    "poetais": "poetar",
    "poetam": "poetar",
    "poetamo": "poetar",
    "poetamos": "poetar",
    "poetando": "poetar",
    "poetara": "poetar",
    "poetaram": "poetar",
    "poetaras": "poetar",
    "poetarde": "poetar",
    "poetardes": "poetar",
    "poetare": "poetar",
    "poetarei": "poetar",
    "poetareis": "poetar",
    "poetarem": "poetar",
    "poetaremos": "poetar",
    "poetares": "poetar",
    "poetaria": "poetar",
    "poetariam": "poetar",
    "poetarias": "poetar",
    "poetarmo": "poetar",
    "poetarmos": "poetar",
    "poetará": "poetar",
    "poetarás": "poetar",
    "poetarão": "poetar",
    "poetaríamos": "poetar",
    "poetaríeis": "poetar",
    "poetas": "poetar",
    "poetasse": "poetar",
    "poetassem": "poetar",
    "poetasses": "poetar",
    "poetaste": "poetar",
    "poetastes": "poetar",
    "poetastra": "poetastro",
    "poetastras": "poetastro",
    "poetastros": "poetastro",
    "poetava": "poetar",
    "poetavam": "poetar",
    "poetavas": "poetar",
    "poetaça": "poetaço",
    "poetaças": "poetaço",
    "poetaços": "poetaço",
    "poete": "poetar",
    "poetei": "poetar",
    "poeteis": "poetar",
    "poetem": "poetar",
    "poetemo": "poetar",
    "poetemos": "poetar",
    "poetes": "poetar",
    "poetisa": "poeta",
    "poetisas": "poeta",
    "poetismos": "poetismo",
    "poetiza": "poetizar",
    "poetizada": "poetizar",
    "poetizadas": "poetizar",
    "poetizado": "poetizar",
    "poetizados": "poetizar",
    "poetizai": "poetizar",
    "poetizais": "poetizar",
    "poetizam": "poetizar",
    "poetizamo": "poetizar",
    "poetizamos": "poetizar",
    "poetizando": "poetizar",
    "poetizara": "poetizar",
    "poetizaram": "poetizar",
    "poetizaras": "poetizar",
    "poetizarde": "poetizar",
    "poetizardes": "poetizar",
    "poetizare": "poetizar",
    "poetizarei": "poetizar",
    "poetizareis": "poetizar",
    "poetizarem": "poetizar",
    "poetizaremos": "poetizar",
    "poetizares": "poetizar",
    "poetizaria": "poetizar",
    "poetizariam": "poetizar",
    "poetizarias": "poetizar",
    "poetizarmo": "poetizar",
    "poetizarmos": "poetizar",
    "poetizará": "poetizar",
    "poetizarás": "poetizar",
    "poetizarão": "poetizar",
    "poetizaríamos": "poetizar",
    "poetizaríeis": "poetizar",
    "poetizas": "poetizar",
    "poetizasse": "poetizar",
    "poetizassem": "poetizar",
    "poetizasses": "poetizar",
    "poetizaste": "poetizar",
    "poetizastes": "poetizar",
    "poetizava": "poetizar",
    "poetizavam": "poetizar",
    "poetizavas": "poetizar",
    "poetizações": "poetização",
    "poetize": "poetizar",
    "poetizei": "poetizar",
    "poetizeis": "poetizar",
    "poetizem": "poetizar",
    "poetizemo": "poetizar",
    "poetizemos": "poetizar",
    "poetizes": "poetizar",
    "poetizo": "poetizar",
    "poetizou": "poetizar",
    "poetizá": "poetizar",
    "poetizámo": "poetizar",
    "poetizámos": "poetizar",
    "poetizáramo": "poetizar",
    "poetizáramos": "poetizar",
    "poetizárei": "poetizar",
    "poetizáreis": "poetizar",
    "poetizásseis": "poetizar",
    "poetizássemos": "poetizar",
    "poetizávamo": "poetizar",
    "poetizávamos": "poetizar",
    "poetizávei": "poetizar",
    "poetizáveis": "poetizar",
    "poeto": "poetar",
    "poetou": "poetar",
    "poetá": "poetar",
    "poetámo": "poetar",
    "poetámos": "poetar",
    "poetáramo": "poetar",
    "poetáramos": "poetar",
    "poetárei": "poetar",
    "poetáreis": "poetar",
    "poetásseis": "poetar",
    "poetássemos": "poetar",
    "poetávamo": "poetar",
    "poetávamos": "poetar",
    "poetávei": "poetar",
    "poetáveis": "poetar",
    "poeu": "poer",
    "pogoníases": "pogoníase",
    "pogonófora": "pogonóforo",
    "pogonóforas": "pogonóforo",
    "pogonóforos": "pogonóforo",
    "pogonópodes": "pogonópode",
    "poiais": "poial",
    "poias": "poia",
    "poilões": "poilão",
    "poios": "poio",
    "poiquilotermias": "poiquilotermia",
    "poiquilotérmica": "poiquilotérmico",
    "poiquilotérmicas": "poiquilotérmico",
    "poiquilotérmicos": "poiquilotérmico",
    "poisa": "poisar",
    "poisada": "poisar",
    "poisadas": "poisar",
    "poisadeiras": "poisadeira",
    "poisadias": "poisadia",
    "poisado": "poisar",
    "poisadoiros": "poisadoiro",
    "poisados": "poisar",
    "poisai": "poisar",
    "poisais": "poisar",
    "poisam": "poisar",
    "poisamo": "poisar",
    "poisamos": "poisar",
    "poisando": "poisar",
    "poisara": "poisar",
    "poisaram": "poisar",
    "poisaras": "poisar",
    "poisarde": "poisar",
    "poisardes": "poisar",
    "poisare": "poisar",
    "poisarei": "poisar",
    "poisareis": "poisar",
    "poisarem": "poisar",
    "poisaremos": "poisar",
    "poisares": "poisar",
    "poisaria": "poisar",
    "poisariam": "poisar",
    "poisarias": "poisar",
    "poisarmo": "poisar",
    "poisarmos": "poisar",
    "poisará": "poisar",
    "poisarás": "poisar",
    "poisarão": "poisar",
    "poisaríamos": "poisar",
    "poisaríeis": "poisar",
    "poisas": "poisar",
    "poisasse": "poisar",
    "poisassem": "poisar",
    "poisasses": "poisar",
    "poisaste": "poisar",
    "poisastes": "poisar",
    "poisava": "poisar",
    "poisavam": "poisar",
    "poisavas": "poisar",
    "poise": "poisar",
    "poisei": "poisar",
    "poiseis": "poisar",
    "poisem": "poisar",
    "poisemo": "poisar",
    "poisemos": "poisar",
    "poises": "poise",
    "poisios": "poisio",
    "poiso": "poisar",
    "poisos": "poiso",
    "poisou": "poisar",
    "poisá": "poisar",
    "poisámo": "poisar",
    "poisámos": "poisar",
    "poisáramo": "poisar",
    "poisáramos": "poisar",
    "poisárei": "poisar",
    "poisáreis": "poisar",
    "poisásseis": "poisar",
    "poisássemos": "poisar",
    "poisávamo": "poisar",
    "poisávamos": "poisar",
    "poisávei": "poisar",
    "poisáveis": "poisar",
    "poita": "poitar",
    "poitada": "poitar",
    "poitadas": "poitar",
    "poitado": "poitar",
    "poitados": "poitar",
    "poitai": "poitar",
    "poitais": "poitar",
    "poitam": "poitar",
    "poitamo": "poitar",
    "poitamos": "poitar",
    "poitando": "poitar",
    "poitara": "poitar",
    "poitaram": "poitar",
    "poitaras": "poitar",
    "poitarde": "poitar",
    "poitardes": "poitar",
    "poitare": "poitar",
    "poitarei": "poitar",
    "poitareis": "poitar",
    "poitarem": "poitar",
    "poitaremos": "poitar",
    "poitares": "poitar",
    "poitaria": "poitar",
    "poitariam": "poitar",
    "poitarias": "poitar",
    "poitarmo": "poitar",
    "poitarmos": "poitar",
    "poitará": "poitar",
    "poitarás": "poitar",
    "poitarão": "poitar",
    "poitaríamos": "poitar",
    "poitaríeis": "poitar",
    "poitas": "poitar",
    "poitasse": "poitar",
    "poitassem": "poitar",
    "poitasses": "poitar",
    "poitaste": "poitar",
    "poitastes": "poitar",
    "poitava": "poitar",
    "poitavam": "poitar",
    "poitavas": "poitar",
    "poite": "poitar",
    "poitei": "poitar",
    "poiteis": "poitar",
    "poitem": "poitar",
    "poitemo": "poitar",
    "poitemos": "poitar",
    "poites": "poitar",
    "poito": "poitar",
    "poitou": "poitar",
    "poitá": "poitar",
    "poitámo": "poitar",
    "poitámos": "poitar",
    "poitáramo": "poitar",
    "poitáramos": "poitar",
    "poitárei": "poitar",
    "poitáreis": "poitar",
    "poitásseis": "poitar",
    "poitássemos": "poitar",
    "poitávamo": "poitar",
    "poitávamos": "poitar",
    "poitávei": "poitar",
    "poitáveis": "poitar",
    "poitões": "poitão",
    "poja": "pojar",
    "pojada": "pojar",
    "pojadas": "pojar",
    "pojado": "pojar",
    "pojadoiros": "pojadoiro",
    "pojados": "pojar",
    "pojadouros": "pojadouro",
    "pojaduras": "pojadura",
    "pojai": "pojar",
    "pojais": "pojar",
    "pojam": "pojar",
    "pojamo": "pojar",
    "pojamos": "pojar",
    "pojando": "pojar",
    "pojantes": "pojante",
    "pojara": "pojar",
    "pojaram": "pojar",
    "pojaras": "pojar",
    "pojarde": "pojar",
    "pojardes": "pojar",
    "pojare": "pojar",
    "pojarei": "pojar",
    "pojareis": "pojar",
    "pojarem": "pojar",
    "pojaremos": "pojar",
    "pojares": "pojar",
    "pojaria": "pojar",
    "pojariam": "pojar",
    "pojarias": "pojar",
    "pojarmo": "pojar",
    "pojarmos": "pojar",
    "pojará": "pojar",
    "pojarás": "pojar",
    "pojarão": "pojar",
    "pojaríamos": "pojar",
    "pojaríeis": "pojar",
    "pojas": "pojar",
    "pojasse": "pojar",
    "pojassem": "pojar",
    "pojasses": "pojar",
    "pojaste": "pojar",
    "pojastes": "pojar",
    "pojava": "pojar",
    "pojavam": "pojar",
    "pojavas": "pojar",
    "poje": "pojar",
    "pojei": "pojar",
    "pojeias": "pojeia",
    "pojeis": "pojar",
    "pojem": "pojar",
    "pojemo": "pojar",
    "pojemos": "pojar",
    "pojes": "pojar",
    "pojo": "pojar",
    "pojos": "pojo",
    "pojou": "pojar",
    "pojá": "pojar",
    "pojámo": "pojar",
    "pojámos": "pojar",
    "pojáramo": "pojar",
    "pojáramos": "pojar",
    "pojárei": "pojar",
    "pojáreis": "pojar",
    "pojásseis": "pojar",
    "pojássemos": "pojar",
    "pojávamo": "pojar",
    "pojávamos": "pojar",
    "pojávei": "pojar",
    "pojáveis": "pojar",
    "pokeres": "poker",
    "polaca": "polaco",
    "polacas": "polaco",
    "polaciúrias": "polaciúria",
    "polacos": "polaco",
    "polainada": "polainado",
    "polainadas": "polainado",
    "polainados": "polainado",
    "polainas": "polaina",
    "polainitos": "polainito",
    "polainuda": "polainudo",
    "polainudas": "polainudo",
    "polainudos": "polainudo",
    "polares": "polar",
    "polaridades": "polaridade",
    "polarigráfica": "polarigráfico",
    "polarigráficas": "polarigráfico",
    "polarigráficos": "polarigráfico",
    "polarimetrias": "polarimetria",
    "polarimétrica": "polarimétrico",
    "polarimétricas": "polarimétrico",
    "polarimétricos": "polarimétrico",
    "polariscopias": "polariscopia",
    "polariscópica": "polariscópico",
    "polariscópicas": "polariscópico",
    "polariscópicos": "polariscópico",
    "polariscópios": "polariscópio",
    "polariza": "polarizar",
    "polarizada": "polarizar",
    "polarizadas": "polarizar",
    "polarizado": "polarizar",
    "polarizadora": "polarizador",
    "polarizadoras": "polarizador",
    "polarizadores": "polarizador",
    "polarizados": "polarizar",
    "polarizai": "polarizar",
    "polarizais": "polarizar",
    "polarizam": "polarizar",
    "polarizamo": "polarizar",
    "polarizamos": "polarizar",
    "polarizando": "polarizar",
    "polarizara": "polarizar",
    "polarizaram": "polarizar",
    "polarizaras": "polarizar",
    "polarizarde": "polarizar",
    "polarizardes": "polarizar",
    "polarizare": "polarizar",
    "polarizarei": "polarizar",
    "polarizareis": "polarizar",
    "polarizarem": "polarizar",
    "polarizaremos": "polarizar",
    "polarizares": "polarizar",
    "polarizaria": "polarizar",
    "polarizariam": "polarizar",
    "polarizarias": "polarizar",
    "polarizarmo": "polarizar",
    "polarizarmos": "polarizar",
    "polarizará": "polarizar",
    "polarizarás": "polarizar",
    "polarizarão": "polarizar",
    "polarizaríamos": "polarizar",
    "polarizaríeis": "polarizar",
    "polarizas": "polarizar",
    "polarizasse": "polarizar",
    "polarizassem": "polarizar",
    "polarizasses": "polarizar",
    "polarizaste": "polarizar",
    "polarizastes": "polarizar",
    "polarizava": "polarizar",
    "polarizavam": "polarizar",
    "polarizavas": "polarizar",
    "polarizações": "polarização",
    "polarize": "polarizar",
    "polarizei": "polarizar",
    "polarizeis": "polarizar",
    "polarizem": "polarizar",
    "polarizemo": "polarizar",
    "polarizemos": "polarizar",
    "polarizes": "polarizar",
    "polarizo": "polarizar",
    "polarizou": "polarizar",
    "polarizá": "polarizar",
    "polarizámo": "polarizar",
    "polarizámos": "polarizar",
    "polarizáramo": "polarizar",
    "polarizáramos": "polarizar",
    "polarizárei": "polarizar",
    "polarizáreis": "polarizar",
    "polarizásseis": "polarizar",
    "polarizássemos": "polarizar",
    "polarizávamo": "polarizar",
    "polarizávamos": "polarizar",
    "polarizávei": "polarizar",
    "polarizáveis": "polarizável",
    "polarografias": "polarografia",
    "polarímetros": "polarímetro",
    "polarógrafos": "polarógrafo",
    "polaróides": "polaróide",
    "polarões": "polarão",
    "polca": "polcar",
    "polcada": "polcar",
    "polcadas": "polcar",
    "polcado": "polcar",
    "polcados": "polcar",
    "polcais": "polcar",
    "polcam": "polcar",
    "polcamo": "polcar",
    "polcamos": "polcar",
    "polcando": "polcar",
    "polcara": "polcar",
    "polcaram": "polcar",
    "polcaras": "polcar",
    "polcardes": "polcar",
    "polcarei": "polcar",
    "polcareis": "polcar",
    "polcarem": "polcar",
    "polcaremos": "polcar",
    "polcares": "polcar",
    "polcaria": "polcar",
    "polcariam": "polcar",
    "polcarias": "polcar",
    "polcarmo": "polcar",
    "polcarmos": "polcar",
    "polcará": "polcar",
    "polcarás": "polcar",
    "polcarão": "polcar",
    "polcaríamos": "polcar",
    "polcaríeis": "polcar",
    "polcas": "polcar",
    "polcasse": "polcar",
    "polcassem": "polcar",
    "polcasses": "polcar",
    "polcaste": "polcar",
    "polcastes": "polcar",
    "polcava": "polcar",
    "polcavam": "polcar",
    "polcavas": "polcar",
    "polco": "polcar",
    "polcou": "polcar",
    "polcámo": "polcar",
    "polcámos": "polcar",
    "polcáramo": "polcar",
    "polcáramos": "polcar",
    "polcáreis": "polcar",
    "polcásseis": "polcar",
    "polcássemos": "polcar",
    "polcávamo": "polcar",
    "polcávamos": "polcar",
    "polcáveis": "polcar",
    "poldra": "poldro",
    "poldras": "poldro",
    "poldris": "poldril",
    "poldros": "poldro",
    "poleada": "polear",
    "poleadas": "polear",
    "poleadelas": "poleadela",
    "poleado": "polear",
    "poleados": "polear",
    "poleai": "polear",
    "poleais": "polear",
    "poleames": "poleame",
    "poleamo": "polear",
    "poleamos": "polear",
    "poleando": "polear",
    "poleara": "polear",
    "polearam": "polear",
    "polearas": "polear",
    "polearde": "polear",
    "poleardes": "polear",
    "poleare": "polear",
    "polearei": "polear",
    "poleareis": "polear",
    "polearem": "polear",
    "polearemos": "polear",
    "poleares": "polear",
    "polearia": "polear",
    "poleariam": "polear",
    "polearias": "polearia",
    "polearmo": "polear",
    "polearmos": "polear",
    "poleará": "polear",
    "polearás": "polear",
    "polearão": "polear",
    "polearíamos": "polear",
    "polearíeis": "polear",
    "poleasse": "polear",
    "poleassem": "polear",
    "poleasses": "polear",
    "poleaste": "polear",
    "poleastes": "polear",
    "poleava": "polear",
    "poleavam": "polear",
    "poleavas": "polear",
    "poleei": "polear",
    "poleeira": "poleeiro",
    "poleeiras": "poleeiro",
    "poleeiros": "poleeiro",
    "poleeis": "polear",
    "poleemo": "polear",
    "poleemos": "polear",
    "polegadas": "polegada",
    "polegares": "polegar",
    "poleia": "polear",
    "poleiam": "polear",
    "poleias": "poleia",
    "poleie": "polear",
    "poleiem": "polear",
    "poleies": "polear",
    "poleio": "polear",
    "poleiros": "poleiro",
    "polelas": "polela",
    "polemica": "polemicar",
    "polemicada": "polemicar",
    "polemicadas": "polemicar",
    "polemicado": "polemicar",
    "polemicados": "polemicar",
    "polemicai": "polemicar",
    "polemicais": "polemicar",
    "polemicam": "polemicar",
    "polemicamo": "polemicar",
    "polemicamos": "polemicar",
    "polemicando": "polemicar",
    "polemicara": "polemicar",
    "polemicaram": "polemicar",
    "polemicaras": "polemicar",
    "polemicarde": "polemicar",
    "polemicardes": "polemicar",
    "polemicare": "polemicar",
    "polemicarei": "polemicar",
    "polemicareis": "polemicar",
    "polemicarem": "polemicar",
    "polemicaremos": "polemicar",
    "polemicares": "polemicar",
    "polemicaria": "polemicar",
    "polemicariam": "polemicar",
    "polemicarias": "polemicar",
    "polemicarmo": "polemicar",
    "polemicarmos": "polemicar",
    "polemicará": "polemicar",
    "polemicarás": "polemicar",
    "polemicarão": "polemicar",
    "polemicaríamos": "polemicar",
    "polemicaríeis": "polemicar",
    "polemicas": "polemicar",
    "polemicasse": "polemicar",
    "polemicassem": "polemicar",
    "polemicasses": "polemicar",
    "polemicaste": "polemicar",
    "polemicastes": "polemicar",
    "polemicava": "polemicar",
    "polemicavam": "polemicar",
    "polemicavas": "polemicar",
    "polemico": "polemicar",
    "polemicou": "polemicar",
    "polemicá": "polemicar",
    "polemicámo": "polemicar",
    "polemicámos": "polemicar",
    "polemicáramo": "polemicar",
    "polemicáramos": "polemicar",
    "polemicárei": "polemicar",
    "polemicáreis": "polemicar",
    "polemicásseis": "polemicar",
    "polemicássemos": "polemicar",
    "polemicávamo": "polemicar",
    "polemicávamos": "polemicar",
    "polemicávei": "polemicar",
    "polemicáveis": "polemicar",
    "polemique": "polemicar",
    "polemiquei": "polemicar",
    "polemiqueis": "polemicar",
    "polemiquem": "polemicar",
    "polemiquemo": "polemicar",
    "polemiquemos": "polemicar",
    "polemiques": "polemicar",
    "polemistas": "polemista",
    "polemiza": "polemizar",
    "polemizada": "polemizar",
    "polemizadas": "polemizar",
    "polemizado": "polemizar",
    "polemizados": "polemizar",
    "polemizai": "polemizar",
    "polemizais": "polemizar",
    "polemizam": "polemizar",
    "polemizamo": "polemizar",
    "polemizamos": "polemizar",
    "polemizando": "polemizar",
    "polemizara": "polemizar",
    "polemizaram": "polemizar",
    "polemizaras": "polemizar",
    "polemizarde": "polemizar",
    "polemizardes": "polemizar",
    "polemizare": "polemizar",
    "polemizarei": "polemizar",
    "polemizareis": "polemizar",
    "polemizarem": "polemizar",
    "polemizaremos": "polemizar",
    "polemizares": "polemizar",
    "polemizaria": "polemizar",
    "polemizariam": "polemizar",
    "polemizarias": "polemizar",
    "polemizarmo": "polemizar",
    "polemizarmos": "polemizar",
    "polemizará": "polemizar",
    "polemizarás": "polemizar",
    "polemizarão": "polemizar",
    "polemizaríamos": "polemizar",
    "polemizaríeis": "polemizar",
    "polemizas": "polemizar",
    "polemizasse": "polemizar",
    "polemizassem": "polemizar",
    "polemizasses": "polemizar",
    "polemizaste": "polemizar",
    "polemizastes": "polemizar",
    "polemizava": "polemizar",
    "polemizavam": "polemizar",
    "polemizavas": "polemizar",
    "polemize": "polemizar",
    "polemizei": "polemizar",
    "polemizeis": "polemizar",
    "polemizem": "polemizar",
    "polemizemo": "polemizar",
    "polemizemos": "polemizar",
    "polemizes": "polemizar",
    "polemizo": "polemizar",
    "polemizou": "polemizar",
    "polemizá": "polemizar",
    "polemizámo": "polemizar",
    "polemizámos": "polemizar",
    "polemizáramo": "polemizar",
    "polemizáramos": "polemizar",
    "polemizárei": "polemizar",
    "polemizáreis": "polemizar",
    "polemizásseis": "polemizar",
    "polemizássemos": "polemizar",
    "polemizávamo": "polemizar",
    "polemizávamos": "polemizar",
    "polemizávei": "polemizar",
    "polemizáveis": "polemizar",
    "polemografias": "polemografia",
    "polemografistas": "polemografista",
    "polemográfica": "polemográfico",
    "polemográficas": "polemográfico",
    "polemográficos": "polemográfico",
    "polemológica": "polemológico",
    "polemológicas": "polemológico",
    "polemológicos": "polemológico",
    "polemoscópica": "polemoscópico",
    "polemoscópicas": "polemoscópico",
    "polemoscópicos": "polemoscópico",
    "polemógrafa": "polemógrafo",
    "polemógrafas": "polemógrafo",
    "polemógrafos": "polemógrafo",
    "polendas": "polenda",
    "polentas": "polenta",
    "poleou": "polear",
    "poleá": "polear",
    "poleámo": "polear",
    "poleámos": "polear",
    "poleáramo": "polear",
    "poleáramos": "polear",
    "poleárei": "polear",
    "poleáreis": "polear",
    "poleás": "poleá",
    "poleásseis": "polear",
    "poleássemos": "polear",
    "poleávamo": "polear",
    "poleávamos": "polear",
    "poleávei": "polear",
    "poleáveis": "polear",
    "polha": "polho",
    "polhas": "polho",
    "polhastros": "polhastro",
    "polhos": "polho",
    "poli": "polir",
    "polia": "polir",
    "poliacanta": "poliacanto",
    "poliacantas": "poliacanto",
    "poliacantos": "poliacanto",
    "poliadelfa": "poliadelfo",
    "poliadelfas": "poliadelfo",
    "poliadelfias": "poliadelfia",
    "poliadelfos": "poliadelfo",
    "poliadélfica": "poliadélfico",
    "poliadélficas": "poliadélfico",
    "poliadélficos": "poliadélfico",
    "poliam": "polir",
    "poliamidas": "poliamida",
    "poliamídica": "poliamídico",
    "poliamídicas": "poliamídico",
    "poliamídicos": "poliamídico",
    "poliandra": "poliandro",
    "poliandras": "poliandro",
    "poliandrias": "poliandria",
    "poliandros": "poliandro",
    "polianites": "polianite",
    "polianta": "polianto",
    "poliantas": "polianto",
    "polianteias": "polianteia",
    "poliantes": "poliante",
    "poliantos": "polianto",
    "poliaquénios": "poliaquénio",
    "poliarquias": "poliarquia",
    "poliarticulada": "poliarticulado",
    "poliarticuladas": "poliarticulado",
    "poliarticulados": "poliarticulado",
    "poliarticulares": "poliarticular",
    "poliartrites": "poliartrite",
    "poliartrítica": "poliartrítico",
    "poliartríticas": "poliartrítico",
    "poliartríticos": "poliartrítico",
    "polias": "polir",
    "poliatómica": "poliatómico",
    "poliatómicas": "poliatómico",
    "poliatómicos": "poliatómico",
    "polibásica": "polibásico",
    "polibásicas": "polibásico",
    "polibásicos": "polibásico",
    "policarpa": "policarpo",
    "policarpas": "policarpo",
    "policarpelares": "policarpelar",
    "policarpos": "policarpo",
    "policelulares": "policelular",
    "polichinelos": "polichinelo",
    "policia": "policiar",
    "policiada": "policiar",
    "policiadas": "policiar",
    "policiado": "policiar",
    "policiados": "policiar",
    "policiai": "policiar",
    "policiais": "policiar",
    "policiam": "policiar",
    "policiamentos": "policiamento",
    "policiamo": "policiar",
    "policiamos": "policiar",
    "policiando": "policiar",
    "policiara": "policiar",
    "policiaram": "policiar",
    "policiaras": "policiar",
    "policiarde": "policiar",
    "policiardes": "policiar",
    "policiare": "policiar",
    "policiarei": "policiar",
    "policiareis": "policiar",
    "policiarem": "policiar",
    "policiaremos": "policiar",
    "policiares": "policiar",
    "policiaria": "policiar",
    "policiariam": "policiar",
    "policiarias": "policiar",
    "policiarmo": "policiar",
    "policiarmos": "policiar",
    "policiará": "policiar",
    "policiarás": "policiar",
    "policiarão": "policiar",
    "policiaríamos": "policiar",
    "policiaríeis": "policiar",
    "policias": "policiar",
    "policiasse": "policiar",
    "policiassem": "policiar",
    "policiasses": "policiar",
    "policiaste": "policiar",
    "policiastes": "policiar",
    "policiava": "policiar",
    "policiavam": "policiar",
    "policiavas": "policiar",
    "policie": "policiar",
    "policiei": "policiar",
    "policieis": "policiar",
    "policiem": "policiar",
    "policiemo": "policiar",
    "policiemos": "policiar",
    "policies": "policiar",
    "policio": "policiar",
    "policiou": "policiar",
    "policitações": "policitação",
    "policiá": "policiar",
    "policiámo": "policiar",
    "policiámos": "policiar",
    "policiáramo": "policiar",
    "policiáramos": "policiar",
    "policiárei": "policiar",
    "policiáreis": "policiar",
    "policiásseis": "policiar",
    "policiássemos": "policiar",
    "policiávamo": "policiar",
    "policiávamos": "policiar",
    "policiávei": "policiar",
    "policiáveis": "policiável",
    "policlínica": "policlínico",
    "policlínicas": "policlínico",
    "policlínicos": "policlínico",
    "policresta": "policresto",
    "policrestas": "policresto",
    "policrestos": "policresto",
    "policroma": "policromo",
    "policromada": "policromado",
    "policromadas": "policromado",
    "policromados": "policromado",
    "policromas": "policromo",
    "policromias": "policromia",
    "policromos": "policromo",
    "policromática": "policromático",
    "policromáticas": "policromático",
    "policromáticos": "policromático",
    "policroísmos": "policroísmo",
    "policulturas": "policultura",
    "policurva": "policurvo",
    "policurvas": "policurvo",
    "policurvos": "policurvo",
    "policárpica": "policárpico",
    "policárpicas": "policárpico",
    "policárpicos": "policárpico",
    "policéfala": "policéfalo",
    "policéfalas": "policéfalo",
    "policéfalos": "policéfalo",
    "policêntrica": "policêntrico",
    "policêntricas": "policêntrico",
    "policêntricos": "policêntrico",
    "policíclica": "policíclico",
    "policíclicas": "policíclico",
    "policíclicos": "policíclico",
    "polida": "polir",
    "polidactilias": "polidactilia",
    "polidas": "polir",
    "polidazinha": "polido",
    "polidazinhas": "polido",
    "polidazita": "polido",
    "polidazitas": "polido",
    "polidesportiva": "polidesportivo",
    "polidesportivas": "polidesportivo",
    "polidesportivos": "polidesportivo",
    "polidesportos": "polidesporto",
    "polidezes": "polidez",
    "polidipsias": "polidipsia",
    "polido": "polir",
    "polidora": "polidor",
    "polidoras": "polidor",
    "polidores": "polidor",
    "polidos": "polir",
    "polidozinho": "polido",
    "polidozinhos": "polido",
    "polidozito": "polido",
    "polidozitos": "polido",
    "poliduras": "polidura",
    "polidáctila": "polidáctilo",
    "polidáctilas": "polidáctilo",
    "polidáctilos": "polidáctilo",
    "polidípsica": "polidípsico",
    "polidípsicas": "polidípsico",
    "polidípsicos": "polidípsico",
    "polidíssima": "polido",
    "polidíssimas": "polido",
    "polidíssimo": "polido",
    "polidíssimos": "polido",
    "poliedra": "poliedro",
    "poliedras": "poliedro",
    "poliedros": "poliedro",
    "poliembrionias": "poliembrionia",
    "poliembriónica": "poliembriónico",
    "poliembriónicas": "poliembriónico",
    "poliembriónicos": "poliembriónico",
    "poliemias": "poliemia",
    "polietilenos": "polietileno",
    "polifagias": "polifagia",
    "polifila": "polifilo",
    "polifilas": "polifilo",
    "polifilos": "polifilo",
    "polifolética": "polifolético",
    "polifoléticas": "polifolético",
    "polifoléticos": "polifolético",
    "polifonias": "polifonia",
    "polifágica": "polifágico",
    "polifágicas": "polifágico",
    "polifágicos": "polifágico",
    "polifásica": "polifásico",
    "polifásicas": "polifásico",
    "polifásicos": "polifásico",
    "polifónica": "polifónico",
    "polifónicas": "polifónico",
    "polifónicos": "polifónico",
    "polifórmica": "polifórmico",
    "polifórmicas": "polifórmico",
    "polifórmicos": "polifórmico",
    "poligaláceas": "poligalácea",
    "poligamias": "poligamia",
    "poligastra": "poligastro",
    "poligastras": "poligastro",
    "poligastricidades": "poligastricidade",
    "poligastros": "poligastro",
    "poligenismos": "poligenismo",
    "poligenistas": "poligenista",
    "poliginias": "poliginia",
    "poliglota": "poligloto",
    "poliglotas": "poligloto",
    "poliglotismos": "poliglotismo",
    "poliglotistas": "poliglotista",
    "poliglotos": "poligloto",
    "poliglótica": "poliglótico",
    "poliglóticas": "poliglótico",
    "poliglóticos": "poliglótico",
    "poligonais": "poligonal",
    "poligonáceas": "poligonácea",
    "poligrafias": "poligrafia",
    "poligráfica": "poligráfico",
    "poligráficas": "poligráfico",
    "poligráficos": "poligráfico",
    "poligástrica": "poligástrico",
    "poligástricas": "poligástrico",
    "poligástricos": "poligástrico",
    "poligâmicas": "poligâmica",
    "poligénica": "poligénico",
    "poligénicas": "poligénico",
    "poligénicos": "poligénico",
    "poligínica": "poligínico",
    "poligínicas": "poligínico",
    "poligínicos": "poligínico",
    "polilhas": "polilha",
    "polimastias": "polimastia",
    "polimatias": "polimatia",
    "polimentos": "polimento",
    "polimerias": "polimeria",
    "polimerismos": "polimerismo",
    "polimeriza": "polimerizar",
    "polimerizada": "polimerizar",
    "polimerizadas": "polimerizar",
    "polimerizado": "polimerizar",
    "polimerizados": "polimerizar",
    "polimerizai": "polimerizar",
    "polimerizais": "polimerizar",
    "polimerizam": "polimerizar",
    "polimerizamo": "polimerizar",
    "polimerizamos": "polimerizar",
    "polimerizando": "polimerizar",
    "polimerizara": "polimerizar",
    "polimerizaram": "polimerizar",
    "polimerizaras": "polimerizar",
    "polimerizarde": "polimerizar",
    "polimerizardes": "polimerizar",
    "polimerizare": "polimerizar",
    "polimerizarei": "polimerizar",
    "polimerizareis": "polimerizar",
    "polimerizarem": "polimerizar",
    "polimerizaremos": "polimerizar",
    "polimerizares": "polimerizar",
    "polimerizaria": "polimerizar",
    "polimerizariam": "polimerizar",
    "polimerizarias": "polimerizar",
    "polimerizarmo": "polimerizar",
    "polimerizarmos": "polimerizar",
    "polimerizará": "polimerizar",
    "polimerizarás": "polimerizar",
    "polimerizarão": "polimerizar",
    "polimerizaríamos": "polimerizar",
    "polimerizaríeis": "polimerizar",
    "polimerizas": "polimerizar",
    "polimerizasse": "polimerizar",
    "polimerizassem": "polimerizar",
    "polimerizasses": "polimerizar",
    "polimerizaste": "polimerizar",
    "polimerizastes": "polimerizar",
    "polimerizava": "polimerizar",
    "polimerizavam": "polimerizar",
    "polimerizavas": "polimerizar",
    "polimerizações": "polimerização",
    "polimerize": "polimerizar",
    "polimerizei": "polimerizar",
    "polimerizeis": "polimerizar",
    "polimerizem": "polimerizar",
    "polimerizemo": "polimerizar",
    "polimerizemos": "polimerizar",
    "polimerizes": "polimerizar",
    "polimerizo": "polimerizar",
    "polimerizou": "polimerizar",
    "polimerizá": "polimerizar",
    "polimerizámo": "polimerizar",
    "polimerizámos": "polimerizar",
    "polimerizáramo": "polimerizar",
    "polimerizáramos": "polimerizar",
    "polimerizárei": "polimerizar",
    "polimerizáreis": "polimerizar",
    "polimerizásseis": "polimerizar",
    "polimerizássemos": "polimerizar",
    "polimerizávamo": "polimerizar",
    "polimerizávamos": "polimerizar",
    "polimerizávei": "polimerizar",
    "polimerizáveis": "polimerizar",
    "polimetrias": "polimetria",
    "polimo": "polir",
    "polimorfa": "polimorfo",
    "polimorfas": "polimorfo",
    "polimorfias": "polimorfia",
    "polimorfismos": "polimorfismo",
    "polimorfos": "polimorfo",
    "polimos": "polir",
    "polimástica": "polimástico",
    "polimásticas": "polimástico",
    "polimásticos": "polimástico",
    "polimática": "polimático",
    "polimáticas": "polimático",
    "polimáticos": "polimático",
    "polimérica": "polimérico",
    "poliméricas": "polimérico",
    "poliméricos": "polimérico",
    "polimórfica": "polimórfico",
    "polimórficas": "polimórfico",
    "polimórficos": "polimórfico",
    "polindo": "polir",
    "polinervada": "polinervado",
    "polinervadas": "polinervado",
    "polinervados": "polinervado",
    "poliniza": "polinizar",
    "polinizada": "polinizar",
    "polinizadas": "polinizar",
    "polinizado": "polinizar",
    "polinizadora": "polinizador",
    "polinizadoras": "polinizador",
    "polinizadores": "polinizador",
    "polinizados": "polinizar",
    "polinizai": "polinizar",
    "polinizais": "polinizar",
    "polinizam": "polinizar",
    "polinizamo": "polinizar",
    "polinizamos": "polinizar",
    "polinizando": "polinizar",
    "polinizara": "polinizar",
    "polinizaram": "polinizar",
    "polinizaras": "polinizar",
    "polinizarde": "polinizar",
    "polinizardes": "polinizar",
    "polinizare": "polinizar",
    "polinizarei": "polinizar",
    "polinizareis": "polinizar",
    "polinizarem": "polinizar",
    "polinizaremos": "polinizar",
    "polinizares": "polinizar",
    "polinizaria": "polinizar",
    "polinizariam": "polinizar",
    "polinizarias": "polinizar",
    "polinizarmo": "polinizar",
    "polinizarmos": "polinizar",
    "polinizará": "polinizar",
    "polinizarás": "polinizar",
    "polinizarão": "polinizar",
    "polinizaríamos": "polinizar",
    "polinizaríeis": "polinizar",
    "polinizas": "polinizar",
    "polinizasse": "polinizar",
    "polinizassem": "polinizar",
    "polinizasses": "polinizar",
    "polinizaste": "polinizar",
    "polinizastes": "polinizar",
    "polinizava": "polinizar",
    "polinizavam": "polinizar",
    "polinizavas": "polinizar",
    "polinizações": "polinização",
    "polinize": "polinizar",
    "polinizei": "polinizar",
    "polinizeis": "polinizar",
    "polinizem": "polinizar",
    "polinizemo": "polinizar",
    "polinizemos": "polinizar",
    "polinizes": "polinizar",
    "polinizo": "polinizar",
    "polinizou": "polinizar",
    "polinizá": "polinizar",
    "polinizámo": "polinizar",
    "polinizámos": "polinizar",
    "polinizáramo": "polinizar",
    "polinizáramos": "polinizar",
    "polinizárei": "polinizar",
    "polinizáreis": "polinizar",
    "polinizásseis": "polinizar",
    "polinizássemos": "polinizar",
    "polinizávamo": "polinizar",
    "polinizávamos": "polinizar",
    "polinizávei": "polinizar",
    "polinizáveis": "polinizável",
    "polinomiais": "polinomial",
    "polinosa": "polinoso",
    "polinosas": "polinoso",
    "polinosos": "polinoso",
    "polinsaturada": "polinsaturado",
    "polinsaturadas": "polinsaturado",
    "polinsaturados": "polinsaturado",
    "polinucleada": "polinucleado",
    "polinucleadas": "polinucleado",
    "polinucleados": "polinucleado",
    "polinucleares": "polinuclear",
    "polinésia": "polinésio",
    "polinésias": "polinésio",
    "polinésica": "polinésico",
    "polinésicas": "polinésico",
    "polinésicos": "polinésico",
    "polinésios": "polinésio",
    "polinífera": "polinífero",
    "poliníferas": "polinífero",
    "poliníferos": "polinífero",
    "polinómica": "polinómico",
    "polinómicas": "polinómico",
    "polinómicos": "polinómico",
    "polinómios": "polinómio",
    "poliomelítica": "poliomelítico",
    "poliomelíticas": "poliomelítico",
    "poliomelíticos": "poliomelítico",
    "poliomielites": "poliomielite",
    "poliopsias": "poliopsia",
    "polioses": "poliose",
    "polipeiros": "polipeiro",
    "polipeptídica": "polipeptídico",
    "polipeptídicas": "polipeptídico",
    "polipeptídicos": "polipeptídico",
    "polipeptídios": "polipeptídio",
    "poliplóides": "poliplóide",
    "poliplóidica": "poliplóidico",
    "poliplóidicas": "poliplóidico",
    "poliplóidicos": "poliplóidico",
    "polipneias": "polipneia",
    "polipneica": "polipneico",
    "polipneicas": "polipneico",
    "polipneicos": "polipneico",
    "polipodiáceas": "polipodiácea",
    "poliporáceas": "poliporácea",
    "polipos": "polipo",
    "poliposa": "poliposo",
    "poliposas": "poliposo",
    "poliposos": "poliposo",
    "polipropilenos": "polipropileno",
    "poliptotos": "poliptoto",
    "poliptéridas": "poliptérida",
    "poliptótones": "poliptóton",
    "poliptótons": "poliptóton",
    "polipétala": "polipétalo",
    "polipétalas": "polipétalo",
    "polipétalos": "polipétalo",
    "polipódios": "polipódio",
    "poliquenta": "poliquento",
    "poliquentas": "poliquento",
    "poliquentos": "poliquento",
    "poliquetas": "poliqueta",
    "polira": "polir",
    "poliram": "polir",
    "poliras": "polir",
    "polirde": "polir",
    "polirdes": "polir",
    "polire": "polir",
    "polirei": "polir",
    "polireis": "polir",
    "polirem": "polir",
    "poliremos": "polir",
    "polires": "polir",
    "poliria": "polir",
    "poliriam": "polir",
    "polirias": "polir",
    "polirmo": "polir",
    "polirmos": "polir",
    "polirremes": "polirreme",
    "polirriza": "polirrizo",
    "polirrizas": "polirrizo",
    "polirrizos": "polirrizo",
    "polirrítmica": "polirrítmico",
    "polirrítmicas": "polirrítmico",
    "polirrítmicos": "polirrítmico",
    "polirá": "polir",
    "polirás": "polir",
    "polirão": "polir",
    "poliríamos": "polir",
    "poliríeis": "polir",
    "polis": "polir",
    "polisarcias": "polisarcia",
    "polisperma": "polispermo",
    "polispermas": "polispermo",
    "polispermias": "polispermia",
    "polispermos": "polispermo",
    "polispérmica": "polispérmico",
    "polispérmicas": "polispérmico",
    "polispérmicos": "polispérmico",
    "polissacarídea": "polissacarídeo",
    "polissacarídeas": "polissacarídeo",
    "polissacarídeos": "polissacarídeo",
    "polissacárida": "polissacárido",
    "polissacáridas": "polissacárido",
    "polissacáridos": "polissacárido",
    "polissarcarídios": "polissarcarídio",
    "polisse": "polir",
    "polissem": "polir",
    "polissemias": "polissemia",
    "polisses": "polir",
    "polissidáctila": "polissidáctilo",
    "polissidáctilas": "polissidáctilo",
    "polissidáctilos": "polissidáctilo",
    "polissifónias": "polissifónia",
    "polissifónica": "polissifónico",
    "polissifónicas": "polissifónico",
    "polissifónicos": "polissifónico",
    "polissilogismos": "polissilogismo",
    "polissilogística": "polissilogístico",
    "polissilogísticas": "polissilogístico",
    "polissilogísticos": "polissilogístico",
    "polissilábica": "polissilábico",
    "polissilábicas": "polissilábico",
    "polissilábicos": "polissilábico",
    "polissindáctilos": "polissindáctilo",
    "polissindética": "polissindético",
    "polissindéticas": "polissindético",
    "polissindéticos": "polissindético",
    "polissintetismos": "polissintetismo",
    "polissintética": "polissintético",
    "polissintéticas": "polissintético",
    "polissintéticos": "polissintético",
    "polissárcica": "polissárcico",
    "polissárcicas": "polissárcico",
    "polissárcicos": "polissárcico",
    "polissémica": "polissémico",
    "polissémicas": "polissémico",
    "polissémicos": "polissémico",
    "polissépalos": "polissépalo",
    "polissílaba": "polissílabo",
    "polissílabas": "polissílabo",
    "polissílabos": "polissílabo",
    "polissíndetones": "polissíndeton",
    "polissíndetons": "polissíndeton",
    "polissíndetos": "polissíndeto",
    "polissínteses": "polissíntese",
    "poliste": "polir",
    "polistes": "polir",
    "polistila": "polistilo",
    "polistilas": "polistilo",
    "polistilos": "polistilo",
    "polistirenos": "polistireno",
    "polistélica": "polistélico",
    "polistélicas": "polistélico",
    "polistélicos": "polistélico",
    "polistómia": "polistómio",
    "polistómias": "polistómio",
    "polistómios": "polistómio",
    "politeamas": "politeama",
    "politelismos": "politelismo",
    "politelística": "politelístico",
    "politelísticas": "politelístico",
    "politelísticos": "politelístico",
    "politenos": "politeno",
    "politeísmos": "politeísmo",
    "politeístas": "politeísta",
    "politica": "politicar",
    "politicada": "politicar",
    "politicadas": "politicar",
    "politicado": "politicar",
    "politicados": "politicar",
    "politicagens": "politicagem",
    "politicai": "politicar",
    "politicais": "politicar",
    "politicalhas": "politicalha",
    "politicam": "politicar",
    "politicamo": "politicar",
    "politicamos": "politicar",
    "politicando": "politicar",
    "politicantes": "politicante",
    "politicara": "politicar",
    "politicaram": "politicar",
    "politicaras": "politicar",
    "politicarde": "politicar",
    "politicardes": "politicar",
    "politicare": "politicar",
    "politicarei": "politicar",
    "politicareis": "politicar",
    "politicarem": "politicar",
    "politicaremos": "politicar",
    "politicares": "politicar",
    "politicaria": "politicar",
    "politicariam": "politicar",
    "politicarias": "politicar",
    "politicarmo": "politicar",
    "politicarmos": "politicar",
    "politicará": "politicar",
    "politicarás": "politicar",
    "politicarão": "politicar",
    "politicaríamos": "politicar",
    "politicaríeis": "politicar",
    "politicas": "politicar",
    "politicasse": "politicar",
    "politicassem": "politicar",
    "politicasses": "politicar",
    "politicaste": "politicar",
    "politicastes": "politicar",
    "politicastra": "politicastro",
    "politicastras": "politicastro",
    "politicastros": "politicastro",
    "politicava": "politicar",
    "politicavam": "politicar",
    "politicavas": "politicar",
    "politico": "politicar",
    "politicomanias": "politicomania",
    "politicomaníaca": "politicomaníaco",
    "politicomaníacas": "politicomaníaco",
    "politicomaníacos": "politicomaníaco",
    "politicona": "politicão",
    "politiconas": "politicão",
    "politicotes": "politicote",
    "politicou": "politicar",
    "politicá": "politicar",
    "politicámo": "politicar",
    "politicámos": "politicar",
    "politicáramo": "politicar",
    "politicáramos": "politicar",
    "politicárei": "politicar",
    "politicáreis": "politicar",
    "politicásseis": "politicar",
    "politicássemos": "politicar",
    "politicávamo": "politicar",
    "politicávamos": "politicar",
    "politicávei": "politicar",
    "politicáveis": "politicar",
    "politicóides": "politicóide",
    "politicómana": "politicómano",
    "politicómanas": "politicómano",
    "politicómanos": "politicómano",
    "politicões": "politicão",
    "politique": "politicar",
    "politiquei": "politicar",
    "politiqueira": "politiqueiro",
    "politiqueiras": "politiqueiro",
    "politiqueiros": "politiqueiro",
    "politiqueis": "politicar",
    "politiquem": "politicar",
    "politiquemo": "politicar",
    "politiquemos": "politicar",
    "politiques": "politicar",
    "politiquetes": "politiquete",
    "politiquices": "politiquice",
    "politiquismos": "politiquismo",
    "politiza": "politizar",
    "politizada": "politizar",
    "politizadas": "politizar",
    "politizado": "politizar",
    "politizados": "politizar",
    "politizai": "politizar",
    "politizais": "politizar",
    "politizam": "politizar",
    "politizamo": "politizar",
    "politizamos": "politizar",
    "politizando": "politizar",
    "politizara": "politizar",
    "politizaram": "politizar",
    "politizaras": "politizar",
    "politizarde": "politizar",
    "politizardes": "politizar",
    "politizare": "politizar",
    "politizarei": "politizar",
    "politizareis": "politizar",
    "politizarem": "politizar",
    "politizaremos": "politizar",
    "politizares": "politizar",
    "politizaria": "politizar",
    "politizariam": "politizar",
    "politizarias": "politizar",
    "politizarmo": "politizar",
    "politizarmos": "politizar",
    "politizará": "politizar",
    "politizarás": "politizar",
    "politizarão": "politizar",
    "politizaríamos": "politizar",
    "politizaríeis": "politizar",
    "politizas": "politizar",
    "politizasse": "politizar",
    "politizassem": "politizar",
    "politizasses": "politizar",
    "politizaste": "politizar",
    "politizastes": "politizar",
    "politizava": "politizar",
    "politizavam": "politizar",
    "politizavas": "politizar",
    "politizações": "politização",
    "politize": "politizar",
    "politizei": "politizar",
    "politizeis": "politizar",
    "politizem": "politizar",
    "politizemo": "politizar",
    "politizemos": "politizar",
    "politizes": "politizar",
    "politizo": "politizar",
    "politizou": "politizar",
    "politizá": "politizar",
    "politizámo": "politizar",
    "politizámos": "politizar",
    "politizáramo": "politizar",
    "politizáramos": "politizar",
    "politizárei": "politizar",
    "politizáreis": "politizar",
    "politizásseis": "politizar",
    "politizássemos": "politizar",
    "politizávamo": "politizar",
    "politizávamos": "politizar",
    "politizávei": "politizar",
    "politizáveis": "politizar",
    "politonais": "politonal",
    "politonalidades": "politonalidade",
    "politraumatismos": "politraumatismo",
    "politraumatizada": "politraumatizado",
    "politraumatizadas": "politraumatizado",
    "politraumatizados": "politraumatizado",
    "politricáceas": "politricácea",
    "politrofias": "politrofia",
    "politrófica": "politrófico",
    "politróficas": "politrófico",
    "politróficos": "politrófico",
    "politécnica": "politécnico",
    "politécnicas": "politécnico",
    "politécnicos": "politécnico",
    "politóloga": "politólogo",
    "politólogas": "politólogo",
    "politólogos": "politólogo",
    "poliu": "polir",
    "polivalentes": "polivalente",
    "polivalves": "polivalve",
    "polivalências": "polivalência",
    "poliárquica": "poliárquico",
    "poliárquicas": "poliárquico",
    "poliárquicos": "poliárquico",
    "poliândrias": "poliândria",
    "poliândrica": "poliândrico",
    "poliândricas": "poliândrico",
    "poliândricos": "poliândrico",
    "poliédrica": "poliédrico",
    "poliédricas": "poliédrico",
    "poliédricos": "poliédrico",
    "poliénica": "poliénico",
    "poliénicas": "poliénico",
    "poliénicos": "poliénico",
    "poliésteres": "poliéster",
    "poliónima": "poliónimo",
    "poliónimas": "poliónimo",
    "poliónimos": "poliónimo",
    "poliópica": "poliópico",
    "poliópicas": "poliópico",
    "poliópicos": "poliópico",
    "poliúrias": "poliúria",
    "poliúrica": "poliúrico",
    "poliúricas": "poliúrico",
    "poliúricos": "poliúrico",
    "polmes": "polme",
    "polmos": "polmo",
    "polmões": "polmão",
    "polografias": "polografia",
    "polográfica": "polográfico",
    "polográficas": "polográfico",
    "polográficos": "polográfico",
    "polonesa": "polonês",
    "polonesas": "polonesa",
    "poloneses": "polonês",
    "polozânica": "polozânico",
    "polozânicas": "polozânico",
    "polozânicos": "polozânico",
    "polpas": "polpa",
    "polpações": "polpação",
    "polpectomias": "polpectomia",
    "polpectómica": "polpectómico",
    "polpectómicas": "polpectómico",
    "polpectómicos": "polpectómico",
    "polpuda": "polpudo",
    "polpudas": "polpudo",
    "polpudos": "polpudo",
    "polque": "polcar",
    "polquei": "polcar",
    "polqueis": "polcar",
    "polquem": "polcar",
    "polquemos": "polcar",
    "polques": "polcar",
    "polquistas": "polquista",
    "poltranazes": "poltranaz",
    "poltroeada": "poltroear",
    "poltroeadas": "poltroear",
    "poltroeado": "poltroear",
    "poltroeados": "poltroear",
    "poltroeai": "poltroear",
    "poltroeais": "poltroear",
    "poltroeamo": "poltroear",
    "poltroeamos": "poltroear",
    "poltroeando": "poltroear",
    "poltroeara": "poltroear",
    "poltroearam": "poltroear",
    "poltroearas": "poltroear",
    "poltroearde": "poltroear",
    "poltroeardes": "poltroear",
    "poltroeare": "poltroear",
    "poltroearei": "poltroear",
    "poltroeareis": "poltroear",
    "poltroearem": "poltroear",
    "poltroearemos": "poltroear",
    "poltroeares": "poltroear",
    "poltroearia": "poltroear",
    "poltroeariam": "poltroear",
    "poltroearias": "poltroear",
    "poltroearmo": "poltroear",
    "poltroearmos": "poltroear",
    "poltroeará": "poltroear",
    "poltroearás": "poltroear",
    "poltroearão": "poltroear",
    "poltroearíamos": "poltroear",
    "poltroearíeis": "poltroear",
    "poltroeasse": "poltroear",
    "poltroeassem": "poltroear",
    "poltroeasses": "poltroear",
    "poltroeaste": "poltroear",
    "poltroeastes": "poltroear",
    "poltroeava": "poltroear",
    "poltroeavam": "poltroear",
    "poltroeavas": "poltroear",
    "poltroeei": "poltroear",
    "poltroeeis": "poltroear",
    "poltroeemo": "poltroear",
    "poltroeemos": "poltroear",
    "poltroeia": "poltroear",
    "poltroeiam": "poltroear",
    "poltroeias": "poltroear",
    "poltroeie": "poltroear",
    "poltroeiem": "poltroear",
    "poltroeies": "poltroear",
    "poltroeio": "poltroear",
    "poltroeou": "poltroear",
    "poltroeá": "poltroear",
    "poltroeámo": "poltroear",
    "poltroeámos": "poltroear",
    "poltroeáramo": "poltroear",
    "poltroeáramos": "poltroear",
    "poltroeárei": "poltroear",
    "poltroeáreis": "poltroear",
    "poltroeásseis": "poltroear",
    "poltroeássemos": "poltroear",
    "poltroeávamo": "poltroear",
    "poltroeávamos": "poltroear",
    "poltroeávei": "poltroear",
    "poltroeáveis": "poltroear",
    "poltrona": "poltrão",
    "poltronarias": "poltronaria",
    "poltronas": "poltrona",
    "poltronices": "poltronice",
    "poltrões": "poltrão",
    "polua": "poluir",
    "poluais": "poluir",
    "poluam": "poluir",
    "poluamo": "poluir",
    "poluamos": "poluir",
    "poluas": "poluir",
    "poluem": "poluir",
    "poluentes": "poluente",
    "polui": "poluir",
    "poluidazinha": "poluído",
    "poluidazinhas": "poluído",
    "poluidazita": "poluído",
    "poluidazitas": "poluído",
    "poluidinha": "poluído",
    "poluidinhas": "poluído",
    "poluidinho": "poluído",
    "poluidinhos": "poluído",
    "poluidita": "poluído",
    "poluiditas": "poluído",
    "poluidito": "poluído",
    "poluiditos": "poluído",
    "poluidora": "poluidor",
    "poluidoras": "poluidor",
    "poluidores": "poluidor",
    "poluidozinho": "poluído",
    "poluidozinhos": "poluído",
    "poluidozito": "poluído",
    "poluidozitos": "poluído",
    "poluidíssima": "poluído",
    "poluidíssimas": "poluído",
    "poluidíssimo": "poluído",
    "poluidíssimos": "poluído",
    "poluindo": "poluir",
    "poluirde": "poluir",
    "poluirdes": "poluir",
    "poluirei": "poluir",
    "poluireis": "poluir",
    "poluiremos": "poluir",
    "poluiria": "poluir",
    "poluiriam": "poluir",
    "poluirias": "poluir",
    "poluirmo": "poluir",
    "poluirmos": "poluir",
    "poluirá": "poluir",
    "poluirás": "poluir",
    "poluirão": "poluir",
    "poluiríamos": "poluir",
    "poluiríeis": "poluir",
    "poluis": "poluir",
    "poluiu": "poluir",
    "poluições": "poluição",
    "poluo": "poluir",
    "poluta": "poluto",
    "polutas": "poluto",
    "polutos": "poluto",
    "poluções": "polução",
    "poluí": "poluir",
    "poluía": "poluir",
    "poluíam": "poluir",
    "poluíamo": "poluir",
    "poluíamos": "poluir",
    "poluías": "poluir",
    "poluída": "poluir",
    "poluídas": "poluir",
    "poluído": "poluir",
    "poluídos": "poluir",
    "poluíei": "poluir",
    "poluíeis": "poluir",
    "poluímo": "poluir",
    "poluímos": "poluir",
    "poluíra": "poluir",
    "poluíram": "poluir",
    "poluíramo": "poluir",
    "poluíramos": "poluir",
    "poluíras": "poluir",
    "poluíre": "poluir",
    "poluírei": "poluir",
    "poluíreis": "poluir",
    "poluírem": "poluir",
    "poluíres": "poluir",
    "poluís": "poluir",
    "poluísse": "poluir",
    "poluísseis": "poluir",
    "poluíssem": "poluir",
    "poluíssemos": "poluir",
    "poluísses": "poluir",
    "poluíste": "poluir",
    "poluístes": "poluir",
    "poluíveis": "poluível",
    "polvilha": "polvilhar",
    "polvilhada": "polvilhar",
    "polvilhadas": "polvilhar",
    "polvilhado": "polvilhar",
    "polvilhados": "polvilhar",
    "polvilhai": "polvilhar",
    "polvilhais": "polvilhar",
    "polvilham": "polvilhar",
    "polvilhamentos": "polvilhamento",
    "polvilhamo": "polvilhar",
    "polvilhamos": "polvilhar",
    "polvilhando": "polvilhar",
    "polvilhara": "polvilhar",
    "polvilharam": "polvilhar",
    "polvilharas": "polvilhar",
    "polvilharde": "polvilhar",
    "polvilhardes": "polvilhar",
    "polvilhare": "polvilhar",
    "polvilharei": "polvilhar",
    "polvilhareis": "polvilhar",
    "polvilharem": "polvilhar",
    "polvilharemos": "polvilhar",
    "polvilhares": "polvilhar",
    "polvilharia": "polvilhar",
    "polvilhariam": "polvilhar",
    "polvilharias": "polvilhar",
    "polvilharmo": "polvilhar",
    "polvilharmos": "polvilhar",
    "polvilhará": "polvilhar",
    "polvilharás": "polvilhar",
    "polvilharão": "polvilhar",
    "polvilharíamos": "polvilhar",
    "polvilharíeis": "polvilhar",
    "polvilhas": "polvilhar",
    "polvilhasse": "polvilhar",
    "polvilhassem": "polvilhar",
    "polvilhasses": "polvilhar",
    "polvilhaste": "polvilhar",
    "polvilhastes": "polvilhar",
    "polvilhava": "polvilhar",
    "polvilhavam": "polvilhar",
    "polvilhavas": "polvilhar",
    "polvilhações": "polvilhação",
    "polvilhe": "polvilhar",
    "polvilhei": "polvilhar",
    "polvilheis": "polvilhar",
    "polvilhem": "polvilhar",
    "polvilhemo": "polvilhar",
    "polvilhemos": "polvilhar",
    "polvilhes": "polvilhar",
    "polvilho": "polvilhar",
    "polvilhos": "polvilho",
    "polvilhou": "polvilhar",
    "polvilhá": "polvilhar",
    "polvilhámo": "polvilhar",
    "polvilhámos": "polvilhar",
    "polvilháramo": "polvilhar",
    "polvilháramos": "polvilhar",
    "polvilhárei": "polvilhar",
    "polvilháreis": "polvilhar",
    "polvilhásseis": "polvilhar",
    "polvilhássemos": "polvilhar",
    "polvilhávamo": "polvilhar",
    "polvilhávamos": "polvilhar",
    "polvilhávei": "polvilhar",
    "polvilháveis": "polvilhar",
    "polvoradas": "polvorada",
    "polvorarias": "polvoraria",
    "polvoreira": "polvoreiro",
    "polvoreiras": "polvoreiro",
    "polvoreiros": "polvoreiro",
    "polvorenta": "polvorento",
    "polvorentas": "polvorento",
    "polvorentos": "polvorento",
    "polvorinhos": "polvorinho",
    "polvorins": "polvorim",
    "polvoristas": "polvorista",
    "polvoriza": "polvorizar",
    "polvorizada": "polvorizar",
    "polvorizadas": "polvorizar",
    "polvorizado": "polvorizar",
    "polvorizados": "polvorizar",
    "polvorizai": "polvorizar",
    "polvorizais": "polvorizar",
    "polvorizam": "polvorizar",
    "polvorizamo": "polvorizar",
    "polvorizamos": "polvorizar",
    "polvorizando": "polvorizar",
    "polvorizara": "polvorizar",
    "polvorizaram": "polvorizar",
    "polvorizaras": "polvorizar",
    "polvorizarde": "polvorizar",
    "polvorizardes": "polvorizar",
    "polvorizare": "polvorizar",
    "polvorizarei": "polvorizar",
    "polvorizareis": "polvorizar",
    "polvorizarem": "polvorizar",
    "polvorizaremos": "polvorizar",
    "polvorizares": "polvorizar",
    "polvorizaria": "polvorizar",
    "polvorizariam": "polvorizar",
    "polvorizarias": "polvorizar",
    "polvorizarmo": "polvorizar",
    "polvorizarmos": "polvorizar",
    "polvorizará": "polvorizar",
    "polvorizarás": "polvorizar",
    "polvorizarão": "polvorizar",
    "polvorizaríamos": "polvorizar",
    "polvorizaríeis": "polvorizar",
    "polvorizas": "polvorizar",
    "polvorizasse": "polvorizar",
    "polvorizassem": "polvorizar",
    "polvorizasses": "polvorizar",
    "polvorizaste": "polvorizar",
    "polvorizastes": "polvorizar",
    "polvorizava": "polvorizar",
    "polvorizavam": "polvorizar",
    "polvorizavas": "polvorizar",
    "polvorize": "polvorizar",
    "polvorizei": "polvorizar",
    "polvorizeis": "polvorizar",
    "polvorizem": "polvorizar",
    "polvorizemo": "polvorizar",
    "polvorizemos": "polvorizar",
    "polvorizes": "polvorizar",
    "polvorizo": "polvorizar",
    "polvorizou": "polvorizar",
    "polvorizá": "polvorizar",
    "polvorizámo": "polvorizar",
    "polvorizámos": "polvorizar",
    "polvorizáramo": "polvorizar",
    "polvorizáramos": "polvorizar",
    "polvorizárei": "polvorizar",
    "polvorizáreis": "polvorizar",
    "polvorizásseis": "polvorizar",
    "polvorizássemos": "polvorizar",
    "polvorizávamo": "polvorizar",
    "polvorizávamos": "polvorizar",
    "polvorizávei": "polvorizar",
    "polvorizáveis": "polvorizar",
    "polvorosa": "polvoroso",
    "polvorosas": "polvoroso",
    "polvorosos": "polvoroso",
    "polvos": "polvo",
    "polémica": "polémico",
    "polémicas": "polémico",
    "polémicos": "polémico",
    "polés": "polé",
    "políamo": "polir",
    "políamos": "polir",
    "polícias": "polícia",
    "políei": "polir",
    "políeis": "polir",
    "polífaga": "polífago",
    "polífagas": "polífago",
    "polífagos": "polífago",
    "polífita": "polífito",
    "polífitas": "polífito",
    "polífitos": "polífito",
    "polífona": "polífono",
    "polífonas": "polífono",
    "polífonos": "polífono",
    "polígalas": "polígala",
    "polígama": "polígamo",
    "polígamas": "polígamo",
    "polígamos": "polígamo",
    "polígena": "polígeno",
    "polígenas": "polígeno",
    "polígenos": "polígeno",
    "polígina": "polígino",
    "políginas": "polígino",
    "políginos": "polígino",
    "polígonos": "polígono",
    "polígrafos": "polígrafo",
    "polímatas": "polímata",
    "polímates": "polímate",
    "polímera": "polímero",
    "polímeras": "polímero",
    "polímeros": "polímero",
    "polímetros": "polímetro",
    "políndroma": "políndromo",
    "políndromas": "políndromo",
    "políndromos": "políndromo",
    "polínias": "polínia",
    "polínica": "polínico",
    "polínicas": "polínico",
    "polínicos": "polínico",
    "polípodes": "polípode",
    "políptera": "políptero",
    "polípteras": "políptero",
    "polípteros": "políptero",
    "políptica": "políptico",
    "polípticas": "políptico",
    "polípticos": "políptico",
    "políramo": "polir",
    "políramos": "polir",
    "polírei": "polir",
    "políreis": "polir",
    "polísseis": "polir",
    "políssemos": "polir",
    "polístomos": "polístomo",
    "política": "político",
    "políticas": "político",
    "políticos": "político",
    "polítricos": "polítrico",
    "polítrofa": "polítrofo",
    "polítrofas": "polítrofo",
    "polítrofos": "polítrofo",
    "políveis": "polível",
    "polónia": "polónio",
    "polónias": "polónio",
    "polónios": "polónio",
    "pomadas": "pomada",
    "pomadinha": "pomada",
    "pomadinhas": "pomada",
    "pomadistas": "pomadista",
    "pomadita": "pomada",
    "pomaditas": "pomada",
    "pomaradas": "pomarada",
    "pomareira": "pomareiro",
    "pomareiras": "pomareiro",
    "pomareiros": "pomareiro",
    "pomarejos": "pomarejo",
    "pomares": "pomar",
    "pomas": "poma",
    "pomba": "pombo",
    "pombais": "pombal",
    "pombalenses": "pombalense",
    "pombalesca": "pombalesco",
    "pombalescas": "pombalesco",
    "pombalescos": "pombalesco",
    "pombalina": "pombalino",
    "pombalinas": "pombalino",
    "pombalinos": "pombalino",
    "pombalismos": "pombalismo",
    "pombalistas": "pombalista",
    "pombas": "pombo",
    "pombeada": "pombear",
    "pombeadas": "pombear",
    "pombeado": "pombear",
    "pombeados": "pombear",
    "pombeai": "pombear",
    "pombeais": "pombear",
    "pombeamo": "pombear",
    "pombeamos": "pombear",
    "pombeando": "pombear",
    "pombeara": "pombear",
    "pombearam": "pombear",
    "pombearas": "pombear",
    "pombearde": "pombear",
    "pombeardes": "pombear",
    "pombeare": "pombear",
    "pombearei": "pombear",
    "pombeareis": "pombear",
    "pombearem": "pombear",
    "pombearemos": "pombear",
    "pombeares": "pombear",
    "pombearia": "pombear",
    "pombeariam": "pombear",
    "pombearias": "pombear",
    "pombearmo": "pombear",
    "pombearmos": "pombear",
    "pombeará": "pombear",
    "pombearás": "pombear",
    "pombearão": "pombear",
    "pombearíamos": "pombear",
    "pombearíeis": "pombear",
    "pombeasse": "pombear",
    "pombeassem": "pombear",
    "pombeasses": "pombear",
    "pombeaste": "pombear",
    "pombeastes": "pombear",
    "pombeava": "pombear",
    "pombeavam": "pombear",
    "pombeavas": "pombear",
    "pombeei": "pombear",
    "pombeeis": "pombear",
    "pombeemo": "pombear",
    "pombeemos": "pombear",
    "pombeia": "pombear",
    "pombeiam": "pombear",
    "pombeias": "pombear",
    "pombeie": "pombear",
    "pombeiem": "pombear",
    "pombeies": "pombear",
    "pombeio": "pombear",
    "pombeira": "pombeiro",
    "pombeirada": "pombeirar",
    "pombeiradas": "pombeirar",
    "pombeirado": "pombeirar",
    "pombeirados": "pombeirar",
    "pombeirai": "pombeirar",
    "pombeirais": "pombeirar",
    "pombeiram": "pombeirar",
    "pombeiramo": "pombeirar",
    "pombeiramos": "pombeirar",
    "pombeirando": "pombeirar",
    "pombeirara": "pombeirar",
    "pombeiraram": "pombeirar",
    "pombeiraras": "pombeirar",
    "pombeirarde": "pombeirar",
    "pombeirardes": "pombeirar",
    "pombeirare": "pombeirar",
    "pombeirarei": "pombeirar",
    "pombeirareis": "pombeirar",
    "pombeirarem": "pombeirar",
    "pombeiraremos": "pombeirar",
    "pombeirares": "pombeirar",
    "pombeiraria": "pombeirar",
    "pombeirariam": "pombeirar",
    "pombeirarias": "pombeirar",
    "pombeirarmo": "pombeirar",
    "pombeirarmos": "pombeirar",
    "pombeirará": "pombeirar",
    "pombeirarás": "pombeirar",
    "pombeirarão": "pombeirar",
    "pombeiraríamos": "pombeirar",
    "pombeiraríeis": "pombeirar",
    "pombeiras": "pombeiro",
    "pombeirasse": "pombeirar",
    "pombeirassem": "pombeirar",
    "pombeirasses": "pombeirar",
    "pombeiraste": "pombeirar",
    "pombeirastes": "pombeirar",
    "pombeirava": "pombeirar",
    "pombeiravam": "pombeirar",
    "pombeiravas": "pombeirar",
    "pombeire": "pombeirar",
    "pombeirei": "pombeirar",
    "pombeireis": "pombeirar",
    "pombeirem": "pombeirar",
    "pombeiremo": "pombeirar",
    "pombeiremos": "pombeirar",
    "pombeires": "pombeirar",
    "pombeiro": "pombeirar",
    "pombeiros": "pombeiro",
    "pombeirou": "pombeirar",
    "pombeirá": "pombeirar",
    "pombeirámo": "pombeirar",
    "pombeirámos": "pombeirar",
    "pombeiráramo": "pombeirar",
    "pombeiráramos": "pombeirar",
    "pombeirárei": "pombeirar",
    "pombeiráreis": "pombeirar",
    "pombeirásseis": "pombeirar",
    "pombeirássemos": "pombeirar",
    "pombeirávamo": "pombeirar",
    "pombeirávamos": "pombeirar",
    "pombeirávei": "pombeirar",
    "pombeiráveis": "pombeirar",
    "pombeou": "pombear",
    "pombes": "pombe",
    "pombeá": "pombear",
    "pombeámo": "pombear",
    "pombeámos": "pombear",
    "pombeáramo": "pombear",
    "pombeáramos": "pombear",
    "pombeárei": "pombear",
    "pombeáreis": "pombear",
    "pombeásseis": "pombear",
    "pombeássemos": "pombear",
    "pombeávamo": "pombear",
    "pombeávamos": "pombear",
    "pombeávei": "pombear",
    "pombeáveis": "pombear",
    "pombinha": "pombo",
    "pombinhas": "pombo",
    "pombinho": "pombo",
    "pombinhos": "pombo",
    "pombita": "pombo",
    "pombitas": "pombo",
    "pombito": "pombo",
    "pombitos": "pombo",
    "pombos": "pombo",
    "pomicultora": "pomicultor",
    "pomicultoras": "pomicultor",
    "pomicultores": "pomicultor",
    "pomiculturas": "pomicultura",
    "pomifica": "pomificar",
    "pomificada": "pomificar",
    "pomificadas": "pomificar",
    "pomificado": "pomificar",
    "pomificados": "pomificar",
    "pomificai": "pomificar",
    "pomificais": "pomificar",
    "pomificam": "pomificar",
    "pomificamo": "pomificar",
    "pomificamos": "pomificar",
    "pomificando": "pomificar",
    "pomificara": "pomificar",
    "pomificaram": "pomificar",
    "pomificaras": "pomificar",
    "pomificarde": "pomificar",
    "pomificardes": "pomificar",
    "pomificare": "pomificar",
    "pomificarei": "pomificar",
    "pomificareis": "pomificar",
    "pomificarem": "pomificar",
    "pomificaremos": "pomificar",
    "pomificares": "pomificar",
    "pomificaria": "pomificar",
    "pomificariam": "pomificar",
    "pomificarias": "pomificar",
    "pomificarmo": "pomificar",
    "pomificarmos": "pomificar",
    "pomificará": "pomificar",
    "pomificarás": "pomificar",
    "pomificarão": "pomificar",
    "pomificaríamos": "pomificar",
    "pomificaríeis": "pomificar",
    "pomificas": "pomificar",
    "pomificasse": "pomificar",
    "pomificassem": "pomificar",
    "pomificasses": "pomificar",
    "pomificaste": "pomificar",
    "pomificastes": "pomificar",
    "pomificava": "pomificar",
    "pomificavam": "pomificar",
    "pomificavas": "pomificar",
    "pomifico": "pomificar",
    "pomificou": "pomificar",
    "pomificá": "pomificar",
    "pomificámo": "pomificar",
    "pomificámos": "pomificar",
    "pomificáramo": "pomificar",
    "pomificáramos": "pomificar",
    "pomificárei": "pomificar",
    "pomificáreis": "pomificar",
    "pomificásseis": "pomificar",
    "pomificássemos": "pomificar",
    "pomificávamo": "pomificar",
    "pomificávamos": "pomificar",
    "pomificávei": "pomificar",
    "pomificáveis": "pomificar",
    "pomifique": "pomificar",
    "pomifiquei": "pomificar",
    "pomifiqueis": "pomificar",
    "pomifiquem": "pomificar",
    "pomifiquemo": "pomificar",
    "pomifiquemos": "pomificar",
    "pomifiques": "pomificar",
    "pomiformes": "pomiforme",
    "pomitos": "pomito",
    "pomo": "pôr",
    "pomologias": "pomologia",
    "pomologistas": "pomologista",
    "pomológica": "pomológico",
    "pomológicas": "pomológico",
    "pomológicos": "pomológico",
    "pomos": "pôr",
    "pompadourismos": "pompadourismo",
    "pompadouristas": "pompadourista",
    "pompas": "pompa",
    "pompeada": "pompear",
    "pompeadas": "pompear",
    "pompeado": "pompear",
    "pompeados": "pompear",
    "pompeai": "pompear",
    "pompeais": "pompear",
    "pompeamo": "pompear",
    "pompeamos": "pompear",
    "pompeando": "pompear",
    "pompeantes": "pompeante",
    "pompeara": "pompear",
    "pompearam": "pompear",
    "pompearas": "pompear",
    "pompearde": "pompear",
    "pompeardes": "pompear",
    "pompeare": "pompear",
    "pompearei": "pompear",
    "pompeareis": "pompear",
    "pompearem": "pompear",
    "pompearemos": "pompear",
    "pompeares": "pompear",
    "pompearia": "pompear",
    "pompeariam": "pompear",
    "pompearias": "pompear",
    "pompearmo": "pompear",
    "pompearmos": "pompear",
    "pompeará": "pompear",
    "pompearás": "pompear",
    "pompearão": "pompear",
    "pompearíamos": "pompear",
    "pompearíeis": "pompear",
    "pompeasse": "pompear",
    "pompeassem": "pompear",
    "pompeasses": "pompear",
    "pompeaste": "pompear",
    "pompeastes": "pompear",
    "pompeava": "pompear",
    "pompeavam": "pompear",
    "pompeavas": "pompear",
    "pompeei": "pompear",
    "pompeeis": "pompear",
    "pompeemo": "pompear",
    "pompeemos": "pompear",
    "pompeia": "pompear",
    "pompeiam": "pompear",
    "pompeiana": "pompeiano",
    "pompeianas": "pompeiano",
    "pompeianos": "pompeiano",
    "pompeias": "pompear",
    "pompeie": "pompear",
    "pompeiem": "pompear",
    "pompeies": "pompear",
    "pompeio": "pompear",
    "pompeou": "pompear",
    "pompeá": "pompear",
    "pompeámo": "pompear",
    "pompeámos": "pompear",
    "pompeáramo": "pompear",
    "pompeáramos": "pompear",
    "pompeárei": "pompear",
    "pompeáreis": "pompear",
    "pompeásseis": "pompear",
    "pompeássemos": "pompear",
    "pompeávamo": "pompear",
    "pompeávamos": "pompear",
    "pompeávei": "pompear",
    "pompeáveis": "pompear",
    "pompons": "pompom",
    "pompos": "pompo",
    "pomposa": "pomposo",
    "pomposas": "pomposo",
    "pomposidades": "pomposidade",
    "pomposos": "pomposo",
    "pomposíssima": "pomposo",
    "pomposíssimas": "pomposo",
    "pomposíssimo": "pomposo",
    "pomposíssimos": "pomposo",
    "pomácea": "pomáceo",
    "pomáceas": "pomáceo",
    "pomáceos": "pomáceo",
    "pomícolas": "pomícola",
    "pomífera": "pomífero",
    "pomíferas": "pomífero",
    "pomíferos": "pomífero",
    "pomóloga": "pomólogo",
    "pomólogas": "pomólogo",
    "pomólogos": "pomólogo",
    "poncheiras": "poncheira",
    "ponches": "ponche",
    "ponchos": "poncho",
    "ponde": "pôr",
    "pondera": "ponderar",
    "ponderabilidades": "ponderabilidade",
    "ponderada": "ponderar",
    "ponderadas": "ponderar",
    "ponderado": "ponderar",
    "ponderadora": "ponderador",
    "ponderadoras": "ponderador",
    "ponderadores": "ponderador",
    "ponderados": "ponderar",
    "ponderadíssima": "ponderado",
    "ponderadíssimas": "ponderado",
    "ponderadíssimo": "ponderado",
    "ponderadíssimos": "ponderado",
    "ponderai": "ponderar",
    "ponderais": "ponderar",
    "ponderam": "ponderar",
    "ponderamo": "ponderar",
    "ponderamos": "ponderar",
    "ponderando": "ponderar",
    "ponderara": "ponderar",
    "ponderaram": "ponderar",
    "ponderaras": "ponderar",
    "ponderarde": "ponderar",
    "ponderardes": "ponderar",
    "ponderare": "ponderar",
    "ponderarei": "ponderar",
    "ponderareis": "ponderar",
    "ponderarem": "ponderar",
    "ponderaremos": "ponderar",
    "ponderares": "ponderar",
    "ponderaria": "ponderar",
    "ponderariam": "ponderar",
    "ponderarias": "ponderar",
    "ponderarmo": "ponderar",
    "ponderarmos": "ponderar",
    "ponderará": "ponderar",
    "ponderarás": "ponderar",
    "ponderarão": "ponderar",
    "ponderaríamos": "ponderar",
    "ponderaríeis": "ponderar",
    "ponderas": "ponderar",
    "ponderasse": "ponderar",
    "ponderassem": "ponderar",
    "ponderasses": "ponderar",
    "ponderaste": "ponderar",
    "ponderastes": "ponderar",
    "ponderativa": "ponderativo",
    "ponderativas": "ponderativo",
    "ponderativos": "ponderativo",
    "ponderava": "ponderar",
    "ponderavam": "ponderar",
    "ponderavas": "ponderar",
    "ponderaveis": "ponderavel",
    "ponderações": "ponderação",
    "pondere": "ponderar",
    "ponderei": "ponderar",
    "pondereis": "ponderar",
    "ponderem": "ponderar",
    "ponderemo": "ponderar",
    "ponderemos": "ponderar",
    "ponderes": "ponderar",
    "pondero": "ponderar",
    "ponderosa": "ponderoso",
    "ponderosas": "ponderoso",
    "ponderosos": "ponderoso",
    "ponderou": "ponderar",
    "ponderá": "ponderar",
    "ponderámo": "ponderar",
    "ponderámos": "ponderar",
    "ponderáramo": "ponderar",
    "ponderáramos": "ponderar",
    "ponderárei": "ponderar",
    "ponderáreis": "ponderar",
    "ponderásseis": "ponderar",
    "ponderássemos": "ponderar",
    "ponderávamo": "ponderar",
    "ponderávamos": "ponderar",
    "ponderávei": "ponderar",
    "ponderáveis": "ponderável",
    "pondes": "pôr",
    "pondo": "pôr",
    "pondos": "pondo",
    "pondras": "pondra",
    "ponentes": "ponente",
    "pongos": "pongo",
    "pongues": "pongue",
    "pongídeos": "pongídeo",
    "ponha": "pôr",
    "ponhais": "pôr",
    "ponham": "pôr",
    "ponhamo": "pôr",
    "ponhamos": "pôr",
    "ponhas": "pôr",
    "ponho": "pôr",
    "ponta": "pontar",
    "pontada": "pontar",
    "pontadas": "pontar",
    "pontado": "pontar",
    "pontados": "pontar",
    "pontai": "pontar",
    "pontais": "pontar",
    "pontaleta": "pontaletar",
    "pontaletada": "pontaletar",
    "pontaletadas": "pontaletar",
    "pontaletado": "pontaletar",
    "pontaletados": "pontaletar",
    "pontaletai": "pontaletar",
    "pontaletais": "pontaletar",
    "pontaletam": "pontaletar",
    "pontaletamo": "pontaletar",
    "pontaletamos": "pontaletar",
    "pontaletando": "pontaletar",
    "pontaletara": "pontaletar",
    "pontaletaram": "pontaletar",
    "pontaletaras": "pontaletar",
    "pontaletarde": "pontaletar",
    "pontaletardes": "pontaletar",
    "pontaletare": "pontaletar",
    "pontaletarei": "pontaletar",
    "pontaletareis": "pontaletar",
    "pontaletarem": "pontaletar",
    "pontaletaremos": "pontaletar",
    "pontaletares": "pontaletar",
    "pontaletaria": "pontaletar",
    "pontaletariam": "pontaletar",
    "pontaletarias": "pontaletar",
    "pontaletarmo": "pontaletar",
    "pontaletarmos": "pontaletar",
    "pontaletará": "pontaletar",
    "pontaletarás": "pontaletar",
    "pontaletarão": "pontaletar",
    "pontaletaríamos": "pontaletar",
    "pontaletaríeis": "pontaletar",
    "pontaletas": "pontaletar",
    "pontaletasse": "pontaletar",
    "pontaletassem": "pontaletar",
    "pontaletasses": "pontaletar",
    "pontaletaste": "pontaletar",
    "pontaletastes": "pontaletar",
    "pontaletava": "pontaletar",
    "pontaletavam": "pontaletar",
    "pontaletavas": "pontaletar",
    "pontalete": "pontaletar",
    "pontaletei": "pontaletar",
    "pontaleteis": "pontaletar",
    "pontaletem": "pontaletar",
    "pontaletemo": "pontaletar",
    "pontaletemos": "pontaletar",
    "pontaletes": "pontalete",
    "pontaleto": "pontaletar",
    "pontaletou": "pontaletar",
    "pontaletá": "pontaletar",
    "pontaletámo": "pontaletar",
    "pontaletámos": "pontaletar",
    "pontaletáramo": "pontaletar",
    "pontaletáramos": "pontaletar",
    "pontaletárei": "pontaletar",
    "pontaletáreis": "pontaletar",
    "pontaletásseis": "pontaletar",
    "pontaletássemos": "pontaletar",
    "pontaletávamo": "pontaletar",
    "pontaletávamos": "pontaletar",
    "pontaletávei": "pontaletar",
    "pontaletáveis": "pontaletar",
    "pontam": "pontar",
    "pontamo": "pontar",
    "pontamos": "pontar",
    "pontando": "pontar",
    "pontapea": "pontapear",
    "pontapeada": "pontapear",
    "pontapeadas": "pontapear",
    "pontapeado": "pontapear",
    "pontapeados": "pontapear",
    "pontapeai": "pontapear",
    "pontapeais": "pontapear",
    "pontapeam": "pontapear",
    "pontapeamo": "pontapear",
    "pontapeamos": "pontapear",
    "pontapeando": "pontapear",
    "pontapeara": "pontapear",
    "pontapearam": "pontapear",
    "pontapearas": "pontapear",
    "pontapearde": "pontapear",
    "pontapeardes": "pontapear",
    "pontapeare": "pontapear",
    "pontapearei": "pontapear",
    "pontapeareis": "pontapear",
    "pontapearem": "pontapear",
    "pontapearemos": "pontapear",
    "pontapeares": "pontapear",
    "pontapearia": "pontapear",
    "pontapeariam": "pontapear",
    "pontapearias": "pontapear",
    "pontapearmo": "pontapear",
    "pontapearmos": "pontapear",
    "pontapeará": "pontapear",
    "pontapearás": "pontapear",
    "pontapearão": "pontapear",
    "pontapearíamos": "pontapear",
    "pontapearíeis": "pontapear",
    "pontapeas": "pontapear",
    "pontapeasse": "pontapear",
    "pontapeassem": "pontapear",
    "pontapeasses": "pontapear",
    "pontapeaste": "pontapear",
    "pontapeastes": "pontapear",
    "pontapeava": "pontapear",
    "pontapeavam": "pontapear",
    "pontapeavas": "pontapear",
    "pontapee": "pontapear",
    "pontapeei": "pontapear",
    "pontapeeis": "pontapear",
    "pontapeem": "pontapear",
    "pontapeemo": "pontapear",
    "pontapeemos": "pontapear",
    "pontapees": "pontapear",
    "pontapeo": "pontapear",
    "pontapeou": "pontapear",
    "pontapezinho": "pontapé",
    "pontapezinhos": "pontapé",
    "pontapezito": "pontapé",
    "pontapezitos": "pontapé",
    "pontapeá": "pontapear",
    "pontapeámo": "pontapear",
    "pontapeámos": "pontapear",
    "pontapeáramo": "pontapear",
    "pontapeáramos": "pontapear",
    "pontapeárei": "pontapear",
    "pontapeáreis": "pontapear",
    "pontapeásseis": "pontapear",
    "pontapeássemos": "pontapear",
    "pontapeávamo": "pontapear",
    "pontapeávamos": "pontapear",
    "pontapeávei": "pontapear",
    "pontapeáveis": "pontapear",
    "pontapés": "pontapé",
    "pontara": "pontar",
    "pontaram": "pontar",
    "pontaras": "pontar",
    "pontarde": "pontar",
    "pontardes": "pontar",
    "pontare": "pontar",
    "pontarei": "pontar",
    "pontareis": "pontar",
    "pontarelos": "pontarelo",
    "pontarem": "pontar",
    "pontaremos": "pontar",
    "pontares": "pontar",
    "pontaria": "pontar",
    "pontariam": "pontar",
    "pontarias": "pontaria",
    "pontarmo": "pontar",
    "pontarmos": "pontar",
    "pontará": "pontar",
    "pontarás": "pontar",
    "pontarão": "pontar",
    "pontaríamos": "pontar",
    "pontaríeis": "pontar",
    "pontas": "pontar",
    "pontasse": "pontar",
    "pontassem": "pontar",
    "pontasses": "pontar",
    "pontaste": "pontar",
    "pontastes": "pontar",
    "pontava": "pontar",
    "pontavam": "pontar",
    "pontavantes": "pontavante",
    "pontavas": "pontar",
    "ponte": "pontar",
    "ponteada": "pontear",
    "ponteadas": "pontear",
    "ponteado": "pontear",
    "ponteados": "pontear",
    "ponteaguda": "ponteagudo",
    "ponteagudas": "ponteagudo",
    "ponteagudos": "ponteagudo",
    "ponteai": "pontear",
    "ponteais": "pontear",
    "ponteamo": "pontear",
    "ponteamos": "pontear",
    "ponteando": "pontear",
    "ponteara": "pontear",
    "pontearam": "pontear",
    "pontearas": "pontear",
    "pontearde": "pontear",
    "ponteardes": "pontear",
    "ponteare": "pontear",
    "pontearei": "pontear",
    "ponteareis": "pontear",
    "pontearem": "pontear",
    "pontearemos": "pontear",
    "ponteares": "pontear",
    "pontearia": "pontear",
    "ponteariam": "pontear",
    "pontearias": "pontear",
    "pontearmo": "pontear",
    "pontearmos": "pontear",
    "ponteará": "pontear",
    "pontearás": "pontear",
    "pontearão": "pontear",
    "pontearíamos": "pontear",
    "pontearíeis": "pontear",
    "ponteasse": "pontear",
    "ponteassem": "pontear",
    "ponteasses": "pontear",
    "ponteaste": "pontear",
    "ponteastes": "pontear",
    "ponteava": "pontear",
    "ponteavam": "pontear",
    "ponteavas": "pontear",
    "pontecos": "ponteco",
    "ponteei": "pontear",
    "ponteeis": "pontear",
    "ponteemo": "pontear",
    "ponteemos": "pontear",
    "pontei": "pontar",
    "ponteia": "pontear",
    "ponteiam": "pontear",
    "ponteias": "pontear",
    "ponteie": "pontear",
    "ponteiem": "pontear",
    "ponteies": "pontear",
    "ponteio": "pontear",
    "ponteira": "ponteiro",
    "ponteiras": "ponteiro",
    "ponteiros": "ponteiro",
    "ponteis": "pontar",
    "pontem": "pontar",
    "pontemo": "pontar",
    "pontemos": "pontar",
    "ponteou": "pontear",
    "pontes": "ponte",
    "pontezinha": "ponte",
    "pontezinhas": "ponte",
    "pontezita": "ponte",
    "pontezitas": "ponte",
    "ponteá": "pontear",
    "ponteámo": "pontear",
    "ponteámos": "pontear",
    "ponteáramo": "pontear",
    "ponteáramos": "pontear",
    "ponteárei": "pontear",
    "ponteáreis": "pontear",
    "ponteásseis": "pontear",
    "ponteássemos": "pontear",
    "ponteávamo": "pontear",
    "ponteávamos": "pontear",
    "ponteávei": "pontear",
    "ponteáveis": "pontear",
    "pontiaguda": "pontiagudo",
    "pontiagudas": "pontiagudo",
    "pontiagudos": "pontiagudo",
    "pontianos": "pontiano",
    "ponticidades": "ponticidade",
    "ponticula": "ponticular",
    "ponticulada": "ponticular",
    "ponticuladas": "ponticular",
    "ponticulado": "ponticular",
    "ponticulados": "ponticular",
    "ponticulai": "ponticular",
    "ponticulais": "ponticular",
    "ponticulam": "ponticular",
    "ponticulamo": "ponticular",
    "ponticulamos": "ponticular",
    "ponticulando": "ponticular",
    "ponticulara": "ponticular",
    "ponticularam": "ponticular",
    "ponticularas": "ponticular",
    "ponticularde": "ponticular",
    "ponticulardes": "ponticular",
    "ponticulare": "ponticular",
    "ponticularei": "ponticular",
    "ponticulareis": "ponticular",
    "ponticularem": "ponticular",
    "ponticularemos": "ponticular",
    "ponticulares": "ponticular",
    "ponticularia": "ponticular",
    "ponticulariam": "ponticular",
    "ponticularias": "ponticular",
    "ponticularmo": "ponticular",
    "ponticularmos": "ponticular",
    "ponticulará": "ponticular",
    "ponticularás": "ponticular",
    "ponticularão": "ponticular",
    "ponticularíamos": "ponticular",
    "ponticularíeis": "ponticular",
    "ponticulas": "ponticular",
    "ponticulasse": "ponticular",
    "ponticulassem": "ponticular",
    "ponticulasses": "ponticular",
    "ponticulaste": "ponticular",
    "ponticulastes": "ponticular",
    "ponticulava": "ponticular",
    "ponticulavam": "ponticular",
    "ponticulavas": "ponticular",
    "ponticule": "ponticular",
    "ponticulei": "ponticular",
    "ponticuleis": "ponticular",
    "ponticulem": "ponticular",
    "ponticulemo": "ponticular",
    "ponticulemos": "ponticular",
    "ponticules": "ponticular",
    "ponticulo": "ponticular",
    "ponticulou": "ponticular",
    "ponticulá": "ponticular",
    "ponticulámo": "ponticular",
    "ponticulámos": "ponticular",
    "ponticuláramo": "ponticular",
    "ponticuláramos": "ponticular",
    "ponticulárei": "ponticular",
    "ponticuláreis": "ponticular",
    "ponticulásseis": "ponticular",
    "ponticulássemos": "ponticular",
    "ponticulávamo": "ponticular",
    "ponticulávamos": "ponticular",
    "ponticulávei": "ponticular",
    "ponticuláveis": "ponticular",
    "pontifica": "pontificar",
    "pontificada": "pontificar",
    "pontificadas": "pontificar",
    "pontificado": "pontificar",
    "pontificados": "pontificar",
    "pontificai": "pontificar",
    "pontificais": "pontificar",
    "pontificam": "pontificar",
    "pontificamo": "pontificar",
    "pontificamos": "pontificar",
    "pontificando": "pontificar",
    "pontificantes": "pontificante",
    "pontificara": "pontificar",
    "pontificaram": "pontificar",
    "pontificaras": "pontificar",
    "pontificarde": "pontificar",
    "pontificardes": "pontificar",
    "pontificare": "pontificar",
    "pontificarei": "pontificar",
    "pontificareis": "pontificar",
    "pontificarem": "pontificar",
    "pontificaremos": "pontificar",
    "pontificares": "pontificar",
    "pontificaria": "pontificar",
    "pontificariam": "pontificar",
    "pontificarias": "pontificar",
    "pontificarmo": "pontificar",
    "pontificarmos": "pontificar",
    "pontificará": "pontificar",
    "pontificarás": "pontificar",
    "pontificarão": "pontificar",
    "pontificaríamos": "pontificar",
    "pontificaríeis": "pontificar",
    "pontificas": "pontificar",
    "pontificasse": "pontificar",
    "pontificassem": "pontificar",
    "pontificasses": "pontificar",
    "pontificaste": "pontificar",
    "pontificastes": "pontificar",
    "pontificava": "pontificar",
    "pontificavam": "pontificar",
    "pontificavas": "pontificar",
    "pontificações": "pontificação",
    "pontifico": "pontificar",
    "pontificou": "pontificar",
    "pontificá": "pontificar",
    "pontificámo": "pontificar",
    "pontificámos": "pontificar",
    "pontificáramo": "pontificar",
    "pontificáramos": "pontificar",
    "pontificárei": "pontificar",
    "pontificáreis": "pontificar",
    "pontificásseis": "pontificar",
    "pontificássemos": "pontificar",
    "pontificávamo": "pontificar",
    "pontificávamos": "pontificar",
    "pontificávei": "pontificar",
    "pontificáveis": "pontificar",
    "pontifique": "pontificar",
    "pontifiquei": "pontificar",
    "pontifiqueis": "pontificar",
    "pontifiquem": "pontificar",
    "pontifiquemo": "pontificar",
    "pontifiquemos": "pontificar",
    "pontifiques": "pontificar",
    "pontifícia": "pontifício",
    "pontifícias": "pontifício",
    "pontifícios": "pontifício",
    "pontilha": "pontilhar",
    "pontilhada": "pontilhar",
    "pontilhadas": "pontilhar",
    "pontilhado": "pontilhar",
    "pontilhados": "pontilhar",
    "pontilhai": "pontilhar",
    "pontilhais": "pontilhar",
    "pontilham": "pontilhar",
    "pontilhamo": "pontilhar",
    "pontilhamos": "pontilhar",
    "pontilhando": "pontilhar",
    "pontilhara": "pontilhar",
    "pontilharam": "pontilhar",
    "pontilharas": "pontilhar",
    "pontilharde": "pontilhar",
    "pontilhardes": "pontilhar",
    "pontilhare": "pontilhar",
    "pontilharei": "pontilhar",
    "pontilhareis": "pontilhar",
    "pontilharem": "pontilhar",
    "pontilharemos": "pontilhar",
    "pontilhares": "pontilhar",
    "pontilharia": "pontilhar",
    "pontilhariam": "pontilhar",
    "pontilharias": "pontilhar",
    "pontilharmo": "pontilhar",
    "pontilharmos": "pontilhar",
    "pontilhará": "pontilhar",
    "pontilharás": "pontilhar",
    "pontilharão": "pontilhar",
    "pontilharíamos": "pontilhar",
    "pontilharíeis": "pontilhar",
    "pontilhas": "pontilhar",
    "pontilhasse": "pontilhar",
    "pontilhassem": "pontilhar",
    "pontilhasses": "pontilhar",
    "pontilhaste": "pontilhar",
    "pontilhastes": "pontilhar",
    "pontilhava": "pontilhar",
    "pontilhavam": "pontilhar",
    "pontilhavas": "pontilhar",
    "pontilhações": "pontilhação",
    "pontilhe": "pontilhar",
    "pontilhei": "pontilhar",
    "pontilheira": "pontilheiro",
    "pontilheiras": "pontilheiro",
    "pontilheiros": "pontilheiro",
    "pontilheis": "pontilhar",
    "pontilhem": "pontilhar",
    "pontilhemo": "pontilhar",
    "pontilhemos": "pontilhar",
    "pontilhes": "pontilhar",
    "pontilho": "pontilhar",
    "pontilhos": "pontilho",
    "pontilhosa": "pontilhoso",
    "pontilhosas": "pontilhoso",
    "pontilhosos": "pontilhoso",
    "pontilhou": "pontilhar",
    "pontilhá": "pontilhar",
    "pontilhámo": "pontilhar",
    "pontilhámos": "pontilhar",
    "pontilháramo": "pontilhar",
    "pontilháramos": "pontilhar",
    "pontilhárei": "pontilhar",
    "pontilháreis": "pontilhar",
    "pontilhásseis": "pontilhar",
    "pontilhássemos": "pontilhar",
    "pontilhávamo": "pontilhar",
    "pontilhávamos": "pontilhar",
    "pontilhávei": "pontilhar",
    "pontilháveis": "pontilhar",
    "pontilhões": "pontilhão",
    "pontina": "pontino",
    "pontinas": "pontino",
    "pontinha": "ponta",
    "pontinhas": "pontinha",
    "pontinho": "ponto",
    "pontinhos": "ponto",
    "pontinos": "pontino",
    "pontita": "ponta",
    "pontitas": "ponta",
    "pontito": "ponto",
    "pontitos": "ponto",
    "pontizelas": "pontizela",
    "ponto": "pontar",
    "pontoa": "pontoar",
    "pontoada": "pontoar",
    "pontoadas": "pontoar",
    "pontoado": "pontoar",
    "pontoados": "pontoar",
    "pontoai": "pontoar",
    "pontoais": "pontoar",
    "pontoam": "pontoar",
    "pontoamo": "pontoar",
    "pontoamos": "pontoar",
    "pontoando": "pontoar",
    "pontoara": "pontoar",
    "pontoaram": "pontoar",
    "pontoaras": "pontoar",
    "pontoarde": "pontoar",
    "pontoardes": "pontoar",
    "pontoare": "pontoar",
    "pontoarei": "pontoar",
    "pontoareis": "pontoar",
    "pontoarem": "pontoar",
    "pontoaremos": "pontoar",
    "pontoares": "pontoar",
    "pontoaria": "pontoar",
    "pontoariam": "pontoar",
    "pontoarias": "pontoar",
    "pontoarmo": "pontoar",
    "pontoarmos": "pontoar",
    "pontoará": "pontoar",
    "pontoarás": "pontoar",
    "pontoarão": "pontoar",
    "pontoaríamos": "pontoar",
    "pontoaríeis": "pontoar",
    "pontoas": "pontoar",
    "pontoasse": "pontoar",
    "pontoassem": "pontoar",
    "pontoasses": "pontoar",
    "pontoaste": "pontoar",
    "pontoastes": "pontoar",
    "pontoava": "pontoar",
    "pontoavam": "pontoar",
    "pontoavas": "pontoar",
    "pontoe": "pontoar",
    "pontoei": "pontoar",
    "pontoeis": "pontoar",
    "pontoem": "pontoar",
    "pontoemo": "pontoar",
    "pontoemos": "pontoar",
    "pontoes": "pontoar",
    "pontoneira": "pontoneiro",
    "pontoneiras": "pontoneiro",
    "pontoneiros": "pontoneiro",
    "pontoo": "pontoar",
    "pontoou": "pontoar",
    "pontos": "ponto",
    "pontou": "pontar",
    "pontoá": "pontoar",
    "pontoámo": "pontoar",
    "pontoámos": "pontoar",
    "pontoáramo": "pontoar",
    "pontoáramos": "pontoar",
    "pontoárei": "pontoar",
    "pontoáreis": "pontoar",
    "pontoásseis": "pontoar",
    "pontoássemos": "pontoar",
    "pontoávamo": "pontoar",
    "pontoávamos": "pontoar",
    "pontoávei": "pontoar",
    "pontoáveis": "pontoar",
    "pontua": "pontuar",
    "pontuada": "pontuar",
    "pontuadas": "pontuar",
    "pontuado": "pontuar",
    "pontuados": "pontuar",
    "pontuadíssima": "pontuado",
    "pontuadíssimas": "pontuado",
    "pontuadíssimo": "pontuado",
    "pontuadíssimos": "pontuado",
    "pontuai": "pontuar",
    "pontuais": "pontuar",
    "pontualidades": "pontualidade",
    "pontualíssima": "pontual",
    "pontualíssimas": "pontual",
    "pontualíssimo": "pontual",
    "pontualíssimos": "pontual",
    "pontuam": "pontuar",
    "pontuamo": "pontuar",
    "pontuamos": "pontuar",
    "pontuando": "pontuar",
    "pontuara": "pontuar",
    "pontuaram": "pontuar",
    "pontuaras": "pontuar",
    "pontuarde": "pontuar",
    "pontuardes": "pontuar",
    "pontuare": "pontuar",
    "pontuarei": "pontuar",
    "pontuareis": "pontuar",
    "pontuarem": "pontuar",
    "pontuaremos": "pontuar",
    "pontuares": "pontuar",
    "pontuaria": "pontuar",
    "pontuariam": "pontuar",
    "pontuarias": "pontuar",
    "pontuarmo": "pontuar",
    "pontuarmos": "pontuar",
    "pontuará": "pontuar",
    "pontuarás": "pontuar",
    "pontuarão": "pontuar",
    "pontuaríamos": "pontuar",
    "pontuaríeis": "pontuar",
    "pontuas": "pontuar",
    "pontuasse": "pontuar",
    "pontuassem": "pontuar",
    "pontuasses": "pontuar",
    "pontuaste": "pontuar",
    "pontuastes": "pontuar",
    "pontuava": "pontuar",
    "pontuavam": "pontuar",
    "pontuavas": "pontuar",
    "pontuações": "pontuação",
    "pontuda": "pontudo",
    "pontudas": "pontudo",
    "pontudos": "pontudo",
    "pontue": "pontuar",
    "pontuei": "pontuar",
    "pontueis": "pontuar",
    "pontuem": "pontuar",
    "pontuemo": "pontuar",
    "pontuemos": "pontuar",
    "pontues": "pontuar",
    "pontuo": "pontuar",
    "pontuou": "pontuar",
    "pontuá": "pontuar",
    "pontuámo": "pontuar",
    "pontuámos": "pontuar",
    "pontuáramo": "pontuar",
    "pontuáramos": "pontuar",
    "pontuárei": "pontuar",
    "pontuáreis": "pontuar",
    "pontuásseis": "pontuar",
    "pontuássemos": "pontuar",
    "pontuávamo": "pontuar",
    "pontuávamos": "pontuar",
    "pontuávei": "pontuar",
    "pontuáveis": "pontuável",
    "pontá": "pontar",
    "pontámo": "pontar",
    "pontámos": "pontar",
    "pontáramo": "pontar",
    "pontáramos": "pontar",
    "pontárei": "pontar",
    "pontáreis": "pontar",
    "pontásseis": "pontar",
    "pontássemos": "pontar",
    "pontávamo": "pontar",
    "pontávamos": "pontar",
    "pontávei": "pontar",
    "pontáveis": "pontar",
    "pontéis": "pontel",
    "pontículas": "pontícula",
    "pontículos": "pontículo",
    "pontífices": "pontífice",
    "pontófila": "pontófilo",
    "pontófilas": "pontófilo",
    "pontófilos": "pontófilo",
    "pontões": "pontão",
    "poo": "poer",
    "popas": "popa",
    "popelinas": "popelina",
    "popes": "pope",
    "popinha": "popa",
    "popinhas": "popinha",
    "popita": "popa",
    "popitas": "popa",
    "poplítea": "poplíteo",
    "poplíteas": "poplíteo",
    "poplíteos": "poplíteo",
    "poplítica": "poplítico",
    "poplíticas": "poplítico",
    "poplíticos": "poplítico",
    "pops": "pop",
    "populachos": "populacho",
    "populacionais": "populacional",
    "populares": "popular",
    "popularidades": "popularidade",
    "popularismos": "popularismo",
    "populariza": "popularizar",
    "popularizada": "popularizar",
    "popularizadas": "popularizar",
    "popularizado": "popularizar",
    "popularizados": "popularizar",
    "popularizai": "popularizar",
    "popularizais": "popularizar",
    "popularizam": "popularizar",
    "popularizamo": "popularizar",
    "popularizamos": "popularizar",
    "popularizando": "popularizar",
    "popularizara": "popularizar",
    "popularizaram": "popularizar",
    "popularizaras": "popularizar",
    "popularizarde": "popularizar",
    "popularizardes": "popularizar",
    "popularizare": "popularizar",
    "popularizarei": "popularizar",
    "popularizareis": "popularizar",
    "popularizarem": "popularizar",
    "popularizaremos": "popularizar",
    "popularizares": "popularizar",
    "popularizaria": "popularizar",
    "popularizariam": "popularizar",
    "popularizarias": "popularizar",
    "popularizarmo": "popularizar",
    "popularizarmos": "popularizar",
    "popularizará": "popularizar",
    "popularizarás": "popularizar",
    "popularizarão": "popularizar",
    "popularizaríamos": "popularizar",
    "popularizaríeis": "popularizar",
    "popularizas": "popularizar",
    "popularizasse": "popularizar",
    "popularizassem": "popularizar",
    "popularizasses": "popularizar",
    "popularizaste": "popularizar",
    "popularizastes": "popularizar",
    "popularizava": "popularizar",
    "popularizavam": "popularizar",
    "popularizavas": "popularizar",
    "popularizações": "popularização",
    "popularize": "popularizar",
    "popularizei": "popularizar",
    "popularizeis": "popularizar",
    "popularizem": "popularizar",
    "popularizemo": "popularizar",
    "popularizemos": "popularizar",
    "popularizes": "popularizar",
    "popularizo": "popularizar",
    "popularizou": "popularizar",
    "popularizá": "popularizar",
    "popularizámo": "popularizar",
    "popularizámos": "popularizar",
    "popularizáramo": "popularizar",
    "popularizáramos": "popularizar",
    "popularizárei": "popularizar",
    "popularizáreis": "popularizar",
    "popularizásseis": "popularizar",
    "popularizássemos": "popularizar",
    "popularizávamo": "popularizar",
    "popularizávamos": "popularizar",
    "popularizávei": "popularizar",
    "popularizáveis": "popularizável",
    "popularucha": "popularucho",
    "popularuchas": "popularucho",
    "popularuchos": "popularucho",
    "popularíssima": "popular",
    "popularíssimas": "popular",
    "popularíssimo": "popular",
    "popularíssimos": "popular",
    "populaças": "populaça",
    "populações": "população",
    "populinas": "populina",
    "populismos": "populismo",
    "populistas": "populista",
    "populosa": "populoso",
    "populosas": "populoso",
    "populosos": "populoso",
    "populínica": "populínico",
    "populínicas": "populínico",
    "populínicos": "populínico",
    "popós": "popó",
    "popúlea": "popúleo",
    "popúleas": "popúleo",
    "popúleos": "popúleo",
    "porca": "porco",
    "porcadas": "porcada",
    "porcalha": "porcalho",
    "porcalhas": "porcalho",
    "porcalhices": "porcalhice",
    "porcalhona": "porcalhão",
    "porcalhonas": "porcalhão",
    "porcalhos": "porcalho",
    "porcalhões": "porcalhão",
    "porcarias": "porcaria",
    "porcariça": "porcariço",
    "porcariças": "porcariço",
    "porcariços": "porcariço",
    "porcas": "porco",
    "porcelanas": "porcelana",
    "porcelanites": "porcelanite",
    "porcelanitos": "porcelanito",
    "porcelânica": "porcelânico",
    "porcelânicas": "porcelânico",
    "porcelânicos": "porcelânico",
    "porcentagens": "porcentagem",
    "porcina": "porcino",
    "porcinas": "porcino",
    "porcinos": "porcino",
    "porcionistas": "porcionista",
    "porcionária": "porcionário",
    "porcionárias": "porcionário",
    "porcionários": "porcionário",
    "porciúnculas": "porciúncula",
    "porcos": "porco",
    "porcélios": "porcélio",
    "porde": "pôr",
    "pordes": "pôr",
    "pore": "pôr",
    "porei": "pôr",
    "poreis": "pôr",
    "poreja": "porejar",
    "porejada": "porejar",
    "porejadas": "porejar",
    "porejado": "porejar",
    "porejados": "porejar",
    "porejai": "porejar",
    "porejais": "porejar",
    "porejam": "porejar",
    "porejamo": "porejar",
    "porejamos": "porejar",
    "porejando": "porejar",
    "porejara": "porejar",
    "porejaram": "porejar",
    "porejaras": "porejar",
    "porejarde": "porejar",
    "porejardes": "porejar",
    "porejare": "porejar",
    "porejarei": "porejar",
    "porejareis": "porejar",
    "porejarem": "porejar",
    "porejaremos": "porejar",
    "porejares": "porejar",
    "porejaria": "porejar",
    "porejariam": "porejar",
    "porejarias": "porejar",
    "porejarmo": "porejar",
    "porejarmos": "porejar",
    "porejará": "porejar",
    "porejarás": "porejar",
    "porejarão": "porejar",
    "porejaríamos": "porejar",
    "porejaríeis": "porejar",
    "porejas": "porejar",
    "porejasse": "porejar",
    "porejassem": "porejar",
    "porejasses": "porejar",
    "porejaste": "porejar",
    "porejastes": "porejar",
    "porejava": "porejar",
    "porejavam": "porejar",
    "porejavas": "porejar",
    "poreje": "porejar",
    "porejei": "porejar",
    "porejeis": "porejar",
    "porejem": "porejar",
    "porejemo": "porejar",
    "porejemos": "porejar",
    "porejes": "porejar",
    "porejo": "porejar",
    "porejou": "porejar",
    "porejá": "porejar",
    "porejámo": "porejar",
    "porejámos": "porejar",
    "porejáramo": "porejar",
    "porejáramos": "porejar",
    "porejárei": "porejar",
    "porejáreis": "porejar",
    "porejásseis": "porejar",
    "porejássemos": "porejar",
    "porejávamo": "porejar",
    "porejávamos": "porejar",
    "porejávei": "porejar",
    "porejáveis": "porejar",
    "porem": "pôr",
    "poremos": "pôr",
    "pores": "pôr",
    "porfenda": "porfender",
    "porfendais": "porfender",
    "porfendam": "porfender",
    "porfendamo": "porfender",
    "porfendamos": "porfender",
    "porfendas": "porfender",
    "porfende": "porfender",
    "porfendei": "porfender",
    "porfendeis": "porfender",
    "porfendem": "porfender",
    "porfendemo": "porfender",
    "porfendemos": "porfender",
    "porfendendo": "porfender",
    "porfendera": "porfender",
    "porfenderam": "porfender",
    "porfenderas": "porfender",
    "porfenderde": "porfender",
    "porfenderdes": "porfender",
    "porfendere": "porfender",
    "porfenderei": "porfender",
    "porfendereis": "porfender",
    "porfenderem": "porfender",
    "porfenderemos": "porfender",
    "porfenderes": "porfender",
    "porfenderia": "porfender",
    "porfenderiam": "porfender",
    "porfenderias": "porfender",
    "porfendermo": "porfender",
    "porfendermos": "porfender",
    "porfenderá": "porfender",
    "porfenderás": "porfender",
    "porfenderão": "porfender",
    "porfenderíamos": "porfender",
    "porfenderíeis": "porfender",
    "porfendes": "porfender",
    "porfendesse": "porfender",
    "porfendessem": "porfender",
    "porfendesses": "porfender",
    "porfendeste": "porfender",
    "porfendestes": "porfender",
    "porfendeu": "porfender",
    "porfendi": "porfender",
    "porfendia": "porfender",
    "porfendiam": "porfender",
    "porfendias": "porfender",
    "porfendida": "porfender",
    "porfendidas": "porfender",
    "porfendido": "porfender",
    "porfendidos": "porfender",
    "porfendo": "porfender",
    "porfendê": "porfender",
    "porfendêramo": "porfender",
    "porfendêramos": "porfender",
    "porfendêrei": "porfender",
    "porfendêreis": "porfender",
    "porfendêsseis": "porfender",
    "porfendêssemos": "porfender",
    "porfendíamo": "porfender",
    "porfendíamos": "porfender",
    "porfendíei": "porfender",
    "porfendíeis": "porfender",
    "porfia": "porfiar",
    "porfiada": "porfiar",
    "porfiadas": "porfiar",
    "porfiado": "porfiar",
    "porfiadora": "porfiador",
    "porfiadoras": "porfiador",
    "porfiadores": "porfiador",
    "porfiados": "porfiar",
    "porfiai": "porfiar",
    "porfiais": "porfiar",
    "porfiam": "porfiar",
    "porfiamo": "porfiar",
    "porfiamos": "porfiar",
    "porfiando": "porfiar",
    "porfiara": "porfiar",
    "porfiaram": "porfiar",
    "porfiaras": "porfiar",
    "porfiarde": "porfiar",
    "porfiardes": "porfiar",
    "porfiare": "porfiar",
    "porfiarei": "porfiar",
    "porfiareis": "porfiar",
    "porfiarem": "porfiar",
    "porfiaremos": "porfiar",
    "porfiares": "porfiar",
    "porfiaria": "porfiar",
    "porfiariam": "porfiar",
    "porfiarias": "porfiar",
    "porfiarmo": "porfiar",
    "porfiarmos": "porfiar",
    "porfiará": "porfiar",
    "porfiarás": "porfiar",
    "porfiarão": "porfiar",
    "porfiaríamos": "porfiar",
    "porfiaríeis": "porfiar",
    "porfias": "porfiar",
    "porfiasse": "porfiar",
    "porfiassem": "porfiar",
    "porfiasses": "porfiar",
    "porfiaste": "porfiar",
    "porfiastes": "porfiar",
    "porfiava": "porfiar",
    "porfiavam": "porfiar",
    "porfiavas": "porfiar",
    "porfie": "porfiar",
    "porfiei": "porfiar",
    "porfieis": "porfiar",
    "porfiem": "porfiar",
    "porfiemo": "porfiar",
    "porfiemos": "porfiar",
    "porfies": "porfiar",
    "porfio": "porfiar",
    "porfiosa": "porfioso",
    "porfiosas": "porfioso",
    "porfiosos": "porfioso",
    "porfiou": "porfiar",
    "porfiriza": "porfirizar",
    "porfirizada": "porfirizar",
    "porfirizadas": "porfirizar",
    "porfirizado": "porfirizar",
    "porfirizados": "porfirizar",
    "porfirizai": "porfirizar",
    "porfirizais": "porfirizar",
    "porfirizam": "porfirizar",
    "porfirizamo": "porfirizar",
    "porfirizamos": "porfirizar",
    "porfirizando": "porfirizar",
    "porfirizara": "porfirizar",
    "porfirizaram": "porfirizar",
    "porfirizaras": "porfirizar",
    "porfirizarde": "porfirizar",
    "porfirizardes": "porfirizar",
    "porfirizare": "porfirizar",
    "porfirizarei": "porfirizar",
    "porfirizareis": "porfirizar",
    "porfirizarem": "porfirizar",
    "porfirizaremos": "porfirizar",
    "porfirizares": "porfirizar",
    "porfirizaria": "porfirizar",
    "porfirizariam": "porfirizar",
    "porfirizarias": "porfirizar",
    "porfirizarmo": "porfirizar",
    "porfirizarmos": "porfirizar",
    "porfirizará": "porfirizar",
    "porfirizarás": "porfirizar",
    "porfirizarão": "porfirizar",
    "porfirizaríamos": "porfirizar",
    "porfirizaríeis": "porfirizar",
    "porfirizas": "porfirizar",
    "porfirizasse": "porfirizar",
    "porfirizassem": "porfirizar",
    "porfirizasses": "porfirizar",
    "porfirizaste": "porfirizar",
    "porfirizastes": "porfirizar",
    "porfirizava": "porfirizar",
    "porfirizavam": "porfirizar",
    "porfirizavas": "porfirizar",
    "porfirize": "porfirizar",
    "porfirizei": "porfirizar",
    "porfirizeis": "porfirizar",
    "porfirizem": "porfirizar",
    "porfirizemo": "porfirizar",
    "porfirizemos": "porfirizar",
    "porfirizes": "porfirizar",
    "porfirizo": "porfirizar",
    "porfirizou": "porfirizar",
    "porfirizá": "porfirizar",
    "porfirizámo": "porfirizar",
    "porfirizámos": "porfirizar",
    "porfirizáramo": "porfirizar",
    "porfirizáramos": "porfirizar",
    "porfirizárei": "porfirizar",
    "porfirizáreis": "porfirizar",
    "porfirizásseis": "porfirizar",
    "porfirizássemos": "porfirizar",
    "porfirizávamo": "porfirizar",
    "porfirizávamos": "porfirizar",
    "porfirizávei": "porfirizar",
    "porfirizáveis": "porfirizar",
    "porfiá": "porfiar",
    "porfiámo": "porfiar",
    "porfiámos": "porfiar",
    "porfiáramo": "porfiar",
    "porfiáramos": "porfiar",
    "porfiárei": "porfiar",
    "porfiáreis": "porfiar",
    "porfiásseis": "porfiar",
    "porfiássemos": "porfiar",
    "porfiávamo": "porfiar",
    "porfiávamos": "porfiar",
    "porfiávei": "porfiar",
    "porfiáveis": "porfiar",
    "porfírica": "porfírico",
    "porfíricas": "porfírico",
    "porfíricos": "porfírico",
    "poria": "pôr",
    "poriam": "pôr",
    "porias": "pôr",
    "poricidas": "poricida",
    "pormenores": "pormenor",
    "pormenoriza": "pormenorizar",
    "pormenorizada": "pormenorizar",
    "pormenorizadas": "pormenorizar",
    "pormenorizado": "pormenorizar",
    "pormenorizados": "pormenorizar",
    "pormenorizadíssima": "pormenorizado",
    "pormenorizadíssimas": "pormenorizado",
    "pormenorizadíssimo": "pormenorizado",
    "pormenorizadíssimos": "pormenorizado",
    "pormenorizai": "pormenorizar",
    "pormenorizais": "pormenorizar",
    "pormenorizam": "pormenorizar",
    "pormenorizamo": "pormenorizar",
    "pormenorizamos": "pormenorizar",
    "pormenorizando": "pormenorizar",
    "pormenorizara": "pormenorizar",
    "pormenorizaram": "pormenorizar",
    "pormenorizaras": "pormenorizar",
    "pormenorizarde": "pormenorizar",
    "pormenorizardes": "pormenorizar",
    "pormenorizare": "pormenorizar",
    "pormenorizarei": "pormenorizar",
    "pormenorizareis": "pormenorizar",
    "pormenorizarem": "pormenorizar",
    "pormenorizaremos": "pormenorizar",
    "pormenorizares": "pormenorizar",
    "pormenorizaria": "pormenorizar",
    "pormenorizariam": "pormenorizar",
    "pormenorizarias": "pormenorizar",
    "pormenorizarmo": "pormenorizar",
    "pormenorizarmos": "pormenorizar",
    "pormenorizará": "pormenorizar",
    "pormenorizarás": "pormenorizar",
    "pormenorizarão": "pormenorizar",
    "pormenorizaríamos": "pormenorizar",
    "pormenorizaríeis": "pormenorizar",
    "pormenorizas": "pormenorizar",
    "pormenorizasse": "pormenorizar",
    "pormenorizassem": "pormenorizar",
    "pormenorizasses": "pormenorizar",
    "pormenorizaste": "pormenorizar",
    "pormenorizastes": "pormenorizar",
    "pormenorizava": "pormenorizar",
    "pormenorizavam": "pormenorizar",
    "pormenorizavas": "pormenorizar",
    "pormenorizações": "pormenorização",
    "pormenorize": "pormenorizar",
    "pormenorizei": "pormenorizar",
    "pormenorizeis": "pormenorizar",
    "pormenorizem": "pormenorizar",
    "pormenorizemo": "pormenorizar",
    "pormenorizemos": "pormenorizar",
    "pormenorizes": "pormenorizar",
    "pormenorizo": "pormenorizar",
    "pormenorizou": "pormenorizar",
    "pormenorizá": "pormenorizar",
    "pormenorizámo": "pormenorizar",
    "pormenorizámos": "pormenorizar",
    "pormenorizáramo": "pormenorizar",
    "pormenorizáramos": "pormenorizar",
    "pormenorizárei": "pormenorizar",
    "pormenorizáreis": "pormenorizar",
    "pormenorizásseis": "pormenorizar",
    "pormenorizássemos": "pormenorizar",
    "pormenorizávamo": "pormenorizar",
    "pormenorizávamos": "pormenorizar",
    "pormenorizávei": "pormenorizar",
    "pormenorizáveis": "pormenorizar",
    "pormo": "pôr",
    "pormos": "pôr",
    "pornocracias": "pornocracia",
    "pornocrática": "pornocrático",
    "pornocráticas": "pornocrático",
    "pornocráticos": "pornocrático",
    "pornografa": "pornografar",
    "pornografada": "pornografar",
    "pornografadas": "pornografar",
    "pornografado": "pornografar",
    "pornografados": "pornografar",
    "pornografai": "pornografar",
    "pornografais": "pornografar",
    "pornografam": "pornografar",
    "pornografamo": "pornografar",
    "pornografamos": "pornografar",
    "pornografando": "pornografar",
    "pornografara": "pornografar",
    "pornografaram": "pornografar",
    "pornografaras": "pornografar",
    "pornografarde": "pornografar",
    "pornografardes": "pornografar",
    "pornografare": "pornografar",
    "pornografarei": "pornografar",
    "pornografareis": "pornografar",
    "pornografarem": "pornografar",
    "pornografaremos": "pornografar",
    "pornografares": "pornografar",
    "pornografaria": "pornografar",
    "pornografariam": "pornografar",
    "pornografarias": "pornografar",
    "pornografarmo": "pornografar",
    "pornografarmos": "pornografar",
    "pornografará": "pornografar",
    "pornografarás": "pornografar",
    "pornografarão": "pornografar",
    "pornografaríamos": "pornografar",
    "pornografaríeis": "pornografar",
    "pornografas": "pornografar",
    "pornografasse": "pornografar",
    "pornografassem": "pornografar",
    "pornografasses": "pornografar",
    "pornografaste": "pornografar",
    "pornografastes": "pornografar",
    "pornografava": "pornografar",
    "pornografavam": "pornografar",
    "pornografavas": "pornografar",
    "pornografe": "pornografar",
    "pornografei": "pornografar",
    "pornografeis": "pornografar",
    "pornografem": "pornografar",
    "pornografemo": "pornografar",
    "pornografemos": "pornografar",
    "pornografes": "pornografar",
    "pornografias": "pornografia",
    "pornografismos": "pornografismo",
    "pornografo": "pornografar",
    "pornografou": "pornografar",
    "pornografá": "pornografar",
    "pornografámo": "pornografar",
    "pornografámos": "pornografar",
    "pornografáramo": "pornografar",
    "pornografáramos": "pornografar",
    "pornografárei": "pornografar",
    "pornografáreis": "pornografar",
    "pornografásseis": "pornografar",
    "pornografássemos": "pornografar",
    "pornografávamo": "pornografar",
    "pornografávamos": "pornografar",
    "pornografávei": "pornografar",
    "pornografáveis": "pornografar",
    "pornográfica": "pornográfico",
    "pornográficas": "pornográfico",
    "pornográficos": "pornográfico",
    "pornos": "porno",
    "pornógrafos": "pornógrafo",
    "porogamias": "porogamia",
    "pororocas": "pororoca",
    "poros": "poro",
    "porosa": "poroso",
    "porosas": "poroso",
    "porosidades": "porosidade",
    "porosos": "poroso",
    "porpianhos": "porpianho",
    "porqueira": "porqueiro",
    "porqueiras": "porqueiro",
    "porqueiros": "porqueiro",
    "porquices": "porquice",
    "porquidades": "porquidade",
    "porquidões": "porquidão",
    "porquinha": "porco",
    "porquinhas": "porco",
    "porquinho": "porco",
    "porquinhos": "porquinho",
    "porquita": "porco",
    "porquitas": "porco",
    "porquito": "porco",
    "porquitos": "porco",
    "porquês": "porquê",
    "porquíssima": "porco",
    "porquíssimas": "porco",
    "porquíssimo": "porco",
    "porquíssimos": "porco",
    "porradas": "porrada",
    "porrais": "porral",
    "porras": "porra",
    "porreira": "porreiro",
    "porreiras": "porreiro",
    "porreirinha": "porreiro",
    "porreirinhas": "porreiro",
    "porreirinho": "porreiro",
    "porreirinhos": "porreiro",
    "porreirismos": "porreirismo",
    "porreirita": "porreiro",
    "porreiritas": "porreiro",
    "porreirito": "porreiro",
    "porreiritos": "porreiro",
    "porreiros": "porreiro",
    "porreiríssima": "porreiro",
    "porreiríssimas": "porreiro",
    "porreiríssimo": "porreiro",
    "porreiríssimos": "porreiro",
    "porretadas": "porretada",
    "porretas": "porreta",
    "porretes": "porrete",
    "porrigens": "porrigem",
    "porriginosa": "porriginoso",
    "porriginosas": "porriginoso",
    "porriginosos": "porriginoso",
    "porrigos": "porrigo",
    "porrinhos": "porrinho",
    "porros": "porro",
    "porrões": "porrão",
    "porta": "portar",
    "portabilidades": "portabilidade",
    "portada": "portar",
    "portadas": "portar",
    "portado": "portar",
    "portadora": "portador",
    "portadoras": "portador",
    "portadores": "portador",
    "portados": "portar",
    "portageira": "portageiro",
    "portageiras": "portageiro",
    "portageiros": "portageiro",
    "portagens": "portagem",
    "portai": "portar",
    "portais": "portar",
    "portalegranses": "portalegranse",
    "portalós": "portaló",
    "portam": "portar",
    "portamo": "portar",
    "portamos": "portar",
    "portando": "portar",
    "portantes": "portante",
    "portara": "portar",
    "portaram": "portar",
    "portaras": "portar",
    "portarde": "portar",
    "portardes": "portar",
    "portare": "portar",
    "portarei": "portar",
    "portareis": "portar",
    "portarem": "portar",
    "portaremos": "portar",
    "portares": "portar",
    "portaria": "portar",
    "portariam": "portar",
    "portarias": "portaria",
    "portarmo": "portar",
    "portarmos": "portar",
    "portará": "portar",
    "portarás": "portar",
    "portarão": "portar",
    "portaríamos": "portar",
    "portaríeis": "portar",
    "portas": "portar",
    "portasse": "portar",
    "portassem": "portar",
    "portasses": "portar",
    "portaste": "portar",
    "portastes": "portar",
    "portatória": "portatório",
    "portatórias": "portatório",
    "portatórios": "portatório",
    "portava": "portar",
    "portavam": "portar",
    "portavas": "portar",
    "porte": "portar",
    "porteada": "portear",
    "porteadas": "portear",
    "porteado": "portear",
    "porteados": "portear",
    "porteai": "portear",
    "porteais": "portear",
    "porteamo": "portear",
    "porteamos": "portear",
    "porteando": "portear",
    "porteara": "portear",
    "portearam": "portear",
    "portearas": "portear",
    "portearde": "portear",
    "porteardes": "portear",
    "porteare": "portear",
    "portearei": "portear",
    "porteareis": "portear",
    "portearem": "portear",
    "portearemos": "portear",
    "porteares": "portear",
    "portearia": "portear",
    "porteariam": "portear",
    "portearias": "portear",
    "portearmo": "portear",
    "portearmos": "portear",
    "porteará": "portear",
    "portearás": "portear",
    "portearão": "portear",
    "portearíamos": "portear",
    "portearíeis": "portear",
    "porteasse": "portear",
    "porteassem": "portear",
    "porteasses": "portear",
    "porteaste": "portear",
    "porteastes": "portear",
    "porteava": "portear",
    "porteavam": "portear",
    "porteavas": "portear",
    "porteei": "portear",
    "porteeis": "portear",
    "porteemo": "portear",
    "porteemos": "portear",
    "portei": "portar",
    "porteia": "portear",
    "porteiam": "portear",
    "porteias": "portear",
    "porteie": "portear",
    "porteiem": "portear",
    "porteies": "portear",
    "porteio": "portear",
    "porteira": "porteiro",
    "porteiras": "porteiro",
    "porteiros": "porteiro",
    "porteis": "portar",
    "portelas": "portela",
    "portelos": "portelo",
    "portem": "portar",
    "portemo": "portar",
    "portemos": "portar",
    "portentos": "portento",
    "portentosa": "portentoso",
    "portentosas": "portentoso",
    "portentosos": "portentoso",
    "porteou": "portear",
    "portes": "porte",
    "porteá": "portear",
    "porteámo": "portear",
    "porteámos": "portear",
    "porteáramo": "portear",
    "porteáramos": "portear",
    "porteárei": "portear",
    "porteáreis": "portear",
    "porteásseis": "portear",
    "porteássemos": "portear",
    "porteávamo": "portear",
    "porteávamos": "portear",
    "porteávei": "portear",
    "porteáveis": "portear",
    "portfólios": "portfólio",
    "portilhas": "portilha",
    "portilhos": "portilho",
    "portimonenses": "portimonense",
    "portinha": "porta",
    "portinhas": "porta",
    "portinho": "porto",
    "portinholas": "portinhola",
    "portinhos": "porto",
    "portistas": "portista",
    "portita": "porta",
    "portitas": "porta",
    "portito": "porto",
    "portitos": "porto",
    "portlandianos": "portlandiano",
    "porto": "portar",
    "portos": "porto",
    "portou": "portar",
    "portozinho": "porto",
    "portozinhos": "porto",
    "portozito": "porto",
    "portozitos": "porto",
    "portucalenses": "portucalense",
    "portucha": "portuchar",
    "portuchada": "portuchar",
    "portuchadas": "portuchar",
    "portuchado": "portuchar",
    "portuchados": "portuchar",
    "portuchai": "portuchar",
    "portuchais": "portuchar",
    "portucham": "portuchar",
    "portuchamo": "portuchar",
    "portuchamos": "portuchar",
    "portuchando": "portuchar",
    "portuchara": "portuchar",
    "portucharam": "portuchar",
    "portucharas": "portuchar",
    "portucharde": "portuchar",
    "portuchardes": "portuchar",
    "portuchare": "portuchar",
    "portucharei": "portuchar",
    "portuchareis": "portuchar",
    "portucharem": "portuchar",
    "portucharemos": "portuchar",
    "portuchares": "portuchar",
    "portucharia": "portuchar",
    "portuchariam": "portuchar",
    "portucharias": "portuchar",
    "portucharmo": "portuchar",
    "portucharmos": "portuchar",
    "portuchará": "portuchar",
    "portucharás": "portuchar",
    "portucharão": "portuchar",
    "portucharíamos": "portuchar",
    "portucharíeis": "portuchar",
    "portuchas": "portuchar",
    "portuchasse": "portuchar",
    "portuchassem": "portuchar",
    "portuchasses": "portuchar",
    "portuchaste": "portuchar",
    "portuchastes": "portuchar",
    "portuchava": "portuchar",
    "portuchavam": "portuchar",
    "portuchavas": "portuchar",
    "portuche": "portuchar",
    "portuchei": "portuchar",
    "portucheis": "portuchar",
    "portuchem": "portuchar",
    "portuchemo": "portuchar",
    "portuchemos": "portuchar",
    "portuches": "portuchar",
    "portucho": "portuchar",
    "portuchos": "portucho",
    "portuchou": "portuchar",
    "portuchá": "portuchar",
    "portuchámo": "portuchar",
    "portuchámos": "portuchar",
    "portucháramo": "portuchar",
    "portucháramos": "portuchar",
    "portuchárei": "portuchar",
    "portucháreis": "portuchar",
    "portuchásseis": "portuchar",
    "portuchássemos": "portuchar",
    "portuchávamo": "portuchar",
    "portuchávamos": "portuchar",
    "portuchávei": "portuchar",
    "portucháveis": "portuchar",
    "portuenses": "portuense",
    "portugalenses": "portugalense",
    "portugalidades": "portugalidade",
    "portugaliza": "portugalizar",
    "portugalizada": "portugalizar",
    "portugalizadas": "portugalizar",
    "portugalizado": "portugalizar",
    "portugalizados": "portugalizar",
    "portugalizai": "portugalizar",
    "portugalizais": "portugalizar",
    "portugalizam": "portugalizar",
    "portugalizamo": "portugalizar",
    "portugalizamos": "portugalizar",
    "portugalizando": "portugalizar",
    "portugalizara": "portugalizar",
    "portugalizaram": "portugalizar",
    "portugalizaras": "portugalizar",
    "portugalizarde": "portugalizar",
    "portugalizardes": "portugalizar",
    "portugalizare": "portugalizar",
    "portugalizarei": "portugalizar",
    "portugalizareis": "portugalizar",
    "portugalizarem": "portugalizar",
    "portugalizaremos": "portugalizar",
    "portugalizares": "portugalizar",
    "portugalizaria": "portugalizar",
    "portugalizariam": "portugalizar",
    "portugalizarias": "portugalizar",
    "portugalizarmo": "portugalizar",
    "portugalizarmos": "portugalizar",
    "portugalizará": "portugalizar",
    "portugalizarás": "portugalizar",
    "portugalizarão": "portugalizar",
    "portugalizaríamos": "portugalizar",
    "portugalizaríeis": "portugalizar",
    "portugalizas": "portugalizar",
    "portugalizasse": "portugalizar",
    "portugalizassem": "portugalizar",
    "portugalizasses": "portugalizar",
    "portugalizaste": "portugalizar",
    "portugalizastes": "portugalizar",
    "portugalizava": "portugalizar",
    "portugalizavam": "portugalizar",
    "portugalizavas": "portugalizar",
    "portugalize": "portugalizar",
    "portugalizei": "portugalizar",
    "portugalizeis": "portugalizar",
    "portugalizem": "portugalizar",
    "portugalizemo": "portugalizar",
    "portugalizemos": "portugalizar",
    "portugalizes": "portugalizar",
    "portugalizo": "portugalizar",
    "portugalizou": "portugalizar",
    "portugalizá": "portugalizar",
    "portugalizámo": "portugalizar",
    "portugalizámos": "portugalizar",
    "portugalizáramo": "portugalizar",
    "portugalizáramos": "portugalizar",
    "portugalizárei": "portugalizar",
    "portugalizáreis": "portugalizar",
    "portugalizásseis": "portugalizar",
    "portugalizássemos": "portugalizar",
    "portugalizávamo": "portugalizar",
    "portugalizávamos": "portugalizar",
    "portugalizávei": "portugalizar",
    "portugalizáveis": "portugalizável",
    "portugas": "portuga",
    "portuguesa": "portuguesar",
    "portuguesada": "portuguesar",
    "portuguesadas": "portuguesar",
    "portuguesado": "portuguesar",
    "portuguesados": "portuguesar",
    "portuguesai": "portuguesar",
    "portuguesais": "portuguesar",
    "portuguesam": "portuguesar",
    "portuguesamo": "portuguesar",
    "portuguesamos": "portuguesar",
    "portuguesando": "portuguesar",
    "portuguesara": "portuguesar",
    "portuguesaram": "portuguesar",
    "portuguesaras": "portuguesar",
    "portuguesarde": "portuguesar",
    "portuguesardes": "portuguesar",
    "portuguesare": "portuguesar",
    "portuguesarei": "portuguesar",
    "portuguesareis": "portuguesar",
    "portuguesarem": "portuguesar",
    "portuguesaremos": "portuguesar",
    "portuguesares": "portuguesar",
    "portuguesaria": "portuguesar",
    "portuguesariam": "portuguesar",
    "portuguesarias": "portuguesar",
    "portuguesarmo": "portuguesar",
    "portuguesarmos": "portuguesar",
    "portuguesará": "portuguesar",
    "portuguesarás": "portuguesar",
    "portuguesarão": "portuguesar",
    "portuguesaríamos": "portuguesar",
    "portuguesaríeis": "portuguesar",
    "portuguesas": "portuguesar",
    "portuguesasse": "portuguesar",
    "portuguesassem": "portuguesar",
    "portuguesasses": "portuguesar",
    "portuguesaste": "portuguesar",
    "portuguesastes": "portuguesar",
    "portuguesava": "portuguesar",
    "portuguesavam": "portuguesar",
    "portuguesavas": "portuguesar",
    "portuguesazinha": "português",
    "portuguesazinhas": "português",
    "portuguesazita": "português",
    "portuguesazitas": "português",
    "portuguese": "portuguesar",
    "portuguesei": "portuguesar",
    "portugueseis": "portuguesar",
    "portuguesem": "portuguesar",
    "portuguesemo": "portuguesar",
    "portuguesemos": "portuguesar",
    "portugueses": "portuguesar",
    "portuguesismos": "portuguesismo",
    "portugueso": "portuguesar",
    "portuguesou": "portuguesar",
    "portuguesá": "portuguesar",
    "portuguesámo": "portuguesar",
    "portuguesámos": "portuguesar",
    "portuguesáramo": "portuguesar",
    "portuguesáramos": "portuguesar",
    "portuguesárei": "portuguesar",
    "portuguesáreis": "portuguesar",
    "portuguesásseis": "portuguesar",
    "portuguesássemos": "portuguesar",
    "portuguesávamo": "portuguesar",
    "portuguesávamos": "portuguesar",
    "portuguesávei": "portuguesar",
    "portuguesáveis": "portuguesável",
    "portuguezinho": "português",
    "portuguezinhos": "português",
    "portuguezito": "português",
    "portuguezitos": "português",
    "portulacáceas": "portulacácea",
    "portulanos": "portulano",
    "portuosa": "portuoso",
    "portuosas": "portuoso",
    "portuosos": "portuoso",
    "portuária": "portuário",
    "portuárias": "portuário",
    "portuários": "portuário",
    "portá": "portar",
    "portámo": "portar",
    "portámos": "portar",
    "portáramo": "portar",
    "portáramos": "portar",
    "portárei": "portar",
    "portáreis": "portar",
    "portásseis": "portar",
    "portássemos": "portar",
    "portáteis": "portátil",
    "portávamo": "portar",
    "portávamos": "portar",
    "portávei": "portar",
    "portáveis": "portar",
    "portões": "portão",
    "porvindoira": "porvindoiro",
    "porvindoiras": "porvindoiro",
    "porvindoiros": "porvindoiro",
    "porvindoura": "porvindouro",
    "porvindouras": "porvindouro",
    "porvindouros": "porvindouro",
    "porvires": "porvir",
    "porá": "pôr",
    "porás": "pôr",
    "porão": "pôr",
    "porãozinho": "porão",
    "porãozito": "porão",
    "porções": "porção",
    "poríamos": "pôr",
    "poríeis": "pôr",
    "porífera": "porífero",
    "poríferas": "porífero",
    "poríferos": "porífero",
    "porões": "porão",
    "porõezinhos": "porão",
    "porõezitos": "porão",
    "posa": "posar",
    "posada": "posar",
    "posadas": "posar",
    "posado": "posar",
    "posados": "posar",
    "posai": "posar",
    "posais": "posar",
    "posam": "posar",
    "posamo": "posar",
    "posamos": "posar",
    "posando": "posar",
    "posara": "posar",
    "posaram": "posar",
    "posaras": "posar",
    "posardes": "posar",
    "posarei": "posar",
    "posareis": "posar",
    "posarem": "posar",
    "posaremos": "posar",
    "posares": "posar",
    "posaria": "posar",
    "posariam": "posar",
    "posarias": "posar",
    "posarmo": "posar",
    "posarmos": "posar",
    "posará": "posar",
    "posarás": "posar",
    "posarão": "posar",
    "posaríamos": "posar",
    "posaríeis": "posar",
    "posas": "posar",
    "posasse": "posar",
    "posassem": "posar",
    "posasses": "posar",
    "posaste": "posar",
    "posastes": "posar",
    "posava": "posar",
    "posavam": "posar",
    "posavas": "posar",
    "poscénica": "poscénico",
    "poscénicas": "poscénico",
    "poscénicos": "poscénico",
    "poscénios": "poscénio",
    "pose": "posar",
    "posei": "posar",
    "poseis": "posar",
    "posem": "posar",
    "posemo": "posar",
    "posemos": "posar",
    "poses": "pose",
    "posfácios": "posfácio",
    "posiciona": "posicionar",
    "posicionada": "posicionar",
    "posicionadas": "posicionar",
    "posicionado": "posicionar",
    "posicionados": "posicionar",
    "posicionai": "posicionar",
    "posicionais": "posicionar",
    "posicionam": "posicionar",
    "posicionamentos": "posicionamento",
    "posicionamo": "posicionar",
    "posicionamos": "posicionar",
    "posicionando": "posicionar",
    "posicionara": "posicionar",
    "posicionaram": "posicionar",
    "posicionaras": "posicionar",
    "posicionarde": "posicionar",
    "posicionardes": "posicionar",
    "posicionare": "posicionar",
    "posicionarei": "posicionar",
    "posicionareis": "posicionar",
    "posicionarem": "posicionar",
    "posicionaremos": "posicionar",
    "posicionares": "posicionar",
    "posicionaria": "posicionar",
    "posicionariam": "posicionar",
    "posicionarias": "posicionar",
    "posicionarmo": "posicionar",
    "posicionarmos": "posicionar",
    "posicionará": "posicionar",
    "posicionarás": "posicionar",
    "posicionarão": "posicionar",
    "posicionaríamos": "posicionar",
    "posicionaríeis": "posicionar",
    "posicionas": "posicionar",
    "posicionasse": "posicionar",
    "posicionassem": "posicionar",
    "posicionasses": "posicionar",
    "posicionaste": "posicionar",
    "posicionastes": "posicionar",
    "posicionava": "posicionar",
    "posicionavam": "posicionar",
    "posicionavas": "posicionar",
    "posicione": "posicionar",
    "posicionei": "posicionar",
    "posicioneis": "posicionar",
    "posicionem": "posicionar",
    "posicionemo": "posicionar",
    "posicionemos": "posicionar",
    "posiciones": "posicionar",
    "posiciono": "posicionar",
    "posicionou": "posicionar",
    "posicioná": "posicionar",
    "posicionámo": "posicionar",
    "posicionámos": "posicionar",
    "posicionáramo": "posicionar",
    "posicionáramos": "posicionar",
    "posicionárei": "posicionar",
    "posicionáreis": "posicionar",
    "posicionásseis": "posicionar",
    "posicionássemos": "posicionar",
    "posicionávamo": "posicionar",
    "posicionávamos": "posicionar",
    "posicionávei": "posicionar",
    "posicionáveis": "posicionável",
    "positiva": "positivo",
    "positivada": "positivar",
    "positivadas": "positivar",
    "positivado": "positivar",
    "positivados": "positivar",
    "positivai": "positivar",
    "positivais": "positivar",
    "positivam": "positivar",
    "positivamo": "positivar",
    "positivamos": "positivar",
    "positivando": "positivar",
    "positivara": "positivar",
    "positivaram": "positivar",
    "positivaras": "positivar",
    "positivarde": "positivar",
    "positivardes": "positivar",
    "positivare": "positivar",
    "positivarei": "positivar",
    "positivareis": "positivar",
    "positivarem": "positivar",
    "positivaremos": "positivar",
    "positivares": "positivar",
    "positivaria": "positivar",
    "positivariam": "positivar",
    "positivarias": "positivar",
    "positivarmo": "positivar",
    "positivarmos": "positivar",
    "positivará": "positivar",
    "positivarás": "positivar",
    "positivarão": "positivar",
    "positivaríamos": "positivar",
    "positivaríeis": "positivar",
    "positivas": "positivo",
    "positivasse": "positivar",
    "positivassem": "positivar",
    "positivasses": "positivar",
    "positivaste": "positivar",
    "positivastes": "positivar",
    "positivava": "positivar",
    "positivavam": "positivar",
    "positivavas": "positivar",
    "positive": "positivar",
    "positivei": "positivar",
    "positiveis": "positivar",
    "positivem": "positivar",
    "positivemo": "positivar",
    "positivemos": "positivar",
    "positives": "positivar",
    "positividades": "positividade",
    "positivismos": "positivismo",
    "positivistas": "positivista",
    "positivo": "positivar",
    "positivos": "positivo",
    "positivou": "positivar",
    "positivá": "positivar",
    "positivámo": "positivar",
    "positivámos": "positivar",
    "positiváramo": "positivar",
    "positiváramos": "positivar",
    "positivárei": "positivar",
    "positiváreis": "positivar",
    "positivásseis": "positivar",
    "positivássemos": "positivar",
    "positivávamo": "positivar",
    "positivávamos": "positivar",
    "positivávei": "positivar",
    "positiváveis": "positivar",
    "positrónica": "positrónico",
    "positrónicas": "positrónico",
    "positrónicos": "positrónico",
    "positrónios": "positrónio",
    "positrões": "positrão",
    "positões": "positão",
    "posições": "posição",
    "poso": "posar",
    "posologias": "posologia",
    "posológica": "posológico",
    "posológicas": "posológico",
    "posológicos": "posológico",
    "posou": "posar",
    "pospelos": "pospelo",
    "pospernas": "posperna",
    "pospomo": "pospor",
    "pospomos": "pospor",
    "posponde": "pospor",
    "pospondes": "pospor",
    "pospondo": "pospor",
    "posponha": "pospor",
    "posponhais": "pospor",
    "posponham": "pospor",
    "posponhamo": "pospor",
    "posponhamos": "pospor",
    "posponhas": "pospor",
    "posponho": "pospor",
    "pospontos": "posponto",
    "posponíveis": "posponível",
    "posporde": "pospor",
    "pospordes": "pospor",
    "pospore": "pospor",
    "posporei": "pospor",
    "posporeis": "pospor",
    "posporem": "pospor",
    "posporemos": "pospor",
    "pospores": "pospor",
    "posporia": "pospor",
    "posporiam": "pospor",
    "posporias": "pospor",
    "pospormo": "pospor",
    "pospormos": "pospor",
    "posporá": "pospor",
    "posporás": "pospor",
    "posporão": "pospor",
    "posporíamos": "pospor",
    "posporíeis": "pospor",
    "pospositiva": "pospositivo",
    "pospositivas": "pospositivo",
    "pospositivos": "pospositivo",
    "posposições": "posposição",
    "posposta": "posposto",
    "pospostas": "posposto",
    "posposto": "pospor",
    "pospostos": "posposto",
    "pospunha": "pospor",
    "pospunham": "pospor",
    "pospunhas": "pospor",
    "pospus": "pospor",
    "pospusemo": "pospor",
    "pospusemos": "pospor",
    "pospuser": "pospor",
    "pospusera": "pospor",
    "pospuseram": "pospor",
    "pospuseras": "pospor",
    "pospuserdes": "pospor",
    "pospuserem": "pospor",
    "pospuseres": "pospor",
    "pospusermos": "pospor",
    "pospusesse": "pospor",
    "pospusessem": "pospor",
    "pospusesses": "pospor",
    "pospuseste": "pospor",
    "pospusestes": "pospor",
    "pospuséramo": "pospor",
    "pospuséramos": "pospor",
    "pospusérei": "pospor",
    "pospuséreis": "pospor",
    "pospusésseis": "pospor",
    "pospuséssemos": "pospor",
    "pospérmica": "pospérmico",
    "pospérmicas": "pospérmico",
    "pospérmicos": "pospérmico",
    "pospô": "pospor",
    "pospôs": "pospor",
    "pospõe": "pospor",
    "pospõem": "pospor",
    "pospões": "pospor",
    "pospúnhamo": "pospor",
    "pospúnhamos": "pospor",
    "pospúnhei": "pospor",
    "pospúnheis": "pospor",
    "possa": "poder",
    "possais": "poder",
    "possam": "poder",
    "possamo": "poder",
    "possamos": "poder",
    "possantes": "possante",
    "possanças": "possança",
    "possas": "poder",
    "posseiros": "posseiro",
    "posses": "posse",
    "possessa": "possesso",
    "possessas": "possesso",
    "possessibilidades": "possessibilidade",
    "possessiva": "possessivo",
    "possessivas": "possessivo",
    "possessivos": "possessivo",
    "possessora": "possessor",
    "possessoras": "possessor",
    "possessores": "possessor",
    "possessos": "possesso",
    "possessíveis": "possessível",
    "possessória": "possessório",
    "possessórias": "possessório",
    "possessórios": "possessório",
    "possessões": "possessão",
    "possibilidades": "possibilidade",
    "possibilismos": "possibilismo",
    "possibilistas": "possibilista",
    "possibilita": "possibilitar",
    "possibilitada": "possibilitar",
    "possibilitadas": "possibilitar",
    "possibilitado": "possibilitar",
    "possibilitados": "possibilitar",
    "possibilitai": "possibilitar",
    "possibilitais": "possibilitar",
    "possibilitam": "possibilitar",
    "possibilitamo": "possibilitar",
    "possibilitamos": "possibilitar",
    "possibilitando": "possibilitar",
    "possibilitara": "possibilitar",
    "possibilitaram": "possibilitar",
    "possibilitaras": "possibilitar",
    "possibilitarde": "possibilitar",
    "possibilitardes": "possibilitar",
    "possibilitare": "possibilitar",
    "possibilitarei": "possibilitar",
    "possibilitareis": "possibilitar",
    "possibilitarem": "possibilitar",
    "possibilitaremos": "possibilitar",
    "possibilitares": "possibilitar",
    "possibilitaria": "possibilitar",
    "possibilitariam": "possibilitar",
    "possibilitarias": "possibilitar",
    "possibilitarmo": "possibilitar",
    "possibilitarmos": "possibilitar",
    "possibilitará": "possibilitar",
    "possibilitarás": "possibilitar",
    "possibilitarão": "possibilitar",
    "possibilitaríamos": "possibilitar",
    "possibilitaríeis": "possibilitar",
    "possibilitas": "possibilitar",
    "possibilitasse": "possibilitar",
    "possibilitassem": "possibilitar",
    "possibilitasses": "possibilitar",
    "possibilitaste": "possibilitar",
    "possibilitastes": "possibilitar",
    "possibilitava": "possibilitar",
    "possibilitavam": "possibilitar",
    "possibilitavas": "possibilitar",
    "possibilite": "possibilitar",
    "possibilitei": "possibilitar",
    "possibiliteis": "possibilitar",
    "possibilitem": "possibilitar",
    "possibilitemo": "possibilitar",
    "possibilitemos": "possibilitar",
    "possibilites": "possibilitar",
    "possibilito": "possibilitar",
    "possibilitou": "possibilitar",
    "possibilitá": "possibilitar",
    "possibilitámo": "possibilitar",
    "possibilitámos": "possibilitar",
    "possibilitáramo": "possibilitar",
    "possibilitáramos": "possibilitar",
    "possibilitárei": "possibilitar",
    "possibilitáreis": "possibilitar",
    "possibilitásseis": "possibilitar",
    "possibilitássemos": "possibilitar",
    "possibilitávamo": "possibilitar",
    "possibilitávamos": "possibilitar",
    "possibilitávei": "possibilitar",
    "possibilitáveis": "possibilitar",
    "possidentes": "possidente",
    "possidónia": "possidónio",
    "possidónias": "possidónio",
    "possidónios": "possidónio",
    "posso": "poder",
    "possua": "possuir",
    "possuais": "possuir",
    "possuam": "possuir",
    "possuamo": "possuir",
    "possuamos": "possuir",
    "possuas": "possuir",
    "possuem": "possuir",
    "possui": "possuir",
    "possuidora": "possuidor",
    "possuidoras": "possuidor",
    "possuidores": "possuidor",
    "possuindo": "possuir",
    "possuintes": "possuinte",
    "possuirde": "possuir",
    "possuirdes": "possuir",
    "possuirei": "possuir",
    "possuireis": "possuir",
    "possuiremos": "possuir",
    "possuiria": "possuir",
    "possuiriam": "possuir",
    "possuirias": "possuir",
    "possuirmo": "possuir",
    "possuirmos": "possuir",
    "possuirá": "possuir",
    "possuirás": "possuir",
    "possuirão": "possuir",
    "possuiríamos": "possuir",
    "possuiríeis": "possuir",
    "possuis": "possuir",
    "possuiu": "possuir",
    "possuo": "possuir",
    "possuí": "possuir",
    "possuía": "possuir",
    "possuíam": "possuir",
    "possuíamo": "possuir",
    "possuíamos": "possuir",
    "possuías": "possuir",
    "possuída": "possuir",
    "possuídas": "possuir",
    "possuído": "possuir",
    "possuídos": "possuir",
    "possuíei": "possuir",
    "possuíeis": "possuir",
    "possuímo": "possuir",
    "possuímos": "possuir",
    "possuíra": "possuir",
    "possuíram": "possuir",
    "possuíramo": "possuir",
    "possuíramos": "possuir",
    "possuíras": "possuir",
    "possuíre": "possuir",
    "possuírei": "possuir",
    "possuíreis": "possuir",
    "possuírem": "possuir",
    "possuíres": "possuir",
    "possuís": "possuir",
    "possuísse": "possuir",
    "possuísseis": "possuir",
    "possuíssem": "possuir",
    "possuíssemos": "possuir",
    "possuísses": "possuir",
    "possuíste": "possuir",
    "possuístes": "possuir",
    "possíveis": "possível",
    "posta": "posto",
    "postada": "postar",
    "postadas": "postar",
    "postado": "postar",
    "postados": "postar",
    "postai": "postar",
    "postais": "postar",
    "postam": "postar",
    "postamo": "postar",
    "postamos": "postar",
    "postando": "postar",
    "postara": "postar",
    "postaram": "postar",
    "postaras": "postar",
    "postarde": "postar",
    "postardes": "postar",
    "postare": "postar",
    "postarei": "postar",
    "postareis": "postar",
    "postarem": "postar",
    "postaremos": "postar",
    "postares": "postar",
    "postaria": "postar",
    "postariam": "postar",
    "postarias": "postar",
    "postarmo": "postar",
    "postarmos": "postar",
    "postará": "postar",
    "postarás": "postar",
    "postarão": "postar",
    "postaríamos": "postar",
    "postaríeis": "postar",
    "postas": "posto",
    "postasse": "postar",
    "postassem": "postar",
    "postasses": "postar",
    "postaste": "postar",
    "postastes": "postar",
    "postava": "postar",
    "postavam": "postar",
    "postavas": "postar",
    "poste": "postar",
    "postei": "postar",
    "posteira": "posteiro",
    "posteiras": "posteiro",
    "posteiros": "posteiro",
    "posteis": "postar",
    "posteja": "postejar",
    "postejada": "postejar",
    "postejadas": "postejar",
    "postejado": "postejar",
    "postejados": "postejar",
    "postejai": "postejar",
    "postejais": "postejar",
    "postejam": "postejar",
    "postejamo": "postejar",
    "postejamos": "postejar",
    "postejando": "postejar",
    "postejara": "postejar",
    "postejaram": "postejar",
    "postejaras": "postejar",
    "postejarde": "postejar",
    "postejardes": "postejar",
    "postejare": "postejar",
    "postejarei": "postejar",
    "postejareis": "postejar",
    "postejarem": "postejar",
    "postejaremos": "postejar",
    "postejares": "postejar",
    "postejaria": "postejar",
    "postejariam": "postejar",
    "postejarias": "postejar",
    "postejarmo": "postejar",
    "postejarmos": "postejar",
    "postejará": "postejar",
    "postejarás": "postejar",
    "postejarão": "postejar",
    "postejaríamos": "postejar",
    "postejaríeis": "postejar",
    "postejas": "postejar",
    "postejasse": "postejar",
    "postejassem": "postejar",
    "postejasses": "postejar",
    "postejaste": "postejar",
    "postejastes": "postejar",
    "postejava": "postejar",
    "postejavam": "postejar",
    "postejavas": "postejar",
    "posteje": "postejar",
    "postejei": "postejar",
    "postejeis": "postejar",
    "postejem": "postejar",
    "postejemo": "postejar",
    "postejemos": "postejar",
    "postejes": "postejar",
    "postejo": "postejar",
    "postejou": "postejar",
    "postejá": "postejar",
    "postejámo": "postejar",
    "postejámos": "postejar",
    "postejáramo": "postejar",
    "postejáramos": "postejar",
    "postejárei": "postejar",
    "postejáreis": "postejar",
    "postejásseis": "postejar",
    "postejássemos": "postejar",
    "postejávamo": "postejar",
    "postejávamos": "postejar",
    "postejávei": "postejar",
    "postejáveis": "postejar",
    "postem": "postar",
    "postemas": "postema",
    "postemeiros": "postemeiro",
    "postemo": "postar",
    "postemos": "postar",
    "postemões": "postemão",
    "posterga": "postergar",
    "postergada": "postergar",
    "postergadas": "postergar",
    "postergado": "postergar",
    "postergadora": "postergador",
    "postergadoras": "postergador",
    "postergadores": "postergador",
    "postergados": "postergar",
    "postergai": "postergar",
    "postergais": "postergar",
    "postergam": "postergar",
    "postergamo": "postergar",
    "postergamos": "postergar",
    "postergando": "postergar",
    "postergara": "postergar",
    "postergaram": "postergar",
    "postergaras": "postergar",
    "postergarde": "postergar",
    "postergardes": "postergar",
    "postergare": "postergar",
    "postergarei": "postergar",
    "postergareis": "postergar",
    "postergarem": "postergar",
    "postergaremos": "postergar",
    "postergares": "postergar",
    "postergaria": "postergar",
    "postergariam": "postergar",
    "postergarias": "postergar",
    "postergarmo": "postergar",
    "postergarmos": "postergar",
    "postergará": "postergar",
    "postergarás": "postergar",
    "postergarão": "postergar",
    "postergaríamos": "postergar",
    "postergaríeis": "postergar",
    "postergas": "postergar",
    "postergasse": "postergar",
    "postergassem": "postergar",
    "postergasses": "postergar",
    "postergaste": "postergar",
    "postergastes": "postergar",
    "postergava": "postergar",
    "postergavam": "postergar",
    "postergavas": "postergar",
    "postergações": "postergação",
    "postergo": "postergar",
    "postergou": "postergar",
    "postergue": "postergar",
    "posterguei": "postergar",
    "postergueis": "postergar",
    "posterguem": "postergar",
    "posterguemo": "postergar",
    "posterguemos": "postergar",
    "postergues": "postergar",
    "postergá": "postergar",
    "postergámo": "postergar",
    "postergámos": "postergar",
    "postergáramo": "postergar",
    "postergáramos": "postergar",
    "postergárei": "postergar",
    "postergáreis": "postergar",
    "postergásseis": "postergar",
    "postergássemos": "postergar",
    "postergávamo": "postergar",
    "postergávamos": "postergar",
    "postergávei": "postergar",
    "postergáveis": "postergar",
    "posteridades": "posteridade",
    "posteriores": "posterior",
    "posterioridades": "posterioridade",
    "posteriza": "posterizar",
    "posterizada": "posterizar",
    "posterizadas": "posterizar",
    "posterizado": "posterizar",
    "posterizados": "posterizar",
    "posterizai": "posterizar",
    "posterizais": "posterizar",
    "posterizam": "posterizar",
    "posterizamo": "posterizar",
    "posterizamos": "posterizar",
    "posterizando": "posterizar",
    "posterizara": "posterizar",
    "posterizaram": "posterizar",
    "posterizaras": "posterizar",
    "posterizarde": "posterizar",
    "posterizardes": "posterizar",
    "posterizare": "posterizar",
    "posterizarei": "posterizar",
    "posterizareis": "posterizar",
    "posterizarem": "posterizar",
    "posterizaremos": "posterizar",
    "posterizares": "posterizar",
    "posterizaria": "posterizar",
    "posterizariam": "posterizar",
    "posterizarias": "posterizar",
    "posterizarmo": "posterizar",
    "posterizarmos": "posterizar",
    "posterizará": "posterizar",
    "posterizarás": "posterizar",
    "posterizarão": "posterizar",
    "posterizaríamos": "posterizar",
    "posterizaríeis": "posterizar",
    "posterizas": "posterizar",
    "posterizasse": "posterizar",
    "posterizassem": "posterizar",
    "posterizasses": "posterizar",
    "posterizaste": "posterizar",
    "posterizastes": "posterizar",
    "posterizava": "posterizar",
    "posterizavam": "posterizar",
    "posterizavas": "posterizar",
    "posterize": "posterizar",
    "posterizei": "posterizar",
    "posterizeis": "posterizar",
    "posterizem": "posterizar",
    "posterizemo": "posterizar",
    "posterizemos": "posterizar",
    "posterizes": "posterizar",
    "posterizo": "posterizar",
    "posterizou": "posterizar",
    "posterizá": "posterizar",
    "posterizámo": "posterizar",
    "posterizámos": "posterizar",
    "posterizáramo": "posterizar",
    "posterizáramos": "posterizar",
    "posterizárei": "posterizar",
    "posterizáreis": "posterizar",
    "posterizásseis": "posterizar",
    "posterizássemos": "posterizar",
    "posterizávamo": "posterizar",
    "posterizávamos": "posterizar",
    "posterizávei": "posterizar",
    "posterizáveis": "posterizar",
    "posternadora": "posternador",
    "posternadoras": "posternador",
    "posternadores": "posternador",
    "posternações": "posternação",
    "postes": "poste",
    "postigos": "postigo",
    "postilas": "postila",
    "postilhões": "postilhão",
    "postiça": "postiço",
    "postiças": "postiço",
    "postiços": "postiço",
    "posto": "postar",
    "postos": "posto",
    "postou": "postar",
    "postrema": "postremo",
    "postremas": "postremo",
    "postremos": "postremo",
    "postres": "postre",
    "postula": "postular",
    "postulada": "postular",
    "postuladas": "postular",
    "postulado": "postular",
    "postuladora": "postulador",
    "postuladoras": "postulador",
    "postuladores": "postulador",
    "postulados": "postular",
    "postulai": "postular",
    "postulais": "postular",
    "postulam": "postular",
    "postulamo": "postular",
    "postulamos": "postular",
    "postulando": "postular",
    "postulantes": "postulante",
    "postulara": "postular",
    "postularam": "postular",
    "postularas": "postular",
    "postularde": "postular",
    "postulardes": "postular",
    "postulare": "postular",
    "postularei": "postular",
    "postulareis": "postular",
    "postularem": "postular",
    "postularemos": "postular",
    "postulares": "postular",
    "postularia": "postular",
    "postulariam": "postular",
    "postularias": "postular",
    "postularmo": "postular",
    "postularmos": "postular",
    "postulará": "postular",
    "postularás": "postular",
    "postularão": "postular",
    "postularíamos": "postular",
    "postularíeis": "postular",
    "postulas": "postular",
    "postulasse": "postular",
    "postulassem": "postular",
    "postulasses": "postular",
    "postulaste": "postular",
    "postulastes": "postular",
    "postulava": "postular",
    "postulavam": "postular",
    "postulavas": "postular",
    "postulações": "postulação",
    "postule": "postular",
    "postulei": "postular",
    "postuleis": "postular",
    "postulem": "postular",
    "postulemo": "postular",
    "postulemos": "postular",
    "postules": "postular",
    "postulo": "postular",
    "postulou": "postular",
    "postulá": "postular",
    "postulámo": "postular",
    "postulámos": "postular",
    "postuláramo": "postular",
    "postuláramos": "postular",
    "postulárei": "postular",
    "postuláreis": "postular",
    "postulásseis": "postular",
    "postulássemos": "postular",
    "postulávamo": "postular",
    "postulávamos": "postular",
    "postulávei": "postular",
    "postuláveis": "postulável",
    "postura": "posturar",
    "posturada": "posturar",
    "posturadas": "posturar",
    "posturado": "posturar",
    "posturados": "posturar",
    "posturai": "posturar",
    "posturais": "posturar",
    "posturam": "posturar",
    "posturamo": "posturar",
    "posturamos": "posturar",
    "posturando": "posturar",
    "posturara": "posturar",
    "posturaram": "posturar",
    "posturaras": "posturar",
    "posturardes": "posturar",
    "posturarei": "posturar",
    "posturareis": "posturar",
    "posturarem": "posturar",
    "posturaremos": "posturar",
    "posturares": "posturar",
    "posturaria": "posturar",
    "posturariam": "posturar",
    "posturarias": "posturar",
    "posturarmo": "posturar",
    "posturarmos": "posturar",
    "posturará": "posturar",
    "posturarás": "posturar",
    "posturarão": "posturar",
    "posturaríamos": "posturar",
    "posturaríeis": "posturar",
    "posturas": "posturar",
    "posturasse": "posturar",
    "posturassem": "posturar",
    "posturasses": "posturar",
    "posturaste": "posturar",
    "posturastes": "posturar",
    "posturava": "posturar",
    "posturavam": "posturar",
    "posturavas": "posturar",
    "posture": "posturar",
    "posturei": "posturar",
    "postureis": "posturar",
    "posturem": "posturar",
    "posturemo": "posturar",
    "posturemos": "posturar",
    "postures": "posturar",
    "posturo": "posturar",
    "posturou": "posturar",
    "posturámo": "posturar",
    "posturámos": "posturar",
    "posturáramo": "posturar",
    "posturáramos": "posturar",
    "posturáreis": "posturar",
    "posturásseis": "posturar",
    "posturássemos": "posturar",
    "posturávamo": "posturar",
    "posturávamos": "posturar",
    "posturáveis": "posturar",
    "postá": "postar",
    "postámo": "postar",
    "postámos": "postar",
    "postáramo": "postar",
    "postáramos": "postar",
    "postárei": "postar",
    "postáreis": "postar",
    "postásseis": "postar",
    "postássemos": "postar",
    "postávamo": "postar",
    "postávamos": "postar",
    "postávei": "postar",
    "postáveis": "postar",
    "postémica": "postémico",
    "postémicas": "postémico",
    "postémicos": "postémico",
    "postónica": "postónico",
    "postónicas": "postónico",
    "postónicos": "postónico",
    "posámo": "posar",
    "posámos": "posar",
    "posáramo": "posar",
    "posáramos": "posar",
    "posáreis": "posar",
    "posásseis": "posar",
    "posássemos": "posar",
    "posávamo": "posar",
    "posávamos": "posar",
    "posáveis": "posar",
    "potabilidades": "potabilidade",
    "potamitas": "potamita",
    "potamofilias": "potamofilia",
    "potamofílica": "potamofílico",
    "potamofílicas": "potamofílico",
    "potamofílicos": "potamofílico",
    "potamogetonáceas": "potamogetonácea",
    "potamografias": "potamografia",
    "potamográfica": "potamográfico",
    "potamográficas": "potamográfico",
    "potamográficos": "potamográfico",
    "potamolatrias": "potamolatria",
    "potamologias": "potamologia",
    "potamologistas": "potamologista",
    "potamológica": "potamológico",
    "potamológicas": "potamológico",
    "potamológicos": "potamológico",
    "potamomímica": "potamomímico",
    "potamomímicas": "potamomímico",
    "potamomímicos": "potamomímico",
    "potamonímias": "potamonímia",
    "potamoplanctónica": "potamoplanctónico",
    "potamoplanctónicas": "potamoplanctónico",
    "potamoplanctónicos": "potamoplanctónico",
    "potamoplânctons": "potamoplâncton",
    "potamófila": "potamófilo",
    "potamófilas": "potamófilo",
    "potamófilos": "potamófilo",
    "potamógrafa": "potamógrafo",
    "potamógrafas": "potamógrafo",
    "potamógrafos": "potamógrafo",
    "potamólatras": "potamólatra",
    "potamóloga": "potamólogo",
    "potamólogas": "potamólogo",
    "potamólogos": "potamólogo",
    "potamónimos": "potamónimo",
    "potamótoca": "potamótoco",
    "potamótocas": "potamótoco",
    "potamótocos": "potamótoco",
    "potassas": "potassa",
    "poteica": "poteico",
    "poteicas": "poteico",
    "poteicos": "poteico",
    "potencia": "potenciar",
    "potenciada": "potenciar",
    "potenciadas": "potenciar",
    "potenciado": "potenciar",
    "potenciadora": "potenciador",
    "potenciadoras": "potenciador",
    "potenciadores": "potenciador",
    "potenciados": "potenciar",
    "potenciai": "potenciar",
    "potenciais": "potenciar",
    "potencialidades": "potencialidade",
    "potencializa": "potencializar",
    "potencializada": "potencializar",
    "potencializadas": "potencializar",
    "potencializado": "potencializar",
    "potencializados": "potencializar",
    "potencializai": "potencializar",
    "potencializais": "potencializar",
    "potencializam": "potencializar",
    "potencializamo": "potencializar",
    "potencializamos": "potencializar",
    "potencializando": "potencializar",
    "potencializara": "potencializar",
    "potencializaram": "potencializar",
    "potencializaras": "potencializar",
    "potencializarde": "potencializar",
    "potencializardes": "potencializar",
    "potencializare": "potencializar",
    "potencializarei": "potencializar",
    "potencializareis": "potencializar",
    "potencializarem": "potencializar",
    "potencializaremos": "potencializar",
    "potencializares": "potencializar",
    "potencializaria": "potencializar",
    "potencializariam": "potencializar",
    "potencializarias": "potencializar",
    "potencializarmo": "potencializar",
    "potencializarmos": "potencializar",
    "potencializará": "potencializar",
    "potencializarás": "potencializar",
    "potencializarão": "potencializar",
    "potencializaríamos": "potencializar",
    "potencializaríeis": "potencializar",
    "potencializas": "potencializar",
    "potencializasse": "potencializar",
    "potencializassem": "potencializar",
    "potencializasses": "potencializar",
    "potencializaste": "potencializar",
    "potencializastes": "potencializar",
    "potencializava": "potencializar",
    "potencializavam": "potencializar",
    "potencializavas": "potencializar",
    "potencialize": "potencializar",
    "potencializei": "potencializar",
    "potencializeis": "potencializar",
    "potencializem": "potencializar",
    "potencializemo": "potencializar",
    "potencializemos": "potencializar",
    "potencializes": "potencializar",
    "potencializo": "potencializar",
    "potencializou": "potencializar",
    "potencializá": "potencializar",
    "potencializámo": "potencializar",
    "potencializámos": "potencializar",
    "potencializáramo": "potencializar",
    "potencializáramos": "potencializar",
    "potencializárei": "potencializar",
    "potencializáreis": "potencializar",
    "potencializásseis": "potencializar",
    "potencializássemos": "potencializar",
    "potencializávamo": "potencializar",
    "potencializávamos": "potencializar",
    "potencializávei": "potencializar",
    "potencializáveis": "potencializar",
    "potenciam": "potenciar",
    "potenciamo": "potenciar",
    "potenciamos": "potenciar",
    "potenciando": "potenciar",
    "potenciara": "potenciar",
    "potenciaram": "potenciar",
    "potenciaras": "potenciar",
    "potenciarde": "potenciar",
    "potenciardes": "potenciar",
    "potenciare": "potenciar",
    "potenciarei": "potenciar",
    "potenciareis": "potenciar",
    "potenciarem": "potenciar",
    "potenciaremos": "potenciar",
    "potenciares": "potenciar",
    "potenciaria": "potenciar",
    "potenciariam": "potenciar",
    "potenciarias": "potenciar",
    "potenciarmo": "potenciar",
    "potenciarmos": "potenciar",
    "potenciará": "potenciar",
    "potenciarás": "potenciar",
    "potenciarão": "potenciar",
    "potenciaríamos": "potenciar",
    "potenciaríeis": "potenciar",
    "potencias": "potenciar",
    "potenciasse": "potenciar",
    "potenciassem": "potenciar",
    "potenciasses": "potenciar",
    "potenciaste": "potenciar",
    "potenciastes": "potenciar",
    "potenciava": "potenciar",
    "potenciavam": "potenciar",
    "potenciavas": "potenciar",
    "potenciações": "potenciação",
    "potencie": "potenciar",
    "potenciei": "potenciar",
    "potencieis": "potenciar",
    "potenciem": "potenciar",
    "potenciemo": "potenciar",
    "potenciemos": "potenciar",
    "potencies": "potenciar",
    "potencio": "potenciar",
    "potenciometrias": "potenciometria",
    "potenciométrica": "potenciométrico",
    "potenciométricas": "potenciométrico",
    "potenciométricos": "potenciométrico",
    "potenciostática": "potenciostático",
    "potenciostáticas": "potenciostático",
    "potenciostáticos": "potenciostático",
    "potenciou": "potenciar",
    "potenciá": "potenciar",
    "potenciámo": "potenciar",
    "potenciámos": "potenciar",
    "potenciáramo": "potenciar",
    "potenciáramos": "potenciar",
    "potenciárei": "potenciar",
    "potenciáreis": "potenciar",
    "potenciásseis": "potenciar",
    "potenciássemos": "potenciar",
    "potenciávamo": "potenciar",
    "potenciávamos": "potenciar",
    "potenciávei": "potenciar",
    "potenciáveis": "potenciar",
    "potenciómetros": "potenciómetro",
    "potencióstatos": "potencióstato",
    "potentada": "potentado",
    "potentadas": "potentado",
    "potentados": "potentado",
    "potentes": "potente",
    "potentilhas": "potentilha",
    "potentíssima": "potente",
    "potentíssimas": "potente",
    "potentíssimo": "potente",
    "potentíssimos": "potente",
    "poternas": "poterna",
    "potes": "pote",
    "potestades": "potestade",
    "potologias": "potologia",
    "potologistas": "potologista",
    "potomanias": "potomania",
    "potomaníaca": "potomaníaco",
    "potomaníacas": "potomaníaco",
    "potomaníacos": "potomaníaco",
    "potometrias": "potometria",
    "potos": "poto",
    "potra": "potro",
    "potranca": "potranco",
    "potrancadas": "potrancada",
    "potrancas": "potranco",
    "potrancos": "potranco",
    "potras": "potro",
    "potreadas": "potreada",
    "potreira": "potreiro",
    "potreiras": "potreiro",
    "potreiros": "potreiro",
    "potrilha": "potrilho",
    "potrilhas": "potrilho",
    "potrilhos": "potrilho",
    "potris": "potril",
    "potros": "potro",
    "potrosa": "potroso",
    "potrosas": "potroso",
    "potrosos": "potroso",
    "potássica": "potássico",
    "potássicas": "potássico",
    "potássicos": "potássico",
    "potássios": "potássio",
    "potáveis": "potável",
    "potâmides": "potâmide",
    "potências": "potência",
    "potóloga": "potólogo",
    "potólogas": "potólogo",
    "potólogos": "potólogo",
    "potómana": "potómano",
    "potómanas": "potómano",
    "potómanos": "potómano",
    "potómetros": "potómetro",
    "pouca": "pouco",
    "poucacha": "poucacho",
    "poucachas": "poucacho",
    "poucachinha": "poucachinho",
    "poucachinhas": "poucachinho",
    "poucachinhos": "poucachinho",
    "poucachos": "poucacho",
    "poucas": "pouco",
    "poucochinha": "poucochinho",
    "poucochinhas": "poucochinho",
    "poucochinhos": "poucochinho",
    "poucos": "pouco",
    "poulas": "poula",
    "poules": "poule",
    "poulos": "poulo",
    "poupa": "poupar",
    "poupada": "poupar",
    "poupadas": "poupar",
    "poupadinha": "poupado",
    "poupadinhas": "poupado",
    "poupadinho": "poupado",
    "poupadinhos": "poupado",
    "poupadita": "poupado",
    "poupaditas": "poupado",
    "poupadito": "poupado",
    "poupaditos": "poupado",
    "poupado": "poupar",
    "poupadora": "poupador",
    "poupadoras": "poupador",
    "poupadores": "poupador",
    "poupados": "poupar",
    "poupadíssima": "poupado",
    "poupadíssimas": "poupado",
    "poupadíssimo": "poupado",
    "poupadíssimos": "poupado",
    "poupai": "poupar",
    "poupais": "poupar",
    "poupam": "poupar",
    "poupamo": "poupar",
    "poupamos": "poupar",
    "poupando": "poupar",
    "poupanças": "poupança",
    "poupara": "poupar",
    "pouparam": "poupar",
    "pouparas": "poupar",
    "pouparde": "poupar",
    "poupardes": "poupar",
    "poupare": "poupar",
    "pouparei": "poupar",
    "poupareis": "poupar",
    "pouparem": "poupar",
    "pouparemos": "poupar",
    "poupares": "poupar",
    "pouparia": "poupar",
    "poupariam": "poupar",
    "pouparias": "poupar",
    "pouparmo": "poupar",
    "pouparmos": "poupar",
    "poupará": "poupar",
    "pouparás": "poupar",
    "pouparão": "poupar",
    "pouparíamos": "poupar",
    "pouparíeis": "poupar",
    "poupas": "poupar",
    "poupasse": "poupar",
    "poupassem": "poupar",
    "poupasses": "poupar",
    "poupaste": "poupar",
    "poupastes": "poupar",
    "poupava": "poupar",
    "poupavam": "poupar",
    "poupavas": "poupar",
    "poupe": "poupar",
    "poupei": "poupar",
    "poupeis": "poupar",
    "poupem": "poupar",
    "poupemo": "poupar",
    "poupemos": "poupar",
    "poupes": "poupar",
    "poupinhas": "poupinha",
    "poupo": "poupar",
    "poupou": "poupar",
    "poupuda": "poupudo",
    "poupudas": "poupudo",
    "poupudos": "poupudo",
    "poupá": "poupar",
    "poupámo": "poupar",
    "poupámos": "poupar",
    "poupáramo": "poupar",
    "poupáramos": "poupar",
    "poupárei": "poupar",
    "poupáreis": "poupar",
    "poupásseis": "poupar",
    "poupássemos": "poupar",
    "poupávamo": "poupar",
    "poupávamos": "poupar",
    "poupávei": "poupar",
    "poupáveis": "poupar",
    "pouquidades": "pouquidade",
    "pouquidões": "pouquidão",
    "pouquinha": "pouco",
    "pouquinhas": "pouco",
    "pouquinho": "pouco",
    "pouquinhos": "pouquinho",
    "pouquita": "pouco",
    "pouquitas": "pouco",
    "pouquito": "pouco",
    "pouquitos": "pouco",
    "pouquíssima": "pouco",
    "pouquíssimas": "pouco",
    "pouquíssimo": "pouco",
    "pouquíssimos": "pouco",
    "pousa": "pousar",
    "pousada": "pousar",
    "pousadas": "pousar",
    "pousadeira": "pousadeiro",
    "pousadeiras": "pousadeiro",
    "pousadeiros": "pousadeiro",
    "pousadias": "pousadia",
    "pousado": "pousar",
    "pousados": "pousar",
    "pousadouros": "pousadouro",
    "pousai": "pousar",
    "pousais": "pousar",
    "pousam": "pousar",
    "pousamo": "pousar",
    "pousamos": "pousar",
    "pousando": "pousar",
    "pousara": "pousar",
    "pousaram": "pousar",
    "pousaras": "pousar",
    "pousarde": "pousar",
    "pousardes": "pousar",
    "pousare": "pousar",
    "pousarei": "pousar",
    "pousareis": "pousar",
    "pousarem": "pousar",
    "pousaremos": "pousar",
    "pousares": "pousar",
    "pousaria": "pousar",
    "pousariam": "pousar",
    "pousarias": "pousar",
    "pousarmo": "pousar",
    "pousarmos": "pousar",
    "pousará": "pousar",
    "pousarás": "pousar",
    "pousarão": "pousar",
    "pousaríamos": "pousar",
    "pousaríeis": "pousar",
    "pousas": "pousar",
    "pousasse": "pousar",
    "pousassem": "pousar",
    "pousasses": "pousar",
    "pousaste": "pousar",
    "pousastes": "pousar",
    "pousava": "pousar",
    "pousavam": "pousar",
    "pousavas": "pousar",
    "pouse": "pousar",
    "pousei": "pousar",
    "pouseira": "pouseiro",
    "pouseiras": "pouseiro",
    "pouseiros": "pouseiro",
    "pouseis": "pousar",
    "pousem": "pousar",
    "pousemo": "pousar",
    "pousemos": "pousar",
    "pouses": "pousar",
    "pousios": "pousio",
    "pouso": "pousar",
    "pousos": "pouso",
    "pousou": "pousar",
    "pousá": "pousar",
    "pousámo": "pousar",
    "pousámos": "pousar",
    "pousáramo": "pousar",
    "pousáramos": "pousar",
    "pousárei": "pousar",
    "pousáreis": "pousar",
    "pousásseis": "pousar",
    "pousássemos": "pousar",
    "pousávamo": "pousar",
    "pousávamos": "pousar",
    "pousávei": "pousar",
    "pousáveis": "pousar",
    "pouta": "poutar",
    "poutada": "poutar",
    "poutadas": "poutar",
    "poutado": "poutar",
    "poutados": "poutar",
    "poutai": "poutar",
    "poutais": "poutar",
    "poutam": "poutar",
    "poutamo": "poutar",
    "poutamos": "poutar",
    "poutando": "poutar",
    "poutara": "poutar",
    "poutaram": "poutar",
    "poutaras": "poutar",
    "poutarde": "poutar",
    "poutardes": "poutar",
    "poutare": "poutar",
    "poutarei": "poutar",
    "poutareis": "poutar",
    "poutarem": "poutar",
    "poutaremos": "poutar",
    "poutares": "poutar",
    "poutaria": "poutar",
    "poutariam": "poutar",
    "poutarias": "poutar",
    "poutarmo": "poutar",
    "poutarmos": "poutar",
    "poutará": "poutar",
    "poutarás": "poutar",
    "poutarão": "poutar",
    "poutaríamos": "poutar",
    "poutaríeis": "poutar",
    "poutas": "poutar",
    "poutasse": "poutar",
    "poutassem": "poutar",
    "poutasses": "poutar",
    "poutaste": "poutar",
    "poutastes": "poutar",
    "poutava": "poutar",
    "poutavam": "poutar",
    "poutavas": "poutar",
    "poute": "poutar",
    "poutei": "poutar",
    "pouteis": "poutar",
    "poutem": "poutar",
    "poutemo": "poutar",
    "poutemos": "poutar",
    "poutes": "poutar",
    "pouto": "poutar",
    "poutou": "poutar",
    "poutá": "poutar",
    "poutámo": "poutar",
    "poutámos": "poutar",
    "poutáramo": "poutar",
    "poutáramos": "poutar",
    "poutárei": "poutar",
    "poutáreis": "poutar",
    "poutásseis": "poutar",
    "poutássemos": "poutar",
    "poutávamo": "poutar",
    "poutávamos": "poutar",
    "poutávei": "poutar",
    "poutáveis": "poutar",
    "poutões": "poutão",
    "povaréus": "povaréu",
    "poveira": "poveiro",
    "poveiras": "poveiro",
    "poveiros": "poveiro",
    "povilhais": "povilhal",
    "poviléus": "poviléu",
    "povinho": "povo",
    "povinhos": "povo",
    "povito": "povo",
    "povitos": "povo",
    "povoa": "povoar",
    "povoada": "povoar",
    "povoadas": "povoar",
    "povoado": "povoar",
    "povoadora": "povoador",
    "povoadoras": "povoador",
    "povoadores": "povoador",
    "povoados": "povoar",
    "povoai": "povoar",
    "povoais": "povoar",
    "povoam": "povoar",
    "povoamentos": "povoamento",
    "povoamo": "povoar",
    "povoamos": "povoar",
    "povoando": "povoar",
    "povoara": "povoar",
    "povoaram": "povoar",
    "povoaras": "povoar",
    "povoarde": "povoar",
    "povoardes": "povoar",
    "povoare": "povoar",
    "povoarei": "povoar",
    "povoareis": "povoar",
    "povoarem": "povoar",
    "povoaremos": "povoar",
    "povoares": "povoar",
    "povoaria": "povoar",
    "povoariam": "povoar",
    "povoarias": "povoar",
    "povoarmo": "povoar",
    "povoarmos": "povoar",
    "povoará": "povoar",
    "povoarás": "povoar",
    "povoarão": "povoar",
    "povoaríamos": "povoar",
    "povoaríeis": "povoar",
    "povoas": "povoar",
    "povoasse": "povoar",
    "povoassem": "povoar",
    "povoasses": "povoar",
    "povoaste": "povoar",
    "povoastes": "povoar",
    "povoava": "povoar",
    "povoavam": "povoar",
    "povoavas": "povoar",
    "povoações": "povoação",
    "povoe": "povoar",
    "povoei": "povoar",
    "povoeiras": "povoeira",
    "povoeis": "povoar",
    "povoem": "povoar",
    "povoemo": "povoar",
    "povoemos": "povoar",
    "povoenses": "povoense",
    "povoes": "povoar",
    "povoléus": "povoléu",
    "povoo": "povoar",
    "povoou": "povoar",
    "povos": "povo",
    "povoá": "povoar",
    "povoámo": "povoar",
    "povoámos": "povoar",
    "povoáramo": "povoar",
    "povoáramos": "povoar",
    "povoárei": "povoar",
    "povoáreis": "povoar",
    "povoásseis": "povoar",
    "povoássemos": "povoar",
    "povoávamo": "povoar",
    "povoávamos": "povoar",
    "povoávei": "povoar",
    "povoáveis": "povoável",
    "pozinho": "pó",
    "pozinhos": "pó",
    "pozito": "pó",
    "pozitos": "pó",
    "pozolanas": "pozolana",
    "pozolâmica": "pozolâmico",
    "pozolâmicas": "pozolâmico",
    "pozolâmicos": "pozolâmico",
    "poáceas": "poácea",
    "poçadas": "poçada",
    "poçais": "poçal",
    "poças": "poça",
    "poçocas": "poçoca",
    "poços": "poço",
    "poções": "poção",
    "poética": "poético",
    "poéticas": "poético",
    "poéticos": "poético",
    "poê": "poer",
    "poêramo": "poer",
    "poêramos": "poer",
    "poêrei": "poer",
    "poêreis": "poer",
    "poêsseis": "poer",
    "poêssemos": "poer",
    "poí": "poer",
    "poía": "poer",
    "poíam": "poer",
    "poíamo": "poer",
    "poíamos": "poer",
    "poías": "poer",
    "poída": "poer",
    "poídas": "poer",
    "poído": "poer",
    "poídos": "poer",
    "poíei": "poer",
    "poíeis": "poer",
    "pp": "p",
    "praceada": "pracear",
    "praceadas": "pracear",
    "praceado": "pracear",
    "praceados": "pracear",
    "praceai": "pracear",
    "praceais": "pracear",
    "praceamo": "pracear",
    "praceamos": "pracear",
    "praceando": "pracear",
    "praceara": "pracear",
    "pracearam": "pracear",
    "pracearas": "pracear",
    "pracearde": "pracear",
    "praceardes": "pracear",
    "praceare": "pracear",
    "pracearei": "pracear",
    "praceareis": "pracear",
    "pracearem": "pracear",
    "pracearemos": "pracear",
    "praceares": "pracear",
    "pracearia": "pracear",
    "praceariam": "pracear",
    "pracearias": "pracear",
    "pracearmo": "pracear",
    "pracearmos": "pracear",
    "praceará": "pracear",
    "pracearás": "pracear",
    "pracearão": "pracear",
    "pracearíamos": "pracear",
    "pracearíeis": "pracear",
    "praceasse": "pracear",
    "praceassem": "pracear",
    "praceasses": "pracear",
    "praceaste": "pracear",
    "praceastes": "pracear",
    "praceava": "pracear",
    "praceavam": "pracear",
    "praceavas": "pracear",
    "praceei": "pracear",
    "praceeis": "pracear",
    "praceemo": "pracear",
    "praceemos": "pracear",
    "praceia": "pracear",
    "praceiam": "pracear",
    "praceias": "pracear",
    "praceie": "pracear",
    "praceiem": "pracear",
    "praceies": "pracear",
    "praceio": "pracear",
    "praceira": "praceiro",
    "praceiras": "praceiro",
    "praceiros": "praceiro",
    "praceja": "pracejar",
    "pracejada": "pracejar",
    "pracejadas": "pracejar",
    "pracejado": "pracejar",
    "pracejados": "pracejar",
    "pracejai": "pracejar",
    "pracejais": "pracejar",
    "pracejam": "pracejar",
    "pracejamo": "pracejar",
    "pracejamos": "pracejar",
    "pracejando": "pracejar",
    "pracejara": "pracejar",
    "pracejaram": "pracejar",
    "pracejaras": "pracejar",
    "pracejarde": "pracejar",
    "pracejardes": "pracejar",
    "pracejare": "pracejar",
    "pracejarei": "pracejar",
    "pracejareis": "pracejar",
    "pracejarem": "pracejar",
    "pracejaremos": "pracejar",
    "pracejares": "pracejar",
    "pracejaria": "pracejar",
    "pracejariam": "pracejar",
    "pracejarias": "pracejar",
    "pracejarmo": "pracejar",
    "pracejarmos": "pracejar",
    "pracejará": "pracejar",
    "pracejarás": "pracejar",
    "pracejarão": "pracejar",
    "pracejaríamos": "pracejar",
    "pracejaríeis": "pracejar",
    "pracejas": "pracejar",
    "pracejasse": "pracejar",
    "pracejassem": "pracejar",
    "pracejasses": "pracejar",
    "pracejaste": "pracejar",
    "pracejastes": "pracejar",
    "pracejava": "pracejar",
    "pracejavam": "pracejar",
    "pracejavas": "pracejar",
    "praceje": "pracejar",
    "pracejei": "pracejar",
    "pracejeis": "pracejar",
    "pracejem": "pracejar",
    "pracejemo": "pracejar",
    "pracejemos": "pracejar",
    "pracejes": "pracejar",
    "pracejo": "pracejar",
    "pracejou": "pracejar",
    "pracejá": "pracejar",
    "pracejámo": "pracejar",
    "pracejámos": "pracejar",
    "pracejáramo": "pracejar",
    "pracejáramos": "pracejar",
    "pracejárei": "pracejar",
    "pracejáreis": "pracejar",
    "pracejásseis": "pracejar",
    "pracejássemos": "pracejar",
    "pracejávamo": "pracejar",
    "pracejávamos": "pracejar",
    "pracejávei": "pracejar",
    "pracejáveis": "pracejar",
    "praceou": "pracear",
    "pracetas": "praceta",
    "praceá": "pracear",
    "praceámo": "pracear",
    "praceámos": "pracear",
    "praceáramo": "pracear",
    "praceáramos": "pracear",
    "praceárei": "pracear",
    "praceáreis": "pracear",
    "praceásseis": "pracear",
    "praceássemos": "pracear",
    "praceávamo": "pracear",
    "praceávamos": "pracear",
    "praceávei": "pracear",
    "praceáveis": "pracear",
    "pracistas": "pracista",
    "pracrítica": "pracrítico",
    "pracríticas": "pracrítico",
    "pracríticos": "pracrítico",
    "practores": "practor",
    "pradarias": "pradaria",
    "pradeja": "pradejar",
    "pradejada": "pradejar",
    "pradejadas": "pradejar",
    "pradejado": "pradejar",
    "pradejados": "pradejar",
    "pradejai": "pradejar",
    "pradejais": "pradejar",
    "pradejam": "pradejar",
    "pradejamo": "pradejar",
    "pradejamos": "pradejar",
    "pradejando": "pradejar",
    "pradejara": "pradejar",
    "pradejaram": "pradejar",
    "pradejaras": "pradejar",
    "pradejardes": "pradejar",
    "pradejarei": "pradejar",
    "pradejareis": "pradejar",
    "pradejarem": "pradejar",
    "pradejaremos": "pradejar",
    "pradejares": "pradejar",
    "pradejaria": "pradejar",
    "pradejariam": "pradejar",
    "pradejarias": "pradejar",
    "pradejarmo": "pradejar",
    "pradejarmos": "pradejar",
    "pradejará": "pradejar",
    "pradejarás": "pradejar",
    "pradejarão": "pradejar",
    "pradejaríamos": "pradejar",
    "pradejaríeis": "pradejar",
    "pradejas": "pradejar",
    "pradejasse": "pradejar",
    "pradejassem": "pradejar",
    "pradejasses": "pradejar",
    "pradejaste": "pradejar",
    "pradejastes": "pradejar",
    "pradejava": "pradejar",
    "pradejavam": "pradejar",
    "pradejavas": "pradejar",
    "pradeje": "pradejar",
    "pradejei": "pradejar",
    "pradejeis": "pradejar",
    "pradejem": "pradejar",
    "pradejemo": "pradejar",
    "pradejemos": "pradejar",
    "pradejes": "pradejar",
    "pradejo": "pradejar",
    "pradejou": "pradejar",
    "pradejámo": "pradejar",
    "pradejámos": "pradejar",
    "pradejáramo": "pradejar",
    "pradejáramos": "pradejar",
    "pradejáreis": "pradejar",
    "pradejásseis": "pradejar",
    "pradejássemos": "pradejar",
    "pradejávamo": "pradejar",
    "pradejávamos": "pradejar",
    "pradejáveis": "pradejar",
    "prados": "prado",
    "pradosa": "pradoso",
    "pradosas": "pradoso",
    "pradosos": "pradoso",
    "pragais": "pragal",
    "praganas": "pragana",
    "praganeiras": "praganeira",
    "praganosa": "praganoso",
    "praganosas": "praganoso",
    "praganosos": "praganoso",
    "praganás": "praganá",
    "praganãs": "praganã",
    "pragas": "praga",
    "pragmaticismos": "pragmaticismo",
    "pragmaticistas": "pragmaticista",
    "pragmatismos": "pragmatismo",
    "pragmatistas": "pragmatista",
    "pragmática": "pragmático",
    "pragmáticas": "pragmático",
    "pragmáticos": "pragmático",
    "praguedos": "praguedo",
    "pragueja": "praguejar",
    "praguejada": "praguejar",
    "praguejadas": "praguejar",
    "praguejado": "praguejar",
    "praguejadora": "praguejador",
    "praguejadoras": "praguejador",
    "praguejadores": "praguejador",
    "praguejados": "praguejar",
    "praguejai": "praguejar",
    "praguejais": "praguejar",
    "praguejam": "praguejar",
    "praguejamentos": "praguejamento",
    "praguejamo": "praguejar",
    "praguejamos": "praguejar",
    "praguejando": "praguejar",
    "praguejara": "praguejar",
    "praguejaram": "praguejar",
    "praguejaras": "praguejar",
    "praguejardes": "praguejar",
    "praguejarei": "praguejar",
    "praguejareis": "praguejar",
    "praguejarem": "praguejar",
    "praguejaremos": "praguejar",
    "praguejares": "praguejar",
    "praguejaria": "praguejar",
    "praguejariam": "praguejar",
    "praguejarias": "praguejar",
    "praguejarmo": "praguejar",
    "praguejarmos": "praguejar",
    "praguejará": "praguejar",
    "praguejarás": "praguejar",
    "praguejarão": "praguejar",
    "praguejaríamos": "praguejar",
    "praguejaríeis": "praguejar",
    "praguejas": "praguejar",
    "praguejasse": "praguejar",
    "praguejassem": "praguejar",
    "praguejasses": "praguejar",
    "praguejaste": "praguejar",
    "praguejastes": "praguejar",
    "praguejava": "praguejar",
    "praguejavam": "praguejar",
    "praguejavas": "praguejar",
    "pragueje": "praguejar",
    "praguejei": "praguejar",
    "praguejeis": "praguejar",
    "praguejem": "praguejar",
    "praguejemo": "praguejar",
    "praguejemos": "praguejar",
    "praguejes": "praguejar",
    "praguejo": "praguejar",
    "praguejou": "praguejar",
    "praguejámo": "praguejar",
    "praguejámos": "praguejar",
    "praguejáramo": "praguejar",
    "praguejáramos": "praguejar",
    "praguejáreis": "praguejar",
    "praguejásseis": "praguejar",
    "praguejássemos": "praguejar",
    "praguejávamo": "praguejar",
    "praguejávamos": "praguejar",
    "praguejáveis": "praguejar",
    "praguenta": "praguento",
    "praguentas": "praguento",
    "praguentos": "praguento",
    "praiana": "praiano",
    "praianas": "praiano",
    "praianos": "praiano",
    "praias": "praia",
    "praieira": "praieiro",
    "praieiras": "praieiro",
    "praieiros": "praieiro",
    "praienses": "praiense",
    "praiinha": "praia",
    "praiinhas": "praia",
    "praiita": "praia",
    "praiitas": "praia",
    "pralinada": "pralinado",
    "pralinadas": "pralinado",
    "pralinados": "pralinado",
    "pralinas": "pralina",
    "pralinés": "praliné",
    "prancha": "pranchar",
    "pranchada": "pranchar",
    "pranchadas": "pranchar",
    "pranchado": "pranchar",
    "pranchados": "pranchar",
    "pranchai": "pranchar",
    "pranchais": "pranchar",
    "prancham": "pranchar",
    "pranchamo": "pranchar",
    "pranchamos": "pranchar",
    "pranchando": "pranchar",
    "pranchara": "pranchar",
    "prancharam": "pranchar",
    "prancharas": "pranchar",
    "prancharde": "pranchar",
    "pranchardes": "pranchar",
    "pranchare": "pranchar",
    "prancharei": "pranchar",
    "pranchareis": "pranchar",
    "prancharem": "pranchar",
    "prancharemos": "pranchar",
    "pranchares": "pranchar",
    "prancharia": "pranchar",
    "pranchariam": "pranchar",
    "prancharias": "pranchar",
    "prancharmo": "pranchar",
    "prancharmos": "pranchar",
    "pranchará": "pranchar",
    "prancharás": "pranchar",
    "prancharão": "pranchar",
    "prancharíamos": "pranchar",
    "prancharíeis": "pranchar",
    "pranchas": "pranchar",
    "pranchasse": "pranchar",
    "pranchassem": "pranchar",
    "pranchasses": "pranchar",
    "pranchaste": "pranchar",
    "pranchastes": "pranchar",
    "pranchava": "pranchar",
    "pranchavam": "pranchar",
    "pranchavas": "pranchar",
    "pranche": "pranchar",
    "prancheada": "pranchear",
    "prancheadas": "pranchear",
    "prancheado": "pranchear",
    "prancheados": "pranchear",
    "prancheai": "pranchear",
    "prancheais": "pranchear",
    "prancheamo": "pranchear",
    "prancheamos": "pranchear",
    "prancheando": "pranchear",
    "prancheara": "pranchear",
    "pranchearam": "pranchear",
    "pranchearas": "pranchear",
    "pranchearde": "pranchear",
    "prancheardes": "pranchear",
    "prancheare": "pranchear",
    "pranchearei": "pranchear",
    "prancheareis": "pranchear",
    "pranchearem": "pranchear",
    "pranchearemos": "pranchear",
    "prancheares": "pranchear",
    "pranchearia": "pranchear",
    "prancheariam": "pranchear",
    "pranchearias": "pranchear",
    "pranchearmo": "pranchear",
    "pranchearmos": "pranchear",
    "prancheará": "pranchear",
    "pranchearás": "pranchear",
    "pranchearão": "pranchear",
    "pranchearíamos": "pranchear",
    "pranchearíeis": "pranchear",
    "prancheasse": "pranchear",
    "prancheassem": "pranchear",
    "prancheasses": "pranchear",
    "prancheaste": "pranchear",
    "prancheastes": "pranchear",
    "prancheava": "pranchear",
    "prancheavam": "pranchear",
    "prancheavas": "pranchear",
    "prancheei": "pranchear",
    "prancheeis": "pranchear",
    "prancheemo": "pranchear",
    "prancheemos": "pranchear",
    "pranchei": "pranchar",
    "prancheia": "pranchear",
    "prancheiam": "pranchear",
    "prancheias": "pranchear",
    "prancheie": "pranchear",
    "prancheiem": "pranchear",
    "prancheies": "pranchear",
    "prancheio": "pranchear",
    "prancheis": "pranchar",
    "pranchem": "pranchar",
    "pranchemo": "pranchar",
    "pranchemos": "pranchar",
    "prancheou": "pranchear",
    "pranches": "pranchar",
    "pranchetas": "prancheta",
    "prancheá": "pranchear",
    "prancheámo": "pranchear",
    "prancheámos": "pranchear",
    "prancheáramo": "pranchear",
    "prancheáramos": "pranchear",
    "prancheárei": "pranchear",
    "prancheáreis": "pranchear",
    "prancheásseis": "pranchear",
    "prancheássemos": "pranchear",
    "prancheávamo": "pranchear",
    "prancheávamos": "pranchear",
    "prancheávei": "pranchear",
    "prancheáveis": "pranchear",
    "pranchinha": "prancha",
    "pranchinhas": "prancha",
    "pranchita": "prancha",
    "pranchitas": "prancha",
    "prancho": "pranchar",
    "pranchou": "pranchar",
    "pranchá": "pranchar",
    "pranchámo": "pranchar",
    "pranchámos": "pranchar",
    "prancháramo": "pranchar",
    "prancháramos": "pranchar",
    "pranchárei": "pranchar",
    "prancháreis": "pranchar",
    "pranchásseis": "pranchar",
    "pranchássemos": "pranchar",
    "pranchávamo": "pranchar",
    "pranchávamos": "pranchar",
    "pranchávei": "pranchar",
    "prancháveis": "pranchar",
    "pranchões": "pranchão",
    "prandiais": "prandial",
    "pranta": "prantar",
    "prantada": "prantar",
    "prantadas": "prantar",
    "prantado": "prantar",
    "prantados": "prantar",
    "prantai": "prantar",
    "prantais": "prantar",
    "prantam": "prantar",
    "prantamo": "prantar",
    "prantamos": "prantar",
    "prantando": "prantar",
    "prantara": "prantar",
    "prantaram": "prantar",
    "prantaras": "prantar",
    "prantarde": "prantar",
    "prantardes": "prantar",
    "prantare": "prantar",
    "prantarei": "prantar",
    "prantareis": "prantar",
    "prantarem": "prantar",
    "prantaremos": "prantar",
    "prantares": "prantar",
    "prantaria": "prantar",
    "prantariam": "prantar",
    "prantarias": "prantar",
    "prantarmo": "prantar",
    "prantarmos": "prantar",
    "prantará": "prantar",
    "prantarás": "prantar",
    "prantarão": "prantar",
    "prantaríamos": "prantar",
    "prantaríeis": "prantar",
    "prantas": "prantar",
    "prantasse": "prantar",
    "prantassem": "prantar",
    "prantasses": "prantar",
    "prantaste": "prantar",
    "prantastes": "prantar",
    "prantava": "prantar",
    "prantavam": "prantar",
    "prantavas": "prantar",
    "prante": "prantar",
    "pranteada": "prantear",
    "pranteadas": "prantear",
    "pranteadeira": "pranteador",
    "pranteadeiras": "pranteador",
    "pranteado": "prantear",
    "pranteadores": "pranteador",
    "pranteados": "prantear",
    "pranteai": "prantear",
    "pranteais": "prantear",
    "pranteamo": "prantear",
    "pranteamos": "prantear",
    "pranteando": "prantear",
    "pranteara": "prantear",
    "prantearam": "prantear",
    "prantearas": "prantear",
    "prantearde": "prantear",
    "pranteardes": "prantear",
    "pranteare": "prantear",
    "prantearei": "prantear",
    "pranteareis": "prantear",
    "prantearem": "prantear",
    "prantearemos": "prantear",
    "pranteares": "prantear",
    "prantearia": "prantear",
    "pranteariam": "prantear",
    "prantearias": "prantear",
    "prantearmo": "prantear",
    "prantearmos": "prantear",
    "pranteará": "prantear",
    "prantearás": "prantear",
    "prantearão": "prantear",
    "prantearíamos": "prantear",
    "prantearíeis": "prantear",
    "pranteasse": "prantear",
    "pranteassem": "prantear",
    "pranteasses": "prantear",
    "pranteaste": "prantear",
    "pranteastes": "prantear",
    "pranteava": "prantear",
    "pranteavam": "prantear",
    "pranteavas": "prantear",
    "pranteei": "prantear",
    "pranteeis": "prantear",
    "pranteemo": "prantear",
    "pranteemos": "prantear",
    "prantei": "prantar",
    "pranteia": "prantear",
    "pranteiam": "prantear",
    "pranteias": "prantear",
    "pranteie": "prantear",
    "pranteiem": "prantear",
    "pranteies": "prantear",
    "pranteio": "prantear",
    "pranteis": "prantar",
    "prantem": "prantar",
    "prantemo": "prantar",
    "prantemos": "prantar",
    "pranteou": "prantear",
    "prantes": "prantar",
    "pranteá": "prantear",
    "pranteámo": "prantear",
    "pranteámos": "prantear",
    "pranteáramo": "prantear",
    "pranteáramos": "prantear",
    "pranteárei": "prantear",
    "pranteáreis": "prantear",
    "pranteásseis": "prantear",
    "pranteássemos": "prantear",
    "pranteávamo": "prantear",
    "pranteávamos": "prantear",
    "pranteávei": "prantear",
    "pranteáveis": "prantear",
    "prantiva": "prantivo",
    "prantivas": "prantivo",
    "prantivos": "prantivo",
    "pranto": "prantar",
    "prantos": "pranto",
    "prantou": "prantar",
    "prantozinho": "pranto",
    "prantozinhos": "pranto",
    "prantozito": "pranto",
    "prantozitos": "pranto",
    "prantá": "prantar",
    "prantámo": "prantar",
    "prantámos": "prantar",
    "prantáramo": "prantar",
    "prantáramos": "prantar",
    "prantárei": "prantar",
    "prantáreis": "prantar",
    "prantásseis": "prantar",
    "prantássemos": "prantar",
    "prantávamo": "prantar",
    "prantávamos": "prantar",
    "prantávei": "prantar",
    "prantáveis": "prantar",
    "praseodímica": "praseodímico",
    "praseodímicas": "praseodímico",
    "praseodímicos": "praseodímico",
    "prasiodímios": "prasiodímio",
    "pratadas": "pratada",
    "pratalhadas": "pratalhada",
    "pratalhazes": "pratalhaz",
    "pratarias": "prataria",
    "pratarradas": "pratarrada",
    "pratarrazes": "pratarraz",
    "pratas": "prata",
    "prateada": "pratear",
    "prateadas": "pratear",
    "prateado": "pratear",
    "prateadora": "prateador",
    "prateadoras": "prateador",
    "prateadores": "prateador",
    "prateados": "pratear",
    "prateaduras": "prateadura",
    "prateai": "pratear",
    "prateais": "pratear",
    "prateamentos": "prateamento",
    "prateamo": "pratear",
    "prateamos": "pratear",
    "prateando": "pratear",
    "prateara": "pratear",
    "pratearam": "pratear",
    "pratearas": "pratear",
    "pratearde": "pratear",
    "prateardes": "pratear",
    "prateare": "pratear",
    "pratearei": "pratear",
    "prateareis": "pratear",
    "pratearem": "pratear",
    "pratearemos": "pratear",
    "prateares": "pratear",
    "pratearia": "pratear",
    "prateariam": "pratear",
    "pratearias": "pratear",
    "pratearmo": "pratear",
    "pratearmos": "pratear",
    "prateará": "pratear",
    "pratearás": "pratear",
    "pratearão": "pratear",
    "pratearíamos": "pratear",
    "pratearíeis": "pratear",
    "prateasse": "pratear",
    "prateassem": "pratear",
    "prateasses": "pratear",
    "prateaste": "pratear",
    "prateastes": "pratear",
    "prateava": "pratear",
    "prateavam": "pratear",
    "prateavas": "pratear",
    "prateações": "prateação",
    "prateei": "pratear",
    "prateeis": "pratear",
    "prateemo": "pratear",
    "prateemos": "pratear",
    "prateia": "pratear",
    "prateiam": "pratear",
    "prateias": "pratear",
    "prateie": "pratear",
    "prateiem": "pratear",
    "prateies": "pratear",
    "prateio": "pratear",
    "prateiras": "prateira",
    "prateja": "pratejar",
    "pratejada": "pratejar",
    "pratejadas": "pratejar",
    "pratejado": "pratejar",
    "pratejados": "pratejar",
    "pratejai": "pratejar",
    "pratejais": "pratejar",
    "pratejam": "pratejar",
    "pratejamo": "pratejar",
    "pratejamos": "pratejar",
    "pratejando": "pratejar",
    "pratejara": "pratejar",
    "pratejaram": "pratejar",
    "pratejaras": "pratejar",
    "pratejardes": "pratejar",
    "pratejarei": "pratejar",
    "pratejareis": "pratejar",
    "pratejarem": "pratejar",
    "pratejaremos": "pratejar",
    "pratejares": "pratejar",
    "pratejaria": "pratejar",
    "pratejariam": "pratejar",
    "pratejarias": "pratejar",
    "pratejarmo": "pratejar",
    "pratejarmos": "pratejar",
    "pratejará": "pratejar",
    "pratejarás": "pratejar",
    "pratejarão": "pratejar",
    "pratejaríamos": "pratejar",
    "pratejaríeis": "pratejar",
    "pratejas": "pratejar",
    "pratejasse": "pratejar",
    "pratejassem": "pratejar",
    "pratejasses": "pratejar",
    "pratejaste": "pratejar",
    "pratejastes": "pratejar",
    "pratejava": "pratejar",
    "pratejavam": "pratejar",
    "pratejavas": "pratejar",
    "prateje": "pratejar",
    "pratejei": "pratejar",
    "pratejeis": "pratejar",
    "pratejem": "pratejar",
    "pratejemo": "pratejar",
    "pratejemos": "pratejar",
    "pratejes": "pratejar",
    "pratejo": "pratejar",
    "pratejou": "pratejar",
    "pratejámo": "pratejar",
    "pratejámos": "pratejar",
    "pratejáramo": "pratejar",
    "pratejáramos": "pratejar",
    "pratejáreis": "pratejar",
    "pratejásseis": "pratejar",
    "pratejássemos": "pratejar",
    "pratejávamo": "pratejar",
    "pratejávamos": "pratejar",
    "pratejáveis": "pratejar",
    "prateleira": "prateleiro",
    "prateleiras": "prateleiro",
    "prateleirinha": "prateleira",
    "prateleirinhas": "prateleira",
    "prateleirita": "prateleira",
    "prateleiritas": "prateleira",
    "prateleiros": "prateleiro",
    "pratenses": "pratense",
    "prateou": "pratear",
    "prateá": "pratear",
    "prateámo": "pratear",
    "prateámos": "pratear",
    "prateáramo": "pratear",
    "prateáramos": "pratear",
    "prateárei": "pratear",
    "prateáreis": "pratear",
    "prateásseis": "pratear",
    "prateássemos": "pratear",
    "prateávamo": "pratear",
    "prateávamos": "pratear",
    "prateávei": "pratear",
    "prateáveis": "prateável",
    "pratica": "praticar",
    "praticabilidades": "praticabilidade",
    "praticada": "praticar",
    "praticadas": "praticar",
    "praticado": "praticar",
    "praticadora": "praticador",
    "praticadoras": "praticador",
    "praticadores": "praticador",
    "praticados": "praticar",
    "praticagens": "praticagem",
    "praticai": "praticar",
    "praticais": "praticar",
    "praticam": "praticar",
    "praticamo": "praticar",
    "praticamos": "praticar",
    "praticando": "praticar",
    "praticantes": "praticante",
    "praticara": "praticar",
    "praticaram": "praticar",
    "praticaras": "praticar",
    "praticarde": "praticar",
    "praticardes": "praticar",
    "praticare": "praticar",
    "praticarei": "praticar",
    "praticareis": "praticar",
    "praticarem": "praticar",
    "praticaremos": "praticar",
    "praticares": "praticar",
    "praticaria": "praticar",
    "praticariam": "praticar",
    "praticarias": "praticar",
    "praticarmo": "praticar",
    "praticarmos": "praticar",
    "praticará": "praticar",
    "praticarás": "praticar",
    "praticarão": "praticar",
    "praticaríamos": "praticar",
    "praticaríeis": "praticar",
    "praticas": "praticar",
    "praticasse": "praticar",
    "praticassem": "praticar",
    "praticasses": "praticar",
    "praticaste": "praticar",
    "praticastes": "praticar",
    "praticava": "praticar",
    "praticavam": "praticar",
    "praticavas": "praticar",
    "pratico": "praticar",
    "praticou": "praticar",
    "praticultora": "praticultor",
    "praticultoras": "praticultor",
    "praticultores": "praticultor",
    "praticulturas": "praticultura",
    "praticá": "praticar",
    "praticámo": "praticar",
    "praticámos": "praticar",
    "praticáramo": "praticar",
    "praticáramos": "praticar",
    "praticárei": "praticar",
    "praticáreis": "praticar",
    "praticásseis": "praticar",
    "praticássemos": "praticar",
    "praticávamo": "praticar",
    "praticávamos": "praticar",
    "praticávei": "praticar",
    "praticáveis": "praticável",
    "pratilheira": "pratilheiro",
    "pratilheiras": "pratilheiro",
    "pratilheiros": "pratilheiro",
    "pratilhos": "pratilho",
    "pratinha": "prata",
    "pratinhas": "prata",
    "pratinho": "prato",
    "pratinhos": "prato",
    "pratique": "praticar",
    "pratiquei": "praticar",
    "pratiqueis": "praticar",
    "pratiquem": "praticar",
    "pratiquemo": "praticar",
    "pratiquemos": "praticar",
    "pratiques": "praticar",
    "pratita": "prata",
    "pratitas": "prata",
    "pratito": "prato",
    "pratitos": "prato",
    "pratos": "prato",
    "pratéis": "pratel",
    "pratícolas": "pratícola",
    "prava": "pravo",
    "pravas": "pravo",
    "pravidades": "pravidade",
    "pravos": "pravo",
    "praxa": "praxar",
    "praxada": "praxar",
    "praxadas": "praxar",
    "praxado": "praxar",
    "praxados": "praxar",
    "praxai": "praxar",
    "praxais": "praxar",
    "praxam": "praxar",
    "praxamo": "praxar",
    "praxamos": "praxar",
    "praxando": "praxar",
    "praxara": "praxar",
    "praxaram": "praxar",
    "praxaras": "praxar",
    "praxarde": "praxar",
    "praxardes": "praxar",
    "praxare": "praxar",
    "praxarei": "praxar",
    "praxareis": "praxar",
    "praxarem": "praxar",
    "praxaremos": "praxar",
    "praxares": "praxar",
    "praxaria": "praxar",
    "praxariam": "praxar",
    "praxarias": "praxar",
    "praxarmo": "praxar",
    "praxarmos": "praxar",
    "praxará": "praxar",
    "praxarás": "praxar",
    "praxarão": "praxar",
    "praxaríamos": "praxar",
    "praxaríeis": "praxar",
    "praxas": "praxar",
    "praxasse": "praxar",
    "praxassem": "praxar",
    "praxasses": "praxar",
    "praxaste": "praxar",
    "praxastes": "praxar",
    "praxava": "praxar",
    "praxavam": "praxar",
    "praxavas": "praxar",
    "praxe": "praxar",
    "praxei": "praxar",
    "praxeis": "praxar",
    "praxem": "praxar",
    "praxemo": "praxar",
    "praxemos": "praxar",
    "praxeologias": "praxeologia",
    "praxeológica": "praxeológico",
    "praxeológicas": "praxeológico",
    "praxeológicos": "praxeológico",
    "praxes": "praxe",
    "praxias": "praxia",
    "praxismos": "praxismo",
    "praxistas": "praxista",
    "praxo": "praxar",
    "praxologias": "praxologia",
    "praxológica": "praxológico",
    "praxológicas": "praxológico",
    "praxológicos": "praxológico",
    "praxou": "praxar",
    "praxá": "praxar",
    "praxámo": "praxar",
    "praxámos": "praxar",
    "praxáramo": "praxar",
    "praxáramos": "praxar",
    "praxárei": "praxar",
    "praxáreis": "praxar",
    "praxásseis": "praxar",
    "praxássemos": "praxar",
    "praxávamo": "praxar",
    "praxávamos": "praxar",
    "praxávei": "praxar",
    "praxáveis": "praxar",
    "praz": "prazer",
    "praza": "prazer",
    "prazam": "prazer",
    "prazem": "prazer",
    "prazendo": "prazer",
    "prazenteada": "prazentear",
    "prazenteadas": "prazentear",
    "prazenteado": "prazentear",
    "prazenteados": "prazentear",
    "prazenteai": "prazentear",
    "prazenteais": "prazentear",
    "prazenteamo": "prazentear",
    "prazenteamos": "prazentear",
    "prazenteando": "prazentear",
    "prazenteara": "prazentear",
    "prazentearam": "prazentear",
    "prazentearas": "prazentear",
    "prazentearde": "prazentear",
    "prazenteardes": "prazentear",
    "prazenteare": "prazentear",
    "prazentearei": "prazentear",
    "prazenteareis": "prazentear",
    "prazentearem": "prazentear",
    "prazentearemos": "prazentear",
    "prazenteares": "prazentear",
    "prazentearia": "prazentear",
    "prazenteariam": "prazentear",
    "prazentearias": "prazentear",
    "prazentearmo": "prazentear",
    "prazentearmos": "prazentear",
    "prazenteará": "prazentear",
    "prazentearás": "prazentear",
    "prazentearão": "prazentear",
    "prazentearíamos": "prazentear",
    "prazentearíeis": "prazentear",
    "prazenteasse": "prazentear",
    "prazenteassem": "prazentear",
    "prazenteasses": "prazentear",
    "prazenteaste": "prazentear",
    "prazenteastes": "prazentear",
    "prazenteava": "prazentear",
    "prazenteavam": "prazentear",
    "prazenteavas": "prazentear",
    "prazenteei": "prazentear",
    "prazenteeis": "prazentear",
    "prazenteemo": "prazentear",
    "prazenteemos": "prazentear",
    "prazenteia": "prazentear",
    "prazenteiam": "prazentear",
    "prazenteias": "prazentear",
    "prazenteie": "prazentear",
    "prazenteiem": "prazentear",
    "prazenteies": "prazentear",
    "prazenteio": "prazentear",
    "prazenteios": "prazenteio",
    "prazenteira": "prazenteiro",
    "prazenteiras": "prazenteiro",
    "prazenteiros": "prazenteiro",
    "prazenteou": "prazentear",
    "prazenteá": "prazentear",
    "prazenteámo": "prazentear",
    "prazenteámos": "prazentear",
    "prazenteáramo": "prazentear",
    "prazenteáramos": "prazentear",
    "prazenteárei": "prazentear",
    "prazenteáreis": "prazentear",
    "prazenteásseis": "prazentear",
    "prazenteássemos": "prazentear",
    "prazenteávamo": "prazentear",
    "prazenteávamos": "prazentear",
    "prazenteávei": "prazentear",
    "prazenteáveis": "prazentear",
    "prazerem": "prazer",
    "prazeres": "prazer",
    "prazeria": "prazer",
    "prazeriam": "prazer",
    "prazerá": "prazer",
    "prazerão": "prazer",
    "prazia": "prazer",
    "praziam": "prazer",
    "prazida": "prazer",
    "prazidas": "prazer",
    "prazido": "prazer",
    "prazidos": "prazer",
    "prazimentos": "prazimento",
    "prazos": "prazo",
    "prazíveis": "prazível",
    "praças": "praça",
    "preada": "prear",
    "preadas": "prear",
    "preadivinha": "preadivinhar",
    "preadivinhada": "preadivinhar",
    "preadivinhadas": "preadivinhar",
    "preadivinhado": "preadivinhar",
    "preadivinhados": "preadivinhar",
    "preadivinhai": "preadivinhar",
    "preadivinhais": "preadivinhar",
    "preadivinham": "preadivinhar",
    "preadivinhamo": "preadivinhar",
    "preadivinhamos": "preadivinhar",
    "preadivinhando": "preadivinhar",
    "preadivinhara": "preadivinhar",
    "preadivinharam": "preadivinhar",
    "preadivinharas": "preadivinhar",
    "preadivinharde": "preadivinhar",
    "preadivinhardes": "preadivinhar",
    "preadivinhare": "preadivinhar",
    "preadivinharei": "preadivinhar",
    "preadivinhareis": "preadivinhar",
    "preadivinharem": "preadivinhar",
    "preadivinharemos": "preadivinhar",
    "preadivinhares": "preadivinhar",
    "preadivinharia": "preadivinhar",
    "preadivinhariam": "preadivinhar",
    "preadivinharias": "preadivinhar",
    "preadivinharmo": "preadivinhar",
    "preadivinharmos": "preadivinhar",
    "preadivinhará": "preadivinhar",
    "preadivinharás": "preadivinhar",
    "preadivinharão": "preadivinhar",
    "preadivinharíamos": "preadivinhar",
    "preadivinharíeis": "preadivinhar",
    "preadivinhas": "preadivinhar",
    "preadivinhasse": "preadivinhar",
    "preadivinhassem": "preadivinhar",
    "preadivinhasses": "preadivinhar",
    "preadivinhaste": "preadivinhar",
    "preadivinhastes": "preadivinhar",
    "preadivinhava": "preadivinhar",
    "preadivinhavam": "preadivinhar",
    "preadivinhavas": "preadivinhar",
    "preadivinhe": "preadivinhar",
    "preadivinhei": "preadivinhar",
    "preadivinheis": "preadivinhar",
    "preadivinhem": "preadivinhar",
    "preadivinhemo": "preadivinhar",
    "preadivinhemos": "preadivinhar",
    "preadivinhes": "preadivinhar",
    "preadivinho": "preadivinhar",
    "preadivinhou": "preadivinhar",
    "preadivinhá": "preadivinhar",
    "preadivinhámo": "preadivinhar",
    "preadivinhámos": "preadivinhar",
    "preadivinháramo": "preadivinhar",
    "preadivinháramos": "preadivinhar",
    "preadivinhárei": "preadivinhar",
    "preadivinháreis": "preadivinhar",
    "preadivinhásseis": "preadivinhar",
    "preadivinhássemos": "preadivinhar",
    "preadivinhávamo": "preadivinhar",
    "preadivinhávamos": "preadivinhar",
    "preadivinhávei": "preadivinhar",
    "preadivinháveis": "preadivinhar",
    "preado": "prear",
    "preados": "prear",
    "preai": "prear",
    "preais": "prear",
    "prealega": "prealegar",
    "prealegada": "prealegar",
    "prealegadas": "prealegar",
    "prealegado": "prealegar",
    "prealegados": "prealegar",
    "prealegai": "prealegar",
    "prealegais": "prealegar",
    "prealegam": "prealegar",
    "prealegamo": "prealegar",
    "prealegamos": "prealegar",
    "prealegando": "prealegar",
    "prealegara": "prealegar",
    "prealegaram": "prealegar",
    "prealegaras": "prealegar",
    "prealegarde": "prealegar",
    "prealegardes": "prealegar",
    "prealegare": "prealegar",
    "prealegarei": "prealegar",
    "prealegareis": "prealegar",
    "prealegarem": "prealegar",
    "prealegaremos": "prealegar",
    "prealegares": "prealegar",
    "prealegaria": "prealegar",
    "prealegariam": "prealegar",
    "prealegarias": "prealegar",
    "prealegarmo": "prealegar",
    "prealegarmos": "prealegar",
    "prealegará": "prealegar",
    "prealegarás": "prealegar",
    "prealegarão": "prealegar",
    "prealegaríamos": "prealegar",
    "prealegaríeis": "prealegar",
    "prealegas": "prealegar",
    "prealegasse": "prealegar",
    "prealegassem": "prealegar",
    "prealegasses": "prealegar",
    "prealegaste": "prealegar",
    "prealegastes": "prealegar",
    "prealegava": "prealegar",
    "prealegavam": "prealegar",
    "prealegavas": "prealegar",
    "prealego": "prealegar",
    "prealegou": "prealegar",
    "prealegue": "prealegar",
    "prealeguei": "prealegar",
    "prealegueis": "prealegar",
    "prealeguem": "prealegar",
    "prealeguemo": "prealegar",
    "prealeguemos": "prealegar",
    "prealegues": "prealegar",
    "prealegá": "prealegar",
    "prealegámo": "prealegar",
    "prealegámos": "prealegar",
    "prealegáramo": "prealegar",
    "prealegáramos": "prealegar",
    "prealegárei": "prealegar",
    "prealegáreis": "prealegar",
    "prealegásseis": "prealegar",
    "prealegássemos": "prealegar",
    "prealegávamo": "prealegar",
    "prealegávamos": "prealegar",
    "prealegávei": "prealegar",
    "prealegáveis": "prealegar",
    "preamares": "preamar",
    "preambula": "preambular",
    "preambulada": "preambular",
    "preambuladas": "preambular",
    "preambulado": "preambular",
    "preambulados": "preambular",
    "preambulai": "preambular",
    "preambulais": "preambular",
    "preambulam": "preambular",
    "preambulamo": "preambular",
    "preambulamos": "preambular",
    "preambulando": "preambular",
    "preambulara": "preambular",
    "preambularam": "preambular",
    "preambularas": "preambular",
    "preambularde": "preambular",
    "preambulardes": "preambular",
    "preambulare": "preambular",
    "preambularei": "preambular",
    "preambulareis": "preambular",
    "preambularem": "preambular",
    "preambularemos": "preambular",
    "preambulares": "preambular",
    "preambularia": "preambular",
    "preambulariam": "preambular",
    "preambularias": "preambular",
    "preambularmo": "preambular",
    "preambularmos": "preambular",
    "preambulará": "preambular",
    "preambularás": "preambular",
    "preambularão": "preambular",
    "preambularíamos": "preambular",
    "preambularíeis": "preambular",
    "preambulas": "preambular",
    "preambulasse": "preambular",
    "preambulassem": "preambular",
    "preambulasses": "preambular",
    "preambulaste": "preambular",
    "preambulastes": "preambular",
    "preambulava": "preambular",
    "preambulavam": "preambular",
    "preambulavas": "preambular",
    "preambule": "preambular",
    "preambulei": "preambular",
    "preambuleis": "preambular",
    "preambulem": "preambular",
    "preambulemo": "preambular",
    "preambulemos": "preambular",
    "preambules": "preambular",
    "preambulo": "preambular",
    "preambulou": "preambular",
    "preambulá": "preambular",
    "preambulámo": "preambular",
    "preambulámos": "preambular",
    "preambuláramo": "preambular",
    "preambuláramos": "preambular",
    "preambulárei": "preambular",
    "preambuláreis": "preambular",
    "preambulásseis": "preambular",
    "preambulássemos": "preambular",
    "preambulávamo": "preambular",
    "preambulávamos": "preambular",
    "preambulávei": "preambular",
    "preambuláveis": "preambular",
    "preamo": "prear",
    "preamos": "prear",
    "preando": "prear",
    "preanuncia": "preanunciar",
    "preanunciada": "preanunciar",
    "preanunciadas": "preanunciar",
    "preanunciado": "preanunciar",
    "preanunciadora": "preanunciador",
    "preanunciadoras": "preanunciador",
    "preanunciadores": "preanunciador",
    "preanunciados": "preanunciar",
    "preanunciai": "preanunciar",
    "preanunciais": "preanunciar",
    "preanunciam": "preanunciar",
    "preanunciamo": "preanunciar",
    "preanunciamos": "preanunciar",
    "preanunciando": "preanunciar",
    "preanunciara": "preanunciar",
    "preanunciaram": "preanunciar",
    "preanunciaras": "preanunciar",
    "preanunciarde": "preanunciar",
    "preanunciardes": "preanunciar",
    "preanunciare": "preanunciar",
    "preanunciarei": "preanunciar",
    "preanunciareis": "preanunciar",
    "preanunciarem": "preanunciar",
    "preanunciaremos": "preanunciar",
    "preanunciares": "preanunciar",
    "preanunciaria": "preanunciar",
    "preanunciariam": "preanunciar",
    "preanunciarias": "preanunciar",
    "preanunciarmo": "preanunciar",
    "preanunciarmos": "preanunciar",
    "preanunciará": "preanunciar",
    "preanunciarás": "preanunciar",
    "preanunciarão": "preanunciar",
    "preanunciaríamos": "preanunciar",
    "preanunciaríeis": "preanunciar",
    "preanuncias": "preanunciar",
    "preanunciasse": "preanunciar",
    "preanunciassem": "preanunciar",
    "preanunciasses": "preanunciar",
    "preanunciaste": "preanunciar",
    "preanunciastes": "preanunciar",
    "preanunciava": "preanunciar",
    "preanunciavam": "preanunciar",
    "preanunciavas": "preanunciar",
    "preanunciações": "preanunciação",
    "preanuncie": "preanunciar",
    "preanunciei": "preanunciar",
    "preanuncieis": "preanunciar",
    "preanunciem": "preanunciar",
    "preanunciemo": "preanunciar",
    "preanunciemos": "preanunciar",
    "preanuncies": "preanunciar",
    "preanuncio": "preanunciar",
    "preanunciou": "preanunciar",
    "preanunciá": "preanunciar",
    "preanunciámo": "preanunciar",
    "preanunciámos": "preanunciar",
    "preanunciáramo": "preanunciar",
    "preanunciáramos": "preanunciar",
    "preanunciárei": "preanunciar",
    "preanunciáreis": "preanunciar",
    "preanunciásseis": "preanunciar",
    "preanunciássemos": "preanunciar",
    "preanunciávamo": "preanunciar",
    "preanunciávamos": "preanunciar",
    "preanunciávei": "preanunciar",
    "preanunciáveis": "preanunciar",
    "preara": "prear",
    "prearam": "prear",
    "prearas": "prear",
    "prearde": "prear",
    "preardes": "prear",
    "preare": "prear",
    "prearei": "prear",
    "preareis": "prear",
    "prearem": "prear",
    "prearemos": "prear",
    "preares": "prear",
    "prearia": "prear",
    "preariam": "prear",
    "prearias": "prear",
    "prearmo": "prear",
    "prearmos": "prear",
    "preará": "prear",
    "prearás": "prear",
    "prearão": "prear",
    "prearíamos": "prear",
    "prearíeis": "prear",
    "preasse": "prear",
    "preassem": "prear",
    "preasses": "prear",
    "preaste": "prear",
    "preastes": "prear",
    "preava": "prear",
    "preavam": "prear",
    "preavas": "prear",
    "prebenda": "prebendar",
    "prebendada": "prebendar",
    "prebendadas": "prebendar",
    "prebendado": "prebendar",
    "prebendados": "prebendar",
    "prebendai": "prebendar",
    "prebendais": "prebendar",
    "prebendam": "prebendar",
    "prebendamo": "prebendar",
    "prebendamos": "prebendar",
    "prebendando": "prebendar",
    "prebendara": "prebendar",
    "prebendaram": "prebendar",
    "prebendaras": "prebendar",
    "prebendarde": "prebendar",
    "prebendardes": "prebendar",
    "prebendare": "prebendar",
    "prebendarei": "prebendar",
    "prebendareis": "prebendar",
    "prebendarem": "prebendar",
    "prebendaremos": "prebendar",
    "prebendares": "prebendar",
    "prebendaria": "prebendar",
    "prebendariam": "prebendar",
    "prebendarias": "prebendaria",
    "prebendarmo": "prebendar",
    "prebendarmos": "prebendar",
    "prebendará": "prebendar",
    "prebendarás": "prebendar",
    "prebendarão": "prebendar",
    "prebendaríamos": "prebendar",
    "prebendaríeis": "prebendar",
    "prebendas": "prebendar",
    "prebendasse": "prebendar",
    "prebendassem": "prebendar",
    "prebendasses": "prebendar",
    "prebendaste": "prebendar",
    "prebendastes": "prebendar",
    "prebendava": "prebendar",
    "prebendavam": "prebendar",
    "prebendavas": "prebendar",
    "prebende": "prebendar",
    "prebendei": "prebendar",
    "prebendeira": "prebendeiro",
    "prebendeiras": "prebendeiro",
    "prebendeiros": "prebendeiro",
    "prebendeis": "prebendar",
    "prebendem": "prebendar",
    "prebendemo": "prebendar",
    "prebendemos": "prebendar",
    "prebendes": "prebendar",
    "prebendo": "prebendar",
    "prebendou": "prebendar",
    "prebendá": "prebendar",
    "prebendámo": "prebendar",
    "prebendámos": "prebendar",
    "prebendáramo": "prebendar",
    "prebendáramos": "prebendar",
    "prebendárei": "prebendar",
    "prebendáreis": "prebendar",
    "prebendária": "prebendário",
    "prebendárias": "prebendário",
    "prebendários": "prebendário",
    "prebendásseis": "prebendar",
    "prebendássemos": "prebendar",
    "prebendávamo": "prebendar",
    "prebendávamos": "prebendar",
    "prebendávei": "prebendar",
    "prebendáveis": "prebendar",
    "prebostados": "prebostado",
    "prebostais": "prebostal",
    "prebostes": "preboste",
    "precanta": "precantar",
    "precantada": "precantar",
    "precantadas": "precantar",
    "precantado": "precantar",
    "precantados": "precantar",
    "precantai": "precantar",
    "precantais": "precantar",
    "precantam": "precantar",
    "precantamo": "precantar",
    "precantamos": "precantar",
    "precantando": "precantar",
    "precantara": "precantar",
    "precantaram": "precantar",
    "precantaras": "precantar",
    "precantarde": "precantar",
    "precantardes": "precantar",
    "precantare": "precantar",
    "precantarei": "precantar",
    "precantareis": "precantar",
    "precantarem": "precantar",
    "precantaremos": "precantar",
    "precantares": "precantar",
    "precantaria": "precantar",
    "precantariam": "precantar",
    "precantarias": "precantar",
    "precantarmo": "precantar",
    "precantarmos": "precantar",
    "precantará": "precantar",
    "precantarás": "precantar",
    "precantarão": "precantar",
    "precantaríamos": "precantar",
    "precantaríeis": "precantar",
    "precantas": "precantar",
    "precantasse": "precantar",
    "precantassem": "precantar",
    "precantasses": "precantar",
    "precantaste": "precantar",
    "precantastes": "precantar",
    "precantava": "precantar",
    "precantavam": "precantar",
    "precantavas": "precantar",
    "precante": "precantar",
    "precantei": "precantar",
    "precanteis": "precantar",
    "precantem": "precantar",
    "precantemo": "precantar",
    "precantemos": "precantar",
    "precantes": "precantar",
    "precanto": "precantar",
    "precantou": "precantar",
    "precantá": "precantar",
    "precantámo": "precantar",
    "precantámos": "precantar",
    "precantáramo": "precantar",
    "precantáramos": "precantar",
    "precantárei": "precantar",
    "precantáreis": "precantar",
    "precantásseis": "precantar",
    "precantássemos": "precantar",
    "precantávamo": "precantar",
    "precantávamos": "precantar",
    "precantávei": "precantar",
    "precantáveis": "precantar",
    "precaridades": "precaridade",
    "precarizações": "precarização",
    "precata": "precatar",
    "precatada": "precatar",
    "precatadas": "precatar",
    "precatado": "precatar",
    "precatados": "precatar",
    "precatadíssima": "precatado",
    "precatadíssimas": "precatado",
    "precatadíssimo": "precatado",
    "precatadíssimos": "precatado",
    "precatai": "precatar",
    "precatais": "precatar",
    "precatam": "precatar",
    "precatamo": "precatar",
    "precatamos": "precatar",
    "precatando": "precatar",
    "precatara": "precatar",
    "precataram": "precatar",
    "precataras": "precatar",
    "precatarde": "precatar",
    "precatardes": "precatar",
    "precatare": "precatar",
    "precatarei": "precatar",
    "precatareis": "precatar",
    "precatarem": "precatar",
    "precataremos": "precatar",
    "precatares": "precatar",
    "precataria": "precatar",
    "precatariam": "precatar",
    "precatarias": "precatar",
    "precatarmo": "precatar",
    "precatarmos": "precatar",
    "precatará": "precatar",
    "precatarás": "precatar",
    "precatarão": "precatar",
    "precataríamos": "precatar",
    "precataríeis": "precatar",
    "precatas": "precatar",
    "precatasse": "precatar",
    "precatassem": "precatar",
    "precatasses": "precatar",
    "precataste": "precatar",
    "precatastes": "precatar",
    "precatava": "precatar",
    "precatavam": "precatar",
    "precatavas": "precatar",
    "precate": "precatar",
    "precatei": "precatar",
    "precateis": "precatar",
    "precatem": "precatar",
    "precatemo": "precatar",
    "precatemos": "precatar",
    "precates": "precatar",
    "precato": "precatar",
    "precatou": "precatar",
    "precatá": "precatar",
    "precatámo": "precatar",
    "precatámos": "precatar",
    "precatáramo": "precatar",
    "precatáramos": "precatar",
    "precatárei": "precatar",
    "precatáreis": "precatar",
    "precatásseis": "precatar",
    "precatássemos": "precatar",
    "precatávamo": "precatar",
    "precatávamos": "precatar",
    "precatávei": "precatar",
    "precatáveis": "precatar",
    "precatória": "precatório",
    "precatórias": "precatório",
    "precatórios": "precatório",
    "precauciona": "precaucionar",
    "precaucionada": "precaucionar",
    "precaucionadas": "precaucionar",
    "precaucionado": "precaucionar",
    "precaucionados": "precaucionar",
    "precaucionai": "precaucionar",
    "precaucionais": "precaucionar",
    "precaucionam": "precaucionar",
    "precaucionamo": "precaucionar",
    "precaucionamos": "precaucionar",
    "precaucionando": "precaucionar",
    "precaucionara": "precaucionar",
    "precaucionaram": "precaucionar",
    "precaucionaras": "precaucionar",
    "precaucionarde": "precaucionar",
    "precaucionardes": "precaucionar",
    "precaucionare": "precaucionar",
    "precaucionarei": "precaucionar",
    "precaucionareis": "precaucionar",
    "precaucionarem": "precaucionar",
    "precaucionaremos": "precaucionar",
    "precaucionares": "precaucionar",
    "precaucionaria": "precaucionar",
    "precaucionariam": "precaucionar",
    "precaucionarias": "precaucionar",
    "precaucionarmo": "precaucionar",
    "precaucionarmos": "precaucionar",
    "precaucionará": "precaucionar",
    "precaucionarás": "precaucionar",
    "precaucionarão": "precaucionar",
    "precaucionaríamos": "precaucionar",
    "precaucionaríeis": "precaucionar",
    "precaucionas": "precaucionar",
    "precaucionasse": "precaucionar",
    "precaucionassem": "precaucionar",
    "precaucionasses": "precaucionar",
    "precaucionaste": "precaucionar",
    "precaucionastes": "precaucionar",
    "precaucionava": "precaucionar",
    "precaucionavam": "precaucionar",
    "precaucionavas": "precaucionar",
    "precaucione": "precaucionar",
    "precaucionei": "precaucionar",
    "precaucioneis": "precaucionar",
    "precaucionem": "precaucionar",
    "precaucionemo": "precaucionar",
    "precaucionemos": "precaucionar",
    "precauciones": "precaucionar",
    "precauciono": "precaucionar",
    "precaucionou": "precaucionar",
    "precaucioná": "precaucionar",
    "precaucionámo": "precaucionar",
    "precaucionámos": "precaucionar",
    "precaucionáramo": "precaucionar",
    "precaucionáramos": "precaucionar",
    "precaucionárei": "precaucionar",
    "precaucionáreis": "precaucionar",
    "precaucionásseis": "precaucionar",
    "precaucionássemos": "precaucionar",
    "precaucionávamo": "precaucionar",
    "precaucionávamos": "precaucionar",
    "precaucionávei": "precaucionar",
    "precaucionáveis": "precaucionar",
    "precautela": "precautelar",
    "precautelada": "precautelar",
    "precauteladas": "precautelar",
    "precautelado": "precautelar",
    "precautelados": "precautelar",
    "precautelai": "precautelar",
    "precautelais": "precautelar",
    "precautelam": "precautelar",
    "precautelamo": "precautelar",
    "precautelamos": "precautelar",
    "precautelando": "precautelar",
    "precautelara": "precautelar",
    "precautelaram": "precautelar",
    "precautelaras": "precautelar",
    "precautelarde": "precautelar",
    "precautelardes": "precautelar",
    "precautelare": "precautelar",
    "precautelarei": "precautelar",
    "precautelareis": "precautelar",
    "precautelarem": "precautelar",
    "precautelaremos": "precautelar",
    "precautelares": "precautelar",
    "precautelaria": "precautelar",
    "precautelariam": "precautelar",
    "precautelarias": "precautelar",
    "precautelarmo": "precautelar",
    "precautelarmos": "precautelar",
    "precautelará": "precautelar",
    "precautelarás": "precautelar",
    "precautelarão": "precautelar",
    "precautelaríamos": "precautelar",
    "precautelaríeis": "precautelar",
    "precautelas": "precautelar",
    "precautelasse": "precautelar",
    "precautelassem": "precautelar",
    "precautelasses": "precautelar",
    "precautelaste": "precautelar",
    "precautelastes": "precautelar",
    "precautelava": "precautelar",
    "precautelavam": "precautelar",
    "precautelavas": "precautelar",
    "precautele": "precautelar",
    "precautelei": "precautelar",
    "precauteleis": "precautelar",
    "precautelem": "precautelar",
    "precautelemo": "precautelar",
    "precautelemos": "precautelar",
    "precauteles": "precautelar",
    "precautelo": "precautelar",
    "precautelou": "precautelar",
    "precautelá": "precautelar",
    "precautelámo": "precautelar",
    "precautelámos": "precautelar",
    "precauteláramo": "precautelar",
    "precauteláramos": "precautelar",
    "precautelárei": "precautelar",
    "precauteláreis": "precautelar",
    "precautelásseis": "precautelar",
    "precautelássemos": "precautelar",
    "precautelávamo": "precautelar",
    "precautelávamos": "precautelar",
    "precautelávei": "precautelar",
    "precauteláveis": "precautelar",
    "precautória": "precautório",
    "precautórias": "precautório",
    "precautórios": "precautório",
    "precauções": "precaução",
    "precava": "precaver",
    "precavais": "precaver",
    "precavam": "precaver",
    "precavamo": "precaver",
    "precavamos": "precaver",
    "precavas": "precaver",
    "precave": "precaver",
    "precavei": "precaver",
    "precaveis": "precaver",
    "precavem": "precaver",
    "precavemo": "precaver",
    "precavemos": "precaver",
    "precavendo": "precaver",
    "precavera": "precaver",
    "precaveram": "precaver",
    "precaveras": "precaver",
    "precaverde": "precaver",
    "precaverdes": "precaver",
    "precavere": "precaver",
    "precaverei": "precaver",
    "precavereis": "precaver",
    "precaverem": "precaver",
    "precaveremos": "precaver",
    "precaveres": "precaver",
    "precaveria": "precaver",
    "precaveriam": "precaver",
    "precaverias": "precaver",
    "precavermo": "precaver",
    "precavermos": "precaver",
    "precaverá": "precaver",
    "precaverás": "precaver",
    "precaverão": "precaver",
    "precaveríamos": "precaver",
    "precaveríeis": "precaver",
    "precaves": "precaver",
    "precavesse": "precaver",
    "precavessem": "precaver",
    "precavesses": "precaver",
    "precaveste": "precaver",
    "precavestes": "precaver",
    "precaveu": "precaver",
    "precavi": "precaver",
    "precavia": "precaver",
    "precaviam": "precaver",
    "precavias": "precaver",
    "precavida": "precavido",
    "precavidas": "precavido",
    "precavido": "precaver",
    "precavidos": "precavido",
    "precavidíssima": "precavido",
    "precavidíssimas": "precavido",
    "precavidíssimo": "precavido",
    "precavidíssimos": "precavido",
    "precavo": "precaver",
    "precavê": "precaver",
    "precavêramo": "precaver",
    "precavêramos": "precaver",
    "precavêrei": "precaver",
    "precavêreis": "precaver",
    "precavêsseis": "precaver",
    "precavêssemos": "precaver",
    "precavíamo": "precaver",
    "precavíamos": "precaver",
    "precavíei": "precaver",
    "precavíeis": "precaver",
    "precações": "precação",
    "preceda": "preceder",
    "precedais": "preceder",
    "precedam": "preceder",
    "precedamo": "preceder",
    "precedamos": "preceder",
    "precedas": "preceder",
    "precede": "preceder",
    "precedei": "preceder",
    "precedeis": "preceder",
    "precedem": "preceder",
    "precedemo": "preceder",
    "precedemos": "preceder",
    "precedendo": "preceder",
    "precedentes": "precedente",
    "precedera": "preceder",
    "precederam": "preceder",
    "precederas": "preceder",
    "precederde": "preceder",
    "precederdes": "preceder",
    "precedere": "preceder",
    "precederei": "preceder",
    "precedereis": "preceder",
    "precederem": "preceder",
    "precederemos": "preceder",
    "precederes": "preceder",
    "precederia": "preceder",
    "precederiam": "preceder",
    "precederias": "preceder",
    "precedermo": "preceder",
    "precedermos": "preceder",
    "precederá": "preceder",
    "precederás": "preceder",
    "precederão": "preceder",
    "precederíamos": "preceder",
    "precederíeis": "preceder",
    "precedes": "preceder",
    "precedesse": "preceder",
    "precedessem": "preceder",
    "precedesses": "preceder",
    "precedeste": "preceder",
    "precedestes": "preceder",
    "precedeu": "preceder",
    "precedi": "preceder",
    "precedia": "preceder",
    "precediam": "preceder",
    "precedias": "preceder",
    "precedida": "precedido",
    "precedidas": "precedido",
    "precedido": "preceder",
    "precedidos": "precedido",
    "precedo": "preceder",
    "precedê": "preceder",
    "precedências": "precedência",
    "precedêramo": "preceder",
    "precedêramos": "preceder",
    "precedêrei": "preceder",
    "precedêreis": "preceder",
    "precedêsseis": "preceder",
    "precedêssemos": "preceder",
    "precedíamo": "preceder",
    "precedíamos": "preceder",
    "precedíei": "preceder",
    "precedíeis": "preceder",
    "preceitos": "preceito",
    "preceitua": "preceituar",
    "preceituada": "preceituar",
    "preceituadas": "preceituar",
    "preceituado": "preceituar",
    "preceituadora": "preceituador",
    "preceituadoras": "preceituador",
    "preceituadores": "preceituador",
    "preceituados": "preceituar",
    "preceituai": "preceituar",
    "preceituais": "preceituar",
    "preceituam": "preceituar",
    "preceituamo": "preceituar",
    "preceituamos": "preceituar",
    "preceituando": "preceituar",
    "preceituara": "preceituar",
    "preceituaram": "preceituar",
    "preceituaras": "preceituar",
    "preceituarde": "preceituar",
    "preceituardes": "preceituar",
    "preceituare": "preceituar",
    "preceituarei": "preceituar",
    "preceituareis": "preceituar",
    "preceituarem": "preceituar",
    "preceituaremos": "preceituar",
    "preceituares": "preceituar",
    "preceituaria": "preceituar",
    "preceituariam": "preceituar",
    "preceituarias": "preceituar",
    "preceituarmo": "preceituar",
    "preceituarmos": "preceituar",
    "preceituará": "preceituar",
    "preceituarás": "preceituar",
    "preceituarão": "preceituar",
    "preceituaríamos": "preceituar",
    "preceituaríeis": "preceituar",
    "preceituas": "preceituar",
    "preceituasse": "preceituar",
    "preceituassem": "preceituar",
    "preceituasses": "preceituar",
    "preceituaste": "preceituar",
    "preceituastes": "preceituar",
    "preceituava": "preceituar",
    "preceituavam": "preceituar",
    "preceituavas": "preceituar",
    "preceituações": "preceituação",
    "preceitue": "preceituar",
    "preceituei": "preceituar",
    "preceitueis": "preceituar",
    "preceituem": "preceituar",
    "preceituemo": "preceituar",
    "preceituemos": "preceituar",
    "preceitues": "preceituar",
    "preceituo": "preceituar",
    "preceituosa": "preceituoso",
    "preceituosas": "preceituoso",
    "preceituosos": "preceituoso",
    "preceituou": "preceituar",
    "preceituá": "preceituar",
    "preceituámo": "preceituar",
    "preceituámos": "preceituar",
    "preceituáramo": "preceituar",
    "preceituáramos": "preceituar",
    "preceituárei": "preceituar",
    "preceituáreis": "preceituar",
    "preceituários": "preceituário",
    "preceituásseis": "preceituar",
    "preceituássemos": "preceituar",
    "preceituávamo": "preceituar",
    "preceituávamos": "preceituar",
    "preceituávei": "preceituar",
    "preceituáveis": "preceituar",
    "preceptiva": "preceptivo",
    "preceptivas": "preceptivo",
    "preceptivos": "preceptivo",
    "preceptora": "preceptor",
    "preceptorados": "preceptorado",
    "preceptorais": "preceptoral",
    "preceptoras": "preceptor",
    "preceptores": "preceptor",
    "preceptoriais": "preceptorial",
    "preces": "prece",
    "precessões": "precessão",
    "precinge": "precingir",
    "precingem": "precingir",
    "precinges": "precingir",
    "precingi": "precingir",
    "precingia": "precingir",
    "precingiam": "precingir",
    "precingias": "precingir",
    "precingida": "precingir",
    "precingidas": "precingir",
    "precingido": "precingir",
    "precingidos": "precingir",
    "precingimo": "precingir",
    "precingimos": "precingir",
    "precingindo": "precingir",
    "precingira": "precingir",
    "precingiram": "precingir",
    "precingiras": "precingir",
    "precingirde": "precingir",
    "precingirdes": "precingir",
    "precingire": "precingir",
    "precingirei": "precingir",
    "precingireis": "precingir",
    "precingirem": "precingir",
    "precingiremos": "precingir",
    "precingires": "precingir",
    "precingiria": "precingir",
    "precingiriam": "precingir",
    "precingirias": "precingir",
    "precingirmo": "precingir",
    "precingirmos": "precingir",
    "precingirá": "precingir",
    "precingirás": "precingir",
    "precingirão": "precingir",
    "precingiríamos": "precingir",
    "precingiríeis": "precingir",
    "precingis": "precingir",
    "precingisse": "precingir",
    "precingissem": "precingir",
    "precingisses": "precingir",
    "precingiste": "precingir",
    "precingistes": "precingir",
    "precingiu": "precingir",
    "precingíamo": "precingir",
    "precingíamos": "precingir",
    "precingíei": "precingir",
    "precingíeis": "precingir",
    "precingíramo": "precingir",
    "precingíramos": "precingir",
    "precingírei": "precingir",
    "precingíreis": "precingir",
    "precingísseis": "precingir",
    "precingíssemos": "precingir",
    "precinja": "precingir",
    "precinjais": "precingir",
    "precinjam": "precingir",
    "precinjamo": "precingir",
    "precinjamos": "precingir",
    "precinjas": "precingir",
    "precinjo": "precingir",
    "precinta": "precintar",
    "precintada": "precintar",
    "precintadas": "precintar",
    "precintado": "precintar",
    "precintados": "precintar",
    "precintai": "precintar",
    "precintais": "precintar",
    "precintam": "precintar",
    "precintamo": "precintar",
    "precintamos": "precintar",
    "precintando": "precintar",
    "precintara": "precintar",
    "precintaram": "precintar",
    "precintaras": "precintar",
    "precintarde": "precintar",
    "precintardes": "precintar",
    "precintare": "precintar",
    "precintarei": "precintar",
    "precintareis": "precintar",
    "precintarem": "precintar",
    "precintaremos": "precintar",
    "precintares": "precintar",
    "precintaria": "precintar",
    "precintariam": "precintar",
    "precintarias": "precintar",
    "precintarmo": "precintar",
    "precintarmos": "precintar",
    "precintará": "precintar",
    "precintarás": "precintar",
    "precintarão": "precintar",
    "precintaríamos": "precintar",
    "precintaríeis": "precintar",
    "precintas": "precintar",
    "precintasse": "precintar",
    "precintassem": "precintar",
    "precintasses": "precintar",
    "precintaste": "precintar",
    "precintastes": "precintar",
    "precintava": "precintar",
    "precintavam": "precintar",
    "precintavas": "precintar",
    "precinte": "precintar",
    "precintei": "precintar",
    "precinteis": "precintar",
    "precintem": "precintar",
    "precintemo": "precintar",
    "precintemos": "precintar",
    "precintes": "precintar",
    "precinto": "precintar",
    "precintos": "precinto",
    "precintou": "precintar",
    "precintá": "precintar",
    "precintámo": "precintar",
    "precintámos": "precintar",
    "precintáramo": "precintar",
    "precintáramos": "precintar",
    "precintárei": "precintar",
    "precintáreis": "precintar",
    "precintásseis": "precintar",
    "precintássemos": "precintar",
    "precintávamo": "precintar",
    "precintávamos": "precintar",
    "precintávei": "precintar",
    "precintáveis": "precintar",
    "precinções": "precinção",
    "preciosa": "precioso",
    "preciosas": "precioso",
    "preciosidades": "preciosidade",
    "preciosismos": "preciosismo",
    "preciosos": "precioso",
    "preciosíssima": "precioso",
    "preciosíssimas": "precioso",
    "preciosíssimo": "precioso",
    "preciosíssimos": "precioso",
    "precipita": "precipitar",
    "precipitada": "precipitar",
    "precipitadas": "precipitar",
    "precipitado": "precipitar",
    "precipitados": "precipitar",
    "precipitadíssima": "precipitado",
    "precipitadíssimas": "precipitado",
    "precipitadíssimo": "precipitado",
    "precipitadíssimos": "precipitado",
    "precipitai": "precipitar",
    "precipitais": "precipitar",
    "precipitam": "precipitar",
    "precipitamo": "precipitar",
    "precipitamos": "precipitar",
    "precipitando": "precipitar",
    "precipitantes": "precipitante",
    "precipitara": "precipitar",
    "precipitaram": "precipitar",
    "precipitaras": "precipitar",
    "precipitarde": "precipitar",
    "precipitardes": "precipitar",
    "precipitare": "precipitar",
    "precipitarei": "precipitar",
    "precipitareis": "precipitar",
    "precipitarem": "precipitar",
    "precipitaremos": "precipitar",
    "precipitares": "precipitar",
    "precipitaria": "precipitar",
    "precipitariam": "precipitar",
    "precipitarias": "precipitar",
    "precipitarmo": "precipitar",
    "precipitarmos": "precipitar",
    "precipitará": "precipitar",
    "precipitarás": "precipitar",
    "precipitarão": "precipitar",
    "precipitaríamos": "precipitar",
    "precipitaríeis": "precipitar",
    "precipitas": "precipitar",
    "precipitasse": "precipitar",
    "precipitassem": "precipitar",
    "precipitasses": "precipitar",
    "precipitaste": "precipitar",
    "precipitastes": "precipitar",
    "precipitava": "precipitar",
    "precipitavam": "precipitar",
    "precipitavas": "precipitar",
    "precipitações": "precipitação",
    "precipite": "precipitar",
    "precipitei": "precipitar",
    "precipiteis": "precipitar",
    "precipitem": "precipitar",
    "precipitemo": "precipitar",
    "precipitemos": "precipitar",
    "precipites": "precipitar",
    "precipito": "precipitar",
    "precipitosa": "precipitoso",
    "precipitosas": "precipitoso",
    "precipitosos": "precipitoso",
    "precipitou": "precipitar",
    "precipitá": "precipitar",
    "precipitámo": "precipitar",
    "precipitámos": "precipitar",
    "precipitáramo": "precipitar",
    "precipitáramos": "precipitar",
    "precipitárei": "precipitar",
    "precipitáreis": "precipitar",
    "precipitásseis": "precipitar",
    "precipitássemos": "precipitar",
    "precipitávamo": "precipitar",
    "precipitávamos": "precipitar",
    "precipitávei": "precipitar",
    "precipitáveis": "precipitável",
    "precipícios": "precipício",
    "precisa": "preciso",
    "precisada": "precisar",
    "precisadas": "precisar",
    "precisado": "precisar",
    "precisados": "precisar",
    "precisai": "precisar",
    "precisais": "precisar",
    "precisam": "precisar",
    "precisamo": "precisar",
    "precisamos": "precisar",
    "precisando": "precisar",
    "precisara": "precisar",
    "precisaram": "precisar",
    "precisaras": "precisar",
    "precisarde": "precisar",
    "precisardes": "precisar",
    "precisare": "precisar",
    "precisarei": "precisar",
    "precisareis": "precisar",
    "precisarem": "precisar",
    "precisaremos": "precisar",
    "precisares": "precisar",
    "precisaria": "precisar",
    "precisariam": "precisar",
    "precisarias": "precisar",
    "precisarmo": "precisar",
    "precisarmos": "precisar",
    "precisará": "precisar",
    "precisarás": "precisar",
    "precisarão": "precisar",
    "precisaríamos": "precisar",
    "precisaríeis": "precisar",
    "precisas": "preciso",
    "precisasse": "precisar",
    "precisassem": "precisar",
    "precisasses": "precisar",
    "precisaste": "precisar",
    "precisastes": "precisar",
    "precisava": "precisar",
    "precisavam": "precisar",
    "precisavas": "precisar",
    "precise": "precisar",
    "precisei": "precisar",
    "preciseis": "precisar",
    "precisem": "precisar",
    "precisemo": "precisar",
    "precisemos": "precisar",
    "precises": "precisar",
    "preciso": "precisar",
    "precisos": "preciso",
    "precisou": "precisar",
    "precisá": "precisar",
    "precisámo": "precisar",
    "precisámos": "precisar",
    "precisáramo": "precisar",
    "precisáramos": "precisar",
    "precisárei": "precisar",
    "precisáreis": "precisar",
    "precisásseis": "precisar",
    "precisássemos": "precisar",
    "precisávamo": "precisar",
    "precisávamos": "precisar",
    "precisávei": "precisar",
    "precisáveis": "precisar",
    "precisões": "precisão",
    "precita": "precito",
    "precitas": "precito",
    "precitos": "precito",
    "preclara": "preclaro",
    "preclaras": "preclaro",
    "preclaridades": "preclaridade",
    "preclaros": "preclaro",
    "preclaríssima": "preclaro",
    "preclaríssimas": "preclaro",
    "preclaríssimo": "preclaro",
    "preclaríssimos": "preclaro",
    "precluda": "precludir",
    "precludais": "precludir",
    "precludam": "precludir",
    "precludamo": "precludir",
    "precludamos": "precludir",
    "precludas": "precludir",
    "preclude": "precludir",
    "precludem": "precludir",
    "precludes": "precludir",
    "precludi": "precludir",
    "precludia": "precludir",
    "precludiam": "precludir",
    "precludias": "precludir",
    "precludida": "precludir",
    "precludidas": "precludir",
    "precludido": "precludir",
    "precludidos": "precludir",
    "precludimo": "precludir",
    "precludimos": "precludir",
    "precludindo": "precludir",
    "precludira": "precludir",
    "precludiram": "precludir",
    "precludiras": "precludir",
    "precludirde": "precludir",
    "precludirdes": "precludir",
    "precludire": "precludir",
    "precludirei": "precludir",
    "precludireis": "precludir",
    "precludirem": "precludir",
    "precludiremos": "precludir",
    "precludires": "precludir",
    "precludiria": "precludir",
    "precludiriam": "precludir",
    "precludirias": "precludir",
    "precludirmo": "precludir",
    "precludirmos": "precludir",
    "precludirá": "precludir",
    "precludirás": "precludir",
    "precludirão": "precludir",
    "precludiríamos": "precludir",
    "precludiríeis": "precludir",
    "precludis": "precludir",
    "precludisse": "precludir",
    "precludissem": "precludir",
    "precludisses": "precludir",
    "precludiste": "precludir",
    "precludistes": "precludir",
    "precludiu": "precludir",
    "precludo": "precludir",
    "precludíamo": "precludir",
    "precludíamos": "precludir",
    "precludíei": "precludir",
    "precludíeis": "precludir",
    "precludíramo": "precludir",
    "precludíramos": "precludir",
    "precludírei": "precludir",
    "precludíreis": "precludir",
    "precludísseis": "precludir",
    "precludíssemos": "precludir",
    "preclusões": "preclusão",
    "precoces": "precoce",
    "precocidades": "precocidade",
    "precogita": "precogitar",
    "precogitada": "precogitar",
    "precogitadas": "precogitar",
    "precogitado": "precogitar",
    "precogitados": "precogitar",
    "precogitai": "precogitar",
    "precogitais": "precogitar",
    "precogitam": "precogitar",
    "precogitamo": "precogitar",
    "precogitamos": "precogitar",
    "precogitando": "precogitar",
    "precogitara": "precogitar",
    "precogitaram": "precogitar",
    "precogitaras": "precogitar",
    "precogitarde": "precogitar",
    "precogitardes": "precogitar",
    "precogitare": "precogitar",
    "precogitarei": "precogitar",
    "precogitareis": "precogitar",
    "precogitarem": "precogitar",
    "precogitaremos": "precogitar",
    "precogitares": "precogitar",
    "precogitaria": "precogitar",
    "precogitariam": "precogitar",
    "precogitarias": "precogitar",
    "precogitarmo": "precogitar",
    "precogitarmos": "precogitar",
    "precogitará": "precogitar",
    "precogitarás": "precogitar",
    "precogitarão": "precogitar",
    "precogitaríamos": "precogitar",
    "precogitaríeis": "precogitar",
    "precogitas": "precogitar",
    "precogitasse": "precogitar",
    "precogitassem": "precogitar",
    "precogitasses": "precogitar",
    "precogitaste": "precogitar",
    "precogitastes": "precogitar",
    "precogitava": "precogitar",
    "precogitavam": "precogitar",
    "precogitavas": "precogitar",
    "precogite": "precogitar",
    "precogitei": "precogitar",
    "precogiteis": "precogitar",
    "precogitem": "precogitar",
    "precogitemo": "precogitar",
    "precogitemos": "precogitar",
    "precogites": "precogitar",
    "precogito": "precogitar",
    "precogitou": "precogitar",
    "precogitá": "precogitar",
    "precogitámo": "precogitar",
    "precogitámos": "precogitar",
    "precogitáramo": "precogitar",
    "precogitáramos": "precogitar",
    "precogitárei": "precogitar",
    "precogitáreis": "precogitar",
    "precogitásseis": "precogitar",
    "precogitássemos": "precogitar",
    "precogitávamo": "precogitar",
    "precogitávamos": "precogitar",
    "precogitávei": "precogitar",
    "precogitáveis": "precogitar",
    "precognições": "precognição",
    "preconceba": "preconceber",
    "preconcebais": "preconceber",
    "preconcebam": "preconceber",
    "preconcebamo": "preconceber",
    "preconcebamos": "preconceber",
    "preconcebas": "preconceber",
    "preconcebe": "preconceber",
    "preconcebei": "preconceber",
    "preconcebeis": "preconceber",
    "preconcebem": "preconceber",
    "preconcebemo": "preconceber",
    "preconcebemos": "preconceber",
    "preconcebendo": "preconceber",
    "preconcebera": "preconceber",
    "preconceberam": "preconceber",
    "preconceberas": "preconceber",
    "preconceberde": "preconceber",
    "preconceberdes": "preconceber",
    "preconcebere": "preconceber",
    "preconceberei": "preconceber",
    "preconcebereis": "preconceber",
    "preconceberem": "preconceber",
    "preconceberemos": "preconceber",
    "preconceberes": "preconceber",
    "preconceberia": "preconceber",
    "preconceberiam": "preconceber",
    "preconceberias": "preconceber",
    "preconcebermo": "preconceber",
    "preconcebermos": "preconceber",
    "preconceberá": "preconceber",
    "preconceberás": "preconceber",
    "preconceberão": "preconceber",
    "preconceberíamos": "preconceber",
    "preconceberíeis": "preconceber",
    "preconcebes": "preconceber",
    "preconcebesse": "preconceber",
    "preconcebessem": "preconceber",
    "preconcebesses": "preconceber",
    "preconcebeste": "preconceber",
    "preconcebestes": "preconceber",
    "preconcebeu": "preconceber",
    "preconcebi": "preconceber",
    "preconcebia": "preconceber",
    "preconcebiam": "preconceber",
    "preconcebias": "preconceber",
    "preconcebida": "preconcebido",
    "preconcebidas": "preconcebido",
    "preconcebido": "preconceber",
    "preconcebidos": "preconcebido",
    "preconcebo": "preconceber",
    "preconcebê": "preconceber",
    "preconcebêramo": "preconceber",
    "preconcebêramos": "preconceber",
    "preconcebêrei": "preconceber",
    "preconcebêreis": "preconceber",
    "preconcebêsseis": "preconceber",
    "preconcebêssemos": "preconceber",
    "preconcebíamo": "preconceber",
    "preconcebíamos": "preconceber",
    "preconcebíei": "preconceber",
    "preconcebíeis": "preconceber",
    "preconcebíveis": "preconcebível",
    "preconceitos": "preconceito",
    "preconceituosa": "preconceituoso",
    "preconceituosas": "preconceituoso",
    "preconceituosos": "preconceituoso",
    "preconcepções": "preconcepção",
    "preconiza": "preconizar",
    "preconizada": "preconizar",
    "preconizadas": "preconizar",
    "preconizado": "preconizar",
    "preconizadora": "preconizador",
    "preconizadoras": "preconizador",
    "preconizadores": "preconizador",
    "preconizados": "preconizar",
    "preconizai": "preconizar",
    "preconizais": "preconizar",
    "preconizam": "preconizar",
    "preconizamo": "preconizar",
    "preconizamos": "preconizar",
    "preconizando": "preconizar",
    "preconizara": "preconizar",
    "preconizaram": "preconizar",
    "preconizaras": "preconizar",
    "preconizarde": "preconizar",
    "preconizardes": "preconizar",
    "preconizare": "preconizar",
    "preconizarei": "preconizar",
    "preconizareis": "preconizar",
    "preconizarem": "preconizar",
    "preconizaremos": "preconizar",
    "preconizares": "preconizar",
    "preconizaria": "preconizar",
    "preconizariam": "preconizar",
    "preconizarias": "preconizar",
    "preconizarmo": "preconizar",
    "preconizarmos": "preconizar",
    "preconizará": "preconizar",
    "preconizarás": "preconizar",
    "preconizarão": "preconizar",
    "preconizaríamos": "preconizar",
    "preconizaríeis": "preconizar",
    "preconizas": "preconizar",
    "preconizasse": "preconizar",
    "preconizassem": "preconizar",
    "preconizasses": "preconizar",
    "preconizaste": "preconizar",
    "preconizastes": "preconizar",
    "preconizava": "preconizar",
    "preconizavam": "preconizar",
    "preconizavas": "preconizar",
    "preconizações": "preconização",
    "preconize": "preconizar",
    "preconizei": "preconizar",
    "preconizeis": "preconizar",
    "preconizem": "preconizar",
    "preconizemo": "preconizar",
    "preconizemos": "preconizar",
    "preconizes": "preconizar",
    "preconizo": "preconizar",
    "preconizou": "preconizar",
    "preconizá": "preconizar",
    "preconizámo": "preconizar",
    "preconizámos": "preconizar",
    "preconizáramo": "preconizar",
    "preconizáramos": "preconizar",
    "preconizárei": "preconizar",
    "preconizáreis": "preconizar",
    "preconizásseis": "preconizar",
    "preconizássemos": "preconizar",
    "preconizávamo": "preconizar",
    "preconizávamos": "preconizar",
    "preconizávei": "preconizar",
    "preconizáveis": "preconizável",
    "precordais": "precordal",
    "precordiais": "precordial",
    "precursora": "precursor",
    "precursoras": "precursor",
    "precursorazinha": "precursor",
    "precursorazinhas": "precursor",
    "precursorazita": "precursor",
    "precursorazitas": "precursor",
    "precursores": "precursor",
    "precursorzinho": "precursor",
    "precursorzinhos": "precursor",
    "precursorzito": "precursor",
    "precursorzitos": "precursor",
    "precursões": "precursão",
    "precária": "precário",
    "precárias": "precário",
    "precários": "precário",
    "precípites": "precípite",
    "precípua": "precípuo",
    "precípuas": "precípuo",
    "precípuos": "precípuo",
    "precógnita": "precógnito",
    "precógnitas": "precógnito",
    "precógnitos": "precógnito",
    "predadora": "predador",
    "predadoras": "predador",
    "predadores": "predador",
    "predatória": "predatório",
    "predatórias": "predatório",
    "predatórios": "predatório",
    "predações": "predação",
    "predecessora": "predecessor",
    "predecessoras": "predecessor",
    "predecessores": "predecessor",
    "predefina": "predefinir",
    "predefinais": "predefinir",
    "predefinam": "predefinir",
    "predefinamo": "predefinir",
    "predefinamos": "predefinir",
    "predefinas": "predefinir",
    "predefine": "predefinir",
    "predefinem": "predefinir",
    "predefines": "predefinir",
    "predefini": "predefinir",
    "predefinia": "predefinir",
    "predefiniam": "predefinir",
    "predefinias": "predefinir",
    "predefinida": "predefinir",
    "predefinidas": "predefinir",
    "predefinido": "predefinir",
    "predefinidos": "predefinir",
    "predefinimo": "predefinir",
    "predefinimos": "predefinir",
    "predefinindo": "predefinir",
    "predefinira": "predefinir",
    "predefiniram": "predefinir",
    "predefiniras": "predefinir",
    "predefinirde": "predefinir",
    "predefinirdes": "predefinir",
    "predefinire": "predefinir",
    "predefinirei": "predefinir",
    "predefinireis": "predefinir",
    "predefinirem": "predefinir",
    "predefiniremos": "predefinir",
    "predefinires": "predefinir",
    "predefiniria": "predefinir",
    "predefiniriam": "predefinir",
    "predefinirias": "predefinir",
    "predefinirmo": "predefinir",
    "predefinirmos": "predefinir",
    "predefinirá": "predefinir",
    "predefinirás": "predefinir",
    "predefinirão": "predefinir",
    "predefiniríamos": "predefinir",
    "predefiniríeis": "predefinir",
    "predefinis": "predefinir",
    "predefinisse": "predefinir",
    "predefinissem": "predefinir",
    "predefinisses": "predefinir",
    "predefiniste": "predefinir",
    "predefinistes": "predefinir",
    "predefiniu": "predefinir",
    "predefinições": "predefinição",
    "predefino": "predefinir",
    "predefiníamo": "predefinir",
    "predefiníamos": "predefinir",
    "predefiníei": "predefinir",
    "predefiníeis": "predefinir",
    "predefiníramo": "predefinir",
    "predefiníramos": "predefinir",
    "predefinírei": "predefinir",
    "predefiníreis": "predefinir",
    "predefinísseis": "predefinir",
    "predefiníssemos": "predefinir",
    "predestina": "predestinar",
    "predestinacionismos": "predestinacionismo",
    "predestinacionistas": "predestinacionista",
    "predestinada": "predestinar",
    "predestinadas": "predestinar",
    "predestinado": "predestinar",
    "predestinados": "predestinar",
    "predestinadíssima": "predestinado",
    "predestinadíssimas": "predestinado",
    "predestinadíssimo": "predestinado",
    "predestinadíssimos": "predestinado",
    "predestinai": "predestinar",
    "predestinais": "predestinar",
    "predestinam": "predestinar",
    "predestinamo": "predestinar",
    "predestinamos": "predestinar",
    "predestinando": "predestinar",
    "predestinara": "predestinar",
    "predestinaram": "predestinar",
    "predestinaras": "predestinar",
    "predestinarde": "predestinar",
    "predestinardes": "predestinar",
    "predestinare": "predestinar",
    "predestinarei": "predestinar",
    "predestinareis": "predestinar",
    "predestinarem": "predestinar",
    "predestinaremos": "predestinar",
    "predestinares": "predestinar",
    "predestinaria": "predestinar",
    "predestinariam": "predestinar",
    "predestinarias": "predestinar",
    "predestinarmo": "predestinar",
    "predestinarmos": "predestinar",
    "predestinará": "predestinar",
    "predestinarás": "predestinar",
    "predestinarão": "predestinar",
    "predestinaríamos": "predestinar",
    "predestinaríeis": "predestinar",
    "predestinas": "predestinar",
    "predestinasse": "predestinar",
    "predestinassem": "predestinar",
    "predestinasses": "predestinar",
    "predestinaste": "predestinar",
    "predestinastes": "predestinar",
    "predestinava": "predestinar",
    "predestinavam": "predestinar",
    "predestinavas": "predestinar",
    "predestinações": "predestinação",
    "predestine": "predestinar",
    "predestinei": "predestinar",
    "predestineis": "predestinar",
    "predestinem": "predestinar",
    "predestinemo": "predestinar",
    "predestinemos": "predestinar",
    "predestines": "predestinar",
    "predestino": "predestinar",
    "predestinou": "predestinar",
    "predestiná": "predestinar",
    "predestinámo": "predestinar",
    "predestinámos": "predestinar",
    "predestináramo": "predestinar",
    "predestináramos": "predestinar",
    "predestinárei": "predestinar",
    "predestináreis": "predestinar",
    "predestinásseis": "predestinar",
    "predestinássemos": "predestinar",
    "predestinávamo": "predestinar",
    "predestinávamos": "predestinar",
    "predestinávei": "predestinar",
    "predestináveis": "predestinar",
    "predetermina": "predeterminar",
    "predeterminada": "predeterminar",
    "predeterminadas": "predeterminar",
    "predeterminado": "predeterminar",
    "predeterminados": "predeterminar",
    "predeterminai": "predeterminar",
    "predeterminais": "predeterminar",
    "predeterminam": "predeterminar",
    "predeterminamo": "predeterminar",
    "predeterminamos": "predeterminar",
    "predeterminando": "predeterminar",
    "predeterminantes": "predeterminante",
    "predeterminara": "predeterminar",
    "predeterminaram": "predeterminar",
    "predeterminaras": "predeterminar",
    "predeterminarde": "predeterminar",
    "predeterminardes": "predeterminar",
    "predeterminare": "predeterminar",
    "predeterminarei": "predeterminar",
    "predeterminareis": "predeterminar",
    "predeterminarem": "predeterminar",
    "predeterminaremos": "predeterminar",
    "predeterminares": "predeterminar",
    "predeterminaria": "predeterminar",
    "predeterminariam": "predeterminar",
    "predeterminarias": "predeterminar",
    "predeterminarmo": "predeterminar",
    "predeterminarmos": "predeterminar",
    "predeterminará": "predeterminar",
    "predeterminarás": "predeterminar",
    "predeterminarão": "predeterminar",
    "predeterminaríamos": "predeterminar",
    "predeterminaríeis": "predeterminar",
    "predeterminas": "predeterminar",
    "predeterminasse": "predeterminar",
    "predeterminassem": "predeterminar",
    "predeterminasses": "predeterminar",
    "predeterminaste": "predeterminar",
    "predeterminastes": "predeterminar",
    "predeterminava": "predeterminar",
    "predeterminavam": "predeterminar",
    "predeterminavas": "predeterminar",
    "predeterminações": "predeterminação",
    "predetermine": "predeterminar",
    "predeterminei": "predeterminar",
    "predetermineis": "predeterminar",
    "predeterminem": "predeterminar",
    "predeterminemo": "predeterminar",
    "predeterminemos": "predeterminar",
    "predetermines": "predeterminar",
    "predetermino": "predeterminar",
    "predeterminou": "predeterminar",
    "predeterminá": "predeterminar",
    "predeterminámo": "predeterminar",
    "predeterminámos": "predeterminar",
    "predetermináramo": "predeterminar",
    "predetermináramos": "predeterminar",
    "predeterminárei": "predeterminar",
    "predetermináreis": "predeterminar",
    "predeterminásseis": "predeterminar",
    "predeterminássemos": "predeterminar",
    "predeterminávamo": "predeterminar",
    "predeterminávamos": "predeterminar",
    "predeterminávei": "predeterminar",
    "predetermináveis": "predeterminar",
    "prediais": "predial",
    "predica": "predicar",
    "predicada": "predicar",
    "predicadas": "predicar",
    "predicado": "predicar",
    "predicadora": "predicador",
    "predicadoras": "predicador",
    "predicadores": "predicador",
    "predicados": "predicar",
    "predicai": "predicar",
    "predicais": "predicar",
    "predicam": "predicar",
    "predicamenta": "predicamentar",
    "predicamentada": "predicamentar",
    "predicamentadas": "predicamentar",
    "predicamentado": "predicamentar",
    "predicamentados": "predicamentar",
    "predicamentai": "predicamentar",
    "predicamentais": "predicamentar",
    "predicamentam": "predicamentar",
    "predicamentamo": "predicamentar",
    "predicamentamos": "predicamentar",
    "predicamentando": "predicamentar",
    "predicamentara": "predicamentar",
    "predicamentaram": "predicamentar",
    "predicamentaras": "predicamentar",
    "predicamentarde": "predicamentar",
    "predicamentardes": "predicamentar",
    "predicamentare": "predicamentar",
    "predicamentarei": "predicamentar",
    "predicamentareis": "predicamentar",
    "predicamentarem": "predicamentar",
    "predicamentaremos": "predicamentar",
    "predicamentares": "predicamentar",
    "predicamentaria": "predicamentar",
    "predicamentariam": "predicamentar",
    "predicamentarias": "predicamentar",
    "predicamentarmo": "predicamentar",
    "predicamentarmos": "predicamentar",
    "predicamentará": "predicamentar",
    "predicamentarás": "predicamentar",
    "predicamentarão": "predicamentar",
    "predicamentaríamos": "predicamentar",
    "predicamentaríeis": "predicamentar",
    "predicamentas": "predicamentar",
    "predicamentasse": "predicamentar",
    "predicamentassem": "predicamentar",
    "predicamentasses": "predicamentar",
    "predicamentaste": "predicamentar",
    "predicamentastes": "predicamentar",
    "predicamentava": "predicamentar",
    "predicamentavam": "predicamentar",
    "predicamentavas": "predicamentar",
    "predicamente": "predicamentar",
    "predicamentei": "predicamentar",
    "predicamenteis": "predicamentar",
    "predicamentem": "predicamentar",
    "predicamentemo": "predicamentar",
    "predicamentemos": "predicamentar",
    "predicamentes": "predicamentar",
    "predicamento": "predicamentar",
    "predicamentos": "predicamento",
    "predicamentou": "predicamentar",
    "predicamentá": "predicamentar",
    "predicamentámo": "predicamentar",
    "predicamentámos": "predicamentar",
    "predicamentáramo": "predicamentar",
    "predicamentáramos": "predicamentar",
    "predicamentárei": "predicamentar",
    "predicamentáreis": "predicamentar",
    "predicamentásseis": "predicamentar",
    "predicamentássemos": "predicamentar",
    "predicamentávamo": "predicamentar",
    "predicamentávamos": "predicamentar",
    "predicamentávei": "predicamentar",
    "predicamentáveis": "predicamentar",
    "predicamo": "predicar",
    "predicamos": "predicar",
    "predicando": "predicar",
    "predicantes": "predicante",
    "predicara": "predicar",
    "predicaram": "predicar",
    "predicaras": "predicar",
    "predicarde": "predicar",
    "predicardes": "predicar",
    "predicare": "predicar",
    "predicarei": "predicar",
    "predicareis": "predicar",
    "predicarem": "predicar",
    "predicaremos": "predicar",
    "predicares": "predicar",
    "predicaria": "predicar",
    "predicariam": "predicar",
    "predicarias": "predicar",
    "predicarmo": "predicar",
    "predicarmos": "predicar",
    "predicará": "predicar",
    "predicarás": "predicar",
    "predicarão": "predicar",
    "predicaríamos": "predicar",
    "predicaríeis": "predicar",
    "predicas": "predicar",
    "predicasse": "predicar",
    "predicassem": "predicar",
    "predicasses": "predicar",
    "predicaste": "predicar",
    "predicastes": "predicar",
    "predicativa": "predicativo",
    "predicativas": "predicativo",
    "predicativos": "predicativo",
    "predicatória": "predicatório",
    "predicatórias": "predicatório",
    "predicatórios": "predicatório",
    "predicava": "predicar",
    "predicavam": "predicar",
    "predicavas": "predicar",
    "predicações": "predicação",
    "predico": "predicar",
    "predicou": "predicar",
    "predicá": "predicar",
    "predicámo": "predicar",
    "predicámos": "predicar",
    "predicáramo": "predicar",
    "predicáramos": "predicar",
    "predicárei": "predicar",
    "predicáreis": "predicar",
    "predicásseis": "predicar",
    "predicássemos": "predicar",
    "predicávamo": "predicar",
    "predicávamos": "predicar",
    "predicávei": "predicar",
    "predicáveis": "predicável",
    "prediga": "predizer",
    "predigais": "predizer",
    "predigam": "predizer",
    "predigamo": "predizer",
    "predigamos": "predizer",
    "predigas": "predizer",
    "predigo": "predizer",
    "predilecta": "predilecto",
    "predilectas": "predilecto",
    "predilectos": "predilecto",
    "predilectíssima": "predilecto",
    "predilectíssimas": "predilecto",
    "predilectíssimo": "predilecto",
    "predilectíssimos": "predilecto",
    "predilecções": "predilecção",
    "prediozinho": "prédio",
    "prediozinhos": "prédio",
    "prediozito": "prédio",
    "prediozitos": "prédio",
    "predique": "predicar",
    "prediquei": "predicar",
    "prediqueis": "predicar",
    "prediquem": "predicar",
    "prediquemo": "predicar",
    "prediquemos": "predicar",
    "prediques": "predicar",
    "predirei": "predizer",
    "predireis": "predizer",
    "prediremos": "predizer",
    "prediria": "predizer",
    "prediriam": "predizer",
    "predirias": "predizer",
    "predirá": "predizer",
    "predirás": "predizer",
    "predirão": "predizer",
    "prediríamos": "predizer",
    "prediríeis": "predizer",
    "predispomo": "predispor",
    "predispomos": "predispor",
    "predisponde": "predispor",
    "predispondes": "predispor",
    "predispondo": "predispor",
    "predisponentes": "predisponente",
    "predisponha": "predispor",
    "predisponhais": "predispor",
    "predisponham": "predispor",
    "predisponhamo": "predispor",
    "predisponhamos": "predispor",
    "predisponhas": "predispor",
    "predisponho": "predispor",
    "predisponíveis": "predisponível",
    "predisporde": "predispor",
    "predispordes": "predispor",
    "predispore": "predispor",
    "predisporei": "predispor",
    "predisporeis": "predispor",
    "predisporem": "predispor",
    "predisporemos": "predispor",
    "predispores": "predispor",
    "predisporia": "predispor",
    "predisporiam": "predispor",
    "predisporias": "predispor",
    "predispormo": "predispor",
    "predispormos": "predispor",
    "predisporá": "predispor",
    "predisporás": "predispor",
    "predisporão": "predispor",
    "predisporíamos": "predispor",
    "predisporíeis": "predispor",
    "predisposições": "predisposição",
    "predisposta": "predisposto",
    "predispostas": "predisposto",
    "predisposto": "predispor",
    "predispostos": "predisposto",
    "predispunha": "predispor",
    "predispunham": "predispor",
    "predispunhas": "predispor",
    "predispus": "predispor",
    "predispusemo": "predispor",
    "predispusemos": "predispor",
    "predispuser": "predispor",
    "predispusera": "predispor",
    "predispuseram": "predispor",
    "predispuseras": "predispor",
    "predispuserdes": "predispor",
    "predispuserem": "predispor",
    "predispuseres": "predispor",
    "predispusermos": "predispor",
    "predispusesse": "predispor",
    "predispusessem": "predispor",
    "predispusesses": "predispor",
    "predispuseste": "predispor",
    "predispusestes": "predispor",
    "predispuséramo": "predispor",
    "predispuséramos": "predispor",
    "predispusérei": "predispor",
    "predispuséreis": "predispor",
    "predispusésseis": "predispor",
    "predispuséssemos": "predispor",
    "predispô": "predispor",
    "predispôs": "predispor",
    "predispõe": "predispor",
    "predispõem": "predispor",
    "predispões": "predispor",
    "predispúnhamo": "predispor",
    "predispúnhamos": "predispor",
    "predispúnhei": "predispor",
    "predispúnheis": "predispor",
    "predisse": "predizer",
    "predissemo": "predizer",
    "predissemos": "predizer",
    "predisser": "predizer",
    "predissera": "predizer",
    "predisseram": "predizer",
    "predisseras": "predizer",
    "predisserdes": "predizer",
    "predisserem": "predizer",
    "predisseres": "predizer",
    "predissermos": "predizer",
    "predissesse": "predizer",
    "predissessem": "predizer",
    "predissesses": "predizer",
    "predisseste": "predizer",
    "predissestes": "predizer",
    "predisséramo": "predizer",
    "predisséramos": "predizer",
    "predissérei": "predizer",
    "predisséreis": "predizer",
    "predissésseis": "predizer",
    "predisséssemos": "predizer",
    "predita": "predizer",
    "preditas": "predizer",
    "preditiva": "preditivo",
    "preditivas": "preditivo",
    "preditivos": "preditivo",
    "predito": "predizer",
    "preditores": "preditor",
    "preditos": "predizer",
    "prediz": "predizer",
    "predize": "predizer",
    "predizei": "predizer",
    "predizeis": "predizer",
    "predizem": "predizer",
    "predizemo": "predizer",
    "predizemos": "predizer",
    "predizendo": "predizer",
    "predizerde": "predizer",
    "predizerdes": "predizer",
    "predizere": "predizer",
    "predizerem": "predizer",
    "predizeres": "predizer",
    "predizermo": "predizer",
    "predizermos": "predizer",
    "predizes": "predizer",
    "predizia": "predizer",
    "prediziam": "predizer",
    "predizias": "predizer",
    "predizê": "predizer",
    "predizíamo": "predizer",
    "predizíamos": "predizer",
    "predizíei": "predizer",
    "predizíeis": "predizer",
    "predizíveis": "predizível",
    "predições": "predição",
    "predomina": "predominar",
    "predominada": "predominar",
    "predominadas": "predominar",
    "predominado": "predominar",
    "predominadora": "predominador",
    "predominadoras": "predominador",
    "predominadores": "predominador",
    "predominados": "predominar",
    "predominai": "predominar",
    "predominais": "predominar",
    "predominam": "predominar",
    "predominamo": "predominar",
    "predominamos": "predominar",
    "predominando": "predominar",
    "predominantes": "predominante",
    "predominara": "predominar",
    "predominaram": "predominar",
    "predominaras": "predominar",
    "predominardes": "predominar",
    "predominarei": "predominar",
    "predominareis": "predominar",
    "predominarem": "predominar",
    "predominaremos": "predominar",
    "predominares": "predominar",
    "predominaria": "predominar",
    "predominariam": "predominar",
    "predominarias": "predominar",
    "predominarmo": "predominar",
    "predominarmos": "predominar",
    "predominará": "predominar",
    "predominarás": "predominar",
    "predominarão": "predominar",
    "predominaríamos": "predominar",
    "predominaríeis": "predominar",
    "predominas": "predominar",
    "predominasse": "predominar",
    "predominassem": "predominar",
    "predominasses": "predominar",
    "predominaste": "predominar",
    "predominastes": "predominar",
    "predominava": "predominar",
    "predominavam": "predominar",
    "predominavas": "predominar",
    "predominações": "predominação",
    "predomine": "predominar",
    "predominei": "predominar",
    "predomineis": "predominar",
    "predominem": "predominar",
    "predominemo": "predominar",
    "predominemos": "predominar",
    "predomines": "predominar",
    "predomino": "predominar",
    "predominou": "predominar",
    "predominámo": "predominar",
    "predominámos": "predominar",
    "predomináramo": "predominar",
    "predomináramos": "predominar",
    "predomináreis": "predominar",
    "predominásseis": "predominar",
    "predominássemos": "predominar",
    "predominávamo": "predominar",
    "predominávamos": "predominar",
    "predomináveis": "predominar",
    "predominâncias": "predominância",
    "predomínios": "predomínio",
    "preei": "prear",
    "preeis": "prear",
    "preeminentes": "preeminente",
    "preeminências": "preeminência",
    "preemo": "prear",
    "preemos": "prear",
    "preempções": "preempção",
    "preencha": "preencher",
    "preenchais": "preencher",
    "preencham": "preencher",
    "preenchamo": "preencher",
    "preenchamos": "preencher",
    "preenchas": "preencher",
    "preenche": "preencher",
    "preenchei": "preencher",
    "preencheis": "preencher",
    "preenchem": "preencher",
    "preenchemo": "preencher",
    "preenchemos": "preencher",
    "preenchendo": "preencher",
    "preenchera": "preencher",
    "preencheram": "preencher",
    "preencheras": "preencher",
    "preencherde": "preencher",
    "preencherdes": "preencher",
    "preenchere": "preencher",
    "preencherei": "preencher",
    "preenchereis": "preencher",
    "preencherem": "preencher",
    "preencheremos": "preencher",
    "preencheres": "preencher",
    "preencheria": "preencher",
    "preencheriam": "preencher",
    "preencherias": "preencher",
    "preenchermo": "preencher",
    "preenchermos": "preencher",
    "preencherá": "preencher",
    "preencherás": "preencher",
    "preencherão": "preencher",
    "preencheríamos": "preencher",
    "preencheríeis": "preencher",
    "preenches": "preencher",
    "preenchesse": "preencher",
    "preenchessem": "preencher",
    "preenchesses": "preencher",
    "preencheste": "preencher",
    "preenchestes": "preencher",
    "preencheu": "preencher",
    "preenchi": "preencher",
    "preenchia": "preencher",
    "preenchiam": "preencher",
    "preenchias": "preencher",
    "preenchida": "preenchido",
    "preenchidas": "preenchido",
    "preenchido": "preencher",
    "preenchidos": "preenchido",
    "preenchimentos": "preenchimento",
    "preencho": "preencher",
    "preenchê": "preencher",
    "preenchêramo": "preencher",
    "preenchêramos": "preencher",
    "preenchêrei": "preencher",
    "preenchêreis": "preencher",
    "preenchêsseis": "preencher",
    "preenchêssemos": "preencher",
    "preenchíamo": "preencher",
    "preenchíamos": "preencher",
    "preenchíei": "preencher",
    "preenchíeis": "preencher",
    "preenchíveis": "preenchível",
    "preensões": "preensão",
    "preestabelece": "preestabelecer",
    "preestabelecei": "preestabelecer",
    "preestabeleceis": "preestabelecer",
    "preestabelecem": "preestabelecer",
    "preestabelecemo": "preestabelecer",
    "preestabelecemos": "preestabelecer",
    "preestabelecendo": "preestabelecer",
    "preestabelecera": "preestabelecer",
    "preestabeleceram": "preestabelecer",
    "preestabeleceras": "preestabelecer",
    "preestabelecerde": "preestabelecer",
    "preestabelecerdes": "preestabelecer",
    "preestabelecere": "preestabelecer",
    "preestabelecerei": "preestabelecer",
    "preestabelecereis": "preestabelecer",
    "preestabelecerem": "preestabelecer",
    "preestabeleceremos": "preestabelecer",
    "preestabeleceres": "preestabelecer",
    "preestabeleceria": "preestabelecer",
    "preestabeleceriam": "preestabelecer",
    "preestabelecerias": "preestabelecer",
    "preestabelecermo": "preestabelecer",
    "preestabelecermos": "preestabelecer",
    "preestabelecerá": "preestabelecer",
    "preestabelecerás": "preestabelecer",
    "preestabelecerão": "preestabelecer",
    "preestabeleceríamos": "preestabelecer",
    "preestabeleceríeis": "preestabelecer",
    "preestabeleces": "preestabelecer",
    "preestabelecesse": "preestabelecer",
    "preestabelecessem": "preestabelecer",
    "preestabelecesses": "preestabelecer",
    "preestabeleceste": "preestabelecer",
    "preestabelecestes": "preestabelecer",
    "preestabeleceu": "preestabelecer",
    "preestabeleci": "preestabelecer",
    "preestabelecia": "preestabelecer",
    "preestabeleciam": "preestabelecer",
    "preestabelecias": "preestabelecer",
    "preestabelecida": "preestabelecido",
    "preestabelecidas": "preestabelecido",
    "preestabelecido": "preestabelecer",
    "preestabelecidos": "preestabelecido",
    "preestabelecê": "preestabelecer",
    "preestabelecêramo": "preestabelecer",
    "preestabelecêramos": "preestabelecer",
    "preestabelecêrei": "preestabelecer",
    "preestabelecêreis": "preestabelecer",
    "preestabelecêsseis": "preestabelecer",
    "preestabelecêssemos": "preestabelecer",
    "preestabelecíamo": "preestabelecer",
    "preestabelecíamos": "preestabelecer",
    "preestabelecíei": "preestabelecer",
    "preestabelecíeis": "preestabelecer",
    "preestabeleça": "preestabelecer",
    "preestabeleçais": "preestabelecer",
    "preestabeleçam": "preestabelecer",
    "preestabeleçamo": "preestabelecer",
    "preestabeleçamos": "preestabelecer",
    "preestabeleças": "preestabelecer",
    "preestabeleço": "preestabelecer",
    "preexcelentes": "preexcelente",
    "preexcelsa": "preexcelso",
    "preexcelsas": "preexcelso",
    "preexcelsos": "preexcelso",
    "preexcelências": "preexcelência",
    "preexista": "preexistir",
    "preexistais": "preexistir",
    "preexistam": "preexistir",
    "preexistamo": "preexistir",
    "preexistamos": "preexistir",
    "preexistas": "preexistir",
    "preexiste": "preexistir",
    "preexistem": "preexistir",
    "preexistencialismos": "preexistencialismo",
    "preexistencialistas": "preexistencialista",
    "preexistentes": "preexistente",
    "preexistes": "preexistir",
    "preexisti": "preexistir",
    "preexistia": "preexistir",
    "preexistiam": "preexistir",
    "preexistias": "preexistir",
    "preexistida": "preexistir",
    "preexistidas": "preexistir",
    "preexistido": "preexistir",
    "preexistidos": "preexistir",
    "preexistimo": "preexistir",
    "preexistimos": "preexistir",
    "preexistindo": "preexistir",
    "preexistira": "preexistir",
    "preexistiram": "preexistir",
    "preexistiras": "preexistir",
    "preexistirde": "preexistir",
    "preexistirdes": "preexistir",
    "preexistire": "preexistir",
    "preexistirei": "preexistir",
    "preexistireis": "preexistir",
    "preexistirem": "preexistir",
    "preexistiremos": "preexistir",
    "preexistires": "preexistir",
    "preexistiria": "preexistir",
    "preexistiriam": "preexistir",
    "preexistirias": "preexistir",
    "preexistirmo": "preexistir",
    "preexistirmos": "preexistir",
    "preexistirá": "preexistir",
    "preexistirás": "preexistir",
    "preexistirão": "preexistir",
    "preexistiríamos": "preexistir",
    "preexistiríeis": "preexistir",
    "preexistis": "preexistir",
    "preexistisse": "preexistir",
    "preexistissem": "preexistir",
    "preexistisses": "preexistir",
    "preexististe": "preexistir",
    "preexististes": "preexistir",
    "preexistiu": "preexistir",
    "preexisto": "preexistir",
    "preexistências": "preexistência",
    "preexistíamo": "preexistir",
    "preexistíamos": "preexistir",
    "preexistíei": "preexistir",
    "preexistíeis": "preexistir",
    "preexistíramo": "preexistir",
    "preexistíramos": "preexistir",
    "preexistírei": "preexistir",
    "preexistíreis": "preexistir",
    "preexistísseis": "preexistir",
    "preexistíssemos": "preexistir",
    "prefabricada": "prefabricado",
    "prefabricadas": "prefabricado",
    "prefabricados": "prefabricado",
    "prefacia": "prefaciar",
    "prefaciada": "prefaciar",
    "prefaciadas": "prefaciar",
    "prefaciado": "prefaciar",
    "prefaciadora": "prefaciador",
    "prefaciadoras": "prefaciador",
    "prefaciadores": "prefaciador",
    "prefaciados": "prefaciar",
    "prefaciai": "prefaciar",
    "prefaciais": "prefaciar",
    "prefaciam": "prefaciar",
    "prefaciamo": "prefaciar",
    "prefaciamos": "prefaciar",
    "prefaciando": "prefaciar",
    "prefaciara": "prefaciar",
    "prefaciaram": "prefaciar",
    "prefaciaras": "prefaciar",
    "prefaciarde": "prefaciar",
    "prefaciardes": "prefaciar",
    "prefaciare": "prefaciar",
    "prefaciarei": "prefaciar",
    "prefaciareis": "prefaciar",
    "prefaciarem": "prefaciar",
    "prefaciaremos": "prefaciar",
    "prefaciares": "prefaciar",
    "prefaciaria": "prefaciar",
    "prefaciariam": "prefaciar",
    "prefaciarias": "prefaciar",
    "prefaciarmo": "prefaciar",
    "prefaciarmos": "prefaciar",
    "prefaciará": "prefaciar",
    "prefaciarás": "prefaciar",
    "prefaciarão": "prefaciar",
    "prefaciaríamos": "prefaciar",
    "prefaciaríeis": "prefaciar",
    "prefacias": "prefaciar",
    "prefaciasse": "prefaciar",
    "prefaciassem": "prefaciar",
    "prefaciasses": "prefaciar",
    "prefaciaste": "prefaciar",
    "prefaciastes": "prefaciar",
    "prefaciava": "prefaciar",
    "prefaciavam": "prefaciar",
    "prefaciavas": "prefaciar",
    "prefacie": "prefaciar",
    "prefaciei": "prefaciar",
    "prefacieis": "prefaciar",
    "prefaciem": "prefaciar",
    "prefaciemo": "prefaciar",
    "prefaciemos": "prefaciar",
    "prefacies": "prefaciar",
    "prefacio": "prefaciar",
    "prefaciou": "prefaciar",
    "prefaciá": "prefaciar",
    "prefaciámo": "prefaciar",
    "prefaciámos": "prefaciar",
    "prefaciáramo": "prefaciar",
    "prefaciáramos": "prefaciar",
    "prefaciárei": "prefaciar",
    "prefaciáreis": "prefaciar",
    "prefaciásseis": "prefaciar",
    "prefaciássemos": "prefaciar",
    "prefaciávamo": "prefaciar",
    "prefaciávamos": "prefaciar",
    "prefaciávei": "prefaciar",
    "prefaciáveis": "prefaciar",
    "prefações": "prefação",
    "prefeita": "prefeito",
    "prefeitas": "prefeito",
    "prefeitorais": "prefeitoral",
    "prefeitos": "prefeito",
    "prefeituras": "prefeitura",
    "prefere": "preferir",
    "preferem": "preferir",
    "preferenciais": "preferencial",
    "preferentes": "preferente",
    "preferes": "preferir",
    "preferi": "preferir",
    "preferia": "preferir",
    "preferiam": "preferir",
    "preferias": "preferir",
    "preferida": "preferir",
    "preferidas": "preferir",
    "preferido": "preferir",
    "preferidos": "preferir",
    "preferimo": "preferir",
    "preferimos": "preferir",
    "preferindo": "preferir",
    "preferira": "preferir",
    "preferiram": "preferir",
    "preferiras": "preferir",
    "preferirde": "preferir",
    "preferirdes": "preferir",
    "preferire": "preferir",
    "preferirei": "preferir",
    "preferireis": "preferir",
    "preferirem": "preferir",
    "preferiremos": "preferir",
    "preferires": "preferir",
    "preferiria": "preferir",
    "prefeririam": "preferir",
    "preferirias": "preferir",
    "preferirmo": "preferir",
    "preferirmos": "preferir",
    "preferirá": "preferir",
    "preferirás": "preferir",
    "preferirão": "preferir",
    "preferiríamos": "preferir",
    "preferiríeis": "preferir",
    "preferis": "preferir",
    "preferisse": "preferir",
    "preferissem": "preferir",
    "preferisses": "preferir",
    "preferiste": "preferir",
    "preferistes": "preferir",
    "preferiu": "preferir",
    "preferências": "preferência",
    "preferíamo": "preferir",
    "preferíamos": "preferir",
    "preferíei": "preferir",
    "preferíeis": "preferir",
    "preferíramo": "preferir",
    "preferíramos": "preferir",
    "preferírei": "preferir",
    "preferíreis": "preferir",
    "preferísseis": "preferir",
    "preferíssemos": "preferir",
    "preferíveis": "preferível",
    "prefigura": "prefigurar",
    "prefigurada": "prefigurar",
    "prefiguradas": "prefigurar",
    "prefigurado": "prefigurar",
    "prefigurados": "prefigurar",
    "prefigurai": "prefigurar",
    "prefigurais": "prefigurar",
    "prefiguram": "prefigurar",
    "prefiguramo": "prefigurar",
    "prefiguramos": "prefigurar",
    "prefigurando": "prefigurar",
    "prefigurara": "prefigurar",
    "prefiguraram": "prefigurar",
    "prefiguraras": "prefigurar",
    "prefigurarde": "prefigurar",
    "prefigurardes": "prefigurar",
    "prefigurare": "prefigurar",
    "prefigurarei": "prefigurar",
    "prefigurareis": "prefigurar",
    "prefigurarem": "prefigurar",
    "prefiguraremos": "prefigurar",
    "prefigurares": "prefigurar",
    "prefiguraria": "prefigurar",
    "prefigurariam": "prefigurar",
    "prefigurarias": "prefigurar",
    "prefigurarmo": "prefigurar",
    "prefigurarmos": "prefigurar",
    "prefigurará": "prefigurar",
    "prefigurarás": "prefigurar",
    "prefigurarão": "prefigurar",
    "prefiguraríamos": "prefigurar",
    "prefiguraríeis": "prefigurar",
    "prefiguras": "prefigurar",
    "prefigurasse": "prefigurar",
    "prefigurassem": "prefigurar",
    "prefigurasses": "prefigurar",
    "prefiguraste": "prefigurar",
    "prefigurastes": "prefigurar",
    "prefigurava": "prefigurar",
    "prefiguravam": "prefigurar",
    "prefiguravas": "prefigurar",
    "prefigurações": "prefiguração",
    "prefigure": "prefigurar",
    "prefigurei": "prefigurar",
    "prefigureis": "prefigurar",
    "prefigurem": "prefigurar",
    "prefiguremo": "prefigurar",
    "prefiguremos": "prefigurar",
    "prefigures": "prefigurar",
    "prefiguro": "prefigurar",
    "prefigurou": "prefigurar",
    "prefigurá": "prefigurar",
    "prefigurámo": "prefigurar",
    "prefigurámos": "prefigurar",
    "prefiguráramo": "prefigurar",
    "prefiguráramos": "prefigurar",
    "prefigurárei": "prefigurar",
    "prefiguráreis": "prefigurar",
    "prefigurásseis": "prefigurar",
    "prefigurássemos": "prefigurar",
    "prefigurávamo": "prefigurar",
    "prefigurávamos": "prefigurar",
    "prefigurávei": "prefigurar",
    "prefiguráveis": "prefigurar",
    "prefina": "prefinir",
    "prefinais": "prefinir",
    "prefinam": "prefinir",
    "prefinamo": "prefinir",
    "prefinamos": "prefinir",
    "prefinas": "prefinir",
    "prefine": "prefinir",
    "prefinem": "prefinir",
    "prefines": "prefinir",
    "prefini": "prefinir",
    "prefinia": "prefinir",
    "prefiniam": "prefinir",
    "prefinias": "prefinir",
    "prefinida": "prefinir",
    "prefinidas": "prefinir",
    "prefinido": "prefinir",
    "prefinidos": "prefinir",
    "prefinimo": "prefinir",
    "prefinimos": "prefinir",
    "prefinindo": "prefinir",
    "prefinira": "prefinir",
    "prefiniram": "prefinir",
    "prefiniras": "prefinir",
    "prefinirde": "prefinir",
    "prefinirdes": "prefinir",
    "prefinire": "prefinir",
    "prefinirei": "prefinir",
    "prefinireis": "prefinir",
    "prefinirem": "prefinir",
    "prefiniremos": "prefinir",
    "prefinires": "prefinir",
    "prefiniria": "prefinir",
    "prefiniriam": "prefinir",
    "prefinirias": "prefinir",
    "prefinirmo": "prefinir",
    "prefinirmos": "prefinir",
    "prefinirá": "prefinir",
    "prefinirás": "prefinir",
    "prefinirão": "prefinir",
    "prefiniríamos": "prefinir",
    "prefiniríeis": "prefinir",
    "prefinis": "prefinir",
    "prefinisse": "prefinir",
    "prefinissem": "prefinir",
    "prefinisses": "prefinir",
    "prefiniste": "prefinir",
    "prefinistes": "prefinir",
    "prefiniu": "prefinir",
    "prefino": "prefinir",
    "prefiníamo": "prefinir",
    "prefiníamos": "prefinir",
    "prefiníei": "prefinir",
    "prefiníeis": "prefinir",
    "prefiníramo": "prefinir",
    "prefiníramos": "prefinir",
    "prefinírei": "prefinir",
    "prefiníreis": "prefinir",
    "prefinísseis": "prefinir",
    "prefiníssemos": "prefinir",
    "prefira": "preferir",
    "prefirais": "preferir",
    "prefiram": "preferir",
    "prefiramo": "preferir",
    "prefiramos": "preferir",
    "prefiras": "preferir",
    "prefiro": "preferir",
    "prefixa": "prefixo",
    "prefixada": "prefixar",
    "prefixadas": "prefixar",
    "prefixado": "prefixar",
    "prefixados": "prefixar",
    "prefixai": "prefixar",
    "prefixais": "prefixar",
    "prefixam": "prefixar",
    "prefixamo": "prefixar",
    "prefixamos": "prefixar",
    "prefixando": "prefixar",
    "prefixara": "prefixar",
    "prefixaram": "prefixar",
    "prefixaras": "prefixar",
    "prefixarde": "prefixar",
    "prefixardes": "prefixar",
    "prefixare": "prefixar",
    "prefixarei": "prefixar",
    "prefixareis": "prefixar",
    "prefixarem": "prefixar",
    "prefixaremos": "prefixar",
    "prefixares": "prefixar",
    "prefixaria": "prefixar",
    "prefixariam": "prefixar",
    "prefixarias": "prefixar",
    "prefixarmo": "prefixar",
    "prefixarmos": "prefixar",
    "prefixará": "prefixar",
    "prefixarás": "prefixar",
    "prefixarão": "prefixar",
    "prefixaríamos": "prefixar",
    "prefixaríeis": "prefixar",
    "prefixas": "prefixo",
    "prefixasse": "prefixar",
    "prefixassem": "prefixar",
    "prefixasses": "prefixar",
    "prefixaste": "prefixar",
    "prefixastes": "prefixar",
    "prefixativa": "prefixativo",
    "prefixativas": "prefixativo",
    "prefixativos": "prefixativo",
    "prefixava": "prefixar",
    "prefixavam": "prefixar",
    "prefixavas": "prefixar",
    "prefixações": "prefixação",
    "prefixe": "prefixar",
    "prefixei": "prefixar",
    "prefixeis": "prefixar",
    "prefixem": "prefixar",
    "prefixemo": "prefixar",
    "prefixemos": "prefixar",
    "prefixes": "prefixar",
    "prefixo": "prefixar",
    "prefixos": "prefixo",
    "prefixou": "prefixar",
    "prefixá": "prefixar",
    "prefixámo": "prefixar",
    "prefixámos": "prefixar",
    "prefixáramo": "prefixar",
    "prefixáramos": "prefixar",
    "prefixárei": "prefixar",
    "prefixáreis": "prefixar",
    "prefixásseis": "prefixar",
    "prefixássemos": "prefixar",
    "prefixávamo": "prefixar",
    "prefixávamos": "prefixar",
    "prefixávei": "prefixar",
    "prefixáveis": "prefixável",
    "preflorações": "prefloração",
    "preflorescentes": "preflorescente",
    "preflorescências": "preflorescência",
    "prefoliada": "prefoliado",
    "prefoliadas": "prefoliado",
    "prefoliados": "prefoliado",
    "prefoliações": "prefoliação",
    "preformações": "preformação",
    "prefulge": "prefulgir",
    "prefulgem": "prefulgir",
    "prefulgentes": "prefulgente",
    "prefulges": "prefulgir",
    "prefulgi": "prefulgir",
    "prefulgia": "prefulgir",
    "prefulgiam": "prefulgir",
    "prefulgias": "prefulgir",
    "prefulgida": "prefulgir",
    "prefulgidas": "prefulgir",
    "prefulgido": "prefulgir",
    "prefulgidos": "prefulgir",
    "prefulgimo": "prefulgir",
    "prefulgimos": "prefulgir",
    "prefulgindo": "prefulgir",
    "prefulgira": "prefulgir",
    "prefulgiram": "prefulgir",
    "prefulgiras": "prefulgir",
    "prefulgirde": "prefulgir",
    "prefulgirdes": "prefulgir",
    "prefulgire": "prefulgir",
    "prefulgirei": "prefulgir",
    "prefulgireis": "prefulgir",
    "prefulgirem": "prefulgir",
    "prefulgiremos": "prefulgir",
    "prefulgires": "prefulgir",
    "prefulgiria": "prefulgir",
    "prefulgiriam": "prefulgir",
    "prefulgirias": "prefulgir",
    "prefulgirmo": "prefulgir",
    "prefulgirmos": "prefulgir",
    "prefulgirá": "prefulgir",
    "prefulgirás": "prefulgir",
    "prefulgirão": "prefulgir",
    "prefulgiríamos": "prefulgir",
    "prefulgiríeis": "prefulgir",
    "prefulgis": "prefulgir",
    "prefulgisse": "prefulgir",
    "prefulgissem": "prefulgir",
    "prefulgisses": "prefulgir",
    "prefulgiste": "prefulgir",
    "prefulgistes": "prefulgir",
    "prefulgiu": "prefulgir",
    "prefulgura": "prefulgurar",
    "prefulgurada": "prefulgurar",
    "prefulguradas": "prefulgurar",
    "prefulgurado": "prefulgurar",
    "prefulgurados": "prefulgurar",
    "prefulgurai": "prefulgurar",
    "prefulgurais": "prefulgurar",
    "prefulguram": "prefulgurar",
    "prefulguramo": "prefulgurar",
    "prefulguramos": "prefulgurar",
    "prefulgurando": "prefulgurar",
    "prefulgurara": "prefulgurar",
    "prefulguraram": "prefulgurar",
    "prefulguraras": "prefulgurar",
    "prefulgurardes": "prefulgurar",
    "prefulgurarei": "prefulgurar",
    "prefulgurareis": "prefulgurar",
    "prefulgurarem": "prefulgurar",
    "prefulguraremos": "prefulgurar",
    "prefulgurares": "prefulgurar",
    "prefulguraria": "prefulgurar",
    "prefulgurariam": "prefulgurar",
    "prefulgurarias": "prefulgurar",
    "prefulgurarmo": "prefulgurar",
    "prefulgurarmos": "prefulgurar",
    "prefulgurará": "prefulgurar",
    "prefulgurarás": "prefulgurar",
    "prefulgurarão": "prefulgurar",
    "prefulguraríamos": "prefulgurar",
    "prefulguraríeis": "prefulgurar",
    "prefulguras": "prefulgurar",
    "prefulgurasse": "prefulgurar",
    "prefulgurassem": "prefulgurar",
    "prefulgurasses": "prefulgurar",
    "prefulguraste": "prefulgurar",
    "prefulgurastes": "prefulgurar",
    "prefulgurava": "prefulgurar",
    "prefulguravam": "prefulgurar",
    "prefulguravas": "prefulgurar",
    "prefulgurações": "prefulguração",
    "prefulgure": "prefulgurar",
    "prefulgurei": "prefulgurar",
    "prefulgureis": "prefulgurar",
    "prefulgurem": "prefulgurar",
    "prefulguremo": "prefulgurar",
    "prefulguremos": "prefulgurar",
    "prefulgures": "prefulgurar",
    "prefulguro": "prefulgurar",
    "prefulgurou": "prefulgurar",
    "prefulgurámo": "prefulgurar",
    "prefulgurámos": "prefulgurar",
    "prefulguráramo": "prefulgurar",
    "prefulguráramos": "prefulgurar",
    "prefulguráreis": "prefulgurar",
    "prefulgurásseis": "prefulgurar",
    "prefulgurássemos": "prefulgurar",
    "prefulgurávamo": "prefulgurar",
    "prefulgurávamos": "prefulgurar",
    "prefulguráveis": "prefulgurar",
    "prefulgências": "prefulgência",
    "prefulgíamo": "prefulgir",
    "prefulgíamos": "prefulgir",
    "prefulgíei": "prefulgir",
    "prefulgíeis": "prefulgir",
    "prefulgíramo": "prefulgir",
    "prefulgíramos": "prefulgir",
    "prefulgírei": "prefulgir",
    "prefulgíreis": "prefulgir",
    "prefulgísseis": "prefulgir",
    "prefulgíssemos": "prefulgir",
    "prefulja": "prefulgir",
    "prefuljais": "prefulgir",
    "prefuljam": "prefulgir",
    "prefuljamo": "prefulgir",
    "prefuljamos": "prefulgir",
    "prefuljas": "prefulgir",
    "prefuljo": "prefulgir",
    "prefácios": "prefácio",
    "prega": "pregar",
    "pregada": "pregar",
    "pregadas": "pregar",
    "pregadeiras": "pregadeira",
    "pregado": "pregar",
    "pregadora": "pregador",
    "pregadoras": "pregador",
    "pregadores": "pregador",
    "pregados": "pregar",
    "pregaduras": "pregadura",
    "pregagens": "pregagem",
    "pregai": "pregar",
    "pregais": "pregar",
    "pregalhos": "pregalho",
    "pregam": "pregar",
    "pregamentos": "pregamento",
    "pregamo": "pregar",
    "pregamos": "pregar",
    "pregando": "pregar",
    "pregara": "pregar",
    "pregaram": "pregar",
    "pregaras": "pregar",
    "pregarde": "pregar",
    "pregardes": "pregar",
    "pregare": "pregar",
    "pregarei": "pregar",
    "pregareis": "pregar",
    "pregarem": "pregar",
    "pregaremos": "pregar",
    "pregares": "pregar",
    "pregaria": "pregar",
    "pregariam": "pregar",
    "pregarias": "pregaria",
    "pregarmo": "pregar",
    "pregarmos": "pregar",
    "pregará": "pregar",
    "pregarás": "pregar",
    "pregarão": "pregar",
    "pregaríamos": "pregar",
    "pregaríeis": "pregar",
    "pregas": "pregar",
    "pregasse": "pregar",
    "pregassem": "pregar",
    "pregasses": "pregar",
    "pregaste": "pregar",
    "pregastes": "pregar",
    "pregava": "pregar",
    "pregavam": "pregar",
    "pregavas": "pregar",
    "pregações": "pregação",
    "pregnâncias": "pregnância",
    "prego": "pregar",
    "pregoa": "pregoar",
    "pregoada": "pregoar",
    "pregoadas": "pregoar",
    "pregoado": "pregoar",
    "pregoados": "pregoar",
    "pregoai": "pregoar",
    "pregoais": "pregoar",
    "pregoam": "pregoar",
    "pregoamo": "pregoar",
    "pregoamos": "pregoar",
    "pregoando": "pregoar",
    "pregoara": "pregoar",
    "pregoaram": "pregoar",
    "pregoaras": "pregoar",
    "pregoarde": "pregoar",
    "pregoardes": "pregoar",
    "pregoare": "pregoar",
    "pregoarei": "pregoar",
    "pregoareis": "pregoar",
    "pregoarem": "pregoar",
    "pregoaremos": "pregoar",
    "pregoares": "pregoar",
    "pregoaria": "pregoar",
    "pregoariam": "pregoar",
    "pregoarias": "pregoar",
    "pregoarmo": "pregoar",
    "pregoarmos": "pregoar",
    "pregoará": "pregoar",
    "pregoarás": "pregoar",
    "pregoarão": "pregoar",
    "pregoaríamos": "pregoar",
    "pregoaríeis": "pregoar",
    "pregoas": "pregoar",
    "pregoasse": "pregoar",
    "pregoassem": "pregoar",
    "pregoasses": "pregoar",
    "pregoaste": "pregoar",
    "pregoastes": "pregoar",
    "pregoava": "pregoar",
    "pregoavam": "pregoar",
    "pregoavas": "pregoar",
    "pregoe": "pregoar",
    "pregoei": "pregoar",
    "pregoeira": "pregoeiro",
    "pregoeiras": "pregoeiro",
    "pregoeiros": "pregoeiro",
    "pregoeis": "pregoar",
    "pregoem": "pregoar",
    "pregoemo": "pregoar",
    "pregoemos": "pregoar",
    "pregoes": "pregoar",
    "pregoo": "pregoar",
    "pregoou": "pregoar",
    "pregos": "prego",
    "pregou": "pregar",
    "pregoá": "pregoar",
    "pregoámo": "pregoar",
    "pregoámos": "pregoar",
    "pregoáramo": "pregoar",
    "pregoáramos": "pregoar",
    "pregoárei": "pregoar",
    "pregoáreis": "pregoar",
    "pregoásseis": "pregoar",
    "pregoássemos": "pregoar",
    "pregoávamo": "pregoar",
    "pregoávamos": "pregoar",
    "pregoávei": "pregoar",
    "pregoáveis": "pregoar",
    "pregressa": "pregresso",
    "pregressas": "pregresso",
    "pregressos": "pregresso",
    "pregue": "pregar",
    "pregueada": "preguear",
    "pregueadas": "preguear",
    "pregueadeira": "pregueador",
    "pregueadeiras": "pregueador",
    "pregueado": "preguear",
    "pregueadora": "pregueador",
    "pregueadoras": "pregueador",
    "pregueadores": "pregueador",
    "pregueados": "preguear",
    "pregueai": "preguear",
    "pregueais": "preguear",
    "pregueamo": "preguear",
    "pregueamos": "preguear",
    "pregueando": "preguear",
    "pregueara": "preguear",
    "preguearam": "preguear",
    "preguearas": "preguear",
    "preguearde": "preguear",
    "pregueardes": "preguear",
    "pregueare": "preguear",
    "preguearei": "preguear",
    "pregueareis": "preguear",
    "preguearem": "preguear",
    "preguearemos": "preguear",
    "pregueares": "preguear",
    "preguearia": "preguear",
    "pregueariam": "preguear",
    "preguearias": "preguear",
    "preguearmo": "preguear",
    "preguearmos": "preguear",
    "pregueará": "preguear",
    "preguearás": "preguear",
    "preguearão": "preguear",
    "preguearíamos": "preguear",
    "preguearíeis": "preguear",
    "pregueasse": "preguear",
    "pregueassem": "preguear",
    "pregueasses": "preguear",
    "pregueaste": "preguear",
    "pregueastes": "preguear",
    "pregueava": "preguear",
    "pregueavam": "preguear",
    "pregueavas": "preguear",
    "pregueei": "preguear",
    "pregueeis": "preguear",
    "pregueemo": "preguear",
    "pregueemos": "preguear",
    "preguei": "pregar",
    "pregueia": "preguear",
    "pregueiam": "preguear",
    "pregueias": "preguear",
    "pregueie": "preguear",
    "pregueiem": "preguear",
    "pregueies": "preguear",
    "pregueio": "preguear",
    "pregueira": "pregueiro",
    "pregueiras": "pregueiro",
    "pregueiros": "pregueiro",
    "pregueis": "pregar",
    "preguem": "pregar",
    "preguemo": "pregar",
    "preguemos": "pregar",
    "pregueou": "preguear",
    "pregues": "pregar",
    "pregueá": "preguear",
    "pregueámo": "preguear",
    "pregueámos": "preguear",
    "pregueáramo": "preguear",
    "pregueáramos": "preguear",
    "pregueárei": "preguear",
    "pregueáreis": "preguear",
    "pregueásseis": "preguear",
    "pregueássemos": "preguear",
    "pregueávamo": "preguear",
    "pregueávamos": "preguear",
    "pregueávei": "preguear",
    "pregueáveis": "preguear",
    "preguice": "preguiçar",
    "preguicei": "preguiçar",
    "preguiceira": "preguiceiro",
    "preguiceiras": "preguiceiro",
    "preguiceiros": "preguiceiro",
    "preguiceis": "preguiçar",
    "preguicem": "preguiçar",
    "preguicemo": "preguiçar",
    "preguicemos": "preguiçar",
    "preguicenta": "preguicento",
    "preguicentas": "preguicento",
    "preguicentos": "preguicento",
    "preguices": "preguiçar",
    "preguistas": "preguista",
    "preguiça": "preguiçar",
    "preguiçada": "preguiçar",
    "preguiçadas": "preguiçar",
    "preguiçado": "preguiçar",
    "preguiçados": "preguiçar",
    "preguiçai": "preguiçar",
    "preguiçais": "preguiçar",
    "preguiçam": "preguiçar",
    "preguiçamo": "preguiçar",
    "preguiçamos": "preguiçar",
    "preguiçando": "preguiçar",
    "preguiçara": "preguiçar",
    "preguiçaram": "preguiçar",
    "preguiçaras": "preguiçar",
    "preguiçardes": "preguiçar",
    "preguiçarei": "preguiçar",
    "preguiçareis": "preguiçar",
    "preguiçarem": "preguiçar",
    "preguiçaremos": "preguiçar",
    "preguiçares": "preguiçar",
    "preguiçaria": "preguiçar",
    "preguiçariam": "preguiçar",
    "preguiçarias": "preguiçar",
    "preguiçarmo": "preguiçar",
    "preguiçarmos": "preguiçar",
    "preguiçará": "preguiçar",
    "preguiçarás": "preguiçar",
    "preguiçarão": "preguiçar",
    "preguiçaríamos": "preguiçar",
    "preguiçaríeis": "preguiçar",
    "preguiças": "preguiçar",
    "preguiçasse": "preguiçar",
    "preguiçassem": "preguiçar",
    "preguiçasses": "preguiçar",
    "preguiçaste": "preguiçar",
    "preguiçastes": "preguiçar",
    "preguiçava": "preguiçar",
    "preguiçavam": "preguiçar",
    "preguiçavas": "preguiçar",
    "preguiço": "preguiçar",
    "preguiçosa": "preguiçoso",
    "preguiçosas": "preguiçoso",
    "preguiçosos": "preguiçoso",
    "preguiçou": "preguiçar",
    "preguiçámo": "preguiçar",
    "preguiçámos": "preguiçar",
    "preguiçáramo": "preguiçar",
    "preguiçáramos": "preguiçar",
    "preguiçáreis": "preguiçar",
    "preguiçásseis": "preguiçar",
    "preguiçássemos": "preguiçar",
    "preguiçávamo": "preguiçar",
    "preguiçávamos": "preguiçar",
    "preguiçáveis": "preguiçar",
    "pregusta": "pregustar",
    "pregustada": "pregustar",
    "pregustadas": "pregustar",
    "pregustado": "pregustar",
    "pregustados": "pregustar",
    "pregustai": "pregustar",
    "pregustais": "pregustar",
    "pregustam": "pregustar",
    "pregustamo": "pregustar",
    "pregustamos": "pregustar",
    "pregustando": "pregustar",
    "pregustara": "pregustar",
    "pregustaram": "pregustar",
    "pregustaras": "pregustar",
    "pregustarde": "pregustar",
    "pregustardes": "pregustar",
    "pregustare": "pregustar",
    "pregustarei": "pregustar",
    "pregustareis": "pregustar",
    "pregustarem": "pregustar",
    "pregustaremos": "pregustar",
    "pregustares": "pregustar",
    "pregustaria": "pregustar",
    "pregustariam": "pregustar",
    "pregustarias": "pregustar",
    "pregustarmo": "pregustar",
    "pregustarmos": "pregustar",
    "pregustará": "pregustar",
    "pregustarás": "pregustar",
    "pregustarão": "pregustar",
    "pregustaríamos": "pregustar",
    "pregustaríeis": "pregustar",
    "pregustas": "pregustar",
    "pregustasse": "pregustar",
    "pregustassem": "pregustar",
    "pregustasses": "pregustar",
    "pregustaste": "pregustar",
    "pregustastes": "pregustar",
    "pregustava": "pregustar",
    "pregustavam": "pregustar",
    "pregustavas": "pregustar",
    "pregustações": "pregustação",
    "preguste": "pregustar",
    "pregustei": "pregustar",
    "pregusteis": "pregustar",
    "pregustem": "pregustar",
    "pregustemo": "pregustar",
    "pregustemos": "pregustar",
    "pregustes": "pregustar",
    "pregusto": "pregustar",
    "pregustou": "pregustar",
    "pregustá": "pregustar",
    "pregustámo": "pregustar",
    "pregustámos": "pregustar",
    "pregustáramo": "pregustar",
    "pregustáramos": "pregustar",
    "pregustárei": "pregustar",
    "pregustáreis": "pregustar",
    "pregustásseis": "pregustar",
    "pregustássemos": "pregustar",
    "pregustávamo": "pregustar",
    "pregustávamos": "pregustar",
    "pregustávei": "pregustar",
    "pregustáveis": "pregustar",
    "pregá": "pregar",
    "pregámo": "pregar",
    "pregámos": "pregar",
    "pregáramo": "pregar",
    "pregáramos": "pregar",
    "pregárei": "pregar",
    "pregáreis": "pregar",
    "pregásseis": "pregar",
    "pregássemos": "pregar",
    "pregávamo": "pregar",
    "pregávamos": "pregar",
    "pregávei": "pregar",
    "pregáveis": "pregar",
    "pregões": "pregão",
    "preia": "prear",
    "preiam": "prear",
    "preias": "preia",
    "preie": "prear",
    "preiem": "prear",
    "preies": "prear",
    "preio": "prear",
    "preiteada": "preitear",
    "preiteadas": "preitear",
    "preiteado": "preitear",
    "preiteados": "preitear",
    "preiteai": "preitear",
    "preiteais": "preitear",
    "preiteamo": "preitear",
    "preiteamos": "preitear",
    "preiteando": "preitear",
    "preiteara": "preitear",
    "preitearam": "preitear",
    "preitearas": "preitear",
    "preitearde": "preitear",
    "preiteardes": "preitear",
    "preiteare": "preitear",
    "preitearei": "preitear",
    "preiteareis": "preitear",
    "preitearem": "preitear",
    "preitearemos": "preitear",
    "preiteares": "preitear",
    "preitearia": "preitear",
    "preiteariam": "preitear",
    "preitearias": "preitear",
    "preitearmo": "preitear",
    "preitearmos": "preitear",
    "preiteará": "preitear",
    "preitearás": "preitear",
    "preitearão": "preitear",
    "preitearíamos": "preitear",
    "preitearíeis": "preitear",
    "preiteasse": "preitear",
    "preiteassem": "preitear",
    "preiteasses": "preitear",
    "preiteaste": "preitear",
    "preiteastes": "preitear",
    "preiteava": "preitear",
    "preiteavam": "preitear",
    "preiteavas": "preitear",
    "preiteei": "preitear",
    "preiteeis": "preitear",
    "preiteemo": "preitear",
    "preiteemos": "preitear",
    "preiteia": "preitear",
    "preiteiam": "preitear",
    "preiteias": "preitear",
    "preiteie": "preitear",
    "preiteiem": "preitear",
    "preiteies": "preitear",
    "preiteio": "preitear",
    "preiteja": "preitejar",
    "preitejada": "preitejar",
    "preitejadas": "preitejar",
    "preitejado": "preitejar",
    "preitejados": "preitejar",
    "preitejai": "preitejar",
    "preitejais": "preitejar",
    "preitejam": "preitejar",
    "preitejamo": "preitejar",
    "preitejamos": "preitejar",
    "preitejando": "preitejar",
    "preitejara": "preitejar",
    "preitejaram": "preitejar",
    "preitejaras": "preitejar",
    "preitejarde": "preitejar",
    "preitejardes": "preitejar",
    "preitejare": "preitejar",
    "preitejarei": "preitejar",
    "preitejareis": "preitejar",
    "preitejarem": "preitejar",
    "preitejaremos": "preitejar",
    "preitejares": "preitejar",
    "preitejaria": "preitejar",
    "preitejariam": "preitejar",
    "preitejarias": "preitejar",
    "preitejarmo": "preitejar",
    "preitejarmos": "preitejar",
    "preitejará": "preitejar",
    "preitejarás": "preitejar",
    "preitejarão": "preitejar",
    "preitejaríamos": "preitejar",
    "preitejaríeis": "preitejar",
    "preitejas": "preitejar",
    "preitejasse": "preitejar",
    "preitejassem": "preitejar",
    "preitejasses": "preitejar",
    "preitejaste": "preitejar",
    "preitejastes": "preitejar",
    "preitejava": "preitejar",
    "preitejavam": "preitejar",
    "preitejavas": "preitejar",
    "preiteje": "preitejar",
    "preitejei": "preitejar",
    "preitejeis": "preitejar",
    "preitejem": "preitejar",
    "preitejemo": "preitejar",
    "preitejemos": "preitejar",
    "preitejes": "preitejar",
    "preitejo": "preitejar",
    "preitejou": "preitejar",
    "preitejá": "preitejar",
    "preitejámo": "preitejar",
    "preitejámos": "preitejar",
    "preitejáramo": "preitejar",
    "preitejáramos": "preitejar",
    "preitejárei": "preitejar",
    "preitejáreis": "preitejar",
    "preitejásseis": "preitejar",
    "preitejássemos": "preitejar",
    "preitejávamo": "preitejar",
    "preitejávamos": "preitejar",
    "preitejávei": "preitejar",
    "preitejáveis": "preitejar",
    "preiteou": "preitear",
    "preiteá": "preitear",
    "preiteámo": "preitear",
    "preiteámos": "preitear",
    "preiteáramo": "preitear",
    "preiteáramos": "preitear",
    "preiteárei": "preitear",
    "preiteáreis": "preitear",
    "preiteásseis": "preitear",
    "preiteássemos": "preitear",
    "preiteávamo": "preitear",
    "preiteávamos": "preitear",
    "preiteávei": "preitear",
    "preiteáveis": "preitear",
    "preitos": "preito",
    "prejudica": "prejudicar",
    "prejudicada": "prejudicar",
    "prejudicadas": "prejudicar",
    "prejudicado": "prejudicar",
    "prejudicadora": "prejudicador",
    "prejudicadoras": "prejudicador",
    "prejudicadores": "prejudicador",
    "prejudicados": "prejudicar",
    "prejudicai": "prejudicar",
    "prejudicais": "prejudicar",
    "prejudicam": "prejudicar",
    "prejudicamo": "prejudicar",
    "prejudicamos": "prejudicar",
    "prejudicando": "prejudicar",
    "prejudicara": "prejudicar",
    "prejudicaram": "prejudicar",
    "prejudicaras": "prejudicar",
    "prejudicarde": "prejudicar",
    "prejudicardes": "prejudicar",
    "prejudicare": "prejudicar",
    "prejudicarei": "prejudicar",
    "prejudicareis": "prejudicar",
    "prejudicarem": "prejudicar",
    "prejudicaremos": "prejudicar",
    "prejudicares": "prejudicar",
    "prejudicaria": "prejudicar",
    "prejudicariam": "prejudicar",
    "prejudicarias": "prejudicar",
    "prejudicarmo": "prejudicar",
    "prejudicarmos": "prejudicar",
    "prejudicará": "prejudicar",
    "prejudicarás": "prejudicar",
    "prejudicarão": "prejudicar",
    "prejudicaríamos": "prejudicar",
    "prejudicaríeis": "prejudicar",
    "prejudicas": "prejudicar",
    "prejudicasse": "prejudicar",
    "prejudicassem": "prejudicar",
    "prejudicasses": "prejudicar",
    "prejudicaste": "prejudicar",
    "prejudicastes": "prejudicar",
    "prejudicava": "prejudicar",
    "prejudicavam": "prejudicar",
    "prejudicavas": "prejudicar",
    "prejudiciais": "prejudicial",
    "prejudico": "prejudicar",
    "prejudicou": "prejudicar",
    "prejudicá": "prejudicar",
    "prejudicámo": "prejudicar",
    "prejudicámos": "prejudicar",
    "prejudicáramo": "prejudicar",
    "prejudicáramos": "prejudicar",
    "prejudicárei": "prejudicar",
    "prejudicáreis": "prejudicar",
    "prejudicásseis": "prejudicar",
    "prejudicássemos": "prejudicar",
    "prejudicávamo": "prejudicar",
    "prejudicávamos": "prejudicar",
    "prejudicávei": "prejudicar",
    "prejudicáveis": "prejudicar",
    "prejudique": "prejudicar",
    "prejudiquei": "prejudicar",
    "prejudiqueis": "prejudicar",
    "prejudiquem": "prejudicar",
    "prejudiquemo": "prejudicar",
    "prejudiquemos": "prejudicar",
    "prejudiques": "prejudicar",
    "prejuízos": "prejuízo",
    "prelacia": "prelaciar",
    "prelaciada": "prelaciar",
    "prelaciadas": "prelaciar",
    "prelaciado": "prelaciar",
    "prelaciados": "prelaciar",
    "prelaciai": "prelaciar",
    "prelaciais": "prelaciar",
    "prelaciam": "prelaciar",
    "prelaciamo": "prelaciar",
    "prelaciamos": "prelaciar",
    "prelaciando": "prelaciar",
    "prelaciara": "prelaciar",
    "prelaciaram": "prelaciar",
    "prelaciaras": "prelaciar",
    "prelaciardes": "prelaciar",
    "prelaciarei": "prelaciar",
    "prelaciareis": "prelaciar",
    "prelaciarem": "prelaciar",
    "prelaciaremos": "prelaciar",
    "prelaciares": "prelaciar",
    "prelaciaria": "prelaciar",
    "prelaciariam": "prelaciar",
    "prelaciarias": "prelaciar",
    "prelaciarmo": "prelaciar",
    "prelaciarmos": "prelaciar",
    "prelaciará": "prelaciar",
    "prelaciarás": "prelaciar",
    "prelaciarão": "prelaciar",
    "prelaciaríamos": "prelaciar",
    "prelaciaríeis": "prelaciar",
    "prelacias": "prelaciar",
    "prelaciasse": "prelaciar",
    "prelaciassem": "prelaciar",
    "prelaciasses": "prelaciar",
    "prelaciaste": "prelaciar",
    "prelaciastes": "prelaciar",
    "prelaciava": "prelaciar",
    "prelaciavam": "prelaciar",
    "prelaciavas": "prelaciar",
    "prelacie": "prelaciar",
    "prelaciei": "prelaciar",
    "prelacieis": "prelaciar",
    "prelaciem": "prelaciar",
    "prelaciemo": "prelaciar",
    "prelaciemos": "prelaciar",
    "prelacies": "prelaciar",
    "prelacio": "prelaciar",
    "prelaciou": "prelaciar",
    "prelaciámo": "prelaciar",
    "prelaciámos": "prelaciar",
    "prelaciáramo": "prelaciar",
    "prelaciáramos": "prelaciar",
    "prelaciáreis": "prelaciar",
    "prelaciásseis": "prelaciar",
    "prelaciássemos": "prelaciar",
    "prelaciávamo": "prelaciar",
    "prelaciávamos": "prelaciar",
    "prelaciáveis": "prelaciar",
    "prelada": "prelado",
    "preladas": "prelado",
    "preladias": "preladia",
    "prelados": "prelado",
    "prelativa": "prelativo",
    "prelativas": "prelativo",
    "prelativos": "prelativo",
    "prelaturas": "prelatura",
    "prelatícia": "prelatício",
    "prelatícias": "prelatício",
    "prelatícios": "prelatício",
    "prelazias": "prelazia",
    "prelações": "prelação",
    "prelecciona": "preleccionar",
    "preleccionada": "preleccionar",
    "preleccionadas": "preleccionar",
    "preleccionado": "preleccionar",
    "preleccionados": "preleccionar",
    "preleccionai": "preleccionar",
    "preleccionais": "preleccionar",
    "preleccionam": "preleccionar",
    "preleccionamo": "preleccionar",
    "preleccionamos": "preleccionar",
    "preleccionando": "preleccionar",
    "preleccionara": "preleccionar",
    "preleccionaram": "preleccionar",
    "preleccionaras": "preleccionar",
    "preleccionarde": "preleccionar",
    "preleccionardes": "preleccionar",
    "preleccionare": "preleccionar",
    "preleccionarei": "preleccionar",
    "preleccionareis": "preleccionar",
    "preleccionarem": "preleccionar",
    "preleccionaremos": "preleccionar",
    "preleccionares": "preleccionar",
    "preleccionaria": "preleccionar",
    "preleccionariam": "preleccionar",
    "preleccionarias": "preleccionar",
    "preleccionarmo": "preleccionar",
    "preleccionarmos": "preleccionar",
    "preleccionará": "preleccionar",
    "preleccionarás": "preleccionar",
    "preleccionarão": "preleccionar",
    "preleccionaríamos": "preleccionar",
    "preleccionaríeis": "preleccionar",
    "preleccionas": "preleccionar",
    "preleccionasse": "preleccionar",
    "preleccionassem": "preleccionar",
    "preleccionasses": "preleccionar",
    "preleccionaste": "preleccionar",
    "preleccionastes": "preleccionar",
    "preleccionava": "preleccionar",
    "preleccionavam": "preleccionar",
    "preleccionavas": "preleccionar",
    "preleccione": "preleccionar",
    "preleccionei": "preleccionar",
    "preleccioneis": "preleccionar",
    "preleccionem": "preleccionar",
    "preleccionemo": "preleccionar",
    "preleccionemos": "preleccionar",
    "prelecciones": "preleccionar",
    "preleccionistas": "preleccionista",
    "prelecciono": "preleccionar",
    "preleccionou": "preleccionar",
    "preleccioná": "preleccionar",
    "preleccionámo": "preleccionar",
    "preleccionámos": "preleccionar",
    "preleccionáramo": "preleccionar",
    "preleccionáramos": "preleccionar",
    "preleccionárei": "preleccionar",
    "preleccionáreis": "preleccionar",
    "preleccionásseis": "preleccionar",
    "preleccionássemos": "preleccionar",
    "preleccionávamo": "preleccionar",
    "preleccionávamos": "preleccionar",
    "preleccionávei": "preleccionar",
    "preleccionáveis": "preleccionar",
    "prelectora": "prelector",
    "prelectoras": "prelector",
    "prelectores": "prelector",
    "prelecções": "prelecção",
    "preleva": "prelevar",
    "prelevada": "prelevar",
    "prelevadas": "prelevar",
    "prelevado": "prelevar",
    "prelevados": "prelevar",
    "prelevai": "prelevar",
    "prelevais": "prelevar",
    "prelevam": "prelevar",
    "prelevamo": "prelevar",
    "prelevamos": "prelevar",
    "prelevando": "prelevar",
    "prelevara": "prelevar",
    "prelevaram": "prelevar",
    "prelevaras": "prelevar",
    "prelevarde": "prelevar",
    "prelevardes": "prelevar",
    "prelevare": "prelevar",
    "prelevarei": "prelevar",
    "prelevareis": "prelevar",
    "prelevarem": "prelevar",
    "prelevaremos": "prelevar",
    "prelevares": "prelevar",
    "prelevaria": "prelevar",
    "prelevariam": "prelevar",
    "prelevarias": "prelevar",
    "prelevarmo": "prelevar",
    "prelevarmos": "prelevar",
    "prelevará": "prelevar",
    "prelevarás": "prelevar",
    "prelevarão": "prelevar",
    "prelevaríamos": "prelevar",
    "prelevaríeis": "prelevar",
    "prelevas": "prelevar",
    "prelevasse": "prelevar",
    "prelevassem": "prelevar",
    "prelevasses": "prelevar",
    "prelevaste": "prelevar",
    "prelevastes": "prelevar",
    "prelevava": "prelevar",
    "prelevavam": "prelevar",
    "prelevavas": "prelevar",
    "preleve": "prelevar",
    "prelevei": "prelevar",
    "preleveis": "prelevar",
    "prelevem": "prelevar",
    "prelevemo": "prelevar",
    "prelevemos": "prelevar",
    "preleves": "prelevar",
    "prelevo": "prelevar",
    "prelevou": "prelevar",
    "prelevá": "prelevar",
    "prelevámo": "prelevar",
    "prelevámos": "prelevar",
    "preleváramo": "prelevar",
    "preleváramos": "prelevar",
    "prelevárei": "prelevar",
    "preleváreis": "prelevar",
    "prelevásseis": "prelevar",
    "prelevássemos": "prelevar",
    "prelevávamo": "prelevar",
    "prelevávamos": "prelevar",
    "prelevávei": "prelevar",
    "preleváveis": "prelevar",
    "preliba": "prelibar",
    "prelibada": "prelibar",
    "prelibadas": "prelibar",
    "prelibado": "prelibar",
    "prelibadora": "prelibador",
    "prelibadoras": "prelibador",
    "prelibadores": "prelibador",
    "prelibados": "prelibar",
    "prelibai": "prelibar",
    "prelibais": "prelibar",
    "prelibam": "prelibar",
    "prelibamo": "prelibar",
    "prelibamos": "prelibar",
    "prelibando": "prelibar",
    "prelibara": "prelibar",
    "prelibaram": "prelibar",
    "prelibaras": "prelibar",
    "prelibarde": "prelibar",
    "prelibardes": "prelibar",
    "prelibare": "prelibar",
    "prelibarei": "prelibar",
    "prelibareis": "prelibar",
    "prelibarem": "prelibar",
    "prelibaremos": "prelibar",
    "prelibares": "prelibar",
    "prelibaria": "prelibar",
    "prelibariam": "prelibar",
    "prelibarias": "prelibar",
    "prelibarmo": "prelibar",
    "prelibarmos": "prelibar",
    "prelibará": "prelibar",
    "prelibarás": "prelibar",
    "prelibarão": "prelibar",
    "prelibaríamos": "prelibar",
    "prelibaríeis": "prelibar",
    "prelibas": "prelibar",
    "prelibasse": "prelibar",
    "prelibassem": "prelibar",
    "prelibasses": "prelibar",
    "prelibaste": "prelibar",
    "prelibastes": "prelibar",
    "prelibava": "prelibar",
    "prelibavam": "prelibar",
    "prelibavas": "prelibar",
    "prelibações": "prelibação",
    "prelibe": "prelibar",
    "prelibei": "prelibar",
    "prelibeis": "prelibar",
    "prelibem": "prelibar",
    "prelibemo": "prelibar",
    "prelibemos": "prelibar",
    "prelibes": "prelibar",
    "prelibo": "prelibar",
    "prelibou": "prelibar",
    "prelibá": "prelibar",
    "prelibámo": "prelibar",
    "prelibámos": "prelibar",
    "prelibáramo": "prelibar",
    "prelibáramos": "prelibar",
    "prelibárei": "prelibar",
    "prelibáreis": "prelibar",
    "prelibásseis": "prelibar",
    "prelibássemos": "prelibar",
    "prelibávamo": "prelibar",
    "prelibávamos": "prelibar",
    "prelibávei": "prelibar",
    "prelibáveis": "prelibar",
    "prelimiares": "prelimiar",
    "preliminares": "preliminar",
    "prelistas": "prelista",
    "prelos": "prelo",
    "prelucidações": "prelucidação",
    "preludia": "preludiar",
    "preludiada": "preludiar",
    "preludiadas": "preludiar",
    "preludiado": "preludiar",
    "preludiados": "preludiar",
    "preludiai": "preludiar",
    "preludiais": "preludiar",
    "preludiam": "preludiar",
    "preludiamo": "preludiar",
    "preludiamos": "preludiar",
    "preludiando": "preludiar",
    "preludiara": "preludiar",
    "preludiaram": "preludiar",
    "preludiaras": "preludiar",
    "preludiarde": "preludiar",
    "preludiardes": "preludiar",
    "preludiare": "preludiar",
    "preludiarei": "preludiar",
    "preludiareis": "preludiar",
    "preludiarem": "preludiar",
    "preludiaremos": "preludiar",
    "preludiares": "preludiar",
    "preludiaria": "preludiar",
    "preludiariam": "preludiar",
    "preludiarias": "preludiar",
    "preludiarmo": "preludiar",
    "preludiarmos": "preludiar",
    "preludiará": "preludiar",
    "preludiarás": "preludiar",
    "preludiarão": "preludiar",
    "preludiaríamos": "preludiar",
    "preludiaríeis": "preludiar",
    "preludias": "preludiar",
    "preludiasse": "preludiar",
    "preludiassem": "preludiar",
    "preludiasses": "preludiar",
    "preludiaste": "preludiar",
    "preludiastes": "preludiar",
    "preludiava": "preludiar",
    "preludiavam": "preludiar",
    "preludiavas": "preludiar",
    "preludie": "preludiar",
    "preludiei": "preludiar",
    "preludieis": "preludiar",
    "preludiem": "preludiar",
    "preludiemo": "preludiar",
    "preludiemos": "preludiar",
    "preludies": "preludiar",
    "preludio": "preludiar",
    "preludiou": "preludiar",
    "preludiá": "preludiar",
    "preludiámo": "preludiar",
    "preludiámos": "preludiar",
    "preludiáramo": "preludiar",
    "preludiáramos": "preludiar",
    "preludiárei": "preludiar",
    "preludiáreis": "preludiar",
    "preludiásseis": "preludiar",
    "preludiássemos": "preludiar",
    "preludiávamo": "preludiar",
    "preludiávamos": "preludiar",
    "preludiávei": "preludiar",
    "preludiáveis": "preludiar",
    "preluz": "preluzir",
    "preluza": "preluzir",
    "preluzais": "preluzir",
    "preluzam": "preluzir",
    "preluzamo": "preluzir",
    "preluzamos": "preluzir",
    "preluzas": "preluzir",
    "preluze": "preluzir",
    "preluzem": "preluzir",
    "preluzentes": "preluzente",
    "preluzes": "preluzir",
    "preluzi": "preluzir",
    "preluzia": "preluzir",
    "preluziam": "preluzir",
    "preluzias": "preluzir",
    "preluzida": "preluzir",
    "preluzidas": "preluzir",
    "preluzido": "preluzir",
    "preluzidos": "preluzir",
    "preluzimo": "preluzir",
    "preluzimos": "preluzir",
    "preluzindo": "preluzir",
    "preluzira": "preluzir",
    "preluziram": "preluzir",
    "preluziras": "preluzir",
    "preluzirdes": "preluzir",
    "preluzirei": "preluzir",
    "preluzireis": "preluzir",
    "preluzirem": "preluzir",
    "preluziremos": "preluzir",
    "preluzires": "preluzir",
    "preluziria": "preluzir",
    "preluziriam": "preluzir",
    "preluzirias": "preluzir",
    "preluzirmo": "preluzir",
    "preluzirmos": "preluzir",
    "preluzirá": "preluzir",
    "preluzirás": "preluzir",
    "preluzirão": "preluzir",
    "preluziríamos": "preluzir",
    "preluziríeis": "preluzir",
    "preluzis": "preluzir",
    "preluzisse": "preluzir",
    "preluzissem": "preluzir",
    "preluzisses": "preluzir",
    "preluziste": "preluzir",
    "preluzistes": "preluzir",
    "preluziu": "preluzir",
    "preluzo": "preluzir",
    "preluzíamo": "preluzir",
    "preluzíamos": "preluzir",
    "preluzíeis": "preluzir",
    "preluzíramo": "preluzir",
    "preluzíramos": "preluzir",
    "preluzíreis": "preluzir",
    "preluzísseis": "preluzir",
    "preluzíssemos": "preluzir",
    "prelúcida": "prelúcido",
    "prelúcidas": "prelúcido",
    "prelúcidos": "prelúcido",
    "prelúdios": "prelúdio",
    "prema": "premer",
    "premais": "premer",
    "premam": "premer",
    "premamo": "premer",
    "premamos": "premer",
    "premas": "premer",
    "prematura": "prematuro",
    "prematuras": "prematuro",
    "prematurações": "prematuração",
    "prematuridades": "prematuridade",
    "prematuros": "prematuro",
    "premaxilares": "premaxilar",
    "preme": "premer",
    "premedeiras": "premedeira",
    "premedita": "premeditar",
    "premeditada": "premeditar",
    "premeditadas": "premeditar",
    "premeditado": "premeditar",
    "premeditados": "premeditar",
    "premeditai": "premeditar",
    "premeditais": "premeditar",
    "premeditam": "premeditar",
    "premeditamo": "premeditar",
    "premeditamos": "premeditar",
    "premeditando": "premeditar",
    "premeditara": "premeditar",
    "premeditaram": "premeditar",
    "premeditaras": "premeditar",
    "premeditarde": "premeditar",
    "premeditardes": "premeditar",
    "premeditare": "premeditar",
    "premeditarei": "premeditar",
    "premeditareis": "premeditar",
    "premeditarem": "premeditar",
    "premeditaremos": "premeditar",
    "premeditares": "premeditar",
    "premeditaria": "premeditar",
    "premeditariam": "premeditar",
    "premeditarias": "premeditar",
    "premeditarmo": "premeditar",
    "premeditarmos": "premeditar",
    "premeditará": "premeditar",
    "premeditarás": "premeditar",
    "premeditarão": "premeditar",
    "premeditaríamos": "premeditar",
    "premeditaríeis": "premeditar",
    "premeditas": "premeditar",
    "premeditasse": "premeditar",
    "premeditassem": "premeditar",
    "premeditasses": "premeditar",
    "premeditaste": "premeditar",
    "premeditastes": "premeditar",
    "premeditava": "premeditar",
    "premeditavam": "premeditar",
    "premeditavas": "premeditar",
    "premeditações": "premeditação",
    "premedite": "premeditar",
    "premeditei": "premeditar",
    "premediteis": "premeditar",
    "premeditem": "premeditar",
    "premeditemo": "premeditar",
    "premeditemos": "premeditar",
    "premedites": "premeditar",
    "premedito": "premeditar",
    "premeditou": "premeditar",
    "premeditá": "premeditar",
    "premeditámo": "premeditar",
    "premeditámos": "premeditar",
    "premeditáramo": "premeditar",
    "premeditáramos": "premeditar",
    "premeditárei": "premeditar",
    "premeditáreis": "premeditar",
    "premeditásseis": "premeditar",
    "premeditássemos": "premeditar",
    "premeditávamo": "premeditar",
    "premeditávamos": "premeditar",
    "premeditávei": "premeditar",
    "premeditáveis": "premeditável",
    "premei": "premer",
    "premeia": "premiar",
    "premeiam": "premiar",
    "premeias": "premiar",
    "premeie": "premiar",
    "premeiem": "premiar",
    "premeies": "premiar",
    "premeio": "premiar",
    "premeis": "premer",
    "premem": "premer",
    "prememo": "premer",
    "prememos": "premer",
    "premendo": "premer",
    "prementes": "premente",
    "premera": "premer",
    "premeram": "premer",
    "premeras": "premer",
    "premerde": "premer",
    "premerdes": "premer",
    "premere": "premer",
    "premerei": "premer",
    "premereis": "premer",
    "premerem": "premer",
    "premeremos": "premer",
    "premeres": "premer",
    "premeria": "premer",
    "premeriam": "premer",
    "premerias": "premer",
    "premermo": "premer",
    "premermos": "premer",
    "premerá": "premer",
    "premerás": "premer",
    "premerão": "premer",
    "premeríamos": "premer",
    "premeríeis": "premer",
    "premes": "premer",
    "premesse": "premer",
    "premessem": "premer",
    "premesses": "premer",
    "premeste": "premer",
    "premestes": "premer",
    "premeu": "premer",
    "premi": "premir",
    "premia": "premir",
    "premiada": "premiar",
    "premiadas": "premiar",
    "premiado": "premiar",
    "premiadora": "premiador",
    "premiadoras": "premiador",
    "premiadores": "premiador",
    "premiados": "premiar",
    "premiai": "premiar",
    "premiais": "premiar",
    "premiam": "premir",
    "premiamo": "premiar",
    "premiamos": "premiar",
    "premiando": "premiar",
    "premiara": "premiar",
    "premiaram": "premiar",
    "premiaras": "premiar",
    "premiarde": "premiar",
    "premiardes": "premiar",
    "premiare": "premiar",
    "premiarei": "premiar",
    "premiareis": "premiar",
    "premiarem": "premiar",
    "premiaremos": "premiar",
    "premiares": "premiar",
    "premiaria": "premiar",
    "premiariam": "premiar",
    "premiarias": "premiar",
    "premiarmo": "premiar",
    "premiarmos": "premiar",
    "premiará": "premiar",
    "premiarás": "premiar",
    "premiarão": "premiar",
    "premiaríamos": "premiar",
    "premiaríeis": "premiar",
    "premias": "premir",
    "premiasse": "premiar",
    "premiassem": "premiar",
    "premiasses": "premiar",
    "premiaste": "premiar",
    "premiastes": "premiar",
    "premiativa": "premiativo",
    "premiativas": "premiativo",
    "premiativos": "premiativo",
    "premiava": "premiar",
    "premiavam": "premiar",
    "premiavas": "premiar",
    "premida": "premir",
    "premidas": "premir",
    "premido": "premir",
    "premidos": "premir",
    "premiei": "premiar",
    "premieis": "premiar",
    "premiemo": "premiar",
    "premiemos": "premiar",
    "premimo": "premir",
    "premimos": "premir",
    "premindo": "premir",
    "premiou": "premiar",
    "premira": "premir",
    "premiram": "premir",
    "premiras": "premir",
    "premirde": "premir",
    "premirdes": "premir",
    "premire": "premir",
    "premirei": "premir",
    "premireis": "premir",
    "premirem": "premir",
    "premiremos": "premir",
    "premires": "premir",
    "premiria": "premir",
    "premiriam": "premir",
    "premirias": "premir",
    "premirmo": "premir",
    "premirmos": "premir",
    "premirá": "premir",
    "premirás": "premir",
    "premirão": "premir",
    "premiríamos": "premir",
    "premiríeis": "premir",
    "premis": "premir",
    "premissas": "premissa",
    "premisse": "premir",
    "premissem": "premir",
    "premisses": "premir",
    "premiste": "premir",
    "premistes": "premir",
    "premiu": "premir",
    "premiá": "premiar",
    "premiámo": "premiar",
    "premiámos": "premiar",
    "premiáramo": "premiar",
    "premiáramos": "premiar",
    "premiárei": "premiar",
    "premiáreis": "premiar",
    "premiásseis": "premiar",
    "premiássemos": "premiar",
    "premiávamo": "premiar",
    "premiávamos": "premiar",
    "premiávei": "premiar",
    "premiáveis": "premiável",
    "premo": "premer",
    "premonitória": "premonitório",
    "premonitórias": "premonitório",
    "premonitórios": "premonitório",
    "premonições": "premonição",
    "premorsa": "premorso",
    "premorsas": "premorso",
    "premorsos": "premorso",
    "premoções": "premoção",
    "premuna": "premunir",
    "premunais": "premunir",
    "premunam": "premunir",
    "premunamo": "premunir",
    "premunamos": "premunir",
    "premunas": "premunir",
    "premune": "premunir",
    "premunem": "premunir",
    "premunes": "premunir",
    "premuni": "premunir",
    "premunia": "premunir",
    "premuniam": "premunir",
    "premunias": "premunir",
    "premunida": "premunir",
    "premunidas": "premunir",
    "premunido": "premunir",
    "premunidos": "premunir",
    "premunimo": "premunir",
    "premunimos": "premunir",
    "premunindo": "premunir",
    "premunira": "premunir",
    "premuniram": "premunir",
    "premuniras": "premunir",
    "premunirde": "premunir",
    "premunirdes": "premunir",
    "premunire": "premunir",
    "premunirei": "premunir",
    "premunireis": "premunir",
    "premunirem": "premunir",
    "premuniremos": "premunir",
    "premunires": "premunir",
    "premuniria": "premunir",
    "premuniriam": "premunir",
    "premunirias": "premunir",
    "premunirmo": "premunir",
    "premunirmos": "premunir",
    "premunirá": "premunir",
    "premunirás": "premunir",
    "premunirão": "premunir",
    "premuniríamos": "premunir",
    "premuniríeis": "premunir",
    "premunis": "premunir",
    "premunisse": "premunir",
    "premunissem": "premunir",
    "premunisses": "premunir",
    "premuniste": "premunir",
    "premunistes": "premunir",
    "premunitiva": "premunitivo",
    "premunitivas": "premunitivo",
    "premunitivos": "premunitivo",
    "premuniu": "premunir",
    "premunições": "premunição",
    "premuno": "premunir",
    "premuníamo": "premunir",
    "premuníamos": "premunir",
    "premuníei": "premunir",
    "premuníeis": "premunir",
    "premuníramo": "premunir",
    "premuníramos": "premunir",
    "premunírei": "premunir",
    "premuníreis": "premunir",
    "premunísseis": "premunir",
    "premuníssemos": "premunir",
    "premê": "premer",
    "premências": "premência",
    "premêramo": "premer",
    "premêramos": "premer",
    "premêrei": "premer",
    "premêreis": "premer",
    "premêsseis": "premer",
    "premêssemos": "premer",
    "premíamo": "premir",
    "premíamos": "premir",
    "premíei": "premir",
    "premíeis": "premir",
    "premíramo": "premir",
    "premíramos": "premir",
    "premírei": "premir",
    "premíreis": "premir",
    "premísseis": "premir",
    "premíssemos": "premir",
    "prena": "prenar",
    "prenada": "prenar",
    "prenadas": "prenar",
    "prenado": "prenar",
    "prenados": "prenar",
    "prenai": "prenar",
    "prenais": "prenar",
    "prenam": "prenar",
    "prenamo": "prenar",
    "prenamos": "prenar",
    "prenando": "prenar",
    "prenara": "prenar",
    "prenaram": "prenar",
    "prenaras": "prenar",
    "prenarde": "prenar",
    "prenardes": "prenar",
    "prenare": "prenar",
    "prenarei": "prenar",
    "prenareis": "prenar",
    "prenarem": "prenar",
    "prenaremos": "prenar",
    "prenares": "prenar",
    "prenaria": "prenar",
    "prenariam": "prenar",
    "prenarias": "prenar",
    "prenarmo": "prenar",
    "prenarmos": "prenar",
    "prenará": "prenar",
    "prenarás": "prenar",
    "prenarão": "prenar",
    "prenaríamos": "prenar",
    "prenaríeis": "prenar",
    "prenas": "prenar",
    "prenasse": "prenar",
    "prenassem": "prenar",
    "prenasses": "prenar",
    "prenaste": "prenar",
    "prenastes": "prenar",
    "prenava": "prenar",
    "prenavam": "prenar",
    "prenavas": "prenar",
    "prenda": "prender",
    "prendada": "prendar",
    "prendadas": "prendar",
    "prendado": "prendar",
    "prendados": "prendar",
    "prendadíssima": "prendado",
    "prendadíssimas": "prendado",
    "prendadíssimo": "prendado",
    "prendadíssimos": "prendado",
    "prendai": "prendar",
    "prendais": "prender",
    "prendam": "prender",
    "prendamo": "prender",
    "prendamos": "prender",
    "prendando": "prendar",
    "prendara": "prendar",
    "prendaram": "prendar",
    "prendaras": "prendar",
    "prendarde": "prendar",
    "prendardes": "prendar",
    "prendare": "prendar",
    "prendarei": "prendar",
    "prendareis": "prendar",
    "prendarem": "prendar",
    "prendaremos": "prendar",
    "prendares": "prendar",
    "prendaria": "prendar",
    "prendariam": "prendar",
    "prendarias": "prendar",
    "prendarmo": "prendar",
    "prendarmos": "prendar",
    "prendará": "prendar",
    "prendarás": "prendar",
    "prendarão": "prendar",
    "prendaríamos": "prendar",
    "prendaríeis": "prendar",
    "prendas": "prender",
    "prendasse": "prendar",
    "prendassem": "prendar",
    "prendasses": "prendar",
    "prendaste": "prendar",
    "prendastes": "prendar",
    "prendava": "prendar",
    "prendavam": "prendar",
    "prendavas": "prendar",
    "prende": "prender",
    "prendei": "prender",
    "prendeis": "prender",
    "prendem": "prender",
    "prendemo": "prender",
    "prendemos": "prender",
    "prendendo": "prender",
    "prendera": "prender",
    "prenderam": "prender",
    "prenderas": "prender",
    "prenderde": "prender",
    "prenderdes": "prender",
    "prendere": "prender",
    "prenderei": "prender",
    "prendereis": "prender",
    "prenderem": "prender",
    "prenderemos": "prender",
    "prenderes": "prender",
    "prenderia": "prender",
    "prenderiam": "prender",
    "prenderias": "prender",
    "prendermo": "prender",
    "prendermos": "prender",
    "prenderá": "prender",
    "prenderás": "prender",
    "prenderão": "prender",
    "prenderíamos": "prender",
    "prenderíeis": "prender",
    "prendes": "prender",
    "prendesse": "prender",
    "prendessem": "prender",
    "prendesses": "prender",
    "prendeste": "prender",
    "prendestes": "prender",
    "prendeu": "prender",
    "prendi": "prender",
    "prendia": "prender",
    "prendiam": "prender",
    "prendias": "prender",
    "prendida": "prendido",
    "prendidas": "prendido",
    "prendido": "prender",
    "prendidos": "prendido",
    "prendinha": "prenda",
    "prendinhas": "prenda",
    "prendita": "prenda",
    "prenditas": "prenda",
    "prendo": "prender",
    "prendou": "prendar",
    "prendá": "prendar",
    "prendámo": "prendar",
    "prendámos": "prendar",
    "prendáramo": "prendar",
    "prendáramos": "prendar",
    "prendárei": "prendar",
    "prendáreis": "prendar",
    "prendásseis": "prendar",
    "prendássemos": "prendar",
    "prendávamo": "prendar",
    "prendávamos": "prendar",
    "prendávei": "prendar",
    "prendáveis": "prendar",
    "prendê": "prender",
    "prendêramo": "prender",
    "prendêramos": "prender",
    "prendêrei": "prender",
    "prendêreis": "prender",
    "prendêsseis": "prender",
    "prendêssemos": "prender",
    "prendíamo": "prender",
    "prendíamos": "prender",
    "prendíei": "prender",
    "prendíeis": "prender",
    "prene": "prenar",
    "prenei": "prenar",
    "preneis": "prenar",
    "prenem": "prenar",
    "prenemo": "prenar",
    "prenemos": "prenar",
    "prenes": "prenar",
    "prenhas": "prenha",
    "prenhes": "prenhe",
    "prenhezes": "prenhez",
    "prenhidões": "prenhidão",
    "prenhites": "prenhite",
    "preno": "prenar",
    "prenomeações": "prenomeação",
    "prenomes": "prenome",
    "prenomina": "prenominar",
    "prenominada": "prenominar",
    "prenominadas": "prenominar",
    "prenominado": "prenominar",
    "prenominados": "prenominar",
    "prenominai": "prenominar",
    "prenominais": "prenominar",
    "prenominam": "prenominar",
    "prenominamo": "prenominar",
    "prenominamos": "prenominar",
    "prenominando": "prenominar",
    "prenominara": "prenominar",
    "prenominaram": "prenominar",
    "prenominaras": "prenominar",
    "prenominarde": "prenominar",
    "prenominardes": "prenominar",
    "prenominare": "prenominar",
    "prenominarei": "prenominar",
    "prenominareis": "prenominar",
    "prenominarem": "prenominar",
    "prenominaremos": "prenominar",
    "prenominares": "prenominar",
    "prenominaria": "prenominar",
    "prenominariam": "prenominar",
    "prenominarias": "prenominar",
    "prenominarmo": "prenominar",
    "prenominarmos": "prenominar",
    "prenominará": "prenominar",
    "prenominarás": "prenominar",
    "prenominarão": "prenominar",
    "prenominaríamos": "prenominar",
    "prenominaríeis": "prenominar",
    "prenominas": "prenominar",
    "prenominasse": "prenominar",
    "prenominassem": "prenominar",
    "prenominasses": "prenominar",
    "prenominaste": "prenominar",
    "prenominastes": "prenominar",
    "prenominava": "prenominar",
    "prenominavam": "prenominar",
    "prenominavas": "prenominar",
    "prenomine": "prenominar",
    "prenominei": "prenominar",
    "prenomineis": "prenominar",
    "prenominem": "prenominar",
    "prenominemo": "prenominar",
    "prenominemos": "prenominar",
    "prenomines": "prenominar",
    "prenomino": "prenominar",
    "prenominou": "prenominar",
    "prenominá": "prenominar",
    "prenominámo": "prenominar",
    "prenominámos": "prenominar",
    "prenomináramo": "prenominar",
    "prenomináramos": "prenominar",
    "prenominárei": "prenominar",
    "prenomináreis": "prenominar",
    "prenominásseis": "prenominar",
    "prenominássemos": "prenominar",
    "prenominávamo": "prenominar",
    "prenominávamos": "prenominar",
    "prenominávei": "prenominar",
    "prenomináveis": "prenominar",
    "prenota": "prenotar",
    "prenotada": "prenotar",
    "prenotadas": "prenotar",
    "prenotado": "prenotar",
    "prenotados": "prenotar",
    "prenotai": "prenotar",
    "prenotais": "prenotar",
    "prenotam": "prenotar",
    "prenotamo": "prenotar",
    "prenotamos": "prenotar",
    "prenotando": "prenotar",
    "prenotara": "prenotar",
    "prenotaram": "prenotar",
    "prenotaras": "prenotar",
    "prenotarde": "prenotar",
    "prenotardes": "prenotar",
    "prenotare": "prenotar",
    "prenotarei": "prenotar",
    "prenotareis": "prenotar",
    "prenotarem": "prenotar",
    "prenotaremos": "prenotar",
    "prenotares": "prenotar",
    "prenotaria": "prenotar",
    "prenotariam": "prenotar",
    "prenotarias": "prenotar",
    "prenotarmo": "prenotar",
    "prenotarmos": "prenotar",
    "prenotará": "prenotar",
    "prenotarás": "prenotar",
    "prenotarão": "prenotar",
    "prenotaríamos": "prenotar",
    "prenotaríeis": "prenotar",
    "prenotas": "prenotar",
    "prenotasse": "prenotar",
    "prenotassem": "prenotar",
    "prenotasses": "prenotar",
    "prenotaste": "prenotar",
    "prenotastes": "prenotar",
    "prenotava": "prenotar",
    "prenotavam": "prenotar",
    "prenotavas": "prenotar",
    "prenote": "prenotar",
    "prenotei": "prenotar",
    "prenoteis": "prenotar",
    "prenotem": "prenotar",
    "prenotemo": "prenotar",
    "prenotemos": "prenotar",
    "prenotes": "prenotar",
    "prenoto": "prenotar",
    "prenotou": "prenotar",
    "prenotá": "prenotar",
    "prenotámo": "prenotar",
    "prenotámos": "prenotar",
    "prenotáramo": "prenotar",
    "prenotáramos": "prenotar",
    "prenotárei": "prenotar",
    "prenotáreis": "prenotar",
    "prenotásseis": "prenotar",
    "prenotássemos": "prenotar",
    "prenotávamo": "prenotar",
    "prenotávamos": "prenotar",
    "prenotávei": "prenotar",
    "prenotáveis": "prenotar",
    "prenou": "prenar",
    "prenoções": "prenoção",
    "prensada": "prensado",
    "prensadas": "prensado",
    "prensadora": "prensador",
    "prensadoras": "prensador",
    "prensadores": "prensador",
    "prensados": "prensado",
    "prensagens": "prensagem",
    "prensas": "prensa",
    "prensistas": "prensista",
    "prenuncia": "prenunciar",
    "prenunciada": "prenunciar",
    "prenunciadas": "prenunciar",
    "prenunciado": "prenunciar",
    "prenunciadora": "prenunciador",
    "prenunciadoras": "prenunciador",
    "prenunciadores": "prenunciador",
    "prenunciados": "prenunciar",
    "prenunciai": "prenunciar",
    "prenunciais": "prenunciar",
    "prenunciam": "prenunciar",
    "prenunciamo": "prenunciar",
    "prenunciamos": "prenunciar",
    "prenunciando": "prenunciar",
    "prenunciara": "prenunciar",
    "prenunciaram": "prenunciar",
    "prenunciaras": "prenunciar",
    "prenunciarde": "prenunciar",
    "prenunciardes": "prenunciar",
    "prenunciare": "prenunciar",
    "prenunciarei": "prenunciar",
    "prenunciareis": "prenunciar",
    "prenunciarem": "prenunciar",
    "prenunciaremos": "prenunciar",
    "prenunciares": "prenunciar",
    "prenunciaria": "prenunciar",
    "prenunciariam": "prenunciar",
    "prenunciarias": "prenunciar",
    "prenunciarmo": "prenunciar",
    "prenunciarmos": "prenunciar",
    "prenunciará": "prenunciar",
    "prenunciarás": "prenunciar",
    "prenunciarão": "prenunciar",
    "prenunciaríamos": "prenunciar",
    "prenunciaríeis": "prenunciar",
    "prenuncias": "prenunciar",
    "prenunciasse": "prenunciar",
    "prenunciassem": "prenunciar",
    "prenunciasses": "prenunciar",
    "prenunciaste": "prenunciar",
    "prenunciastes": "prenunciar",
    "prenunciativa": "prenunciativo",
    "prenunciativas": "prenunciativo",
    "prenunciativos": "prenunciativo",
    "prenunciava": "prenunciar",
    "prenunciavam": "prenunciar",
    "prenunciavas": "prenunciar",
    "prenunciações": "prenunciação",
    "prenuncie": "prenunciar",
    "prenunciei": "prenunciar",
    "prenuncieis": "prenunciar",
    "prenunciem": "prenunciar",
    "prenunciemo": "prenunciar",
    "prenunciemos": "prenunciar",
    "prenuncies": "prenunciar",
    "prenuncio": "prenunciar",
    "prenunciou": "prenunciar",
    "prenunciá": "prenunciar",
    "prenunciámo": "prenunciar",
    "prenunciámos": "prenunciar",
    "prenunciáramo": "prenunciar",
    "prenunciáramos": "prenunciar",
    "prenunciárei": "prenunciar",
    "prenunciáreis": "prenunciar",
    "prenunciásseis": "prenunciar",
    "prenunciássemos": "prenunciar",
    "prenunciávamo": "prenunciar",
    "prenunciávamos": "prenunciar",
    "prenunciávei": "prenunciar",
    "prenunciáveis": "prenunciar",
    "prená": "prenar",
    "prenámo": "prenar",
    "prenámos": "prenar",
    "prenáramo": "prenar",
    "prenáramos": "prenar",
    "prenárei": "prenar",
    "prenáreis": "prenar",
    "prenásseis": "prenar",
    "prenássemos": "prenar",
    "prenávamo": "prenar",
    "prenávamos": "prenar",
    "prenávei": "prenar",
    "prenáveis": "prenar",
    "prenúncios": "prenúncio",
    "preocupa": "preocupar",
    "preocupada": "preocupar",
    "preocupadas": "preocupar",
    "preocupadazinha": "preocupado",
    "preocupadazinhas": "preocupado",
    "preocupadazita": "preocupado",
    "preocupadazitas": "preocupado",
    "preocupadinha": "preocupado",
    "preocupadinhas": "preocupado",
    "preocupadinho": "preocupado",
    "preocupadinhos": "preocupado",
    "preocupadita": "preocupado",
    "preocupaditas": "preocupado",
    "preocupadito": "preocupado",
    "preocupaditos": "preocupado",
    "preocupado": "preocupar",
    "preocupados": "preocupar",
    "preocupadozinho": "preocupado",
    "preocupadozinhos": "preocupado",
    "preocupadozito": "preocupado",
    "preocupadozitos": "preocupado",
    "preocupadíssima": "preocupado",
    "preocupadíssimas": "preocupado",
    "preocupadíssimo": "preocupado",
    "preocupadíssimos": "preocupado",
    "preocupai": "preocupar",
    "preocupais": "preocupar",
    "preocupam": "preocupar",
    "preocupamo": "preocupar",
    "preocupamos": "preocupar",
    "preocupando": "preocupar",
    "preocupantes": "preocupante",
    "preocupara": "preocupar",
    "preocuparam": "preocupar",
    "preocuparas": "preocupar",
    "preocuparde": "preocupar",
    "preocupardes": "preocupar",
    "preocupare": "preocupar",
    "preocuparei": "preocupar",
    "preocupareis": "preocupar",
    "preocuparem": "preocupar",
    "preocuparemos": "preocupar",
    "preocupares": "preocupar",
    "preocuparia": "preocupar",
    "preocupariam": "preocupar",
    "preocuparias": "preocupar",
    "preocuparmo": "preocupar",
    "preocuparmos": "preocupar",
    "preocupará": "preocupar",
    "preocuparás": "preocupar",
    "preocuparão": "preocupar",
    "preocuparíamos": "preocupar",
    "preocuparíeis": "preocupar",
    "preocupas": "preocupar",
    "preocupasse": "preocupar",
    "preocupassem": "preocupar",
    "preocupasses": "preocupar",
    "preocupaste": "preocupar",
    "preocupastes": "preocupar",
    "preocupava": "preocupar",
    "preocupavam": "preocupar",
    "preocupavas": "preocupar",
    "preocupações": "preocupação",
    "preocupe": "preocupar",
    "preocupei": "preocupar",
    "preocupeis": "preocupar",
    "preocupem": "preocupar",
    "preocupemo": "preocupar",
    "preocupemos": "preocupar",
    "preocupes": "preocupar",
    "preocupo": "preocupar",
    "preocupou": "preocupar",
    "preocupá": "preocupar",
    "preocupámo": "preocupar",
    "preocupámos": "preocupar",
    "preocupáramo": "preocupar",
    "preocupáramos": "preocupar",
    "preocupárei": "preocupar",
    "preocupáreis": "preocupar",
    "preocupásseis": "preocupar",
    "preocupássemos": "preocupar",
    "preocupávamo": "preocupar",
    "preocupávamos": "preocupar",
    "preocupávei": "preocupar",
    "preocupáveis": "preocupar",
    "preopina": "preopinar",
    "preopinada": "preopinar",
    "preopinadas": "preopinar",
    "preopinado": "preopinar",
    "preopinados": "preopinar",
    "preopinai": "preopinar",
    "preopinais": "preopinar",
    "preopinam": "preopinar",
    "preopinamo": "preopinar",
    "preopinamos": "preopinar",
    "preopinando": "preopinar",
    "preopinantes": "preopinante",
    "preopinara": "preopinar",
    "preopinaram": "preopinar",
    "preopinaras": "preopinar",
    "preopinardes": "preopinar",
    "preopinarei": "preopinar",
    "preopinareis": "preopinar",
    "preopinarem": "preopinar",
    "preopinaremos": "preopinar",
    "preopinares": "preopinar",
    "preopinaria": "preopinar",
    "preopinariam": "preopinar",
    "preopinarias": "preopinar",
    "preopinarmo": "preopinar",
    "preopinarmos": "preopinar",
    "preopinará": "preopinar",
    "preopinarás": "preopinar",
    "preopinarão": "preopinar",
    "preopinaríamos": "preopinar",
    "preopinaríeis": "preopinar",
    "preopinas": "preopinar",
    "preopinasse": "preopinar",
    "preopinassem": "preopinar",
    "preopinasses": "preopinar",
    "preopinaste": "preopinar",
    "preopinastes": "preopinar",
    "preopinava": "preopinar",
    "preopinavam": "preopinar",
    "preopinavas": "preopinar",
    "preopine": "preopinar",
    "preopinei": "preopinar",
    "preopineis": "preopinar",
    "preopinem": "preopinar",
    "preopinemo": "preopinar",
    "preopinemos": "preopinar",
    "preopines": "preopinar",
    "preopino": "preopinar",
    "preopinou": "preopinar",
    "preopinámo": "preopinar",
    "preopinámos": "preopinar",
    "preopináramo": "preopinar",
    "preopináramos": "preopinar",
    "preopináreis": "preopinar",
    "preopinásseis": "preopinar",
    "preopinássemos": "preopinar",
    "preopinávamo": "preopinar",
    "preopinávamos": "preopinar",
    "preopináveis": "preopinar",
    "preopérculos": "preopérculo",
    "preordena": "preordenar",
    "preordenada": "preordenar",
    "preordenadas": "preordenar",
    "preordenado": "preordenar",
    "preordenados": "preordenar",
    "preordenai": "preordenar",
    "preordenais": "preordenar",
    "preordenam": "preordenar",
    "preordenamo": "preordenar",
    "preordenamos": "preordenar",
    "preordenando": "preordenar",
    "preordenara": "preordenar",
    "preordenaram": "preordenar",
    "preordenaras": "preordenar",
    "preordenarde": "preordenar",
    "preordenardes": "preordenar",
    "preordenare": "preordenar",
    "preordenarei": "preordenar",
    "preordenareis": "preordenar",
    "preordenarem": "preordenar",
    "preordenaremos": "preordenar",
    "preordenares": "preordenar",
    "preordenaria": "preordenar",
    "preordenariam": "preordenar",
    "preordenarias": "preordenar",
    "preordenarmo": "preordenar",
    "preordenarmos": "preordenar",
    "preordenará": "preordenar",
    "preordenarás": "preordenar",
    "preordenarão": "preordenar",
    "preordenaríamos": "preordenar",
    "preordenaríeis": "preordenar",
    "preordenas": "preordenar",
    "preordenasse": "preordenar",
    "preordenassem": "preordenar",
    "preordenasses": "preordenar",
    "preordenaste": "preordenar",
    "preordenastes": "preordenar",
    "preordenava": "preordenar",
    "preordenavam": "preordenar",
    "preordenavas": "preordenar",
    "preordenações": "preordenação",
    "preordene": "preordenar",
    "preordenei": "preordenar",
    "preordeneis": "preordenar",
    "preordenem": "preordenar",
    "preordenemo": "preordenar",
    "preordenemos": "preordenar",
    "preordenes": "preordenar",
    "preordeno": "preordenar",
    "preordenou": "preordenar",
    "preordená": "preordenar",
    "preordenámo": "preordenar",
    "preordenámos": "preordenar",
    "preordenáramo": "preordenar",
    "preordenáramos": "preordenar",
    "preordenárei": "preordenar",
    "preordenáreis": "preordenar",
    "preordenásseis": "preordenar",
    "preordenássemos": "preordenar",
    "preordenávamo": "preordenar",
    "preordenávamos": "preordenar",
    "preordenávei": "preordenar",
    "preordenáveis": "preordenar",
    "preou": "prear",
    "prepara": "preparar",
    "preparada": "preparar",
    "preparadas": "preparar",
    "preparado": "preparar",
    "preparadora": "preparador",
    "preparadoras": "preparador",
    "preparadores": "preparador",
    "preparados": "preparar",
    "preparadíssima": "preparado",
    "preparadíssimas": "preparado",
    "preparadíssimo": "preparado",
    "preparadíssimos": "preparado",
    "preparai": "preparar",
    "preparais": "preparar",
    "preparam": "preparar",
    "preparamo": "preparar",
    "preparamos": "preparar",
    "preparando": "preparar",
    "preparara": "preparar",
    "prepararam": "preparar",
    "prepararas": "preparar",
    "prepararde": "preparar",
    "preparardes": "preparar",
    "preparare": "preparar",
    "prepararei": "preparar",
    "preparareis": "preparar",
    "prepararem": "preparar",
    "prepararemos": "preparar",
    "preparares": "preparar",
    "prepararia": "preparar",
    "preparariam": "preparar",
    "prepararias": "preparar",
    "prepararmo": "preparar",
    "prepararmos": "preparar",
    "preparará": "preparar",
    "prepararás": "preparar",
    "prepararão": "preparar",
    "prepararíamos": "preparar",
    "prepararíeis": "preparar",
    "preparas": "preparar",
    "preparasse": "preparar",
    "preparassem": "preparar",
    "preparasses": "preparar",
    "preparaste": "preparar",
    "preparastes": "preparar",
    "preparativa": "preparativo",
    "preparativas": "preparativo",
    "preparativos": "preparativo",
    "preparatória": "preparatório",
    "preparatórias": "preparatório",
    "preparatórios": "preparatório",
    "preparava": "preparar",
    "preparavam": "preparar",
    "preparavas": "preparar",
    "preparações": "preparação",
    "prepare": "preparar",
    "preparei": "preparar",
    "prepareis": "preparar",
    "preparem": "preparar",
    "preparemo": "preparar",
    "preparemos": "preparar",
    "prepares": "preparar",
    "preparo": "preparar",
    "preparos": "preparo",
    "preparou": "preparar",
    "prepará": "preparar",
    "preparámo": "preparar",
    "preparámos": "preparar",
    "preparáramo": "preparar",
    "preparáramos": "preparar",
    "preparárei": "preparar",
    "preparáreis": "preparar",
    "preparásseis": "preparar",
    "preparássemos": "preparar",
    "preparávamo": "preparar",
    "preparávamos": "preparar",
    "preparávei": "preparar",
    "preparáveis": "preparável",
    "prepaus": "prepau",
    "prepomo": "prepor",
    "prepomos": "prepor",
    "preponde": "prepor",
    "prepondera": "preponderar",
    "preponderada": "preponderar",
    "preponderadas": "preponderar",
    "preponderado": "preponderar",
    "preponderados": "preponderar",
    "preponderai": "preponderar",
    "preponderais": "preponderar",
    "preponderam": "preponderar",
    "preponderamo": "preponderar",
    "preponderamos": "preponderar",
    "preponderando": "preponderar",
    "preponderantes": "preponderante",
    "preponderantismos": "preponderantismo",
    "preponderara": "preponderar",
    "preponderaram": "preponderar",
    "preponderaras": "preponderar",
    "preponderardes": "preponderar",
    "preponderarei": "preponderar",
    "preponderareis": "preponderar",
    "preponderarem": "preponderar",
    "preponderaremos": "preponderar",
    "preponderares": "preponderar",
    "preponderaria": "preponderar",
    "preponderariam": "preponderar",
    "preponderarias": "preponderar",
    "preponderarmo": "preponderar",
    "preponderarmos": "preponderar",
    "preponderará": "preponderar",
    "preponderarás": "preponderar",
    "preponderarão": "preponderar",
    "preponderaríamos": "preponderar",
    "preponderaríeis": "preponderar",
    "preponderas": "preponderar",
    "preponderasse": "preponderar",
    "preponderassem": "preponderar",
    "preponderasses": "preponderar",
    "preponderaste": "preponderar",
    "preponderastes": "preponderar",
    "preponderava": "preponderar",
    "preponderavam": "preponderar",
    "preponderavas": "preponderar",
    "prepondere": "preponderar",
    "preponderei": "preponderar",
    "prepondereis": "preponderar",
    "preponderem": "preponderar",
    "preponderemo": "preponderar",
    "preponderemos": "preponderar",
    "preponderes": "preponderar",
    "prepondero": "preponderar",
    "preponderou": "preponderar",
    "preponderámo": "preponderar",
    "preponderámos": "preponderar",
    "preponderáramo": "preponderar",
    "preponderáramos": "preponderar",
    "preponderáreis": "preponderar",
    "preponderásseis": "preponderar",
    "preponderássemos": "preponderar",
    "preponderávamo": "preponderar",
    "preponderávamos": "preponderar",
    "preponderáveis": "preponderar",
    "preponderâncias": "preponderância",
    "prepondes": "prepor",
    "prepondo": "prepor",
    "preponentes": "preponente",
    "preponha": "prepor",
    "preponhais": "prepor",
    "preponham": "prepor",
    "preponhamo": "prepor",
    "preponhamos": "prepor",
    "preponhas": "prepor",
    "preponho": "prepor",
    "preporde": "prepor",
    "prepordes": "prepor",
    "prepore": "prepor",
    "preporei": "prepor",
    "preporeis": "prepor",
    "preporem": "prepor",
    "preporemos": "prepor",
    "prepores": "prepor",
    "preporia": "prepor",
    "preporiam": "prepor",
    "preporias": "prepor",
    "prepormo": "prepor",
    "prepormos": "prepor",
    "preporá": "prepor",
    "preporás": "prepor",
    "preporão": "prepor",
    "preporíamos": "prepor",
    "preporíeis": "prepor",
    "preposicionada": "preposicionado",
    "preposicionadas": "preposicionado",
    "preposicionados": "preposicionado",
    "preposicionais": "preposicional",
    "prepositiva": "prepositivo",
    "prepositivas": "prepositivo",
    "prepositivos": "prepositivo",
    "preposições": "preposição",
    "preposta": "preposto",
    "prepostas": "preposto",
    "prepostera": "preposterar",
    "preposterada": "preposterar",
    "preposteradas": "preposterar",
    "preposterado": "preposterar",
    "preposterados": "preposterar",
    "preposterai": "preposterar",
    "preposterais": "preposterar",
    "preposteram": "preposterar",
    "preposteramo": "preposterar",
    "preposteramos": "preposterar",
    "preposterando": "preposterar",
    "preposterara": "preposterar",
    "preposteraram": "preposterar",
    "preposteraras": "preposterar",
    "preposterarde": "preposterar",
    "preposterardes": "preposterar",
    "preposterare": "preposterar",
    "preposterarei": "preposterar",
    "preposterareis": "preposterar",
    "preposterarem": "preposterar",
    "preposteraremos": "preposterar",
    "preposterares": "preposterar",
    "preposteraria": "preposterar",
    "preposterariam": "preposterar",
    "preposterarias": "preposterar",
    "preposterarmo": "preposterar",
    "preposterarmos": "preposterar",
    "preposterará": "preposterar",
    "preposterarás": "preposterar",
    "preposterarão": "preposterar",
    "preposteraríamos": "preposterar",
    "preposteraríeis": "preposterar",
    "preposteras": "preposterar",
    "preposterasse": "preposterar",
    "preposterassem": "preposterar",
    "preposterasses": "preposterar",
    "preposteraste": "preposterar",
    "preposterastes": "preposterar",
    "preposterava": "preposterar",
    "preposteravam": "preposterar",
    "preposteravas": "preposterar",
    "preposterações": "preposteração",
    "prepostere": "preposterar",
    "preposterei": "preposterar",
    "prepostereis": "preposterar",
    "preposterem": "preposterar",
    "preposteremo": "preposterar",
    "preposteremos": "preposterar",
    "preposteres": "preposterar",
    "preposteridades": "preposteridade",
    "prepostero": "preposterar",
    "preposterou": "preposterar",
    "preposterá": "preposterar",
    "preposterámo": "preposterar",
    "preposterámos": "preposterar",
    "preposteráramo": "preposterar",
    "preposteráramos": "preposterar",
    "preposterárei": "preposterar",
    "preposteráreis": "preposterar",
    "preposterásseis": "preposterar",
    "preposterássemos": "preposterar",
    "preposterávamo": "preposterar",
    "preposterávamos": "preposterar",
    "preposterávei": "preposterar",
    "preposteráveis": "preposterar",
    "preposto": "prepor",
    "prepostos": "preposto",
    "prepotentes": "prepotente",
    "prepotências": "prepotência",
    "prepuciais": "prepucial",
    "prepunha": "prepor",
    "prepunham": "prepor",
    "prepunhas": "prepor",
    "prepus": "prepor",
    "prepusemo": "prepor",
    "prepusemos": "prepor",
    "prepuser": "prepor",
    "prepusera": "prepor",
    "prepuseram": "prepor",
    "prepuseras": "prepor",
    "prepuserdes": "prepor",
    "prepuserem": "prepor",
    "prepuseres": "prepor",
    "prepusermos": "prepor",
    "prepusesse": "prepor",
    "prepusessem": "prepor",
    "prepusesses": "prepor",
    "prepuseste": "prepor",
    "prepusestes": "prepor",
    "prepuséramo": "prepor",
    "prepuséramos": "prepor",
    "prepusérei": "prepor",
    "prepuséreis": "prepor",
    "prepusésseis": "prepor",
    "prepuséssemos": "prepor",
    "prepósitos": "prepósito",
    "prepóstera": "prepóstero",
    "prepósteras": "prepóstero",
    "prepósteros": "prepóstero",
    "prepô": "prepor",
    "prepôs": "prepor",
    "prepõe": "prepor",
    "prepõem": "prepor",
    "prepões": "prepor",
    "prepúcios": "prepúcio",
    "prepúnhamo": "prepor",
    "prepúnhamos": "prepor",
    "prepúnhei": "prepor",
    "prepúnheis": "prepor",
    "prerrogativas": "prerrogativa",
    "prerrompa": "prerromper",
    "prerrompais": "prerromper",
    "prerrompam": "prerromper",
    "prerrompamo": "prerromper",
    "prerrompamos": "prerromper",
    "prerrompas": "prerromper",
    "prerrompe": "prerromper",
    "prerrompei": "prerromper",
    "prerrompeis": "prerromper",
    "prerrompem": "prerromper",
    "prerrompemo": "prerromper",
    "prerrompemos": "prerromper",
    "prerrompendo": "prerromper",
    "prerrompera": "prerromper",
    "prerromperam": "prerromper",
    "prerromperas": "prerromper",
    "prerromperde": "prerromper",
    "prerromperdes": "prerromper",
    "prerrompere": "prerromper",
    "prerromperei": "prerromper",
    "prerrompereis": "prerromper",
    "prerromperem": "prerromper",
    "prerromperemos": "prerromper",
    "prerromperes": "prerromper",
    "prerromperia": "prerromper",
    "prerromperiam": "prerromper",
    "prerromperias": "prerromper",
    "prerrompermo": "prerromper",
    "prerrompermos": "prerromper",
    "prerromperá": "prerromper",
    "prerromperás": "prerromper",
    "prerromperão": "prerromper",
    "prerromperíamos": "prerromper",
    "prerromperíeis": "prerromper",
    "prerrompes": "prerromper",
    "prerrompesse": "prerromper",
    "prerrompessem": "prerromper",
    "prerrompesses": "prerromper",
    "prerrompeste": "prerromper",
    "prerrompestes": "prerromper",
    "prerrompeu": "prerromper",
    "prerrompi": "prerromper",
    "prerrompia": "prerromper",
    "prerrompiam": "prerromper",
    "prerrompias": "prerromper",
    "prerrompida": "prerromper",
    "prerrompidas": "prerromper",
    "prerrompido": "prerromper",
    "prerrompidos": "prerromper",
    "prerrompo": "prerromper",
    "prerrompê": "prerromper",
    "prerrompêramo": "prerromper",
    "prerrompêramos": "prerromper",
    "prerrompêrei": "prerromper",
    "prerrompêreis": "prerromper",
    "prerrompêsseis": "prerromper",
    "prerrompêssemos": "prerromper",
    "prerrompíamo": "prerromper",
    "prerrompíamos": "prerromper",
    "prerrompíei": "prerromper",
    "prerrompíeis": "prerromper",
    "presa": "preso",
    "presada": "presar",
    "presadas": "presar",
    "presado": "presar",
    "presadora": "presador",
    "presadoras": "presador",
    "presadores": "presador",
    "presados": "presar",
    "presai": "presar",
    "presais": "presar",
    "presam": "presar",
    "presamo": "presar",
    "presamos": "presar",
    "presando": "presar",
    "presara": "presar",
    "presaram": "presar",
    "presaras": "presar",
    "presarde": "presar",
    "presardes": "presar",
    "presare": "presar",
    "presarei": "presar",
    "presareis": "presar",
    "presarem": "presar",
    "presaremos": "presar",
    "presares": "presar",
    "presaria": "presar",
    "presariam": "presar",
    "presarias": "presar",
    "presarmo": "presar",
    "presarmos": "presar",
    "presará": "presar",
    "presarás": "presar",
    "presarão": "presar",
    "presaríamos": "presar",
    "presaríeis": "presar",
    "presas": "preso",
    "presasse": "presar",
    "presassem": "presar",
    "presasses": "presar",
    "presaste": "presar",
    "presastes": "presar",
    "presava": "presar",
    "presavam": "presar",
    "presavas": "presar",
    "presbiacusias": "presbiacusia",
    "presbiacísica": "presbiacísico",
    "presbiacísicas": "presbiacísico",
    "presbiacísicos": "presbiacísico",
    "presbiofrenias": "presbiofrenia",
    "presbiofrénica": "presbiofrénico",
    "presbiofrénicas": "presbiofrénico",
    "presbiofrénicos": "presbiofrénico",
    "presbiopias": "presbiopia",
    "presbitas": "presbita",
    "presbiterados": "presbiterado",
    "presbiterais": "presbiteral",
    "presbiterana": "presbiterano",
    "presbiteranas": "presbiterano",
    "presbiteranismos": "presbiteranismo",
    "presbiteranistas": "presbiteranista",
    "presbiteranos": "presbiterano",
    "presbiteriana": "presbiteriano",
    "presbiterianas": "presbiteriano",
    "presbiterianos": "presbiteriano",
    "presbites": "presbite",
    "presbitias": "presbitia",
    "presbitismos": "presbitismo",
    "presbitérios": "presbitério",
    "presbíopes": "presbíope",
    "presbítera": "presbítero",
    "presbíteras": "presbítero",
    "presbíteros": "presbítero",
    "presbítica": "presbítico",
    "presbíticas": "presbítico",
    "presbíticos": "presbítico",
    "prescientes": "presciente",
    "prescinda": "prescindir",
    "prescindais": "prescindir",
    "prescindam": "prescindir",
    "prescindamo": "prescindir",
    "prescindamos": "prescindir",
    "prescindas": "prescindir",
    "prescinde": "prescindir",
    "prescindem": "prescindir",
    "prescindes": "prescindir",
    "prescindi": "prescindir",
    "prescindia": "prescindir",
    "prescindiam": "prescindir",
    "prescindias": "prescindir",
    "prescindida": "prescindir",
    "prescindidas": "prescindir",
    "prescindido": "prescindir",
    "prescindidos": "prescindir",
    "prescindimo": "prescindir",
    "prescindimos": "prescindir",
    "prescindindo": "prescindir",
    "prescindira": "prescindir",
    "prescindiram": "prescindir",
    "prescindiras": "prescindir",
    "prescindirdes": "prescindir",
    "prescindirei": "prescindir",
    "prescindireis": "prescindir",
    "prescindirem": "prescindir",
    "prescindiremos": "prescindir",
    "prescindires": "prescindir",
    "prescindiria": "prescindir",
    "prescindiriam": "prescindir",
    "prescindirias": "prescindir",
    "prescindirmo": "prescindir",
    "prescindirmos": "prescindir",
    "prescindirá": "prescindir",
    "prescindirás": "prescindir",
    "prescindirão": "prescindir",
    "prescindiríamos": "prescindir",
    "prescindiríeis": "prescindir",
    "prescindis": "prescindir",
    "prescindisse": "prescindir",
    "prescindissem": "prescindir",
    "prescindisses": "prescindir",
    "prescindiste": "prescindir",
    "prescindistes": "prescindir",
    "prescindiu": "prescindir",
    "prescindo": "prescindir",
    "prescindíamo": "prescindir",
    "prescindíamos": "prescindir",
    "prescindíeis": "prescindir",
    "prescindíramo": "prescindir",
    "prescindíramos": "prescindir",
    "prescindíreis": "prescindir",
    "prescindísseis": "prescindir",
    "prescindíssemos": "prescindir",
    "prescindíveis": "prescindível",
    "presciências": "presciência",
    "prescreva": "prescrever",
    "prescrevais": "prescrever",
    "prescrevam": "prescrever",
    "prescrevamo": "prescrever",
    "prescrevamos": "prescrever",
    "prescrevas": "prescrever",
    "prescreve": "prescrever",
    "prescrevei": "prescrever",
    "prescreveis": "prescrever",
    "prescrevem": "prescrever",
    "prescrevemo": "prescrever",
    "prescrevemos": "prescrever",
    "prescrevendo": "prescrever",
    "prescrevera": "prescrever",
    "prescreveram": "prescrever",
    "prescreveras": "prescrever",
    "prescreverde": "prescrever",
    "prescreverdes": "prescrever",
    "prescrevere": "prescrever",
    "prescreverei": "prescrever",
    "prescrevereis": "prescrever",
    "prescreverem": "prescrever",
    "prescreveremos": "prescrever",
    "prescreveres": "prescrever",
    "prescreveria": "prescrever",
    "prescreveriam": "prescrever",
    "prescreverias": "prescrever",
    "prescrevermo": "prescrever",
    "prescrevermos": "prescrever",
    "prescreverá": "prescrever",
    "prescreverás": "prescrever",
    "prescreverão": "prescrever",
    "prescreveríamos": "prescrever",
    "prescreveríeis": "prescrever",
    "prescreves": "prescrever",
    "prescrevesse": "prescrever",
    "prescrevessem": "prescrever",
    "prescrevesses": "prescrever",
    "prescreveste": "prescrever",
    "prescrevestes": "prescrever",
    "prescreveu": "prescrever",
    "prescrevi": "prescrever",
    "prescrevia": "prescrever",
    "prescreviam": "prescrever",
    "prescrevias": "prescrever",
    "prescrevo": "prescrever",
    "prescrevê": "prescrever",
    "prescrevêramo": "prescrever",
    "prescrevêramos": "prescrever",
    "prescrevêrei": "prescrever",
    "prescrevêreis": "prescrever",
    "prescrevêsseis": "prescrever",
    "prescrevêssemos": "prescrever",
    "prescrevíamo": "prescrever",
    "prescrevíamos": "prescrever",
    "prescrevíei": "prescrever",
    "prescrevíeis": "prescrever",
    "prescribentes": "prescribente",
    "prescrita": "prescrito",
    "prescritas": "prescrito",
    "prescritiva": "prescritivo",
    "prescritivas": "prescritivo",
    "prescritivos": "prescritivo",
    "prescrito": "prescrever",
    "prescritora": "prescritor",
    "prescritoras": "prescritor",
    "prescritores": "prescritor",
    "prescritos": "prescrito",
    "prescritíveis": "prescritível",
    "prescrições": "prescrição",
    "prese": "presar",
    "presei": "presar",
    "preseis": "presar",
    "presem": "presar",
    "presemo": "presar",
    "presemos": "presar",
    "presencia": "presenciar",
    "presenciada": "presenciar",
    "presenciadas": "presenciar",
    "presenciado": "presenciar",
    "presenciados": "presenciar",
    "presenciai": "presenciar",
    "presenciais": "presenciar",
    "presenciam": "presenciar",
    "presenciamo": "presenciar",
    "presenciamos": "presenciar",
    "presenciando": "presenciar",
    "presenciara": "presenciar",
    "presenciaram": "presenciar",
    "presenciaras": "presenciar",
    "presenciarde": "presenciar",
    "presenciardes": "presenciar",
    "presenciare": "presenciar",
    "presenciarei": "presenciar",
    "presenciareis": "presenciar",
    "presenciarem": "presenciar",
    "presenciaremos": "presenciar",
    "presenciares": "presenciar",
    "presenciaria": "presenciar",
    "presenciariam": "presenciar",
    "presenciarias": "presenciar",
    "presenciarmo": "presenciar",
    "presenciarmos": "presenciar",
    "presenciará": "presenciar",
    "presenciarás": "presenciar",
    "presenciarão": "presenciar",
    "presenciaríamos": "presenciar",
    "presenciaríeis": "presenciar",
    "presencias": "presenciar",
    "presenciasse": "presenciar",
    "presenciassem": "presenciar",
    "presenciasses": "presenciar",
    "presenciaste": "presenciar",
    "presenciastes": "presenciar",
    "presenciava": "presenciar",
    "presenciavam": "presenciar",
    "presenciavas": "presenciar",
    "presencie": "presenciar",
    "presenciei": "presenciar",
    "presencieis": "presenciar",
    "presenciem": "presenciar",
    "presenciemo": "presenciar",
    "presenciemos": "presenciar",
    "presencies": "presenciar",
    "presencio": "presenciar",
    "presenciou": "presenciar",
    "presenciá": "presenciar",
    "presenciámo": "presenciar",
    "presenciámos": "presenciar",
    "presenciáramo": "presenciar",
    "presenciáramos": "presenciar",
    "presenciárei": "presenciar",
    "presenciáreis": "presenciar",
    "presenciásseis": "presenciar",
    "presenciássemos": "presenciar",
    "presenciávamo": "presenciar",
    "presenciávamos": "presenciar",
    "presenciávei": "presenciar",
    "presenciáveis": "presenciar",
    "presenta": "presentar",
    "presentada": "presentar",
    "presentadas": "presentar",
    "presentado": "presentar",
    "presentados": "presentar",
    "presentai": "presentar",
    "presentais": "presentar",
    "presentam": "presentar",
    "presentamo": "presentar",
    "presentamos": "presentar",
    "presentando": "presentar",
    "presentara": "presentar",
    "presentaram": "presentar",
    "presentaras": "presentar",
    "presentarde": "presentar",
    "presentardes": "presentar",
    "presentare": "presentar",
    "presentarei": "presentar",
    "presentareis": "presentar",
    "presentarem": "presentar",
    "presentaremos": "presentar",
    "presentares": "presentar",
    "presentaria": "presentar",
    "presentariam": "presentar",
    "presentarias": "presentar",
    "presentarmo": "presentar",
    "presentarmos": "presentar",
    "presentará": "presentar",
    "presentarás": "presentar",
    "presentarão": "presentar",
    "presentaríamos": "presentar",
    "presentaríeis": "presentar",
    "presentas": "presentar",
    "presentasse": "presentar",
    "presentassem": "presentar",
    "presentasses": "presentar",
    "presentaste": "presentar",
    "presentastes": "presentar",
    "presentava": "presentar",
    "presentavam": "presentar",
    "presentavas": "presentar",
    "presentações": "presentação",
    "presente": "presentar",
    "presenteada": "presentear",
    "presenteadas": "presentear",
    "presenteado": "presentear",
    "presenteadora": "presenteador",
    "presenteadoras": "presenteador",
    "presenteadores": "presenteador",
    "presenteados": "presentear",
    "presenteai": "presentear",
    "presenteais": "presentear",
    "presenteamo": "presentear",
    "presenteamos": "presentear",
    "presenteando": "presentear",
    "presenteara": "presentear",
    "presentearam": "presentear",
    "presentearas": "presentear",
    "presentearde": "presentear",
    "presenteardes": "presentear",
    "presenteare": "presentear",
    "presentearei": "presentear",
    "presenteareis": "presentear",
    "presentearem": "presentear",
    "presentearemos": "presentear",
    "presenteares": "presentear",
    "presentearia": "presentear",
    "presenteariam": "presentear",
    "presentearias": "presentear",
    "presentearmo": "presentear",
    "presentearmos": "presentear",
    "presenteará": "presentear",
    "presentearás": "presentear",
    "presentearão": "presentear",
    "presentearíamos": "presentear",
    "presentearíeis": "presentear",
    "presenteasse": "presentear",
    "presenteassem": "presentear",
    "presenteasses": "presentear",
    "presenteaste": "presentear",
    "presenteastes": "presentear",
    "presenteava": "presentear",
    "presenteavam": "presentear",
    "presenteavas": "presentear",
    "presenteei": "presentear",
    "presenteeis": "presentear",
    "presenteemo": "presentear",
    "presenteemos": "presentear",
    "presentei": "presentar",
    "presenteia": "presentear",
    "presenteiam": "presentear",
    "presenteias": "presentear",
    "presenteie": "presentear",
    "presenteiem": "presentear",
    "presenteies": "presentear",
    "presenteio": "presentear",
    "presenteis": "presentar",
    "presentem": "presentar",
    "presentemo": "presentar",
    "presentemos": "presentar",
    "presenteou": "presentear",
    "presentes": "presente",
    "presenteá": "presentear",
    "presenteámo": "presentear",
    "presenteámos": "presentear",
    "presenteáramo": "presentear",
    "presenteáramos": "presentear",
    "presenteárei": "presentear",
    "presenteáreis": "presentear",
    "presenteásseis": "presentear",
    "presenteássemos": "presentear",
    "presenteávamo": "presentear",
    "presenteávamos": "presentear",
    "presenteávei": "presentear",
    "presenteáveis": "presentear",
    "presentinhos": "presentinho",
    "presento": "presentar",
    "presentou": "presentar",
    "presentá": "presentar",
    "presentámo": "presentar",
    "presentámos": "presentar",
    "presentáramo": "presentar",
    "presentáramos": "presentar",
    "presentárei": "presentar",
    "presentáreis": "presentar",
    "presentásseis": "presentar",
    "presentássemos": "presentar",
    "presentávamo": "presentar",
    "presentávamos": "presentar",
    "presentávei": "presentar",
    "presentáveis": "presentar",
    "presentânea": "presentâneo",
    "presentâneas": "presentâneo",
    "presentâneos": "presentâneo",
    "presenças": "presença",
    "presepes": "presepe",
    "preserva": "preservar",
    "preservada": "preservar",
    "preservadas": "preservar",
    "preservadinha": "preservado",
    "preservadinhas": "preservado",
    "preservadinho": "preservado",
    "preservadinhos": "preservado",
    "preservadita": "preservado",
    "preservaditas": "preservado",
    "preservadito": "preservado",
    "preservaditos": "preservado",
    "preservado": "preservar",
    "preservadora": "preservador",
    "preservadoras": "preservador",
    "preservadores": "preservador",
    "preservados": "preservar",
    "preservadíssima": "preservado",
    "preservadíssimas": "preservado",
    "preservadíssimo": "preservado",
    "preservadíssimos": "preservado",
    "preservai": "preservar",
    "preservais": "preservar",
    "preservam": "preservar",
    "preservamo": "preservar",
    "preservamos": "preservar",
    "preservando": "preservar",
    "preservara": "preservar",
    "preservaram": "preservar",
    "preservaras": "preservar",
    "preservarde": "preservar",
    "preservardes": "preservar",
    "preservare": "preservar",
    "preservarei": "preservar",
    "preservareis": "preservar",
    "preservarem": "preservar",
    "preservaremos": "preservar",
    "preservares": "preservar",
    "preservaria": "preservar",
    "preservariam": "preservar",
    "preservarias": "preservar",
    "preservarmo": "preservar",
    "preservarmos": "preservar",
    "preservará": "preservar",
    "preservarás": "preservar",
    "preservarão": "preservar",
    "preservaríamos": "preservar",
    "preservaríeis": "preservar",
    "preservas": "preservar",
    "preservasse": "preservar",
    "preservassem": "preservar",
    "preservasses": "preservar",
    "preservaste": "preservar",
    "preservastes": "preservar",
    "preservativa": "preservativo",
    "preservativas": "preservativo",
    "preservativos": "preservativo",
    "preservava": "preservar",
    "preservavam": "preservar",
    "preservavas": "preservar",
    "preservações": "preservação",
    "preserve": "preservar",
    "preservei": "preservar",
    "preserveis": "preservar",
    "preservem": "preservar",
    "preservemo": "preservar",
    "preservemos": "preservar",
    "preserves": "preservar",
    "preservo": "preservar",
    "preservou": "preservar",
    "preservá": "preservar",
    "preservámo": "preservar",
    "preservámos": "preservar",
    "preserváramo": "preservar",
    "preserváramos": "preservar",
    "preservárei": "preservar",
    "preserváreis": "preservar",
    "preservásseis": "preservar",
    "preservássemos": "preservar",
    "preservávamo": "preservar",
    "preservávamos": "preservar",
    "preservávei": "preservar",
    "preserváveis": "preservável",
    "preses": "presar",
    "presida": "presidir",
    "presidais": "presidir",
    "presidam": "presidir",
    "presidamo": "presidir",
    "presidamos": "presidir",
    "presidas": "presidir",
    "preside": "presidir",
    "presidem": "presidir",
    "presidenciais": "presidencial",
    "presidencialismos": "presidencialismo",
    "presidencialistas": "presidencialista",
    "presidenta": "presidente",
    "presidentas": "presidente",
    "presidentes": "presidente",
    "presides": "presidir",
    "presidi": "presidir",
    "presidia": "presidir",
    "presidiada": "presidiar",
    "presidiadas": "presidiar",
    "presidiado": "presidiar",
    "presidiados": "presidiar",
    "presidiai": "presidiar",
    "presidiais": "presidiar",
    "presidiam": "presidir",
    "presidiamo": "presidiar",
    "presidiamos": "presidiar",
    "presidiando": "presidiar",
    "presidiara": "presidiar",
    "presidiaram": "presidiar",
    "presidiaras": "presidiar",
    "presidiarde": "presidiar",
    "presidiardes": "presidiar",
    "presidiare": "presidiar",
    "presidiarei": "presidiar",
    "presidiareis": "presidiar",
    "presidiarem": "presidiar",
    "presidiaremos": "presidiar",
    "presidiares": "presidiar",
    "presidiaria": "presidiar",
    "presidiariam": "presidiar",
    "presidiarias": "presidiar",
    "presidiarmo": "presidiar",
    "presidiarmos": "presidiar",
    "presidiará": "presidiar",
    "presidiarás": "presidiar",
    "presidiarão": "presidiar",
    "presidiaríamos": "presidiar",
    "presidiaríeis": "presidiar",
    "presidias": "presidir",
    "presidiasse": "presidiar",
    "presidiassem": "presidiar",
    "presidiasses": "presidiar",
    "presidiaste": "presidiar",
    "presidiastes": "presidiar",
    "presidiava": "presidiar",
    "presidiavam": "presidiar",
    "presidiavas": "presidiar",
    "presidida": "presidir",
    "presididas": "presidir",
    "presidido": "presidir",
    "presididos": "presidir",
    "presidie": "presidiar",
    "presidiei": "presidiar",
    "presidieis": "presidiar",
    "presidiem": "presidiar",
    "presidiemo": "presidiar",
    "presidiemos": "presidiar",
    "presidies": "presidiar",
    "presidimo": "presidir",
    "presidimos": "presidir",
    "presidindo": "presidir",
    "presidio": "presidiar",
    "presidiou": "presidiar",
    "presidira": "presidir",
    "presidiram": "presidir",
    "presidiras": "presidir",
    "presidirdes": "presidir",
    "presidirei": "presidir",
    "presidireis": "presidir",
    "presidirem": "presidir",
    "presidiremos": "presidir",
    "presidires": "presidir",
    "presidiria": "presidir",
    "presidiriam": "presidir",
    "presidirias": "presidir",
    "presidirmo": "presidir",
    "presidirmos": "presidir",
    "presidirá": "presidir",
    "presidirás": "presidir",
    "presidirão": "presidir",
    "presidiríamos": "presidir",
    "presidiríeis": "presidir",
    "presidis": "presidir",
    "presidisse": "presidir",
    "presidissem": "presidir",
    "presidisses": "presidir",
    "presidiste": "presidir",
    "presidistes": "presidir",
    "presidiu": "presidir",
    "presidiá": "presidiar",
    "presidiámo": "presidiar",
    "presidiámos": "presidiar",
    "presidiáramo": "presidiar",
    "presidiáramos": "presidiar",
    "presidiárei": "presidiar",
    "presidiáreis": "presidiar",
    "presidiária": "presidiário",
    "presidiárias": "presidiário",
    "presidiários": "presidiário",
    "presidiásseis": "presidiar",
    "presidiássemos": "presidiar",
    "presidiávamo": "presidiar",
    "presidiávamos": "presidiar",
    "presidiávei": "presidiar",
    "presidiáveis": "presidiar",
    "presido": "presidir",
    "presidências": "presidência",
    "presidíamo": "presidir",
    "presidíamos": "presidir",
    "presidíeis": "presidir",
    "presidíramo": "presidir",
    "presidíramos": "presidir",
    "presidíreis": "presidir",
    "presidísseis": "presidir",
    "presidíssemos": "presidir",
    "presiga": "presigar",
    "presigada": "presigar",
    "presigadas": "presigar",
    "presigado": "presigar",
    "presigados": "presigar",
    "presigai": "presigar",
    "presigais": "presigar",
    "presigam": "presigar",
    "presigamo": "presigar",
    "presigamos": "presigar",
    "presigando": "presigar",
    "presigangas": "presiganga",
    "presigara": "presigar",
    "presigaram": "presigar",
    "presigaras": "presigar",
    "presigarde": "presigar",
    "presigardes": "presigar",
    "presigare": "presigar",
    "presigarei": "presigar",
    "presigareis": "presigar",
    "presigarem": "presigar",
    "presigaremos": "presigar",
    "presigares": "presigar",
    "presigaria": "presigar",
    "presigariam": "presigar",
    "presigarias": "presigar",
    "presigarmo": "presigar",
    "presigarmos": "presigar",
    "presigará": "presigar",
    "presigarás": "presigar",
    "presigarão": "presigar",
    "presigaríamos": "presigar",
    "presigaríeis": "presigar",
    "presigas": "presigar",
    "presigasse": "presigar",
    "presigassem": "presigar",
    "presigasses": "presigar",
    "presigaste": "presigar",
    "presigastes": "presigar",
    "presigava": "presigar",
    "presigavam": "presigar",
    "presigavas": "presigar",
    "presigo": "presigar",
    "presigos": "presigo",
    "presigou": "presigar",
    "presigue": "presigar",
    "presiguei": "presigar",
    "presigueis": "presigar",
    "presiguem": "presigar",
    "presiguemo": "presigar",
    "presiguemos": "presigar",
    "presigues": "presigar",
    "presigá": "presigar",
    "presigámo": "presigar",
    "presigámos": "presigar",
    "presigáramo": "presigar",
    "presigáramos": "presigar",
    "presigárei": "presigar",
    "presigáreis": "presigar",
    "presigásseis": "presigar",
    "presigássemos": "presigar",
    "presigávamo": "presigar",
    "presigávamos": "presigar",
    "presigávei": "presigar",
    "presigáveis": "presigar",
    "presilhas": "presilha",
    "presilheira": "presilheiro",
    "presilheiras": "presilheiro",
    "presilheiros": "presilheiro",
    "preso": "presar",
    "presos": "preso",
    "presou": "presar",
    "pressaga": "pressago",
    "pressagas": "pressago",
    "pressagia": "pressagiar",
    "pressagiada": "pressagiar",
    "pressagiadas": "pressagiar",
    "pressagiado": "pressagiar",
    "pressagiados": "pressagiar",
    "pressagiai": "pressagiar",
    "pressagiais": "pressagiar",
    "pressagiam": "pressagiar",
    "pressagiamo": "pressagiar",
    "pressagiamos": "pressagiar",
    "pressagiando": "pressagiar",
    "pressagiara": "pressagiar",
    "pressagiaram": "pressagiar",
    "pressagiaras": "pressagiar",
    "pressagiarde": "pressagiar",
    "pressagiardes": "pressagiar",
    "pressagiare": "pressagiar",
    "pressagiarei": "pressagiar",
    "pressagiareis": "pressagiar",
    "pressagiarem": "pressagiar",
    "pressagiaremos": "pressagiar",
    "pressagiares": "pressagiar",
    "pressagiaria": "pressagiar",
    "pressagiariam": "pressagiar",
    "pressagiarias": "pressagiar",
    "pressagiarmo": "pressagiar",
    "pressagiarmos": "pressagiar",
    "pressagiará": "pressagiar",
    "pressagiarás": "pressagiar",
    "pressagiarão": "pressagiar",
    "pressagiaríamos": "pressagiar",
    "pressagiaríeis": "pressagiar",
    "pressagias": "pressagiar",
    "pressagiasse": "pressagiar",
    "pressagiassem": "pressagiar",
    "pressagiasses": "pressagiar",
    "pressagiaste": "pressagiar",
    "pressagiastes": "pressagiar",
    "pressagiava": "pressagiar",
    "pressagiavam": "pressagiar",
    "pressagiavas": "pressagiar",
    "pressagie": "pressagiar",
    "pressagiei": "pressagiar",
    "pressagieis": "pressagiar",
    "pressagiem": "pressagiar",
    "pressagiemo": "pressagiar",
    "pressagiemos": "pressagiar",
    "pressagies": "pressagiar",
    "pressagio": "pressagiar",
    "pressagiosa": "pressagioso",
    "pressagiosas": "pressagioso",
    "pressagiosos": "pressagioso",
    "pressagiou": "pressagiar",
    "pressagiá": "pressagiar",
    "pressagiámo": "pressagiar",
    "pressagiámos": "pressagiar",
    "pressagiáramo": "pressagiar",
    "pressagiáramos": "pressagiar",
    "pressagiárei": "pressagiar",
    "pressagiáreis": "pressagiar",
    "pressagiásseis": "pressagiar",
    "pressagiássemos": "pressagiar",
    "pressagiávamo": "pressagiar",
    "pressagiávamos": "pressagiar",
    "pressagiávei": "pressagiar",
    "pressagiáveis": "pressagiar",
    "pressagos": "pressago",
    "pressas": "pressa",
    "pressente": "pressentir",
    "pressentem": "pressentir",
    "pressentes": "pressentir",
    "pressenti": "pressentir",
    "pressentia": "pressentir",
    "pressentiam": "pressentir",
    "pressentias": "pressentir",
    "pressentida": "pressentir",
    "pressentidas": "pressentir",
    "pressentido": "pressentir",
    "pressentidos": "pressentir",
    "pressentimentos": "pressentimento",
    "pressentimo": "pressentir",
    "pressentimos": "pressentir",
    "pressentindo": "pressentir",
    "pressentira": "pressentir",
    "pressentiram": "pressentir",
    "pressentiras": "pressentir",
    "pressentirde": "pressentir",
    "pressentirdes": "pressentir",
    "pressentire": "pressentir",
    "pressentirei": "pressentir",
    "pressentireis": "pressentir",
    "pressentirem": "pressentir",
    "pressentiremos": "pressentir",
    "pressentires": "pressentir",
    "pressentiria": "pressentir",
    "pressentiriam": "pressentir",
    "pressentirias": "pressentir",
    "pressentirmo": "pressentir",
    "pressentirmos": "pressentir",
    "pressentirá": "pressentir",
    "pressentirás": "pressentir",
    "pressentirão": "pressentir",
    "pressentiríamos": "pressentir",
    "pressentiríeis": "pressentir",
    "pressentis": "pressentir",
    "pressentisse": "pressentir",
    "pressentissem": "pressentir",
    "pressentisses": "pressentir",
    "pressentiste": "pressentir",
    "pressentistes": "pressentir",
    "pressentiu": "pressentir",
    "pressentíamo": "pressentir",
    "pressentíamos": "pressentir",
    "pressentíei": "pressentir",
    "pressentíeis": "pressentir",
    "pressentíramo": "pressentir",
    "pressentíramos": "pressentir",
    "pressentírei": "pressentir",
    "pressentíreis": "pressentir",
    "pressentísseis": "pressentir",
    "pressentíssemos": "pressentir",
    "pressinta": "pressentir",
    "pressintais": "pressentir",
    "pressintam": "pressentir",
    "pressintamo": "pressentir",
    "pressintamos": "pressentir",
    "pressintas": "pressentir",
    "pressinto": "pressentir",
    "pressiona": "pressionar",
    "pressionada": "pressionar",
    "pressionadas": "pressionar",
    "pressionado": "pressionar",
    "pressionados": "pressionar",
    "pressionadíssima": "pressionado",
    "pressionadíssimas": "pressionado",
    "pressionadíssimo": "pressionado",
    "pressionadíssimos": "pressionado",
    "pressionai": "pressionar",
    "pressionais": "pressionar",
    "pressionam": "pressionar",
    "pressionamo": "pressionar",
    "pressionamos": "pressionar",
    "pressionando": "pressionar",
    "pressionantes": "pressionante",
    "pressionara": "pressionar",
    "pressionaram": "pressionar",
    "pressionaras": "pressionar",
    "pressionarde": "pressionar",
    "pressionardes": "pressionar",
    "pressionare": "pressionar",
    "pressionarei": "pressionar",
    "pressionareis": "pressionar",
    "pressionarem": "pressionar",
    "pressionaremos": "pressionar",
    "pressionares": "pressionar",
    "pressionaria": "pressionar",
    "pressionariam": "pressionar",
    "pressionarias": "pressionar",
    "pressionarmo": "pressionar",
    "pressionarmos": "pressionar",
    "pressionará": "pressionar",
    "pressionarás": "pressionar",
    "pressionarão": "pressionar",
    "pressionaríamos": "pressionar",
    "pressionaríeis": "pressionar",
    "pressionas": "pressionar",
    "pressionasse": "pressionar",
    "pressionassem": "pressionar",
    "pressionasses": "pressionar",
    "pressionaste": "pressionar",
    "pressionastes": "pressionar",
    "pressionava": "pressionar",
    "pressionavam": "pressionar",
    "pressionavas": "pressionar",
    "pressione": "pressionar",
    "pressionei": "pressionar",
    "pressioneis": "pressionar",
    "pressionem": "pressionar",
    "pressionemo": "pressionar",
    "pressionemos": "pressionar",
    "pressiones": "pressionar",
    "pressiono": "pressionar",
    "pressionou": "pressionar",
    "pressioná": "pressionar",
    "pressionámo": "pressionar",
    "pressionámos": "pressionar",
    "pressionáramo": "pressionar",
    "pressionáramos": "pressionar",
    "pressionárei": "pressionar",
    "pressionáreis": "pressionar",
    "pressionásseis": "pressionar",
    "pressionássemos": "pressionar",
    "pressionávamo": "pressionar",
    "pressionávamos": "pressionar",
    "pressionávei": "pressionar",
    "pressionáveis": "pressionável",
    "pressirrostra": "pressirrostro",
    "pressirrostras": "pressirrostro",
    "pressirrostros": "pressirrostro",
    "pressupomo": "pressupor",
    "pressupomos": "pressupor",
    "pressuponde": "pressupor",
    "pressupondes": "pressupor",
    "pressupondo": "pressupor",
    "pressuponha": "pressupor",
    "pressuponhais": "pressupor",
    "pressuponham": "pressupor",
    "pressuponhamo": "pressupor",
    "pressuponhamos": "pressupor",
    "pressuponhas": "pressupor",
    "pressuponho": "pressupor",
    "pressuporde": "pressupor",
    "pressupordes": "pressupor",
    "pressupore": "pressupor",
    "pressuporei": "pressupor",
    "pressuporeis": "pressupor",
    "pressuporem": "pressupor",
    "pressuporemos": "pressupor",
    "pressupores": "pressupor",
    "pressuporia": "pressupor",
    "pressuporiam": "pressupor",
    "pressuporias": "pressupor",
    "pressupormo": "pressupor",
    "pressupormos": "pressupor",
    "pressuporá": "pressupor",
    "pressuporás": "pressupor",
    "pressuporão": "pressupor",
    "pressuporíamos": "pressupor",
    "pressuporíeis": "pressupor",
    "pressuposições": "pressuposição",
    "pressuposta": "pressuposto",
    "pressupostas": "pressuposto",
    "pressuposto": "pressupor",
    "pressupostos": "pressuposto",
    "pressupunha": "pressupor",
    "pressupunham": "pressupor",
    "pressupunhas": "pressupor",
    "pressupus": "pressupor",
    "pressupusemo": "pressupor",
    "pressupusemos": "pressupor",
    "pressupuser": "pressupor",
    "pressupusera": "pressupor",
    "pressupuseram": "pressupor",
    "pressupuseras": "pressupor",
    "pressupuserdes": "pressupor",
    "pressupuserem": "pressupor",
    "pressupuseres": "pressupor",
    "pressupusermos": "pressupor",
    "pressupusesse": "pressupor",
    "pressupusessem": "pressupor",
    "pressupusesses": "pressupor",
    "pressupuseste": "pressupor",
    "pressupusestes": "pressupor",
    "pressupuséramo": "pressupor",
    "pressupuséramos": "pressupor",
    "pressupusérei": "pressupor",
    "pressupuséreis": "pressupor",
    "pressupusésseis": "pressupor",
    "pressupuséssemos": "pressupor",
    "pressupô": "pressupor",
    "pressupôs": "pressupor",
    "pressupõe": "pressupor",
    "pressupõem": "pressupor",
    "pressupões": "pressupor",
    "pressupúnhamo": "pressupor",
    "pressupúnhamos": "pressupor",
    "pressupúnhei": "pressupor",
    "pressupúnheis": "pressupor",
    "pressuriza": "pressurizar",
    "pressurizada": "pressurizar",
    "pressurizadas": "pressurizar",
    "pressurizado": "pressurizar",
    "pressurizados": "pressurizar",
    "pressurizai": "pressurizar",
    "pressurizais": "pressurizar",
    "pressurizam": "pressurizar",
    "pressurizamo": "pressurizar",
    "pressurizamos": "pressurizar",
    "pressurizando": "pressurizar",
    "pressurizara": "pressurizar",
    "pressurizaram": "pressurizar",
    "pressurizaras": "pressurizar",
    "pressurizarde": "pressurizar",
    "pressurizardes": "pressurizar",
    "pressurizare": "pressurizar",
    "pressurizarei": "pressurizar",
    "pressurizareis": "pressurizar",
    "pressurizarem": "pressurizar",
    "pressurizaremos": "pressurizar",
    "pressurizares": "pressurizar",
    "pressurizaria": "pressurizar",
    "pressurizariam": "pressurizar",
    "pressurizarias": "pressurizar",
    "pressurizarmo": "pressurizar",
    "pressurizarmos": "pressurizar",
    "pressurizará": "pressurizar",
    "pressurizarás": "pressurizar",
    "pressurizarão": "pressurizar",
    "pressurizaríamos": "pressurizar",
    "pressurizaríeis": "pressurizar",
    "pressurizas": "pressurizar",
    "pressurizasse": "pressurizar",
    "pressurizassem": "pressurizar",
    "pressurizasses": "pressurizar",
    "pressurizaste": "pressurizar",
    "pressurizastes": "pressurizar",
    "pressurizava": "pressurizar",
    "pressurizavam": "pressurizar",
    "pressurizavas": "pressurizar",
    "pressurize": "pressurizar",
    "pressurizei": "pressurizar",
    "pressurizeis": "pressurizar",
    "pressurizem": "pressurizar",
    "pressurizemo": "pressurizar",
    "pressurizemos": "pressurizar",
    "pressurizes": "pressurizar",
    "pressurizo": "pressurizar",
    "pressurizou": "pressurizar",
    "pressurizá": "pressurizar",
    "pressurizámo": "pressurizar",
    "pressurizámos": "pressurizar",
    "pressurizáramo": "pressurizar",
    "pressurizáramos": "pressurizar",
    "pressurizárei": "pressurizar",
    "pressurizáreis": "pressurizar",
    "pressurizásseis": "pressurizar",
    "pressurizássemos": "pressurizar",
    "pressurizávamo": "pressurizar",
    "pressurizávamos": "pressurizar",
    "pressurizávei": "pressurizar",
    "pressurizáveis": "pressurizar",
    "pressurosa": "pressuroso",
    "pressurosas": "pressuroso",
    "pressurosos": "pressuroso",
    "presságios": "presságio",
    "pressões": "pressão",
    "presta": "presto",
    "prestabilidades": "prestabilidade",
    "prestabilíssima": "prestável",
    "prestabilíssimas": "prestável",
    "prestabilíssimo": "prestável",
    "prestabilíssimos": "prestável",
    "prestada": "prestar",
    "prestadas": "prestar",
    "prestadia": "prestadio",
    "prestadias": "prestadio",
    "prestadios": "prestadio",
    "prestado": "prestar",
    "prestadora": "prestador",
    "prestadoras": "prestador",
    "prestadores": "prestador",
    "prestados": "prestar",
    "prestai": "prestar",
    "prestais": "prestar",
    "prestam": "prestar",
    "prestameira": "prestameiro",
    "prestameiras": "prestameiro",
    "prestameiros": "prestameiro",
    "prestamistas": "prestamista",
    "prestamo": "prestar",
    "prestamos": "prestar",
    "prestando": "prestar",
    "prestantes": "prestante",
    "prestanças": "prestança",
    "prestara": "prestar",
    "prestaram": "prestar",
    "prestaras": "prestar",
    "prestarde": "prestar",
    "prestardes": "prestar",
    "prestare": "prestar",
    "prestarei": "prestar",
    "prestareis": "prestar",
    "prestarem": "prestar",
    "prestaremos": "prestar",
    "prestares": "prestar",
    "prestaria": "prestar",
    "prestariam": "prestar",
    "prestarias": "prestar",
    "prestarmo": "prestar",
    "prestarmos": "prestar",
    "prestará": "prestar",
    "prestarás": "prestar",
    "prestarão": "prestar",
    "prestaríamos": "prestar",
    "prestaríeis": "prestar",
    "prestas": "presto",
    "prestasse": "prestar",
    "prestassem": "prestar",
    "prestasses": "prestar",
    "prestaste": "prestar",
    "prestastes": "prestar",
    "prestativa": "prestativo",
    "prestativas": "prestativo",
    "prestativos": "prestativo",
    "prestava": "prestar",
    "prestavam": "prestar",
    "prestavas": "prestar",
    "prestações": "prestação",
    "preste": "prestar",
    "prestei": "prestar",
    "presteis": "prestar",
    "prestem": "prestar",
    "prestemo": "prestar",
    "prestemos": "prestar",
    "prestes": "prestar",
    "prestezas": "presteza",
    "prestidigitadora": "prestidigitador",
    "prestidigitadoras": "prestidigitador",
    "prestidigitadores": "prestidigitador",
    "prestidigitações": "prestidigitação",
    "prestigia": "prestigiar",
    "prestigiada": "prestigiar",
    "prestigiadas": "prestigiar",
    "prestigiado": "prestigiar",
    "prestigiadora": "prestigiador",
    "prestigiadoras": "prestigiador",
    "prestigiadores": "prestigiador",
    "prestigiados": "prestigiar",
    "prestigiadíssima": "prestigiado",
    "prestigiadíssimas": "prestigiado",
    "prestigiadíssimo": "prestigiado",
    "prestigiadíssimos": "prestigiado",
    "prestigiai": "prestigiar",
    "prestigiais": "prestigiar",
    "prestigiam": "prestigiar",
    "prestigiamo": "prestigiar",
    "prestigiamos": "prestigiar",
    "prestigiando": "prestigiar",
    "prestigiantes": "prestigiante",
    "prestigiantíssima": "prestigiante",
    "prestigiantíssimas": "prestigiante",
    "prestigiantíssimo": "prestigiante",
    "prestigiantíssimos": "prestigiante",
    "prestigiara": "prestigiar",
    "prestigiaram": "prestigiar",
    "prestigiaras": "prestigiar",
    "prestigiarde": "prestigiar",
    "prestigiardes": "prestigiar",
    "prestigiare": "prestigiar",
    "prestigiarei": "prestigiar",
    "prestigiareis": "prestigiar",
    "prestigiarem": "prestigiar",
    "prestigiaremos": "prestigiar",
    "prestigiares": "prestigiar",
    "prestigiaria": "prestigiar",
    "prestigiariam": "prestigiar",
    "prestigiarias": "prestigiar",
    "prestigiarmo": "prestigiar",
    "prestigiarmos": "prestigiar",
    "prestigiará": "prestigiar",
    "prestigiarás": "prestigiar",
    "prestigiarão": "prestigiar",
    "prestigiaríamos": "prestigiar",
    "prestigiaríeis": "prestigiar",
    "prestigias": "prestigiar",
    "prestigiasse": "prestigiar",
    "prestigiassem": "prestigiar",
    "prestigiasses": "prestigiar",
    "prestigiaste": "prestigiar",
    "prestigiastes": "prestigiar",
    "prestigiava": "prestigiar",
    "prestigiavam": "prestigiar",
    "prestigiavas": "prestigiar",
    "prestigiações": "prestigiação",
    "prestigie": "prestigiar",
    "prestigiei": "prestigiar",
    "prestigieis": "prestigiar",
    "prestigiem": "prestigiar",
    "prestigiemo": "prestigiar",
    "prestigiemos": "prestigiar",
    "prestigies": "prestigiar",
    "prestigio": "prestigiar",
    "prestigiosa": "prestigioso",
    "prestigiosas": "prestigioso",
    "prestigiosos": "prestigioso",
    "prestigiosíssima": "prestigioso",
    "prestigiosíssimas": "prestigioso",
    "prestigiosíssimo": "prestigioso",
    "prestigiosíssimos": "prestigioso",
    "prestigiou": "prestigiar",
    "prestigiá": "prestigiar",
    "prestigiámo": "prestigiar",
    "prestigiámos": "prestigiar",
    "prestigiáramo": "prestigiar",
    "prestigiáramos": "prestigiar",
    "prestigiárei": "prestigiar",
    "prestigiáreis": "prestigiar",
    "prestigiásseis": "prestigiar",
    "prestigiássemos": "prestigiar",
    "prestigiávamo": "prestigiar",
    "prestigiávamos": "prestigiar",
    "prestigiávei": "prestigiar",
    "prestigiáveis": "prestigiar",
    "prestimoniada": "prestimoniado",
    "prestimoniadas": "prestimoniado",
    "prestimoniados": "prestimoniado",
    "prestimoniais": "prestimonial",
    "prestimoniária": "prestimoniário",
    "prestimoniárias": "prestimoniário",
    "prestimoniários": "prestimoniário",
    "prestimosa": "prestimoso",
    "prestimosas": "prestimoso",
    "prestimosos": "prestimoso",
    "prestimónios": "prestimónio",
    "presto": "prestar",
    "prestos": "presto",
    "prestou": "prestar",
    "prestá": "prestar",
    "prestámo": "prestar",
    "prestámos": "prestar",
    "prestáramo": "prestar",
    "prestáramos": "prestar",
    "prestárei": "prestar",
    "prestáreis": "prestar",
    "prestásseis": "prestar",
    "prestássemos": "prestar",
    "prestávamo": "prestar",
    "prestávamos": "prestar",
    "prestávei": "prestar",
    "prestáveis": "prestável",
    "prestâncias": "prestância",
    "prestígios": "prestígio",
    "prestímana": "prestímano",
    "prestímanas": "prestímano",
    "prestímanos": "prestímano",
    "prestíssima": "presto",
    "prestíssimas": "presto",
    "prestíssimo": "presto",
    "prestíssimos": "presto",
    "presuma": "presumir",
    "presumada": "presumar",
    "presumadas": "presumar",
    "presumado": "presumar",
    "presumados": "presumar",
    "presumai": "presumar",
    "presumais": "presumir",
    "presumam": "presumir",
    "presumamo": "presumir",
    "presumamos": "presumir",
    "presumando": "presumar",
    "presumara": "presumar",
    "presumaram": "presumar",
    "presumaras": "presumar",
    "presumarde": "presumar",
    "presumardes": "presumar",
    "presumare": "presumar",
    "presumarei": "presumar",
    "presumareis": "presumar",
    "presumarem": "presumar",
    "presumaremos": "presumar",
    "presumares": "presumar",
    "presumaria": "presumar",
    "presumariam": "presumar",
    "presumarias": "presumar",
    "presumarmo": "presumar",
    "presumarmos": "presumar",
    "presumará": "presumar",
    "presumarás": "presumar",
    "presumarão": "presumar",
    "presumaríamos": "presumar",
    "presumaríeis": "presumar",
    "presumas": "presumir",
    "presumasse": "presumar",
    "presumassem": "presumar",
    "presumasses": "presumar",
    "presumaste": "presumar",
    "presumastes": "presumar",
    "presumava": "presumar",
    "presumavam": "presumar",
    "presumavas": "presumar",
    "presume": "presumir",
    "presumei": "presumar",
    "presumeis": "presumar",
    "presumem": "presumir",
    "presumemo": "presumar",
    "presumemos": "presumar",
    "presumes": "presumir",
    "presumi": "presumir",
    "presumia": "presumir",
    "presumiam": "presumir",
    "presumias": "presumir",
    "presumida": "presumir",
    "presumidas": "presumir",
    "presumido": "presumir",
    "presumidora": "presumidor",
    "presumidoras": "presumidor",
    "presumidores": "presumidor",
    "presumidos": "presumir",
    "presumimo": "presumir",
    "presumimos": "presumir",
    "presumindo": "presumir",
    "presumira": "presumir",
    "presumiram": "presumir",
    "presumiras": "presumir",
    "presumirde": "presumir",
    "presumirdes": "presumir",
    "presumire": "presumir",
    "presumirei": "presumir",
    "presumireis": "presumir",
    "presumirem": "presumir",
    "presumiremos": "presumir",
    "presumires": "presumir",
    "presumiria": "presumir",
    "presumiriam": "presumir",
    "presumirias": "presumir",
    "presumirmo": "presumir",
    "presumirmos": "presumir",
    "presumirá": "presumir",
    "presumirás": "presumir",
    "presumirão": "presumir",
    "presumiríamos": "presumir",
    "presumiríeis": "presumir",
    "presumis": "presumir",
    "presumisse": "presumir",
    "presumissem": "presumir",
    "presumisses": "presumir",
    "presumiste": "presumir",
    "presumistes": "presumir",
    "presumiu": "presumir",
    "presumo": "presumir",
    "presumou": "presumar",
    "presumá": "presumar",
    "presumámo": "presumar",
    "presumámos": "presumar",
    "presumáramo": "presumar",
    "presumáramos": "presumar",
    "presumárei": "presumar",
    "presumáreis": "presumar",
    "presumásseis": "presumar",
    "presumássemos": "presumar",
    "presumávamo": "presumar",
    "presumávamos": "presumar",
    "presumávei": "presumar",
    "presumáveis": "presumar",
    "presumíamo": "presumir",
    "presumíamos": "presumir",
    "presumíei": "presumir",
    "presumíeis": "presumir",
    "presumíramo": "presumir",
    "presumíramos": "presumir",
    "presumírei": "presumir",
    "presumíreis": "presumir",
    "presumísseis": "presumir",
    "presumíssemos": "presumir",
    "presumíveis": "presumível",
    "presunhos": "presunho",
    "presuntinho": "presunto",
    "presuntinhos": "presunto",
    "presuntito": "presunto",
    "presuntitos": "presunto",
    "presuntiva": "presuntivo",
    "presuntivas": "presuntivo",
    "presuntivos": "presuntivo",
    "presuntos": "presunto",
    "presuntuosa": "presuntuoso",
    "presuntuosas": "presuntuoso",
    "presuntuosos": "presuntuoso",
    "presunçosa": "presunçoso",
    "presunçosas": "presunçoso",
    "presunçosos": "presunçoso",
    "presunções": "presunção",
    "presá": "presar",
    "presámo": "presar",
    "presámos": "presar",
    "presáramo": "presar",
    "presáramos": "presar",
    "presárei": "presar",
    "presáreis": "presar",
    "presásseis": "presar",
    "presássemos": "presar",
    "presávamo": "presar",
    "presávamos": "presar",
    "presávei": "presar",
    "presáveis": "presar",
    "presépios": "presépio",
    "presídios": "presídio",
    "presúrias": "presúria",
    "preta": "preto",
    "pretalhadas": "pretalhada",
    "pretarias": "pretaria",
    "pretas": "preto",
    "pretazinha": "preto",
    "pretazinhas": "preto",
    "pretazita": "preto",
    "pretazitas": "preto",
    "pretenda": "pretender",
    "pretendais": "pretender",
    "pretendam": "pretender",
    "pretendamo": "pretender",
    "pretendamos": "pretender",
    "pretendas": "pretender",
    "pretende": "pretender",
    "pretendedora": "pretendedor",
    "pretendedoras": "pretendedor",
    "pretendedores": "pretendedor",
    "pretendei": "pretender",
    "pretendeis": "pretender",
    "pretendem": "pretender",
    "pretendemo": "pretender",
    "pretendemos": "pretender",
    "pretendendo": "pretender",
    "pretendentes": "pretendente",
    "pretendera": "pretender",
    "pretenderam": "pretender",
    "pretenderas": "pretender",
    "pretenderde": "pretender",
    "pretenderdes": "pretender",
    "pretendere": "pretender",
    "pretenderei": "pretender",
    "pretendereis": "pretender",
    "pretenderem": "pretender",
    "pretenderemos": "pretender",
    "pretenderes": "pretender",
    "pretenderia": "pretender",
    "pretenderiam": "pretender",
    "pretenderias": "pretender",
    "pretendermo": "pretender",
    "pretendermos": "pretender",
    "pretenderá": "pretender",
    "pretenderás": "pretender",
    "pretenderão": "pretender",
    "pretenderíamos": "pretender",
    "pretenderíeis": "pretender",
    "pretendes": "pretender",
    "pretendesse": "pretender",
    "pretendessem": "pretender",
    "pretendesses": "pretender",
    "pretendeste": "pretender",
    "pretendestes": "pretender",
    "pretendeu": "pretender",
    "pretendi": "pretender",
    "pretendia": "pretender",
    "pretendiam": "pretender",
    "pretendias": "pretender",
    "pretendida": "pretendido",
    "pretendidas": "pretendido",
    "pretendido": "pretender",
    "pretendidos": "pretendido",
    "pretendidíssima": "pretendido",
    "pretendidíssimas": "pretendido",
    "pretendidíssimo": "pretendido",
    "pretendidíssimos": "pretendido",
    "pretendo": "pretender",
    "pretendê": "pretender",
    "pretendêramo": "pretender",
    "pretendêramos": "pretender",
    "pretendêrei": "pretender",
    "pretendêreis": "pretender",
    "pretendêsseis": "pretender",
    "pretendêssemos": "pretender",
    "pretendíamo": "pretender",
    "pretendíamos": "pretender",
    "pretendíei": "pretender",
    "pretendíeis": "pretender",
    "pretensa": "pretenso",
    "pretensas": "pretenso",
    "pretensiosa": "pretensioso",
    "pretensiosas": "pretensioso",
    "pretensiosismos": "pretensiosismo",
    "pretensiosos": "pretensioso",
    "pretensora": "pretensor",
    "pretensoras": "pretensor",
    "pretensores": "pretensor",
    "pretensos": "pretenso",
    "pretensões": "pretensão",
    "pretere": "preterir",
    "preterem": "preterir",
    "preteres": "preterir",
    "preteri": "preterir",
    "preteria": "preterir",
    "preteriam": "preterir",
    "preterias": "preterir",
    "preterida": "preterir",
    "preteridas": "preterir",
    "preterido": "preterir",
    "preteridos": "preterir",
    "preterimo": "preterir",
    "preterimos": "preterir",
    "preterindo": "preterir",
    "preterira": "preterir",
    "preteriram": "preterir",
    "preteriras": "preterir",
    "preterirde": "preterir",
    "preterirdes": "preterir",
    "preterire": "preterir",
    "preterirei": "preterir",
    "preterireis": "preterir",
    "preterirem": "preterir",
    "preteriremos": "preterir",
    "preterires": "preterir",
    "preteriria": "preterir",
    "preteririam": "preterir",
    "preteririas": "preterir",
    "preterirmo": "preterir",
    "preterirmos": "preterir",
    "preterirá": "preterir",
    "preterirás": "preterir",
    "preterirão": "preterir",
    "preteriríamos": "preterir",
    "preteriríeis": "preterir",
    "preteris": "preterir",
    "preterisse": "preterir",
    "preterissem": "preterir",
    "preterisses": "preterir",
    "preteriste": "preterir",
    "preteristes": "preterir",
    "preteriu": "preterir",
    "preterições": "preterição",
    "pretermissões": "pretermissão",
    "pretermita": "pretermitir",
    "pretermitais": "pretermitir",
    "pretermitam": "pretermitir",
    "pretermitamo": "pretermitir",
    "pretermitamos": "pretermitir",
    "pretermitas": "pretermitir",
    "pretermite": "pretermitir",
    "pretermitem": "pretermitir",
    "pretermites": "pretermitir",
    "pretermiti": "pretermitir",
    "pretermitia": "pretermitir",
    "pretermitiam": "pretermitir",
    "pretermitias": "pretermitir",
    "pretermitida": "pretermitir",
    "pretermitidas": "pretermitir",
    "pretermitido": "pretermitir",
    "pretermitidos": "pretermitir",
    "pretermitimo": "pretermitir",
    "pretermitimos": "pretermitir",
    "pretermitindo": "pretermitir",
    "pretermitira": "pretermitir",
    "pretermitiram": "pretermitir",
    "pretermitiras": "pretermitir",
    "pretermitirde": "pretermitir",
    "pretermitirdes": "pretermitir",
    "pretermitire": "pretermitir",
    "pretermitirei": "pretermitir",
    "pretermitireis": "pretermitir",
    "pretermitirem": "pretermitir",
    "pretermitiremos": "pretermitir",
    "pretermitires": "pretermitir",
    "pretermitiria": "pretermitir",
    "pretermitiriam": "pretermitir",
    "pretermitirias": "pretermitir",
    "pretermitirmo": "pretermitir",
    "pretermitirmos": "pretermitir",
    "pretermitirá": "pretermitir",
    "pretermitirás": "pretermitir",
    "pretermitirão": "pretermitir",
    "pretermitiríamos": "pretermitir",
    "pretermitiríeis": "pretermitir",
    "pretermitis": "pretermitir",
    "pretermitisse": "pretermitir",
    "pretermitissem": "pretermitir",
    "pretermitisses": "pretermitir",
    "pretermitiste": "pretermitir",
    "pretermitistes": "pretermitir",
    "pretermitiu": "pretermitir",
    "pretermito": "pretermitir",
    "pretermitíamo": "pretermitir",
    "pretermitíamos": "pretermitir",
    "pretermitíei": "pretermitir",
    "pretermitíeis": "pretermitir",
    "pretermitíramo": "pretermitir",
    "pretermitíramos": "pretermitir",
    "pretermitírei": "pretermitir",
    "pretermitíreis": "pretermitir",
    "pretermitísseis": "pretermitir",
    "pretermitíssemos": "pretermitir",
    "preternaturais": "preternatural",
    "preterências": "preterência",
    "preteríamo": "preterir",
    "preteríamos": "preterir",
    "preteríei": "preterir",
    "preteríeis": "preterir",
    "preteríramo": "preterir",
    "preteríramos": "preterir",
    "preterírei": "preterir",
    "preteríreis": "preterir",
    "preterísseis": "preterir",
    "preteríssemos": "preterir",
    "preteríveis": "preterível",
    "pretexta": "pretextar",
    "pretextada": "pretextar",
    "pretextadas": "pretextar",
    "pretextado": "pretextar",
    "pretextados": "pretextar",
    "pretextai": "pretextar",
    "pretextais": "pretextar",
    "pretextam": "pretextar",
    "pretextamo": "pretextar",
    "pretextamos": "pretextar",
    "pretextando": "pretextar",
    "pretextara": "pretextar",
    "pretextaram": "pretextar",
    "pretextaras": "pretextar",
    "pretextarde": "pretextar",
    "pretextardes": "pretextar",
    "pretextare": "pretextar",
    "pretextarei": "pretextar",
    "pretextareis": "pretextar",
    "pretextarem": "pretextar",
    "pretextaremos": "pretextar",
    "pretextares": "pretextar",
    "pretextaria": "pretextar",
    "pretextariam": "pretextar",
    "pretextarias": "pretextar",
    "pretextarmo": "pretextar",
    "pretextarmos": "pretextar",
    "pretextará": "pretextar",
    "pretextarás": "pretextar",
    "pretextarão": "pretextar",
    "pretextaríamos": "pretextar",
    "pretextaríeis": "pretextar",
    "pretextas": "pretextar",
    "pretextasse": "pretextar",
    "pretextassem": "pretextar",
    "pretextasses": "pretextar",
    "pretextaste": "pretextar",
    "pretextastes": "pretextar",
    "pretextava": "pretextar",
    "pretextavam": "pretextar",
    "pretextavas": "pretextar",
    "pretexte": "pretextar",
    "pretextei": "pretextar",
    "pretexteis": "pretextar",
    "pretextem": "pretextar",
    "pretextemo": "pretextar",
    "pretextemos": "pretextar",
    "pretextes": "pretextar",
    "pretexto": "pretextar",
    "pretextos": "pretexto",
    "pretextou": "pretextar",
    "pretextá": "pretextar",
    "pretextámo": "pretextar",
    "pretextámos": "pretextar",
    "pretextáramo": "pretextar",
    "pretextáramos": "pretextar",
    "pretextárei": "pretextar",
    "pretextáreis": "pretextar",
    "pretextásseis": "pretextar",
    "pretextássemos": "pretextar",
    "pretextávamo": "pretextar",
    "pretextávamos": "pretextar",
    "pretextávei": "pretextar",
    "pretextáveis": "pretextar",
    "pretidões": "pretidão",
    "pretinha": "preto",
    "pretinhas": "preto",
    "pretinho": "preto",
    "pretinhos": "preto",
    "pretira": "preterir",
    "pretirais": "preterir",
    "pretiram": "preterir",
    "pretiramo": "preterir",
    "pretiramos": "preterir",
    "pretiras": "preterir",
    "pretiro": "preterir",
    "pretita": "preto",
    "pretitas": "preto",
    "pretito": "preto",
    "pretitos": "preto",
    "pretores": "pretor",
    "pretoriana": "pretoriano",
    "pretorianas": "pretoriano",
    "pretorianos": "pretoriano",
    "pretorias": "pretoria",
    "pretos": "preto",
    "pretozinho": "preto",
    "pretozinhos": "preto",
    "pretozito": "preto",
    "pretozitos": "preto",
    "pretérita": "pretérito",
    "pretéritas": "pretérito",
    "pretéritos": "pretérito",
    "pretíssima": "preto",
    "pretíssimas": "preto",
    "pretíssimo": "preto",
    "pretíssimos": "preto",
    "pretónica": "pretónico",
    "pretónicas": "pretónico",
    "pretónicos": "pretónico",
    "pretórios": "pretório",
    "prevalece": "prevalecer",
    "prevalecei": "prevalecer",
    "prevaleceis": "prevalecer",
    "prevalecem": "prevalecer",
    "prevalecemo": "prevalecer",
    "prevalecemos": "prevalecer",
    "prevalecendo": "prevalecer",
    "prevalecentes": "prevalecente",
    "prevalecera": "prevalecer",
    "prevaleceram": "prevalecer",
    "prevaleceras": "prevalecer",
    "prevalecerde": "prevalecer",
    "prevalecerdes": "prevalecer",
    "prevalecere": "prevalecer",
    "prevalecerei": "prevalecer",
    "prevalecereis": "prevalecer",
    "prevalecerem": "prevalecer",
    "prevaleceremos": "prevalecer",
    "prevaleceres": "prevalecer",
    "prevaleceria": "prevalecer",
    "prevaleceriam": "prevalecer",
    "prevalecerias": "prevalecer",
    "prevalecermo": "prevalecer",
    "prevalecermos": "prevalecer",
    "prevalecerá": "prevalecer",
    "prevalecerás": "prevalecer",
    "prevalecerão": "prevalecer",
    "prevaleceríamos": "prevalecer",
    "prevaleceríeis": "prevalecer",
    "prevaleces": "prevalecer",
    "prevalecesse": "prevalecer",
    "prevalecessem": "prevalecer",
    "prevalecesses": "prevalecer",
    "prevaleceste": "prevalecer",
    "prevalecestes": "prevalecer",
    "prevaleceu": "prevalecer",
    "prevaleci": "prevalecer",
    "prevalecia": "prevalecer",
    "prevaleciam": "prevalecer",
    "prevalecias": "prevalecer",
    "prevalecida": "prevalecer",
    "prevalecidas": "prevalecer",
    "prevalecido": "prevalecer",
    "prevalecidos": "prevalecer",
    "prevalecimentos": "prevalecimento",
    "prevalecê": "prevalecer",
    "prevalecêramo": "prevalecer",
    "prevalecêramos": "prevalecer",
    "prevalecêrei": "prevalecer",
    "prevalecêreis": "prevalecer",
    "prevalecêsseis": "prevalecer",
    "prevalecêssemos": "prevalecer",
    "prevalecíamo": "prevalecer",
    "prevalecíamos": "prevalecer",
    "prevalecíei": "prevalecer",
    "prevalecíeis": "prevalecer",
    "prevaleça": "prevalecer",
    "prevaleçais": "prevalecer",
    "prevaleçam": "prevalecer",
    "prevaleçamo": "prevalecer",
    "prevaleçamos": "prevalecer",
    "prevaleças": "prevalecer",
    "prevaleço": "prevalecer",
    "prevalências": "prevalência",
    "prevarica": "prevaricar",
    "prevaricada": "prevaricar",
    "prevaricadas": "prevaricar",
    "prevaricado": "prevaricar",
    "prevaricadora": "prevaricador",
    "prevaricadoras": "prevaricador",
    "prevaricadores": "prevaricador",
    "prevaricados": "prevaricar",
    "prevaricais": "prevaricar",
    "prevaricam": "prevaricar",
    "prevaricamo": "prevaricar",
    "prevaricamos": "prevaricar",
    "prevaricando": "prevaricar",
    "prevaricara": "prevaricar",
    "prevaricaram": "prevaricar",
    "prevaricaras": "prevaricar",
    "prevaricardes": "prevaricar",
    "prevaricarei": "prevaricar",
    "prevaricareis": "prevaricar",
    "prevaricarem": "prevaricar",
    "prevaricaremos": "prevaricar",
    "prevaricares": "prevaricar",
    "prevaricaria": "prevaricar",
    "prevaricariam": "prevaricar",
    "prevaricarias": "prevaricar",
    "prevaricarmo": "prevaricar",
    "prevaricarmos": "prevaricar",
    "prevaricará": "prevaricar",
    "prevaricarás": "prevaricar",
    "prevaricarão": "prevaricar",
    "prevaricaríamos": "prevaricar",
    "prevaricaríeis": "prevaricar",
    "prevaricas": "prevaricar",
    "prevaricasse": "prevaricar",
    "prevaricassem": "prevaricar",
    "prevaricasses": "prevaricar",
    "prevaricaste": "prevaricar",
    "prevaricastes": "prevaricar",
    "prevaricava": "prevaricar",
    "prevaricavam": "prevaricar",
    "prevaricavas": "prevaricar",
    "prevaricações": "prevaricação",
    "prevarico": "prevaricar",
    "prevaricou": "prevaricar",
    "prevaricámo": "prevaricar",
    "prevaricámos": "prevaricar",
    "prevaricáramo": "prevaricar",
    "prevaricáramos": "prevaricar",
    "prevaricáreis": "prevaricar",
    "prevaricásseis": "prevaricar",
    "prevaricássemos": "prevaricar",
    "prevaricávamo": "prevaricar",
    "prevaricávamos": "prevaricar",
    "prevaricáveis": "prevaricar",
    "prevarique": "prevaricar",
    "prevariquei": "prevaricar",
    "prevariqueis": "prevaricar",
    "prevariquem": "prevaricar",
    "prevariquemos": "prevaricar",
    "prevariques": "prevaricar",
    "prevede": "prever",
    "prevedes": "prever",
    "preveja": "prever",
    "prevejais": "prever",
    "prevejam": "prever",
    "prevejamo": "prever",
    "prevejamos": "prever",
    "prevejas": "prever",
    "prevejo": "prever",
    "prevemo": "prever",
    "prevemos": "prever",
    "prevendo": "prever",
    "preveni": "prevenir",
    "prevenia": "prevenir",
    "preveniam": "prevenir",
    "prevenias": "prevenir",
    "prevenida": "prevenir",
    "prevenidas": "prevenir",
    "prevenido": "prevenir",
    "prevenidos": "prevenir",
    "prevenientes": "preveniente",
    "prevenimo": "prevenir",
    "prevenimos": "prevenir",
    "prevenindo": "prevenir",
    "prevenira": "prevenir",
    "preveniram": "prevenir",
    "preveniras": "prevenir",
    "prevenirde": "prevenir",
    "prevenirdes": "prevenir",
    "prevenire": "prevenir",
    "prevenirei": "prevenir",
    "prevenireis": "prevenir",
    "prevenirem": "prevenir",
    "preveniremos": "prevenir",
    "prevenires": "prevenir",
    "preveniria": "prevenir",
    "preveniriam": "prevenir",
    "prevenirias": "prevenir",
    "prevenirmo": "prevenir",
    "prevenirmos": "prevenir",
    "prevenirá": "prevenir",
    "prevenirás": "prevenir",
    "prevenirão": "prevenir",
    "preveniríamos": "prevenir",
    "preveniríeis": "prevenir",
    "prevenis": "prevenir",
    "prevenisse": "prevenir",
    "prevenissem": "prevenir",
    "prevenisses": "prevenir",
    "preveniste": "prevenir",
    "prevenistes": "prevenir",
    "preveniu": "prevenir",
    "preventiva": "preventivo",
    "preventivas": "preventivo",
    "preventivos": "preventivo",
    "preventora": "preventor",
    "preventoras": "preventor",
    "preventores": "preventor",
    "preventórios": "preventório",
    "prevenções": "prevenção",
    "preveníamo": "prevenir",
    "preveníamos": "prevenir",
    "preveníei": "prevenir",
    "preveníeis": "prevenir",
    "preveníramo": "prevenir",
    "preveníramos": "prevenir",
    "prevenírei": "prevenir",
    "preveníreis": "prevenir",
    "prevenísseis": "prevenir",
    "preveníssemos": "prevenir",
    "preverde": "prever",
    "preverdes": "prever",
    "prevere": "prever",
    "preverei": "prever",
    "prevereis": "prever",
    "preverem": "prever",
    "preveremos": "prever",
    "preveres": "prever",
    "preveria": "prever",
    "preveriam": "prever",
    "preverias": "prever",
    "prevermo": "prever",
    "prevermos": "prever",
    "preverá": "prever",
    "preverás": "prever",
    "preverão": "prever",
    "preveríamos": "prever",
    "preveríeis": "prever",
    "previ": "prever",
    "previa": "prever",
    "previam": "prever",
    "previas": "prever",
    "previdentes": "previdente",
    "previdentíssima": "previdente",
    "previdentíssimas": "previdente",
    "previdentíssimo": "previdente",
    "previdentíssimos": "previdente",
    "previdências": "previdência",
    "previmo": "prever",
    "previmos": "prever",
    "previna": "prevenir",
    "previnais": "prevenir",
    "previnam": "prevenir",
    "previnamo": "prevenir",
    "previnamos": "prevenir",
    "previnas": "prevenir",
    "previne": "prevenir",
    "previnem": "prevenir",
    "prevines": "prevenir",
    "previno": "prevenir",
    "previr": "prever",
    "previra": "prever",
    "previram": "prever",
    "previras": "prever",
    "previrdes": "prever",
    "previrem": "prever",
    "previres": "prever",
    "previrmos": "prever",
    "previsibilidades": "previsibilidade",
    "previsse": "prever",
    "previssem": "prever",
    "previsses": "prever",
    "prevista": "previsto",
    "previstas": "previsto",
    "previste": "prever",
    "previstes": "prever",
    "previsto": "prever",
    "previstos": "previsto",
    "previsíveis": "previsível",
    "previsões": "previsão",
    "previu": "prever",
    "previva": "previver",
    "previvais": "previver",
    "previvam": "previver",
    "previvamo": "previver",
    "previvamos": "previver",
    "previvas": "previver",
    "previve": "previver",
    "previvei": "previver",
    "previveis": "previver",
    "previvem": "previver",
    "previvemo": "previver",
    "previvemos": "previver",
    "previvendo": "previver",
    "previvera": "previver",
    "previveram": "previver",
    "previveras": "previver",
    "previverdes": "previver",
    "previverei": "previver",
    "previvereis": "previver",
    "previverem": "previver",
    "previveremos": "previver",
    "previveres": "previver",
    "previveria": "previver",
    "previveriam": "previver",
    "previverias": "previver",
    "previvermo": "previver",
    "previvermos": "previver",
    "previverá": "previver",
    "previverás": "previver",
    "previverão": "previver",
    "previveríamos": "previver",
    "previveríeis": "previver",
    "previves": "previver",
    "previvesse": "previver",
    "previvessem": "previver",
    "previvesses": "previver",
    "previveste": "previver",
    "previvestes": "previver",
    "previveu": "previver",
    "previvi": "previver",
    "previvia": "previver",
    "previviam": "previver",
    "previvias": "previver",
    "previvida": "previver",
    "prevividas": "previver",
    "previvido": "previver",
    "prevividos": "previver",
    "previvo": "previver",
    "previvêramo": "previver",
    "previvêramos": "previver",
    "previvêreis": "previver",
    "previvêsseis": "previver",
    "previvêssemos": "previver",
    "previvíamo": "previver",
    "previvíamos": "previver",
    "previvíeis": "previver",
    "prevê": "prever",
    "prevêem": "prever",
    "prevês": "prever",
    "prevíamo": "prever",
    "prevíamos": "prever",
    "prevíei": "prever",
    "prevíeis": "prever",
    "prevíramo": "prever",
    "prevíramos": "prever",
    "prevírei": "prever",
    "prevíreis": "prever",
    "prevísseis": "prever",
    "prevíssemos": "prever",
    "preza": "prezar",
    "prezada": "prezar",
    "prezadas": "prezar",
    "prezado": "prezar",
    "prezadora": "prezador",
    "prezadoras": "prezador",
    "prezadores": "prezador",
    "prezados": "prezar",
    "prezadíssima": "prezado",
    "prezadíssimas": "prezado",
    "prezadíssimo": "prezado",
    "prezadíssimos": "prezado",
    "prezai": "prezar",
    "prezais": "prezar",
    "prezam": "prezar",
    "prezamo": "prezar",
    "prezamos": "prezar",
    "prezando": "prezar",
    "prezara": "prezar",
    "prezaram": "prezar",
    "prezaras": "prezar",
    "prezarde": "prezar",
    "prezardes": "prezar",
    "prezare": "prezar",
    "prezarei": "prezar",
    "prezareis": "prezar",
    "prezarem": "prezar",
    "prezaremos": "prezar",
    "prezares": "prezar",
    "prezaria": "prezar",
    "prezariam": "prezar",
    "prezarias": "prezar",
    "prezarmo": "prezar",
    "prezarmos": "prezar",
    "prezará": "prezar",
    "prezarás": "prezar",
    "prezarão": "prezar",
    "prezaríamos": "prezar",
    "prezaríeis": "prezar",
    "prezas": "prezar",
    "prezasse": "prezar",
    "prezassem": "prezar",
    "prezasses": "prezar",
    "prezaste": "prezar",
    "prezastes": "prezar",
    "prezava": "prezar",
    "prezavam": "prezar",
    "prezavas": "prezar",
    "preze": "prezar",
    "prezei": "prezar",
    "prezeis": "prezar",
    "prezem": "prezar",
    "prezemo": "prezar",
    "prezemos": "prezar",
    "prezes": "prezar",
    "prezo": "prezar",
    "prezou": "prezar",
    "prezá": "prezar",
    "prezámo": "prezar",
    "prezámos": "prezar",
    "prezáramo": "prezar",
    "prezáramos": "prezar",
    "prezárei": "prezar",
    "prezáreis": "prezar",
    "prezásseis": "prezar",
    "prezássemos": "prezar",
    "prezávamo": "prezar",
    "prezávamos": "prezar",
    "prezávei": "prezar",
    "prezáveis": "prezável",
    "preá": "prear",
    "preámo": "prear",
    "preámos": "prear",
    "preáramo": "prear",
    "preáramos": "prear",
    "preárei": "prear",
    "preáreis": "prear",
    "preásseis": "prear",
    "preássemos": "prear",
    "preávamo": "prear",
    "preávamos": "prear",
    "preávei": "prear",
    "preáveis": "prear",
    "preâmbulos": "preâmbulo",
    "preços": "preço",
    "preçários": "preçário",
    "preênsis": "preênsil",
    "priabonianos": "priaboniano",
    "priapismos": "priapismo",
    "prima": "primo",
    "primaciais": "primacial",
    "primada": "primar",
    "primadas": "primar",
    "primado": "primar",
    "primados": "primar",
    "primagens": "primagem",
    "primai": "primar",
    "primais": "primar",
    "primam": "primar",
    "primamo": "primar",
    "primamos": "primar",
    "primando": "primar",
    "primara": "primar",
    "primaram": "primar",
    "primaras": "primar",
    "primardes": "primar",
    "primarei": "primar",
    "primareis": "primar",
    "primarem": "primar",
    "primaremos": "primar",
    "primares": "primar",
    "primaria": "primar",
    "primariam": "primar",
    "primarias": "primar",
    "primarismos": "primarismo",
    "primarmo": "primar",
    "primarmos": "primar",
    "primará": "primar",
    "primarás": "primar",
    "primarão": "primar",
    "primaríamos": "primar",
    "primaríeis": "primar",
    "primas": "primo",
    "primasse": "primar",
    "primassem": "primar",
    "primasses": "primar",
    "primaste": "primar",
    "primastes": "primar",
    "primatas": "primata",
    "primates": "primate",
    "primatologias": "primatologia",
    "primatologistas": "primatologista",
    "primatológica": "primatológico",
    "primatológicas": "primatológico",
    "primatológicos": "primatológico",
    "primatóloga": "primatólogo",
    "primatólogas": "primatólogo",
    "primatólogos": "primatólogo",
    "primava": "primar",
    "primavam": "primar",
    "primavas": "primar",
    "primavera": "primaverar",
    "primaverada": "primaverar",
    "primaveradas": "primaverar",
    "primaverado": "primaverar",
    "primaverados": "primaverar",
    "primaverai": "primaverar",
    "primaverais": "primaverar",
    "primaveram": "primaverar",
    "primaveramo": "primaverar",
    "primaveramos": "primaverar",
    "primaverando": "primaverar",
    "primaverara": "primaverar",
    "primaveraram": "primaverar",
    "primaveraras": "primaverar",
    "primaverardes": "primaverar",
    "primaverarei": "primaverar",
    "primaverareis": "primaverar",
    "primaverarem": "primaverar",
    "primaveraremos": "primaverar",
    "primaverares": "primaverar",
    "primaveraria": "primaverar",
    "primaverariam": "primaverar",
    "primaverarias": "primaverar",
    "primaverarmo": "primaverar",
    "primaverarmos": "primaverar",
    "primaverará": "primaverar",
    "primaverarás": "primaverar",
    "primaverarão": "primaverar",
    "primaveraríamos": "primaverar",
    "primaveraríeis": "primaverar",
    "primaveras": "primaverar",
    "primaverasse": "primaverar",
    "primaverassem": "primaverar",
    "primaverasses": "primaverar",
    "primaveraste": "primaverar",
    "primaverastes": "primaverar",
    "primaverava": "primaverar",
    "primaveravam": "primaverar",
    "primaveravas": "primaverar",
    "primavere": "primaverar",
    "primaverei": "primaverar",
    "primavereis": "primaverar",
    "primaverem": "primaverar",
    "primaveremo": "primaverar",
    "primaveremos": "primaverar",
    "primaveres": "primaverar",
    "primaveris": "primaveril",
    "primavero": "primaverar",
    "primaverou": "primaverar",
    "primaverámo": "primaverar",
    "primaverámos": "primaverar",
    "primaveráramo": "primaverar",
    "primaveráramos": "primaverar",
    "primaveráreis": "primaverar",
    "primaverásseis": "primaverar",
    "primaverássemos": "primaverar",
    "primaverávamo": "primaverar",
    "primaverávamos": "primaverar",
    "primaveráveis": "primaverar",
    "primazes": "primaz",
    "primazias": "primazia",
    "prime": "primar",
    "primei": "primar",
    "primeira": "primeiro",
    "primeiranistas": "primeiranista",
    "primeiras": "primeiro",
    "primeirinha": "primeiro",
    "primeirinhas": "primeiro",
    "primeirinho": "primeiro",
    "primeirinhos": "primeiro",
    "primeirita": "primeiro",
    "primeiritas": "primeiro",
    "primeirito": "primeiro",
    "primeiritos": "primeiro",
    "primeiros": "primeiro",
    "primeiríssima": "primeiro",
    "primeiríssimas": "primeiro",
    "primeiríssimo": "primeiro",
    "primeiríssimos": "primeiro",
    "primeis": "primar",
    "primem": "primar",
    "primemo": "primar",
    "primemos": "primar",
    "primes": "primar",
    "primeva": "primevo",
    "primevas": "primevo",
    "primevos": "primevo",
    "primicéria": "primicério",
    "primicérias": "primicério",
    "primicérios": "primicério",
    "primigénia": "primigénio",
    "primigénias": "primigénio",
    "primigénios": "primigénio",
    "priminas": "primina",
    "priminha": "primo",
    "priminhas": "primo",
    "priminho": "primo",
    "priminhos": "primo",
    "primiparidades": "primiparidade",
    "primita": "primo",
    "primitas": "primo",
    "primitiva": "primitivo",
    "primitivada": "primitivar",
    "primitivadas": "primitivar",
    "primitivado": "primitivar",
    "primitivados": "primitivar",
    "primitivai": "primitivar",
    "primitivais": "primitivar",
    "primitivam": "primitivar",
    "primitivamo": "primitivar",
    "primitivamos": "primitivar",
    "primitivando": "primitivar",
    "primitivara": "primitivar",
    "primitivaram": "primitivar",
    "primitivaras": "primitivar",
    "primitivarde": "primitivar",
    "primitivardes": "primitivar",
    "primitivare": "primitivar",
    "primitivarei": "primitivar",
    "primitivareis": "primitivar",
    "primitivarem": "primitivar",
    "primitivaremos": "primitivar",
    "primitivares": "primitivar",
    "primitivaria": "primitivar",
    "primitivariam": "primitivar",
    "primitivarias": "primitivar",
    "primitivarmo": "primitivar",
    "primitivarmos": "primitivar",
    "primitivará": "primitivar",
    "primitivarás": "primitivar",
    "primitivarão": "primitivar",
    "primitivaríamos": "primitivar",
    "primitivaríeis": "primitivar",
    "primitivas": "primitivo",
    "primitivasse": "primitivar",
    "primitivassem": "primitivar",
    "primitivasses": "primitivar",
    "primitivaste": "primitivar",
    "primitivastes": "primitivar",
    "primitivava": "primitivar",
    "primitivavam": "primitivar",
    "primitivavas": "primitivar",
    "primitive": "primitivar",
    "primitivei": "primitivar",
    "primitiveis": "primitivar",
    "primitivem": "primitivar",
    "primitivemo": "primitivar",
    "primitivemos": "primitivar",
    "primitives": "primitivar",
    "primitivismos": "primitivismo",
    "primitivo": "primitivar",
    "primitivos": "primitivo",
    "primitivou": "primitivar",
    "primitivá": "primitivar",
    "primitivámo": "primitivar",
    "primitivámos": "primitivar",
    "primitiváramo": "primitivar",
    "primitiváramos": "primitivar",
    "primitivárei": "primitivar",
    "primitiváreis": "primitivar",
    "primitivásseis": "primitivar",
    "primitivássemos": "primitivar",
    "primitivávamo": "primitivar",
    "primitivávamos": "primitivar",
    "primitivávei": "primitivar",
    "primitiváveis": "primitivar",
    "primitivíssima": "primitivo",
    "primitivíssimas": "primitivo",
    "primitivíssimo": "primitivo",
    "primitivíssimos": "primitivo",
    "primito": "primo",
    "primitos": "primo",
    "primo": "primar",
    "primogenitora": "primogenitor",
    "primogenitoras": "primogenitor",
    "primogenitores": "primogenitor",
    "primogenituras": "primogenitura",
    "primogénita": "primogénito",
    "primogénitas": "primogénito",
    "primogénitos": "primogénito",
    "primomoventes": "primomovente",
    "primordiais": "primordial",
    "primores": "primor",
    "primorosa": "primoroso",
    "primorosas": "primoroso",
    "primorosos": "primoroso",
    "primorosíssima": "primoroso",
    "primorosíssimas": "primoroso",
    "primorosíssimo": "primoroso",
    "primorosíssimos": "primoroso",
    "primos": "primo",
    "primou": "primar",
    "primuláceas": "primulácea",
    "primámo": "primar",
    "primámos": "primar",
    "primáramo": "primar",
    "primáramos": "primar",
    "primáreis": "primar",
    "primária": "primário",
    "primárias": "primário",
    "primários": "primário",
    "primásseis": "primar",
    "primássemos": "primar",
    "primávamo": "primar",
    "primávamos": "primar",
    "primáveis": "primar",
    "primícias": "primícia",
    "primígena": "primígeno",
    "primígenas": "primígeno",
    "primígenos": "primígeno",
    "primíparas": "primípara",
    "primórdios": "primórdio",
    "princesa": "príncipe",
    "princesas": "príncipe",
    "princesazinha": "príncipe",
    "princesazinhas": "príncipe",
    "princesazita": "príncipe",
    "princesazitas": "príncipe",
    "princesinha": "príncipe",
    "princesinhas": "príncipe",
    "princesita": "príncipe",
    "princesitas": "príncipe",
    "principados": "principado",
    "principais": "principal",
    "principalidades": "principalidade",
    "principelha": "principelho",
    "principelhas": "principelho",
    "principelhos": "principelho",
    "principesca": "principesco",
    "principescas": "principesco",
    "principescos": "principesco",
    "principezinho": "príncipe",
    "principezinhos": "príncipe",
    "principezito": "príncipe",
    "principezitos": "príncipe",
    "principia": "principiar",
    "principiada": "principiar",
    "principiadas": "principiar",
    "principiado": "principiar",
    "principiadora": "principiador",
    "principiadoras": "principiador",
    "principiadores": "principiador",
    "principiados": "principiar",
    "principiai": "principiar",
    "principiais": "principiar",
    "principiam": "principiar",
    "principiamo": "principiar",
    "principiamos": "principiar",
    "principiando": "principiar",
    "principiantes": "principiante",
    "principiara": "principiar",
    "principiaram": "principiar",
    "principiaras": "principiar",
    "principiarde": "principiar",
    "principiardes": "principiar",
    "principiare": "principiar",
    "principiarei": "principiar",
    "principiareis": "principiar",
    "principiarem": "principiar",
    "principiaremos": "principiar",
    "principiares": "principiar",
    "principiaria": "principiar",
    "principiariam": "principiar",
    "principiarias": "principiar",
    "principiarmo": "principiar",
    "principiarmos": "principiar",
    "principiará": "principiar",
    "principiarás": "principiar",
    "principiarão": "principiar",
    "principiaríamos": "principiar",
    "principiaríeis": "principiar",
    "principias": "principiar",
    "principiasse": "principiar",
    "principiassem": "principiar",
    "principiasses": "principiar",
    "principiaste": "principiar",
    "principiastes": "principiar",
    "principiava": "principiar",
    "principiavam": "principiar",
    "principiavas": "principiar",
    "principie": "principiar",
    "principiei": "principiar",
    "principieis": "principiar",
    "principiem": "principiar",
    "principiemo": "principiar",
    "principiemos": "principiar",
    "principies": "principiar",
    "principio": "principiar",
    "principiou": "principiar",
    "principiá": "principiar",
    "principiámo": "principiar",
    "principiámos": "principiar",
    "principiáramo": "principiar",
    "principiáramos": "principiar",
    "principiárei": "principiar",
    "principiáreis": "principiar",
    "principiásseis": "principiar",
    "principiássemos": "principiar",
    "principiávamo": "principiar",
    "principiávamos": "principiar",
    "principiávei": "principiar",
    "principiáveis": "principiar",
    "principículos": "principículo",
    "princípios": "princípio",
    "priora": "prior",
    "priorados": "priorado",
    "priorais": "prioral",
    "prioras": "prior",
    "prioratos": "priorato",
    "priores": "prior",
    "prioresa": "prior",
    "prioresas": "prior",
    "prioridades": "prioridade",
    "prioritária": "prioritário",
    "prioritárias": "prioritário",
    "prioritários": "prioritário",
    "priostes": "prioste",
    "prisca": "prisco",
    "priscas": "prisco",
    "priscilianismos": "priscilianismo",
    "priscilianistas": "priscilianista",
    "priscos": "prisco",
    "prisionais": "prisional",
    "prisioneira": "prisioneiro",
    "prisioneiras": "prisioneiro",
    "prisioneiros": "prisioneiro",
    "prismas": "prisma",
    "prismatizações": "prismatização",
    "prismatóides": "prismatóide",
    "prismática": "prismático",
    "prismáticas": "prismático",
    "prismáticos": "prismático",
    "prismóides": "prismóide",
    "pristiníssima": "prístino",
    "pristiníssimas": "prístino",
    "pristiníssimo": "prístino",
    "pristiníssimos": "prístino",
    "prisões": "prisão",
    "priva": "privar",
    "privacidades": "privacidade",
    "privada": "privar",
    "privadas": "privar",
    "privado": "privar",
    "privados": "privar",
    "privadíssima": "privado",
    "privadíssimas": "privado",
    "privadíssimo": "privado",
    "privadíssimos": "privado",
    "privai": "privar",
    "privais": "privar",
    "privam": "privar",
    "privamo": "privar",
    "privamos": "privar",
    "privando": "privar",
    "privanças": "privança",
    "privara": "privar",
    "privaram": "privar",
    "privaras": "privar",
    "privarde": "privar",
    "privardes": "privar",
    "privare": "privar",
    "privarei": "privar",
    "privareis": "privar",
    "privarem": "privar",
    "privaremos": "privar",
    "privares": "privar",
    "privaria": "privar",
    "privariam": "privar",
    "privarias": "privar",
    "privarmo": "privar",
    "privarmos": "privar",
    "privará": "privar",
    "privarás": "privar",
    "privarão": "privar",
    "privaríamos": "privar",
    "privaríeis": "privar",
    "privas": "privar",
    "privasse": "privar",
    "privassem": "privar",
    "privasses": "privar",
    "privaste": "privar",
    "privastes": "privar",
    "privativa": "privativo",
    "privativas": "privativo",
    "privativos": "privativo",
    "privatiza": "privatizar",
    "privatizada": "privatizar",
    "privatizadas": "privatizar",
    "privatizado": "privatizar",
    "privatizadora": "privatizador",
    "privatizadoras": "privatizador",
    "privatizadores": "privatizador",
    "privatizados": "privatizar",
    "privatizai": "privatizar",
    "privatizais": "privatizar",
    "privatizam": "privatizar",
    "privatizamo": "privatizar",
    "privatizamos": "privatizar",
    "privatizando": "privatizar",
    "privatizara": "privatizar",
    "privatizaram": "privatizar",
    "privatizaras": "privatizar",
    "privatizarde": "privatizar",
    "privatizardes": "privatizar",
    "privatizare": "privatizar",
    "privatizarei": "privatizar",
    "privatizareis": "privatizar",
    "privatizarem": "privatizar",
    "privatizaremos": "privatizar",
    "privatizares": "privatizar",
    "privatizaria": "privatizar",
    "privatizariam": "privatizar",
    "privatizarias": "privatizar",
    "privatizarmo": "privatizar",
    "privatizarmos": "privatizar",
    "privatizará": "privatizar",
    "privatizarás": "privatizar",
    "privatizarão": "privatizar",
    "privatizaríamos": "privatizar",
    "privatizaríeis": "privatizar",
    "privatizas": "privatizar",
    "privatizasse": "privatizar",
    "privatizassem": "privatizar",
    "privatizasses": "privatizar",
    "privatizaste": "privatizar",
    "privatizastes": "privatizar",
    "privatizava": "privatizar",
    "privatizavam": "privatizar",
    "privatizavas": "privatizar",
    "privatizações": "privatização",
    "privatize": "privatizar",
    "privatizei": "privatizar",
    "privatizeis": "privatizar",
    "privatizem": "privatizar",
    "privatizemo": "privatizar",
    "privatizemos": "privatizar",
    "privatizes": "privatizar",
    "privatizo": "privatizar",
    "privatizou": "privatizar",
    "privatizá": "privatizar",
    "privatizámo": "privatizar",
    "privatizámos": "privatizar",
    "privatizáramo": "privatizar",
    "privatizáramos": "privatizar",
    "privatizárei": "privatizar",
    "privatizáreis": "privatizar",
    "privatizásseis": "privatizar",
    "privatizássemos": "privatizar",
    "privatizávamo": "privatizar",
    "privatizávamos": "privatizar",
    "privatizávei": "privatizar",
    "privatizáveis": "privatizar",
    "privava": "privar",
    "privavam": "privar",
    "privavas": "privar",
    "privações": "privação",
    "prive": "privar",
    "privei": "privar",
    "priveis": "privar",
    "privem": "privar",
    "privemo": "privar",
    "privemos": "privar",
    "prives": "privar",
    "privilegia": "privilegiar",
    "privilegiada": "privilegiar",
    "privilegiadas": "privilegiar",
    "privilegiadazinha": "privilegiado",
    "privilegiadazinhas": "privilegiado",
    "privilegiadazita": "privilegiado",
    "privilegiadazitas": "privilegiado",
    "privilegiadinha": "privilegiado",
    "privilegiadinhas": "privilegiado",
    "privilegiadinho": "privilegiado",
    "privilegiadinhos": "privilegiado",
    "privilegiadita": "privilegiado",
    "privilegiaditas": "privilegiado",
    "privilegiadito": "privilegiado",
    "privilegiaditos": "privilegiado",
    "privilegiado": "privilegiar",
    "privilegiados": "privilegiar",
    "privilegiadozinho": "privilegiado",
    "privilegiadozinhos": "privilegiado",
    "privilegiadozito": "privilegiado",
    "privilegiadozitos": "privilegiado",
    "privilegiadíssima": "privilegiado",
    "privilegiadíssimas": "privilegiado",
    "privilegiadíssimo": "privilegiado",
    "privilegiadíssimos": "privilegiado",
    "privilegiai": "privilegiar",
    "privilegiais": "privilegiar",
    "privilegiam": "privilegiar",
    "privilegiamo": "privilegiar",
    "privilegiamos": "privilegiar",
    "privilegiando": "privilegiar",
    "privilegiara": "privilegiar",
    "privilegiaram": "privilegiar",
    "privilegiaras": "privilegiar",
    "privilegiarde": "privilegiar",
    "privilegiardes": "privilegiar",
    "privilegiare": "privilegiar",
    "privilegiarei": "privilegiar",
    "privilegiareis": "privilegiar",
    "privilegiarem": "privilegiar",
    "privilegiaremos": "privilegiar",
    "privilegiares": "privilegiar",
    "privilegiaria": "privilegiar",
    "privilegiariam": "privilegiar",
    "privilegiarias": "privilegiar",
    "privilegiarmo": "privilegiar",
    "privilegiarmos": "privilegiar",
    "privilegiará": "privilegiar",
    "privilegiarás": "privilegiar",
    "privilegiarão": "privilegiar",
    "privilegiaríamos": "privilegiar",
    "privilegiaríeis": "privilegiar",
    "privilegias": "privilegiar",
    "privilegiasse": "privilegiar",
    "privilegiassem": "privilegiar",
    "privilegiasses": "privilegiar",
    "privilegiaste": "privilegiar",
    "privilegiastes": "privilegiar",
    "privilegiava": "privilegiar",
    "privilegiavam": "privilegiar",
    "privilegiavas": "privilegiar",
    "privilegie": "privilegiar",
    "privilegiei": "privilegiar",
    "privilegieis": "privilegiar",
    "privilegiem": "privilegiar",
    "privilegiemo": "privilegiar",
    "privilegiemos": "privilegiar",
    "privilegies": "privilegiar",
    "privilegio": "privilegiar",
    "privilegiou": "privilegiar",
    "privilegiá": "privilegiar",
    "privilegiámo": "privilegiar",
    "privilegiámos": "privilegiar",
    "privilegiáramo": "privilegiar",
    "privilegiáramos": "privilegiar",
    "privilegiárei": "privilegiar",
    "privilegiáreis": "privilegiar",
    "privilegiásseis": "privilegiar",
    "privilegiássemos": "privilegiar",
    "privilegiávamo": "privilegiar",
    "privilegiávamos": "privilegiar",
    "privilegiávei": "privilegiar",
    "privilegiáveis": "privilegiar",
    "privilégios": "privilégio",
    "privo": "privar",
    "privou": "privar",
    "privá": "privar",
    "privámo": "privar",
    "privámos": "privar",
    "priváramo": "privar",
    "priváramos": "privar",
    "privárei": "privar",
    "priváreis": "privar",
    "privásseis": "privar",
    "privássemos": "privar",
    "privávamo": "privar",
    "privávamos": "privar",
    "privávei": "privar",
    "priváveis": "privar",
    "priões": "prião",
    "proa": "proar",
    "proada": "proar",
    "proadas": "proar",
    "proado": "proar",
    "proados": "proar",
    "proai": "proar",
    "proais": "proar",
    "proam": "proar",
    "proamo": "proar",
    "proamos": "proar",
    "proando": "proar",
    "proara": "proar",
    "proaram": "proar",
    "proaras": "proar",
    "proardes": "proar",
    "proarei": "proar",
    "proareis": "proar",
    "proarem": "proar",
    "proaremos": "proar",
    "proares": "proar",
    "proaria": "proar",
    "proariam": "proar",
    "proarias": "proar",
    "proarmo": "proar",
    "proarmos": "proar",
    "proará": "proar",
    "proarás": "proar",
    "proarão": "proar",
    "proaríamos": "proar",
    "proaríeis": "proar",
    "proas": "proar",
    "proasse": "proar",
    "proassem": "proar",
    "proasses": "proar",
    "proaste": "proar",
    "proastes": "proar",
    "proava": "proar",
    "proavam": "proar",
    "proavas": "proar",
    "proba": "probo",
    "probabilidades": "probabilidade",
    "probabilismos": "probabilismo",
    "probabilistas": "probabilista",
    "probabilística": "probabilístico",
    "probabilísticas": "probabilístico",
    "probabilísticos": "probabilístico",
    "probantes": "probante",
    "probas": "probo",
    "probatória": "probatório",
    "probatórias": "probatório",
    "probatórios": "probatório",
    "probidades": "probidade",
    "problemas": "problema",
    "problematiza": "problematizar",
    "problematizada": "problematizar",
    "problematizadas": "problematizar",
    "problematizado": "problematizar",
    "problematizados": "problematizar",
    "problematizai": "problematizar",
    "problematizais": "problematizar",
    "problematizam": "problematizar",
    "problematizamo": "problematizar",
    "problematizamos": "problematizar",
    "problematizando": "problematizar",
    "problematizara": "problematizar",
    "problematizaram": "problematizar",
    "problematizaras": "problematizar",
    "problematizarde": "problematizar",
    "problematizardes": "problematizar",
    "problematizare": "problematizar",
    "problematizarei": "problematizar",
    "problematizareis": "problematizar",
    "problematizarem": "problematizar",
    "problematizaremos": "problematizar",
    "problematizares": "problematizar",
    "problematizaria": "problematizar",
    "problematizariam": "problematizar",
    "problematizarias": "problematizar",
    "problematizarmo": "problematizar",
    "problematizarmos": "problematizar",
    "problematizará": "problematizar",
    "problematizarás": "problematizar",
    "problematizarão": "problematizar",
    "problematizaríamos": "problematizar",
    "problematizaríeis": "problematizar",
    "problematizas": "problematizar",
    "problematizasse": "problematizar",
    "problematizassem": "problematizar",
    "problematizasses": "problematizar",
    "problematizaste": "problematizar",
    "problematizastes": "problematizar",
    "problematizava": "problematizar",
    "problematizavam": "problematizar",
    "problematizavas": "problematizar",
    "problematizações": "problematização",
    "problematize": "problematizar",
    "problematizei": "problematizar",
    "problematizeis": "problematizar",
    "problematizem": "problematizar",
    "problematizemo": "problematizar",
    "problematizemos": "problematizar",
    "problematizes": "problematizar",
    "problematizo": "problematizar",
    "problematizou": "problematizar",
    "problematizá": "problematizar",
    "problematizámo": "problematizar",
    "problematizámos": "problematizar",
    "problematizáramo": "problematizar",
    "problematizáramos": "problematizar",
    "problematizárei": "problematizar",
    "problematizáreis": "problematizar",
    "problematizásseis": "problematizar",
    "problematizássemos": "problematizar",
    "problematizávamo": "problematizar",
    "problematizávamos": "problematizar",
    "problematizávei": "problematizar",
    "problematizáveis": "problematizar",
    "probleminha": "problema",
    "probleminhas": "problema",
    "problemita": "problema",
    "problemitas": "problema",
    "problemática": "problemático",
    "problemáticas": "problemático",
    "problemáticos": "problemático",
    "probos": "probo",
    "proboscídea": "proboscídeo",
    "proboscídeas": "proboscídeo",
    "proboscídeos": "proboscídeo",
    "probóscida": "probóscide",
    "probóscidas": "probóscide",
    "probóscides": "probóscide",
    "procaces": "procace",
    "procacidades": "procacidade",
    "procazes": "procaz",
    "proceda": "proceder",
    "procedais": "proceder",
    "procedam": "proceder",
    "procedamo": "proceder",
    "procedamos": "proceder",
    "procedas": "proceder",
    "procede": "proceder",
    "procedei": "proceder",
    "procedeis": "proceder",
    "procedem": "proceder",
    "procedemo": "proceder",
    "procedemos": "proceder",
    "procedendo": "proceder",
    "procedentes": "procedente",
    "procedera": "proceder",
    "procederam": "proceder",
    "procederas": "proceder",
    "procederdes": "proceder",
    "procederei": "proceder",
    "procedereis": "proceder",
    "procederem": "proceder",
    "procederemos": "proceder",
    "procederes": "proceder",
    "procederia": "proceder",
    "procederiam": "proceder",
    "procederias": "proceder",
    "procedermo": "proceder",
    "procedermos": "proceder",
    "procederá": "proceder",
    "procederás": "proceder",
    "procederão": "proceder",
    "procederíamos": "proceder",
    "procederíeis": "proceder",
    "procedes": "proceder",
    "procedesse": "proceder",
    "procedessem": "proceder",
    "procedesses": "proceder",
    "procedeste": "proceder",
    "procedestes": "proceder",
    "procedeu": "proceder",
    "procedi": "proceder",
    "procedia": "proceder",
    "procediam": "proceder",
    "procedias": "proceder",
    "procedida": "procedido",
    "procedidas": "procedido",
    "procedido": "proceder",
    "procedidos": "procedido",
    "procedimentais": "procedimental",
    "procedimentos": "procedimento",
    "procedo": "proceder",
    "procedências": "procedência",
    "procedêramo": "proceder",
    "procedêramos": "proceder",
    "procedêreis": "proceder",
    "procedêsseis": "proceder",
    "procedêssemos": "proceder",
    "procedíamo": "proceder",
    "procedíamos": "proceder",
    "procedíeis": "proceder",
    "procelariformes": "procelariforme",
    "procelarídeos": "procelarídeo",
    "procelaríidas": "procelaríida",
    "procelas": "procela",
    "proceleusmática": "proceleusmático",
    "proceleusmáticas": "proceleusmático",
    "proceleusmáticos": "proceleusmático",
    "procelosa": "proceloso",
    "procelosas": "proceloso",
    "procelosos": "proceloso",
    "procelosíssima": "proceloso",
    "procelosíssimas": "proceloso",
    "procelosíssimo": "proceloso",
    "procelosíssimos": "proceloso",
    "procelárias": "procelária",
    "procera": "procero",
    "proceras": "procero",
    "proceridades": "proceridade",
    "proceros": "procero",
    "processa": "processar",
    "processabilidades": "processabilidade",
    "processada": "processar",
    "processadas": "processar",
    "processado": "processar",
    "processadores": "processador",
    "processados": "processar",
    "processai": "processar",
    "processais": "processar",
    "processam": "processar",
    "processamentos": "processamento",
    "processamo": "processar",
    "processamos": "processar",
    "processando": "processar",
    "processara": "processar",
    "processaram": "processar",
    "processaras": "processar",
    "processarde": "processar",
    "processardes": "processar",
    "processare": "processar",
    "processarei": "processar",
    "processareis": "processar",
    "processarem": "processar",
    "processaremos": "processar",
    "processares": "processar",
    "processaria": "processar",
    "processariam": "processar",
    "processarias": "processar",
    "processarmo": "processar",
    "processarmos": "processar",
    "processará": "processar",
    "processarás": "processar",
    "processarão": "processar",
    "processaríamos": "processar",
    "processaríeis": "processar",
    "processas": "processar",
    "processasse": "processar",
    "processassem": "processar",
    "processasses": "processar",
    "processaste": "processar",
    "processastes": "processar",
    "processava": "processar",
    "processavam": "processar",
    "processavas": "processar",
    "processe": "processar",
    "processei": "processar",
    "processeis": "processar",
    "processem": "processar",
    "processemo": "processar",
    "processemos": "processar",
    "processes": "processar",
    "processionais": "processional",
    "processionárias": "processionária",
    "processionários": "processionário",
    "processiva": "processivo",
    "processivas": "processivo",
    "processivos": "processivo",
    "processo": "processar",
    "processologias": "processologia",
    "processológica": "processológico",
    "processológicas": "processológico",
    "processológicos": "processológico",
    "processos": "processo",
    "processou": "processar",
    "processuais": "processual",
    "processá": "processar",
    "processámo": "processar",
    "processámos": "processar",
    "processáramo": "processar",
    "processáramos": "processar",
    "processárei": "processar",
    "processáreis": "processar",
    "processásseis": "processar",
    "processássemos": "processar",
    "processávamo": "processar",
    "processávamos": "processar",
    "processávei": "processar",
    "processáveis": "processável",
    "processões": "processão",
    "procidentes": "procidente",
    "procidências": "procidência",
    "procissões": "procissão",
    "proclama": "proclamar",
    "proclamada": "proclamar",
    "proclamadas": "proclamar",
    "proclamado": "proclamar",
    "proclamadora": "proclamador",
    "proclamadoras": "proclamador",
    "proclamadores": "proclamador",
    "proclamados": "proclamar",
    "proclamai": "proclamar",
    "proclamais": "proclamar",
    "proclamam": "proclamar",
    "proclamamo": "proclamar",
    "proclamamos": "proclamar",
    "proclamando": "proclamar",
    "proclamara": "proclamar",
    "proclamaram": "proclamar",
    "proclamaras": "proclamar",
    "proclamarde": "proclamar",
    "proclamardes": "proclamar",
    "proclamare": "proclamar",
    "proclamarei": "proclamar",
    "proclamareis": "proclamar",
    "proclamarem": "proclamar",
    "proclamaremos": "proclamar",
    "proclamares": "proclamar",
    "proclamaria": "proclamar",
    "proclamariam": "proclamar",
    "proclamarias": "proclamar",
    "proclamarmo": "proclamar",
    "proclamarmos": "proclamar",
    "proclamará": "proclamar",
    "proclamarás": "proclamar",
    "proclamarão": "proclamar",
    "proclamaríamos": "proclamar",
    "proclamaríeis": "proclamar",
    "proclamas": "proclamar",
    "proclamasse": "proclamar",
    "proclamassem": "proclamar",
    "proclamasses": "proclamar",
    "proclamaste": "proclamar",
    "proclamastes": "proclamar",
    "proclamatória": "proclamatório",
    "proclamatórias": "proclamatório",
    "proclamatórios": "proclamatório",
    "proclamava": "proclamar",
    "proclamavam": "proclamar",
    "proclamavas": "proclamar",
    "proclamações": "proclamação",
    "proclame": "proclamar",
    "proclamei": "proclamar",
    "proclameis": "proclamar",
    "proclamem": "proclamar",
    "proclamemo": "proclamar",
    "proclamemos": "proclamar",
    "proclames": "proclamar",
    "proclamo": "proclamar",
    "proclamou": "proclamar",
    "proclamá": "proclamar",
    "proclamámo": "proclamar",
    "proclamámos": "proclamar",
    "proclamáramo": "proclamar",
    "proclamáramos": "proclamar",
    "proclamárei": "proclamar",
    "proclamáreis": "proclamar",
    "proclamásseis": "proclamar",
    "proclamássemos": "proclamar",
    "proclamávamo": "proclamar",
    "proclamávamos": "proclamar",
    "proclamávei": "proclamar",
    "proclamáveis": "proclamar",
    "proclina": "proclinar",
    "proclinada": "proclinar",
    "proclinadas": "proclinar",
    "proclinado": "proclinar",
    "proclinados": "proclinar",
    "proclinai": "proclinar",
    "proclinais": "proclinar",
    "proclinam": "proclinar",
    "proclinamo": "proclinar",
    "proclinamos": "proclinar",
    "proclinando": "proclinar",
    "proclinara": "proclinar",
    "proclinaram": "proclinar",
    "proclinaras": "proclinar",
    "proclinarde": "proclinar",
    "proclinardes": "proclinar",
    "proclinare": "proclinar",
    "proclinarei": "proclinar",
    "proclinareis": "proclinar",
    "proclinarem": "proclinar",
    "proclinaremos": "proclinar",
    "proclinares": "proclinar",
    "proclinaria": "proclinar",
    "proclinariam": "proclinar",
    "proclinarias": "proclinar",
    "proclinarmo": "proclinar",
    "proclinarmos": "proclinar",
    "proclinará": "proclinar",
    "proclinarás": "proclinar",
    "proclinarão": "proclinar",
    "proclinaríamos": "proclinar",
    "proclinaríeis": "proclinar",
    "proclinas": "proclinar",
    "proclinasse": "proclinar",
    "proclinassem": "proclinar",
    "proclinasses": "proclinar",
    "proclinaste": "proclinar",
    "proclinastes": "proclinar",
    "proclinava": "proclinar",
    "proclinavam": "proclinar",
    "proclinavas": "proclinar",
    "procline": "proclinar",
    "proclinei": "proclinar",
    "proclineis": "proclinar",
    "proclinem": "proclinar",
    "proclinemo": "proclinar",
    "proclinemos": "proclinar",
    "proclines": "proclinar",
    "proclino": "proclinar",
    "proclinou": "proclinar",
    "procliná": "proclinar",
    "proclinámo": "proclinar",
    "proclinámos": "proclinar",
    "proclináramo": "proclinar",
    "proclináramos": "proclinar",
    "proclinárei": "proclinar",
    "proclináreis": "proclinar",
    "proclinásseis": "proclinar",
    "proclinássemos": "proclinar",
    "proclinávamo": "proclinar",
    "proclinávamos": "proclinar",
    "proclinávei": "proclinar",
    "proclináveis": "proclinar",
    "proclives": "proclive",
    "proclividades": "proclividade",
    "proclítica": "proclítico",
    "proclíticas": "proclítico",
    "proclíticos": "proclítico",
    "proconsulados": "proconsulado",
    "proconsulares": "proconsular",
    "proconsulesa": "procônsul",
    "proconsulesas": "procônsul",
    "procos": "proco",
    "procrastina": "procrastinar",
    "procrastinada": "procrastinar",
    "procrastinadas": "procrastinar",
    "procrastinado": "procrastinar",
    "procrastinadora": "procrastinador",
    "procrastinadoras": "procrastinador",
    "procrastinadores": "procrastinador",
    "procrastinados": "procrastinar",
    "procrastinai": "procrastinar",
    "procrastinais": "procrastinar",
    "procrastinam": "procrastinar",
    "procrastinamo": "procrastinar",
    "procrastinamos": "procrastinar",
    "procrastinando": "procrastinar",
    "procrastinara": "procrastinar",
    "procrastinaram": "procrastinar",
    "procrastinaras": "procrastinar",
    "procrastinarde": "procrastinar",
    "procrastinardes": "procrastinar",
    "procrastinare": "procrastinar",
    "procrastinarei": "procrastinar",
    "procrastinareis": "procrastinar",
    "procrastinarem": "procrastinar",
    "procrastinaremos": "procrastinar",
    "procrastinares": "procrastinar",
    "procrastinaria": "procrastinar",
    "procrastinariam": "procrastinar",
    "procrastinarias": "procrastinar",
    "procrastinarmo": "procrastinar",
    "procrastinarmos": "procrastinar",
    "procrastinará": "procrastinar",
    "procrastinarás": "procrastinar",
    "procrastinarão": "procrastinar",
    "procrastinaríamos": "procrastinar",
    "procrastinaríeis": "procrastinar",
    "procrastinas": "procrastinar",
    "procrastinasse": "procrastinar",
    "procrastinassem": "procrastinar",
    "procrastinasses": "procrastinar",
    "procrastinaste": "procrastinar",
    "procrastinastes": "procrastinar",
    "procrastinatória": "procrastinatório",
    "procrastinatórias": "procrastinatório",
    "procrastinatórios": "procrastinatório",
    "procrastinava": "procrastinar",
    "procrastinavam": "procrastinar",
    "procrastinavas": "procrastinar",
    "procrastinações": "procrastinação",
    "procrastine": "procrastinar",
    "procrastinei": "procrastinar",
    "procrastineis": "procrastinar",
    "procrastinem": "procrastinar",
    "procrastinemo": "procrastinar",
    "procrastinemos": "procrastinar",
    "procrastines": "procrastinar",
    "procrastino": "procrastinar",
    "procrastinou": "procrastinar",
    "procrastiná": "procrastinar",
    "procrastinámo": "procrastinar",
    "procrastinámos": "procrastinar",
    "procrastináramo": "procrastinar",
    "procrastináramos": "procrastinar",
    "procrastinárei": "procrastinar",
    "procrastináreis": "procrastinar",
    "procrastinásseis": "procrastinar",
    "procrastinássemos": "procrastinar",
    "procrastinávamo": "procrastinar",
    "procrastinávamos": "procrastinar",
    "procrastinávei": "procrastinar",
    "procrastináveis": "procrastinar",
    "procria": "procriar",
    "procriada": "procriar",
    "procriadas": "procriar",
    "procriado": "procriar",
    "procriadora": "procriador",
    "procriadoras": "procriador",
    "procriadores": "procriador",
    "procriados": "procriar",
    "procriai": "procriar",
    "procriais": "procriar",
    "procriam": "procriar",
    "procriamo": "procriar",
    "procriamos": "procriar",
    "procriando": "procriar",
    "procriara": "procriar",
    "procriaram": "procriar",
    "procriaras": "procriar",
    "procriarde": "procriar",
    "procriardes": "procriar",
    "procriare": "procriar",
    "procriarei": "procriar",
    "procriareis": "procriar",
    "procriarem": "procriar",
    "procriaremos": "procriar",
    "procriares": "procriar",
    "procriaria": "procriar",
    "procriariam": "procriar",
    "procriarias": "procriar",
    "procriarmo": "procriar",
    "procriarmos": "procriar",
    "procriará": "procriar",
    "procriarás": "procriar",
    "procriarão": "procriar",
    "procriaríamos": "procriar",
    "procriaríeis": "procriar",
    "procrias": "procriar",
    "procriasse": "procriar",
    "procriassem": "procriar",
    "procriasses": "procriar",
    "procriaste": "procriar",
    "procriastes": "procriar",
    "procriativa": "procriativo",
    "procriativas": "procriativo",
    "procriativos": "procriativo",
    "procriava": "procriar",
    "procriavam": "procriar",
    "procriavas": "procriar",
    "procriações": "procriação",
    "procrie": "procriar",
    "procriei": "procriar",
    "procrieis": "procriar",
    "procriem": "procriar",
    "procriemo": "procriar",
    "procriemos": "procriar",
    "procries": "procriar",
    "procrio": "procriar",
    "procriou": "procriar",
    "procriá": "procriar",
    "procriámo": "procriar",
    "procriámos": "procriar",
    "procriáramo": "procriar",
    "procriáramos": "procriar",
    "procriárei": "procriar",
    "procriáreis": "procriar",
    "procriásseis": "procriar",
    "procriássemos": "procriar",
    "procriávamo": "procriar",
    "procriávamos": "procriar",
    "procriávei": "procriar",
    "procriáveis": "procriar",
    "procronismos": "procronismo",
    "procrónica": "procrónico",
    "procrónicas": "procrónico",
    "procrónicos": "procrónico",
    "proctais": "proctal",
    "proctalgias": "proctalgia",
    "proctites": "proctite",
    "proctoceles": "proctocele",
    "proctocélica": "proctocélico",
    "proctocélicas": "proctocélico",
    "proctocélicos": "proctocélico",
    "proctoplastias": "proctoplastia",
    "proctoplástica": "proctoplástico",
    "proctoplásticas": "proctoplástico",
    "proctoplásticos": "proctoplástico",
    "proctoscopias": "proctoscopia",
    "proctoscópica": "proctoscópico",
    "proctoscópicas": "proctoscópico",
    "proctoscópicos": "proctoscópico",
    "proctoscópios": "proctoscópio",
    "proctotomias": "proctotomia",
    "proctotómica": "proctotómico",
    "proctotómicas": "proctotómico",
    "proctotómicos": "proctotómico",
    "proctálgica": "proctálgico",
    "proctálgicas": "proctálgico",
    "proctálgicos": "proctálgico",
    "proctítica": "proctítico",
    "proctíticas": "proctítico",
    "proctíticos": "proctítico",
    "proctótomos": "proctótomo",
    "procumba": "procumbir",
    "procumbais": "procumbir",
    "procumbam": "procumbir",
    "procumbamo": "procumbir",
    "procumbamos": "procumbir",
    "procumbas": "procumbir",
    "procumbe": "procumbir",
    "procumbem": "procumbir",
    "procumbes": "procumbir",
    "procumbi": "procumbir",
    "procumbia": "procumbir",
    "procumbiam": "procumbir",
    "procumbias": "procumbir",
    "procumbida": "procumbir",
    "procumbidas": "procumbir",
    "procumbido": "procumbir",
    "procumbidos": "procumbir",
    "procumbimo": "procumbir",
    "procumbimos": "procumbir",
    "procumbindo": "procumbir",
    "procumbira": "procumbir",
    "procumbiram": "procumbir",
    "procumbiras": "procumbir",
    "procumbirdes": "procumbir",
    "procumbirei": "procumbir",
    "procumbireis": "procumbir",
    "procumbirem": "procumbir",
    "procumbiremos": "procumbir",
    "procumbires": "procumbir",
    "procumbiria": "procumbir",
    "procumbiriam": "procumbir",
    "procumbirias": "procumbir",
    "procumbirmo": "procumbir",
    "procumbirmos": "procumbir",
    "procumbirá": "procumbir",
    "procumbirás": "procumbir",
    "procumbirão": "procumbir",
    "procumbiríamos": "procumbir",
    "procumbiríeis": "procumbir",
    "procumbis": "procumbir",
    "procumbisse": "procumbir",
    "procumbissem": "procumbir",
    "procumbisses": "procumbir",
    "procumbiste": "procumbir",
    "procumbistes": "procumbir",
    "procumbiu": "procumbir",
    "procumbo": "procumbir",
    "procumbíamo": "procumbir",
    "procumbíamos": "procumbir",
    "procumbíeis": "procumbir",
    "procumbíramo": "procumbir",
    "procumbíramos": "procumbir",
    "procumbíreis": "procumbir",
    "procumbísseis": "procumbir",
    "procumbíssemos": "procumbir",
    "procura": "procurar",
    "procurada": "procurar",
    "procuradas": "procurar",
    "procuradeira": "procurador",
    "procuradeiras": "procurador",
    "procurado": "procurar",
    "procuradora": "procurador",
    "procuradoras": "procurador",
    "procuradores": "procurador",
    "procuradorias": "procuradoria",
    "procurados": "procurar",
    "procuradíssima": "procurado",
    "procuradíssimas": "procurado",
    "procuradíssimo": "procurado",
    "procuradíssimos": "procurado",
    "procurai": "procurar",
    "procurais": "procurar",
    "procuram": "procurar",
    "procuramo": "procurar",
    "procuramos": "procurar",
    "procurando": "procurar",
    "procurara": "procurar",
    "procuraram": "procurar",
    "procuraras": "procurar",
    "procurarde": "procurar",
    "procurardes": "procurar",
    "procurare": "procurar",
    "procurarei": "procurar",
    "procurareis": "procurar",
    "procurarem": "procurar",
    "procuraremos": "procurar",
    "procurares": "procurar",
    "procuraria": "procurar",
    "procurariam": "procurar",
    "procurarias": "procurar",
    "procurarmo": "procurar",
    "procurarmos": "procurar",
    "procurará": "procurar",
    "procurarás": "procurar",
    "procurarão": "procurar",
    "procuraríamos": "procurar",
    "procuraríeis": "procurar",
    "procuras": "procurar",
    "procurasse": "procurar",
    "procurassem": "procurar",
    "procurasses": "procurar",
    "procuraste": "procurar",
    "procurastes": "procurar",
    "procuratorias": "procuratoria",
    "procuraturas": "procuratura",
    "procuratória": "procuratório",
    "procuratórias": "procuratório",
    "procuratórios": "procuratório",
    "procurava": "procurar",
    "procuravam": "procurar",
    "procuravas": "procurar",
    "procurações": "procuração",
    "procure": "procurar",
    "procurei": "procurar",
    "procureis": "procurar",
    "procurem": "procurar",
    "procuremo": "procurar",
    "procuremos": "procurar",
    "procures": "procurar",
    "procuro": "procurar",
    "procurou": "procurar",
    "procurá": "procurar",
    "procurámo": "procurar",
    "procurámos": "procurar",
    "procuráramo": "procurar",
    "procuráramos": "procurar",
    "procurárei": "procurar",
    "procuráreis": "procurar",
    "procurásseis": "procurar",
    "procurássemos": "procurar",
    "procurávamo": "procurar",
    "procurávamos": "procurar",
    "procurávei": "procurar",
    "procuráveis": "procurar",
    "procustiana": "procustiano",
    "procustianas": "procustiano",
    "procustianos": "procustiano",
    "procônsules": "procônsul",
    "procústea": "procústeo",
    "procústeas": "procústeo",
    "procústeos": "procústeo",
    "prodiagnósticos": "prodiagnóstico",
    "prodiga": "prodigar",
    "prodigada": "prodigar",
    "prodigadas": "prodigar",
    "prodigado": "prodigar",
    "prodigados": "prodigar",
    "prodigai": "prodigar",
    "prodigais": "prodigar",
    "prodigalidades": "prodigalidade",
    "prodigaliza": "prodigalizar",
    "prodigalizada": "prodigalizar",
    "prodigalizadas": "prodigalizar",
    "prodigalizado": "prodigalizar",
    "prodigalizadora": "prodigalizador",
    "prodigalizadoras": "prodigalizador",
    "prodigalizadores": "prodigalizador",
    "prodigalizados": "prodigalizar",
    "prodigalizai": "prodigalizar",
    "prodigalizais": "prodigalizar",
    "prodigalizam": "prodigalizar",
    "prodigalizamo": "prodigalizar",
    "prodigalizamos": "prodigalizar",
    "prodigalizando": "prodigalizar",
    "prodigalizara": "prodigalizar",
    "prodigalizaram": "prodigalizar",
    "prodigalizaras": "prodigalizar",
    "prodigalizarde": "prodigalizar",
    "prodigalizardes": "prodigalizar",
    "prodigalizare": "prodigalizar",
    "prodigalizarei": "prodigalizar",
    "prodigalizareis": "prodigalizar",
    "prodigalizarem": "prodigalizar",
    "prodigalizaremos": "prodigalizar",
    "prodigalizares": "prodigalizar",
    "prodigalizaria": "prodigalizar",
    "prodigalizariam": "prodigalizar",
    "prodigalizarias": "prodigalizar",
    "prodigalizarmo": "prodigalizar",
    "prodigalizarmos": "prodigalizar",
    "prodigalizará": "prodigalizar",
    "prodigalizarás": "prodigalizar",
    "prodigalizarão": "prodigalizar",
    "prodigalizaríamos": "prodigalizar",
    "prodigalizaríeis": "prodigalizar",
    "prodigalizas": "prodigalizar",
    "prodigalizasse": "prodigalizar",
    "prodigalizassem": "prodigalizar",
    "prodigalizasses": "prodigalizar",
    "prodigalizaste": "prodigalizar",
    "prodigalizastes": "prodigalizar",
    "prodigalizava": "prodigalizar",
    "prodigalizavam": "prodigalizar",
    "prodigalizavas": "prodigalizar",
    "prodigalize": "prodigalizar",
    "prodigalizei": "prodigalizar",
    "prodigalizeis": "prodigalizar",
    "prodigalizem": "prodigalizar",
    "prodigalizemo": "prodigalizar",
    "prodigalizemos": "prodigalizar",
    "prodigalizes": "prodigalizar",
    "prodigalizo": "prodigalizar",
    "prodigalizou": "prodigalizar",
    "prodigalizá": "prodigalizar",
    "prodigalizámo": "prodigalizar",
    "prodigalizámos": "prodigalizar",
    "prodigalizáramo": "prodigalizar",
    "prodigalizáramos": "prodigalizar",
    "prodigalizárei": "prodigalizar",
    "prodigalizáreis": "prodigalizar",
    "prodigalizásseis": "prodigalizar",
    "prodigalizássemos": "prodigalizar",
    "prodigalizávamo": "prodigalizar",
    "prodigalizávamos": "prodigalizar",
    "prodigalizávei": "prodigalizar",
    "prodigalizáveis": "prodigalizar",
    "prodigam": "prodigar",
    "prodigamo": "prodigar",
    "prodigamos": "prodigar",
    "prodigando": "prodigar",
    "prodigara": "prodigar",
    "prodigaram": "prodigar",
    "prodigaras": "prodigar",
    "prodigarde": "prodigar",
    "prodigardes": "prodigar",
    "prodigare": "prodigar",
    "prodigarei": "prodigar",
    "prodigareis": "prodigar",
    "prodigarem": "prodigar",
    "prodigaremos": "prodigar",
    "prodigares": "prodigar",
    "prodigaria": "prodigar",
    "prodigariam": "prodigar",
    "prodigarias": "prodigar",
    "prodigarmo": "prodigar",
    "prodigarmos": "prodigar",
    "prodigará": "prodigar",
    "prodigarás": "prodigar",
    "prodigarão": "prodigar",
    "prodigaríamos": "prodigar",
    "prodigaríeis": "prodigar",
    "prodigas": "prodigar",
    "prodigasse": "prodigar",
    "prodigassem": "prodigar",
    "prodigasses": "prodigar",
    "prodigaste": "prodigar",
    "prodigastes": "prodigar",
    "prodigava": "prodigar",
    "prodigavam": "prodigar",
    "prodigavas": "prodigar",
    "prodigiosa": "prodigioso",
    "prodigiosas": "prodigioso",
    "prodigiosos": "prodigioso",
    "prodigiosíssima": "prodigioso",
    "prodigiosíssimas": "prodigioso",
    "prodigiosíssimo": "prodigioso",
    "prodigiosíssimos": "prodigioso",
    "prodigo": "prodigar",
    "prodigou": "prodigar",
    "prodigue": "prodigar",
    "prodiguei": "prodigar",
    "prodigueis": "prodigar",
    "prodiguem": "prodigar",
    "prodiguemo": "prodigar",
    "prodiguemos": "prodigar",
    "prodigues": "prodigar",
    "prodigá": "prodigar",
    "prodigámo": "prodigar",
    "prodigámos": "prodigar",
    "prodigáramo": "prodigar",
    "prodigáramos": "prodigar",
    "prodigárei": "prodigar",
    "prodigáreis": "prodigar",
    "prodigásseis": "prodigar",
    "prodigássemos": "prodigar",
    "prodigávamo": "prodigar",
    "prodigávamos": "prodigar",
    "prodigávei": "prodigar",
    "prodigáveis": "prodigar",
    "proditora": "proditor",
    "proditoras": "proditor",
    "proditores": "proditor",
    "proditória": "proditório",
    "proditórias": "proditório",
    "proditórios": "proditório",
    "prodrómica": "prodrómico",
    "prodrómicas": "prodrómico",
    "prodrómicos": "prodrómico",
    "producentes": "producente",
    "produtibilidades": "produtibilidade",
    "produtiva": "produtivo",
    "produtivas": "produtivo",
    "produtividades": "produtividade",
    "produtivismos": "produtivismo",
    "produtivistas": "produtivista",
    "produtivos": "produtivo",
    "produtora": "produtor",
    "produtoras": "produtor",
    "produtores": "produtor",
    "produtos": "produto",
    "produtíveis": "produtível",
    "produz": "produzir",
    "produza": "produzir",
    "produzais": "produzir",
    "produzam": "produzir",
    "produzamo": "produzir",
    "produzamos": "produzir",
    "produzas": "produzir",
    "produze": "produzir",
    "produzem": "produzir",
    "produzes": "produzir",
    "produzi": "produzir",
    "produzia": "produzir",
    "produziam": "produzir",
    "produzias": "produzir",
    "produzida": "produzir",
    "produzidas": "produzir",
    "produzido": "produzir",
    "produzidora": "produzidor",
    "produzidoras": "produzidor",
    "produzidores": "produzidor",
    "produzidos": "produzir",
    "produzimo": "produzir",
    "produzimos": "produzir",
    "produzindo": "produzir",
    "produzira": "produzir",
    "produziram": "produzir",
    "produziras": "produzir",
    "produzirde": "produzir",
    "produzirdes": "produzir",
    "produzire": "produzir",
    "produzirei": "produzir",
    "produzireis": "produzir",
    "produzirem": "produzir",
    "produziremos": "produzir",
    "produzires": "produzir",
    "produziria": "produzir",
    "produziriam": "produzir",
    "produzirias": "produzir",
    "produzirmo": "produzir",
    "produzirmos": "produzir",
    "produzirá": "produzir",
    "produzirás": "produzir",
    "produzirão": "produzir",
    "produziríamos": "produzir",
    "produziríeis": "produzir",
    "produzis": "produzir",
    "produzisse": "produzir",
    "produzissem": "produzir",
    "produzisses": "produzir",
    "produziste": "produzir",
    "produzistes": "produzir",
    "produziu": "produzir",
    "produzo": "produzir",
    "produzíamo": "produzir",
    "produzíamos": "produzir",
    "produzíei": "produzir",
    "produzíeis": "produzir",
    "produzíramo": "produzir",
    "produzíramos": "produzir",
    "produzírei": "produzir",
    "produzíreis": "produzir",
    "produzísseis": "produzir",
    "produzíssemos": "produzir",
    "produzíveis": "produzível",
    "produções": "produção",
    "prodígia": "prodígio",
    "prodígias": "prodígio",
    "prodígios": "prodígio",
    "proe": "proar",
    "proecéfalos": "proecéfalo",
    "proei": "proar",
    "proeira": "proeiro",
    "proeiras": "proeiro",
    "proeiros": "proeiro",
    "proeis": "proar",
    "proeja": "proejar",
    "proejada": "proejar",
    "proejadas": "proejar",
    "proejado": "proejar",
    "proejados": "proejar",
    "proejai": "proejar",
    "proejais": "proejar",
    "proejam": "proejar",
    "proejamo": "proejar",
    "proejamos": "proejar",
    "proejando": "proejar",
    "proejara": "proejar",
    "proejaram": "proejar",
    "proejaras": "proejar",
    "proejarde": "proejar",
    "proejardes": "proejar",
    "proejare": "proejar",
    "proejarei": "proejar",
    "proejareis": "proejar",
    "proejarem": "proejar",
    "proejaremos": "proejar",
    "proejares": "proejar",
    "proejaria": "proejar",
    "proejariam": "proejar",
    "proejarias": "proejar",
    "proejarmo": "proejar",
    "proejarmos": "proejar",
    "proejará": "proejar",
    "proejarás": "proejar",
    "proejarão": "proejar",
    "proejaríamos": "proejar",
    "proejaríeis": "proejar",
    "proejas": "proejar",
    "proejasse": "proejar",
    "proejassem": "proejar",
    "proejasses": "proejar",
    "proejaste": "proejar",
    "proejastes": "proejar",
    "proejava": "proejar",
    "proejavam": "proejar",
    "proejavas": "proejar",
    "proeje": "proejar",
    "proejei": "proejar",
    "proejeis": "proejar",
    "proejem": "proejar",
    "proejemo": "proejar",
    "proejemos": "proejar",
    "proejes": "proejar",
    "proejo": "proejar",
    "proejou": "proejar",
    "proejá": "proejar",
    "proejámo": "proejar",
    "proejámos": "proejar",
    "proejáramo": "proejar",
    "proejáramos": "proejar",
    "proejárei": "proejar",
    "proejáreis": "proejar",
    "proejásseis": "proejar",
    "proejássemos": "proejar",
    "proejávamo": "proejar",
    "proejávamos": "proejar",
    "proejávei": "proejar",
    "proejáveis": "proejar",
    "proem": "proar",
    "proemia": "proemiar",
    "proemiada": "proemiar",
    "proemiadas": "proemiar",
    "proemiado": "proemiar",
    "proemiados": "proemiar",
    "proemiai": "proemiar",
    "proemiais": "proemiar",
    "proemiam": "proemiar",
    "proemiamo": "proemiar",
    "proemiamos": "proemiar",
    "proemiando": "proemiar",
    "proemiara": "proemiar",
    "proemiaram": "proemiar",
    "proemiaras": "proemiar",
    "proemiarde": "proemiar",
    "proemiardes": "proemiar",
    "proemiare": "proemiar",
    "proemiarei": "proemiar",
    "proemiareis": "proemiar",
    "proemiarem": "proemiar",
    "proemiaremos": "proemiar",
    "proemiares": "proemiar",
    "proemiaria": "proemiar",
    "proemiariam": "proemiar",
    "proemiarias": "proemiar",
    "proemiarmo": "proemiar",
    "proemiarmos": "proemiar",
    "proemiará": "proemiar",
    "proemiarás": "proemiar",
    "proemiarão": "proemiar",
    "proemiaríamos": "proemiar",
    "proemiaríeis": "proemiar",
    "proemias": "proemiar",
    "proemiasse": "proemiar",
    "proemiassem": "proemiar",
    "proemiasses": "proemiar",
    "proemiaste": "proemiar",
    "proemiastes": "proemiar",
    "proemiava": "proemiar",
    "proemiavam": "proemiar",
    "proemiavas": "proemiar",
    "proemie": "proemiar",
    "proemiei": "proemiar",
    "proemieis": "proemiar",
    "proemiem": "proemiar",
    "proemiemo": "proemiar",
    "proemiemos": "proemiar",
    "proemies": "proemiar",
    "proemina": "proeminar",
    "proeminada": "proeminar",
    "proeminadas": "proeminar",
    "proeminado": "proeminar",
    "proeminados": "proeminar",
    "proeminai": "proeminar",
    "proeminais": "proeminar",
    "proeminam": "proeminar",
    "proeminamo": "proeminar",
    "proeminamos": "proeminar",
    "proeminando": "proeminar",
    "proeminara": "proeminar",
    "proeminaram": "proeminar",
    "proeminaras": "proeminar",
    "proeminardes": "proeminar",
    "proeminarei": "proeminar",
    "proeminareis": "proeminar",
    "proeminarem": "proeminar",
    "proeminaremos": "proeminar",
    "proeminares": "proeminar",
    "proeminaria": "proeminar",
    "proeminariam": "proeminar",
    "proeminarias": "proeminar",
    "proeminarmo": "proeminar",
    "proeminarmos": "proeminar",
    "proeminará": "proeminar",
    "proeminarás": "proeminar",
    "proeminarão": "proeminar",
    "proeminaríamos": "proeminar",
    "proeminaríeis": "proeminar",
    "proeminas": "proeminar",
    "proeminasse": "proeminar",
    "proeminassem": "proeminar",
    "proeminasses": "proeminar",
    "proeminaste": "proeminar",
    "proeminastes": "proeminar",
    "proeminava": "proeminar",
    "proeminavam": "proeminar",
    "proeminavas": "proeminar",
    "proemine": "proeminar",
    "proeminei": "proeminar",
    "proemineis": "proeminar",
    "proeminem": "proeminar",
    "proeminemo": "proeminar",
    "proeminemos": "proeminar",
    "proeminentes": "proeminente",
    "proemines": "proeminar",
    "proemino": "proeminar",
    "proeminou": "proeminar",
    "proeminámo": "proeminar",
    "proeminámos": "proeminar",
    "proemináramo": "proeminar",
    "proemináramos": "proeminar",
    "proemináreis": "proeminar",
    "proeminásseis": "proeminar",
    "proeminássemos": "proeminar",
    "proeminávamo": "proeminar",
    "proeminávamos": "proeminar",
    "proemináveis": "proeminar",
    "proeminências": "proeminência",
    "proemio": "proemiar",
    "proemiou": "proemiar",
    "proemiá": "proemiar",
    "proemiámo": "proemiar",
    "proemiámos": "proemiar",
    "proemiáramo": "proemiar",
    "proemiáramos": "proemiar",
    "proemiárei": "proemiar",
    "proemiáreis": "proemiar",
    "proemiásseis": "proemiar",
    "proemiássemos": "proemiar",
    "proemiávamo": "proemiar",
    "proemiávamos": "proemiar",
    "proemiávei": "proemiar",
    "proemiáveis": "proemiar",
    "proemo": "proar",
    "proemos": "proar",
    "proencefalias": "proencefalia",
    "proencefálica": "proencefálico",
    "proencefálicas": "proencefálico",
    "proencefálicos": "proencefálico",
    "proenzimas": "proenzima",
    "proenzímica": "proenzímico",
    "proenzímicas": "proenzímico",
    "proenzímicos": "proenzímico",
    "proençais": "proençal",
    "proes": "proar",
    "proezas": "proeza",
    "profa": "prof",
    "profana": "profano",
    "profanada": "profanar",
    "profanadas": "profanar",
    "profanado": "profanar",
    "profanadora": "profanador",
    "profanadoras": "profanador",
    "profanadorazinha": "profanador",
    "profanadorazinhas": "profanador",
    "profanadorazita": "profanador",
    "profanadorazitas": "profanador",
    "profanadores": "profanador",
    "profanadorzinho": "profanador",
    "profanadorzinhos": "profanador",
    "profanadorzito": "profanador",
    "profanadorzitos": "profanador",
    "profanados": "profanar",
    "profanai": "profanar",
    "profanais": "profanar",
    "profanam": "profanar",
    "profanamo": "profanar",
    "profanamos": "profanar",
    "profanando": "profanar",
    "profanara": "profanar",
    "profanaram": "profanar",
    "profanaras": "profanar",
    "profanarde": "profanar",
    "profanardes": "profanar",
    "profanare": "profanar",
    "profanarei": "profanar",
    "profanareis": "profanar",
    "profanarem": "profanar",
    "profanaremos": "profanar",
    "profanares": "profanar",
    "profanaria": "profanar",
    "profanariam": "profanar",
    "profanarias": "profanar",
    "profanarmo": "profanar",
    "profanarmos": "profanar",
    "profanará": "profanar",
    "profanarás": "profanar",
    "profanarão": "profanar",
    "profanaríamos": "profanar",
    "profanaríeis": "profanar",
    "profanas": "profano",
    "profanasse": "profanar",
    "profanassem": "profanar",
    "profanasses": "profanar",
    "profanaste": "profanar",
    "profanastes": "profanar",
    "profanava": "profanar",
    "profanavam": "profanar",
    "profanavas": "profanar",
    "profanações": "profanação",
    "profane": "profanar",
    "profanei": "profanar",
    "profaneis": "profanar",
    "profanem": "profanar",
    "profanemo": "profanar",
    "profanemos": "profanar",
    "profanes": "profanar",
    "profanetes": "profanete",
    "profanidades": "profanidade",
    "profano": "profanar",
    "profanos": "profano",
    "profanou": "profanar",
    "profaná": "profanar",
    "profanámo": "profanar",
    "profanámos": "profanar",
    "profanáramo": "profanar",
    "profanáramos": "profanar",
    "profanárei": "profanar",
    "profanáreis": "profanar",
    "profanásseis": "profanar",
    "profanássemos": "profanar",
    "profanávamo": "profanar",
    "profanávamos": "profanar",
    "profanávei": "profanar",
    "profanáveis": "profanável",
    "profas": "prof",
    "profecias": "profecia",
    "profectícia": "profectício",
    "profectícias": "profectício",
    "profectícios": "profectício",
    "profera": "proferir",
    "proferais": "proferir",
    "proferam": "proferir",
    "proferamo": "proferir",
    "proferamos": "proferir",
    "proferas": "proferir",
    "profere": "proferir",
    "proferem": "proferir",
    "proferes": "proferir",
    "proferi": "proferir",
    "proferia": "proferir",
    "proferiam": "proferir",
    "proferias": "proferir",
    "proferida": "proferir",
    "proferidas": "proferir",
    "proferido": "proferir",
    "proferidos": "proferir",
    "proferimentos": "proferimento",
    "proferimo": "proferir",
    "proferimos": "proferir",
    "proferindo": "proferir",
    "proferira": "proferir",
    "proferiram": "proferir",
    "proferiras": "proferir",
    "proferirde": "proferir",
    "proferirdes": "proferir",
    "proferire": "proferir",
    "proferirei": "proferir",
    "proferireis": "proferir",
    "proferirem": "proferir",
    "proferiremos": "proferir",
    "proferires": "proferir",
    "proferiria": "proferir",
    "profeririam": "proferir",
    "proferirias": "proferir",
    "proferirmo": "proferir",
    "proferirmos": "proferir",
    "proferirá": "proferir",
    "proferirás": "proferir",
    "proferirão": "proferir",
    "proferiríamos": "proferir",
    "proferiríeis": "proferir",
    "proferis": "proferir",
    "proferisse": "proferir",
    "proferissem": "proferir",
    "proferisses": "proferir",
    "proferiste": "proferir",
    "proferistes": "proferir",
    "proferiu": "proferir",
    "proferições": "proferição",
    "profero": "proferir",
    "proferíamo": "proferir",
    "proferíamos": "proferir",
    "proferíei": "proferir",
    "proferíeis": "proferir",
    "proferíramo": "proferir",
    "proferíramos": "proferir",
    "proferírei": "proferir",
    "proferíreis": "proferir",
    "proferísseis": "proferir",
    "proferíssemos": "proferir",
    "professa": "professo",
    "professada": "professar",
    "professadas": "professar",
    "professado": "professar",
    "professados": "professar",
    "professai": "professar",
    "professais": "professar",
    "professam": "professar",
    "professamo": "professar",
    "professamos": "professar",
    "professando": "professar",
    "professantes": "professante",
    "professara": "professar",
    "professaram": "professar",
    "professaras": "professar",
    "professarde": "professar",
    "professardes": "professar",
    "professare": "professar",
    "professarei": "professar",
    "professareis": "professar",
    "professarem": "professar",
    "professaremos": "professar",
    "professares": "professar",
    "professaria": "professar",
    "professariam": "professar",
    "professarias": "professar",
    "professarmo": "professar",
    "professarmos": "professar",
    "professará": "professar",
    "professarás": "professar",
    "professarão": "professar",
    "professaríamos": "professar",
    "professaríeis": "professar",
    "professas": "professo",
    "professasse": "professar",
    "professassem": "professar",
    "professasses": "professar",
    "professaste": "professar",
    "professastes": "professar",
    "professava": "professar",
    "professavam": "professar",
    "professavas": "professar",
    "professe": "professar",
    "professei": "professar",
    "professeis": "professar",
    "professem": "professar",
    "professemo": "professar",
    "professemos": "professar",
    "professes": "professar",
    "professo": "professar",
    "professora": "professorar",
    "professorada": "professorar",
    "professoradas": "professorar",
    "professorado": "professorar",
    "professorados": "professorar",
    "professorai": "professorar",
    "professorais": "professorar",
    "professoram": "professorar",
    "professoramo": "professorar",
    "professoramos": "professorar",
    "professorando": "professorar",
    "professorara": "professorar",
    "professoraram": "professorar",
    "professoraras": "professorar",
    "professorardes": "professorar",
    "professorarei": "professorar",
    "professorareis": "professorar",
    "professorarem": "professorar",
    "professoraremos": "professorar",
    "professorares": "professorar",
    "professoraria": "professorar",
    "professorariam": "professorar",
    "professorarias": "professorar",
    "professorarmo": "professorar",
    "professorarmos": "professorar",
    "professorará": "professorar",
    "professorarás": "professorar",
    "professorarão": "professorar",
    "professoraríamos": "professorar",
    "professoraríeis": "professorar",
    "professoras": "professorar",
    "professorasse": "professorar",
    "professorassem": "professorar",
    "professorasses": "professorar",
    "professoraste": "professorar",
    "professorastes": "professorar",
    "professorava": "professorar",
    "professoravam": "professorar",
    "professoravas": "professorar",
    "professore": "professorar",
    "professorei": "professorar",
    "professoreis": "professorar",
    "professorem": "professorar",
    "professoremo": "professorar",
    "professoremos": "professorar",
    "professores": "professorar",
    "professoro": "professorar",
    "professorou": "professorar",
    "professorámo": "professorar",
    "professorámos": "professorar",
    "professoráramo": "professorar",
    "professoráramos": "professorar",
    "professoráreis": "professorar",
    "professorásseis": "professorar",
    "professorássemos": "professorar",
    "professorávamo": "professorar",
    "professorávamos": "professorar",
    "professoráveis": "professorar",
    "professos": "professo",
    "professou": "professar",
    "professá": "professar",
    "professámo": "professar",
    "professámos": "professar",
    "professáramo": "professar",
    "professáramos": "professar",
    "professárei": "professar",
    "professáreis": "professar",
    "professásseis": "professar",
    "professássemos": "professar",
    "professávamo": "professar",
    "professávamos": "professar",
    "professávei": "professar",
    "professáveis": "professar",
    "profetas": "profeta",
    "profetisa": "profeta",
    "profetisas": "profeta",
    "profetismos": "profetismo",
    "profetiza": "profetizar",
    "profetizada": "profetizar",
    "profetizadas": "profetizar",
    "profetizado": "profetizar",
    "profetizadora": "profetizador",
    "profetizadoras": "profetizador",
    "profetizadores": "profetizador",
    "profetizados": "profetizar",
    "profetizai": "profetizar",
    "profetizais": "profetizar",
    "profetizam": "profetizar",
    "profetizamo": "profetizar",
    "profetizamos": "profetizar",
    "profetizando": "profetizar",
    "profetizara": "profetizar",
    "profetizaram": "profetizar",
    "profetizaras": "profetizar",
    "profetizarde": "profetizar",
    "profetizardes": "profetizar",
    "profetizare": "profetizar",
    "profetizarei": "profetizar",
    "profetizareis": "profetizar",
    "profetizarem": "profetizar",
    "profetizaremos": "profetizar",
    "profetizares": "profetizar",
    "profetizaria": "profetizar",
    "profetizariam": "profetizar",
    "profetizarias": "profetizar",
    "profetizarmo": "profetizar",
    "profetizarmos": "profetizar",
    "profetizará": "profetizar",
    "profetizarás": "profetizar",
    "profetizarão": "profetizar",
    "profetizaríamos": "profetizar",
    "profetizaríeis": "profetizar",
    "profetizas": "profetizar",
    "profetizasse": "profetizar",
    "profetizassem": "profetizar",
    "profetizasses": "profetizar",
    "profetizaste": "profetizar",
    "profetizastes": "profetizar",
    "profetizava": "profetizar",
    "profetizavam": "profetizar",
    "profetizavas": "profetizar",
    "profetize": "profetizar",
    "profetizei": "profetizar",
    "profetizeis": "profetizar",
    "profetizem": "profetizar",
    "profetizemo": "profetizar",
    "profetizemos": "profetizar",
    "profetizes": "profetizar",
    "profetizo": "profetizar",
    "profetizou": "profetizar",
    "profetizá": "profetizar",
    "profetizámo": "profetizar",
    "profetizámos": "profetizar",
    "profetizáramo": "profetizar",
    "profetizáramos": "profetizar",
    "profetizárei": "profetizar",
    "profetizáreis": "profetizar",
    "profetizásseis": "profetizar",
    "profetizássemos": "profetizar",
    "profetizávamo": "profetizar",
    "profetizávamos": "profetizar",
    "profetizávei": "profetizar",
    "profetizáveis": "profetizar",
    "proficientes": "proficiente",
    "proficiências": "proficiência",
    "proficuidades": "proficuidade",
    "profilaxias": "profilaxia",
    "profiláctica": "profiláctico",
    "profilácticas": "profiláctico",
    "profilácticos": "profiláctico",
    "profissionais": "profissional",
    "profissionalismos": "profissionalismo",
    "profissionaliza": "profissionalizar",
    "profissionalizada": "profissionalizar",
    "profissionalizadas": "profissionalizar",
    "profissionalizado": "profissionalizar",
    "profissionalizados": "profissionalizar",
    "profissionalizai": "profissionalizar",
    "profissionalizais": "profissionalizar",
    "profissionalizam": "profissionalizar",
    "profissionalizamo": "profissionalizar",
    "profissionalizamos": "profissionalizar",
    "profissionalizando": "profissionalizar",
    "profissionalizara": "profissionalizar",
    "profissionalizaram": "profissionalizar",
    "profissionalizaras": "profissionalizar",
    "profissionalizarde": "profissionalizar",
    "profissionalizardes": "profissionalizar",
    "profissionalizare": "profissionalizar",
    "profissionalizarei": "profissionalizar",
    "profissionalizareis": "profissionalizar",
    "profissionalizarem": "profissionalizar",
    "profissionalizaremos": "profissionalizar",
    "profissionalizares": "profissionalizar",
    "profissionalizaria": "profissionalizar",
    "profissionalizariam": "profissionalizar",
    "profissionalizarias": "profissionalizar",
    "profissionalizarmo": "profissionalizar",
    "profissionalizarmos": "profissionalizar",
    "profissionalizará": "profissionalizar",
    "profissionalizarás": "profissionalizar",
    "profissionalizarão": "profissionalizar",
    "profissionalizaríamos": "profissionalizar",
    "profissionalizaríeis": "profissionalizar",
    "profissionalizas": "profissionalizar",
    "profissionalizasse": "profissionalizar",
    "profissionalizassem": "profissionalizar",
    "profissionalizasses": "profissionalizar",
    "profissionalizaste": "profissionalizar",
    "profissionalizastes": "profissionalizar",
    "profissionalizava": "profissionalizar",
    "profissionalizavam": "profissionalizar",
    "profissionalizavas": "profissionalizar",
    "profissionalizações": "profissionalização",
    "profissionalize": "profissionalizar",
    "profissionalizei": "profissionalizar",
    "profissionalizeis": "profissionalizar",
    "profissionalizem": "profissionalizar",
    "profissionalizemo": "profissionalizar",
    "profissionalizemos": "profissionalizar",
    "profissionalizes": "profissionalizar",
    "profissionalizo": "profissionalizar",
    "profissionalizou": "profissionalizar",
    "profissionalizá": "profissionalizar",
    "profissionalizámo": "profissionalizar",
    "profissionalizámos": "profissionalizar",
    "profissionalizáramo": "profissionalizar",
    "profissionalizáramos": "profissionalizar",
    "profissionalizárei": "profissionalizar",
    "profissionalizáreis": "profissionalizar",
    "profissionalizásseis": "profissionalizar",
    "profissionalizássemos": "profissionalizar",
    "profissionalizávamo": "profissionalizar",
    "profissionalizávamos": "profissionalizar",
    "profissionalizávei": "profissionalizar",
    "profissionalizáveis": "profissionalizar",
    "profissionalíssima": "profissional",
    "profissionalíssimas": "profissional",
    "profissionalíssimo": "profissional",
    "profissionalíssimos": "profissional",
    "profissões": "profissão",
    "profitentes": "profitente",
    "profliga": "profligar",
    "profligada": "profligar",
    "profligadas": "profligar",
    "profligado": "profligar",
    "profligadora": "profligador",
    "profligadoras": "profligador",
    "profligadores": "profligador",
    "profligados": "profligar",
    "profligai": "profligar",
    "profligais": "profligar",
    "profligam": "profligar",
    "profligamo": "profligar",
    "profligamos": "profligar",
    "profligando": "profligar",
    "profligara": "profligar",
    "profligaram": "profligar",
    "profligaras": "profligar",
    "profligarde": "profligar",
    "profligardes": "profligar",
    "profligare": "profligar",
    "profligarei": "profligar",
    "profligareis": "profligar",
    "profligarem": "profligar",
    "profligaremos": "profligar",
    "profligares": "profligar",
    "profligaria": "profligar",
    "profligariam": "profligar",
    "profligarias": "profligar",
    "profligarmo": "profligar",
    "profligarmos": "profligar",
    "profligará": "profligar",
    "profligarás": "profligar",
    "profligarão": "profligar",
    "profligaríamos": "profligar",
    "profligaríeis": "profligar",
    "profligas": "profligar",
    "profligasse": "profligar",
    "profligassem": "profligar",
    "profligasses": "profligar",
    "profligaste": "profligar",
    "profligastes": "profligar",
    "profligava": "profligar",
    "profligavam": "profligar",
    "profligavas": "profligar",
    "profligações": "profligação",
    "profligo": "profligar",
    "profligou": "profligar",
    "profligue": "profligar",
    "profliguei": "profligar",
    "profligueis": "profligar",
    "profliguem": "profligar",
    "profliguemo": "profligar",
    "profliguemos": "profligar",
    "profligues": "profligar",
    "profligá": "profligar",
    "profligámo": "profligar",
    "profligámos": "profligar",
    "profligáramo": "profligar",
    "profligáramos": "profligar",
    "profligárei": "profligar",
    "profligáreis": "profligar",
    "profligásseis": "profligar",
    "profligássemos": "profligar",
    "profligávamo": "profligar",
    "profligávamos": "profligar",
    "profligávei": "profligar",
    "profligáveis": "profligar",
    "profluentes": "profluente",
    "proflúvios": "proflúvio",
    "proformas": "proforma",
    "profs": "prof",
    "profunda": "profundo",
    "profundada": "profundar",
    "profundadas": "profundar",
    "profundado": "profundar",
    "profundadora": "profundador",
    "profundadoras": "profundador",
    "profundadores": "profundador",
    "profundados": "profundar",
    "profundai": "profundar",
    "profundais": "profundar",
    "profundam": "profundar",
    "profundamo": "profundar",
    "profundamos": "profundar",
    "profundando": "profundar",
    "profundara": "profundar",
    "profundaram": "profundar",
    "profundaras": "profundar",
    "profundarde": "profundar",
    "profundardes": "profundar",
    "profundare": "profundar",
    "profundarei": "profundar",
    "profundareis": "profundar",
    "profundarem": "profundar",
    "profundaremos": "profundar",
    "profundares": "profundar",
    "profundaria": "profundar",
    "profundariam": "profundar",
    "profundarias": "profundar",
    "profundarmo": "profundar",
    "profundarmos": "profundar",
    "profundará": "profundar",
    "profundarás": "profundar",
    "profundarão": "profundar",
    "profundaríamos": "profundar",
    "profundaríeis": "profundar",
    "profundas": "profundo",
    "profundasse": "profundar",
    "profundassem": "profundar",
    "profundasses": "profundar",
    "profundaste": "profundar",
    "profundastes": "profundar",
    "profundava": "profundar",
    "profundavam": "profundar",
    "profundavas": "profundar",
    "profunde": "profundar",
    "profundei": "profundar",
    "profundeis": "profundar",
    "profundem": "profundar",
    "profundemo": "profundar",
    "profundemos": "profundar",
    "profundes": "profundar",
    "profundezas": "profundeza",
    "profundezes": "profundez",
    "profundidades": "profundidade",
    "profundo": "profundar",
    "profundos": "profundo",
    "profundou": "profundar",
    "profunduras": "profundura",
    "profundá": "profundar",
    "profundámo": "profundar",
    "profundámos": "profundar",
    "profundáramo": "profundar",
    "profundáramos": "profundar",
    "profundárei": "profundar",
    "profundáreis": "profundar",
    "profundásseis": "profundar",
    "profundássemos": "profundar",
    "profundávamo": "profundar",
    "profundávamos": "profundar",
    "profundávei": "profundar",
    "profundáveis": "profundável",
    "profundíssima": "profundo",
    "profundíssimas": "profundo",
    "profundíssimo": "profundo",
    "profundíssimos": "profundo",
    "profusa": "profuso",
    "profusas": "profuso",
    "profusos": "profuso",
    "profusíssima": "profuso",
    "profusíssimas": "profuso",
    "profusíssimo": "profuso",
    "profusíssimos": "profuso",
    "profusões": "profusão",
    "profética": "profético",
    "proféticas": "profético",
    "proféticos": "profético",
    "profícua": "profícuo",
    "profícuas": "profícuo",
    "profícuos": "profícuo",
    "progamias": "progamia",
    "progenitora": "progenitor",
    "progenitoras": "progenitor",
    "progenitores": "progenitor",
    "progenituras": "progenitura",
    "progesteronas": "progesterona",
    "proglotes": "proglote",
    "proglótica": "proglótico",
    "proglóticas": "proglótico",
    "proglóticos": "proglótico",
    "proglótides": "proglótide",
    "prognatismos": "prognatismo",
    "prognes": "progne",
    "prognoses": "prognose",
    "prognostica": "prognosticar",
    "prognosticada": "prognosticar",
    "prognosticadas": "prognosticar",
    "prognosticado": "prognosticar",
    "prognosticadora": "prognosticador",
    "prognosticadoras": "prognosticador",
    "prognosticadores": "prognosticador",
    "prognosticados": "prognosticar",
    "prognosticai": "prognosticar",
    "prognosticais": "prognosticar",
    "prognosticam": "prognosticar",
    "prognosticamo": "prognosticar",
    "prognosticamos": "prognosticar",
    "prognosticando": "prognosticar",
    "prognosticara": "prognosticar",
    "prognosticaram": "prognosticar",
    "prognosticaras": "prognosticar",
    "prognosticarde": "prognosticar",
    "prognosticardes": "prognosticar",
    "prognosticare": "prognosticar",
    "prognosticarei": "prognosticar",
    "prognosticareis": "prognosticar",
    "prognosticarem": "prognosticar",
    "prognosticaremos": "prognosticar",
    "prognosticares": "prognosticar",
    "prognosticaria": "prognosticar",
    "prognosticariam": "prognosticar",
    "prognosticarias": "prognosticar",
    "prognosticarmo": "prognosticar",
    "prognosticarmos": "prognosticar",
    "prognosticará": "prognosticar",
    "prognosticarás": "prognosticar",
    "prognosticarão": "prognosticar",
    "prognosticaríamos": "prognosticar",
    "prognosticaríeis": "prognosticar",
    "prognosticas": "prognosticar",
    "prognosticasse": "prognosticar",
    "prognosticassem": "prognosticar",
    "prognosticasses": "prognosticar",
    "prognosticaste": "prognosticar",
    "prognosticastes": "prognosticar",
    "prognosticava": "prognosticar",
    "prognosticavam": "prognosticar",
    "prognosticavas": "prognosticar",
    "prognostico": "prognosticar",
    "prognosticou": "prognosticar",
    "prognosticá": "prognosticar",
    "prognosticámo": "prognosticar",
    "prognosticámos": "prognosticar",
    "prognosticáramo": "prognosticar",
    "prognosticáramos": "prognosticar",
    "prognosticárei": "prognosticar",
    "prognosticáreis": "prognosticar",
    "prognosticásseis": "prognosticar",
    "prognosticássemos": "prognosticar",
    "prognosticávamo": "prognosticar",
    "prognosticávamos": "prognosticar",
    "prognosticávei": "prognosticar",
    "prognosticáveis": "prognosticar",
    "prognostique": "prognosticar",
    "prognostiquei": "prognosticar",
    "prognostiqueis": "prognosticar",
    "prognostiquem": "prognosticar",
    "prognostiquemo": "prognosticar",
    "prognostiquemos": "prognosticar",
    "prognostiques": "prognosticar",
    "prognóstica": "prognóstico",
    "prognósticas": "prognóstico",
    "prognósticos": "prognóstico",
    "programa": "programar",
    "programada": "programar",
    "programadas": "programar",
    "programado": "programar",
    "programadora": "programador",
    "programadoras": "programador",
    "programadores": "programador",
    "programados": "programar",
    "programai": "programar",
    "programais": "programar",
    "programam": "programar",
    "programamo": "programar",
    "programamos": "programar",
    "programando": "programar",
    "programara": "programar",
    "programaram": "programar",
    "programaras": "programar",
    "programarde": "programar",
    "programardes": "programar",
    "programare": "programar",
    "programarei": "programar",
    "programareis": "programar",
    "programarem": "programar",
    "programaremos": "programar",
    "programares": "programar",
    "programaria": "programar",
    "programariam": "programar",
    "programarias": "programar",
    "programarmo": "programar",
    "programarmos": "programar",
    "programará": "programar",
    "programarás": "programar",
    "programarão": "programar",
    "programaríamos": "programar",
    "programaríeis": "programar",
    "programas": "programar",
    "programasse": "programar",
    "programassem": "programar",
    "programasses": "programar",
    "programaste": "programar",
    "programastes": "programar",
    "programatiza": "programatizar",
    "programatizada": "programatizar",
    "programatizadas": "programatizar",
    "programatizado": "programatizar",
    "programatizados": "programatizar",
    "programatizai": "programatizar",
    "programatizais": "programatizar",
    "programatizam": "programatizar",
    "programatizamo": "programatizar",
    "programatizamos": "programatizar",
    "programatizando": "programatizar",
    "programatizara": "programatizar",
    "programatizaram": "programatizar",
    "programatizaras": "programatizar",
    "programatizarde": "programatizar",
    "programatizardes": "programatizar",
    "programatizare": "programatizar",
    "programatizarei": "programatizar",
    "programatizareis": "programatizar",
    "programatizarem": "programatizar",
    "programatizaremos": "programatizar",
    "programatizares": "programatizar",
    "programatizaria": "programatizar",
    "programatizariam": "programatizar",
    "programatizarias": "programatizar",
    "programatizarmo": "programatizar",
    "programatizarmos": "programatizar",
    "programatizará": "programatizar",
    "programatizarás": "programatizar",
    "programatizarão": "programatizar",
    "programatizaríamos": "programatizar",
    "programatizaríeis": "programatizar",
    "programatizas": "programatizar",
    "programatizasse": "programatizar",
    "programatizassem": "programatizar",
    "programatizasses": "programatizar",
    "programatizaste": "programatizar",
    "programatizastes": "programatizar",
    "programatizava": "programatizar",
    "programatizavam": "programatizar",
    "programatizavas": "programatizar",
    "programatize": "programatizar",
    "programatizei": "programatizar",
    "programatizeis": "programatizar",
    "programatizem": "programatizar",
    "programatizemo": "programatizar",
    "programatizemos": "programatizar",
    "programatizes": "programatizar",
    "programatizo": "programatizar",
    "programatizou": "programatizar",
    "programatizá": "programatizar",
    "programatizámo": "programatizar",
    "programatizámos": "programatizar",
    "programatizáramo": "programatizar",
    "programatizáramos": "programatizar",
    "programatizárei": "programatizar",
    "programatizáreis": "programatizar",
    "programatizásseis": "programatizar",
    "programatizássemos": "programatizar",
    "programatizávamo": "programatizar",
    "programatizávamos": "programatizar",
    "programatizávei": "programatizar",
    "programatizáveis": "programatizar",
    "programava": "programar",
    "programavam": "programar",
    "programavas": "programar",
    "programazinho": "programa",
    "programazinhos": "programa",
    "programazito": "programa",
    "programazitos": "programa",
    "programações": "programação",
    "programe": "programar",
    "programei": "programar",
    "programeis": "programar",
    "programem": "programar",
    "programemo": "programar",
    "programemos": "programar",
    "programes": "programar",
    "programinha": "programa",
    "programinhas": "programa",
    "programita": "programa",
    "programitas": "programa",
    "programo": "programar",
    "programou": "programar",
    "programá": "programar",
    "programámo": "programar",
    "programámos": "programar",
    "programáramo": "programar",
    "programáramos": "programar",
    "programárei": "programar",
    "programáreis": "programar",
    "programásseis": "programar",
    "programássemos": "programar",
    "programática": "programático",
    "programáticas": "programático",
    "programáticos": "programático",
    "programávamo": "programar",
    "programávamos": "programar",
    "programávei": "programar",
    "programáveis": "programável",
    "progredi": "progredir",
    "progredia": "progredir",
    "progrediam": "progredir",
    "progredias": "progredir",
    "progredida": "progredir",
    "progredidas": "progredir",
    "progredido": "progredir",
    "progredidos": "progredir",
    "progredimentos": "progredimento",
    "progredimo": "progredir",
    "progredimos": "progredir",
    "progredindo": "progredir",
    "progredira": "progredir",
    "progrediram": "progredir",
    "progrediras": "progredir",
    "progredirdes": "progredir",
    "progredirei": "progredir",
    "progredireis": "progredir",
    "progredirem": "progredir",
    "progrediremos": "progredir",
    "progredires": "progredir",
    "progrediria": "progredir",
    "progrediriam": "progredir",
    "progredirias": "progredir",
    "progredirmo": "progredir",
    "progredirmos": "progredir",
    "progredirá": "progredir",
    "progredirás": "progredir",
    "progredirão": "progredir",
    "progrediríamos": "progredir",
    "progrediríeis": "progredir",
    "progredis": "progredir",
    "progredisse": "progredir",
    "progredissem": "progredir",
    "progredisses": "progredir",
    "progrediste": "progredir",
    "progredistes": "progredir",
    "progrediu": "progredir",
    "progredíamo": "progredir",
    "progredíamos": "progredir",
    "progredíeis": "progredir",
    "progredíramo": "progredir",
    "progredíramos": "progredir",
    "progredíreis": "progredir",
    "progredísseis": "progredir",
    "progredíssemos": "progredir",
    "progressismos": "progressismo",
    "progressistas": "progressista",
    "progressiva": "progressivo",
    "progressivas": "progressivo",
    "progressividades": "progressividade",
    "progressivos": "progressivo",
    "progressos": "progresso",
    "progressões": "progressão",
    "progrida": "progredir",
    "progridais": "progredir",
    "progridam": "progredir",
    "progridamo": "progredir",
    "progridamos": "progredir",
    "progridas": "progredir",
    "progride": "progredir",
    "progridem": "progredir",
    "progrides": "progredir",
    "progrido": "progredir",
    "progâmica": "progâmico",
    "progâmicas": "progâmico",
    "progâmicos": "progâmico",
    "progénica": "progénico",
    "progénicas": "progénico",
    "progénicos": "progénico",
    "progénies": "progénie",
    "progénita": "progénito",
    "progénitas": "progénito",
    "progénitos": "progénito",
    "proibais": "proibir",
    "proibamo": "proibir",
    "proibamos": "proibir",
    "proibi": "proibir",
    "proibia": "proibir",
    "proibiam": "proibir",
    "proibias": "proibir",
    "proibida": "proibir",
    "proibidas": "proibir",
    "proibido": "proibir",
    "proibidora": "proibidor",
    "proibidoras": "proibidor",
    "proibidores": "proibidor",
    "proibidos": "proibir",
    "proibimo": "proibir",
    "proibimos": "proibir",
    "proibindo": "proibir",
    "proibira": "proibir",
    "proibiram": "proibir",
    "proibiras": "proibir",
    "proibirde": "proibir",
    "proibirdes": "proibir",
    "proibire": "proibir",
    "proibirei": "proibir",
    "proibireis": "proibir",
    "proibirem": "proibir",
    "proibiremos": "proibir",
    "proibires": "proibir",
    "proibiria": "proibir",
    "proibiriam": "proibir",
    "proibirias": "proibir",
    "proibirmo": "proibir",
    "proibirmos": "proibir",
    "proibirá": "proibir",
    "proibirás": "proibir",
    "proibirão": "proibir",
    "proibiríamos": "proibir",
    "proibiríeis": "proibir",
    "proibis": "proibir",
    "proibisse": "proibir",
    "proibissem": "proibir",
    "proibisses": "proibir",
    "proibiste": "proibir",
    "proibistes": "proibir",
    "proibitiva": "proibitivo",
    "proibitivas": "proibitivo",
    "proibitivos": "proibitivo",
    "proibitória": "proibitório",
    "proibitórias": "proibitório",
    "proibitórios": "proibitório",
    "proibiu": "proibir",
    "proibições": "proibição",
    "proibíamo": "proibir",
    "proibíamos": "proibir",
    "proibíei": "proibir",
    "proibíeis": "proibir",
    "proibíramo": "proibir",
    "proibíramos": "proibir",
    "proibírei": "proibir",
    "proibíreis": "proibir",
    "proibísseis": "proibir",
    "proibíssemos": "proibir",
    "proizes": "proiz",
    "projeccionistas": "projeccionista",
    "projecta": "projectar",
    "projectada": "projectar",
    "projectadas": "projectar",
    "projectado": "projectar",
    "projectados": "projectar",
    "projectai": "projectar",
    "projectais": "projectar",
    "projectam": "projectar",
    "projectamo": "projectar",
    "projectamos": "projectar",
    "projectando": "projectar",
    "projectantes": "projectante",
    "projectara": "projectar",
    "projectaram": "projectar",
    "projectaras": "projectar",
    "projectarde": "projectar",
    "projectardes": "projectar",
    "projectare": "projectar",
    "projectarei": "projectar",
    "projectareis": "projectar",
    "projectarem": "projectar",
    "projectaremos": "projectar",
    "projectares": "projectar",
    "projectaria": "projectar",
    "projectariam": "projectar",
    "projectarias": "projectar",
    "projectarmo": "projectar",
    "projectarmos": "projectar",
    "projectará": "projectar",
    "projectarás": "projectar",
    "projectarão": "projectar",
    "projectaríamos": "projectar",
    "projectaríeis": "projectar",
    "projectas": "projectar",
    "projectasse": "projectar",
    "projectassem": "projectar",
    "projectasses": "projectar",
    "projectaste": "projectar",
    "projectastes": "projectar",
    "projectava": "projectar",
    "projectavam": "projectar",
    "projectavas": "projectar",
    "projectações": "projectação",
    "projecte": "projectar",
    "projectei": "projectar",
    "projecteis": "projectar",
    "projectem": "projectar",
    "projectemo": "projectar",
    "projectemos": "projectar",
    "projectes": "projectar",
    "projectistas": "projectista",
    "projectiva": "projectivo",
    "projectivas": "projectivo",
    "projectivos": "projectivo",
    "projecto": "projectar",
    "projectores": "projector",
    "projectos": "projecto",
    "projectou": "projectar",
    "projectozinho": "projecto",
    "projectozinhos": "projecto",
    "projectozito": "projecto",
    "projectozitos": "projecto",
    "projecturas": "projectura",
    "projectá": "projectar",
    "projectámo": "projectar",
    "projectámos": "projectar",
    "projectáramo": "projectar",
    "projectáramos": "projectar",
    "projectárei": "projectar",
    "projectáreis": "projectar",
    "projectásseis": "projectar",
    "projectássemos": "projectar",
    "projectávamo": "projectar",
    "projectávamos": "projectar",
    "projectávei": "projectar",
    "projectáveis": "projectar",
    "projecções": "projecção",
    "projécteis": "projéctil",
    "projéctis": "projéctil",
    "prolapsa": "prolapso",
    "prolapsas": "prolapso",
    "prolapsos": "prolapso",
    "prolatora": "prolator",
    "prolatoras": "prolator",
    "prolatores": "prolator",
    "prolações": "prolação",
    "prolepses": "prolepse",
    "proles": "prole",
    "proletariados": "proletariado",
    "proletariza": "proletarizar",
    "proletarizada": "proletarizar",
    "proletarizadas": "proletarizar",
    "proletarizado": "proletarizar",
    "proletarizados": "proletarizar",
    "proletarizai": "proletarizar",
    "proletarizais": "proletarizar",
    "proletarizam": "proletarizar",
    "proletarizamo": "proletarizar",
    "proletarizamos": "proletarizar",
    "proletarizando": "proletarizar",
    "proletarizara": "proletarizar",
    "proletarizaram": "proletarizar",
    "proletarizaras": "proletarizar",
    "proletarizarde": "proletarizar",
    "proletarizardes": "proletarizar",
    "proletarizare": "proletarizar",
    "proletarizarei": "proletarizar",
    "proletarizareis": "proletarizar",
    "proletarizarem": "proletarizar",
    "proletarizaremos": "proletarizar",
    "proletarizares": "proletarizar",
    "proletarizaria": "proletarizar",
    "proletarizariam": "proletarizar",
    "proletarizarias": "proletarizar",
    "proletarizarmo": "proletarizar",
    "proletarizarmos": "proletarizar",
    "proletarizará": "proletarizar",
    "proletarizarás": "proletarizar",
    "proletarizarão": "proletarizar",
    "proletarizaríamos": "proletarizar",
    "proletarizaríeis": "proletarizar",
    "proletarizas": "proletarizar",
    "proletarizasse": "proletarizar",
    "proletarizassem": "proletarizar",
    "proletarizasses": "proletarizar",
    "proletarizaste": "proletarizar",
    "proletarizastes": "proletarizar",
    "proletarizava": "proletarizar",
    "proletarizavam": "proletarizar",
    "proletarizavas": "proletarizar",
    "proletarizações": "proletarização",
    "proletarize": "proletarizar",
    "proletarizei": "proletarizar",
    "proletarizeis": "proletarizar",
    "proletarizem": "proletarizar",
    "proletarizemo": "proletarizar",
    "proletarizemos": "proletarizar",
    "proletarizes": "proletarizar",
    "proletarizo": "proletarizar",
    "proletarizou": "proletarizar",
    "proletarizá": "proletarizar",
    "proletarizámo": "proletarizar",
    "proletarizámos": "proletarizar",
    "proletarizáramo": "proletarizar",
    "proletarizáramos": "proletarizar",
    "proletarizárei": "proletarizar",
    "proletarizáreis": "proletarizar",
    "proletarizásseis": "proletarizar",
    "proletarizássemos": "proletarizar",
    "proletarizávamo": "proletarizar",
    "proletarizávamos": "proletarizar",
    "proletarizávei": "proletarizar",
    "proletarizáveis": "proletarizar",
    "proletária": "proletário",
    "proletárias": "proletário",
    "proletários": "proletário",
    "prolfaças": "prolfaça",
    "prolifera": "proliferar",
    "proliferada": "proliferar",
    "proliferadas": "proliferar",
    "proliferado": "proliferar",
    "proliferados": "proliferar",
    "proliferai": "proliferar",
    "proliferais": "proliferar",
    "proliferam": "proliferar",
    "proliferamo": "proliferar",
    "proliferamos": "proliferar",
    "proliferando": "proliferar",
    "proliferantes": "proliferante",
    "proliferara": "proliferar",
    "proliferaram": "proliferar",
    "proliferaras": "proliferar",
    "proliferarde": "proliferar",
    "proliferardes": "proliferar",
    "proliferare": "proliferar",
    "proliferarei": "proliferar",
    "proliferareis": "proliferar",
    "proliferarem": "proliferar",
    "proliferaremos": "proliferar",
    "proliferares": "proliferar",
    "proliferaria": "proliferar",
    "proliferariam": "proliferar",
    "proliferarias": "proliferar",
    "proliferarmo": "proliferar",
    "proliferarmos": "proliferar",
    "proliferará": "proliferar",
    "proliferarás": "proliferar",
    "proliferarão": "proliferar",
    "proliferaríamos": "proliferar",
    "proliferaríeis": "proliferar",
    "proliferas": "proliferar",
    "proliferasse": "proliferar",
    "proliferassem": "proliferar",
    "proliferasses": "proliferar",
    "proliferaste": "proliferar",
    "proliferastes": "proliferar",
    "proliferava": "proliferar",
    "proliferavam": "proliferar",
    "proliferavas": "proliferar",
    "proliferações": "proliferação",
    "prolifere": "proliferar",
    "proliferei": "proliferar",
    "prolifereis": "proliferar",
    "proliferem": "proliferar",
    "proliferemo": "proliferar",
    "proliferemos": "proliferar",
    "proliferes": "proliferar",
    "prolifero": "proliferar",
    "proliferou": "proliferar",
    "proliferá": "proliferar",
    "proliferámo": "proliferar",
    "proliferámos": "proliferar",
    "proliferáramo": "proliferar",
    "proliferáramos": "proliferar",
    "proliferárei": "proliferar",
    "proliferáreis": "proliferar",
    "proliferásseis": "proliferar",
    "proliferássemos": "proliferar",
    "proliferávamo": "proliferar",
    "proliferávamos": "proliferar",
    "proliferávei": "proliferar",
    "proliferáveis": "proliferar",
    "prolificações": "prolificação",
    "prolificidades": "prolificidade",
    "prolixa": "prolixo",
    "prolixas": "prolixo",
    "prolixidades": "prolixidade",
    "prolixos": "prolixo",
    "prolixíssima": "prolixo",
    "prolixíssimas": "prolixo",
    "prolixíssimo": "prolixo",
    "prolixíssimos": "prolixo",
    "prologa": "prologar",
    "prologada": "prologar",
    "prologadas": "prologar",
    "prologado": "prologar",
    "prologados": "prologar",
    "prologai": "prologar",
    "prologais": "prologar",
    "prologam": "prologar",
    "prologamo": "prologar",
    "prologamos": "prologar",
    "prologando": "prologar",
    "prologara": "prologar",
    "prologaram": "prologar",
    "prologaras": "prologar",
    "prologarde": "prologar",
    "prologardes": "prologar",
    "prologare": "prologar",
    "prologarei": "prologar",
    "prologareis": "prologar",
    "prologarem": "prologar",
    "prologaremos": "prologar",
    "prologares": "prologar",
    "prologaria": "prologar",
    "prologariam": "prologar",
    "prologarias": "prologar",
    "prologarmo": "prologar",
    "prologarmos": "prologar",
    "prologará": "prologar",
    "prologarás": "prologar",
    "prologarão": "prologar",
    "prologaríamos": "prologar",
    "prologaríeis": "prologar",
    "prologas": "prologar",
    "prologasse": "prologar",
    "prologassem": "prologar",
    "prologasses": "prologar",
    "prologaste": "prologar",
    "prologastes": "prologar",
    "prologava": "prologar",
    "prologavam": "prologar",
    "prologavas": "prologar",
    "prologo": "prologar",
    "prologou": "prologar",
    "prologue": "prologar",
    "prologuei": "prologar",
    "prologueis": "prologar",
    "prologuem": "prologar",
    "prologuemo": "prologar",
    "prologuemos": "prologar",
    "prologues": "prologar",
    "prologá": "prologar",
    "prologámo": "prologar",
    "prologámos": "prologar",
    "prologáramo": "prologar",
    "prologáramos": "prologar",
    "prologárei": "prologar",
    "prologáreis": "prologar",
    "prologásseis": "prologar",
    "prologássemos": "prologar",
    "prologávamo": "prologar",
    "prologávamos": "prologar",
    "prologávei": "prologar",
    "prologáveis": "prologar",
    "prolonga": "prolongar",
    "prolongada": "prolongar",
    "prolongadas": "prolongar",
    "prolongado": "prolongar",
    "prolongados": "prolongar",
    "prolongai": "prolongar",
    "prolongais": "prolongar",
    "prolongam": "prolongar",
    "prolongamentos": "prolongamento",
    "prolongamo": "prolongar",
    "prolongamos": "prolongar",
    "prolongando": "prolongar",
    "prolongara": "prolongar",
    "prolongaram": "prolongar",
    "prolongaras": "prolongar",
    "prolongarde": "prolongar",
    "prolongardes": "prolongar",
    "prolongare": "prolongar",
    "prolongarei": "prolongar",
    "prolongareis": "prolongar",
    "prolongarem": "prolongar",
    "prolongaremos": "prolongar",
    "prolongares": "prolongar",
    "prolongaria": "prolongar",
    "prolongariam": "prolongar",
    "prolongarias": "prolongar",
    "prolongarmo": "prolongar",
    "prolongarmos": "prolongar",
    "prolongará": "prolongar",
    "prolongarás": "prolongar",
    "prolongarão": "prolongar",
    "prolongaríamos": "prolongar",
    "prolongaríeis": "prolongar",
    "prolongas": "prolongar",
    "prolongasse": "prolongar",
    "prolongassem": "prolongar",
    "prolongasses": "prolongar",
    "prolongaste": "prolongar",
    "prolongastes": "prolongar",
    "prolongava": "prolongar",
    "prolongavam": "prolongar",
    "prolongavas": "prolongar",
    "prolongações": "prolongação",
    "prolongo": "prolongar",
    "prolongou": "prolongar",
    "prolongue": "prolongar",
    "prolonguei": "prolongar",
    "prolongueis": "prolongar",
    "prolonguem": "prolongar",
    "prolonguemo": "prolongar",
    "prolonguemos": "prolongar",
    "prolongues": "prolongar",
    "prolongá": "prolongar",
    "prolongámo": "prolongar",
    "prolongámos": "prolongar",
    "prolongáramo": "prolongar",
    "prolongáramos": "prolongar",
    "prolongárei": "prolongar",
    "prolongáreis": "prolongar",
    "prolongásseis": "prolongar",
    "prolongássemos": "prolongar",
    "prolongávamo": "prolongar",
    "prolongávamos": "prolongar",
    "prolongávei": "prolongar",
    "prolongáveis": "prolongável",
    "proloquiais": "proloquial",
    "prolusões": "prolusão",
    "proléptica": "proléptico",
    "prolépticas": "proléptico",
    "prolépticos": "proléptico",
    "prolífera": "prolífero",
    "prolíferas": "prolífero",
    "prolíferos": "prolífero",
    "prolífica": "prolífico",
    "prolíficas": "prolífico",
    "prolíficos": "prolífico",
    "prolígera": "prolígero",
    "prolígeras": "prolígero",
    "prolígeros": "prolígero",
    "prolóquios": "prolóquio",
    "promana": "promanar",
    "promanada": "promanar",
    "promanadas": "promanar",
    "promanado": "promanar",
    "promanados": "promanar",
    "promanai": "promanar",
    "promanais": "promanar",
    "promanam": "promanar",
    "promanamo": "promanar",
    "promanamos": "promanar",
    "promanando": "promanar",
    "promanara": "promanar",
    "promanaram": "promanar",
    "promanaras": "promanar",
    "promanarde": "promanar",
    "promanardes": "promanar",
    "promanare": "promanar",
    "promanarei": "promanar",
    "promanareis": "promanar",
    "promanarem": "promanar",
    "promanaremos": "promanar",
    "promanares": "promanar",
    "promanaria": "promanar",
    "promanariam": "promanar",
    "promanarias": "promanar",
    "promanarmo": "promanar",
    "promanarmos": "promanar",
    "promanará": "promanar",
    "promanarás": "promanar",
    "promanarão": "promanar",
    "promanaríamos": "promanar",
    "promanaríeis": "promanar",
    "promanas": "promanar",
    "promanasse": "promanar",
    "promanassem": "promanar",
    "promanasses": "promanar",
    "promanaste": "promanar",
    "promanastes": "promanar",
    "promanava": "promanar",
    "promanavam": "promanar",
    "promanavas": "promanar",
    "promane": "promanar",
    "promanei": "promanar",
    "promaneis": "promanar",
    "promanem": "promanar",
    "promanemo": "promanar",
    "promanemos": "promanar",
    "promanes": "promanar",
    "promano": "promanar",
    "promanou": "promanar",
    "promaná": "promanar",
    "promanámo": "promanar",
    "promanámos": "promanar",
    "promanáramo": "promanar",
    "promanáramos": "promanar",
    "promanárei": "promanar",
    "promanáreis": "promanar",
    "promanásseis": "promanar",
    "promanássemos": "promanar",
    "promanávamo": "promanar",
    "promanávamos": "promanar",
    "promanávei": "promanar",
    "promanáveis": "promanar",
    "promessas": "promessa",
    "prometa": "prometer",
    "prometais": "prometer",
    "prometam": "prometer",
    "prometamo": "prometer",
    "prometamos": "prometer",
    "prometas": "prometer",
    "promete": "prometer",
    "prometedora": "prometedor",
    "prometedoras": "prometedor",
    "prometedores": "prometedor",
    "prometei": "prometer",
    "prometeica": "prometeico",
    "prometeicas": "prometeico",
    "prometeicos": "prometeico",
    "prometeis": "prometer",
    "prometem": "prometer",
    "prometemo": "prometer",
    "prometemos": "prometer",
    "prometendo": "prometer",
    "prometera": "prometer",
    "prometeram": "prometer",
    "prometeras": "prometer",
    "prometerde": "prometer",
    "prometerdes": "prometer",
    "prometere": "prometer",
    "prometerei": "prometer",
    "prometereis": "prometer",
    "prometerem": "prometer",
    "prometeremos": "prometer",
    "prometeres": "prometer",
    "prometeria": "prometer",
    "prometeriam": "prometer",
    "prometerias": "prometer",
    "prometermo": "prometer",
    "prometermos": "prometer",
    "prometerá": "prometer",
    "prometerás": "prometer",
    "prometerão": "prometer",
    "prometeríamos": "prometer",
    "prometeríeis": "prometer",
    "prometes": "prometer",
    "prometesse": "prometer",
    "prometessem": "prometer",
    "prometesses": "prometer",
    "prometeste": "prometer",
    "prometestes": "prometer",
    "prometeu": "prometer",
    "prometi": "prometer",
    "prometia": "prometer",
    "prometiam": "prometer",
    "prometias": "prometer",
    "prometida": "prometido",
    "prometidas": "prometido",
    "prometidinha": "prometido",
    "prometidinhas": "prometido",
    "prometidinho": "prometido",
    "prometidinhos": "prometido",
    "prometidita": "prometido",
    "prometiditas": "prometido",
    "prometidito": "prometido",
    "prometiditos": "prometido",
    "prometido": "prometer",
    "prometidos": "prometido",
    "prometidíssima": "prometido",
    "prometidíssimas": "prometido",
    "prometidíssimo": "prometido",
    "prometidíssimos": "prometido",
    "prometimentos": "prometimento",
    "prometo": "prometer",
    "prometê": "prometer",
    "prometêramo": "prometer",
    "prometêramos": "prometer",
    "prometêrei": "prometer",
    "prometêreis": "prometer",
    "prometêsseis": "prometer",
    "prometêssemos": "prometer",
    "prometíamo": "prometer",
    "prometíamos": "prometer",
    "prometíei": "prometer",
    "prometíeis": "prometer",
    "promiscua": "promiscuir",
    "promiscuais": "promiscuir",
    "promiscuam": "promiscuir",
    "promiscuamo": "promiscuir",
    "promiscuamos": "promiscuir",
    "promiscuas": "promiscuir",
    "promiscuem": "promiscuir",
    "promiscui": "promiscuir",
    "promiscuidades": "promiscuidade",
    "promiscuindo": "promiscuir",
    "promiscuirdes": "promiscuir",
    "promiscuirei": "promiscuir",
    "promiscuireis": "promiscuir",
    "promiscuiremos": "promiscuir",
    "promiscuiria": "promiscuir",
    "promiscuiriam": "promiscuir",
    "promiscuirias": "promiscuir",
    "promiscuirmo": "promiscuir",
    "promiscuirmos": "promiscuir",
    "promiscuirá": "promiscuir",
    "promiscuirás": "promiscuir",
    "promiscuirão": "promiscuir",
    "promiscuiríamos": "promiscuir",
    "promiscuiríeis": "promiscuir",
    "promiscuis": "promiscuir",
    "promiscuiu": "promiscuir",
    "promiscuo": "promiscuir",
    "promiscuí": "promiscuir",
    "promiscuía": "promiscuir",
    "promiscuíam": "promiscuir",
    "promiscuíamo": "promiscuir",
    "promiscuíamos": "promiscuir",
    "promiscuías": "promiscuir",
    "promiscuída": "promiscuir",
    "promiscuídas": "promiscuir",
    "promiscuído": "promiscuir",
    "promiscuídos": "promiscuir",
    "promiscuíeis": "promiscuir",
    "promiscuímo": "promiscuir",
    "promiscuímos": "promiscuir",
    "promiscuíra": "promiscuir",
    "promiscuíram": "promiscuir",
    "promiscuíramo": "promiscuir",
    "promiscuíramos": "promiscuir",
    "promiscuíras": "promiscuir",
    "promiscuíreis": "promiscuir",
    "promiscuírem": "promiscuir",
    "promiscuíres": "promiscuir",
    "promiscuís": "promiscuir",
    "promiscuísse": "promiscuir",
    "promiscuísseis": "promiscuir",
    "promiscuíssem": "promiscuir",
    "promiscuíssemos": "promiscuir",
    "promiscuísses": "promiscuir",
    "promiscuíste": "promiscuir",
    "promiscuístes": "promiscuir",
    "promissiva": "promissivo",
    "promissivas": "promissivo",
    "promissivos": "promissivo",
    "promissora": "promissor",
    "promissoras": "promissor",
    "promissores": "promissor",
    "promissória": "promissório",
    "promissórias": "promissório",
    "promissórios": "promissório",
    "promissões": "promissão",
    "promitentes": "promitente",
    "promocionais": "promocional",
    "promontoriais": "promontorial",
    "promontórios": "promontório",
    "promotora": "promotor",
    "promotoras": "promotor",
    "promotores": "promotor",
    "promotorias": "promotoria",
    "promova": "promover",
    "promovais": "promover",
    "promovam": "promover",
    "promovamo": "promover",
    "promovamos": "promover",
    "promovas": "promover",
    "promove": "promover",
    "promovedora": "promovedor",
    "promovedoras": "promovedor",
    "promovedores": "promovedor",
    "promovei": "promover",
    "promoveis": "promover",
    "promovem": "promover",
    "promovemo": "promover",
    "promovemos": "promover",
    "promovendo": "promover",
    "promovera": "promover",
    "promoveram": "promover",
    "promoveras": "promover",
    "promoverde": "promover",
    "promoverdes": "promover",
    "promovere": "promover",
    "promoverei": "promover",
    "promovereis": "promover",
    "promoverem": "promover",
    "promoveremos": "promover",
    "promoveres": "promover",
    "promoveria": "promover",
    "promoveriam": "promover",
    "promoverias": "promover",
    "promovermo": "promover",
    "promovermos": "promover",
    "promoverá": "promover",
    "promoverás": "promover",
    "promoverão": "promover",
    "promoveríamos": "promover",
    "promoveríeis": "promover",
    "promoves": "promover",
    "promovesse": "promover",
    "promovessem": "promover",
    "promovesses": "promover",
    "promoveste": "promover",
    "promovestes": "promover",
    "promoveu": "promover",
    "promovi": "promover",
    "promovia": "promover",
    "promoviam": "promover",
    "promovias": "promover",
    "promovida": "promovido",
    "promovidas": "promovido",
    "promovido": "promover",
    "promovidos": "promovido",
    "promovo": "promover",
    "promovê": "promover",
    "promovêramo": "promover",
    "promovêramos": "promover",
    "promovêrei": "promover",
    "promovêreis": "promover",
    "promovêsseis": "promover",
    "promovêssemos": "promover",
    "promovíamo": "promover",
    "promovíamos": "promover",
    "promovíei": "promover",
    "promovíeis": "promover",
    "promovíveis": "promovível",
    "promoções": "promoção",
    "promulga": "promulgar",
    "promulgada": "promulgar",
    "promulgadas": "promulgar",
    "promulgado": "promulgar",
    "promulgadora": "promulgador",
    "promulgadoras": "promulgador",
    "promulgadores": "promulgador",
    "promulgados": "promulgar",
    "promulgai": "promulgar",
    "promulgais": "promulgar",
    "promulgam": "promulgar",
    "promulgamo": "promulgar",
    "promulgamos": "promulgar",
    "promulgando": "promulgar",
    "promulgara": "promulgar",
    "promulgaram": "promulgar",
    "promulgaras": "promulgar",
    "promulgarde": "promulgar",
    "promulgardes": "promulgar",
    "promulgare": "promulgar",
    "promulgarei": "promulgar",
    "promulgareis": "promulgar",
    "promulgarem": "promulgar",
    "promulgaremos": "promulgar",
    "promulgares": "promulgar",
    "promulgaria": "promulgar",
    "promulgariam": "promulgar",
    "promulgarias": "promulgar",
    "promulgarmo": "promulgar",
    "promulgarmos": "promulgar",
    "promulgará": "promulgar",
    "promulgarás": "promulgar",
    "promulgarão": "promulgar",
    "promulgaríamos": "promulgar",
    "promulgaríeis": "promulgar",
    "promulgas": "promulgar",
    "promulgasse": "promulgar",
    "promulgassem": "promulgar",
    "promulgasses": "promulgar",
    "promulgaste": "promulgar",
    "promulgastes": "promulgar",
    "promulgativa": "promulgativo",
    "promulgativas": "promulgativo",
    "promulgativos": "promulgativo",
    "promulgava": "promulgar",
    "promulgavam": "promulgar",
    "promulgavas": "promulgar",
    "promulgações": "promulgação",
    "promulgo": "promulgar",
    "promulgou": "promulgar",
    "promulgue": "promulgar",
    "promulguei": "promulgar",
    "promulgueis": "promulgar",
    "promulguem": "promulgar",
    "promulguemo": "promulgar",
    "promulguemos": "promulgar",
    "promulgues": "promulgar",
    "promulgá": "promulgar",
    "promulgámo": "promulgar",
    "promulgámos": "promulgar",
    "promulgáramo": "promulgar",
    "promulgáramos": "promulgar",
    "promulgárei": "promulgar",
    "promulgáreis": "promulgar",
    "promulgásseis": "promulgar",
    "promulgássemos": "promulgar",
    "promulgávamo": "promulgar",
    "promulgávamos": "promulgar",
    "promulgávei": "promulgar",
    "promulgáveis": "promulgável",
    "prométios": "prométio",
    "promíscua": "promíscuo",
    "promíscuas": "promíscuo",
    "promíscuos": "promíscuo",
    "prona": "prono",
    "pronadora": "pronador",
    "pronadoras": "pronador",
    "pronadores": "pronador",
    "pronas": "prono",
    "pronaus": "pronau",
    "pronações": "pronação",
    "pronefrítica": "pronefrítico",
    "pronefríticas": "pronefrítico",
    "pronefríticos": "pronefrítico",
    "pronomes": "pronome",
    "pronomina": "pronominar",
    "pronominada": "pronominar",
    "pronominadas": "pronominar",
    "pronominado": "pronominar",
    "pronominados": "pronominar",
    "pronominai": "pronominar",
    "pronominais": "pronominar",
    "pronominalizações": "pronominalização",
    "pronominam": "pronominar",
    "pronominamo": "pronominar",
    "pronominamos": "pronominar",
    "pronominando": "pronominar",
    "pronominara": "pronominar",
    "pronominaram": "pronominar",
    "pronominaras": "pronominar",
    "pronominarde": "pronominar",
    "pronominardes": "pronominar",
    "pronominare": "pronominar",
    "pronominarei": "pronominar",
    "pronominareis": "pronominar",
    "pronominarem": "pronominar",
    "pronominaremos": "pronominar",
    "pronominares": "pronominar",
    "pronominaria": "pronominar",
    "pronominariam": "pronominar",
    "pronominarias": "pronominar",
    "pronominarmo": "pronominar",
    "pronominarmos": "pronominar",
    "pronominará": "pronominar",
    "pronominarás": "pronominar",
    "pronominarão": "pronominar",
    "pronominaríamos": "pronominar",
    "pronominaríeis": "pronominar",
    "pronominas": "pronominar",
    "pronominasse": "pronominar",
    "pronominassem": "pronominar",
    "pronominasses": "pronominar",
    "pronominaste": "pronominar",
    "pronominastes": "pronominar",
    "pronominava": "pronominar",
    "pronominavam": "pronominar",
    "pronominavas": "pronominar",
    "pronomine": "pronominar",
    "pronominei": "pronominar",
    "pronomineis": "pronominar",
    "pronominem": "pronominar",
    "pronominemo": "pronominar",
    "pronominemos": "pronominar",
    "pronomines": "pronominar",
    "pronomino": "pronominar",
    "pronominou": "pronominar",
    "pronominá": "pronominar",
    "pronominámo": "pronominar",
    "pronominámos": "pronominar",
    "pronomináramo": "pronominar",
    "pronomináramos": "pronominar",
    "pronominárei": "pronominar",
    "pronomináreis": "pronominar",
    "pronominásseis": "pronominar",
    "pronominássemos": "pronominar",
    "pronominávamo": "pronominar",
    "pronominávamos": "pronominar",
    "pronominávei": "pronominar",
    "pronomináveis": "pronominar",
    "pronos": "prono",
    "pronotos": "pronoto",
    "pronta": "pronto",
    "prontas": "pronto",
    "prontazinha": "pronto",
    "prontazinhas": "pronto",
    "prontazita": "pronto",
    "prontazitas": "pronto",
    "prontidões": "prontidão",
    "prontifica": "prontificar",
    "prontificada": "prontificar",
    "prontificadas": "prontificar",
    "prontificado": "prontificar",
    "prontificados": "prontificar",
    "prontificai": "prontificar",
    "prontificais": "prontificar",
    "prontificam": "prontificar",
    "prontificamo": "prontificar",
    "prontificamos": "prontificar",
    "prontificando": "prontificar",
    "prontificara": "prontificar",
    "prontificaram": "prontificar",
    "prontificaras": "prontificar",
    "prontificarde": "prontificar",
    "prontificardes": "prontificar",
    "prontificare": "prontificar",
    "prontificarei": "prontificar",
    "prontificareis": "prontificar",
    "prontificarem": "prontificar",
    "prontificaremos": "prontificar",
    "prontificares": "prontificar",
    "prontificaria": "prontificar",
    "prontificariam": "prontificar",
    "prontificarias": "prontificar",
    "prontificarmo": "prontificar",
    "prontificarmos": "prontificar",
    "prontificará": "prontificar",
    "prontificarás": "prontificar",
    "prontificarão": "prontificar",
    "prontificaríamos": "prontificar",
    "prontificaríeis": "prontificar",
    "prontificas": "prontificar",
    "prontificasse": "prontificar",
    "prontificassem": "prontificar",
    "prontificasses": "prontificar",
    "prontificaste": "prontificar",
    "prontificastes": "prontificar",
    "prontificava": "prontificar",
    "prontificavam": "prontificar",
    "prontificavas": "prontificar",
    "prontificações": "prontificação",
    "prontifico": "prontificar",
    "prontificou": "prontificar",
    "prontificá": "prontificar",
    "prontificámo": "prontificar",
    "prontificámos": "prontificar",
    "prontificáramo": "prontificar",
    "prontificáramos": "prontificar",
    "prontificárei": "prontificar",
    "prontificáreis": "prontificar",
    "prontificásseis": "prontificar",
    "prontificássemos": "prontificar",
    "prontificávamo": "prontificar",
    "prontificávamos": "prontificar",
    "prontificávei": "prontificar",
    "prontificáveis": "prontificar",
    "prontifique": "prontificar",
    "prontifiquei": "prontificar",
    "prontifiqueis": "prontificar",
    "prontifiquem": "prontificar",
    "prontifiquemo": "prontificar",
    "prontifiquemos": "prontificar",
    "prontifiques": "prontificar",
    "prontinha": "pronto",
    "prontinhas": "pronto",
    "prontinho": "pronto",
    "prontinhos": "pronto",
    "prontita": "pronto",
    "prontitas": "pronto",
    "prontito": "pronto",
    "prontitos": "pronto",
    "prontos": "pronto",
    "prontozinho": "pronto",
    "prontozinhos": "pronto",
    "prontozito": "pronto",
    "prontozitos": "pronto",
    "prontuários": "prontuário",
    "prontíssima": "pronto",
    "prontíssimas": "pronto",
    "prontíssimo": "pronto",
    "prontíssimos": "pronto",
    "pronuncia": "pronunciar",
    "pronunciada": "pronunciar",
    "pronunciadas": "pronunciar",
    "pronunciadinha": "pronunciado",
    "pronunciadinhas": "pronunciado",
    "pronunciadinho": "pronunciado",
    "pronunciadinhos": "pronunciado",
    "pronunciadita": "pronunciado",
    "pronunciaditas": "pronunciado",
    "pronunciadito": "pronunciado",
    "pronunciaditos": "pronunciado",
    "pronunciado": "pronunciar",
    "pronunciados": "pronunciar",
    "pronunciadíssima": "pronunciado",
    "pronunciadíssimas": "pronunciado",
    "pronunciadíssimo": "pronunciado",
    "pronunciadíssimos": "pronunciado",
    "pronunciai": "pronunciar",
    "pronunciais": "pronunciar",
    "pronunciam": "pronunciar",
    "pronunciamentos": "pronunciamento",
    "pronunciamo": "pronunciar",
    "pronunciamos": "pronunciar",
    "pronunciando": "pronunciar",
    "pronunciara": "pronunciar",
    "pronunciaram": "pronunciar",
    "pronunciaras": "pronunciar",
    "pronunciarde": "pronunciar",
    "pronunciardes": "pronunciar",
    "pronunciare": "pronunciar",
    "pronunciarei": "pronunciar",
    "pronunciareis": "pronunciar",
    "pronunciarem": "pronunciar",
    "pronunciaremos": "pronunciar",
    "pronunciares": "pronunciar",
    "pronunciaria": "pronunciar",
    "pronunciariam": "pronunciar",
    "pronunciarias": "pronunciar",
    "pronunciarmo": "pronunciar",
    "pronunciarmos": "pronunciar",
    "pronunciará": "pronunciar",
    "pronunciarás": "pronunciar",
    "pronunciarão": "pronunciar",
    "pronunciaríamos": "pronunciar",
    "pronunciaríeis": "pronunciar",
    "pronuncias": "pronunciar",
    "pronunciasse": "pronunciar",
    "pronunciassem": "pronunciar",
    "pronunciasses": "pronunciar",
    "pronunciaste": "pronunciar",
    "pronunciastes": "pronunciar",
    "pronunciava": "pronunciar",
    "pronunciavam": "pronunciar",
    "pronunciavas": "pronunciar",
    "pronunciações": "pronunciação",
    "pronuncie": "pronunciar",
    "pronunciei": "pronunciar",
    "pronuncieis": "pronunciar",
    "pronunciem": "pronunciar",
    "pronunciemo": "pronunciar",
    "pronunciemos": "pronunciar",
    "pronuncies": "pronunciar",
    "pronuncio": "pronunciar",
    "pronunciou": "pronunciar",
    "pronunciá": "pronunciar",
    "pronunciámo": "pronunciar",
    "pronunciámos": "pronunciar",
    "pronunciáramo": "pronunciar",
    "pronunciáramos": "pronunciar",
    "pronunciárei": "pronunciar",
    "pronunciáreis": "pronunciar",
    "pronunciásseis": "pronunciar",
    "pronunciássemos": "pronunciar",
    "pronunciávamo": "pronunciar",
    "pronunciávamos": "pronunciar",
    "pronunciávei": "pronunciar",
    "pronunciáveis": "pronunciável",
    "pronígrada": "pronígrado",
    "pronígradas": "pronígrado",
    "pronígrados": "pronígrado",
    "pronóstica": "pronóstico",
    "pronósticas": "pronóstico",
    "pronósticos": "pronóstico",
    "pronúcleos": "pronúcleo",
    "pronúncias": "pronúncia",
    "pronúncios": "pronúncio",
    "proo": "proar",
    "proou": "proar",
    "propaga": "propagar",
    "propagada": "propagar",
    "propagadas": "propagar",
    "propagado": "propagar",
    "propagadora": "propagador",
    "propagadoras": "propagador",
    "propagadores": "propagador",
    "propagados": "propagar",
    "propagai": "propagar",
    "propagais": "propagar",
    "propagam": "propagar",
    "propagamo": "propagar",
    "propagamos": "propagar",
    "propagandas": "propaganda",
    "propagandeada": "propagandear",
    "propagandeadas": "propagandear",
    "propagandeado": "propagandear",
    "propagandeados": "propagandear",
    "propagandeai": "propagandear",
    "propagandeais": "propagandear",
    "propagandeamo": "propagandear",
    "propagandeamos": "propagandear",
    "propagandeando": "propagandear",
    "propagandeara": "propagandear",
    "propagandearam": "propagandear",
    "propagandearas": "propagandear",
    "propagandearde": "propagandear",
    "propagandeardes": "propagandear",
    "propagandeare": "propagandear",
    "propagandearei": "propagandear",
    "propagandeareis": "propagandear",
    "propagandearem": "propagandear",
    "propagandearemos": "propagandear",
    "propagandeares": "propagandear",
    "propagandearia": "propagandear",
    "propagandeariam": "propagandear",
    "propagandearias": "propagandear",
    "propagandearmo": "propagandear",
    "propagandearmos": "propagandear",
    "propagandeará": "propagandear",
    "propagandearás": "propagandear",
    "propagandearão": "propagandear",
    "propagandearíamos": "propagandear",
    "propagandearíeis": "propagandear",
    "propagandeasse": "propagandear",
    "propagandeassem": "propagandear",
    "propagandeasses": "propagandear",
    "propagandeaste": "propagandear",
    "propagandeastes": "propagandear",
    "propagandeava": "propagandear",
    "propagandeavam": "propagandear",
    "propagandeavas": "propagandear",
    "propagandeei": "propagandear",
    "propagandeeis": "propagandear",
    "propagandeemo": "propagandear",
    "propagandeemos": "propagandear",
    "propagandeia": "propagandear",
    "propagandeiam": "propagandear",
    "propagandeias": "propagandear",
    "propagandeie": "propagandear",
    "propagandeiem": "propagandear",
    "propagandeies": "propagandear",
    "propagandeio": "propagandear",
    "propagandeou": "propagandear",
    "propagandeá": "propagandear",
    "propagandeámo": "propagandear",
    "propagandeámos": "propagandear",
    "propagandeáramo": "propagandear",
    "propagandeáramos": "propagandear",
    "propagandeárei": "propagandear",
    "propagandeáreis": "propagandear",
    "propagandeásseis": "propagandear",
    "propagandeássemos": "propagandear",
    "propagandeávamo": "propagandear",
    "propagandeávamos": "propagandear",
    "propagandeávei": "propagandear",
    "propagandeáveis": "propagandear",
    "propagandistas": "propagandista",
    "propagando": "propagar",
    "propagandística": "propagandístico",
    "propagandísticas": "propagandístico",
    "propagandísticos": "propagandístico",
    "propagara": "propagar",
    "propagaram": "propagar",
    "propagaras": "propagar",
    "propagarde": "propagar",
    "propagardes": "propagar",
    "propagare": "propagar",
    "propagarei": "propagar",
    "propagareis": "propagar",
    "propagarem": "propagar",
    "propagaremos": "propagar",
    "propagares": "propagar",
    "propagaria": "propagar",
    "propagariam": "propagar",
    "propagarias": "propagar",
    "propagarmo": "propagar",
    "propagarmos": "propagar",
    "propagará": "propagar",
    "propagarás": "propagar",
    "propagarão": "propagar",
    "propagaríamos": "propagar",
    "propagaríeis": "propagar",
    "propagas": "propagar",
    "propagasse": "propagar",
    "propagassem": "propagar",
    "propagasses": "propagar",
    "propagaste": "propagar",
    "propagastes": "propagar",
    "propagativa": "propagativo",
    "propagativas": "propagativo",
    "propagativos": "propagativo",
    "propagava": "propagar",
    "propagavam": "propagar",
    "propagavas": "propagar",
    "propagações": "propagação",
    "propago": "propagar",
    "propagou": "propagar",
    "propague": "propagar",
    "propaguei": "propagar",
    "propagueis": "propagar",
    "propaguem": "propagar",
    "propaguemo": "propagar",
    "propaguemos": "propagar",
    "propagues": "propagar",
    "propagá": "propagar",
    "propagámo": "propagar",
    "propagámos": "propagar",
    "propagáramo": "propagar",
    "propagáramos": "propagar",
    "propagárei": "propagar",
    "propagáreis": "propagar",
    "propagásseis": "propagar",
    "propagássemos": "propagar",
    "propagávamo": "propagar",
    "propagávamos": "propagar",
    "propagávei": "propagar",
    "propagáveis": "propagável",
    "propala": "propalar",
    "propalada": "propalar",
    "propaladas": "propalar",
    "propalado": "propalar",
    "propaladora": "propalador",
    "propaladoras": "propalador",
    "propaladores": "propalador",
    "propalados": "propalar",
    "propalai": "propalar",
    "propalais": "propalar",
    "propalam": "propalar",
    "propalamo": "propalar",
    "propalamos": "propalar",
    "propalando": "propalar",
    "propalara": "propalar",
    "propalaram": "propalar",
    "propalaras": "propalar",
    "propalarde": "propalar",
    "propalardes": "propalar",
    "propalare": "propalar",
    "propalarei": "propalar",
    "propalareis": "propalar",
    "propalarem": "propalar",
    "propalaremos": "propalar",
    "propalares": "propalar",
    "propalaria": "propalar",
    "propalariam": "propalar",
    "propalarias": "propalar",
    "propalarmo": "propalar",
    "propalarmos": "propalar",
    "propalará": "propalar",
    "propalarás": "propalar",
    "propalarão": "propalar",
    "propalaríamos": "propalar",
    "propalaríeis": "propalar",
    "propalas": "propalar",
    "propalasse": "propalar",
    "propalassem": "propalar",
    "propalasses": "propalar",
    "propalaste": "propalar",
    "propalastes": "propalar",
    "propalava": "propalar",
    "propalavam": "propalar",
    "propalavas": "propalar",
    "propale": "propalar",
    "propalei": "propalar",
    "propaleis": "propalar",
    "propalem": "propalar",
    "propalemo": "propalar",
    "propalemos": "propalar",
    "propales": "propalar",
    "propalo": "propalar",
    "propalou": "propalar",
    "propalá": "propalar",
    "propalámo": "propalar",
    "propalámos": "propalar",
    "propaláramo": "propalar",
    "propaláramos": "propalar",
    "propalárei": "propalar",
    "propaláreis": "propalar",
    "propalásseis": "propalar",
    "propalássemos": "propalar",
    "propalávamo": "propalar",
    "propalávamos": "propalar",
    "propalávei": "propalar",
    "propaláveis": "propalar",
    "propanonas": "propanona",
    "propanos": "propano",
    "proparoxítona": "proparoxítono",
    "proparoxítonas": "proparoxítono",
    "proparoxítonos": "proparoxítono",
    "propatias": "propatia",
    "propedeutas": "propedeuta",
    "propedêutica": "propedêutico",
    "propedêuticas": "propedêutico",
    "propedêuticos": "propedêutico",
    "propele": "propelir",
    "propelem": "propelir",
    "propeles": "propelir",
    "propeli": "propelir",
    "propelia": "propelir",
    "propeliam": "propelir",
    "propelias": "propelir",
    "propelida": "propelir",
    "propelidas": "propelir",
    "propelido": "propelir",
    "propelidos": "propelir",
    "propelimo": "propelir",
    "propelimos": "propelir",
    "propelindo": "propelir",
    "propelira": "propelir",
    "propeliram": "propelir",
    "propeliras": "propelir",
    "propelirde": "propelir",
    "propelirdes": "propelir",
    "propelire": "propelir",
    "propelirei": "propelir",
    "propelireis": "propelir",
    "propelirem": "propelir",
    "propeliremos": "propelir",
    "propelires": "propelir",
    "propeliria": "propelir",
    "propeliriam": "propelir",
    "propelirias": "propelir",
    "propelirmo": "propelir",
    "propelirmos": "propelir",
    "propelirá": "propelir",
    "propelirás": "propelir",
    "propelirão": "propelir",
    "propeliríamos": "propelir",
    "propeliríeis": "propelir",
    "propelis": "propelir",
    "propelisse": "propelir",
    "propelissem": "propelir",
    "propelisses": "propelir",
    "propeliste": "propelir",
    "propelistes": "propelir",
    "propeliu": "propelir",
    "propelíamo": "propelir",
    "propelíamos": "propelir",
    "propelíei": "propelir",
    "propelíeis": "propelir",
    "propelíramo": "propelir",
    "propelíramos": "propelir",
    "propelírei": "propelir",
    "propelíreis": "propelir",
    "propelísseis": "propelir",
    "propelíssemos": "propelir",
    "propenal": "propena",
    "propenas": "propena",
    "propenda": "propender",
    "propendais": "propender",
    "propendam": "propender",
    "propendamo": "propender",
    "propendamos": "propender",
    "propendas": "propender",
    "propende": "propender",
    "propendei": "propender",
    "propendeis": "propender",
    "propendem": "propender",
    "propendemo": "propender",
    "propendemos": "propender",
    "propendendo": "propender",
    "propendentes": "propendente",
    "propendera": "propender",
    "propenderam": "propender",
    "propenderas": "propender",
    "propenderdes": "propender",
    "propenderei": "propender",
    "propendereis": "propender",
    "propenderem": "propender",
    "propenderemos": "propender",
    "propenderes": "propender",
    "propenderia": "propender",
    "propenderiam": "propender",
    "propenderias": "propender",
    "propendermo": "propender",
    "propendermos": "propender",
    "propenderá": "propender",
    "propenderás": "propender",
    "propenderão": "propender",
    "propenderíamos": "propender",
    "propenderíeis": "propender",
    "propendes": "propender",
    "propendesse": "propender",
    "propendessem": "propender",
    "propendesses": "propender",
    "propendeste": "propender",
    "propendestes": "propender",
    "propendeu": "propender",
    "propendi": "propender",
    "propendia": "propender",
    "propendiam": "propender",
    "propendias": "propender",
    "propendida": "propender",
    "propendidas": "propender",
    "propendido": "propender",
    "propendidos": "propender",
    "propendo": "propender",
    "propendêramo": "propender",
    "propendêramos": "propender",
    "propendêreis": "propender",
    "propendêsseis": "propender",
    "propendêssemos": "propender",
    "propendíamo": "propender",
    "propendíamos": "propender",
    "propendíeis": "propender",
    "propenos": "propeno",
    "propensa": "propenso",
    "propensas": "propenso",
    "propensos": "propenso",
    "propensões": "propensão",
    "propenálica": "propenálico",
    "propenálicas": "propenálico",
    "propenálicos": "propenálico",
    "propenóica": "propenóico",
    "propenóicas": "propenóico",
    "propenóicos": "propenóico",
    "propianhos": "propianho",
    "propicia": "propiciar",
    "propiciada": "propiciar",
    "propiciadas": "propiciar",
    "propiciado": "propiciar",
    "propiciadora": "propiciador",
    "propiciadoras": "propiciador",
    "propiciadores": "propiciador",
    "propiciados": "propiciar",
    "propiciai": "propiciar",
    "propiciais": "propiciar",
    "propiciam": "propiciar",
    "propiciamo": "propiciar",
    "propiciamos": "propiciar",
    "propiciando": "propiciar",
    "propiciara": "propiciar",
    "propiciaram": "propiciar",
    "propiciaras": "propiciar",
    "propiciarde": "propiciar",
    "propiciardes": "propiciar",
    "propiciare": "propiciar",
    "propiciarei": "propiciar",
    "propiciareis": "propiciar",
    "propiciarem": "propiciar",
    "propiciaremos": "propiciar",
    "propiciares": "propiciar",
    "propiciaria": "propiciar",
    "propiciariam": "propiciar",
    "propiciarias": "propiciar",
    "propiciarmo": "propiciar",
    "propiciarmos": "propiciar",
    "propiciará": "propiciar",
    "propiciarás": "propiciar",
    "propiciarão": "propiciar",
    "propiciaríamos": "propiciar",
    "propiciaríeis": "propiciar",
    "propicias": "propiciar",
    "propiciasse": "propiciar",
    "propiciassem": "propiciar",
    "propiciasses": "propiciar",
    "propiciaste": "propiciar",
    "propiciastes": "propiciar",
    "propiciatória": "propiciatório",
    "propiciatórias": "propiciatório",
    "propiciatórios": "propiciatório",
    "propiciava": "propiciar",
    "propiciavam": "propiciar",
    "propiciavas": "propiciar",
    "propiciações": "propiciação",
    "propicie": "propiciar",
    "propiciei": "propiciar",
    "propicieis": "propiciar",
    "propiciem": "propiciar",
    "propiciemo": "propiciar",
    "propiciemos": "propiciar",
    "propicies": "propiciar",
    "propicio": "propiciar",
    "propiciou": "propiciar",
    "propiciá": "propiciar",
    "propiciámo": "propiciar",
    "propiciámos": "propiciar",
    "propiciáramo": "propiciar",
    "propiciáramos": "propiciar",
    "propiciárei": "propiciar",
    "propiciáreis": "propiciar",
    "propiciásseis": "propiciar",
    "propiciássemos": "propiciar",
    "propiciávamo": "propiciar",
    "propiciávamos": "propiciar",
    "propiciávei": "propiciar",
    "propiciáveis": "propiciar",
    "propila": "propelir",
    "propilais": "propelir",
    "propilam": "propelir",
    "propilamo": "propelir",
    "propilamos": "propelir",
    "propilas": "propelir",
    "propileus": "propileu",
    "propilo": "propelir",
    "propina": "propinar",
    "propinada": "propinar",
    "propinadas": "propinar",
    "propinado": "propinar",
    "propinadora": "propinador",
    "propinadoras": "propinador",
    "propinadores": "propinador",
    "propinados": "propinar",
    "propinai": "propinar",
    "propinais": "propinar",
    "propinam": "propinar",
    "propinamo": "propinar",
    "propinamos": "propinar",
    "propinando": "propinar",
    "propinara": "propinar",
    "propinaram": "propinar",
    "propinaras": "propinar",
    "propinarde": "propinar",
    "propinardes": "propinar",
    "propinare": "propinar",
    "propinarei": "propinar",
    "propinareis": "propinar",
    "propinarem": "propinar",
    "propinaremos": "propinar",
    "propinares": "propinar",
    "propinaria": "propinar",
    "propinariam": "propinar",
    "propinarias": "propinar",
    "propinarmo": "propinar",
    "propinarmos": "propinar",
    "propinará": "propinar",
    "propinarás": "propinar",
    "propinarão": "propinar",
    "propinaríamos": "propinar",
    "propinaríeis": "propinar",
    "propinas": "propinar",
    "propinasse": "propinar",
    "propinassem": "propinar",
    "propinasses": "propinar",
    "propinaste": "propinar",
    "propinastes": "propinar",
    "propinava": "propinar",
    "propinavam": "propinar",
    "propinavas": "propinar",
    "propinações": "propinação",
    "propine": "propinar",
    "propinei": "propinar",
    "propineis": "propinar",
    "propinem": "propinar",
    "propinemo": "propinar",
    "propinemos": "propinar",
    "propines": "propinar",
    "propino": "propinar",
    "propinou": "propinar",
    "propinquidades": "propinquidade",
    "propiná": "propinar",
    "propinámo": "propinar",
    "propinámos": "propinar",
    "propináramo": "propinar",
    "propináramos": "propinar",
    "propinárei": "propinar",
    "propináreis": "propinar",
    "propinásseis": "propinar",
    "propinássemos": "propinar",
    "propinávamo": "propinar",
    "propinávamos": "propinar",
    "propinávei": "propinar",
    "propináveis": "propinar",
    "propitecos": "propiteco",
    "proplástica": "proplástico",
    "proplásticas": "proplástico",
    "proplásticos": "proplástico",
    "propolisações": "propolisação",
    "propoliza": "propolizar",
    "propolizada": "propolizar",
    "propolizadas": "propolizar",
    "propolizado": "propolizar",
    "propolizados": "propolizar",
    "propolizai": "propolizar",
    "propolizais": "propolizar",
    "propolizam": "propolizar",
    "propolizamo": "propolizar",
    "propolizamos": "propolizar",
    "propolizando": "propolizar",
    "propolizara": "propolizar",
    "propolizaram": "propolizar",
    "propolizaras": "propolizar",
    "propolizarde": "propolizar",
    "propolizardes": "propolizar",
    "propolizare": "propolizar",
    "propolizarei": "propolizar",
    "propolizareis": "propolizar",
    "propolizarem": "propolizar",
    "propolizaremos": "propolizar",
    "propolizares": "propolizar",
    "propolizaria": "propolizar",
    "propolizariam": "propolizar",
    "propolizarias": "propolizar",
    "propolizarmo": "propolizar",
    "propolizarmos": "propolizar",
    "propolizará": "propolizar",
    "propolizarás": "propolizar",
    "propolizarão": "propolizar",
    "propolizaríamos": "propolizar",
    "propolizaríeis": "propolizar",
    "propolizas": "propolizar",
    "propolizasse": "propolizar",
    "propolizassem": "propolizar",
    "propolizasses": "propolizar",
    "propolizaste": "propolizar",
    "propolizastes": "propolizar",
    "propolizava": "propolizar",
    "propolizavam": "propolizar",
    "propolizavas": "propolizar",
    "propolize": "propolizar",
    "propolizei": "propolizar",
    "propolizeis": "propolizar",
    "propolizem": "propolizar",
    "propolizemo": "propolizar",
    "propolizemos": "propolizar",
    "propolizes": "propolizar",
    "propolizo": "propolizar",
    "propolizou": "propolizar",
    "propolizá": "propolizar",
    "propolizámo": "propolizar",
    "propolizámos": "propolizar",
    "propolizáramo": "propolizar",
    "propolizáramos": "propolizar",
    "propolizárei": "propolizar",
    "propolizáreis": "propolizar",
    "propolizásseis": "propolizar",
    "propolizássemos": "propolizar",
    "propolizávamo": "propolizar",
    "propolizávamos": "propolizar",
    "propolizávei": "propolizar",
    "propolizáveis": "propolizar",
    "propomo": "propor",
    "propomos": "propor",
    "proponde": "propor",
    "propondes": "propor",
    "propondo": "propor",
    "proponentes": "proponente",
    "proponha": "propor",
    "proponhais": "propor",
    "proponham": "propor",
    "proponhamo": "propor",
    "proponhamos": "propor",
    "proponhas": "propor",
    "proponho": "propor",
    "proponíveis": "proponível",
    "proporciona": "proporcionar",
    "proporcionada": "proporcionar",
    "proporcionadas": "proporcionar",
    "proporcionadinha": "proporcionado",
    "proporcionadinhas": "proporcionado",
    "proporcionadinho": "proporcionado",
    "proporcionadinhos": "proporcionado",
    "proporcionadita": "proporcionado",
    "proporcionaditas": "proporcionado",
    "proporcionadito": "proporcionado",
    "proporcionaditos": "proporcionado",
    "proporcionado": "proporcionar",
    "proporcionadora": "proporcionador",
    "proporcionadoras": "proporcionador",
    "proporcionadores": "proporcionador",
    "proporcionados": "proporcionar",
    "proporcionadíssima": "proporcionado",
    "proporcionadíssimas": "proporcionado",
    "proporcionadíssimo": "proporcionado",
    "proporcionadíssimos": "proporcionado",
    "proporcionai": "proporcionar",
    "proporcionais": "proporcionar",
    "proporcionalidades": "proporcionalidade",
    "proporcionam": "proporcionar",
    "proporcionamo": "proporcionar",
    "proporcionamos": "proporcionar",
    "proporcionando": "proporcionar",
    "proporcionara": "proporcionar",
    "proporcionaram": "proporcionar",
    "proporcionaras": "proporcionar",
    "proporcionarde": "proporcionar",
    "proporcionardes": "proporcionar",
    "proporcionare": "proporcionar",
    "proporcionarei": "proporcionar",
    "proporcionareis": "proporcionar",
    "proporcionarem": "proporcionar",
    "proporcionaremos": "proporcionar",
    "proporcionares": "proporcionar",
    "proporcionaria": "proporcionar",
    "proporcionariam": "proporcionar",
    "proporcionarias": "proporcionar",
    "proporcionarmo": "proporcionar",
    "proporcionarmos": "proporcionar",
    "proporcionará": "proporcionar",
    "proporcionarás": "proporcionar",
    "proporcionarão": "proporcionar",
    "proporcionaríamos": "proporcionar",
    "proporcionaríeis": "proporcionar",
    "proporcionas": "proporcionar",
    "proporcionasse": "proporcionar",
    "proporcionassem": "proporcionar",
    "proporcionasses": "proporcionar",
    "proporcionaste": "proporcionar",
    "proporcionastes": "proporcionar",
    "proporcionava": "proporcionar",
    "proporcionavam": "proporcionar",
    "proporcionavas": "proporcionar",
    "proporcione": "proporcionar",
    "proporcionei": "proporcionar",
    "proporcioneis": "proporcionar",
    "proporcionem": "proporcionar",
    "proporcionemo": "proporcionar",
    "proporcionemos": "proporcionar",
    "proporciones": "proporcionar",
    "proporciono": "proporcionar",
    "proporcionou": "proporcionar",
    "proporcioná": "proporcionar",
    "proporcionámo": "proporcionar",
    "proporcionámos": "proporcionar",
    "proporcionáramo": "proporcionar",
    "proporcionáramos": "proporcionar",
    "proporcionárei": "proporcionar",
    "proporcionáreis": "proporcionar",
    "proporcionásseis": "proporcionar",
    "proporcionássemos": "proporcionar",
    "proporcionávamo": "proporcionar",
    "proporcionávamos": "proporcionar",
    "proporcionávei": "proporcionar",
    "proporcionáveis": "proporcionável",
    "proporde": "propor",
    "propordes": "propor",
    "propore": "propor",
    "proporei": "propor",
    "proporeis": "propor",
    "proporem": "propor",
    "proporemos": "propor",
    "propores": "propor",
    "proporia": "propor",
    "proporiam": "propor",
    "proporias": "propor",
    "propormo": "propor",
    "propormos": "propor",
    "proporá": "propor",
    "proporás": "propor",
    "proporão": "propor",
    "proporções": "proporção",
    "proporíamos": "propor",
    "proporíeis": "propor",
    "proposicionais": "proposicional",
    "propositada": "propositado",
    "propositadas": "propositado",
    "propositados": "propositado",
    "proposituras": "propositura",
    "proposições": "proposição",
    "proposta": "proposto",
    "propostas": "proposto",
    "proposto": "propor",
    "propostos": "proposto",
    "propriadora": "propriador",
    "propriadoras": "propriador",
    "propriadores": "propriador",
    "propriagens": "propriagem",
    "propriedades": "propriedade",
    "proprietariados": "proprietariado",
    "proprietária": "proprietário",
    "proprietárias": "proprietário",
    "proprietários": "proprietário",
    "proprioceptiva": "proprioceptivo",
    "proprioceptivas": "proprioceptivo",
    "proprioceptivos": "proprioceptivo",
    "proprioceptora": "proprioceptor",
    "proprioceptoras": "proprioceptor",
    "proprioceptores": "proprioceptor",
    "proprioplástica": "proprioplástico",
    "proprioplásticas": "proprioplástico",
    "proprioplásticos": "proprioplástico",
    "propriíssima": "próprio",
    "propriíssimas": "próprio",
    "propriíssimo": "próprio",
    "propriíssimos": "próprio",
    "proptomas": "proptoma",
    "proptoses": "proptose",
    "proptómica": "proptómico",
    "proptómicas": "proptómico",
    "proptómicos": "proptómico",
    "proptótica": "proptótico",
    "proptóticas": "proptótico",
    "proptóticos": "proptótico",
    "propugna": "propugnar",
    "propugnada": "propugnar",
    "propugnadas": "propugnar",
    "propugnado": "propugnar",
    "propugnadora": "propugnador",
    "propugnadoras": "propugnador",
    "propugnadores": "propugnador",
    "propugnados": "propugnar",
    "propugnai": "propugnar",
    "propugnais": "propugnar",
    "propugnam": "propugnar",
    "propugnamo": "propugnar",
    "propugnamos": "propugnar",
    "propugnando": "propugnar",
    "propugnara": "propugnar",
    "propugnaram": "propugnar",
    "propugnaras": "propugnar",
    "propugnarde": "propugnar",
    "propugnardes": "propugnar",
    "propugnare": "propugnar",
    "propugnarei": "propugnar",
    "propugnareis": "propugnar",
    "propugnarem": "propugnar",
    "propugnaremos": "propugnar",
    "propugnares": "propugnar",
    "propugnaria": "propugnar",
    "propugnariam": "propugnar",
    "propugnarias": "propugnar",
    "propugnarmo": "propugnar",
    "propugnarmos": "propugnar",
    "propugnará": "propugnar",
    "propugnarás": "propugnar",
    "propugnarão": "propugnar",
    "propugnaríamos": "propugnar",
    "propugnaríeis": "propugnar",
    "propugnas": "propugnar",
    "propugnasse": "propugnar",
    "propugnassem": "propugnar",
    "propugnasses": "propugnar",
    "propugnaste": "propugnar",
    "propugnastes": "propugnar",
    "propugnava": "propugnar",
    "propugnavam": "propugnar",
    "propugnavas": "propugnar",
    "propugnações": "propugnação",
    "propugne": "propugnar",
    "propugnei": "propugnar",
    "propugneis": "propugnar",
    "propugnem": "propugnar",
    "propugnemo": "propugnar",
    "propugnemos": "propugnar",
    "propugnes": "propugnar",
    "propugno": "propugnar",
    "propugnou": "propugnar",
    "propugná": "propugnar",
    "propugnáculos": "propugnáculo",
    "propugnámo": "propugnar",
    "propugnámos": "propugnar",
    "propugnáramo": "propugnar",
    "propugnáramos": "propugnar",
    "propugnárei": "propugnar",
    "propugnáreis": "propugnar",
    "propugnásseis": "propugnar",
    "propugnássemos": "propugnar",
    "propugnávamo": "propugnar",
    "propugnávamos": "propugnar",
    "propugnávei": "propugnar",
    "propugnáveis": "propugnar",
    "propulsa": "propulsar",
    "propulsada": "propulsar",
    "propulsadas": "propulsar",
    "propulsado": "propulsar",
    "propulsados": "propulsar",
    "propulsai": "propulsar",
    "propulsais": "propulsar",
    "propulsam": "propulsar",
    "propulsamo": "propulsar",
    "propulsamos": "propulsar",
    "propulsando": "propulsar",
    "propulsara": "propulsar",
    "propulsaram": "propulsar",
    "propulsaras": "propulsar",
    "propulsarde": "propulsar",
    "propulsardes": "propulsar",
    "propulsare": "propulsar",
    "propulsarei": "propulsar",
    "propulsareis": "propulsar",
    "propulsarem": "propulsar",
    "propulsaremos": "propulsar",
    "propulsares": "propulsar",
    "propulsaria": "propulsar",
    "propulsariam": "propulsar",
    "propulsarias": "propulsar",
    "propulsarmo": "propulsar",
    "propulsarmos": "propulsar",
    "propulsará": "propulsar",
    "propulsarás": "propulsar",
    "propulsarão": "propulsar",
    "propulsaríamos": "propulsar",
    "propulsaríeis": "propulsar",
    "propulsas": "propulsar",
    "propulsasse": "propulsar",
    "propulsassem": "propulsar",
    "propulsasses": "propulsar",
    "propulsaste": "propulsar",
    "propulsastes": "propulsar",
    "propulsava": "propulsar",
    "propulsavam": "propulsar",
    "propulsavas": "propulsar",
    "propulse": "propulsar",
    "propulsei": "propulsar",
    "propulseis": "propulsar",
    "propulsem": "propulsar",
    "propulsemo": "propulsar",
    "propulsemos": "propulsar",
    "propulses": "propulsar",
    "propulsiona": "propulsionar",
    "propulsionada": "propulsionar",
    "propulsionadas": "propulsionar",
    "propulsionado": "propulsionar",
    "propulsionadora": "propulsionador",
    "propulsionadoras": "propulsionador",
    "propulsionadores": "propulsionador",
    "propulsionados": "propulsionar",
    "propulsionai": "propulsionar",
    "propulsionais": "propulsionar",
    "propulsionam": "propulsionar",
    "propulsionamo": "propulsionar",
    "propulsionamos": "propulsionar",
    "propulsionando": "propulsionar",
    "propulsionara": "propulsionar",
    "propulsionaram": "propulsionar",
    "propulsionaras": "propulsionar",
    "propulsionarde": "propulsionar",
    "propulsionardes": "propulsionar",
    "propulsionare": "propulsionar",
    "propulsionarei": "propulsionar",
    "propulsionareis": "propulsionar",
    "propulsionarem": "propulsionar",
    "propulsionaremos": "propulsionar",
    "propulsionares": "propulsionar",
    "propulsionaria": "propulsionar",
    "propulsionariam": "propulsionar",
    "propulsionarias": "propulsionar",
    "propulsionarmo": "propulsionar",
    "propulsionarmos": "propulsionar",
    "propulsionará": "propulsionar",
    "propulsionarás": "propulsionar",
    "propulsionarão": "propulsionar",
    "propulsionaríamos": "propulsionar",
    "propulsionaríeis": "propulsionar",
    "propulsionas": "propulsionar",
    "propulsionasse": "propulsionar",
    "propulsionassem": "propulsionar",
    "propulsionasses": "propulsionar",
    "propulsionaste": "propulsionar",
    "propulsionastes": "propulsionar",
    "propulsionava": "propulsionar",
    "propulsionavam": "propulsionar",
    "propulsionavas": "propulsionar",
    "propulsione": "propulsionar",
    "propulsionei": "propulsionar",
    "propulsioneis": "propulsionar",
    "propulsionem": "propulsionar",
    "propulsionemo": "propulsionar",
    "propulsionemos": "propulsionar",
    "propulsiones": "propulsionar",
    "propulsiono": "propulsionar",
    "propulsionou": "propulsionar",
    "propulsioná": "propulsionar",
    "propulsionámo": "propulsionar",
    "propulsionámos": "propulsionar",
    "propulsionáramo": "propulsionar",
    "propulsionáramos": "propulsionar",
    "propulsionárei": "propulsionar",
    "propulsionáreis": "propulsionar",
    "propulsionásseis": "propulsionar",
    "propulsionássemos": "propulsionar",
    "propulsionávamo": "propulsionar",
    "propulsionávamos": "propulsionar",
    "propulsionávei": "propulsionar",
    "propulsionáveis": "propulsionar",
    "propulsiva": "propulsivo",
    "propulsivas": "propulsivo",
    "propulsivos": "propulsivo",
    "propulso": "propulsar",
    "propulsora": "propulsor",
    "propulsoras": "propulsor",
    "propulsores": "propulsor",
    "propulsou": "propulsar",
    "propulsá": "propulsar",
    "propulsámo": "propulsar",
    "propulsámos": "propulsar",
    "propulsáramo": "propulsar",
    "propulsáramos": "propulsar",
    "propulsárei": "propulsar",
    "propulsáreis": "propulsar",
    "propulsásseis": "propulsar",
    "propulsássemos": "propulsar",
    "propulsávamo": "propulsar",
    "propulsávamos": "propulsar",
    "propulsávei": "propulsar",
    "propulsáveis": "propulsar",
    "propulsões": "propulsão",
    "propunha": "propor",
    "propunham": "propor",
    "propunhas": "propor",
    "propus": "propor",
    "propusemo": "propor",
    "propusemos": "propor",
    "propuser": "propor",
    "propusera": "propor",
    "propuseram": "propor",
    "propuseras": "propor",
    "propuserdes": "propor",
    "propuserem": "propor",
    "propuseres": "propor",
    "propusermos": "propor",
    "propusesse": "propor",
    "propusessem": "propor",
    "propusesses": "propor",
    "propuseste": "propor",
    "propusestes": "propor",
    "propuséramo": "propor",
    "propuséramos": "propor",
    "propusérei": "propor",
    "propuséreis": "propor",
    "propusésseis": "propor",
    "propuséssemos": "propor",
    "propágulos": "propágulo",
    "propática": "propático",
    "propáticas": "propático",
    "propáticos": "propático",
    "propénica": "propénico",
    "propénicas": "propénico",
    "propénicos": "propénico",
    "propícia": "propício",
    "propícias": "propício",
    "propícios": "propício",
    "propílica": "propílico",
    "propílicas": "propílico",
    "propílicos": "propílico",
    "propínqua": "propínquo",
    "propínquas": "propínquo",
    "propínquos": "propínquo",
    "propólica": "propólico",
    "propólicas": "propólico",
    "propólicos": "propólico",
    "propósitos": "propósito",
    "propô": "propor",
    "propôs": "propor",
    "propõe": "propor",
    "propõem": "propor",
    "propões": "propor",
    "propúnhamo": "propor",
    "propúnhamos": "propor",
    "propúnhei": "propor",
    "propúnheis": "propor",
    "proquestores": "proquestor",
    "proquesturas": "proquestura",
    "prorroga": "prorrogar",
    "prorrogabilidades": "prorrogabilidade",
    "prorrogada": "prorrogar",
    "prorrogadas": "prorrogar",
    "prorrogado": "prorrogar",
    "prorrogadora": "prorrogador",
    "prorrogadoras": "prorrogador",
    "prorrogadores": "prorrogador",
    "prorrogados": "prorrogar",
    "prorrogai": "prorrogar",
    "prorrogais": "prorrogar",
    "prorrogam": "prorrogar",
    "prorrogamo": "prorrogar",
    "prorrogamos": "prorrogar",
    "prorrogando": "prorrogar",
    "prorrogara": "prorrogar",
    "prorrogaram": "prorrogar",
    "prorrogaras": "prorrogar",
    "prorrogarde": "prorrogar",
    "prorrogardes": "prorrogar",
    "prorrogare": "prorrogar",
    "prorrogarei": "prorrogar",
    "prorrogareis": "prorrogar",
    "prorrogarem": "prorrogar",
    "prorrogaremos": "prorrogar",
    "prorrogares": "prorrogar",
    "prorrogaria": "prorrogar",
    "prorrogariam": "prorrogar",
    "prorrogarias": "prorrogar",
    "prorrogarmo": "prorrogar",
    "prorrogarmos": "prorrogar",
    "prorrogará": "prorrogar",
    "prorrogarás": "prorrogar",
    "prorrogarão": "prorrogar",
    "prorrogaríamos": "prorrogar",
    "prorrogaríeis": "prorrogar",
    "prorrogas": "prorrogar",
    "prorrogasse": "prorrogar",
    "prorrogassem": "prorrogar",
    "prorrogasses": "prorrogar",
    "prorrogaste": "prorrogar",
    "prorrogastes": "prorrogar",
    "prorrogativa": "prorrogativo",
    "prorrogativas": "prorrogativo",
    "prorrogativos": "prorrogativo",
    "prorrogava": "prorrogar",
    "prorrogavam": "prorrogar",
    "prorrogavas": "prorrogar",
    "prorrogações": "prorrogação",
    "prorrogo": "prorrogar",
    "prorrogou": "prorrogar",
    "prorrogue": "prorrogar",
    "prorroguei": "prorrogar",
    "prorrogueis": "prorrogar",
    "prorroguem": "prorrogar",
    "prorroguemo": "prorrogar",
    "prorroguemos": "prorrogar",
    "prorrogues": "prorrogar",
    "prorrogá": "prorrogar",
    "prorrogámo": "prorrogar",
    "prorrogámos": "prorrogar",
    "prorrogáramo": "prorrogar",
    "prorrogáramos": "prorrogar",
    "prorrogárei": "prorrogar",
    "prorrogáreis": "prorrogar",
    "prorrogásseis": "prorrogar",
    "prorrogássemos": "prorrogar",
    "prorrogávamo": "prorrogar",
    "prorrogávamos": "prorrogar",
    "prorrogávei": "prorrogar",
    "prorrogáveis": "prorrogável",
    "prorrompa": "prorromper",
    "prorrompais": "prorromper",
    "prorrompam": "prorromper",
    "prorrompamo": "prorromper",
    "prorrompamos": "prorromper",
    "prorrompas": "prorromper",
    "prorrompe": "prorromper",
    "prorrompei": "prorromper",
    "prorrompeis": "prorromper",
    "prorrompem": "prorromper",
    "prorrompemo": "prorromper",
    "prorrompemos": "prorromper",
    "prorrompendo": "prorromper",
    "prorrompera": "prorromper",
    "prorromperam": "prorromper",
    "prorromperas": "prorromper",
    "prorromperdes": "prorromper",
    "prorromperei": "prorromper",
    "prorrompereis": "prorromper",
    "prorromperem": "prorromper",
    "prorromperemos": "prorromper",
    "prorromperes": "prorromper",
    "prorromperia": "prorromper",
    "prorromperiam": "prorromper",
    "prorromperias": "prorromper",
    "prorrompermo": "prorromper",
    "prorrompermos": "prorromper",
    "prorromperá": "prorromper",
    "prorromperás": "prorromper",
    "prorromperão": "prorromper",
    "prorromperíamos": "prorromper",
    "prorromperíeis": "prorromper",
    "prorrompes": "prorromper",
    "prorrompesse": "prorromper",
    "prorrompessem": "prorromper",
    "prorrompesses": "prorromper",
    "prorrompeste": "prorromper",
    "prorrompestes": "prorromper",
    "prorrompeu": "prorromper",
    "prorrompi": "prorromper",
    "prorrompia": "prorromper",
    "prorrompiam": "prorromper",
    "prorrompias": "prorromper",
    "prorrompida": "prorromper",
    "prorrompidas": "prorromper",
    "prorrompido": "prorromper",
    "prorrompidos": "prorromper",
    "prorrompimentos": "prorrompimento",
    "prorrompo": "prorromper",
    "prorrompêramo": "prorromper",
    "prorrompêramos": "prorromper",
    "prorrompêreis": "prorromper",
    "prorrompêsseis": "prorromper",
    "prorrompêssemos": "prorromper",
    "prorrompíamo": "prorromper",
    "prorrompíamos": "prorromper",
    "prorrompíeis": "prorromper",
    "prosa": "prosar",
    "prosada": "prosar",
    "prosadas": "prosar",
    "prosado": "prosar",
    "prosadora": "prosador",
    "prosadoras": "prosador",
    "prosadores": "prosador",
    "prosados": "prosar",
    "prosai": "prosar",
    "prosaica": "prosaico",
    "prosaicas": "prosaico",
    "prosaicos": "prosaico",
    "prosais": "prosar",
    "prosam": "prosar",
    "prosamo": "prosar",
    "prosamos": "prosar",
    "prosando": "prosar",
    "prosara": "prosar",
    "prosaram": "prosar",
    "prosaras": "prosar",
    "prosardes": "prosar",
    "prosarei": "prosar",
    "prosareis": "prosar",
    "prosarem": "prosar",
    "prosaremos": "prosar",
    "prosares": "prosar",
    "prosaria": "prosar",
    "prosariam": "prosar",
    "prosarias": "prosar",
    "prosarmo": "prosar",
    "prosarmos": "prosar",
    "prosará": "prosar",
    "prosarás": "prosar",
    "prosarão": "prosar",
    "prosaríamos": "prosar",
    "prosaríeis": "prosar",
    "prosas": "prosar",
    "prosasse": "prosar",
    "prosassem": "prosar",
    "prosasses": "prosar",
    "prosaste": "prosar",
    "prosastes": "prosar",
    "prosava": "prosar",
    "prosavam": "prosar",
    "prosavas": "prosar",
    "prosaísmos": "prosaísmo",
    "proscreva": "proscrever",
    "proscrevais": "proscrever",
    "proscrevam": "proscrever",
    "proscrevamo": "proscrever",
    "proscrevamos": "proscrever",
    "proscrevas": "proscrever",
    "proscreve": "proscrever",
    "proscrevei": "proscrever",
    "proscreveis": "proscrever",
    "proscrevem": "proscrever",
    "proscrevemo": "proscrever",
    "proscrevemos": "proscrever",
    "proscrevendo": "proscrever",
    "proscrevera": "proscrever",
    "proscreveram": "proscrever",
    "proscreveras": "proscrever",
    "proscreverde": "proscrever",
    "proscreverdes": "proscrever",
    "proscrevere": "proscrever",
    "proscreverei": "proscrever",
    "proscrevereis": "proscrever",
    "proscreverem": "proscrever",
    "proscreveremos": "proscrever",
    "proscreveres": "proscrever",
    "proscreveria": "proscrever",
    "proscreveriam": "proscrever",
    "proscreverias": "proscrever",
    "proscrevermo": "proscrever",
    "proscrevermos": "proscrever",
    "proscreverá": "proscrever",
    "proscreverás": "proscrever",
    "proscreverão": "proscrever",
    "proscreveríamos": "proscrever",
    "proscreveríeis": "proscrever",
    "proscreves": "proscrever",
    "proscrevesse": "proscrever",
    "proscrevessem": "proscrever",
    "proscrevesses": "proscrever",
    "proscreveste": "proscrever",
    "proscrevestes": "proscrever",
    "proscreveu": "proscrever",
    "proscrevi": "proscrever",
    "proscrevia": "proscrever",
    "proscreviam": "proscrever",
    "proscrevias": "proscrever",
    "proscrevo": "proscrever",
    "proscrevê": "proscrever",
    "proscrevêramo": "proscrever",
    "proscrevêramos": "proscrever",
    "proscrevêrei": "proscrever",
    "proscrevêreis": "proscrever",
    "proscrevêsseis": "proscrever",
    "proscrevêssemos": "proscrever",
    "proscrevíamo": "proscrever",
    "proscrevíamos": "proscrever",
    "proscrevíei": "proscrever",
    "proscrevíeis": "proscrever",
    "proscrita": "proscrito",
    "proscritas": "proscrito",
    "proscrito": "proscrever",
    "proscritora": "proscritor",
    "proscritoras": "proscritor",
    "proscritores": "proscritor",
    "proscritos": "proscrito",
    "proscrições": "proscrição",
    "proscénica": "proscénico",
    "proscénicas": "proscénico",
    "proscénicos": "proscénico",
    "proscénios": "proscénio",
    "prose": "prosar",
    "proseada": "prosear",
    "proseadas": "prosear",
    "proseado": "prosear",
    "proseados": "prosear",
    "proseai": "prosear",
    "proseais": "prosear",
    "proseamo": "prosear",
    "proseamos": "prosear",
    "proseando": "prosear",
    "proseara": "prosear",
    "prosearam": "prosear",
    "prosearas": "prosear",
    "proseardes": "prosear",
    "prosearei": "prosear",
    "proseareis": "prosear",
    "prosearem": "prosear",
    "prosearemos": "prosear",
    "proseares": "prosear",
    "prosearia": "prosear",
    "proseariam": "prosear",
    "prosearias": "prosear",
    "prosearmo": "prosear",
    "prosearmos": "prosear",
    "proseará": "prosear",
    "prosearás": "prosear",
    "prosearão": "prosear",
    "prosearíamos": "prosear",
    "prosearíeis": "prosear",
    "proseasse": "prosear",
    "proseassem": "prosear",
    "proseasses": "prosear",
    "proseaste": "prosear",
    "proseastes": "prosear",
    "proseava": "prosear",
    "proseavam": "prosear",
    "proseavas": "prosear",
    "proseei": "prosear",
    "proseeis": "prosear",
    "proseemo": "prosear",
    "proseemos": "prosear",
    "prosei": "prosar",
    "proseia": "prosear",
    "proseiam": "prosear",
    "proseias": "prosear",
    "proseie": "prosear",
    "proseiem": "prosear",
    "proseies": "prosear",
    "proseio": "prosear",
    "proseirona": "proseirão",
    "proseironas": "proseirão",
    "proseirões": "proseirão",
    "proseis": "prosar",
    "proselitismos": "proselitismo",
    "proselitistas": "proselitista",
    "proselítica": "proselítico",
    "proselíticas": "proselítico",
    "proselíticos": "proselítico",
    "prosem": "prosar",
    "prosemo": "prosar",
    "prosemos": "prosar",
    "prosenquímea": "prosenquímeo",
    "prosenquímeas": "prosenquímeo",
    "prosenquímeos": "prosenquímeo",
    "proseou": "prosear",
    "proses": "prosar",
    "proseámo": "prosear",
    "proseámos": "prosear",
    "proseáramo": "prosear",
    "proseáramos": "prosear",
    "proseáreis": "prosear",
    "proseásseis": "prosear",
    "proseássemos": "prosear",
    "proseávamo": "prosear",
    "proseávamos": "prosear",
    "proseáveis": "prosear",
    "prosistas": "prosista",
    "proso": "prosar",
    "prosobrânquia": "prosobrânquio",
    "prosobrânquias": "prosobrânquio",
    "prosobrânquica": "prosobrânquico",
    "prosobrânquicas": "prosobrânquico",
    "prosobrânquicos": "prosobrânquico",
    "prosobrânquios": "prosobrânquio",
    "prosodistas": "prosodista",
    "prosonomásias": "prosonomásia",
    "prosonomásica": "prosonomásico",
    "prosonomásicas": "prosonomásico",
    "prosonomásicos": "prosonomásico",
    "prosonomástica": "prosonomástico",
    "prosonomásticas": "prosonomástico",
    "prosonomásticos": "prosonomástico",
    "prosonímias": "prosonímia",
    "prosonímica": "prosonímico",
    "prosonímicas": "prosonímico",
    "prosonímicos": "prosonímico",
    "prosopagnosias": "prosopagnosia",
    "prosopagnóstica": "prosopagnóstico",
    "prosopagnósticas": "prosopagnóstico",
    "prosopagnósticos": "prosopagnóstico",
    "prosopalgias": "prosopalgia",
    "prosopografias": "prosopografia",
    "prosopografistas": "prosopografista",
    "prosopográfica": "prosopográfico",
    "prosopográficas": "prosopográfico",
    "prosopográficos": "prosopográfico",
    "prosopologias": "prosopologia",
    "prosopologistas": "prosopologista",
    "prosopológica": "prosopológico",
    "prosopológicas": "prosopológico",
    "prosopológicos": "prosopológico",
    "prosopopaica": "prosopopaico",
    "prosopopaicas": "prosopopaico",
    "prosopopaicos": "prosopopaico",
    "prosopopeias": "prosopopeia",
    "prosopopeica": "prosopopeico",
    "prosopopeicas": "prosopopeico",
    "prosopopeicos": "prosopopeico",
    "prosopálgica": "prosopálgico",
    "prosopálgicas": "prosopálgico",
    "prosopálgicos": "prosopálgico",
    "prosou": "prosar",
    "prospecta": "prospectar",
    "prospectada": "prospectar",
    "prospectadas": "prospectar",
    "prospectado": "prospectar",
    "prospectados": "prospectar",
    "prospectai": "prospectar",
    "prospectais": "prospectar",
    "prospectam": "prospectar",
    "prospectamo": "prospectar",
    "prospectamos": "prospectar",
    "prospectando": "prospectar",
    "prospectara": "prospectar",
    "prospectaram": "prospectar",
    "prospectaras": "prospectar",
    "prospectarde": "prospectar",
    "prospectardes": "prospectar",
    "prospectare": "prospectar",
    "prospectarei": "prospectar",
    "prospectareis": "prospectar",
    "prospectarem": "prospectar",
    "prospectaremos": "prospectar",
    "prospectares": "prospectar",
    "prospectaria": "prospectar",
    "prospectariam": "prospectar",
    "prospectarias": "prospectar",
    "prospectarmo": "prospectar",
    "prospectarmos": "prospectar",
    "prospectará": "prospectar",
    "prospectarás": "prospectar",
    "prospectarão": "prospectar",
    "prospectaríamos": "prospectar",
    "prospectaríeis": "prospectar",
    "prospectas": "prospectar",
    "prospectasse": "prospectar",
    "prospectassem": "prospectar",
    "prospectasses": "prospectar",
    "prospectaste": "prospectar",
    "prospectastes": "prospectar",
    "prospectava": "prospectar",
    "prospectavam": "prospectar",
    "prospectavas": "prospectar",
    "prospecte": "prospectar",
    "prospectei": "prospectar",
    "prospecteis": "prospectar",
    "prospectem": "prospectar",
    "prospectemo": "prospectar",
    "prospectemos": "prospectar",
    "prospectes": "prospectar",
    "prospectiva": "prospectivo",
    "prospectivas": "prospectivo",
    "prospectivos": "prospectivo",
    "prospecto": "prospectar",
    "prospectora": "prospector",
    "prospectoras": "prospector",
    "prospectores": "prospector",
    "prospectos": "prospecto",
    "prospectou": "prospectar",
    "prospectá": "prospectar",
    "prospectámo": "prospectar",
    "prospectámos": "prospectar",
    "prospectáramo": "prospectar",
    "prospectáramos": "prospectar",
    "prospectárei": "prospectar",
    "prospectáreis": "prospectar",
    "prospectásseis": "prospectar",
    "prospectássemos": "prospectar",
    "prospectávamo": "prospectar",
    "prospectávamos": "prospectar",
    "prospectávei": "prospectar",
    "prospectáveis": "prospectável",
    "prospecções": "prospecção",
    "prospera": "prosperar",
    "prosperada": "prosperar",
    "prosperadas": "prosperar",
    "prosperado": "prosperar",
    "prosperados": "prosperar",
    "prosperai": "prosperar",
    "prosperais": "prosperar",
    "prosperam": "prosperar",
    "prosperamo": "prosperar",
    "prosperamos": "prosperar",
    "prosperando": "prosperar",
    "prosperara": "prosperar",
    "prosperaram": "prosperar",
    "prosperaras": "prosperar",
    "prosperardes": "prosperar",
    "prosperarei": "prosperar",
    "prosperareis": "prosperar",
    "prosperarem": "prosperar",
    "prosperaremos": "prosperar",
    "prosperares": "prosperar",
    "prosperaria": "prosperar",
    "prosperariam": "prosperar",
    "prosperarias": "prosperar",
    "prosperarmo": "prosperar",
    "prosperarmos": "prosperar",
    "prosperará": "prosperar",
    "prosperarás": "prosperar",
    "prosperarão": "prosperar",
    "prosperaríamos": "prosperar",
    "prosperaríeis": "prosperar",
    "prosperas": "prosperar",
    "prosperasse": "prosperar",
    "prosperassem": "prosperar",
    "prosperasses": "prosperar",
    "prosperaste": "prosperar",
    "prosperastes": "prosperar",
    "prosperava": "prosperar",
    "prosperavam": "prosperar",
    "prosperavas": "prosperar",
    "prospere": "prosperar",
    "prosperei": "prosperar",
    "prospereis": "prosperar",
    "prosperem": "prosperar",
    "prosperemo": "prosperar",
    "prosperemos": "prosperar",
    "prosperes": "prosperar",
    "prosperidades": "prosperidade",
    "prospero": "prosperar",
    "prosperou": "prosperar",
    "prosperámo": "prosperar",
    "prosperámos": "prosperar",
    "prosperáramo": "prosperar",
    "prosperáramos": "prosperar",
    "prosperáreis": "prosperar",
    "prosperásseis": "prosperar",
    "prosperássemos": "prosperar",
    "prosperávamo": "prosperar",
    "prosperávamos": "prosperar",
    "prosperáveis": "prosperar",
    "prospérrima": "próspero",
    "prospérrimas": "próspero",
    "prospérrimo": "próspero",
    "prospérrimos": "próspero",
    "prossectora": "prossector",
    "prossectoras": "prossector",
    "prossectores": "prossector",
    "prossecutora": "prossecutor",
    "prossecutoras": "prossecutor",
    "prossecutores": "prossecutor",
    "prossecuções": "prossecução",
    "prossegue": "prosseguir",
    "prosseguem": "prosseguir",
    "prossegues": "prosseguir",
    "prossegui": "prosseguir",
    "prosseguia": "prosseguir",
    "prosseguiam": "prosseguir",
    "prosseguias": "prosseguir",
    "prosseguida": "prosseguir",
    "prosseguidas": "prosseguir",
    "prosseguido": "prosseguir",
    "prosseguidora": "prosseguidor",
    "prosseguidoras": "prosseguidor",
    "prosseguidores": "prosseguidor",
    "prosseguidos": "prosseguir",
    "prosseguimentos": "prosseguimento",
    "prosseguimo": "prosseguir",
    "prosseguimos": "prosseguir",
    "prosseguindo": "prosseguir",
    "prosseguira": "prosseguir",
    "prosseguiram": "prosseguir",
    "prosseguiras": "prosseguir",
    "prosseguirde": "prosseguir",
    "prosseguirdes": "prosseguir",
    "prosseguire": "prosseguir",
    "prosseguirei": "prosseguir",
    "prosseguireis": "prosseguir",
    "prosseguirem": "prosseguir",
    "prosseguiremos": "prosseguir",
    "prosseguires": "prosseguir",
    "prosseguiria": "prosseguir",
    "prosseguiriam": "prosseguir",
    "prosseguirias": "prosseguir",
    "prosseguirmo": "prosseguir",
    "prosseguirmos": "prosseguir",
    "prosseguirá": "prosseguir",
    "prosseguirás": "prosseguir",
    "prosseguirão": "prosseguir",
    "prosseguiríamos": "prosseguir",
    "prosseguiríeis": "prosseguir",
    "prosseguis": "prosseguir",
    "prosseguisse": "prosseguir",
    "prosseguissem": "prosseguir",
    "prosseguisses": "prosseguir",
    "prosseguiste": "prosseguir",
    "prosseguistes": "prosseguir",
    "prosseguiu": "prosseguir",
    "prosseguições": "prosseguição",
    "prosseguíamo": "prosseguir",
    "prosseguíamos": "prosseguir",
    "prosseguíei": "prosseguir",
    "prosseguíeis": "prosseguir",
    "prosseguíramo": "prosseguir",
    "prosseguíramos": "prosseguir",
    "prosseguírei": "prosseguir",
    "prosseguíreis": "prosseguir",
    "prosseguísseis": "prosseguir",
    "prosseguíssemos": "prosseguir",
    "prossiga": "prosseguir",
    "prossigais": "prosseguir",
    "prossigam": "prosseguir",
    "prossigamo": "prosseguir",
    "prossigamos": "prosseguir",
    "prossigas": "prosseguir",
    "prossigo": "prosseguir",
    "prostatalgias": "prostatalgia",
    "prostatectomias": "prostatectomia",
    "prostatectómica": "prostatectómico",
    "prostatectómicas": "prostatectómico",
    "prostatectómicos": "prostatectómico",
    "prostatites": "prostatite",
    "prostatálgica": "prostatálgico",
    "prostatálgicas": "prostatálgico",
    "prostatálgicos": "prostatálgico",
    "prostatítica": "prostatítico",
    "prostatíticas": "prostatítico",
    "prostatíticos": "prostatítico",
    "prosterna": "prosternar",
    "prosternada": "prosternar",
    "prosternadas": "prosternar",
    "prosternado": "prosternar",
    "prosternados": "prosternar",
    "prosternai": "prosternar",
    "prosternais": "prosternar",
    "prosternam": "prosternar",
    "prosternamentos": "prosternamento",
    "prosternamo": "prosternar",
    "prosternamos": "prosternar",
    "prosternando": "prosternar",
    "prosternara": "prosternar",
    "prosternaram": "prosternar",
    "prosternaras": "prosternar",
    "prosternarde": "prosternar",
    "prosternardes": "prosternar",
    "prosternare": "prosternar",
    "prosternarei": "prosternar",
    "prosternareis": "prosternar",
    "prosternarem": "prosternar",
    "prosternaremos": "prosternar",
    "prosternares": "prosternar",
    "prosternaria": "prosternar",
    "prosternariam": "prosternar",
    "prosternarias": "prosternar",
    "prosternarmo": "prosternar",
    "prosternarmos": "prosternar",
    "prosternará": "prosternar",
    "prosternarás": "prosternar",
    "prosternarão": "prosternar",
    "prosternaríamos": "prosternar",
    "prosternaríeis": "prosternar",
    "prosternas": "prosternar",
    "prosternasse": "prosternar",
    "prosternassem": "prosternar",
    "prosternasses": "prosternar",
    "prosternaste": "prosternar",
    "prosternastes": "prosternar",
    "prosternava": "prosternar",
    "prosternavam": "prosternar",
    "prosternavas": "prosternar",
    "prosternações": "prosternação",
    "prosterne": "prosternar",
    "prosternei": "prosternar",
    "prosterneis": "prosternar",
    "prosternem": "prosternar",
    "prosternemo": "prosternar",
    "prosternemos": "prosternar",
    "prosternes": "prosternar",
    "prosterno": "prosternar",
    "prosternos": "prosterno",
    "prosternou": "prosternar",
    "prosterná": "prosternar",
    "prosternámo": "prosternar",
    "prosternámos": "prosternar",
    "prosternáramo": "prosternar",
    "prosternáramos": "prosternar",
    "prosternárei": "prosternar",
    "prosternáreis": "prosternar",
    "prosternásseis": "prosternar",
    "prosternássemos": "prosternar",
    "prosternávamo": "prosternar",
    "prosternávamos": "prosternar",
    "prosternávei": "prosternar",
    "prosternáveis": "prosternar",
    "prostibulares": "prostibular",
    "prostibulários": "prostibulário",
    "prostilos": "prostilo",
    "prostitua": "prostituir",
    "prostituais": "prostituir",
    "prostituam": "prostituir",
    "prostituamo": "prostituir",
    "prostituamos": "prostituir",
    "prostituas": "prostituir",
    "prostituem": "prostituir",
    "prostitui": "prostituir",
    "prostituida": "prostituido",
    "prostituidas": "prostituido",
    "prostituidora": "prostituidor",
    "prostituidoras": "prostituidor",
    "prostituidores": "prostituidor",
    "prostituidos": "prostituido",
    "prostituindo": "prostituir",
    "prostituirde": "prostituir",
    "prostituirdes": "prostituir",
    "prostituirei": "prostituir",
    "prostituireis": "prostituir",
    "prostituiremos": "prostituir",
    "prostituiria": "prostituir",
    "prostituiriam": "prostituir",
    "prostituirias": "prostituir",
    "prostituirmo": "prostituir",
    "prostituirmos": "prostituir",
    "prostituirá": "prostituir",
    "prostituirás": "prostituir",
    "prostituirão": "prostituir",
    "prostituiríamos": "prostituir",
    "prostituiríeis": "prostituir",
    "prostituis": "prostituir",
    "prostituiu": "prostituir",
    "prostituições": "prostituição",
    "prostituo": "prostituir",
    "prostituta": "prostituto",
    "prostitutas": "prostituto",
    "prostitutos": "prostituto",
    "prostituí": "prostituir",
    "prostituía": "prostituir",
    "prostituíam": "prostituir",
    "prostituíamo": "prostituir",
    "prostituíamos": "prostituir",
    "prostituías": "prostituir",
    "prostituída": "prostituir",
    "prostituídas": "prostituir",
    "prostituído": "prostituir",
    "prostituídos": "prostituir",
    "prostituíei": "prostituir",
    "prostituíeis": "prostituir",
    "prostituímo": "prostituir",
    "prostituímos": "prostituir",
    "prostituíra": "prostituir",
    "prostituíram": "prostituir",
    "prostituíramo": "prostituir",
    "prostituíramos": "prostituir",
    "prostituíras": "prostituir",
    "prostituíre": "prostituir",
    "prostituírei": "prostituir",
    "prostituíreis": "prostituir",
    "prostituírem": "prostituir",
    "prostituíres": "prostituir",
    "prostituís": "prostituir",
    "prostituísse": "prostituir",
    "prostituísseis": "prostituir",
    "prostituíssem": "prostituir",
    "prostituíssemos": "prostituir",
    "prostituísses": "prostituir",
    "prostituíste": "prostituir",
    "prostituístes": "prostituir",
    "prostituíveis": "prostituível",
    "prostra": "prostrar",
    "prostrada": "prostrar",
    "prostradas": "prostrar",
    "prostrado": "prostrar",
    "prostrados": "prostrar",
    "prostrai": "prostrar",
    "prostrais": "prostrar",
    "prostram": "prostrar",
    "prostramentos": "prostramento",
    "prostramo": "prostrar",
    "prostramos": "prostrar",
    "prostrando": "prostrar",
    "prostrara": "prostrar",
    "prostraram": "prostrar",
    "prostraras": "prostrar",
    "prostrarde": "prostrar",
    "prostrardes": "prostrar",
    "prostrare": "prostrar",
    "prostrarei": "prostrar",
    "prostrareis": "prostrar",
    "prostrarem": "prostrar",
    "prostraremos": "prostrar",
    "prostrares": "prostrar",
    "prostraria": "prostrar",
    "prostrariam": "prostrar",
    "prostrarias": "prostrar",
    "prostrarmo": "prostrar",
    "prostrarmos": "prostrar",
    "prostrará": "prostrar",
    "prostrarás": "prostrar",
    "prostrarão": "prostrar",
    "prostraríamos": "prostrar",
    "prostraríeis": "prostrar",
    "prostras": "prostrar",
    "prostrasse": "prostrar",
    "prostrassem": "prostrar",
    "prostrasses": "prostrar",
    "prostraste": "prostrar",
    "prostrastes": "prostrar",
    "prostrava": "prostrar",
    "prostravam": "prostrar",
    "prostravas": "prostrar",
    "prostrações": "prostração",
    "prostre": "prostrar",
    "prostrei": "prostrar",
    "prostreis": "prostrar",
    "prostrem": "prostrar",
    "prostremo": "prostrar",
    "prostremos": "prostrar",
    "prostres": "prostrar",
    "prostro": "prostrar",
    "prostrou": "prostrar",
    "prostrá": "prostrar",
    "prostrámo": "prostrar",
    "prostrámos": "prostrar",
    "prostráramo": "prostrar",
    "prostráramos": "prostrar",
    "prostrárei": "prostrar",
    "prostráreis": "prostrar",
    "prostrásseis": "prostrar",
    "prostrássemos": "prostrar",
    "prostrávamo": "prostrar",
    "prostrávamos": "prostrar",
    "prostrávei": "prostrar",
    "prostráveis": "prostrar",
    "prostática": "prostático",
    "prostáticas": "prostático",
    "prostáticos": "prostático",
    "prostética": "prostético",
    "prostéticas": "prostético",
    "prostéticos": "prostético",
    "prostíbulos": "prostíbulo",
    "prostómia": "prostómio",
    "prostómias": "prostómio",
    "prostómios": "prostómio",
    "prosámo": "prosar",
    "prosámos": "prosar",
    "prosápias": "prosápia",
    "prosáramo": "prosar",
    "prosáramos": "prosar",
    "prosáreis": "prosar",
    "prosásseis": "prosar",
    "prosássemos": "prosar",
    "prosávamo": "prosar",
    "prosávamos": "prosar",
    "prosáveis": "prosar",
    "prosélita": "prosélito",
    "prosélitas": "prosélito",
    "prosélitos": "prosélito",
    "prosênquimas": "prosênquima",
    "prosódias": "prosódia",
    "prosódica": "prosódico",
    "prosódicas": "prosódico",
    "prosódicos": "prosódico",
    "prosónimos": "prosónimo",
    "protactínios": "protactínio",
    "protagonismos": "protagonismo",
    "protagonistas": "protagonista",
    "protagoniza": "protagonizar",
    "protagonizada": "protagonizar",
    "protagonizadas": "protagonizar",
    "protagonizado": "protagonizar",
    "protagonizados": "protagonizar",
    "protagonizai": "protagonizar",
    "protagonizais": "protagonizar",
    "protagonizam": "protagonizar",
    "protagonizamo": "protagonizar",
    "protagonizamos": "protagonizar",
    "protagonizando": "protagonizar",
    "protagonizara": "protagonizar",
    "protagonizaram": "protagonizar",
    "protagonizaras": "protagonizar",
    "protagonizarde": "protagonizar",
    "protagonizardes": "protagonizar",
    "protagonizare": "protagonizar",
    "protagonizarei": "protagonizar",
    "protagonizareis": "protagonizar",
    "protagonizarem": "protagonizar",
    "protagonizaremos": "protagonizar",
    "protagonizares": "protagonizar",
    "protagonizaria": "protagonizar",
    "protagonizariam": "protagonizar",
    "protagonizarias": "protagonizar",
    "protagonizarmo": "protagonizar",
    "protagonizarmos": "protagonizar",
    "protagonizará": "protagonizar",
    "protagonizarás": "protagonizar",
    "protagonizarão": "protagonizar",
    "protagonizaríamos": "protagonizar",
    "protagonizaríeis": "protagonizar",
    "protagonizas": "protagonizar",
    "protagonizasse": "protagonizar",
    "protagonizassem": "protagonizar",
    "protagonizasses": "protagonizar",
    "protagonizaste": "protagonizar",
    "protagonizastes": "protagonizar",
    "protagonizava": "protagonizar",
    "protagonizavam": "protagonizar",
    "protagonizavas": "protagonizar",
    "protagonize": "protagonizar",
    "protagonizei": "protagonizar",
    "protagonizeis": "protagonizar",
    "protagonizem": "protagonizar",
    "protagonizemo": "protagonizar",
    "protagonizemos": "protagonizar",
    "protagonizes": "protagonizar",
    "protagonizo": "protagonizar",
    "protagonizou": "protagonizar",
    "protagonizá": "protagonizar",
    "protagonizámo": "protagonizar",
    "protagonizámos": "protagonizar",
    "protagonizáramo": "protagonizar",
    "protagonizáramos": "protagonizar",
    "protagonizárei": "protagonizar",
    "protagonizáreis": "protagonizar",
    "protagonizásseis": "protagonizar",
    "protagonizássemos": "protagonizar",
    "protagonizávamo": "protagonizar",
    "protagonizávamos": "protagonizar",
    "protagonizávei": "protagonizar",
    "protagonizáveis": "protagonizar",
    "protandrias": "protandria",
    "protanopsias": "protanopsia",
    "protanómica": "protanómico",
    "protanómicas": "protanómico",
    "protanómicos": "protanómico",
    "protanóptica": "protanóptico",
    "protanópticas": "protanóptico",
    "protanópticos": "protanóptico",
    "protargóis": "protargol",
    "protarsos": "protarso",
    "proteases": "protease",
    "proteccionais": "proteccional",
    "proteccionismos": "proteccionismo",
    "proteccionistas": "proteccionista",
    "protectodermes": "protectoderme",
    "protectora": "protector",
    "protectorados": "protectorado",
    "protectorais": "protectoral",
    "protectoras": "protector",
    "protectores": "protector",
    "protectorias": "protectoria",
    "protectória": "protectório",
    "protectórias": "protectório",
    "protectórios": "protectório",
    "protecções": "protecção",
    "protege": "proteger",
    "protegedora": "protegedor",
    "protegedoras": "protegedor",
    "protegedores": "protegedor",
    "protegei": "proteger",
    "protegeis": "proteger",
    "protegem": "proteger",
    "protegemo": "proteger",
    "protegemos": "proteger",
    "protegendo": "proteger",
    "protegera": "proteger",
    "protegeram": "proteger",
    "protegeras": "proteger",
    "protegerde": "proteger",
    "protegerdes": "proteger",
    "protegere": "proteger",
    "protegerei": "proteger",
    "protegereis": "proteger",
    "protegerem": "proteger",
    "protegeremos": "proteger",
    "protegeres": "proteger",
    "protegeria": "proteger",
    "protegeriam": "proteger",
    "protegerias": "proteger",
    "protegermo": "proteger",
    "protegermos": "proteger",
    "protegerá": "proteger",
    "protegerás": "proteger",
    "protegerão": "proteger",
    "protegeríamos": "proteger",
    "protegeríeis": "proteger",
    "proteges": "proteger",
    "protegesse": "proteger",
    "protegessem": "proteger",
    "protegesses": "proteger",
    "protegeste": "proteger",
    "protegestes": "proteger",
    "protegeu": "proteger",
    "protegi": "proteger",
    "protegia": "proteger",
    "protegiam": "proteger",
    "protegias": "proteger",
    "protegida": "protegido",
    "protegidas": "protegido",
    "protegidinha": "protegido",
    "protegidinhas": "protegido",
    "protegidinho": "protegido",
    "protegidinhos": "protegido",
    "protegidita": "protegido",
    "protegiditas": "protegido",
    "protegidito": "protegido",
    "protegiditos": "protegido",
    "protegido": "proteger",
    "protegidos": "protegido",
    "protegidíssima": "protegido",
    "protegidíssimas": "protegido",
    "protegidíssimo": "protegido",
    "protegidíssimos": "protegido",
    "protegê": "proteger",
    "protegêramo": "proteger",
    "protegêramos": "proteger",
    "protegêrei": "proteger",
    "protegêreis": "proteger",
    "protegêsseis": "proteger",
    "protegêssemos": "proteger",
    "protegíamo": "proteger",
    "protegíamos": "proteger",
    "protegíei": "proteger",
    "protegíeis": "proteger",
    "protegíveis": "protegível",
    "proteica": "proteico",
    "proteicas": "proteico",
    "proteicos": "proteico",
    "proteiformes": "proteiforme",
    "proteja": "proteger",
    "protejais": "proteger",
    "protejam": "proteger",
    "protejamo": "proteger",
    "protejamos": "proteger",
    "protejas": "proteger",
    "protejo": "proteger",
    "protela": "protelar",
    "protelada": "protelar",
    "proteladas": "protelar",
    "protelado": "protelar",
    "proteladora": "protelador",
    "proteladoras": "protelador",
    "proteladores": "protelador",
    "protelados": "protelar",
    "protelai": "protelar",
    "protelais": "protelar",
    "protelam": "protelar",
    "protelamentos": "protelamento",
    "protelamo": "protelar",
    "protelamos": "protelar",
    "protelando": "protelar",
    "protelara": "protelar",
    "protelaram": "protelar",
    "protelaras": "protelar",
    "protelarde": "protelar",
    "protelardes": "protelar",
    "protelare": "protelar",
    "protelarei": "protelar",
    "protelareis": "protelar",
    "protelarem": "protelar",
    "protelaremos": "protelar",
    "protelares": "protelar",
    "protelaria": "protelar",
    "protelariam": "protelar",
    "protelarias": "protelar",
    "protelarmo": "protelar",
    "protelarmos": "protelar",
    "protelará": "protelar",
    "protelarás": "protelar",
    "protelarão": "protelar",
    "protelaríamos": "protelar",
    "protelaríeis": "protelar",
    "protelas": "protelar",
    "protelasse": "protelar",
    "protelassem": "protelar",
    "protelasses": "protelar",
    "protelaste": "protelar",
    "protelastes": "protelar",
    "protelava": "protelar",
    "protelavam": "protelar",
    "protelavas": "protelar",
    "protelações": "protelação",
    "protele": "protelar",
    "protelei": "protelar",
    "proteleis": "protelar",
    "protelem": "protelar",
    "protelemo": "protelar",
    "protelemos": "protelar",
    "proteles": "protelar",
    "protelo": "protelar",
    "protelou": "protelar",
    "protelá": "protelar",
    "protelámo": "protelar",
    "protelámos": "protelar",
    "proteláramo": "protelar",
    "proteláramos": "protelar",
    "protelárei": "protelar",
    "proteláreis": "protelar",
    "protelásseis": "protelar",
    "protelássemos": "protelar",
    "protelávamo": "protelar",
    "protelávamos": "protelar",
    "protelávei": "protelar",
    "proteláveis": "protelável",
    "protencefálica": "protencefálico",
    "protencefálicas": "protencefálico",
    "protencefálicos": "protencefálico",
    "protencéfalos": "protencéfalo",
    "proteolítica": "proteolítico",
    "proteolíticas": "proteolítico",
    "proteolíticos": "proteolítico",
    "proterotípica": "proterotípico",
    "proterotípicas": "proterotípico",
    "proterotípicos": "proterotípico",
    "proterozóica": "proterozóico",
    "proterozóicas": "proterozóico",
    "proterozóicos": "proterozóico",
    "proterva": "protervo",
    "protervas": "protervo",
    "protervos": "protervo",
    "proterótipos": "proterótipo",
    "protesta": "protestar",
    "protestada": "protestar",
    "protestadas": "protestar",
    "protestado": "protestar",
    "protestadora": "protestador",
    "protestadoras": "protestador",
    "protestadores": "protestador",
    "protestados": "protestar",
    "protestai": "protestar",
    "protestais": "protestar",
    "protestam": "protestar",
    "protestamo": "protestar",
    "protestamos": "protestar",
    "protestando": "protestar",
    "protestantes": "protestante",
    "protestantismos": "protestantismo",
    "protestantistas": "protestantista",
    "protestantiza": "protestantizar",
    "protestantizada": "protestantizar",
    "protestantizadas": "protestantizar",
    "protestantizado": "protestantizar",
    "protestantizados": "protestantizar",
    "protestantizai": "protestantizar",
    "protestantizais": "protestantizar",
    "protestantizam": "protestantizar",
    "protestantizamo": "protestantizar",
    "protestantizamos": "protestantizar",
    "protestantizando": "protestantizar",
    "protestantizara": "protestantizar",
    "protestantizaram": "protestantizar",
    "protestantizaras": "protestantizar",
    "protestantizarde": "protestantizar",
    "protestantizardes": "protestantizar",
    "protestantizare": "protestantizar",
    "protestantizarei": "protestantizar",
    "protestantizareis": "protestantizar",
    "protestantizarem": "protestantizar",
    "protestantizaremos": "protestantizar",
    "protestantizares": "protestantizar",
    "protestantizaria": "protestantizar",
    "protestantizariam": "protestantizar",
    "protestantizarias": "protestantizar",
    "protestantizarmo": "protestantizar",
    "protestantizarmos": "protestantizar",
    "protestantizará": "protestantizar",
    "protestantizarás": "protestantizar",
    "protestantizarão": "protestantizar",
    "protestantizaríamos": "protestantizar",
    "protestantizaríeis": "protestantizar",
    "protestantizas": "protestantizar",
    "protestantizasse": "protestantizar",
    "protestantizassem": "protestantizar",
    "protestantizasses": "protestantizar",
    "protestantizaste": "protestantizar",
    "protestantizastes": "protestantizar",
    "protestantizava": "protestantizar",
    "protestantizavam": "protestantizar",
    "protestantizavas": "protestantizar",
    "protestantize": "protestantizar",
    "protestantizei": "protestantizar",
    "protestantizeis": "protestantizar",
    "protestantizem": "protestantizar",
    "protestantizemo": "protestantizar",
    "protestantizemos": "protestantizar",
    "protestantizes": "protestantizar",
    "protestantizo": "protestantizar",
    "protestantizou": "protestantizar",
    "protestantizá": "protestantizar",
    "protestantizámo": "protestantizar",
    "protestantizámos": "protestantizar",
    "protestantizáramo": "protestantizar",
    "protestantizáramos": "protestantizar",
    "protestantizárei": "protestantizar",
    "protestantizáreis": "protestantizar",
    "protestantizásseis": "protestantizar",
    "protestantizássemos": "protestantizar",
    "protestantizávamo": "protestantizar",
    "protestantizávamos": "protestantizar",
    "protestantizávei": "protestantizar",
    "protestantizáveis": "protestantizar",
    "protestara": "protestar",
    "protestaram": "protestar",
    "protestaras": "protestar",
    "protestarde": "protestar",
    "protestardes": "protestar",
    "protestare": "protestar",
    "protestarei": "protestar",
    "protestareis": "protestar",
    "protestarem": "protestar",
    "protestaremos": "protestar",
    "protestares": "protestar",
    "protestaria": "protestar",
    "protestariam": "protestar",
    "protestarias": "protestar",
    "protestarmo": "protestar",
    "protestarmos": "protestar",
    "protestará": "protestar",
    "protestarás": "protestar",
    "protestarão": "protestar",
    "protestaríamos": "protestar",
    "protestaríeis": "protestar",
    "protestas": "protestar",
    "protestasse": "protestar",
    "protestassem": "protestar",
    "protestasses": "protestar",
    "protestaste": "protestar",
    "protestastes": "protestar",
    "protestativa": "protestativo",
    "protestativas": "protestativo",
    "protestativos": "protestativo",
    "protestatória": "protestatório",
    "protestatórias": "protestatório",
    "protestatórios": "protestatório",
    "protestava": "protestar",
    "protestavam": "protestar",
    "protestavas": "protestar",
    "protestações": "protestação",
    "proteste": "protestar",
    "protestei": "protestar",
    "protesteis": "protestar",
    "protestem": "protestar",
    "protestemo": "protestar",
    "protestemos": "protestar",
    "protestes": "protestar",
    "protesto": "protestar",
    "protestos": "protesto",
    "protestou": "protestar",
    "protestá": "protestar",
    "protestámo": "protestar",
    "protestámos": "protestar",
    "protestáramo": "protestar",
    "protestáramos": "protestar",
    "protestárei": "protestar",
    "protestáreis": "protestar",
    "protestásseis": "protestar",
    "protestássemos": "protestar",
    "protestávamo": "protestar",
    "protestávamos": "protestar",
    "protestávei": "protestar",
    "protestáveis": "protestar",
    "proteáceas": "proteácea",
    "proteídos": "proteído",
    "proteínas": "proteína",
    "proteólises": "proteólise",
    "protistas": "protista",
    "protistologias": "protistologia",
    "protistologistas": "protistologista",
    "protistológica": "protistológico",
    "protistológicas": "protistológico",
    "protistológicos": "protistológico",
    "protistos": "protisto",
    "protocanónica": "protocanónico",
    "protocanónicas": "protocanónico",
    "protocanónicos": "protocanónico",
    "protoclástica": "protoclástico",
    "protoclásticas": "protoclástico",
    "protoclásticos": "protoclástico",
    "protocolares": "protocolar",
    "protocolistas": "protocolista",
    "protocoliza": "protocolizar",
    "protocolizada": "protocolizar",
    "protocolizadas": "protocolizar",
    "protocolizado": "protocolizar",
    "protocolizados": "protocolizar",
    "protocolizai": "protocolizar",
    "protocolizais": "protocolizar",
    "protocolizam": "protocolizar",
    "protocolizamo": "protocolizar",
    "protocolizamos": "protocolizar",
    "protocolizando": "protocolizar",
    "protocolizara": "protocolizar",
    "protocolizaram": "protocolizar",
    "protocolizaras": "protocolizar",
    "protocolizarde": "protocolizar",
    "protocolizardes": "protocolizar",
    "protocolizare": "protocolizar",
    "protocolizarei": "protocolizar",
    "protocolizareis": "protocolizar",
    "protocolizarem": "protocolizar",
    "protocolizaremos": "protocolizar",
    "protocolizares": "protocolizar",
    "protocolizaria": "protocolizar",
    "protocolizariam": "protocolizar",
    "protocolizarias": "protocolizar",
    "protocolizarmo": "protocolizar",
    "protocolizarmos": "protocolizar",
    "protocolizará": "protocolizar",
    "protocolizarás": "protocolizar",
    "protocolizarão": "protocolizar",
    "protocolizaríamos": "protocolizar",
    "protocolizaríeis": "protocolizar",
    "protocolizas": "protocolizar",
    "protocolizasse": "protocolizar",
    "protocolizassem": "protocolizar",
    "protocolizasses": "protocolizar",
    "protocolizaste": "protocolizar",
    "protocolizastes": "protocolizar",
    "protocolizava": "protocolizar",
    "protocolizavam": "protocolizar",
    "protocolizavas": "protocolizar",
    "protocolize": "protocolizar",
    "protocolizei": "protocolizar",
    "protocolizeis": "protocolizar",
    "protocolizem": "protocolizar",
    "protocolizemo": "protocolizar",
    "protocolizemos": "protocolizar",
    "protocolizes": "protocolizar",
    "protocolizo": "protocolizar",
    "protocolizou": "protocolizar",
    "protocolizá": "protocolizar",
    "protocolizámo": "protocolizar",
    "protocolizámos": "protocolizar",
    "protocolizáramo": "protocolizar",
    "protocolizáramos": "protocolizar",
    "protocolizárei": "protocolizar",
    "protocolizáreis": "protocolizar",
    "protocolizásseis": "protocolizar",
    "protocolizássemos": "protocolizar",
    "protocolizávamo": "protocolizar",
    "protocolizávamos": "protocolizar",
    "protocolizávei": "protocolizar",
    "protocolizáveis": "protocolizar",
    "protocolos": "protocolo",
    "protocordada": "protocordado",
    "protocordadas": "protocordado",
    "protocordados": "protocordado",
    "protoginias": "protoginia",
    "protogínica": "protogínico",
    "protogínicas": "protogínico",
    "protogínicos": "protogínico",
    "protolécitos": "protolécito",
    "protolítica": "protolítico",
    "protolíticas": "protolítico",
    "protolíticos": "protolítico",
    "protomártires": "protomártir",
    "protonautas": "protonauta",
    "protonefrídios": "protonefrídio",
    "protonemas": "protonema",
    "protonemática": "protonemático",
    "protonemáticas": "protonemático",
    "protonemáticos": "protonemático",
    "protonotariados": "protonotariado",
    "protonotariais": "protonotarial",
    "protonotários": "protonotário",
    "protopapas": "protopapa",
    "protoplasmas": "protoplasma",
    "protoplasmática": "protoplasmático",
    "protoplasmáticas": "protoplasmático",
    "protoplasmáticos": "protoplasmático",
    "protoplásmica": "protoplásmico",
    "protoplásmicas": "protoplásmico",
    "protoplásmicos": "protoplásmico",
    "protopática": "protopático",
    "protopáticas": "protopático",
    "protopáticos": "protopático",
    "protoráxica": "protoráxico",
    "protoráxicas": "protoráxico",
    "protoráxicos": "protoráxico",
    "prototipos": "prototipo",
    "prototrófica": "prototrófico",
    "prototróficas": "prototrófico",
    "prototróficos": "prototrófico",
    "prototérios": "prototério",
    "prototípica": "prototípico",
    "prototípicas": "prototípico",
    "prototípicos": "prototípico",
    "prototóraxes": "prototórax",
    "protozoologias": "protozoologia",
    "protozoologistas": "protozoologista",
    "protozoológica": "protozoológico",
    "protozoológicas": "protozoológico",
    "protozoológicos": "protozoológico",
    "protozoária": "protozoário",
    "protozoárias": "protozoário",
    "protozoários": "protozoário",
    "protozoóloga": "protozoólogo",
    "protozoólogas": "protozoólogo",
    "protozoólogos": "protozoólogo",
    "protraem": "protrair",
    "protrai": "protrair",
    "protraia": "protrair",
    "protraiais": "protrair",
    "protraiam": "protrair",
    "protraiamo": "protrair",
    "protraiamos": "protrair",
    "protraias": "protrair",
    "protraida": "protraido",
    "protraidas": "protraido",
    "protraidos": "protraido",
    "protraimentos": "protraimento",
    "protraindo": "protrair",
    "protraio": "protrair",
    "protrairde": "protrair",
    "protrairdes": "protrair",
    "protrairei": "protrair",
    "protraireis": "protrair",
    "protrairemos": "protrair",
    "protrairia": "protrair",
    "protrairiam": "protrair",
    "protrairias": "protrair",
    "protrairmo": "protrair",
    "protrairmos": "protrair",
    "protrairá": "protrair",
    "protrairás": "protrair",
    "protrairão": "protrair",
    "protrairíamos": "protrair",
    "protrairíeis": "protrair",
    "protrais": "protrair",
    "protraiu": "protrair",
    "protraqueada": "protraqueado",
    "protraqueadas": "protraqueado",
    "protraqueados": "protraqueado",
    "protraquedos": "protraquedo",
    "protraí": "protrair",
    "protraía": "protrair",
    "protraíam": "protrair",
    "protraíamo": "protrair",
    "protraíamos": "protrair",
    "protraías": "protrair",
    "protraída": "protrair",
    "protraídas": "protrair",
    "protraído": "protrair",
    "protraídos": "protrair",
    "protraíei": "protrair",
    "protraíeis": "protrair",
    "protraímo": "protrair",
    "protraímos": "protrair",
    "protraíra": "protrair",
    "protraíram": "protrair",
    "protraíramo": "protrair",
    "protraíramos": "protrair",
    "protraíras": "protrair",
    "protraíre": "protrair",
    "protraírei": "protrair",
    "protraíreis": "protrair",
    "protraírem": "protrair",
    "protraíres": "protrair",
    "protraís": "protrair",
    "protraísse": "protrair",
    "protraísseis": "protrair",
    "protraíssem": "protrair",
    "protraíssemos": "protrair",
    "protraísses": "protrair",
    "protraíste": "protrair",
    "protraístes": "protrair",
    "protraíveis": "protraível",
    "protrombinas": "protrombina",
    "protrombínica": "protrombínico",
    "protrombínicas": "protrombínico",
    "protrombínicos": "protrombínico",
    "protrusa": "protruso",
    "protrusas": "protruso",
    "protrusos": "protruso",
    "protrusões": "protrusão",
    "protréptica": "protréptico",
    "protrépticas": "protréptico",
    "protrépticos": "protréptico",
    "protuberantes": "protuberante",
    "protuberâncias": "protuberância",
    "protutelas": "protutela",
    "protutora": "protutor",
    "protutoras": "protutor",
    "protutores": "protutor",
    "protática": "protático",
    "protáticas": "protático",
    "protáticos": "protático",
    "protândrica": "protândrico",
    "protândricas": "protândrico",
    "protândricos": "protândrico",
    "protérvias": "protérvia",
    "protésica": "protésico",
    "protésicas": "protésico",
    "protésicos": "protésico",
    "protética": "protético",
    "protéticas": "protético",
    "protéticos": "protético",
    "protídeos": "protídeo",
    "protídica": "protídico",
    "protídicas": "protídico",
    "protídicos": "protídico",
    "protófitos": "protófito",
    "protólises": "protólise",
    "protónica": "protónico",
    "protónicas": "protónico",
    "protónicos": "protónico",
    "protópodes": "protópode",
    "protóptera": "protóptero",
    "protópteras": "protóptero",
    "protópteros": "protóptero",
    "protóraxes": "protórax",
    "protótipos": "protótipo",
    "protóxidos": "protóxido",
    "protões": "protão",
    "proudhoniana": "proudhoniano",
    "proudhonianas": "proudhoniano",
    "proudhonianos": "proudhoniano",
    "proustitas": "proustita",
    "proustites": "proustite",
    "prouve": "prazer",
    "prouver": "prazer",
    "prouvera": "prazer",
    "prouveram": "prazer",
    "prouverem": "prazer",
    "prouvesse": "prazer",
    "prouvessem": "prazer",
    "prova": "provar",
    "provabilíssima": "provável",
    "provabilíssimas": "provável",
    "provabilíssimo": "provável",
    "provabilíssimos": "provável",
    "provada": "provar",
    "provadas": "provar",
    "provado": "provar",
    "provadora": "provador",
    "provadoras": "provador",
    "provadores": "provador",
    "provados": "provar",
    "provaduras": "provadura",
    "provadíssima": "provado",
    "provadíssimas": "provado",
    "provadíssimo": "provado",
    "provadíssimos": "provado",
    "provai": "provar",
    "provais": "provar",
    "provam": "provar",
    "provamo": "provar",
    "provamos": "provar",
    "provando": "provar",
    "provanças": "provança",
    "provara": "provar",
    "provaram": "provar",
    "provaras": "provar",
    "provarde": "provar",
    "provardes": "provar",
    "provare": "provar",
    "provarei": "provar",
    "provareis": "provar",
    "provarem": "provar",
    "provaremos": "provar",
    "provares": "provar",
    "provaria": "provar",
    "provariam": "provar",
    "provarias": "provar",
    "provarmo": "provar",
    "provarmos": "provar",
    "provará": "provar",
    "provarás": "provará",
    "provarão": "provar",
    "provaríamos": "provar",
    "provaríeis": "provar",
    "provas": "provar",
    "provasse": "provar",
    "provassem": "provar",
    "provasses": "provar",
    "provaste": "provar",
    "provastes": "provar",
    "provatória": "provatório",
    "provatórias": "provatório",
    "provatórios": "provatório",
    "provava": "provar",
    "provavam": "provar",
    "provavas": "provar",
    "provações": "provação",
    "prove": "provar",
    "provecta": "provecto",
    "provectas": "provecto",
    "provectos": "provecto",
    "provectíssima": "provecto",
    "provectíssimas": "provecto",
    "provectíssimo": "provecto",
    "provectíssimos": "provecto",
    "provede": "prover",
    "provedes": "prover",
    "provedora": "provedor",
    "provedorais": "provedoral",
    "provedoras": "provedor",
    "provedores": "provedor",
    "provedorias": "provedoria",
    "provei": "provar",
    "proveio": "provir",
    "proveis": "provar",
    "proveitos": "proveito",
    "proveitosa": "proveitoso",
    "proveitosas": "proveitoso",
    "proveitosos": "proveitoso",
    "proveja": "prover",
    "provejais": "prover",
    "provejam": "prover",
    "provejamo": "prover",
    "provejamos": "prover",
    "provejas": "prover",
    "provejo": "prover",
    "provem": "provir",
    "provemo": "prover",
    "provemos": "prover",
    "provendo": "prover",
    "provenha": "provir",
    "provenhais": "provir",
    "provenham": "provir",
    "provenhamo": "provir",
    "provenhamos": "provir",
    "provenhas": "provir",
    "provenho": "provir",
    "provenientes": "proveniente",
    "proveniências": "proveniência",
    "proventos": "provento",
    "proventrículos": "proventrículo",
    "provençais": "provençal",
    "provençalesca": "provençalesco",
    "provençalescas": "provençalesco",
    "provençalescos": "provençalesco",
    "provençalismos": "provençalismo",
    "provençalistas": "provençalista",
    "provera": "prover",
    "proveram": "prover",
    "proveras": "prover",
    "proverbia": "proverbiar",
    "proverbiada": "proverbiar",
    "proverbiadas": "proverbiar",
    "proverbiado": "proverbiar",
    "proverbiados": "proverbiar",
    "proverbiai": "proverbiar",
    "proverbiais": "proverbiar",
    "proverbializa": "proverbializar",
    "proverbializada": "proverbializar",
    "proverbializadas": "proverbializar",
    "proverbializado": "proverbializar",
    "proverbializados": "proverbializar",
    "proverbializai": "proverbializar",
    "proverbializais": "proverbializar",
    "proverbializam": "proverbializar",
    "proverbializamo": "proverbializar",
    "proverbializamos": "proverbializar",
    "proverbializando": "proverbializar",
    "proverbializara": "proverbializar",
    "proverbializaram": "proverbializar",
    "proverbializaras": "proverbializar",
    "proverbializarde": "proverbializar",
    "proverbializardes": "proverbializar",
    "proverbializare": "proverbializar",
    "proverbializarei": "proverbializar",
    "proverbializareis": "proverbializar",
    "proverbializarem": "proverbializar",
    "proverbializaremos": "proverbializar",
    "proverbializares": "proverbializar",
    "proverbializaria": "proverbializar",
    "proverbializariam": "proverbializar",
    "proverbializarias": "proverbializar",
    "proverbializarmo": "proverbializar",
    "proverbializarmos": "proverbializar",
    "proverbializará": "proverbializar",
    "proverbializarás": "proverbializar",
    "proverbializarão": "proverbializar",
    "proverbializaríamos": "proverbializar",
    "proverbializaríeis": "proverbializar",
    "proverbializas": "proverbializar",
    "proverbializasse": "proverbializar",
    "proverbializassem": "proverbializar",
    "proverbializasses": "proverbializar",
    "proverbializaste": "proverbializar",
    "proverbializastes": "proverbializar",
    "proverbializava": "proverbializar",
    "proverbializavam": "proverbializar",
    "proverbializavas": "proverbializar",
    "proverbialize": "proverbializar",
    "proverbializei": "proverbializar",
    "proverbializeis": "proverbializar",
    "proverbializem": "proverbializar",
    "proverbializemo": "proverbializar",
    "proverbializemos": "proverbializar",
    "proverbializes": "proverbializar",
    "proverbializo": "proverbializar",
    "proverbializou": "proverbializar",
    "proverbializá": "proverbializar",
    "proverbializámo": "proverbializar",
    "proverbializámos": "proverbializar",
    "proverbializáramo": "proverbializar",
    "proverbializáramos": "proverbializar",
    "proverbializárei": "proverbializar",
    "proverbializáreis": "proverbializar",
    "proverbializásseis": "proverbializar",
    "proverbializássemos": "proverbializar",
    "proverbializávamo": "proverbializar",
    "proverbializávamos": "proverbializar",
    "proverbializávei": "proverbializar",
    "proverbializáveis": "proverbializar",
    "proverbiam": "proverbiar",
    "proverbiamo": "proverbiar",
    "proverbiamos": "proverbiar",
    "proverbiando": "proverbiar",
    "proverbiara": "proverbiar",
    "proverbiaram": "proverbiar",
    "proverbiaras": "proverbiar",
    "proverbiarde": "proverbiar",
    "proverbiardes": "proverbiar",
    "proverbiare": "proverbiar",
    "proverbiarei": "proverbiar",
    "proverbiareis": "proverbiar",
    "proverbiarem": "proverbiar",
    "proverbiaremos": "proverbiar",
    "proverbiares": "proverbiar",
    "proverbiaria": "proverbiar",
    "proverbiariam": "proverbiar",
    "proverbiarias": "proverbiar",
    "proverbiarmo": "proverbiar",
    "proverbiarmos": "proverbiar",
    "proverbiará": "proverbiar",
    "proverbiarás": "proverbiar",
    "proverbiarão": "proverbiar",
    "proverbiaríamos": "proverbiar",
    "proverbiaríeis": "proverbiar",
    "proverbias": "proverbiar",
    "proverbiasse": "proverbiar",
    "proverbiassem": "proverbiar",
    "proverbiasses": "proverbiar",
    "proverbiaste": "proverbiar",
    "proverbiastes": "proverbiar",
    "proverbiava": "proverbiar",
    "proverbiavam": "proverbiar",
    "proverbiavas": "proverbiar",
    "proverbie": "proverbiar",
    "proverbiei": "proverbiar",
    "proverbieis": "proverbiar",
    "proverbiem": "proverbiar",
    "proverbiemo": "proverbiar",
    "proverbiemos": "proverbiar",
    "proverbies": "proverbiar",
    "proverbio": "proverbiar",
    "proverbiou": "proverbiar",
    "proverbiá": "proverbiar",
    "proverbiámo": "proverbiar",
    "proverbiámos": "proverbiar",
    "proverbiáramo": "proverbiar",
    "proverbiáramos": "proverbiar",
    "proverbiárei": "proverbiar",
    "proverbiáreis": "proverbiar",
    "proverbiásseis": "proverbiar",
    "proverbiássemos": "proverbiar",
    "proverbiávamo": "proverbiar",
    "proverbiávamos": "proverbiar",
    "proverbiávei": "proverbiar",
    "proverbiáveis": "proverbiar",
    "proverde": "prover",
    "proverdes": "prover",
    "provere": "prover",
    "proverei": "prover",
    "provereis": "prover",
    "proverem": "prover",
    "proveremos": "prover",
    "proveres": "prover",
    "proveria": "prover",
    "proveriam": "prover",
    "proverias": "prover",
    "provermo": "prover",
    "provermos": "prover",
    "proversões": "proversão",
    "proverá": "prover",
    "proverás": "prover",
    "proverão": "prover",
    "proveríamos": "prover",
    "proveríeis": "prover",
    "proves": "provar",
    "provesse": "prover",
    "provessem": "prover",
    "provesses": "prover",
    "proveste": "prover",
    "provestes": "prover",
    "provetas": "proveta",
    "provetes": "provete",
    "proveu": "prover",
    "provi": "prover",
    "provia": "prover",
    "proviam": "prover",
    "provias": "prover",
    "provida": "provido",
    "providas": "provido",
    "providencia": "providenciar",
    "providenciada": "providenciar",
    "providenciadas": "providenciar",
    "providenciado": "providenciar",
    "providenciados": "providenciar",
    "providenciai": "providenciar",
    "providenciais": "providenciar",
    "providencialismos": "providencialismo",
    "providencialistas": "providencialista",
    "providenciam": "providenciar",
    "providenciamo": "providenciar",
    "providenciamos": "providenciar",
    "providenciando": "providenciar",
    "providenciara": "providenciar",
    "providenciaram": "providenciar",
    "providenciaras": "providenciar",
    "providenciarde": "providenciar",
    "providenciardes": "providenciar",
    "providenciare": "providenciar",
    "providenciarei": "providenciar",
    "providenciareis": "providenciar",
    "providenciarem": "providenciar",
    "providenciaremos": "providenciar",
    "providenciares": "providenciar",
    "providenciaria": "providenciar",
    "providenciariam": "providenciar",
    "providenciarias": "providenciar",
    "providenciarmo": "providenciar",
    "providenciarmos": "providenciar",
    "providenciará": "providenciar",
    "providenciarás": "providenciar",
    "providenciarão": "providenciar",
    "providenciaríamos": "providenciar",
    "providenciaríeis": "providenciar",
    "providencias": "providenciar",
    "providenciasse": "providenciar",
    "providenciassem": "providenciar",
    "providenciasses": "providenciar",
    "providenciaste": "providenciar",
    "providenciastes": "providenciar",
    "providenciava": "providenciar",
    "providenciavam": "providenciar",
    "providenciavas": "providenciar",
    "providencie": "providenciar",
    "providenciei": "providenciar",
    "providencieis": "providenciar",
    "providenciem": "providenciar",
    "providenciemo": "providenciar",
    "providenciemos": "providenciar",
    "providencies": "providenciar",
    "providencio": "providenciar",
    "providenciou": "providenciar",
    "providenciá": "providenciar",
    "providenciámo": "providenciar",
    "providenciámos": "providenciar",
    "providenciáramo": "providenciar",
    "providenciáramos": "providenciar",
    "providenciárei": "providenciar",
    "providenciáreis": "providenciar",
    "providenciásseis": "providenciar",
    "providenciássemos": "providenciar",
    "providenciávamo": "providenciar",
    "providenciávamos": "providenciar",
    "providenciávei": "providenciar",
    "providenciáveis": "providenciar",
    "providentes": "providente",
    "provido": "prover",
    "providos": "provido",
    "providências": "providência",
    "proviemo": "provir",
    "proviemos": "provir",
    "provier": "provir",
    "proviera": "provir",
    "provieram": "provir",
    "provieras": "provir",
    "provierdes": "provir",
    "provierem": "provir",
    "provieres": "provir",
    "proviermos": "provir",
    "proviesse": "provir",
    "proviessem": "provir",
    "proviesses": "provir",
    "provieste": "provir",
    "proviestes": "provir",
    "provigária": "provigário",
    "provigárias": "provigário",
    "provigários": "provigário",
    "provim": "provir",
    "provimentos": "provimento",
    "provimo": "provir",
    "provimos": "provir",
    "provinciais": "provincial",
    "provincialados": "provincialado",
    "provincialatos": "provincialato",
    "provincialismos": "provincialismo",
    "provinciana": "provinciano",
    "provincianas": "provinciano",
    "provincianismos": "provincianismo",
    "provincianiza": "provincianizar",
    "provincianizada": "provincianizar",
    "provincianizadas": "provincianizar",
    "provincianizado": "provincianizar",
    "provincianizados": "provincianizar",
    "provincianizai": "provincianizar",
    "provincianizais": "provincianizar",
    "provincianizam": "provincianizar",
    "provincianizamo": "provincianizar",
    "provincianizamos": "provincianizar",
    "provincianizando": "provincianizar",
    "provincianizara": "provincianizar",
    "provincianizaram": "provincianizar",
    "provincianizaras": "provincianizar",
    "provincianizarde": "provincianizar",
    "provincianizardes": "provincianizar",
    "provincianizare": "provincianizar",
    "provincianizarei": "provincianizar",
    "provincianizareis": "provincianizar",
    "provincianizarem": "provincianizar",
    "provincianizaremos": "provincianizar",
    "provincianizares": "provincianizar",
    "provincianizaria": "provincianizar",
    "provincianizariam": "provincianizar",
    "provincianizarias": "provincianizar",
    "provincianizarmo": "provincianizar",
    "provincianizarmos": "provincianizar",
    "provincianizará": "provincianizar",
    "provincianizarás": "provincianizar",
    "provincianizarão": "provincianizar",
    "provincianizaríamos": "provincianizar",
    "provincianizaríeis": "provincianizar",
    "provincianizas": "provincianizar",
    "provincianizasse": "provincianizar",
    "provincianizassem": "provincianizar",
    "provincianizasses": "provincianizar",
    "provincianizaste": "provincianizar",
    "provincianizastes": "provincianizar",
    "provincianizava": "provincianizar",
    "provincianizavam": "provincianizar",
    "provincianizavas": "provincianizar",
    "provincianize": "provincianizar",
    "provincianizei": "provincianizar",
    "provincianizeis": "provincianizar",
    "provincianizem": "provincianizar",
    "provincianizemo": "provincianizar",
    "provincianizemos": "provincianizar",
    "provincianizes": "provincianizar",
    "provincianizo": "provincianizar",
    "provincianizou": "provincianizar",
    "provincianizá": "provincianizar",
    "provincianizámo": "provincianizar",
    "provincianizámos": "provincianizar",
    "provincianizáramo": "provincianizar",
    "provincianizáramos": "provincianizar",
    "provincianizárei": "provincianizar",
    "provincianizáreis": "provincianizar",
    "provincianizásseis": "provincianizar",
    "provincianizássemos": "provincianizar",
    "provincianizávamo": "provincianizar",
    "provincianizávamos": "provincianizar",
    "provincianizávei": "provincianizar",
    "provincianizáveis": "provincianizar",
    "provincianos": "provinciano",
    "provinda": "provir",
    "provindas": "provir",
    "provinde": "provir",
    "provindes": "provir",
    "provindo": "provir",
    "provindos": "provir",
    "provinha": "provir",
    "provinham": "provir",
    "provinhas": "provir",
    "provirdes": "provir",
    "provirei": "provir",
    "provireis": "provir",
    "provirem": "provir",
    "proviremos": "provir",
    "provires": "provir",
    "proviria": "provir",
    "proviriam": "provir",
    "provirias": "provir",
    "provirmo": "provir",
    "provirmos": "provir",
    "provirá": "provir",
    "provirás": "provir",
    "provirão": "provir",
    "proviríamos": "provir",
    "proviríeis": "provir",
    "provisiona": "provisionar",
    "provisionada": "provisionar",
    "provisionadas": "provisionar",
    "provisionado": "provisionar",
    "provisionados": "provisionar",
    "provisionai": "provisionar",
    "provisionais": "provisionar",
    "provisionam": "provisionar",
    "provisionamo": "provisionar",
    "provisionamos": "provisionar",
    "provisionando": "provisionar",
    "provisionara": "provisionar",
    "provisionaram": "provisionar",
    "provisionaras": "provisionar",
    "provisionarde": "provisionar",
    "provisionardes": "provisionar",
    "provisionare": "provisionar",
    "provisionarei": "provisionar",
    "provisionareis": "provisionar",
    "provisionarem": "provisionar",
    "provisionaremos": "provisionar",
    "provisionares": "provisionar",
    "provisionaria": "provisionar",
    "provisionariam": "provisionar",
    "provisionarias": "provisionar",
    "provisionarmo": "provisionar",
    "provisionarmos": "provisionar",
    "provisionará": "provisionar",
    "provisionarás": "provisionar",
    "provisionarão": "provisionar",
    "provisionaríamos": "provisionar",
    "provisionaríeis": "provisionar",
    "provisionas": "provisionar",
    "provisionasse": "provisionar",
    "provisionassem": "provisionar",
    "provisionasses": "provisionar",
    "provisionaste": "provisionar",
    "provisionastes": "provisionar",
    "provisionava": "provisionar",
    "provisionavam": "provisionar",
    "provisionavas": "provisionar",
    "provisione": "provisionar",
    "provisionei": "provisionar",
    "provisioneis": "provisionar",
    "provisionem": "provisionar",
    "provisionemo": "provisionar",
    "provisionemos": "provisionar",
    "provisiones": "provisionar",
    "provisiono": "provisionar",
    "provisionou": "provisionar",
    "provisioná": "provisionar",
    "provisionámo": "provisionar",
    "provisionámos": "provisionar",
    "provisionáramo": "provisionar",
    "provisionáramos": "provisionar",
    "provisionárei": "provisionar",
    "provisionáreis": "provisionar",
    "provisionásseis": "provisionar",
    "provisionássemos": "provisionar",
    "provisionávamo": "provisionar",
    "provisionávamos": "provisionar",
    "provisionávei": "provisionar",
    "provisionáveis": "provisionar",
    "provisora": "provisor",
    "provisorados": "provisorado",
    "provisoras": "provisor",
    "provisores": "provisor",
    "provisorias": "provisoria",
    "provisoriedades": "provisoriedade",
    "provisória": "provisório",
    "provisórias": "provisório",
    "provisórios": "provisório",
    "provisões": "provisão",
    "provitaminas": "provitamina",
    "proviéramo": "provir",
    "proviéramos": "provir",
    "proviéreis": "provir",
    "proviésseis": "provir",
    "proviéssemos": "provir",
    "provo": "provar",
    "provoca": "provocar",
    "provocada": "provocar",
    "provocadas": "provocar",
    "provocado": "provocar",
    "provocadora": "provocador",
    "provocadoras": "provocador",
    "provocadores": "provocador",
    "provocados": "provocar",
    "provocai": "provocar",
    "provocais": "provocar",
    "provocam": "provocar",
    "provocamo": "provocar",
    "provocamos": "provocar",
    "provocando": "provocar",
    "provocantes": "provocante",
    "provocantezinha": "provocante",
    "provocantezinhas": "provocante",
    "provocantezinho": "provocante",
    "provocantezinhos": "provocante",
    "provocantezita": "provocante",
    "provocantezitas": "provocante",
    "provocantezito": "provocante",
    "provocantezitos": "provocante",
    "provocantíssima": "provocante",
    "provocantíssimas": "provocante",
    "provocantíssimo": "provocante",
    "provocantíssimos": "provocante",
    "provocara": "provocar",
    "provocaram": "provocar",
    "provocaras": "provocar",
    "provocarde": "provocar",
    "provocardes": "provocar",
    "provocare": "provocar",
    "provocarei": "provocar",
    "provocareis": "provocar",
    "provocarem": "provocar",
    "provocaremos": "provocar",
    "provocares": "provocar",
    "provocaria": "provocar",
    "provocariam": "provocar",
    "provocarias": "provocar",
    "provocarmo": "provocar",
    "provocarmos": "provocar",
    "provocará": "provocar",
    "provocarás": "provocar",
    "provocarão": "provocar",
    "provocaríamos": "provocar",
    "provocaríeis": "provocar",
    "provocas": "provocar",
    "provocasse": "provocar",
    "provocassem": "provocar",
    "provocasses": "provocar",
    "provocaste": "provocar",
    "provocastes": "provocar",
    "provocativa": "provocativo",
    "provocativas": "provocativo",
    "provocativos": "provocativo",
    "provocatória": "provocatório",
    "provocatórias": "provocatório",
    "provocatórios": "provocatório",
    "provocava": "provocar",
    "provocavam": "provocar",
    "provocavas": "provocar",
    "provocações": "provocação",
    "provoco": "provocar",
    "provocou": "provocar",
    "provocá": "provocar",
    "provocámo": "provocar",
    "provocámos": "provocar",
    "provocáramo": "provocar",
    "provocáramos": "provocar",
    "provocárei": "provocar",
    "provocáreis": "provocar",
    "provocásseis": "provocar",
    "provocássemos": "provocar",
    "provocávamo": "provocar",
    "provocávamos": "provocar",
    "provocávei": "provocar",
    "provocáveis": "provocável",
    "provoque": "provocar",
    "provoquei": "provocar",
    "provoqueis": "provocar",
    "provoquem": "provocar",
    "provoquemo": "provocar",
    "provoquemos": "provocar",
    "provoques": "provocar",
    "provou": "provar",
    "prová": "provar",
    "provámo": "provar",
    "provámos": "provar",
    "prováramo": "provar",
    "prováramos": "provar",
    "provárei": "provar",
    "prováreis": "provar",
    "provásseis": "provar",
    "provássemos": "provar",
    "provávamo": "provar",
    "provávamos": "provar",
    "provávei": "provar",
    "prováveis": "provável",
    "provém": "provir",
    "provéns": "provir",
    "provérbios": "provérbio",
    "provê": "prover",
    "provêem": "prover",
    "provêm": "provir",
    "provêramo": "prover",
    "provêramos": "prover",
    "provêrei": "prover",
    "provêreis": "prover",
    "provês": "prover",
    "provêsseis": "prover",
    "provêssemos": "prover",
    "províamo": "prover",
    "províamos": "prover",
    "províei": "prover",
    "províeis": "prover",
    "províncias": "província",
    "provínhamo": "provir",
    "provínhamos": "provir",
    "provínheis": "provir",
    "proxenetas": "proxeneta",
    "proxenetismos": "proxenetismo",
    "proxenias": "proxenia",
    "proximais": "proximal",
    "proximidades": "proximidade",
    "prozóica": "prozóico",
    "prozóicas": "prozóico",
    "prozóicos": "prozóico",
    "proámo": "proar",
    "proámos": "proar",
    "proáramo": "proar",
    "proáramos": "proar",
    "proáreis": "proar",
    "proásseis": "proar",
    "proássemos": "proar",
    "proávamo": "proar",
    "proávamos": "proar",
    "proáveis": "proar",
    "proémios": "proémio",
    "proíba": "proibir",
    "proíbam": "proibir",
    "proíbas": "proibir",
    "proíbe": "proibir",
    "proíbem": "proibir",
    "proíbes": "proibir",
    "proíbo": "proibir",
    "proótica": "proótico",
    "proóticas": "proótico",
    "proóticos": "proótico",
    "prua": "pruir",
    "pruais": "pruir",
    "pruam": "pruir",
    "pruamo": "pruir",
    "pruamos": "pruir",
    "pruas": "pruir",
    "prudenciais": "prudencial",
    "prudentes": "prudente",
    "prudhommiana": "prudhommiano",
    "prudhommianas": "prudhommiano",
    "prudhommianos": "prudhommiano",
    "prudências": "prudência",
    "pruem": "pruir",
    "prui": "pruir",
    "pruindo": "pruir",
    "pruirde": "pruir",
    "pruirdes": "pruir",
    "pruirei": "pruir",
    "pruireis": "pruir",
    "pruiremos": "pruir",
    "pruiria": "pruir",
    "pruiriam": "pruir",
    "pruirias": "pruir",
    "pruirmo": "pruir",
    "pruirmos": "pruir",
    "pruirá": "pruir",
    "pruirás": "pruir",
    "pruirão": "pruir",
    "pruiríamos": "pruir",
    "pruiríeis": "pruir",
    "pruis": "pruir",
    "pruiu": "pruir",
    "pruma": "prumar",
    "prumada": "prumar",
    "prumadas": "prumar",
    "prumado": "prumar",
    "prumados": "prumar",
    "prumagens": "prumagem",
    "prumai": "prumar",
    "prumais": "prumar",
    "prumam": "prumar",
    "prumamo": "prumar",
    "prumamos": "prumar",
    "prumando": "prumar",
    "prumara": "prumar",
    "prumaram": "prumar",
    "prumaras": "prumar",
    "prumardes": "prumar",
    "prumarei": "prumar",
    "prumareis": "prumar",
    "prumarem": "prumar",
    "prumaremos": "prumar",
    "prumares": "prumar",
    "prumaria": "prumar",
    "prumariam": "prumar",
    "prumarias": "prumar",
    "prumarmo": "prumar",
    "prumarmos": "prumar",
    "prumará": "prumar",
    "prumarás": "prumar",
    "prumarão": "prumar",
    "prumaríamos": "prumar",
    "prumaríeis": "prumar",
    "prumas": "prumar",
    "prumasse": "prumar",
    "prumassem": "prumar",
    "prumasses": "prumar",
    "prumaste": "prumar",
    "prumastes": "prumar",
    "prumava": "prumar",
    "prumavam": "prumar",
    "prumavas": "prumar",
    "prume": "prumar",
    "prumei": "prumar",
    "prumeis": "prumar",
    "prumem": "prumar",
    "prumemo": "prumar",
    "prumemos": "prumar",
    "prumes": "prumar",
    "prumo": "prumar",
    "prumos": "prumo",
    "prumou": "prumar",
    "prumámo": "prumar",
    "prumámos": "prumar",
    "prumáramo": "prumar",
    "prumáramos": "prumar",
    "prumáreis": "prumar",
    "prumásseis": "prumar",
    "prumássemos": "prumar",
    "prumávamo": "prumar",
    "prumávamos": "prumar",
    "prumáveis": "prumar",
    "prumões": "prumão",
    "pruniformes": "pruniforme",
    "pruo": "pruir",
    "prura": "prurir",
    "prurais": "prurir",
    "pruram": "prurir",
    "pruramo": "prurir",
    "pruramos": "prurir",
    "pruras": "prurir",
    "prure": "prurir",
    "prurem": "prurir",
    "prures": "prurir",
    "pruri": "prurir",
    "pruria": "prurir",
    "pruriam": "prurir",
    "prurias": "prurir",
    "prurida": "prurir",
    "pruridas": "prurir",
    "prurido": "prurir",
    "pruridos": "prurir",
    "prurientes": "pruriente",
    "prurigens": "prurigem",
    "pruriginosa": "pruriginoso",
    "pruriginosas": "pruriginoso",
    "pruriginosos": "pruriginoso",
    "prurigos": "prurigo",
    "prurimo": "prurir",
    "prurimos": "prurir",
    "prurindo": "prurir",
    "prurira": "prurir",
    "pruriram": "prurir",
    "pruriras": "prurir",
    "prurirde": "prurir",
    "prurirdes": "prurir",
    "prurire": "prurir",
    "prurirei": "prurir",
    "prurireis": "prurir",
    "prurirem": "prurir",
    "pruriremos": "prurir",
    "prurires": "prurir",
    "pruriria": "prurir",
    "pruririam": "prurir",
    "pruririas": "prurir",
    "prurirmo": "prurir",
    "prurirmos": "prurir",
    "prurirá": "prurir",
    "prurirás": "prurir",
    "prurirão": "prurir",
    "pruriríamos": "prurir",
    "pruriríeis": "prurir",
    "pruris": "prurir",
    "prurisse": "prurir",
    "prurissem": "prurir",
    "prurisses": "prurir",
    "pruriste": "prurir",
    "pruristes": "prurir",
    "pruriu": "prurir",
    "pruro": "prurir",
    "pruríamo": "prurir",
    "pruríamos": "prurir",
    "pruríei": "prurir",
    "pruríeis": "prurir",
    "pruríramo": "prurir",
    "pruríramos": "prurir",
    "prurírei": "prurir",
    "pruríreis": "prurir",
    "prurísseis": "prurir",
    "pruríssemos": "prurir",
    "prussa": "prusso",
    "prussas": "prusso",
    "prussiana": "prussiano",
    "prussianas": "prussiano",
    "prussianos": "prussiano",
    "prussiatos": "prussiato",
    "prussos": "prusso",
    "pruí": "pruir",
    "pruía": "pruir",
    "pruíam": "pruir",
    "pruíamo": "pruir",
    "pruíamos": "pruir",
    "pruías": "pruir",
    "pruída": "pruir",
    "pruídas": "pruir",
    "pruído": "pruir",
    "pruídos": "pruir",
    "pruíei": "pruir",
    "pruíeis": "pruir",
    "pruímo": "pruir",
    "pruímos": "pruir",
    "pruínas": "pruína",
    "pruíra": "pruir",
    "pruíram": "pruir",
    "pruíramo": "pruir",
    "pruíramos": "pruir",
    "pruíras": "pruir",
    "pruíre": "pruir",
    "pruírei": "pruir",
    "pruíreis": "pruir",
    "pruírem": "pruir",
    "pruíres": "pruir",
    "pruís": "pruir",
    "pruísse": "pruir",
    "pruísseis": "pruir",
    "pruíssem": "pruir",
    "pruíssemos": "pruir",
    "pruísses": "pruir",
    "pruíste": "pruir",
    "pruístes": "pruir",
    "prácritos": "prácrito",
    "prásia": "prásio",
    "prásias": "prásio",
    "prásina": "prásino",
    "prásinas": "prásino",
    "prásinos": "prásino",
    "prásios": "prásio",
    "prática": "prático",
    "práticas": "prático",
    "práticos": "prático",
    "práxica": "práxico",
    "práxicas": "práxico",
    "práxicos": "práxico",
    "prândios": "prândio",
    "prédicas": "prédica",
    "prédios": "prédio",
    "prélios": "prélio",
    "prémios": "prémio",
    "prés": "pré",
    "préstamos": "préstamo",
    "préstimos": "préstimo",
    "préstites": "préstite",
    "prévia": "prévio",
    "prévias": "prévio",
    "prévios": "prévio",
    "prímulas": "prímula",
    "príncipes": "príncipe",
    "prístina": "prístino",
    "prístinas": "prístino",
    "prístinos": "prístino",
    "prítanes": "prítane",
    "príticas": "prítica",
    "príticos": "prítico",
    "prítigas": "prítiga",
    "próceres": "prócere",
    "próclises": "próclise",
    "pródiga": "pródigo",
    "pródigas": "pródigo",
    "pródigos": "pródigo",
    "pródromos": "pródromo",
    "prófases": "prófase",
    "prófuga": "prófugo",
    "prófugas": "prófugo",
    "prófugos": "prófugo",
    "prógnata": "prógnato",
    "prógnatas": "prógnato",
    "prógnatos": "prógnato",
    "próis": "prol",
    "prólogos": "prólogo",
    "prónefros": "prónefro",
    "prónuba": "prónubo",
    "prónubas": "prónubo",
    "prónubos": "prónubo",
    "própoles": "própole",
    "própria": "próprio",
    "próprias": "próprio",
    "próprios": "próprio",
    "próspera": "próspero",
    "prósperas": "próspero",
    "prósperos": "próspero",
    "próstatas": "próstata",
    "prósteses": "próstese",
    "prótalos": "prótalo",
    "prótases": "prótase",
    "prótea": "próteo",
    "próteas": "próteo",
    "próteos": "próteo",
    "próteses": "prótese",
    "prótios": "prótio",
    "próvida": "próvido",
    "próvidas": "próvido",
    "próvidos": "próvido",
    "próxima": "próximo",
    "próximas": "próximo",
    "próximos": "próximo",
    "prússica": "prússico",
    "prússicas": "prússico",
    "prússicos": "prússico",
    "psamites": "psamite",
    "psamitos": "psamito",
    "psamofilias": "psamofilia",
    "psamofítica": "psamofítico",
    "psamofíticas": "psamofítico",
    "psamofíticos": "psamofítico",
    "psamítica": "psamítico",
    "psamíticas": "psamítico",
    "psamíticos": "psamítico",
    "psamófila": "psamófilo",
    "psamófilas": "psamófilo",
    "psamófilos": "psamófilo",
    "psamófita": "psamófito",
    "psamófitas": "psamófito",
    "psamófitos": "psamófito",
    "psefites": "psefite",
    "psefitos": "psefito",
    "pselismos": "pselismo",
    "pselistas": "pselista",
    "pseudocandidata": "pseudocandidato",
    "pseudocandidatas": "pseudocandidato",
    "pseudocandidatos": "pseudocandidato",
    "pseudocandidaturas": "pseudocandidatura",
    "pseudocientistas": "pseudocientista",
    "pseudocientífica": "pseudocientífico",
    "pseudocientíficas": "pseudocientífico",
    "pseudocientíficos": "pseudocientífico",
    "pseudociências": "pseudociência",
    "pseudoconhecedora": "pseudoconhecedor",
    "pseudoconhecedoras": "pseudoconhecedor",
    "pseudoconhecedores": "pseudoconhecedor",
    "pseudoformadora": "pseudoformador",
    "pseudoformadoras": "pseudoformador",
    "pseudoformadores": "pseudoformador",
    "pseudogótica": "pseudogótico",
    "pseudogóticas": "pseudogótico",
    "pseudogóticos": "pseudogótico",
    "pseudojornalismos": "pseudojornalismo",
    "pseudojornalistas": "pseudojornalista",
    "pseudomoralistas": "pseudomoralista",
    "pseudomorfa": "pseudomorfo",
    "pseudomorfas": "pseudomorfo",
    "pseudomorfos": "pseudomorfo",
    "pseudomorfoses": "pseudomorfose",
    "pseudoneurópteros": "pseudoneuróptero",
    "pseudonevrópteros": "pseudonevróptero",
    "pseudonímias": "pseudonímia",
    "pseudonímica": "pseudonímico",
    "pseudonímicas": "pseudonímico",
    "pseudonímicos": "pseudonímico",
    "pseudoparênquimas": "pseudoparênquima",
    "pseudoprofetas": "pseudoprofeta",
    "pseudoprofetisa": "pseudoprofeta",
    "pseudoprofetisas": "pseudoprofeta",
    "pseudotecidos": "pseudotecido",
    "pseudotuberculosa": "pseudotuberculoso",
    "pseudotuberculosas": "pseudotuberculoso",
    "pseudotuberculoses": "pseudotuberculose",
    "pseudotuberculosos": "pseudotuberculoso",
    "pseudélitros": "pseudélitro",
    "pseudónima": "pseudónimo",
    "pseudónimas": "pseudónimo",
    "pseudónimos": "pseudónimo",
    "pseudópodes": "pseudópode",
    "psicadelismos": "psicadelismo",
    "psicadélica": "psicadélico",
    "psicadélicas": "psicadélico",
    "psicadélicos": "psicadélico",
    "psicagogias": "psicagogia",
    "psicagógica": "psicagógico",
    "psicagógicas": "psicagógico",
    "psicagógicos": "psicagógico",
    "psicalgias": "psicalgia",
    "psicanalistas": "psicanalista",
    "psicanalítica": "psicanalítico",
    "psicanalíticas": "psicanalítico",
    "psicanalíticos": "psicanalítico",
    "psicanálises": "psicanálise",
    "psicastenias": "psicastenia",
    "psicasténica": "psicasténico",
    "psicasténicas": "psicasténico",
    "psicasténicos": "psicasténico",
    "psicochoques": "psicochoque",
    "psicocirurgias": "psicocirurgia",
    "psicocirúrgica": "psicocirúrgico",
    "psicocirúrgicas": "psicocirúrgico",
    "psicocirúrgicos": "psicocirúrgico",
    "psicoculturais": "psicocultural",
    "psicodiagnósticos": "psicodiagnóstico",
    "psicodramas": "psicodrama",
    "psicodramática": "psicodramático",
    "psicodramáticas": "psicodramático",
    "psicodramáticos": "psicodramático",
    "psicofarmacologias": "psicofarmacologia",
    "psicofarmacológica": "psicofarmacológico",
    "psicofarmacológicas": "psicofarmacológico",
    "psicofarmacológicos": "psicofarmacológico",
    "psicofisiologias": "psicofisiologia",
    "psicofisiologistas": "psicofisiologista",
    "psicofisiológica": "psicofisiológico",
    "psicofisiológicas": "psicofisiológico",
    "psicofisiológicos": "psicofisiológico",
    "psicofísica": "psicofísico",
    "psicofísicas": "psicofísico",
    "psicofísicos": "psicofísico",
    "psicogenias": "psicogenia",
    "psicogenésica": "psicogenésico",
    "psicogenésicas": "psicogenésico",
    "psicogenésicos": "psicogenésico",
    "psicogenética": "psicogenético",
    "psicogenéticas": "psicogenético",
    "psicogenéticos": "psicogenético",
    "psicognosias": "psicognosia",
    "psicognóstica": "psicognóstico",
    "psicognósticas": "psicognóstico",
    "psicognósticos": "psicognóstico",
    "psicografias": "psicografia",
    "psicogramas": "psicograma",
    "psicográfica": "psicográfico",
    "psicográficas": "psicográfico",
    "psicográficos": "psicográfico",
    "psicogéneses": "psicogénese",
    "psicolepsias": "psicolepsia",
    "psicolexias": "psicolexia",
    "psicolinguísticas": "psicolinguística",
    "psicologias": "psicologia",
    "psicologismos": "psicologismo",
    "psicologistas": "psicologista",
    "psicoléptica": "psicoléptico",
    "psicolépticas": "psicoléptico",
    "psicolépticos": "psicoléptico",
    "psicolética": "psicolético",
    "psicoléticas": "psicolético",
    "psicoléticos": "psicolético",
    "psicoléxica": "psicoléxico",
    "psicoléxicas": "psicoléxico",
    "psicoléxicos": "psicoléxico",
    "psicológica": "psicológico",
    "psicológicas": "psicológico",
    "psicológicos": "psicológico",
    "psicomancias": "psicomancia",
    "psicomantes": "psicomante",
    "psicometrias": "psicometria",
    "psicomotora": "psicomotor",
    "psicomotoras": "psicomotor",
    "psicomotores": "psicomotor",
    "psicomântica": "psicomântico",
    "psicomânticas": "psicomântico",
    "psicomânticos": "psicomântico",
    "psicométrica": "psicométrico",
    "psicométricas": "psicométrico",
    "psicométricos": "psicométrico",
    "psiconeuroses": "psiconeurose",
    "psiconeurótica": "psiconeurótico",
    "psiconeuróticas": "psiconeurótico",
    "psiconeuróticos": "psiconeurótico",
    "psiconometrias": "psiconometria",
    "psicopatas": "psicopata",
    "psicopatias": "psicopatia",
    "psicopatologias": "psicopatologia",
    "psicopatologistas": "psicopatologista",
    "psicopatológica": "psicopatológico",
    "psicopatológicas": "psicopatológico",
    "psicopatológicos": "psicopatológico",
    "psicopedagoga": "psicopedagogo",
    "psicopedagogas": "psicopedagogo",
    "psicopedagogias": "psicopedagogia",
    "psicopedagogos": "psicopedagogo",
    "psicopedagógica": "psicopedagógico",
    "psicopedagógicas": "psicopedagógico",
    "psicopedagógicos": "psicopedagógico",
    "psicoplegias": "psicoplegia",
    "psicoplégica": "psicoplégico",
    "psicoplégicas": "psicoplégico",
    "psicoplégicos": "psicoplégico",
    "psicopompa": "psicopompo",
    "psicopompas": "psicopompo",
    "psicopompos": "psicopompo",
    "psicoprofilaxias": "psicoprofilaxia",
    "psicoprofilática": "psicoprofilático",
    "psicoprofiláticas": "psicoprofilático",
    "psicoprofiláticos": "psicoprofilático",
    "psicopática": "psicopático",
    "psicopáticas": "psicopático",
    "psicopáticos": "psicopático",
    "psicorrigidezes": "psicorrigidez",
    "psicoses": "psicose",
    "psicossexuais": "psicossexual",
    "psicossociais": "psicossocial",
    "psicossociologias": "psicossociologia",
    "psicossociologistas": "psicossociologista",
    "psicossocióloga": "psicossociólogo",
    "psicossociólogas": "psicossociólogo",
    "psicossociólogos": "psicossociólogo",
    "psicossomática": "psicossomático",
    "psicossomáticas": "psicossomático",
    "psicossomáticos": "psicossomático",
    "psicoterapeutas": "psicoterapeuta",
    "psicoterapias": "psicoterapia",
    "psicotrópica": "psicotrópico",
    "psicotrópicas": "psicotrópico",
    "psicotrópicos": "psicotrópico",
    "psicotécnica": "psicotécnico",
    "psicotécnicas": "psicotécnico",
    "psicotécnicos": "psicotécnico",
    "psicrometrias": "psicrometria",
    "psicrométrica": "psicrométrico",
    "psicrométricas": "psicrométrico",
    "psicrométricos": "psicrométrico",
    "psicronométrica": "psicronométrico",
    "psicronométricas": "psicronométrico",
    "psicronométricos": "psicronométrico",
    "psicrómetros": "psicrómetro",
    "psicálgica": "psicálgico",
    "psicálgicas": "psicálgico",
    "psicálgicos": "psicálgico",
    "psicógrafa": "psicógrafo",
    "psicógrafas": "psicógrafo",
    "psicógrafos": "psicógrafo",
    "psicóloga": "psicólogo",
    "psicólogas": "psicólogo",
    "psicólogos": "psicólogo",
    "psicómetras": "psicómetra",
    "psicótica": "psicótico",
    "psicóticas": "psicótico",
    "psicóticos": "psicótico",
    "psilomelanos": "psilomelano",
    "psilos": "psilo",
    "psiques": "psique",
    "psiquiatra": "psiquiatro",
    "psiquiatras": "psiquiatro",
    "psiquiatrias": "psiquiatria",
    "psiquiatros": "psiquiatro",
    "psiquismos": "psiquismo",
    "psiquiátrica": "psiquiátrico",
    "psiquiátricas": "psiquiátrico",
    "psiquiátricos": "psiquiátrico",
    "psis": "psi",
    "psitacismos": "psitacismo",
    "psitacistas": "psitacista",
    "psitacoses": "psitacose",
    "psitacídeos": "psitacídeo",
    "psitacótica": "psitacótico",
    "psitacóticas": "psitacótico",
    "psitacóticos": "psitacótico",
    "psitácidas": "psitácida",
    "psoriática": "psoriático",
    "psoriáticas": "psoriático",
    "psoriáticos": "psoriático",
    "psoríaca": "psoríaco",
    "psoríacas": "psoríaco",
    "psoríacos": "psoríaco",
    "psoríases": "psoríase",
    "psíquica": "psíquico",
    "psíquicas": "psíquico",
    "psíquicos": "psíquico",
    "psórica": "psórico",
    "psóricas": "psórico",
    "psóricos": "psórico",
    "pteridospermas": "pteridosperma",
    "pteridospérmica": "pteridospérmico",
    "pteridospérmicas": "pteridospérmico",
    "pteridospérmicos": "pteridospérmico",
    "pteridófitas": "pteridófita",
    "pteridófitos": "pteridófito",
    "pterigóides": "pterigóide",
    "pterobranquiada": "pterobranquiado",
    "pterobranquiadas": "pterobranquiado",
    "pterobranquiados": "pterobranquiado",
    "pterobrânquia": "pterobrânquio",
    "pterobrânquias": "pterobrânquio",
    "pterobrânquios": "pterobrânquio",
    "pteroclídeos": "pteroclídeo",
    "pterodáctila": "pterodáctilo",
    "pterodáctilas": "pterodáctilo",
    "pterodáctilos": "pterodáctilo",
    "pterofagias": "pterofagia",
    "pterofágica": "pterofágico",
    "pterofágicas": "pterofágico",
    "pterofágicos": "pterofágico",
    "pteromas": "pteroma",
    "pteromedusas": "pteromedusa",
    "pterossauros": "pterossauro",
    "pteróclidas": "pteróclida",
    "pterófaga": "pterófago",
    "pterófagas": "pterófago",
    "pterófagos": "pterófago",
    "pterópodes": "pterópode",
    "pterótica": "pterótico",
    "pteróticas": "pterótico",
    "pteróticos": "pterótico",
    "ptialinas": "ptialina",
    "ptialismos": "ptialismo",
    "ptialistas": "ptialista",
    "ptigmática": "ptigmático",
    "ptigmáticas": "ptigmático",
    "ptigmáticos": "ptigmático",
    "ptolemaica": "ptolemaico",
    "ptolemaicas": "ptolemaico",
    "ptolemaicos": "ptolemaico",
    "ptomatinas": "ptomatina",
    "ptomaínas": "ptomaína",
    "ptoses": "ptose",
    "ptármica": "ptármico",
    "ptármicas": "ptármico",
    "ptármicos": "ptármico",
    "ptérilas": "ptérila",
    "ptérios": "ptério",
    "ptótica": "ptótico",
    "ptóticas": "ptótico",
    "ptóticos": "ptótico",
    "pua": "puir",
    "puadas": "puada",
    "puados": "puado",
    "puais": "puir",
    "puam": "puir",
    "puamo": "puir",
    "puamos": "puir",
    "puas": "puir",
    "puberdades": "puberdade",
    "pubertária": "pubertário",
    "pubertárias": "pubertário",
    "pubertários": "pubertário",
    "pubes": "pube",
    "pubesce": "pubescer",
    "pubescei": "pubescer",
    "pubesceis": "pubescer",
    "pubescem": "pubescer",
    "pubescemo": "pubescer",
    "pubescemos": "pubescer",
    "pubescendo": "pubescer",
    "pubescentes": "pubescente",
    "pubescera": "pubescer",
    "pubesceram": "pubescer",
    "pubesceras": "pubescer",
    "pubescerdes": "pubescer",
    "pubescerei": "pubescer",
    "pubescereis": "pubescer",
    "pubescerem": "pubescer",
    "pubesceremos": "pubescer",
    "pubesceres": "pubescer",
    "pubesceria": "pubescer",
    "pubesceriam": "pubescer",
    "pubescerias": "pubescer",
    "pubescermo": "pubescer",
    "pubescermos": "pubescer",
    "pubescerá": "pubescer",
    "pubescerás": "pubescer",
    "pubescerão": "pubescer",
    "pubesceríamos": "pubescer",
    "pubesceríeis": "pubescer",
    "pubesces": "pubescer",
    "pubescesse": "pubescer",
    "pubescessem": "pubescer",
    "pubescesses": "pubescer",
    "pubesceste": "pubescer",
    "pubescestes": "pubescer",
    "pubesceu": "pubescer",
    "pubesci": "pubescer",
    "pubescia": "pubescer",
    "pubesciam": "pubescer",
    "pubescias": "pubescer",
    "pubescida": "pubescer",
    "pubescidas": "pubescer",
    "pubescido": "pubescer",
    "pubescidos": "pubescer",
    "pubescências": "pubescência",
    "pubescêramo": "pubescer",
    "pubescêramos": "pubescer",
    "pubescêreis": "pubescer",
    "pubescêsseis": "pubescer",
    "pubescêssemos": "pubescer",
    "pubescíamo": "pubescer",
    "pubescíamos": "pubescer",
    "pubescíeis": "pubescer",
    "pubesça": "pubescer",
    "pubesçais": "pubescer",
    "pubesçam": "pubescer",
    "pubesçamo": "pubescer",
    "pubesçamos": "pubescer",
    "pubesças": "pubescer",
    "pubesço": "pubescer",
    "pubicórnea": "pubicórneo",
    "pubicórneas": "pubicórneo",
    "pubicórneos": "pubicórneo",
    "publica": "publicar",
    "publicada": "publicar",
    "publicadas": "publicar",
    "publicado": "publicar",
    "publicadora": "publicador",
    "publicadoras": "publicador",
    "publicadores": "publicador",
    "publicados": "publicar",
    "publicai": "publicar",
    "publicais": "publicar",
    "publicam": "publicar",
    "publicamo": "publicar",
    "publicamos": "publicar",
    "publicando": "publicar",
    "publicanos": "publicano",
    "publicara": "publicar",
    "publicaram": "publicar",
    "publicaras": "publicar",
    "publicarde": "publicar",
    "publicardes": "publicar",
    "publicare": "publicar",
    "publicarei": "publicar",
    "publicareis": "publicar",
    "publicarem": "publicar",
    "publicaremos": "publicar",
    "publicares": "publicar",
    "publicaria": "publicar",
    "publicariam": "publicar",
    "publicarias": "publicar",
    "publicarmo": "publicar",
    "publicarmos": "publicar",
    "publicará": "publicar",
    "publicarás": "publicar",
    "publicarão": "publicar",
    "publicaríamos": "publicar",
    "publicaríeis": "publicar",
    "publicas": "publicar",
    "publicasse": "publicar",
    "publicassem": "publicar",
    "publicasses": "publicar",
    "publicaste": "publicar",
    "publicastes": "publicar",
    "publicava": "publicar",
    "publicavam": "publicar",
    "publicavas": "publicar",
    "publicações": "publicação",
    "publicidades": "publicidade",
    "publicismos": "publicismo",
    "publicistas": "publicista",
    "publicita": "publicitar",
    "publicitada": "publicitar",
    "publicitadas": "publicitar",
    "publicitado": "publicitar",
    "publicitados": "publicitar",
    "publicitai": "publicitar",
    "publicitais": "publicitar",
    "publicitam": "publicitar",
    "publicitamo": "publicitar",
    "publicitamos": "publicitar",
    "publicitando": "publicitar",
    "publicitara": "publicitar",
    "publicitaram": "publicitar",
    "publicitaras": "publicitar",
    "publicitarde": "publicitar",
    "publicitardes": "publicitar",
    "publicitare": "publicitar",
    "publicitarei": "publicitar",
    "publicitareis": "publicitar",
    "publicitarem": "publicitar",
    "publicitaremos": "publicitar",
    "publicitares": "publicitar",
    "publicitaria": "publicitar",
    "publicitariam": "publicitar",
    "publicitarias": "publicitar",
    "publicitarmo": "publicitar",
    "publicitarmos": "publicitar",
    "publicitará": "publicitar",
    "publicitarás": "publicitar",
    "publicitarão": "publicitar",
    "publicitaríamos": "publicitar",
    "publicitaríeis": "publicitar",
    "publicitas": "publicitar",
    "publicitasse": "publicitar",
    "publicitassem": "publicitar",
    "publicitasses": "publicitar",
    "publicitaste": "publicitar",
    "publicitastes": "publicitar",
    "publicitava": "publicitar",
    "publicitavam": "publicitar",
    "publicitavas": "publicitar",
    "publicitações": "publicitação",
    "publicite": "publicitar",
    "publicitei": "publicitar",
    "publiciteis": "publicitar",
    "publicitem": "publicitar",
    "publicitemo": "publicitar",
    "publicitemos": "publicitar",
    "publicites": "publicitar",
    "publicito": "publicitar",
    "publicitou": "publicitar",
    "publicitá": "publicitar",
    "publicitámo": "publicitar",
    "publicitámos": "publicitar",
    "publicitáramo": "publicitar",
    "publicitáramos": "publicitar",
    "publicitárei": "publicitar",
    "publicitáreis": "publicitar",
    "publicitária": "publicitário",
    "publicitárias": "publicitário",
    "publicitários": "publicitário",
    "publicitásseis": "publicitar",
    "publicitássemos": "publicitar",
    "publicitávamo": "publicitar",
    "publicitávamos": "publicitar",
    "publicitávei": "publicitar",
    "publicitáveis": "publicitar",
    "publico": "publicar",
    "publicou": "publicar",
    "publicá": "publicar",
    "publicámo": "publicar",
    "publicámos": "publicar",
    "publicáramo": "publicar",
    "publicáramos": "publicar",
    "publicárei": "publicar",
    "publicáreis": "publicar",
    "publicásseis": "publicar",
    "publicássemos": "publicar",
    "publicávamo": "publicar",
    "publicávamos": "publicar",
    "publicávei": "publicar",
    "publicáveis": "publicável",
    "publique": "publicar",
    "publiquei": "publicar",
    "publiqueis": "publicar",
    "publiquem": "publicar",
    "publiquemo": "publicar",
    "publiquemos": "publicar",
    "publiques": "publicar",
    "publícolas": "publícola",
    "pubs": "pub",
    "pucareira": "pucareiro",
    "pucareiras": "pucareiro",
    "pucareiros": "pucareiro",
    "pucarinho": "púcaro",
    "pucarinhos": "púcaro",
    "pucarito": "púcaro",
    "pucaritos": "púcaro",
    "pude": "poder",
    "pudemo": "poder",
    "pudemos": "poder",
    "pudenda": "pudendo",
    "pudendas": "pudendo",
    "pudendos": "pudendo",
    "pudentes": "pudente",
    "puder": "poder",
    "pudera": "poder",
    "puderam": "poder",
    "puderas": "poder",
    "puderdes": "poder",
    "puderem": "poder",
    "puderes": "poder",
    "pudermos": "poder",
    "pudesse": "poder",
    "pudessem": "poder",
    "pudesses": "poder",
    "pudeste": "poder",
    "pudestes": "poder",
    "pudibunda": "pudibundo",
    "pudibundas": "pudibundo",
    "pudibundos": "pudibundo",
    "pudica": "pudico",
    "pudicas": "pudico",
    "pudicos": "pudico",
    "pudicícias": "pudicícia",
    "pudins": "pudim",
    "pudlagens": "pudlagem",
    "pudores": "pudor",
    "pudvéns": "pudvém",
    "pudéramo": "poder",
    "pudéramos": "poder",
    "pudérei": "poder",
    "pudéreis": "poder",
    "pudésseis": "poder",
    "pudéssemos": "poder",
    "puelares": "puelar",
    "puem": "puir",
    "puericultora": "puericultor",
    "puericultoras": "puericultor",
    "puericultores": "puericultor",
    "puericulturas": "puericultura",
    "puerilidades": "puerilidade",
    "puerilismos": "puerilismo",
    "pueriliza": "puerilizar",
    "puerilizada": "puerilizar",
    "puerilizadas": "puerilizar",
    "puerilizado": "puerilizar",
    "puerilizados": "puerilizar",
    "puerilizai": "puerilizar",
    "puerilizais": "puerilizar",
    "puerilizam": "puerilizar",
    "puerilizamo": "puerilizar",
    "puerilizamos": "puerilizar",
    "puerilizando": "puerilizar",
    "puerilizara": "puerilizar",
    "puerilizaram": "puerilizar",
    "puerilizaras": "puerilizar",
    "puerilizarde": "puerilizar",
    "puerilizardes": "puerilizar",
    "puerilizare": "puerilizar",
    "puerilizarei": "puerilizar",
    "puerilizareis": "puerilizar",
    "puerilizarem": "puerilizar",
    "puerilizaremos": "puerilizar",
    "puerilizares": "puerilizar",
    "puerilizaria": "puerilizar",
    "puerilizariam": "puerilizar",
    "puerilizarias": "puerilizar",
    "puerilizarmo": "puerilizar",
    "puerilizarmos": "puerilizar",
    "puerilizará": "puerilizar",
    "puerilizarás": "puerilizar",
    "puerilizarão": "puerilizar",
    "puerilizaríamos": "puerilizar",
    "puerilizaríeis": "puerilizar",
    "puerilizas": "puerilizar",
    "puerilizasse": "puerilizar",
    "puerilizassem": "puerilizar",
    "puerilizasses": "puerilizar",
    "puerilizaste": "puerilizar",
    "puerilizastes": "puerilizar",
    "puerilizava": "puerilizar",
    "puerilizavam": "puerilizar",
    "puerilizavas": "puerilizar",
    "puerilize": "puerilizar",
    "puerilizei": "puerilizar",
    "puerilizeis": "puerilizar",
    "puerilizem": "puerilizar",
    "puerilizemo": "puerilizar",
    "puerilizemos": "puerilizar",
    "puerilizes": "puerilizar",
    "puerilizo": "puerilizar",
    "puerilizou": "puerilizar",
    "puerilizá": "puerilizar",
    "puerilizámo": "puerilizar",
    "puerilizámos": "puerilizar",
    "puerilizáramo": "puerilizar",
    "puerilizáramos": "puerilizar",
    "puerilizárei": "puerilizar",
    "puerilizáreis": "puerilizar",
    "puerilizásseis": "puerilizar",
    "puerilizássemos": "puerilizar",
    "puerilizávamo": "puerilizar",
    "puerilizávamos": "puerilizar",
    "puerilizávei": "puerilizar",
    "puerilizáveis": "puerilizar",
    "pueris": "pueril",
    "puerperais": "puerperal",
    "puerperalidades": "puerperalidade",
    "puerpérios": "puerpério",
    "puerícias": "puerícia",
    "pufes": "pufe",
    "pufos": "pufo",
    "pugila": "pugilar",
    "pugilada": "pugilar",
    "pugiladas": "pugilar",
    "pugilado": "pugilar",
    "pugilados": "pugilar",
    "pugilai": "pugilar",
    "pugilais": "pugilar",
    "pugilam": "pugilar",
    "pugilamo": "pugilar",
    "pugilamos": "pugilar",
    "pugilando": "pugilar",
    "pugilara": "pugilar",
    "pugilaram": "pugilar",
    "pugilaras": "pugilar",
    "pugilardes": "pugilar",
    "pugilarei": "pugilar",
    "pugilareis": "pugilar",
    "pugilarem": "pugilar",
    "pugilaremos": "pugilar",
    "pugilares": "pugilar",
    "pugilaria": "pugilar",
    "pugilariam": "pugilar",
    "pugilarias": "pugilar",
    "pugilarmo": "pugilar",
    "pugilarmos": "pugilar",
    "pugilará": "pugilar",
    "pugilarás": "pugilar",
    "pugilarão": "pugilar",
    "pugilaríamos": "pugilar",
    "pugilaríeis": "pugilar",
    "pugilas": "pugilar",
    "pugilasse": "pugilar",
    "pugilassem": "pugilar",
    "pugilasses": "pugilar",
    "pugilaste": "pugilar",
    "pugilastes": "pugilar",
    "pugilatos": "pugilato",
    "pugilava": "pugilar",
    "pugilavam": "pugilar",
    "pugilavas": "pugilar",
    "pugile": "pugilar",
    "pugilei": "pugilar",
    "pugileis": "pugilar",
    "pugilem": "pugilar",
    "pugilemo": "pugilar",
    "pugilemos": "pugilar",
    "pugiles": "pugilar",
    "pugilismos": "pugilismo",
    "pugilistas": "pugilista",
    "pugilo": "pugilar",
    "pugilos": "pugilo",
    "pugilou": "pugilar",
    "pugilámo": "pugilar",
    "pugilámos": "pugilar",
    "pugiláramo": "pugilar",
    "pugiláramos": "pugilar",
    "pugiláreis": "pugilar",
    "pugilásseis": "pugilar",
    "pugilássemos": "pugilar",
    "pugilávamo": "pugilar",
    "pugilávamos": "pugilar",
    "pugiláveis": "pugilar",
    "pugilómetros": "pugilómetro",
    "pugna": "pugnar",
    "pugnacidades": "pugnacidade",
    "pugnada": "pugnar",
    "pugnadas": "pugnar",
    "pugnado": "pugnar",
    "pugnadora": "pugnador",
    "pugnadoras": "pugnador",
    "pugnadores": "pugnador",
    "pugnados": "pugnar",
    "pugnai": "pugnar",
    "pugnais": "pugnar",
    "pugnam": "pugnar",
    "pugnamo": "pugnar",
    "pugnamos": "pugnar",
    "pugnando": "pugnar",
    "pugnara": "pugnar",
    "pugnaram": "pugnar",
    "pugnaras": "pugnar",
    "pugnardes": "pugnar",
    "pugnarei": "pugnar",
    "pugnareis": "pugnar",
    "pugnarem": "pugnar",
    "pugnaremos": "pugnar",
    "pugnares": "pugnar",
    "pugnaria": "pugnar",
    "pugnariam": "pugnar",
    "pugnarias": "pugnar",
    "pugnarmo": "pugnar",
    "pugnarmos": "pugnar",
    "pugnará": "pugnar",
    "pugnarás": "pugnar",
    "pugnarão": "pugnar",
    "pugnaríamos": "pugnar",
    "pugnaríeis": "pugnar",
    "pugnas": "pugnar",
    "pugnasse": "pugnar",
    "pugnassem": "pugnar",
    "pugnasses": "pugnar",
    "pugnaste": "pugnar",
    "pugnastes": "pugnar",
    "pugnava": "pugnar",
    "pugnavam": "pugnar",
    "pugnavas": "pugnar",
    "pugnazes": "pugnaz",
    "pugne": "pugnar",
    "pugnei": "pugnar",
    "pugneis": "pugnar",
    "pugnem": "pugnar",
    "pugnemo": "pugnar",
    "pugnemos": "pugnar",
    "pugnes": "pugnar",
    "pugno": "pugnar",
    "pugnou": "pugnar",
    "pugnámo": "pugnar",
    "pugnámos": "pugnar",
    "pugnáramo": "pugnar",
    "pugnáramos": "pugnar",
    "pugnáreis": "pugnar",
    "pugnásseis": "pugnar",
    "pugnássemos": "pugnar",
    "pugnávamo": "pugnar",
    "pugnávamos": "pugnar",
    "pugnáveis": "pugnar",
    "pui": "puir",
    "puias": "puia",
    "puideiras": "puideira",
    "puidinha": "puído",
    "puidinhas": "puído",
    "puidinho": "puído",
    "puidinhos": "puído",
    "puidita": "puído",
    "puiditas": "puído",
    "puidito": "puído",
    "puiditos": "puído",
    "puidoiros": "puidoiro",
    "puidouros": "puidouro",
    "puidíssima": "puído",
    "puidíssimas": "puído",
    "puidíssimo": "puído",
    "puidíssimos": "puído",
    "puindo": "puir",
    "puirde": "puir",
    "puirdes": "puir",
    "puirei": "puir",
    "puireis": "puir",
    "puiremos": "puir",
    "puiria": "puir",
    "puiriam": "puir",
    "puirias": "puir",
    "puirmo": "puir",
    "puirmos": "puir",
    "puirá": "puir",
    "puirás": "puir",
    "puirão": "puir",
    "puiríamos": "puir",
    "puiríeis": "puir",
    "puis": "puir",
    "puiu": "puir",
    "puja": "pujar",
    "pujada": "pujar",
    "pujadas": "pujar",
    "pujado": "pujar",
    "pujados": "pujar",
    "pujai": "pujar",
    "pujais": "pujar",
    "pujam": "pujar",
    "pujamo": "pujar",
    "pujamos": "pujar",
    "pujando": "pujar",
    "pujantes": "pujante",
    "pujanças": "pujança",
    "pujara": "pujar",
    "pujaram": "pujar",
    "pujaras": "pujar",
    "pujardes": "pujar",
    "pujarei": "pujar",
    "pujareis": "pujar",
    "pujarem": "pujar",
    "pujaremos": "pujar",
    "pujares": "pujar",
    "pujaria": "pujar",
    "pujariam": "pujar",
    "pujarias": "pujar",
    "pujarmo": "pujar",
    "pujarmos": "pujar",
    "pujará": "pujar",
    "pujarás": "pujar",
    "pujarão": "pujar",
    "pujaríamos": "pujar",
    "pujaríeis": "pujar",
    "pujas": "pujar",
    "pujasse": "pujar",
    "pujassem": "pujar",
    "pujasses": "pujar",
    "pujaste": "pujar",
    "pujastes": "pujar",
    "pujava": "pujar",
    "pujavam": "pujar",
    "pujavas": "pujar",
    "puje": "pujar",
    "pujei": "pujar",
    "pujeis": "pujar",
    "pujem": "pujar",
    "pujemo": "pujar",
    "pujemos": "pujar",
    "pujes": "pujar",
    "pujo": "pujar",
    "pujou": "pujar",
    "pujámo": "pujar",
    "pujámos": "pujar",
    "pujáramo": "pujar",
    "pujáramos": "pujar",
    "pujáreis": "pujar",
    "pujásseis": "pujar",
    "pujássemos": "pujar",
    "pujávamo": "pujar",
    "pujávamos": "pujar",
    "pujáveis": "pujar",
    "pula": "pular",
    "pulada": "pular",
    "puladas": "pular",
    "pulado": "pular",
    "pulados": "pular",
    "pulai": "pular",
    "pulais": "pular",
    "pulam": "pular",
    "pulamo": "pular",
    "pulamos": "pular",
    "pulando": "pular",
    "pulantes": "pulante",
    "pulara": "pular",
    "pularam": "pular",
    "pularas": "pular",
    "pularde": "pular",
    "pulardes": "pular",
    "pulare": "pular",
    "pularei": "pular",
    "pulareis": "pular",
    "pularem": "pular",
    "pularemos": "pular",
    "pulares": "pular",
    "pularia": "pular",
    "pulariam": "pular",
    "pularias": "pular",
    "pularmo": "pular",
    "pularmos": "pular",
    "pulará": "pular",
    "pularás": "pular",
    "pularão": "pular",
    "pularíamos": "pular",
    "pularíeis": "pular",
    "pulas": "pular",
    "pulasse": "pular",
    "pulassem": "pular",
    "pulasses": "pular",
    "pulaste": "pular",
    "pulastes": "pular",
    "pulava": "pular",
    "pulavam": "pular",
    "pulavas": "pular",
    "pulcra": "pulcro",
    "pulcras": "pulcro",
    "pulcritudes": "pulcritude",
    "pulcros": "pulcro",
    "pulcrícoma": "pulcrícomo",
    "pulcrícomas": "pulcrícomo",
    "pulcrícomos": "pulcrícomo",
    "pule": "pular",
    "pulei": "pular",
    "puleis": "pular",
    "pulem": "pular",
    "pulemo": "pular",
    "pulemos": "pular",
    "pules": "pular",
    "pulga": "pulgo",
    "pulgas": "pulgo",
    "pulgos": "pulgo",
    "pulgosa": "pulgoso",
    "pulgosas": "pulgoso",
    "pulgosos": "pulgoso",
    "pulguedos": "pulguedo",
    "pulguenta": "pulguento",
    "pulguentas": "pulguento",
    "pulguentos": "pulguento",
    "pulgões": "pulgão",
    "pulhas": "pulha",
    "pulhastra": "pulhastro",
    "pulhastras": "pulhastro",
    "pulhastros": "pulhastro",
    "pulhices": "pulhice",
    "pulhismos": "pulhismo",
    "pulicárias": "pulicária",
    "pulinho": "pulo",
    "pulinhos": "pulo",
    "pulito": "pulo",
    "pulitos": "pulo",
    "pulitárias": "pulitária",
    "pulmoeiras": "pulmoeira",
    "pulmonada": "pulmonado",
    "pulmonadas": "pulmonado",
    "pulmonados": "pulmonado",
    "pulmonares": "pulmonar",
    "pulmonias": "pulmonia",
    "pulmonárias": "pulmonária",
    "pulmotuberculosa": "pulmotuberculoso",
    "pulmotuberculosas": "pulmotuberculoso",
    "pulmotuberculoses": "pulmotuberculose",
    "pulmotuberculosos": "pulmotuberculoso",
    "pulmónica": "pulmónico",
    "pulmónicas": "pulmónico",
    "pulmónicos": "pulmónico",
    "pulmões": "pulmão",
    "pulo": "pular",
    "pulos": "pulo",
    "pulou": "pular",
    "pulquérrima": "pulcro",
    "pulquérrimas": "pulcro",
    "pulquérrimo": "pulcro",
    "pulquérrimos": "pulcro",
    "pulsa": "pulsar",
    "pulsada": "pulsar",
    "pulsadas": "pulsar",
    "pulsado": "pulsar",
    "pulsados": "pulsar",
    "pulsai": "pulsar",
    "pulsais": "pulsar",
    "pulsam": "pulsar",
    "pulsamo": "pulsar",
    "pulsamos": "pulsar",
    "pulsando": "pulsar",
    "pulsara": "pulsar",
    "pulsaram": "pulsar",
    "pulsaras": "pulsar",
    "pulsarde": "pulsar",
    "pulsardes": "pulsar",
    "pulsare": "pulsar",
    "pulsarei": "pulsar",
    "pulsareis": "pulsar",
    "pulsarem": "pulsar",
    "pulsaremos": "pulsar",
    "pulsares": "pulsar",
    "pulsaria": "pulsar",
    "pulsariam": "pulsar",
    "pulsarias": "pulsar",
    "pulsarmo": "pulsar",
    "pulsarmos": "pulsar",
    "pulsará": "pulsar",
    "pulsarás": "pulsar",
    "pulsarão": "pulsar",
    "pulsaríamos": "pulsar",
    "pulsaríeis": "pulsar",
    "pulsas": "pulsar",
    "pulsasse": "pulsar",
    "pulsassem": "pulsar",
    "pulsasses": "pulsar",
    "pulsaste": "pulsar",
    "pulsastes": "pulsar",
    "pulsatilas": "pulsatila",
    "pulsativa": "pulsativo",
    "pulsativas": "pulsativo",
    "pulsativos": "pulsativo",
    "pulsatória": "pulsatório",
    "pulsatórias": "pulsatório",
    "pulsatórios": "pulsatório",
    "pulsava": "pulsar",
    "pulsavam": "pulsar",
    "pulsavas": "pulsar",
    "pulsações": "pulsação",
    "pulse": "pulsar",
    "pulseada": "pulsear",
    "pulseadas": "pulsear",
    "pulseado": "pulsear",
    "pulseados": "pulsear",
    "pulseai": "pulsear",
    "pulseais": "pulsear",
    "pulseamo": "pulsear",
    "pulseamos": "pulsear",
    "pulseando": "pulsear",
    "pulseara": "pulsear",
    "pulsearam": "pulsear",
    "pulsearas": "pulsear",
    "pulseardes": "pulsear",
    "pulsearei": "pulsear",
    "pulseareis": "pulsear",
    "pulsearem": "pulsear",
    "pulsearemos": "pulsear",
    "pulseares": "pulsear",
    "pulsearia": "pulsear",
    "pulseariam": "pulsear",
    "pulsearias": "pulsear",
    "pulsearmo": "pulsear",
    "pulsearmos": "pulsear",
    "pulseará": "pulsear",
    "pulsearás": "pulsear",
    "pulsearão": "pulsear",
    "pulsearíamos": "pulsear",
    "pulsearíeis": "pulsear",
    "pulseasse": "pulsear",
    "pulseassem": "pulsear",
    "pulseasses": "pulsear",
    "pulseaste": "pulsear",
    "pulseastes": "pulsear",
    "pulseava": "pulsear",
    "pulseavam": "pulsear",
    "pulseavas": "pulsear",
    "pulseei": "pulsear",
    "pulseeis": "pulsear",
    "pulseemo": "pulsear",
    "pulseemos": "pulsear",
    "pulsei": "pulsar",
    "pulseia": "pulsear",
    "pulseiam": "pulsear",
    "pulseias": "pulsear",
    "pulseie": "pulsear",
    "pulseiem": "pulsear",
    "pulseies": "pulsear",
    "pulseio": "pulsear",
    "pulseiras": "pulseira",
    "pulseirinha": "pulseira",
    "pulseirinhas": "pulseira",
    "pulseirita": "pulseira",
    "pulseiritas": "pulseira",
    "pulseis": "pulsar",
    "pulsem": "pulsar",
    "pulsemo": "pulsar",
    "pulsemos": "pulsar",
    "pulseou": "pulsear",
    "pulses": "pulsar",
    "pulseámo": "pulsear",
    "pulseámos": "pulsear",
    "pulseáramo": "pulsear",
    "pulseáramos": "pulsear",
    "pulseáreis": "pulsear",
    "pulseásseis": "pulsear",
    "pulseássemos": "pulsear",
    "pulseávamo": "pulsear",
    "pulseávamos": "pulsear",
    "pulseáveis": "pulsear",
    "pulsimétrica": "pulsimétrico",
    "pulsimétricas": "pulsimétrico",
    "pulsimétricos": "pulsimétrico",
    "pulso": "pulsar",
    "pulsos": "pulso",
    "pulsou": "pulsar",
    "pulsá": "pulsar",
    "pulsámo": "pulsar",
    "pulsámos": "pulsar",
    "pulsáramo": "pulsar",
    "pulsáramos": "pulsar",
    "pulsárei": "pulsar",
    "pulsáreis": "pulsar",
    "pulsásseis": "pulsar",
    "pulsássemos": "pulsar",
    "pulsátis": "pulsátil",
    "pulsávamo": "pulsar",
    "pulsávamos": "pulsar",
    "pulsávei": "pulsar",
    "pulsáveis": "pulsar",
    "pulsímetros": "pulsímetro",
    "pulsões": "pulsão",
    "pultações": "pultação",
    "pultácea": "pultáceo",
    "pultáceas": "pultáceo",
    "pultáceos": "pultáceo",
    "pulula": "pulular",
    "pululada": "pulular",
    "pululadas": "pulular",
    "pululado": "pulular",
    "pululados": "pulular",
    "pululai": "pulular",
    "pululais": "pulular",
    "pululam": "pulular",
    "pululamentos": "pululamento",
    "pululamo": "pulular",
    "pululamos": "pulular",
    "pululando": "pulular",
    "pululantes": "pululante",
    "pululara": "pulular",
    "pulularam": "pulular",
    "pulularas": "pulular",
    "pululardes": "pulular",
    "pulularei": "pulular",
    "pululareis": "pulular",
    "pulularem": "pulular",
    "pulularemos": "pulular",
    "pululares": "pulular",
    "pulularia": "pulular",
    "pululariam": "pulular",
    "pulularias": "pulular",
    "pulularmo": "pulular",
    "pulularmos": "pulular",
    "pululará": "pulular",
    "pulularás": "pulular",
    "pulularão": "pulular",
    "pulularíamos": "pulular",
    "pulularíeis": "pulular",
    "pululas": "pulular",
    "pululasse": "pulular",
    "pululassem": "pulular",
    "pululasses": "pulular",
    "pululaste": "pulular",
    "pululastes": "pulular",
    "pululava": "pulular",
    "pululavam": "pulular",
    "pululavas": "pulular",
    "pululações": "pululação",
    "pulule": "pulular",
    "pululei": "pulular",
    "pululeis": "pulular",
    "pululem": "pulular",
    "pululemo": "pulular",
    "pululemos": "pulular",
    "pulules": "pulular",
    "pululo": "pulular",
    "pululou": "pulular",
    "pululámo": "pulular",
    "pululámos": "pulular",
    "pululáramo": "pulular",
    "pululáramos": "pulular",
    "pululáreis": "pulular",
    "pululásseis": "pulular",
    "pululássemos": "pulular",
    "pululávamo": "pulular",
    "pululávamos": "pulular",
    "pululáveis": "pulular",
    "pululâncias": "pululância",
    "pulverescentes": "pulverescente",
    "pulverescências": "pulverescência",
    "pulveriformes": "pulveriforme",
    "pulverinhos": "pulverinho",
    "pulveriza": "pulverizar",
    "pulverizada": "pulverizar",
    "pulverizadas": "pulverizar",
    "pulverizado": "pulverizar",
    "pulverizadora": "pulverizador",
    "pulverizadoras": "pulverizador",
    "pulverizadores": "pulverizador",
    "pulverizados": "pulverizar",
    "pulverizai": "pulverizar",
    "pulverizais": "pulverizar",
    "pulverizam": "pulverizar",
    "pulverizamo": "pulverizar",
    "pulverizamos": "pulverizar",
    "pulverizando": "pulverizar",
    "pulverizara": "pulverizar",
    "pulverizaram": "pulverizar",
    "pulverizaras": "pulverizar",
    "pulverizarde": "pulverizar",
    "pulverizardes": "pulverizar",
    "pulverizare": "pulverizar",
    "pulverizarei": "pulverizar",
    "pulverizareis": "pulverizar",
    "pulverizarem": "pulverizar",
    "pulverizaremos": "pulverizar",
    "pulverizares": "pulverizar",
    "pulverizaria": "pulverizar",
    "pulverizariam": "pulverizar",
    "pulverizarias": "pulverizar",
    "pulverizarmo": "pulverizar",
    "pulverizarmos": "pulverizar",
    "pulverizará": "pulverizar",
    "pulverizarás": "pulverizar",
    "pulverizarão": "pulverizar",
    "pulverizaríamos": "pulverizar",
    "pulverizaríeis": "pulverizar",
    "pulverizas": "pulverizar",
    "pulverizasse": "pulverizar",
    "pulverizassem": "pulverizar",
    "pulverizasses": "pulverizar",
    "pulverizaste": "pulverizar",
    "pulverizastes": "pulverizar",
    "pulverizava": "pulverizar",
    "pulverizavam": "pulverizar",
    "pulverizavas": "pulverizar",
    "pulverizações": "pulverização",
    "pulverize": "pulverizar",
    "pulverizei": "pulverizar",
    "pulverizeis": "pulverizar",
    "pulverizem": "pulverizar",
    "pulverizemo": "pulverizar",
    "pulverizemos": "pulverizar",
    "pulverizes": "pulverizar",
    "pulverizo": "pulverizar",
    "pulverizou": "pulverizar",
    "pulverizá": "pulverizar",
    "pulverizámo": "pulverizar",
    "pulverizámos": "pulverizar",
    "pulverizáramo": "pulverizar",
    "pulverizáramos": "pulverizar",
    "pulverizárei": "pulverizar",
    "pulverizáreis": "pulverizar",
    "pulverizásseis": "pulverizar",
    "pulverizássemos": "pulverizar",
    "pulverizávamo": "pulverizar",
    "pulverizávamos": "pulverizar",
    "pulverizávei": "pulverizar",
    "pulverizáveis": "pulverizar",
    "pulverosa": "pulveroso",
    "pulverosas": "pulveroso",
    "pulverosos": "pulveroso",
    "pulverulenta": "pulverulento",
    "pulverulentas": "pulverulento",
    "pulverulentos": "pulverulento",
    "pulverulências": "pulverulência",
    "pulverácea": "pulveráceo",
    "pulveráceas": "pulveráceo",
    "pulveráceos": "pulveráceo",
    "pulvimétrica": "pulvimétrico",
    "pulvimétricas": "pulvimétrico",
    "pulvimétricos": "pulvimétrico",
    "pulvinos": "pulvino",
    "pulvérea": "pulvéreo",
    "pulvéreas": "pulvéreo",
    "pulvéreos": "pulvéreo",
    "pulvímetros": "pulvímetro",
    "pulá": "pular",
    "pulámo": "pular",
    "pulámos": "pular",
    "puláramo": "pular",
    "puláramos": "pular",
    "pulárei": "pular",
    "puláreis": "pular",
    "pulásseis": "pular",
    "pulássemos": "pular",
    "pulávamo": "pular",
    "pulávamos": "pular",
    "pulávei": "pular",
    "puláveis": "pular",
    "pumas": "puma",
    "puna": "punir",
    "punais": "punir",
    "punam": "punir",
    "punamo": "punir",
    "punamos": "punir",
    "punas": "punir",
    "punce": "punçar",
    "puncei": "punçar",
    "punceis": "punçar",
    "puncem": "punçar",
    "puncemo": "punçar",
    "puncemos": "punçar",
    "punces": "punçar",
    "puncetas": "punceta",
    "punciona": "puncionar",
    "puncionada": "puncionar",
    "puncionadas": "puncionar",
    "puncionado": "puncionar",
    "puncionados": "puncionar",
    "puncionai": "puncionar",
    "puncionais": "puncionar",
    "puncionam": "puncionar",
    "puncionamo": "puncionar",
    "puncionamos": "puncionar",
    "puncionando": "puncionar",
    "puncionara": "puncionar",
    "puncionaram": "puncionar",
    "puncionaras": "puncionar",
    "puncionarde": "puncionar",
    "puncionardes": "puncionar",
    "puncionare": "puncionar",
    "puncionarei": "puncionar",
    "puncionareis": "puncionar",
    "puncionarem": "puncionar",
    "puncionaremos": "puncionar",
    "puncionares": "puncionar",
    "puncionaria": "puncionar",
    "puncionariam": "puncionar",
    "puncionarias": "puncionar",
    "puncionarmo": "puncionar",
    "puncionarmos": "puncionar",
    "puncionará": "puncionar",
    "puncionarás": "puncionar",
    "puncionarão": "puncionar",
    "puncionaríamos": "puncionar",
    "puncionaríeis": "puncionar",
    "puncionas": "puncionar",
    "puncionasse": "puncionar",
    "puncionassem": "puncionar",
    "puncionasses": "puncionar",
    "puncionaste": "puncionar",
    "puncionastes": "puncionar",
    "puncionava": "puncionar",
    "puncionavam": "puncionar",
    "puncionavas": "puncionar",
    "puncione": "puncionar",
    "puncionei": "puncionar",
    "puncioneis": "puncionar",
    "puncionem": "puncionar",
    "puncionemo": "puncionar",
    "puncionemos": "puncionar",
    "punciones": "puncionar",
    "punciono": "puncionar",
    "puncionou": "puncionar",
    "puncioná": "puncionar",
    "puncionámo": "puncionar",
    "puncionámos": "puncionar",
    "puncionáramo": "puncionar",
    "puncionáramos": "puncionar",
    "puncionárei": "puncionar",
    "puncionáreis": "puncionar",
    "puncionásseis": "puncionar",
    "puncionássemos": "puncionar",
    "puncionávamo": "puncionar",
    "puncionávamos": "puncionar",
    "puncionávei": "puncionar",
    "puncionáveis": "puncionar",
    "punctiformes": "punctiforme",
    "puncturas": "punctura",
    "pundonores": "pundonor",
    "pundonorosa": "pundonoroso",
    "pundonorosas": "pundonoroso",
    "pundonorosos": "pundonoroso",
    "pune": "punir",
    "punem": "punir",
    "punes": "punir",
    "pungas": "punga",
    "punge": "pungir",
    "pungem": "pungir",
    "pungentes": "pungente",
    "punges": "pungir",
    "pungi": "pungir",
    "pungia": "pungir",
    "pungiam": "pungir",
    "pungias": "pungir",
    "pungida": "pungir",
    "pungidas": "pungir",
    "pungido": "pungir",
    "pungidos": "pungir",
    "pungimentos": "pungimento",
    "pungimo": "pungir",
    "pungimos": "pungir",
    "pungindo": "pungir",
    "pungira": "pungir",
    "pungiram": "pungir",
    "pungiras": "pungir",
    "pungirde": "pungir",
    "pungirdes": "pungir",
    "pungire": "pungir",
    "pungirei": "pungir",
    "pungireis": "pungir",
    "pungirem": "pungir",
    "pungiremos": "pungir",
    "pungires": "pungir",
    "pungiria": "pungir",
    "pungiriam": "pungir",
    "pungirias": "pungir",
    "pungirmo": "pungir",
    "pungirmos": "pungir",
    "pungirá": "pungir",
    "pungirás": "pungir",
    "pungirão": "pungir",
    "pungiríamos": "pungir",
    "pungiríeis": "pungir",
    "pungis": "pungir",
    "pungisse": "pungir",
    "pungissem": "pungir",
    "pungisses": "pungir",
    "pungiste": "pungir",
    "pungistes": "pungir",
    "pungitiva": "pungitivo",
    "pungitivas": "pungitivo",
    "pungitivos": "pungitivo",
    "pungiu": "pungir",
    "pungues": "pungue",
    "pungíamo": "pungir",
    "pungíamos": "pungir",
    "pungíei": "pungir",
    "pungíeis": "pungir",
    "pungíramo": "pungir",
    "pungíramos": "pungir",
    "pungírei": "pungir",
    "pungíreis": "pungir",
    "pungísseis": "pungir",
    "pungíssemos": "pungir",
    "punha": "pôr",
    "punhadas": "punhada",
    "punhadinho": "punhado",
    "punhadinhos": "punhado",
    "punhadito": "punhado",
    "punhaditos": "punhado",
    "punhados": "punhado",
    "punhais": "punhal",
    "punhaladas": "punhalada",
    "punham": "pôr",
    "punhas": "pôr",
    "punhetas": "punheta",
    "punheteira": "punheteiro",
    "punheteiras": "punheteiro",
    "punheteiros": "punheteiro",
    "punhetes": "punhete",
    "punhos": "punho",
    "puni": "punir",
    "punia": "punir",
    "puniam": "punir",
    "punias": "punir",
    "punibilidades": "punibilidade",
    "punicáceas": "punicácea",
    "punida": "punir",
    "punidas": "punir",
    "punido": "punir",
    "punidora": "punidor",
    "punidoras": "punidor",
    "punidores": "punidor",
    "punidos": "punir",
    "punimo": "punir",
    "punimos": "punir",
    "punindo": "punir",
    "punira": "punir",
    "puniram": "punir",
    "puniras": "punir",
    "punirde": "punir",
    "punirdes": "punir",
    "punire": "punir",
    "punirei": "punir",
    "punireis": "punir",
    "punirem": "punir",
    "puniremos": "punir",
    "punires": "punir",
    "puniria": "punir",
    "puniriam": "punir",
    "punirias": "punir",
    "punirmo": "punir",
    "punirmos": "punir",
    "punirá": "punir",
    "punirás": "punir",
    "punirão": "punir",
    "puniríamos": "punir",
    "puniríeis": "punir",
    "punis": "punir",
    "punisse": "punir",
    "punissem": "punir",
    "punisses": "punir",
    "puniste": "punir",
    "punistes": "punir",
    "punitiva": "punitivo",
    "punitivas": "punitivo",
    "punitivos": "punitivo",
    "puniu": "punir",
    "punições": "punição",
    "punja": "pungir",
    "punjais": "pungir",
    "punjam": "pungir",
    "punjamo": "pungir",
    "punjamos": "pungir",
    "punjas": "punja",
    "punjo": "pungir",
    "punks": "punk",
    "puno": "punir",
    "puns": "pum",
    "punça": "punçar",
    "punçada": "punçar",
    "punçadas": "punçar",
    "punçado": "punçar",
    "punçados": "punçar",
    "punçai": "punçar",
    "punçais": "punçar",
    "punçam": "punçar",
    "punçamo": "punçar",
    "punçamos": "punçar",
    "punçando": "punçar",
    "punçara": "punçar",
    "punçaram": "punçar",
    "punçaras": "punçar",
    "punçarde": "punçar",
    "punçardes": "punçar",
    "punçare": "punçar",
    "punçarei": "punçar",
    "punçareis": "punçar",
    "punçarem": "punçar",
    "punçaremos": "punçar",
    "punçares": "punçar",
    "punçaria": "punçar",
    "punçariam": "punçar",
    "punçarias": "punçar",
    "punçarmo": "punçar",
    "punçarmos": "punçar",
    "punçará": "punçar",
    "punçarás": "punçar",
    "punçarão": "punçar",
    "punçaríamos": "punçar",
    "punçaríeis": "punçar",
    "punças": "punçar",
    "punçasse": "punçar",
    "punçassem": "punçar",
    "punçasses": "punçar",
    "punçaste": "punçar",
    "punçastes": "punçar",
    "punçava": "punçar",
    "punçavam": "punçar",
    "punçavas": "punçar",
    "punço": "punçar",
    "punçoa": "punçoar",
    "punçoada": "punçoar",
    "punçoadas": "punçoar",
    "punçoado": "punçoar",
    "punçoados": "punçoar",
    "punçoai": "punçoar",
    "punçoais": "punçoar",
    "punçoam": "punçoar",
    "punçoamo": "punçoar",
    "punçoamos": "punçoar",
    "punçoando": "punçoar",
    "punçoara": "punçoar",
    "punçoaram": "punçoar",
    "punçoaras": "punçoar",
    "punçoarde": "punçoar",
    "punçoardes": "punçoar",
    "punçoare": "punçoar",
    "punçoarei": "punçoar",
    "punçoareis": "punçoar",
    "punçoarem": "punçoar",
    "punçoaremos": "punçoar",
    "punçoares": "punçoar",
    "punçoaria": "punçoar",
    "punçoariam": "punçoar",
    "punçoarias": "punçoar",
    "punçoarmo": "punçoar",
    "punçoarmos": "punçoar",
    "punçoará": "punçoar",
    "punçoarás": "punçoar",
    "punçoarão": "punçoar",
    "punçoaríamos": "punçoar",
    "punçoaríeis": "punçoar",
    "punçoas": "punçoar",
    "punçoasse": "punçoar",
    "punçoassem": "punçoar",
    "punçoasses": "punçoar",
    "punçoaste": "punçoar",
    "punçoastes": "punçoar",
    "punçoava": "punçoar",
    "punçoavam": "punçoar",
    "punçoavas": "punçoar",
    "punçoe": "punçoar",
    "punçoei": "punçoar",
    "punçoeis": "punçoar",
    "punçoem": "punçoar",
    "punçoemo": "punçoar",
    "punçoemos": "punçoar",
    "punçoes": "punçoar",
    "punçoo": "punçoar",
    "punçoou": "punçoar",
    "punçou": "punçar",
    "punçoá": "punçoar",
    "punçoámo": "punçoar",
    "punçoámos": "punçoar",
    "punçoáramo": "punçoar",
    "punçoáramos": "punçoar",
    "punçoárei": "punçoar",
    "punçoáreis": "punçoar",
    "punçoásseis": "punçoar",
    "punçoássemos": "punçoar",
    "punçoávamo": "punçoar",
    "punçoávamos": "punçoar",
    "punçoávei": "punçoar",
    "punçoáveis": "punçoar",
    "punçá": "punçar",
    "punçámo": "punçar",
    "punçámos": "punçar",
    "punçáramo": "punçar",
    "punçáramos": "punçar",
    "punçárei": "punçar",
    "punçáreis": "punçar",
    "punçásseis": "punçar",
    "punçássemos": "punçar",
    "punçávamo": "punçar",
    "punçávamos": "punçar",
    "punçávei": "punçar",
    "punçáveis": "punçar",
    "punções": "punção",
    "puníamo": "punir",
    "puníamos": "punir",
    "punícea": "puníceo",
    "puníceas": "puníceo",
    "puníceos": "puníceo",
    "puníei": "punir",
    "puníeis": "punir",
    "puníramo": "punir",
    "puníramos": "punir",
    "punírei": "punir",
    "puníreis": "punir",
    "punísseis": "punir",
    "puníssemos": "punir",
    "puníveis": "punível",
    "puo": "puir",
    "pupas": "pupa",
    "pupila": "pupilo",
    "pupilada": "pupilar",
    "pupiladas": "pupilar",
    "pupilado": "pupilar",
    "pupilados": "pupilar",
    "pupilagens": "pupilagem",
    "pupilai": "pupilar",
    "pupilais": "pupilar",
    "pupilam": "pupilar",
    "pupilamo": "pupilar",
    "pupilamos": "pupilar",
    "pupilando": "pupilar",
    "pupilara": "pupilar",
    "pupilaram": "pupilar",
    "pupilaras": "pupilar",
    "pupilardes": "pupilar",
    "pupilarei": "pupilar",
    "pupilareis": "pupilar",
    "pupilarem": "pupilar",
    "pupilaremos": "pupilar",
    "pupilares": "pupilar",
    "pupilaria": "pupilar",
    "pupilariam": "pupilar",
    "pupilarias": "pupilar",
    "pupilaridades": "pupilaridade",
    "pupilarmo": "pupilar",
    "pupilarmos": "pupilar",
    "pupilará": "pupilar",
    "pupilarás": "pupilar",
    "pupilarão": "pupilar",
    "pupilaríamos": "pupilar",
    "pupilaríeis": "pupilar",
    "pupilas": "pupilo",
    "pupilasse": "pupilar",
    "pupilassem": "pupilar",
    "pupilasses": "pupilar",
    "pupilaste": "pupilar",
    "pupilastes": "pupilar",
    "pupilava": "pupilar",
    "pupilavam": "pupilar",
    "pupilavas": "pupilar",
    "pupile": "pupilar",
    "pupilei": "pupilar",
    "pupileis": "pupilar",
    "pupilem": "pupilar",
    "pupilemo": "pupilar",
    "pupilemos": "pupilar",
    "pupiles": "pupilar",
    "pupilo": "pupilar",
    "pupilométrica": "pupilométrico",
    "pupilométricas": "pupilométrico",
    "pupilométricos": "pupilométrico",
    "pupilos": "pupilo",
    "pupilou": "pupilar",
    "pupilámo": "pupilar",
    "pupilámos": "pupilar",
    "pupiláramo": "pupilar",
    "pupiláramos": "pupilar",
    "pupiláreis": "pupilar",
    "pupilásseis": "pupilar",
    "pupilássemos": "pupilar",
    "pupilávamo": "pupilar",
    "pupilávamos": "pupilar",
    "pupiláveis": "pupilar",
    "pupus": "pupu",
    "pupípara": "pupíparo",
    "pupíparas": "pupíparo",
    "pupíparos": "pupíparo",
    "pura": "puro",
    "puras": "puro",
    "purazinha": "puro",
    "purazinhas": "puro",
    "purazita": "puro",
    "purazitas": "puro",
    "pureias": "pureia",
    "purezas": "pureza",
    "purga": "purgar",
    "purgada": "purgar",
    "purgadas": "purgar",
    "purgado": "purgar",
    "purgados": "purgar",
    "purgai": "purgar",
    "purgais": "purgar",
    "purgam": "purgar",
    "purgamo": "purgar",
    "purgamos": "purgar",
    "purgando": "purgar",
    "purgantes": "purgante",
    "purgara": "purgar",
    "purgaram": "purgar",
    "purgaras": "purgar",
    "purgarde": "purgar",
    "purgardes": "purgar",
    "purgare": "purgar",
    "purgarei": "purgar",
    "purgareis": "purgar",
    "purgarem": "purgar",
    "purgaremos": "purgar",
    "purgares": "purgar",
    "purgaria": "purgar",
    "purgariam": "purgar",
    "purgarias": "purgar",
    "purgarmo": "purgar",
    "purgarmos": "purgar",
    "purgará": "purgar",
    "purgarás": "purgar",
    "purgarão": "purgar",
    "purgaríamos": "purgar",
    "purgaríeis": "purgar",
    "purgas": "purgar",
    "purgasse": "purgar",
    "purgassem": "purgar",
    "purgasses": "purgar",
    "purgaste": "purgar",
    "purgastes": "purgar",
    "purgativa": "purgativo",
    "purgativas": "purgativo",
    "purgativos": "purgativo",
    "purgatória": "purgatório",
    "purgatórias": "purgatório",
    "purgatórios": "purgatório",
    "purgava": "purgar",
    "purgavam": "purgar",
    "purgavas": "purgar",
    "purgações": "purgação",
    "purgo": "purgar",
    "purgou": "purgar",
    "purgue": "purgar",
    "purguei": "purgar",
    "purgueiras": "purgueira",
    "purgueis": "purgar",
    "purguem": "purgar",
    "purguemo": "purgar",
    "purguemos": "purgar",
    "purgues": "purgar",
    "purgá": "purgar",
    "purgámo": "purgar",
    "purgámos": "purgar",
    "purgáramo": "purgar",
    "purgáramos": "purgar",
    "purgárei": "purgar",
    "purgáreis": "purgar",
    "purgásseis": "purgar",
    "purgássemos": "purgar",
    "purgávamo": "purgar",
    "purgávamos": "purgar",
    "purgávei": "purgar",
    "purgáveis": "purgar",
    "puridades": "puridade",
    "purifica": "purificar",
    "purificada": "purificar",
    "purificadas": "purificar",
    "purificado": "purificar",
    "purificadora": "purificador",
    "purificadoras": "purificador",
    "purificadores": "purificador",
    "purificados": "purificar",
    "purificai": "purificar",
    "purificais": "purificar",
    "purificam": "purificar",
    "purificamo": "purificar",
    "purificamos": "purificar",
    "purificando": "purificar",
    "purificantes": "purificante",
    "purificara": "purificar",
    "purificaram": "purificar",
    "purificaras": "purificar",
    "purificarde": "purificar",
    "purificardes": "purificar",
    "purificare": "purificar",
    "purificarei": "purificar",
    "purificareis": "purificar",
    "purificarem": "purificar",
    "purificaremos": "purificar",
    "purificares": "purificar",
    "purificaria": "purificar",
    "purificariam": "purificar",
    "purificarias": "purificar",
    "purificarmo": "purificar",
    "purificarmos": "purificar",
    "purificará": "purificar",
    "purificarás": "purificar",
    "purificarão": "purificar",
    "purificaríamos": "purificar",
    "purificaríeis": "purificar",
    "purificas": "purificar",
    "purificasse": "purificar",
    "purificassem": "purificar",
    "purificasses": "purificar",
    "purificaste": "purificar",
    "purificastes": "purificar",
    "purificativa": "purificativo",
    "purificativas": "purificativo",
    "purificativos": "purificativo",
    "purificatória": "purificatório",
    "purificatórias": "purificatório",
    "purificatórios": "purificatório",
    "purificava": "purificar",
    "purificavam": "purificar",
    "purificavas": "purificar",
    "purificações": "purificação",
    "purifico": "purificar",
    "purificou": "purificar",
    "purificá": "purificar",
    "purificámo": "purificar",
    "purificámos": "purificar",
    "purificáramo": "purificar",
    "purificáramos": "purificar",
    "purificárei": "purificar",
    "purificáreis": "purificar",
    "purificásseis": "purificar",
    "purificássemos": "purificar",
    "purificávamo": "purificar",
    "purificávamos": "purificar",
    "purificávei": "purificar",
    "purificáveis": "purificar",
    "purifique": "purificar",
    "purifiquei": "purificar",
    "purifiqueis": "purificar",
    "purifiquem": "purificar",
    "purifiquemo": "purificar",
    "purifiquemos": "purificar",
    "purifiques": "purificar",
    "puriformes": "puriforme",
    "purinas": "purina",
    "purinha": "puro",
    "purinhas": "puro",
    "purinho": "puro",
    "purinhos": "puro",
    "purismos": "purismo",
    "puristas": "purista",
    "purita": "puro",
    "puritana": "puritano",
    "puritanas": "puritano",
    "puritanismos": "puritanismo",
    "puritanistas": "puritanista",
    "puritanos": "puritano",
    "puritas": "puro",
    "purito": "puro",
    "puritos": "puro",
    "puros": "puro",
    "purozinho": "puro",
    "purozinhos": "puro",
    "purozito": "puro",
    "purozitos": "puro",
    "purpura": "purpurar",
    "purpurada": "purpurar",
    "purpuradas": "purpurar",
    "purpurado": "purpurar",
    "purpurados": "purpurar",
    "purpurai": "purpurar",
    "purpurais": "purpurar",
    "purpuram": "purpurar",
    "purpuramo": "purpurar",
    "purpuramos": "purpurar",
    "purpurando": "purpurar",
    "purpurara": "purpurar",
    "purpuraram": "purpurar",
    "purpuraras": "purpurar",
    "purpurarde": "purpurar",
    "purpurardes": "purpurar",
    "purpurare": "purpurar",
    "purpurarei": "purpurar",
    "purpurareis": "purpurar",
    "purpurarem": "purpurar",
    "purpuraremos": "purpurar",
    "purpurares": "purpurar",
    "purpuraria": "purpurar",
    "purpurariam": "purpurar",
    "purpurarias": "purpurar",
    "purpurarmo": "purpurar",
    "purpurarmos": "purpurar",
    "purpurará": "purpurar",
    "purpurarás": "purpurar",
    "purpurarão": "purpurar",
    "purpuraríamos": "purpurar",
    "purpuraríeis": "purpurar",
    "purpuras": "purpurar",
    "purpurasse": "purpurar",
    "purpurassem": "purpurar",
    "purpurasses": "purpurar",
    "purpuraste": "purpurar",
    "purpurastes": "purpurar",
    "purpurava": "purpurar",
    "purpuravam": "purpurar",
    "purpuravas": "purpurar",
    "purpure": "purpurar",
    "purpureada": "purpurear",
    "purpureadas": "purpurear",
    "purpureado": "purpurear",
    "purpureados": "purpurear",
    "purpureai": "purpurear",
    "purpureais": "purpurear",
    "purpureamo": "purpurear",
    "purpureamos": "purpurear",
    "purpureando": "purpurear",
    "purpureara": "purpurear",
    "purpurearam": "purpurear",
    "purpurearas": "purpurear",
    "purpurearde": "purpurear",
    "purpureardes": "purpurear",
    "purpureare": "purpurear",
    "purpurearei": "purpurear",
    "purpureareis": "purpurear",
    "purpurearem": "purpurear",
    "purpurearemos": "purpurear",
    "purpureares": "purpurear",
    "purpurearia": "purpurear",
    "purpureariam": "purpurear",
    "purpurearias": "purpurear",
    "purpurearmo": "purpurear",
    "purpurearmos": "purpurear",
    "purpureará": "purpurear",
    "purpurearás": "purpurear",
    "purpurearão": "purpurear",
    "purpurearíamos": "purpurear",
    "purpurearíeis": "purpurear",
    "purpureasse": "purpurear",
    "purpureassem": "purpurear",
    "purpureasses": "purpurear",
    "purpureaste": "purpurear",
    "purpureastes": "purpurear",
    "purpureava": "purpurear",
    "purpureavam": "purpurear",
    "purpureavas": "purpurear",
    "purpureei": "purpurear",
    "purpureeis": "purpurear",
    "purpureemo": "purpurear",
    "purpureemos": "purpurear",
    "purpurei": "purpurar",
    "purpureia": "purpurear",
    "purpureiam": "purpurear",
    "purpureias": "purpurear",
    "purpureie": "purpurear",
    "purpureiem": "purpurear",
    "purpureies": "purpurear",
    "purpureio": "purpurear",
    "purpureis": "purpurar",
    "purpureja": "purpurejar",
    "purpurejada": "purpurejar",
    "purpurejadas": "purpurejar",
    "purpurejado": "purpurejar",
    "purpurejados": "purpurejar",
    "purpurejai": "purpurejar",
    "purpurejais": "purpurejar",
    "purpurejam": "purpurejar",
    "purpurejamo": "purpurejar",
    "purpurejamos": "purpurejar",
    "purpurejando": "purpurejar",
    "purpurejara": "purpurejar",
    "purpurejaram": "purpurejar",
    "purpurejaras": "purpurejar",
    "purpurejarde": "purpurejar",
    "purpurejardes": "purpurejar",
    "purpurejare": "purpurejar",
    "purpurejarei": "purpurejar",
    "purpurejareis": "purpurejar",
    "purpurejarem": "purpurejar",
    "purpurejaremos": "purpurejar",
    "purpurejares": "purpurejar",
    "purpurejaria": "purpurejar",
    "purpurejariam": "purpurejar",
    "purpurejarias": "purpurejar",
    "purpurejarmo": "purpurejar",
    "purpurejarmos": "purpurejar",
    "purpurejará": "purpurejar",
    "purpurejarás": "purpurejar",
    "purpurejarão": "purpurejar",
    "purpurejaríamos": "purpurejar",
    "purpurejaríeis": "purpurejar",
    "purpurejas": "purpurejar",
    "purpurejasse": "purpurejar",
    "purpurejassem": "purpurejar",
    "purpurejasses": "purpurejar",
    "purpurejaste": "purpurejar",
    "purpurejastes": "purpurejar",
    "purpurejava": "purpurejar",
    "purpurejavam": "purpurejar",
    "purpurejavas": "purpurejar",
    "purpureje": "purpurejar",
    "purpurejei": "purpurejar",
    "purpurejeis": "purpurejar",
    "purpurejem": "purpurejar",
    "purpurejemo": "purpurejar",
    "purpurejemos": "purpurejar",
    "purpurejes": "purpurejar",
    "purpurejo": "purpurejar",
    "purpurejou": "purpurejar",
    "purpurejá": "purpurejar",
    "purpurejámo": "purpurejar",
    "purpurejámos": "purpurejar",
    "purpurejáramo": "purpurejar",
    "purpurejáramos": "purpurejar",
    "purpurejárei": "purpurejar",
    "purpurejáreis": "purpurejar",
    "purpurejásseis": "purpurejar",
    "purpurejássemos": "purpurejar",
    "purpurejávamo": "purpurejar",
    "purpurejávamos": "purpurejar",
    "purpurejávei": "purpurejar",
    "purpurejáveis": "purpurejar",
    "purpurem": "purpurar",
    "purpuremo": "purpurar",
    "purpuremos": "purpurar",
    "purpureou": "purpurear",
    "purpures": "purpurar",
    "purpureá": "purpurear",
    "purpureámo": "purpurear",
    "purpureámos": "purpurear",
    "purpureáramo": "purpurear",
    "purpureáramos": "purpurear",
    "purpureárei": "purpurear",
    "purpureáreis": "purpurear",
    "purpureásseis": "purpurear",
    "purpureássemos": "purpurear",
    "purpureávamo": "purpurear",
    "purpureávamos": "purpurear",
    "purpureávei": "purpurear",
    "purpureáveis": "purpurear",
    "purpurina": "purpurino",
    "purpurinas": "purpurino",
    "purpurinos": "purpurino",
    "purpuriza": "purpurizar",
    "purpurizada": "purpurizar",
    "purpurizadas": "purpurizar",
    "purpurizado": "purpurizar",
    "purpurizados": "purpurizar",
    "purpurizai": "purpurizar",
    "purpurizais": "purpurizar",
    "purpurizam": "purpurizar",
    "purpurizamo": "purpurizar",
    "purpurizamos": "purpurizar",
    "purpurizando": "purpurizar",
    "purpurizara": "purpurizar",
    "purpurizaram": "purpurizar",
    "purpurizaras": "purpurizar",
    "purpurizarde": "purpurizar",
    "purpurizardes": "purpurizar",
    "purpurizare": "purpurizar",
    "purpurizarei": "purpurizar",
    "purpurizareis": "purpurizar",
    "purpurizarem": "purpurizar",
    "purpurizaremos": "purpurizar",
    "purpurizares": "purpurizar",
    "purpurizaria": "purpurizar",
    "purpurizariam": "purpurizar",
    "purpurizarias": "purpurizar",
    "purpurizarmo": "purpurizar",
    "purpurizarmos": "purpurizar",
    "purpurizará": "purpurizar",
    "purpurizarás": "purpurizar",
    "purpurizarão": "purpurizar",
    "purpurizaríamos": "purpurizar",
    "purpurizaríeis": "purpurizar",
    "purpurizas": "purpurizar",
    "purpurizasse": "purpurizar",
    "purpurizassem": "purpurizar",
    "purpurizasses": "purpurizar",
    "purpurizaste": "purpurizar",
    "purpurizastes": "purpurizar",
    "purpurizava": "purpurizar",
    "purpurizavam": "purpurizar",
    "purpurizavas": "purpurizar",
    "purpurize": "purpurizar",
    "purpurizei": "purpurizar",
    "purpurizeis": "purpurizar",
    "purpurizem": "purpurizar",
    "purpurizemo": "purpurizar",
    "purpurizemos": "purpurizar",
    "purpurizes": "purpurizar",
    "purpurizo": "purpurizar",
    "purpurizou": "purpurizar",
    "purpurizá": "purpurizar",
    "purpurizámo": "purpurizar",
    "purpurizámos": "purpurizar",
    "purpurizáramo": "purpurizar",
    "purpurizáramos": "purpurizar",
    "purpurizárei": "purpurizar",
    "purpurizáreis": "purpurizar",
    "purpurizásseis": "purpurizar",
    "purpurizássemos": "purpurizar",
    "purpurizávamo": "purpurizar",
    "purpurizávamos": "purpurizar",
    "purpurizávei": "purpurizar",
    "purpurizáveis": "purpurizar",
    "purpuro": "purpurar",
    "purpurou": "purpurar",
    "purpurá": "purpurar",
    "purpurámo": "purpurar",
    "purpurámos": "purpurar",
    "purpuráramo": "purpurar",
    "purpuráramos": "purpurar",
    "purpurárei": "purpurar",
    "purpuráreis": "purpurar",
    "purpurásseis": "purpurar",
    "purpurássemos": "purpurar",
    "purpurávamo": "purpurar",
    "purpurávamos": "purpurar",
    "purpurávei": "purpurar",
    "purpuráveis": "purpurar",
    "purpurífera": "purpurífero",
    "purpuríferas": "purpurífero",
    "purpuríferos": "purpurífero",
    "purpúrea": "purpúreo",
    "purpúreas": "purpúreo",
    "purpúreos": "purpúreo",
    "purulenta": "purulento",
    "purulentas": "purulento",
    "purulentos": "purulento",
    "purulências": "purulência",
    "pururucas": "pururuca",
    "purés": "puré",
    "puríssima": "puro",
    "puríssimas": "puro",
    "puríssimo": "puro",
    "puríssimos": "puro",
    "pus": "pôr",
    "pusemo": "pôr",
    "pusemos": "pôr",
    "puser": "pôr",
    "pusera": "pôr",
    "puseram": "pôr",
    "puseras": "pôr",
    "puserdes": "pôr",
    "puserem": "pôr",
    "puseres": "pôr",
    "pusermos": "pôr",
    "puses": "pus",
    "pusesse": "pôr",
    "pusessem": "pôr",
    "pusesses": "pôr",
    "puseste": "pôr",
    "pusestes": "pôr",
    "pusilanimidades": "pusilanimidade",
    "pusilânimes": "pusilânime",
    "pustulenta": "pustulento",
    "pustulentas": "pustulento",
    "pustulentos": "pustulento",
    "pustulosa": "pustuloso",
    "pustulosas": "pustuloso",
    "pustulosos": "pustuloso",
    "pusturações": "pusturação",
    "puséramo": "pôr",
    "puséramos": "pôr",
    "pusérei": "pôr",
    "puséreis": "pôr",
    "pusésseis": "pôr",
    "puséssemos": "pôr",
    "putas": "puta",
    "putativa": "putativo",
    "putativas": "putativo",
    "putativos": "putativo",
    "puteais": "puteal",
    "putos": "puto",
    "putrecentes": "putrecente",
    "putredinosa": "putredinoso",
    "putredinosas": "putredinoso",
    "putredinosos": "putredinoso",
    "putrefacientes": "putrefaciente",
    "putrefacta": "putrefacto",
    "putrefactas": "putrefacto",
    "putrefactiva": "putrefactivo",
    "putrefactivas": "putrefactivo",
    "putrefactivos": "putrefactivo",
    "putrefactos": "putrefacto",
    "putrefactória": "putrefactório",
    "putrefactórias": "putrefactório",
    "putrefactórios": "putrefactório",
    "putrefacções": "putrefacção",
    "putrefarei": "putrefazer",
    "putrefareis": "putrefazer",
    "putrefaremos": "putrefazer",
    "putrefaria": "putrefazer",
    "putrefariam": "putrefazer",
    "putrefarias": "putrefazer",
    "putrefará": "putrefazer",
    "putrefarás": "putrefazer",
    "putrefarão": "putrefazer",
    "putrefaríamos": "putrefazer",
    "putrefaríeis": "putrefazer",
    "putrefaz": "putrefazer",
    "putrefaze": "putrefazer",
    "putrefazei": "putrefazer",
    "putrefazeis": "putrefazer",
    "putrefazem": "putrefazer",
    "putrefazemo": "putrefazer",
    "putrefazemos": "putrefazer",
    "putrefazendo": "putrefazer",
    "putrefazerde": "putrefazer",
    "putrefazerdes": "putrefazer",
    "putrefazere": "putrefazer",
    "putrefazerem": "putrefazer",
    "putrefazeres": "putrefazer",
    "putrefazermo": "putrefazer",
    "putrefazermos": "putrefazer",
    "putrefazes": "putrefazer",
    "putrefazia": "putrefazer",
    "putrefaziam": "putrefazer",
    "putrefazias": "putrefazer",
    "putrefazê": "putrefazer",
    "putrefazíamo": "putrefazer",
    "putrefazíamos": "putrefazer",
    "putrefazíei": "putrefazer",
    "putrefazíeis": "putrefazer",
    "putrefaça": "putrefazer",
    "putrefaçais": "putrefazer",
    "putrefaçam": "putrefazer",
    "putrefaçamo": "putrefazer",
    "putrefaçamos": "putrefazer",
    "putrefaças": "putrefazer",
    "putrefaço": "putrefazer",
    "putrefeita": "putrefeito",
    "putrefeitas": "putrefeito",
    "putrefeito": "putrefazer",
    "putrefeitos": "putrefeito",
    "putrefez": "putrefazer",
    "putrefi": "putrefazer",
    "putrefiz": "putrefazer",
    "putrefizemo": "putrefazer",
    "putrefizemos": "putrefazer",
    "putrefizer": "putrefazer",
    "putrefizera": "putrefazer",
    "putrefizeram": "putrefazer",
    "putrefizeras": "putrefazer",
    "putrefizerdes": "putrefazer",
    "putrefizerem": "putrefazer",
    "putrefizeres": "putrefazer",
    "putrefizermos": "putrefazer",
    "putrefizesse": "putrefazer",
    "putrefizessem": "putrefazer",
    "putrefizesses": "putrefazer",
    "putrefizeste": "putrefazer",
    "putrefizestes": "putrefazer",
    "putrefizéramo": "putrefazer",
    "putrefizéramos": "putrefazer",
    "putrefizérei": "putrefazer",
    "putrefizéreis": "putrefazer",
    "putrefizésseis": "putrefazer",
    "putrefizéssemos": "putrefazer",
    "putrefá": "putrefazer",
    "putrefê": "putrefazer",
    "putrescibilidades": "putrescibilidade",
    "putrescências": "putrescência",
    "putrescíveis": "putrescível",
    "putrifica": "putrificar",
    "putrificada": "putrificar",
    "putrificadas": "putrificar",
    "putrificado": "putrificar",
    "putrificados": "putrificar",
    "putrificai": "putrificar",
    "putrificais": "putrificar",
    "putrificam": "putrificar",
    "putrificamo": "putrificar",
    "putrificamos": "putrificar",
    "putrificando": "putrificar",
    "putrificara": "putrificar",
    "putrificaram": "putrificar",
    "putrificaras": "putrificar",
    "putrificarde": "putrificar",
    "putrificardes": "putrificar",
    "putrificare": "putrificar",
    "putrificarei": "putrificar",
    "putrificareis": "putrificar",
    "putrificarem": "putrificar",
    "putrificaremos": "putrificar",
    "putrificares": "putrificar",
    "putrificaria": "putrificar",
    "putrificariam": "putrificar",
    "putrificarias": "putrificar",
    "putrificarmo": "putrificar",
    "putrificarmos": "putrificar",
    "putrificará": "putrificar",
    "putrificarás": "putrificar",
    "putrificarão": "putrificar",
    "putrificaríamos": "putrificar",
    "putrificaríeis": "putrificar",
    "putrificas": "putrificar",
    "putrificasse": "putrificar",
    "putrificassem": "putrificar",
    "putrificasses": "putrificar",
    "putrificaste": "putrificar",
    "putrificastes": "putrificar",
    "putrificava": "putrificar",
    "putrificavam": "putrificar",
    "putrificavas": "putrificar",
    "putrifico": "putrificar",
    "putrificou": "putrificar",
    "putrificá": "putrificar",
    "putrificámo": "putrificar",
    "putrificámos": "putrificar",
    "putrificáramo": "putrificar",
    "putrificáramos": "putrificar",
    "putrificárei": "putrificar",
    "putrificáreis": "putrificar",
    "putrificásseis": "putrificar",
    "putrificássemos": "putrificar",
    "putrificávamo": "putrificar",
    "putrificávamos": "putrificar",
    "putrificávei": "putrificar",
    "putrificáveis": "putrificar",
    "putrifique": "putrificar",
    "putrifiquei": "putrificar",
    "putrifiqueis": "putrificar",
    "putrifiquem": "putrificar",
    "putrifiquemo": "putrificar",
    "putrifiquemos": "putrificar",
    "putrifiques": "putrificar",
    "putrívora": "putrívoro",
    "putrívoras": "putrívoro",
    "putrívoros": "putrívoro",
    "puxa": "puxar",
    "puxada": "puxar",
    "puxadas": "puxar",
    "puxadeiras": "puxadeira",
    "puxadelas": "puxadela",
    "puxadinha": "puxado",
    "puxadinhas": "puxado",
    "puxadinho": "puxado",
    "puxadinhos": "puxado",
    "puxadita": "puxado",
    "puxaditas": "puxado",
    "puxadito": "puxado",
    "puxaditos": "puxado",
    "puxado": "puxar",
    "puxadoiras": "puxadoira",
    "puxadores": "puxador",
    "puxados": "puxar",
    "puxadouras": "puxadoura",
    "puxadíssima": "puxado",
    "puxadíssimas": "puxado",
    "puxadíssimo": "puxado",
    "puxadíssimos": "puxado",
    "puxai": "puxar",
    "puxais": "puxar",
    "puxam": "puxar",
    "puxamo": "puxar",
    "puxamos": "puxar",
    "puxando": "puxar",
    "puxantes": "puxante",
    "puxara": "puxar",
    "puxaram": "puxar",
    "puxaras": "puxar",
    "puxarde": "puxar",
    "puxardes": "puxar",
    "puxare": "puxar",
    "puxarei": "puxar",
    "puxareis": "puxar",
    "puxarem": "puxar",
    "puxaremos": "puxar",
    "puxares": "puxar",
    "puxaria": "puxar",
    "puxariam": "puxar",
    "puxarias": "puxar",
    "puxarmo": "puxar",
    "puxarmos": "puxar",
    "puxará": "puxar",
    "puxarás": "puxar",
    "puxarão": "puxar",
    "puxaríamos": "puxar",
    "puxaríeis": "puxar",
    "puxas": "puxar",
    "puxasse": "puxar",
    "puxassem": "puxar",
    "puxasses": "puxar",
    "puxaste": "puxar",
    "puxastes": "puxar",
    "puxativa": "puxativo",
    "puxativas": "puxativo",
    "puxativos": "puxativo",
    "puxava": "puxar",
    "puxavam": "puxar",
    "puxavantes": "puxavante",
    "puxavas": "puxar",
    "puxe": "puxar",
    "puxei": "puxar",
    "puxeis": "puxar",
    "puxem": "puxar",
    "puxemo": "puxar",
    "puxemos": "puxar",
    "puxes": "puxar",
    "puxo": "puxar",
    "puxos": "puxo",
    "puxou": "puxar",
    "puxá": "puxar",
    "puxámo": "puxar",
    "puxámos": "puxar",
    "puxáramo": "puxar",
    "puxáramos": "puxar",
    "puxárei": "puxar",
    "puxáreis": "puxar",
    "puxásseis": "puxar",
    "puxássemos": "puxar",
    "puxávamo": "puxar",
    "puxávamos": "puxar",
    "puxávei": "puxar",
    "puxáveis": "puxar",
    "puxãozinho": "puxão",
    "puxãozito": "puxão",
    "puxões": "puxão",
    "puxõezinhos": "puxão",
    "puxõezitos": "puxão",
    "puzzles": "puzzle",
    "puérperas": "puérpera",
    "puí": "puir",
    "puía": "puir",
    "puíam": "puir",
    "puíamo": "puir",
    "puíamos": "puir",
    "puías": "puir",
    "puída": "puir",
    "puídas": "puir",
    "puído": "puir",
    "puídos": "puir",
    "puíei": "puir",
    "puíeis": "puir",
    "puímo": "puir",
    "puímos": "puir",
    "puíra": "puir",
    "puíram": "puir",
    "puíramo": "puir",
    "puíramos": "puir",
    "puíras": "puir",
    "puíre": "puir",
    "puírei": "puir",
    "puíreis": "puir",
    "puírem": "puir",
    "puíres": "puir",
    "puís": "puir",
    "puísse": "puir",
    "puísseis": "puir",
    "puíssem": "puir",
    "puíssemos": "puir",
    "puísses": "puir",
    "puíste": "puir",
    "puístes": "puir",
    "puítas": "puíta",
    "pábulos": "pábulo",
    "páginas": "página",
    "pálamos": "pálamo",
    "pálida": "pálido",
    "pálidas": "pálido",
    "pálidos": "pálido",
    "pálios": "pálio",
    "pális": "páli",
    "pálpebras": "pálpebra",
    "pápulas": "pápula",
    "pára": "parar",
    "páralos": "páralo",
    "páramos": "páramo",
    "páras": "pára",
    "páreas": "párea",
    "páreos": "páreo",
    "páreses": "párese",
    "párias": "pária",
    "párocos": "pároco",
    "pártenons": "pártenon",
    "párvula": "párvulo",
    "párvulas": "párvulo",
    "párvulos": "párvulo",
    "pás": "pá",
    "páscoas": "páscoa",
    "pássaras": "pássara",
    "pássaros": "pássaro",
    "páteras": "pátera",
    "pática": "pático",
    "páticas": "pático",
    "páticos": "pático",
    "pátinas": "pátina",
    "pátios": "pátio",
    "pátis": "páti",
    "pátria": "pátrio",
    "pátrias": "pátrio",
    "pátrios": "pátrio",
    "pátula": "pátulo",
    "pátulas": "pátulo",
    "pátulos": "pátulo",
    "pávida": "pávido",
    "pávidas": "pávido",
    "pávidos": "pávido",
    "pâmpalos": "pâmpalo",
    "pâmpanos": "pâmpano",
    "pândega": "pândego",
    "pândegas": "pândego",
    "pândegos": "pândego",
    "pânditas": "pândita",
    "pânicos": "pânico",
    "pânrias": "pânria",
    "pântanos": "pântano",
    "pântans": "pântan",
    "pães": "pão",
    "pãezinhos": "pão",
    "pãezitos": "pão",
    "pãozeira": "pãozeiro",
    "pãozeiras": "pãozeiro",
    "pãozeiros": "pãozeiro",
    "pãozinho": "pão",
    "pãozito": "pão",
    "pãs": "pã",
    "pécoras": "pécora",
    "péctica": "péctico",
    "pécticas": "péctico",
    "pécticos": "péctico",
    "pédites": "pédite",
    "pégasos": "pégaso",
    "pélagos": "pélago",
    "pélas": "péla",
    "pélvica": "pélvico",
    "pélvicas": "pélvico",
    "pélvicos": "pélvico",
    "pénica": "pénico",
    "pénicas": "pénico",
    "pénicos": "pénico",
    "pénula": "pénulo",
    "pénulas": "pénulo",
    "pénulos": "pénulo",
    "péons": "péon",
    "péptica": "péptico",
    "pépticas": "péptico",
    "pépticos": "péptico",
    "péptidios": "péptidio",
    "péras": "péra",
    "pércidas": "pércida",
    "pérfida": "pérfido",
    "pérfidas": "pérfido",
    "pérfidos": "pérfido",
    "pérgulas": "pérgula",
    "périplos": "périplo",
    "pérmicos": "pérmico",
    "pérolas": "pérola",
    "pérsea": "pérseo",
    "pérseas": "pérseo",
    "pérseos": "pérseo",
    "pérsia": "pérsio",
    "pérsias": "pérsio",
    "pérsica": "pérsico",
    "pérsicas": "pérsico",
    "pérsicos": "pérsico",
    "pérsios": "pérsio",
    "pérticas": "pértica",
    "pértigas": "pértiga",
    "pérulas": "pérula",
    "pérvia": "pérvio",
    "pérvias": "pérvio",
    "pérvios": "pérvio",
    "pés": "pé",
    "péssima": "mau",
    "péssimas": "mau",
    "péssimo": "mau",
    "péssimos": "mau",
    "pétalas": "pétala",
    "pétrea": "pétreo",
    "pétreas": "pétreo",
    "pétreos": "pétreo",
    "pêlos": "pêlo",
    "pêndulas": "pêndula",
    "pêndulos": "pêndulo",
    "pênseis": "pênsil",
    "pêntodos": "pêntodo",
    "pêras": "pêra",
    "pêros": "pêro",
    "pês": "pê",
    "pêsames": "pêsame",
    "pêses": "pês",
    "pêssegos": "pêssego",
    "pícara": "pícaro",
    "pícaras": "pícaro",
    "pícaros": "pícaro",
    "pícea": "píceo",
    "píceas": "píceo",
    "píceos": "píceo",
    "pícnica": "pícnico",
    "pícnicas": "pícnico",
    "pícnicos": "pícnico",
    "pícrica": "pícrico",
    "pícricas": "pícrico",
    "pícricos": "pícrico",
    "pífanos": "pífano",
    "pífaros": "pífaro",
    "pífia": "pífio",
    "pífias": "pífio",
    "pífios": "pífio",
    "pílulas": "pílula",
    "píncaros": "píncaro",
    "pínea": "píneo",
    "píneas": "píneo",
    "píneos": "píneo",
    "pínulas": "pínula",
    "pípridas": "píprida",
    "pírales": "pírale",
    "pírexes": "pírex",
    "pírexs": "pírex",
    "pírica": "pírico",
    "píricas": "pírico",
    "píricos": "pírico",
    "pírrica": "pírrico",
    "pírricas": "pírrico",
    "pírricos": "pírrico",
    "pírtigas": "pírtiga",
    "pírtigos": "pírtigo",
    "pírulas": "pírula",
    "píscea": "písceo",
    "písceas": "písceo",
    "písceos": "písceo",
    "píseos": "píseo",
    "pítias": "pítia",
    "pítica": "pítico",
    "píticas": "pítico",
    "píticos": "pítico",
    "píxides": "píxide",
    "pódios": "pódio",
    "pódiuns": "pódium",
    "pói": "poer",
    "póis": "poer",
    "pólas": "póla",
    "pólderes": "pólder",
    "pólece": "pólex",
    "póleces": "pólex",
    "pólenes": "pólen",
    "pólens": "pólen",
    "pólexes": "pólex",
    "pólices": "pólice",
    "pólipos": "pólipo",
    "pólos": "pólo",
    "pólvoras": "pólvora",
    "pómices": "pómice",
    "pómulos": "pómulo",
    "póneis": "pónei",
    "póplites": "póplite",
    "póqueres": "póquer",
    "pórfidos": "pórfido",
    "pórfiros": "pórfiro",
    "pórticos": "pórtico",
    "pós": "pó",
    "póstera": "póstero",
    "pósteras": "póstero",
    "pósteres": "póster",
    "pósteros": "póstero",
    "póstuma": "póstumo",
    "póstumas": "póstumo",
    "póstumos": "póstumo",
    "póvoas": "póvoa",
    "pô": "pôr",
    "pôde": "poder",
    "pôlas": "pôla",
    "pôlos": "pôlo",
    "pôntica": "pôntico",
    "pônticas": "pôntico",
    "pônticos": "pôntico",
    "pôs": "pôr",
    "põe": "pôr",
    "põem": "pôr",
    "pões": "pôr",
    "púberes": "púbere",
    "púbica": "púbico",
    "púbicas": "púbico",
    "púbicos": "púbico",
    "pública": "público",
    "públicas": "público",
    "públicos": "público",
    "púcaras": "púcara",
    "púcaros": "púcaro",
    "púdica": "púdico",
    "púdicas": "púdico",
    "púdicos": "púdico",
    "púgis": "púgil",
    "púlpitos": "púlpito",
    "púnhamo": "pôr",
    "púnhamos": "pôr",
    "púnhei": "pôr",
    "púnheis": "pôr",
    "púnica": "púnico",
    "púnicas": "púnico",
    "púnicos": "púnico",
    "púrpuras": "púrpura",
    "púrria": "púrrio",
    "púrrias": "púrrio",
    "púrrios": "púrrio",
    "pústulas": "pústula",
    "pústuras": "pústura",
    "pútegas": "pútega",
    "pútrida": "pútrido",
    "pútridas": "pútrido",
    "pútridos": "pútrido",
    "qq": "q",
    "quacres": "quacre",
    "quacrismos": "quacrismo",
    "quacristas": "quacrista",
    "quadernada": "quadernado",
    "quadernadas": "quadernado",
    "quadernados": "quadernado",
    "quadernais": "quadernal",
    "quadernas": "quaderna",
    "quadra": "quadrar",
    "quadrada": "quadrar",
    "quadradas": "quadrar",
    "quadradazinha": "quadrado",
    "quadradazinhas": "quadrado",
    "quadradazita": "quadrado",
    "quadradazitas": "quadrado",
    "quadradinha": "quadrado",
    "quadradinhas": "quadrado",
    "quadradinho": "quadrado",
    "quadradinhos": "quadrado",
    "quadradita": "quadrado",
    "quadraditas": "quadrado",
    "quadradito": "quadrado",
    "quadraditos": "quadrado",
    "quadrado": "quadrar",
    "quadradora": "quadrador",
    "quadradoras": "quadrador",
    "quadradores": "quadrador",
    "quadrados": "quadrar",
    "quadradozinho": "quadrado",
    "quadradozinhos": "quadrado",
    "quadradozito": "quadrado",
    "quadradozitos": "quadrado",
    "quadraduras": "quadradura",
    "quadradíssima": "quadrado",
    "quadradíssimas": "quadrado",
    "quadradíssimo": "quadrado",
    "quadradíssimos": "quadrado",
    "quadragenária": "quadragenário",
    "quadragenárias": "quadragenário",
    "quadragenários": "quadragenário",
    "quadragesimais": "quadragesimal",
    "quadragésima": "quadragésimo",
    "quadragésimas": "quadragésimo",
    "quadragésimos": "quadragésimo",
    "quadrai": "quadrar",
    "quadrais": "quadrar",
    "quadram": "quadrar",
    "quadramo": "quadrar",
    "quadramos": "quadrar",
    "quadrando": "quadrar",
    "quadrangulada": "quadrangulado",
    "quadranguladas": "quadrangulado",
    "quadrangulados": "quadrangulado",
    "quadrangulares": "quadrangular",
    "quadrangulações": "quadrangulação",
    "quadrantes": "quadrante",
    "quadrara": "quadrar",
    "quadraram": "quadrar",
    "quadraras": "quadrar",
    "quadrarde": "quadrar",
    "quadrardes": "quadrar",
    "quadrare": "quadrar",
    "quadrarei": "quadrar",
    "quadrareis": "quadrar",
    "quadrarem": "quadrar",
    "quadraremos": "quadrar",
    "quadrares": "quadrar",
    "quadraria": "quadrar",
    "quadrariam": "quadrar",
    "quadrarias": "quadrar",
    "quadrarmo": "quadrar",
    "quadrarmos": "quadrar",
    "quadrará": "quadrar",
    "quadrarás": "quadrar",
    "quadrarão": "quadrar",
    "quadraríamos": "quadrar",
    "quadraríeis": "quadrar",
    "quadras": "quadrar",
    "quadrasse": "quadrar",
    "quadrassem": "quadrar",
    "quadrasses": "quadrar",
    "quadraste": "quadrar",
    "quadrastes": "quadrar",
    "quadratins": "quadratim",
    "quadraturas": "quadratura",
    "quadraturistas": "quadraturista",
    "quadrava": "quadrar",
    "quadravam": "quadrar",
    "quadravas": "quadrar",
    "quadraçais": "quadraçal",
    "quadre": "quadrar",
    "quadrei": "quadrar",
    "quadreis": "quadrar",
    "quadrelas": "quadrela",
    "quadrelos": "quadrelo",
    "quadrem": "quadrar",
    "quadremo": "quadrar",
    "quadremos": "quadrar",
    "quadres": "quadrar",
    "quadriacelerações": "quadriaceleração",
    "quadrialada": "quadrialado",
    "quadrialadas": "quadrialado",
    "quadrialados": "quadrialado",
    "quadricapsulares": "quadricapsular",
    "quadricentenária": "quadricentenário",
    "quadricentenárias": "quadricentenário",
    "quadricentenários": "quadricentenário",
    "quadricicla": "quadriciclo",
    "quadriciclas": "quadriciclo",
    "quadriciclos": "quadriciclo",
    "quadricolores": "quadricolor",
    "quadricromias": "quadricromia",
    "quadricrómica": "quadricrómico",
    "quadricrómicas": "quadricrómico",
    "quadricrómicos": "quadricrómico",
    "quadricula": "quadricular",
    "quadriculada": "quadricular",
    "quadriculadas": "quadricular",
    "quadriculado": "quadricular",
    "quadriculados": "quadricular",
    "quadriculai": "quadricular",
    "quadriculais": "quadricular",
    "quadriculam": "quadricular",
    "quadriculamo": "quadricular",
    "quadriculamos": "quadricular",
    "quadriculando": "quadricular",
    "quadriculara": "quadricular",
    "quadricularam": "quadricular",
    "quadricularas": "quadricular",
    "quadricularde": "quadricular",
    "quadriculardes": "quadricular",
    "quadriculare": "quadricular",
    "quadricularei": "quadricular",
    "quadriculareis": "quadricular",
    "quadricularem": "quadricular",
    "quadricularemos": "quadricular",
    "quadriculares": "quadricular",
    "quadricularia": "quadricular",
    "quadriculariam": "quadricular",
    "quadricularias": "quadricular",
    "quadricularmo": "quadricular",
    "quadricularmos": "quadricular",
    "quadriculará": "quadricular",
    "quadricularás": "quadricular",
    "quadricularão": "quadricular",
    "quadricularíamos": "quadricular",
    "quadricularíeis": "quadricular",
    "quadriculas": "quadricular",
    "quadriculasse": "quadricular",
    "quadriculassem": "quadricular",
    "quadriculasses": "quadricular",
    "quadriculaste": "quadricular",
    "quadriculastes": "quadricular",
    "quadriculava": "quadricular",
    "quadriculavam": "quadricular",
    "quadriculavas": "quadricular",
    "quadricule": "quadricular",
    "quadriculei": "quadricular",
    "quadriculeis": "quadricular",
    "quadriculem": "quadricular",
    "quadriculemo": "quadricular",
    "quadriculemos": "quadricular",
    "quadricules": "quadricular",
    "quadriculo": "quadricular",
    "quadriculou": "quadricular",
    "quadriculá": "quadricular",
    "quadriculámo": "quadricular",
    "quadriculámos": "quadricular",
    "quadriculáramo": "quadricular",
    "quadriculáramos": "quadricular",
    "quadriculárei": "quadricular",
    "quadriculáreis": "quadricular",
    "quadriculásseis": "quadricular",
    "quadriculássemos": "quadricular",
    "quadriculávamo": "quadricular",
    "quadriculávamos": "quadricular",
    "quadriculávei": "quadricular",
    "quadriculáveis": "quadricular",
    "quadricípites": "quadricípite",
    "quadricórnea": "quadricórneo",
    "quadricórneas": "quadricórneo",
    "quadricórneos": "quadricórneo",
    "quadricúspides": "quadricúspide",
    "quadridentada": "quadridentado",
    "quadridentadas": "quadridentado",
    "quadridentados": "quadridentado",
    "quadridigitada": "quadridigitado",
    "quadridigitadas": "quadridigitado",
    "quadridigitados": "quadridigitado",
    "quadrienais": "quadrienal",
    "quadrifendida": "quadrifendido",
    "quadrifendidas": "quadrifendido",
    "quadrifendidos": "quadrifendido",
    "quadriflórea": "quadriflóreo",
    "quadriflóreas": "quadriflóreo",
    "quadriflóreos": "quadriflóreo",
    "quadrifoliada": "quadrifoliado",
    "quadrifoliadas": "quadrifoliado",
    "quadrifoliados": "quadrifoliado",
    "quadriformes": "quadriforme",
    "quadrifrontes": "quadrifronte",
    "quadrifurcada": "quadrifurcado",
    "quadrifurcadas": "quadrifurcado",
    "quadrifurcados": "quadrifurcado",
    "quadrifólia": "quadrifólio",
    "quadrifólias": "quadrifólio",
    "quadrifólios": "quadrifólio",
    "quadrigas": "quadriga",
    "quadrigentenária": "quadrigentenário",
    "quadrigentenárias": "quadrigentenário",
    "quadrigentenários": "quadrigentenário",
    "quadrigentésima": "quadrigentésimo",
    "quadrigentésimas": "quadrigentésimo",
    "quadrigentésimos": "quadrigentésimo",
    "quadrigária": "quadrigário",
    "quadrigárias": "quadrigário",
    "quadrigários": "quadrigário",
    "quadrigémea": "quadrigémeo",
    "quadrigémeas": "quadrigémeo",
    "quadrigémeos": "quadrigémeo",
    "quadrigémina": "quadrigémino",
    "quadrigéminas": "quadrigémino",
    "quadrigéminos": "quadrigémino",
    "quadrigúmea": "quadrigúmeo",
    "quadrigúmeas": "quadrigúmeo",
    "quadrigúmeos": "quadrigúmeo",
    "quadrilaterais": "quadrilateral",
    "quadrilhados": "quadrilhado",
    "quadrilhas": "quadrilha",
    "quadrilheira": "quadrilheiro",
    "quadrilheiras": "quadrilheiro",
    "quadrilheiros": "quadrilheiro",
    "quadrilionésima": "quadrilionésimo",
    "quadrilionésimas": "quadrilionésimo",
    "quadrilionésimos": "quadrilionésimo",
    "quadrilobulada": "quadrilobulado",
    "quadrilobuladas": "quadrilobulado",
    "quadrilobulados": "quadrilobulado",
    "quadriloculada": "quadriloculado",
    "quadriloculadas": "quadriloculado",
    "quadriloculados": "quadriloculado",
    "quadriloculares": "quadrilocular",
    "quadrilonga": "quadrilongo",
    "quadrilongas": "quadrilongo",
    "quadrilongos": "quadrilongo",
    "quadrilunulada": "quadrilunulado",
    "quadrilunuladas": "quadrilunulado",
    "quadrilunulados": "quadrilunulado",
    "quadriláteros": "quadrilátero",
    "quadrimaculada": "quadrimaculado",
    "quadrimaculadas": "quadrimaculado",
    "quadrimaculados": "quadrimaculado",
    "quadrimembres": "quadrimembre",
    "quadrimenta": "quadrimentum",
    "quadrimentos": "quadrimento",
    "quadrimestrais": "quadrimestral",
    "quadrimestres": "quadrimestre",
    "quadrimosqueada": "quadrimosqueado",
    "quadrimosqueadas": "quadrimosqueado",
    "quadrimosqueados": "quadrimosqueado",
    "quadrimotora": "quadrimotor",
    "quadrimotoras": "quadrimotor",
    "quadrimotores": "quadrimotor",
    "quadringentenários": "quadringentenário",
    "quadrinha": "quadra",
    "quadrinhas": "quadra",
    "quadrinho": "quadro",
    "quadrinhos": "quadro",
    "quadrinómios": "quadrinómio",
    "quadripartida": "quadripartido",
    "quadripartidas": "quadripartido",
    "quadripartidos": "quadripartido",
    "quadripenada": "quadripenado",
    "quadripenadas": "quadripenado",
    "quadripenados": "quadripenado",
    "quadripenes": "quadripene",
    "quadriplica": "quadriplicar",
    "quadriplicada": "quadriplicar",
    "quadriplicadas": "quadriplicar",
    "quadriplicado": "quadriplicar",
    "quadriplicados": "quadriplicar",
    "quadriplicai": "quadriplicar",
    "quadriplicais": "quadriplicar",
    "quadriplicam": "quadriplicar",
    "quadriplicamo": "quadriplicar",
    "quadriplicamos": "quadriplicar",
    "quadriplicando": "quadriplicar",
    "quadriplicara": "quadriplicar",
    "quadriplicaram": "quadriplicar",
    "quadriplicaras": "quadriplicar",
    "quadriplicarde": "quadriplicar",
    "quadriplicardes": "quadriplicar",
    "quadriplicare": "quadriplicar",
    "quadriplicarei": "quadriplicar",
    "quadriplicareis": "quadriplicar",
    "quadriplicarem": "quadriplicar",
    "quadriplicaremos": "quadriplicar",
    "quadriplicares": "quadriplicar",
    "quadriplicaria": "quadriplicar",
    "quadriplicariam": "quadriplicar",
    "quadriplicarias": "quadriplicar",
    "quadriplicarmo": "quadriplicar",
    "quadriplicarmos": "quadriplicar",
    "quadriplicará": "quadriplicar",
    "quadriplicarás": "quadriplicar",
    "quadriplicarão": "quadriplicar",
    "quadriplicaríamos": "quadriplicar",
    "quadriplicaríeis": "quadriplicar",
    "quadriplicas": "quadriplicar",
    "quadriplicasse": "quadriplicar",
    "quadriplicassem": "quadriplicar",
    "quadriplicasses": "quadriplicar",
    "quadriplicaste": "quadriplicar",
    "quadriplicastes": "quadriplicar",
    "quadriplicava": "quadriplicar",
    "quadriplicavam": "quadriplicar",
    "quadriplicavas": "quadriplicar",
    "quadriplicações": "quadriplicação",
    "quadriplico": "quadriplicar",
    "quadriplicou": "quadriplicar",
    "quadriplicá": "quadriplicar",
    "quadriplicámo": "quadriplicar",
    "quadriplicámos": "quadriplicar",
    "quadriplicáramo": "quadriplicar",
    "quadriplicáramos": "quadriplicar",
    "quadriplicárei": "quadriplicar",
    "quadriplicáreis": "quadriplicar",
    "quadriplicásseis": "quadriplicar",
    "quadriplicássemos": "quadriplicar",
    "quadriplicávamo": "quadriplicar",
    "quadriplicávamos": "quadriplicar",
    "quadriplicávei": "quadriplicar",
    "quadriplicáveis": "quadriplicar",
    "quadriplique": "quadriplicar",
    "quadripliquei": "quadriplicar",
    "quadripliqueis": "quadriplicar",
    "quadripliquem": "quadriplicar",
    "quadripliquemo": "quadriplicar",
    "quadripliquemos": "quadriplicar",
    "quadripliques": "quadriplicar",
    "quadripolos": "quadripolo",
    "quadriposições": "quadriposição",
    "quadripotenciais": "quadripotencial",
    "quadripétala": "quadripétalo",
    "quadripétalas": "quadripétalo",
    "quadripétalos": "quadripétalo",
    "quadrirremes": "quadrirreme",
    "quadris": "quadril",
    "quadrisseculares": "quadrissecular",
    "quadrissilábica": "quadrissilábico",
    "quadrissilábicas": "quadrissilábico",
    "quadrissilábicos": "quadrissilábico",
    "quadrissílaba": "quadrissílabo",
    "quadrissílabas": "quadrissílabo",
    "quadrissílabos": "quadrissílabo",
    "quadrita": "quadra",
    "quadritas": "quadra",
    "quadrito": "quadro",
    "quadritos": "quadro",
    "quadrivalentes": "quadrivalente",
    "quadrivalves": "quadrivalve",
    "quadrivalvulada": "quadrivalvulado",
    "quadrivalvuladas": "quadrivalvulado",
    "quadrivalvulados": "quadrivalvulado",
    "quadrivalvulares": "quadrivalvular",
    "quadrivectores": "quadrivector",
    "quadriângulos": "quadriângulo",
    "quadriénios": "quadriénio",
    "quadro": "quadrar",
    "quadros": "quadro",
    "quadrou": "quadrar",
    "quadrozinho": "quadro",
    "quadrozinhos": "quadro",
    "quadrozito": "quadro",
    "quadrozitos": "quadro",
    "quadrunviratos": "quadrunvirato",
    "quadrupeda": "quadrupedar",
    "quadrupedada": "quadrupedar",
    "quadrupedadas": "quadrupedar",
    "quadrupedado": "quadrupedar",
    "quadrupedados": "quadrupedar",
    "quadrupedai": "quadrupedar",
    "quadrupedais": "quadrupedar",
    "quadrupedam": "quadrupedar",
    "quadrupedamo": "quadrupedar",
    "quadrupedamos": "quadrupedar",
    "quadrupedando": "quadrupedar",
    "quadrupedantes": "quadrupedante",
    "quadrupedara": "quadrupedar",
    "quadrupedaram": "quadrupedar",
    "quadrupedaras": "quadrupedar",
    "quadrupedardes": "quadrupedar",
    "quadrupedarei": "quadrupedar",
    "quadrupedareis": "quadrupedar",
    "quadrupedarem": "quadrupedar",
    "quadrupedaremos": "quadrupedar",
    "quadrupedares": "quadrupedar",
    "quadrupedaria": "quadrupedar",
    "quadrupedariam": "quadrupedar",
    "quadrupedarias": "quadrupedar",
    "quadrupedarmo": "quadrupedar",
    "quadrupedarmos": "quadrupedar",
    "quadrupedará": "quadrupedar",
    "quadrupedarás": "quadrupedar",
    "quadrupedarão": "quadrupedar",
    "quadrupedaríamos": "quadrupedar",
    "quadrupedaríeis": "quadrupedar",
    "quadrupedas": "quadrupedar",
    "quadrupedasse": "quadrupedar",
    "quadrupedassem": "quadrupedar",
    "quadrupedasses": "quadrupedar",
    "quadrupedaste": "quadrupedar",
    "quadrupedastes": "quadrupedar",
    "quadrupedava": "quadrupedar",
    "quadrupedavam": "quadrupedar",
    "quadrupedavas": "quadrupedar",
    "quadrupede": "quadrupedar",
    "quadrupedei": "quadrupedar",
    "quadrupedeis": "quadrupedar",
    "quadrupedem": "quadrupedar",
    "quadrupedemo": "quadrupedar",
    "quadrupedemos": "quadrupedar",
    "quadrupedes": "quadrupedar",
    "quadrupedo": "quadrupedar",
    "quadrupedou": "quadrupedar",
    "quadrupedámo": "quadrupedar",
    "quadrupedámos": "quadrupedar",
    "quadrupedáramo": "quadrupedar",
    "quadrupedáramos": "quadrupedar",
    "quadrupedáreis": "quadrupedar",
    "quadrupedásseis": "quadrupedar",
    "quadrupedássemos": "quadrupedar",
    "quadrupedávamo": "quadrupedar",
    "quadrupedávamos": "quadrupedar",
    "quadrupedáveis": "quadrupedar",
    "quadrupla": "quadruplar",
    "quadruplada": "quadruplar",
    "quadrupladas": "quadruplar",
    "quadruplado": "quadruplar",
    "quadruplados": "quadruplar",
    "quadruplai": "quadruplar",
    "quadruplais": "quadruplar",
    "quadruplam": "quadruplar",
    "quadruplamo": "quadruplar",
    "quadruplamos": "quadruplar",
    "quadruplando": "quadruplar",
    "quadruplara": "quadruplar",
    "quadruplaram": "quadruplar",
    "quadruplaras": "quadruplar",
    "quadruplarde": "quadruplar",
    "quadruplardes": "quadruplar",
    "quadruplare": "quadruplar",
    "quadruplarei": "quadruplar",
    "quadruplareis": "quadruplar",
    "quadruplarem": "quadruplar",
    "quadruplaremos": "quadruplar",
    "quadruplares": "quadruplar",
    "quadruplaria": "quadruplar",
    "quadruplariam": "quadruplar",
    "quadruplarias": "quadruplar",
    "quadruplarmo": "quadruplar",
    "quadruplarmos": "quadruplar",
    "quadruplará": "quadruplar",
    "quadruplarás": "quadruplar",
    "quadruplarão": "quadruplar",
    "quadruplaríamos": "quadruplar",
    "quadruplaríeis": "quadruplar",
    "quadruplas": "quadruplar",
    "quadruplasse": "quadruplar",
    "quadruplassem": "quadruplar",
    "quadruplasses": "quadruplar",
    "quadruplaste": "quadruplar",
    "quadruplastes": "quadruplar",
    "quadruplava": "quadruplar",
    "quadruplavam": "quadruplar",
    "quadruplavas": "quadruplar",
    "quadruple": "quadruplar",
    "quadruplei": "quadruplar",
    "quadrupleis": "quadruplar",
    "quadruplem": "quadruplar",
    "quadruplemo": "quadruplar",
    "quadruplemos": "quadruplar",
    "quadruples": "quadruplar",
    "quadrupletos": "quadrupleto",
    "quadruplica": "quadruplicar",
    "quadruplicada": "quadruplicar",
    "quadruplicadas": "quadruplicar",
    "quadruplicado": "quadruplicar",
    "quadruplicados": "quadruplicar",
    "quadruplicai": "quadruplicar",
    "quadruplicais": "quadruplicar",
    "quadruplicam": "quadruplicar",
    "quadruplicamo": "quadruplicar",
    "quadruplicamos": "quadruplicar",
    "quadruplicando": "quadruplicar",
    "quadruplicara": "quadruplicar",
    "quadruplicaram": "quadruplicar",
    "quadruplicaras": "quadruplicar",
    "quadruplicarde": "quadruplicar",
    "quadruplicardes": "quadruplicar",
    "quadruplicare": "quadruplicar",
    "quadruplicarei": "quadruplicar",
    "quadruplicareis": "quadruplicar",
    "quadruplicarem": "quadruplicar",
    "quadruplicaremos": "quadruplicar",
    "quadruplicares": "quadruplicar",
    "quadruplicaria": "quadruplicar",
    "quadruplicariam": "quadruplicar",
    "quadruplicarias": "quadruplicar",
    "quadruplicarmo": "quadruplicar",
    "quadruplicarmos": "quadruplicar",
    "quadruplicará": "quadruplicar",
    "quadruplicarás": "quadruplicar",
    "quadruplicarão": "quadruplicar",
    "quadruplicaríamos": "quadruplicar",
    "quadruplicaríeis": "quadruplicar",
    "quadruplicas": "quadruplicar",
    "quadruplicasse": "quadruplicar",
    "quadruplicassem": "quadruplicar",
    "quadruplicasses": "quadruplicar",
    "quadruplicaste": "quadruplicar",
    "quadruplicastes": "quadruplicar",
    "quadruplicava": "quadruplicar",
    "quadruplicavam": "quadruplicar",
    "quadruplicavas": "quadruplicar",
    "quadruplicações": "quadruplicação",
    "quadruplico": "quadruplicar",
    "quadruplicou": "quadruplicar",
    "quadruplicá": "quadruplicar",
    "quadruplicámo": "quadruplicar",
    "quadruplicámos": "quadruplicar",
    "quadruplicáramo": "quadruplicar",
    "quadruplicáramos": "quadruplicar",
    "quadruplicárei": "quadruplicar",
    "quadruplicáreis": "quadruplicar",
    "quadruplicásseis": "quadruplicar",
    "quadruplicássemos": "quadruplicar",
    "quadruplicávamo": "quadruplicar",
    "quadruplicávamos": "quadruplicar",
    "quadruplicávei": "quadruplicar",
    "quadruplicáveis": "quadruplicável",
    "quadruplique": "quadruplicar",
    "quadrupliquei": "quadruplicar",
    "quadrupliqueis": "quadruplicar",
    "quadrupliquem": "quadruplicar",
    "quadrupliquemo": "quadruplicar",
    "quadrupliquemos": "quadruplicar",
    "quadrupliques": "quadruplicar",
    "quadruplo": "quadruplar",
    "quadruplou": "quadruplar",
    "quadruplá": "quadruplar",
    "quadruplámo": "quadruplar",
    "quadruplámos": "quadruplar",
    "quadrupláramo": "quadruplar",
    "quadrupláramos": "quadruplar",
    "quadruplárei": "quadruplar",
    "quadrupláreis": "quadruplar",
    "quadruplásseis": "quadruplar",
    "quadruplássemos": "quadruplar",
    "quadruplávamo": "quadruplar",
    "quadruplávamos": "quadruplar",
    "quadruplávei": "quadruplar",
    "quadrupláveis": "quadruplar",
    "quadrupolos": "quadrupolo",
    "quadrá": "quadrar",
    "quadrámo": "quadrar",
    "quadrámos": "quadrar",
    "quadráramo": "quadrar",
    "quadráramos": "quadrar",
    "quadrárei": "quadrar",
    "quadráreis": "quadrar",
    "quadrásseis": "quadrar",
    "quadrássemos": "quadrar",
    "quadrática": "quadrático",
    "quadráticas": "quadrático",
    "quadráticos": "quadrático",
    "quadrávamo": "quadrar",
    "quadrávamos": "quadrar",
    "quadrávei": "quadrar",
    "quadráveis": "quadrar",
    "quadrângulos": "quadrângulo",
    "quadrículas": "quadrícula",
    "quadrículos": "quadrículo",
    "quadrífica": "quadrífico",
    "quadríficas": "quadrífico",
    "quadríficos": "quadrífico",
    "quadríjuga": "quadríjugo",
    "quadríjugas": "quadríjugo",
    "quadríjugos": "quadríjugo",
    "quadrímana": "quadrímano",
    "quadrímanas": "quadrímano",
    "quadrímanos": "quadrímano",
    "quadrívios": "quadrívio",
    "quadrúmana": "quadrúmano",
    "quadrúmanas": "quadrúmano",
    "quadrúmanos": "quadrúmano",
    "quadrúnvira": "quadrúnviro",
    "quadrúnviras": "quadrúnviro",
    "quadrúnviros": "quadrúnviro",
    "quadrúpedes": "quadrúpede",
    "quais": "qual",
    "quaisquer": "qualquer",
    "qualidades": "qualidade",
    "qualifica": "qualificar",
    "qualificada": "qualificar",
    "qualificadas": "qualificar",
    "qualificado": "qualificar",
    "qualificadora": "qualificador",
    "qualificadoras": "qualificador",
    "qualificadores": "qualificador",
    "qualificados": "qualificar",
    "qualificadíssima": "qualificado",
    "qualificadíssimas": "qualificado",
    "qualificadíssimo": "qualificado",
    "qualificadíssimos": "qualificado",
    "qualificai": "qualificar",
    "qualificais": "qualificar",
    "qualificam": "qualificar",
    "qualificamo": "qualificar",
    "qualificamos": "qualificar",
    "qualificando": "qualificar",
    "qualificara": "qualificar",
    "qualificaram": "qualificar",
    "qualificaras": "qualificar",
    "qualificarde": "qualificar",
    "qualificardes": "qualificar",
    "qualificare": "qualificar",
    "qualificarei": "qualificar",
    "qualificareis": "qualificar",
    "qualificarem": "qualificar",
    "qualificaremos": "qualificar",
    "qualificares": "qualificar",
    "qualificaria": "qualificar",
    "qualificariam": "qualificar",
    "qualificarias": "qualificar",
    "qualificarmo": "qualificar",
    "qualificarmos": "qualificar",
    "qualificará": "qualificar",
    "qualificarás": "qualificar",
    "qualificarão": "qualificar",
    "qualificaríamos": "qualificar",
    "qualificaríeis": "qualificar",
    "qualificas": "qualificar",
    "qualificasse": "qualificar",
    "qualificassem": "qualificar",
    "qualificasses": "qualificar",
    "qualificaste": "qualificar",
    "qualificastes": "qualificar",
    "qualificativos": "qualificativo",
    "qualificava": "qualificar",
    "qualificavam": "qualificar",
    "qualificavas": "qualificar",
    "qualificações": "qualificação",
    "qualifico": "qualificar",
    "qualificou": "qualificar",
    "qualificá": "qualificar",
    "qualificámo": "qualificar",
    "qualificámos": "qualificar",
    "qualificáramo": "qualificar",
    "qualificáramos": "qualificar",
    "qualificárei": "qualificar",
    "qualificáreis": "qualificar",
    "qualificásseis": "qualificar",
    "qualificássemos": "qualificar",
    "qualificávamo": "qualificar",
    "qualificávamos": "qualificar",
    "qualificávei": "qualificar",
    "qualificáveis": "qualificável",
    "qualifique": "qualificar",
    "qualifiquei": "qualificar",
    "qualifiqueis": "qualificar",
    "qualifiquem": "qualificar",
    "qualifiquemo": "qualificar",
    "qualifiquemos": "qualificar",
    "qualifiques": "qualificar",
    "qualitativa": "qualitativo",
    "qualitativas": "qualitativo",
    "qualitativos": "qualitativo",
    "quanta": "quantum",
    "quantas": "quanto",
    "quantia": "quantiar",
    "quantiada": "quantiar",
    "quantiadas": "quantiar",
    "quantiado": "quantiar",
    "quantiados": "quantiar",
    "quantiai": "quantiar",
    "quantiais": "quantiar",
    "quantiam": "quantiar",
    "quantiamo": "quantiar",
    "quantiamos": "quantiar",
    "quantiando": "quantiar",
    "quantiara": "quantiar",
    "quantiaram": "quantiar",
    "quantiaras": "quantiar",
    "quantiarde": "quantiar",
    "quantiardes": "quantiar",
    "quantiare": "quantiar",
    "quantiarei": "quantiar",
    "quantiareis": "quantiar",
    "quantiarem": "quantiar",
    "quantiaremos": "quantiar",
    "quantiares": "quantiar",
    "quantiaria": "quantiar",
    "quantiariam": "quantiar",
    "quantiarias": "quantiar",
    "quantiarmo": "quantiar",
    "quantiarmos": "quantiar",
    "quantiará": "quantiar",
    "quantiarás": "quantiar",
    "quantiarão": "quantiar",
    "quantiaríamos": "quantiar",
    "quantiaríeis": "quantiar",
    "quantias": "quantiar",
    "quantiasse": "quantiar",
    "quantiassem": "quantiar",
    "quantiasses": "quantiar",
    "quantiaste": "quantiar",
    "quantiastes": "quantiar",
    "quantiava": "quantiar",
    "quantiavam": "quantiar",
    "quantiavas": "quantiar",
    "quantidades": "quantidade",
    "quantie": "quantiar",
    "quantiei": "quantiar",
    "quantieis": "quantiar",
    "quantiem": "quantiar",
    "quantiemo": "quantiar",
    "quantiemos": "quantiar",
    "quanties": "quantiar",
    "quantifica": "quantificar",
    "quantificada": "quantificar",
    "quantificadas": "quantificar",
    "quantificado": "quantificar",
    "quantificados": "quantificar",
    "quantificai": "quantificar",
    "quantificais": "quantificar",
    "quantificam": "quantificar",
    "quantificamo": "quantificar",
    "quantificamos": "quantificar",
    "quantificando": "quantificar",
    "quantificara": "quantificar",
    "quantificaram": "quantificar",
    "quantificaras": "quantificar",
    "quantificarde": "quantificar",
    "quantificardes": "quantificar",
    "quantificare": "quantificar",
    "quantificarei": "quantificar",
    "quantificareis": "quantificar",
    "quantificarem": "quantificar",
    "quantificaremos": "quantificar",
    "quantificares": "quantificar",
    "quantificaria": "quantificar",
    "quantificariam": "quantificar",
    "quantificarias": "quantificar",
    "quantificarmo": "quantificar",
    "quantificarmos": "quantificar",
    "quantificará": "quantificar",
    "quantificarás": "quantificar",
    "quantificarão": "quantificar",
    "quantificaríamos": "quantificar",
    "quantificaríeis": "quantificar",
    "quantificas": "quantificar",
    "quantificasse": "quantificar",
    "quantificassem": "quantificar",
    "quantificasses": "quantificar",
    "quantificaste": "quantificar",
    "quantificastes": "quantificar",
    "quantificava": "quantificar",
    "quantificavam": "quantificar",
    "quantificavas": "quantificar",
    "quantificações": "quantificação",
    "quantifico": "quantificar",
    "quantificou": "quantificar",
    "quantificá": "quantificar",
    "quantificámo": "quantificar",
    "quantificámos": "quantificar",
    "quantificáramo": "quantificar",
    "quantificáramos": "quantificar",
    "quantificárei": "quantificar",
    "quantificáreis": "quantificar",
    "quantificásseis": "quantificar",
    "quantificássemos": "quantificar",
    "quantificávamo": "quantificar",
    "quantificávamos": "quantificar",
    "quantificávei": "quantificar",
    "quantificáveis": "quantificável",
    "quantifique": "quantificar",
    "quantifiquei": "quantificar",
    "quantifiqueis": "quantificar",
    "quantifiquem": "quantificar",
    "quantifiquemo": "quantificar",
    "quantifiquemos": "quantificar",
    "quantifiques": "quantificar",
    "quantio": "quantiar",
    "quantiosa": "quantioso",
    "quantiosas": "quantioso",
    "quantiosos": "quantioso",
    "quantiou": "quantiar",
    "quantis": "quantil",
    "quantitativa": "quantitativo",
    "quantitativas": "quantitativo",
    "quantitativos": "quantitativo",
    "quantizações": "quantização",
    "quantiá": "quantiar",
    "quantiámo": "quantiar",
    "quantiámos": "quantiar",
    "quantiáramo": "quantiar",
    "quantiáramos": "quantiar",
    "quantiárei": "quantiar",
    "quantiáreis": "quantiar",
    "quantiásseis": "quantiar",
    "quantiássemos": "quantiar",
    "quantiávamo": "quantiar",
    "quantiávamos": "quantiar",
    "quantiávei": "quantiar",
    "quantiáveis": "quantiar",
    "quanto": "quantum",
    "quantofrenias": "quantofrenia",
    "quantos": "quanto",
    "quantómetros": "quantómetro",
    "quanzas": "quanza",
    "quarcífera": "quarcífero",
    "quarcíferas": "quarcífero",
    "quarcíferos": "quarcífero",
    "quarenta": "quarentar",
    "quarentada": "quarentar",
    "quarentadas": "quarentar",
    "quarentado": "quarentar",
    "quarentados": "quarentar",
    "quarentai": "quarentar",
    "quarentais": "quarentar",
    "quarentam": "quarentar",
    "quarentamo": "quarentar",
    "quarentamos": "quarentar",
    "quarentando": "quarentar",
    "quarentara": "quarentar",
    "quarentaram": "quarentar",
    "quarentaras": "quarentar",
    "quarentardes": "quarentar",
    "quarentarei": "quarentar",
    "quarentareis": "quarentar",
    "quarentarem": "quarentar",
    "quarentaremos": "quarentar",
    "quarentares": "quarentar",
    "quarentaria": "quarentar",
    "quarentariam": "quarentar",
    "quarentarias": "quarentar",
    "quarentarmo": "quarentar",
    "quarentarmos": "quarentar",
    "quarentará": "quarentar",
    "quarentarás": "quarentar",
    "quarentarão": "quarentar",
    "quarentaríamos": "quarentar",
    "quarentaríeis": "quarentar",
    "quarentas": "quarentar",
    "quarentasse": "quarentar",
    "quarentassem": "quarentar",
    "quarentasses": "quarentar",
    "quarentaste": "quarentar",
    "quarentastes": "quarentar",
    "quarentava": "quarentar",
    "quarentavam": "quarentar",
    "quarentavas": "quarentar",
    "quarente": "quarentar",
    "quarentei": "quarentar",
    "quarenteis": "quarentar",
    "quarentem": "quarentar",
    "quarentemo": "quarentar",
    "quarentemos": "quarentar",
    "quarentena": "quarentenar",
    "quarentenada": "quarentenar",
    "quarentenadas": "quarentenar",
    "quarentenado": "quarentenar",
    "quarentenados": "quarentenar",
    "quarentenai": "quarentenar",
    "quarentenais": "quarentenar",
    "quarentenam": "quarentenar",
    "quarentenamo": "quarentenar",
    "quarentenamos": "quarentenar",
    "quarentenando": "quarentenar",
    "quarentenara": "quarentenar",
    "quarentenaram": "quarentenar",
    "quarentenaras": "quarentenar",
    "quarentenardes": "quarentenar",
    "quarentenarei": "quarentenar",
    "quarentenareis": "quarentenar",
    "quarentenarem": "quarentenar",
    "quarentenaremos": "quarentenar",
    "quarentenares": "quarentenar",
    "quarentenaria": "quarentenar",
    "quarentenariam": "quarentenar",
    "quarentenarias": "quarentenar",
    "quarentenarmo": "quarentenar",
    "quarentenarmos": "quarentenar",
    "quarentenará": "quarentenar",
    "quarentenarás": "quarentenar",
    "quarentenarão": "quarentenar",
    "quarentenaríamos": "quarentenar",
    "quarentenaríeis": "quarentenar",
    "quarentenas": "quarentenar",
    "quarentenasse": "quarentenar",
    "quarentenassem": "quarentenar",
    "quarentenasses": "quarentenar",
    "quarentenaste": "quarentenar",
    "quarentenastes": "quarentenar",
    "quarentenava": "quarentenar",
    "quarentenavam": "quarentenar",
    "quarentenavas": "quarentenar",
    "quarentene": "quarentenar",
    "quarentenei": "quarentenar",
    "quarenteneis": "quarentenar",
    "quarentenem": "quarentenar",
    "quarentenemo": "quarentenar",
    "quarentenemos": "quarentenar",
    "quarentenes": "quarentenar",
    "quarenteno": "quarentenar",
    "quarentenou": "quarentenar",
    "quarentenámo": "quarentenar",
    "quarentenámos": "quarentenar",
    "quarentenáramo": "quarentenar",
    "quarentenáramos": "quarentenar",
    "quarentenáreis": "quarentenar",
    "quarentenária": "quarentenário",
    "quarentenárias": "quarentenário",
    "quarentenários": "quarentenário",
    "quarentenásseis": "quarentenar",
    "quarentenássemos": "quarentenar",
    "quarentenávamo": "quarentenar",
    "quarentenávamos": "quarentenar",
    "quarentenáveis": "quarentenar",
    "quarentes": "quarentar",
    "quarento": "quarentar",
    "quarentona": "quarentão",
    "quarentonas": "quarentão",
    "quarentou": "quarentar",
    "quarentámo": "quarentar",
    "quarentámos": "quarentar",
    "quarentáramo": "quarentar",
    "quarentáramos": "quarentar",
    "quarentáreis": "quarentar",
    "quarentásseis": "quarentar",
    "quarentássemos": "quarentar",
    "quarentávamo": "quarentar",
    "quarentávamos": "quarentar",
    "quarentáveis": "quarentar",
    "quarentões": "quarentão",
    "quaresma": "quaresmar",
    "quaresmada": "quaresmar",
    "quaresmadas": "quaresmar",
    "quaresmado": "quaresmar",
    "quaresmados": "quaresmar",
    "quaresmai": "quaresmar",
    "quaresmais": "quaresmar",
    "quaresmam": "quaresmar",
    "quaresmamo": "quaresmar",
    "quaresmamos": "quaresmar",
    "quaresmando": "quaresmar",
    "quaresmara": "quaresmar",
    "quaresmaram": "quaresmar",
    "quaresmaras": "quaresmar",
    "quaresmardes": "quaresmar",
    "quaresmarei": "quaresmar",
    "quaresmareis": "quaresmar",
    "quaresmarem": "quaresmar",
    "quaresmaremos": "quaresmar",
    "quaresmares": "quaresmar",
    "quaresmaria": "quaresmar",
    "quaresmariam": "quaresmar",
    "quaresmarias": "quaresmar",
    "quaresmarmo": "quaresmar",
    "quaresmarmos": "quaresmar",
    "quaresmará": "quaresmar",
    "quaresmarás": "quaresmar",
    "quaresmarão": "quaresmar",
    "quaresmaríamos": "quaresmar",
    "quaresmaríeis": "quaresmar",
    "quaresmas": "quaresmar",
    "quaresmasse": "quaresmar",
    "quaresmassem": "quaresmar",
    "quaresmasses": "quaresmar",
    "quaresmaste": "quaresmar",
    "quaresmastes": "quaresmar",
    "quaresmava": "quaresmar",
    "quaresmavam": "quaresmar",
    "quaresmavas": "quaresmar",
    "quaresme": "quaresmar",
    "quaresmei": "quaresmar",
    "quaresmeis": "quaresmar",
    "quaresmem": "quaresmar",
    "quaresmemo": "quaresmar",
    "quaresmemos": "quaresmar",
    "quaresmes": "quaresmar",
    "quaresmo": "quaresmar",
    "quaresmou": "quaresmar",
    "quaresmámo": "quaresmar",
    "quaresmámos": "quaresmar",
    "quaresmáramo": "quaresmar",
    "quaresmáramos": "quaresmar",
    "quaresmáreis": "quaresmar",
    "quaresmásseis": "quaresmar",
    "quaresmássemos": "quaresmar",
    "quaresmávamo": "quaresmar",
    "quaresmávamos": "quaresmar",
    "quaresmáveis": "quaresmar",
    "quarks": "quark",
    "quarta": "quarto",
    "quartada": "quartar",
    "quartadas": "quartar",
    "quartado": "quartar",
    "quartados": "quartar",
    "quartai": "quartar",
    "quartais": "quartar",
    "quartaluda": "quartaludo",
    "quartaludas": "quartaludo",
    "quartaludos": "quartaludo",
    "quartam": "quartar",
    "quartamo": "quartar",
    "quartamos": "quartar",
    "quartando": "quartar",
    "quartanistas": "quartanista",
    "quartanária": "quartanário",
    "quartanárias": "quartanário",
    "quartanários": "quartanário",
    "quartapisa": "quartapisar",
    "quartapisada": "quartapisar",
    "quartapisadas": "quartapisar",
    "quartapisado": "quartapisar",
    "quartapisados": "quartapisar",
    "quartapisai": "quartapisar",
    "quartapisais": "quartapisar",
    "quartapisam": "quartapisar",
    "quartapisamo": "quartapisar",
    "quartapisamos": "quartapisar",
    "quartapisando": "quartapisar",
    "quartapisara": "quartapisar",
    "quartapisaram": "quartapisar",
    "quartapisaras": "quartapisar",
    "quartapisarde": "quartapisar",
    "quartapisardes": "quartapisar",
    "quartapisare": "quartapisar",
    "quartapisarei": "quartapisar",
    "quartapisareis": "quartapisar",
    "quartapisarem": "quartapisar",
    "quartapisaremos": "quartapisar",
    "quartapisares": "quartapisar",
    "quartapisaria": "quartapisar",
    "quartapisariam": "quartapisar",
    "quartapisarias": "quartapisar",
    "quartapisarmo": "quartapisar",
    "quartapisarmos": "quartapisar",
    "quartapisará": "quartapisar",
    "quartapisarás": "quartapisar",
    "quartapisarão": "quartapisar",
    "quartapisaríamos": "quartapisar",
    "quartapisaríeis": "quartapisar",
    "quartapisas": "quartapisar",
    "quartapisasse": "quartapisar",
    "quartapisassem": "quartapisar",
    "quartapisasses": "quartapisar",
    "quartapisaste": "quartapisar",
    "quartapisastes": "quartapisar",
    "quartapisava": "quartapisar",
    "quartapisavam": "quartapisar",
    "quartapisavas": "quartapisar",
    "quartapise": "quartapisar",
    "quartapisei": "quartapisar",
    "quartapiseis": "quartapisar",
    "quartapisem": "quartapisar",
    "quartapisemo": "quartapisar",
    "quartapisemos": "quartapisar",
    "quartapises": "quartapisar",
    "quartapiso": "quartapisar",
    "quartapisou": "quartapisar",
    "quartapisá": "quartapisar",
    "quartapisámo": "quartapisar",
    "quartapisámos": "quartapisar",
    "quartapisáramo": "quartapisar",
    "quartapisáramos": "quartapisar",
    "quartapisárei": "quartapisar",
    "quartapisáreis": "quartapisar",
    "quartapisásseis": "quartapisar",
    "quartapisássemos": "quartapisar",
    "quartapisávamo": "quartapisar",
    "quartapisávamos": "quartapisar",
    "quartapisávei": "quartapisar",
    "quartapisáveis": "quartapisar",
    "quartara": "quartar",
    "quartaram": "quartar",
    "quartaras": "quartar",
    "quartardes": "quartar",
    "quartarei": "quartar",
    "quartareis": "quartar",
    "quartarem": "quartar",
    "quartaremos": "quartar",
    "quartares": "quartar",
    "quartaria": "quartar",
    "quartariam": "quartar",
    "quartarias": "quartar",
    "quartarmo": "quartar",
    "quartarmos": "quartar",
    "quartará": "quartar",
    "quartarás": "quartar",
    "quartarão": "quartar",
    "quartaríamos": "quartar",
    "quartaríeis": "quartar",
    "quartas": "quarto",
    "quartasse": "quartar",
    "quartassem": "quartar",
    "quartasses": "quartar",
    "quartaste": "quartar",
    "quartastes": "quartar",
    "quartaus": "quartau",
    "quartava": "quartar",
    "quartavam": "quartar",
    "quartavas": "quartar",
    "quarte": "quartar",
    "quarteada": "quartear",
    "quarteadas": "quartear",
    "quarteado": "quartear",
    "quarteados": "quartear",
    "quarteai": "quartear",
    "quarteais": "quartear",
    "quarteamo": "quartear",
    "quarteamos": "quartear",
    "quarteando": "quartear",
    "quarteara": "quartear",
    "quartearam": "quartear",
    "quartearas": "quartear",
    "quartearde": "quartear",
    "quarteardes": "quartear",
    "quarteare": "quartear",
    "quartearei": "quartear",
    "quarteareis": "quartear",
    "quartearem": "quartear",
    "quartearemos": "quartear",
    "quarteares": "quartear",
    "quartearia": "quartear",
    "quarteariam": "quartear",
    "quartearias": "quartear",
    "quartearmo": "quartear",
    "quartearmos": "quartear",
    "quarteará": "quartear",
    "quartearás": "quartear",
    "quartearão": "quartear",
    "quartearíamos": "quartear",
    "quartearíeis": "quartear",
    "quarteasse": "quartear",
    "quarteassem": "quartear",
    "quarteasses": "quartear",
    "quarteaste": "quartear",
    "quarteastes": "quartear",
    "quarteava": "quartear",
    "quarteavam": "quartear",
    "quarteavas": "quartear",
    "quarteei": "quartear",
    "quarteeis": "quartear",
    "quarteemo": "quartear",
    "quarteemos": "quartear",
    "quartei": "quartar",
    "quarteia": "quartear",
    "quarteiam": "quartear",
    "quarteias": "quartear",
    "quarteie": "quartear",
    "quarteiem": "quartear",
    "quarteies": "quartear",
    "quarteio": "quartear",
    "quarteios": "quarteio",
    "quarteira": "quarteiro",
    "quarteiras": "quarteiro",
    "quarteiros": "quarteiro",
    "quarteirões": "quarteirão",
    "quarteis": "quartar",
    "quarteja": "quartejar",
    "quartejada": "quartejar",
    "quartejadas": "quartejar",
    "quartejado": "quartejar",
    "quartejados": "quartejar",
    "quartejai": "quartejar",
    "quartejais": "quartejar",
    "quartejam": "quartejar",
    "quartejamo": "quartejar",
    "quartejamos": "quartejar",
    "quartejando": "quartejar",
    "quartejara": "quartejar",
    "quartejaram": "quartejar",
    "quartejaras": "quartejar",
    "quartejarde": "quartejar",
    "quartejardes": "quartejar",
    "quartejare": "quartejar",
    "quartejarei": "quartejar",
    "quartejareis": "quartejar",
    "quartejarem": "quartejar",
    "quartejaremos": "quartejar",
    "quartejares": "quartejar",
    "quartejaria": "quartejar",
    "quartejariam": "quartejar",
    "quartejarias": "quartejar",
    "quartejarmo": "quartejar",
    "quartejarmos": "quartejar",
    "quartejará": "quartejar",
    "quartejarás": "quartejar",
    "quartejarão": "quartejar",
    "quartejaríamos": "quartejar",
    "quartejaríeis": "quartejar",
    "quartejas": "quartejar",
    "quartejasse": "quartejar",
    "quartejassem": "quartejar",
    "quartejasses": "quartejar",
    "quartejaste": "quartejar",
    "quartejastes": "quartejar",
    "quartejava": "quartejar",
    "quartejavam": "quartejar",
    "quartejavas": "quartejar",
    "quarteje": "quartejar",
    "quartejei": "quartejar",
    "quartejeis": "quartejar",
    "quartejem": "quartejar",
    "quartejemo": "quartejar",
    "quartejemos": "quartejar",
    "quartejes": "quartejar",
    "quartejo": "quartejar",
    "quartejou": "quartejar",
    "quartejá": "quartejar",
    "quartejámo": "quartejar",
    "quartejámos": "quartejar",
    "quartejáramo": "quartejar",
    "quartejáramos": "quartejar",
    "quartejárei": "quartejar",
    "quartejáreis": "quartejar",
    "quartejásseis": "quartejar",
    "quartejássemos": "quartejar",
    "quartejávamo": "quartejar",
    "quartejávamos": "quartejar",
    "quartejávei": "quartejar",
    "quartejáveis": "quartejar",
    "quarteladas": "quartelada",
    "quarteleiros": "quarteleiro",
    "quartem": "quartar",
    "quartemo": "quartar",
    "quartemos": "quartar",
    "quarteou": "quartear",
    "quarterona": "quarterão",
    "quarteronas": "quarterão",
    "quarterões": "quarterão",
    "quartes": "quartar",
    "quartetos": "quarteto",
    "quarteá": "quartear",
    "quarteámo": "quartear",
    "quarteámos": "quartear",
    "quarteáramo": "quartear",
    "quarteáramos": "quartear",
    "quarteárei": "quartear",
    "quarteáreis": "quartear",
    "quarteásseis": "quartear",
    "quarteássemos": "quartear",
    "quarteávamo": "quartear",
    "quarteávamos": "quartear",
    "quarteávei": "quartear",
    "quarteáveis": "quartear",
    "quartilha": "quartilhar",
    "quartilhada": "quartilhar",
    "quartilhadas": "quartilhar",
    "quartilhado": "quartilhar",
    "quartilhados": "quartilhar",
    "quartilhai": "quartilhar",
    "quartilhais": "quartilhar",
    "quartilham": "quartilhar",
    "quartilhames": "quartilhame",
    "quartilhamo": "quartilhar",
    "quartilhamos": "quartilhar",
    "quartilhando": "quartilhar",
    "quartilhara": "quartilhar",
    "quartilharam": "quartilhar",
    "quartilharas": "quartilhar",
    "quartilharde": "quartilhar",
    "quartilhardes": "quartilhar",
    "quartilhare": "quartilhar",
    "quartilharei": "quartilhar",
    "quartilhareis": "quartilhar",
    "quartilharem": "quartilhar",
    "quartilharemos": "quartilhar",
    "quartilhares": "quartilhar",
    "quartilharia": "quartilhar",
    "quartilhariam": "quartilhar",
    "quartilharias": "quartilhar",
    "quartilharmo": "quartilhar",
    "quartilharmos": "quartilhar",
    "quartilhará": "quartilhar",
    "quartilharás": "quartilhar",
    "quartilharão": "quartilhar",
    "quartilharíamos": "quartilhar",
    "quartilharíeis": "quartilhar",
    "quartilhas": "quartilhar",
    "quartilhasse": "quartilhar",
    "quartilhassem": "quartilhar",
    "quartilhasses": "quartilhar",
    "quartilhaste": "quartilhar",
    "quartilhastes": "quartilhar",
    "quartilhava": "quartilhar",
    "quartilhavam": "quartilhar",
    "quartilhavas": "quartilhar",
    "quartilhe": "quartilhar",
    "quartilhei": "quartilhar",
    "quartilheis": "quartilhar",
    "quartilhem": "quartilhar",
    "quartilhemo": "quartilhar",
    "quartilhemos": "quartilhar",
    "quartilhes": "quartilhar",
    "quartilho": "quartilhar",
    "quartilhos": "quartilho",
    "quartilhou": "quartilhar",
    "quartilhá": "quartilhar",
    "quartilhámo": "quartilhar",
    "quartilhámos": "quartilhar",
    "quartilháramo": "quartilhar",
    "quartilháramos": "quartilhar",
    "quartilhárei": "quartilhar",
    "quartilháreis": "quartilhar",
    "quartilhásseis": "quartilhar",
    "quartilhássemos": "quartilhar",
    "quartilhávamo": "quartilhar",
    "quartilhávamos": "quartilhar",
    "quartilhávei": "quartilhar",
    "quartilháveis": "quartilhar",
    "quartinhas": "quartinha",
    "quartinho": "quarto",
    "quartinhos": "quarto",
    "quartis": "quartil",
    "quartito": "quarto",
    "quartitos": "quarto",
    "quarto": "quartar",
    "quartolas": "quartola",
    "quartos": "quarto",
    "quartou": "quartar",
    "quartzinas": "quartzina",
    "quartzitos": "quartzito",
    "quartzos": "quartzo",
    "quartzosa": "quartzoso",
    "quartzosas": "quartzoso",
    "quartzosos": "quartzoso",
    "quartzífera": "quartzífero",
    "quartzíferas": "quartzífero",
    "quartzíferos": "quartzífero",
    "quartámo": "quartar",
    "quartámos": "quartar",
    "quartáramo": "quartar",
    "quartáramos": "quartar",
    "quartáreis": "quartar",
    "quartásseis": "quartar",
    "quartássemos": "quartar",
    "quartávamo": "quartar",
    "quartávamos": "quartar",
    "quartáveis": "quartar",
    "quartãs": "quartã",
    "quartéis": "quartel",
    "quartões": "quartão",
    "quarços": "quarço",
    "quasares": "quasar",
    "quassações": "quassação",
    "quassinas": "quassina",
    "quassites": "quassite",
    "quasímodos": "quasímodo",
    "quaterna": "quaterno",
    "quaternada": "quaternado",
    "quaternadas": "quaternado",
    "quaternados": "quaternado",
    "quaternas": "quaterno",
    "quaternidades": "quaternidade",
    "quaterniões": "quaternião",
    "quaternos": "quaterno",
    "quaternária": "quaternário",
    "quaternárias": "quaternário",
    "quaternários": "quaternário",
    "quatis": "quati",
    "quatorze": "catorze",
    "quatorzes": "quatorze",
    "quatriduana": "quatriduano",
    "quatriduanas": "quatriduano",
    "quatriduanos": "quatriduano",
    "quatrienais": "quatrienal",
    "quatrilhões": "quatrilhão",
    "quatriliões": "quatrilião",
    "quatrincas": "quatrinca",
    "quatrinetas": "quatrineta",
    "quatrins": "quatrim",
    "quatriénios": "quatriénio",
    "quatrocentas": "quatrocentos",
    "quatrocentismos": "quatrocentismo",
    "quatrocentistas": "quatrocentista",
    "quatríduos": "quatríduo",
    "quatuorvirados": "quatuorvirado",
    "quatuorviratos": "quatuorvirato",
    "quatuórviros": "quatuórviro",
    "quebra": "quebrar",
    "quebrachos": "quebracho",
    "quebrada": "quebrar",
    "quebradas": "quebrar",
    "quebradazinha": "quebrado",
    "quebradazinhas": "quebrado",
    "quebradazita": "quebrado",
    "quebradazitas": "quebrado",
    "quebradeiras": "quebradeira",
    "quebradelas": "quebradela",
    "quebradinha": "quebrado",
    "quebradinhas": "quebrado",
    "quebradinho": "quebrado",
    "quebradinhos": "quebrado",
    "quebradita": "quebrado",
    "quebraditas": "quebrado",
    "quebradito": "quebrado",
    "quebraditos": "quebrado",
    "quebradiça": "quebradiço",
    "quebradiças": "quebradiço",
    "quebradiços": "quebradiço",
    "quebrado": "quebrar",
    "quebradoiros": "quebradoiro",
    "quebradora": "quebrador",
    "quebradoras": "quebrador",
    "quebradores": "quebrador",
    "quebrados": "quebrar",
    "quebradouros": "quebradouro",
    "quebradozinho": "quebrado",
    "quebradozinhos": "quebrado",
    "quebradozito": "quebrado",
    "quebradozitos": "quebrado",
    "quebraduras": "quebradura",
    "quebradíssima": "quebrado",
    "quebradíssimas": "quebrado",
    "quebradíssimo": "quebrado",
    "quebradíssimos": "quebrado",
    "quebrai": "quebrar",
    "quebrais": "quebrar",
    "quebralhona": "quebralhão",
    "quebralhonas": "quebralhão",
    "quebralhões": "quebralhão",
    "quebram": "quebrar",
    "quebramentos": "quebramento",
    "quebramo": "quebrar",
    "quebramos": "quebrar",
    "quebrando": "quebrar",
    "quebranta": "quebrantar",
    "quebrantada": "quebrantar",
    "quebrantadas": "quebrantar",
    "quebrantadazinha": "quebrantado",
    "quebrantadazinhas": "quebrantado",
    "quebrantadazita": "quebrantado",
    "quebrantadazitas": "quebrantado",
    "quebrantadinha": "quebrantado",
    "quebrantadinhas": "quebrantado",
    "quebrantadinho": "quebrantado",
    "quebrantadinhos": "quebrantado",
    "quebrantadita": "quebrantado",
    "quebrantaditas": "quebrantado",
    "quebrantadito": "quebrantado",
    "quebrantaditos": "quebrantado",
    "quebrantado": "quebrantar",
    "quebrantadora": "quebrantador",
    "quebrantadoras": "quebrantador",
    "quebrantadores": "quebrantador",
    "quebrantados": "quebrantar",
    "quebrantadozinho": "quebrantado",
    "quebrantadozinhos": "quebrantado",
    "quebrantadozito": "quebrantado",
    "quebrantadozitos": "quebrantado",
    "quebrantadíssima": "quebrantado",
    "quebrantadíssimas": "quebrantado",
    "quebrantadíssimo": "quebrantado",
    "quebrantadíssimos": "quebrantado",
    "quebrantai": "quebrantar",
    "quebrantais": "quebrantar",
    "quebrantam": "quebrantar",
    "quebrantamentos": "quebrantamento",
    "quebrantamo": "quebrantar",
    "quebrantamos": "quebrantar",
    "quebrantando": "quebrantar",
    "quebrantara": "quebrantar",
    "quebrantaram": "quebrantar",
    "quebrantaras": "quebrantar",
    "quebrantarde": "quebrantar",
    "quebrantardes": "quebrantar",
    "quebrantare": "quebrantar",
    "quebrantarei": "quebrantar",
    "quebrantareis": "quebrantar",
    "quebrantarem": "quebrantar",
    "quebrantaremos": "quebrantar",
    "quebrantares": "quebrantar",
    "quebrantaria": "quebrantar",
    "quebrantariam": "quebrantar",
    "quebrantarias": "quebrantar",
    "quebrantarmo": "quebrantar",
    "quebrantarmos": "quebrantar",
    "quebrantará": "quebrantar",
    "quebrantarás": "quebrantar",
    "quebrantarão": "quebrantar",
    "quebrantaríamos": "quebrantar",
    "quebrantaríeis": "quebrantar",
    "quebrantas": "quebrantar",
    "quebrantasse": "quebrantar",
    "quebrantassem": "quebrantar",
    "quebrantasses": "quebrantar",
    "quebrantaste": "quebrantar",
    "quebrantastes": "quebrantar",
    "quebrantava": "quebrantar",
    "quebrantavam": "quebrantar",
    "quebrantavas": "quebrantar",
    "quebrante": "quebrantar",
    "quebrantei": "quebrantar",
    "quebranteis": "quebrantar",
    "quebrantem": "quebrantar",
    "quebrantemo": "quebrantar",
    "quebrantemos": "quebrantar",
    "quebrantes": "quebrantar",
    "quebranto": "quebrantar",
    "quebrantos": "quebranto",
    "quebrantou": "quebrantar",
    "quebrantá": "quebrantar",
    "quebrantámo": "quebrantar",
    "quebrantámos": "quebrantar",
    "quebrantáramo": "quebrantar",
    "quebrantáramos": "quebrantar",
    "quebrantárei": "quebrantar",
    "quebrantáreis": "quebrantar",
    "quebrantásseis": "quebrantar",
    "quebrantássemos": "quebrantar",
    "quebrantávamo": "quebrantar",
    "quebrantávamos": "quebrantar",
    "quebrantávei": "quebrantar",
    "quebrantáveis": "quebrantar",
    "quebranças": "quebrança",
    "quebrara": "quebrar",
    "quebraram": "quebrar",
    "quebraras": "quebrar",
    "quebrarde": "quebrar",
    "quebrardes": "quebrar",
    "quebrare": "quebrar",
    "quebrarei": "quebrar",
    "quebrareis": "quebrar",
    "quebrarem": "quebrar",
    "quebraremos": "quebrar",
    "quebrares": "quebrar",
    "quebraria": "quebrar",
    "quebrariam": "quebrar",
    "quebrarias": "quebrar",
    "quebrarmo": "quebrar",
    "quebrarmos": "quebrar",
    "quebrará": "quebrar",
    "quebrarás": "quebrar",
    "quebrarão": "quebrar",
    "quebraríamos": "quebrar",
    "quebraríeis": "quebrar",
    "quebras": "quebrar",
    "quebrasse": "quebrar",
    "quebrassem": "quebrar",
    "quebrasses": "quebrar",
    "quebraste": "quebrar",
    "quebrastes": "quebrar",
    "quebraturas": "quebratura",
    "quebrava": "quebrar",
    "quebravam": "quebrar",
    "quebravas": "quebrar",
    "quebrações": "quebração",
    "quebre": "quebrar",
    "quebrei": "quebrar",
    "quebreiras": "quebreira",
    "quebreis": "quebrar",
    "quebrem": "quebrar",
    "quebremo": "quebrar",
    "quebremos": "quebrar",
    "quebres": "quebrar",
    "quebro": "quebrar",
    "quebros": "quebro",
    "quebrou": "quebrar",
    "quebrá": "quebrar",
    "quebrámo": "quebrar",
    "quebrámos": "quebrar",
    "quebráramo": "quebrar",
    "quebráramos": "quebrar",
    "quebrárei": "quebrar",
    "quebráreis": "quebrar",
    "quebrásseis": "quebrar",
    "quebrássemos": "quebrar",
    "quebrávamo": "quebrar",
    "quebrávamos": "quebrar",
    "quebrávei": "quebrar",
    "quebráveis": "quebrável",
    "queda": "quedo",
    "quedada": "quedar",
    "quedadas": "quedar",
    "quedado": "quedar",
    "quedados": "quedar",
    "quedai": "quedar",
    "quedais": "quedar",
    "quedam": "quedar",
    "quedamo": "quedar",
    "quedamos": "quedar",
    "quedando": "quedar",
    "quedara": "quedar",
    "quedaram": "quedar",
    "quedaras": "quedar",
    "quedardes": "quedar",
    "quedarei": "quedar",
    "quedareis": "quedar",
    "quedarem": "quedar",
    "quedaremos": "quedar",
    "quedares": "quedar",
    "quedaria": "quedar",
    "quedariam": "quedar",
    "quedarias": "quedar",
    "quedarmo": "quedar",
    "quedarmos": "quedar",
    "quedará": "quedar",
    "quedarás": "quedar",
    "quedarão": "quedar",
    "quedaríamos": "quedar",
    "quedaríeis": "quedar",
    "quedas": "quedo",
    "quedasse": "quedar",
    "quedassem": "quedar",
    "quedasses": "quedar",
    "quedaste": "quedar",
    "quedastes": "quedar",
    "quedava": "quedar",
    "quedavam": "quedar",
    "quedavas": "quedar",
    "quede": "quedar",
    "quedei": "quedar",
    "quedeis": "quedar",
    "quedem": "quedar",
    "quedemo": "quedar",
    "quedemos": "quedar",
    "quedes": "quedar",
    "quedismos": "quedismo",
    "quedistas": "quedista",
    "quedivas": "quediva",
    "quedives": "quedive",
    "quedo": "quedar",
    "quedos": "quedo",
    "quedou": "quedar",
    "quedámo": "quedar",
    "quedámos": "quedar",
    "quedáramo": "quedar",
    "quedáramos": "quedar",
    "quedáreis": "quedar",
    "quedásseis": "quedar",
    "quedássemos": "quedar",
    "quedávamo": "quedar",
    "quedávamos": "quedar",
    "quedáveis": "quedar",
    "quefazeres": "quefazer",
    "quefires": "quefir",
    "quefirinas": "quefirina",
    "quefiroterapias": "quefiroterapia",
    "queija": "queijar",
    "queijada": "queijar",
    "queijadas": "queijar",
    "queijadeira": "queijadeiro",
    "queijadeiras": "queijadeiro",
    "queijadeiros": "queijadeiro",
    "queijadilhos": "queijadilho",
    "queijadinha": "queijada",
    "queijadinhas": "queijada",
    "queijadita": "queijada",
    "queijaditas": "queijada",
    "queijado": "queijar",
    "queijados": "queijar",
    "queijai": "queijar",
    "queijais": "queijar",
    "queijam": "queijar",
    "queijamo": "queijar",
    "queijamos": "queijar",
    "queijando": "queijar",
    "queijara": "queijar",
    "queijaram": "queijar",
    "queijaras": "queijar",
    "queijardes": "queijar",
    "queijarei": "queijar",
    "queijareis": "queijar",
    "queijarem": "queijar",
    "queijaremos": "queijar",
    "queijares": "queijar",
    "queijaria": "queijar",
    "queijariam": "queijar",
    "queijarias": "queijaria",
    "queijarmo": "queijar",
    "queijarmos": "queijar",
    "queijará": "queijar",
    "queijarás": "queijar",
    "queijarão": "queijar",
    "queijaríamos": "queijar",
    "queijaríeis": "queijar",
    "queijas": "queijar",
    "queijasse": "queijar",
    "queijassem": "queijar",
    "queijasses": "queijar",
    "queijaste": "queijar",
    "queijastes": "queijar",
    "queijava": "queijar",
    "queijavam": "queijar",
    "queijavas": "queijar",
    "queije": "queijar",
    "queijei": "queijar",
    "queijeira": "queijeiro",
    "queijeiras": "queijeiro",
    "queijeiros": "queijeiro",
    "queijeis": "queijar",
    "queijem": "queijar",
    "queijemo": "queijar",
    "queijemos": "queijar",
    "queijes": "queijar",
    "queijinho": "queijo",
    "queijinhos": "queijo",
    "queijito": "queijo",
    "queijitos": "queijo",
    "queijo": "queijar",
    "queijos": "queijo",
    "queijou": "queijar",
    "queijámo": "queijar",
    "queijámos": "queijar",
    "queijáramo": "queijar",
    "queijáramos": "queijar",
    "queijáreis": "queijar",
    "queijásseis": "queijar",
    "queijássemos": "queijar",
    "queijávamo": "queijar",
    "queijávamos": "queijar",
    "queijáveis": "queijar",
    "queilodipterídeos": "queilodipterídeo",
    "queilodiptéridas": "queilodiptérida",
    "queima": "queimar",
    "queimada": "queimar",
    "queimadas": "queimar",
    "queimadazinha": "queimado",
    "queimadazinhas": "queimado",
    "queimadazita": "queimado",
    "queimadazitas": "queimado",
    "queimadelas": "queimadela",
    "queimadinha": "queimado",
    "queimadinhas": "queimado",
    "queimadinho": "queimado",
    "queimadinhos": "queimado",
    "queimadita": "queimado",
    "queimaditas": "queimado",
    "queimadito": "queimado",
    "queimaditos": "queimado",
    "queimado": "queimar",
    "queimadoiros": "queimadoiro",
    "queimadora": "queimador",
    "queimadoras": "queimador",
    "queimadores": "queimador",
    "queimados": "queimar",
    "queimadotes": "queimadote",
    "queimadouros": "queimadouro",
    "queimadozinho": "queimado",
    "queimadozinhos": "queimado",
    "queimadozito": "queimado",
    "queimadozitos": "queimado",
    "queimaduras": "queimadura",
    "queimadíssima": "queimado",
    "queimadíssimas": "queimado",
    "queimadíssimo": "queimado",
    "queimadíssimos": "queimado",
    "queimai": "queimar",
    "queimais": "queimar",
    "queimam": "queimar",
    "queimamentos": "queimamento",
    "queimamo": "queimar",
    "queimamos": "queimar",
    "queimando": "queimar",
    "queimantes": "queimante",
    "queimara": "queimar",
    "queimaram": "queimar",
    "queimaras": "queimar",
    "queimarde": "queimar",
    "queimardes": "queimar",
    "queimare": "queimar",
    "queimarei": "queimar",
    "queimareis": "queimar",
    "queimarem": "queimar",
    "queimaremos": "queimar",
    "queimares": "queimar",
    "queimaria": "queimar",
    "queimariam": "queimar",
    "queimarias": "queimar",
    "queimarmo": "queimar",
    "queimarmos": "queimar",
    "queimará": "queimar",
    "queimarás": "queimar",
    "queimarão": "queimar",
    "queimaríamos": "queimar",
    "queimaríeis": "queimar",
    "queimas": "queimar",
    "queimasse": "queimar",
    "queimassem": "queimar",
    "queimasses": "queimar",
    "queimaste": "queimar",
    "queimastes": "queimar",
    "queimava": "queimar",
    "queimavam": "queimar",
    "queimavas": "queimar",
    "queimações": "queimação",
    "queime": "queimar",
    "queimei": "queimar",
    "queimeis": "queimar",
    "queimem": "queimar",
    "queimemo": "queimar",
    "queimemos": "queimar",
    "queimes": "queimar",
    "queimo": "queimar",
    "queimores": "queimor",
    "queimos": "queimo",
    "queimosa": "queimoso",
    "queimosas": "queimoso",
    "queimosos": "queimoso",
    "queimou": "queimar",
    "queimá": "queimar",
    "queimámo": "queimar",
    "queimámos": "queimar",
    "queimáramo": "queimar",
    "queimáramos": "queimar",
    "queimárei": "queimar",
    "queimáreis": "queimar",
    "queimásseis": "queimar",
    "queimássemos": "queimar",
    "queimávamo": "queimar",
    "queimávamos": "queimar",
    "queimávei": "queimar",
    "queimáveis": "queimar",
    "queimões": "queimão",
    "queira": "querer",
    "queirais": "querer",
    "queiram": "querer",
    "queiramo": "querer",
    "queiramos": "querer",
    "queiras": "querer",
    "queirogas": "queiroga",
    "queirosiana": "queirosiano",
    "queirosianas": "queirosiano",
    "queirosianos": "queirosiano",
    "queirós": "queiró",
    "queixa": "queixar",
    "queixada": "queixar",
    "queixadas": "queixar",
    "queixado": "queixar",
    "queixados": "queixar",
    "queixai": "queixar",
    "queixais": "queixar",
    "queixam": "queixar",
    "queixamo": "queixar",
    "queixamos": "queixar",
    "queixando": "queixar",
    "queixara": "queixar",
    "queixaram": "queixar",
    "queixaras": "queixar",
    "queixarde": "queixar",
    "queixardes": "queixar",
    "queixare": "queixar",
    "queixarei": "queixar",
    "queixareis": "queixar",
    "queixarem": "queixar",
    "queixaremos": "queixar",
    "queixares": "queixar",
    "queixaria": "queixar",
    "queixariam": "queixar",
    "queixarias": "queixar",
    "queixarmo": "queixar",
    "queixarmos": "queixar",
    "queixará": "queixar",
    "queixarás": "queixar",
    "queixarão": "queixar",
    "queixaríamos": "queixar",
    "queixaríeis": "queixar",
    "queixas": "queixar",
    "queixasse": "queixar",
    "queixassem": "queixar",
    "queixasses": "queixar",
    "queixaste": "queixar",
    "queixastes": "queixar",
    "queixava": "queixar",
    "queixavam": "queixar",
    "queixavas": "queixar",
    "queixazinha": "queixa",
    "queixazinhas": "queixa",
    "queixazita": "queixa",
    "queixazitas": "queixa",
    "queixe": "queixar",
    "queixei": "queixar",
    "queixeira": "queixeiro",
    "queixeiras": "queixeiro",
    "queixeiros": "queixeiro",
    "queixeis": "queixar",
    "queixem": "queixar",
    "queixemo": "queixar",
    "queixemos": "queixar",
    "queixes": "queixar",
    "queixinha": "queixa",
    "queixinhas": "queixa",
    "queixita": "queixa",
    "queixitas": "queixa",
    "queixo": "queixar",
    "queixos": "queixo",
    "queixosa": "queixoso",
    "queixosas": "queixoso",
    "queixosos": "queixoso",
    "queixou": "queixar",
    "queixuda": "queixudo",
    "queixudas": "queixudo",
    "queixudos": "queixudo",
    "queixumes": "queixume",
    "queixá": "queixar",
    "queixámo": "queixar",
    "queixámos": "queixar",
    "queixáramo": "queixar",
    "queixáramos": "queixar",
    "queixárei": "queixar",
    "queixáreis": "queixar",
    "queixásseis": "queixar",
    "queixássemos": "queixar",
    "queixávamo": "queixar",
    "queixávamos": "queixar",
    "queixávei": "queixar",
    "queixáveis": "queixar",
    "quejadilhos": "quejadilho",
    "quejanda": "quejando",
    "quejandas": "quejando",
    "quejandos": "quejando",
    "queles": "quele",
    "quelhas": "quelha",
    "quelhos": "quelho",
    "quelhórios": "quelhório",
    "quelicerada": "quelicerado",
    "queliceradas": "quelicerado",
    "quelicerados": "quelicerado",
    "quelidídeos": "quelidídeo",
    "quelidónias": "quelidónia",
    "quelimanes": "quelimane",
    "quelmas": "quelma",
    "quelmes": "quelme",
    "queloniídeos": "queloniídeo",
    "quelonografias": "quelonografia",
    "queloníidas": "queloníida",
    "quelonófaga": "quelonófago",
    "quelonófagas": "quelonófago",
    "quelonófagos": "quelonófago",
    "quelonógrafa": "quelonógrafo",
    "quelonógrafas": "quelonógrafo",
    "quelonógrafos": "quelonógrafo",
    "quelíceras": "quelícera",
    "quelídidas": "quelídida",
    "quelípodes": "quelípode",
    "quelónios": "quelónio",
    "queniana": "queniano",
    "quenianas": "queniano",
    "quenianos": "queniano",
    "quenopodiáceas": "quenopodiácea",
    "quenopódios": "quenopódio",
    "quenta": "quentar",
    "quentada": "quentar",
    "quentadas": "quentar",
    "quentado": "quentar",
    "quentados": "quentar",
    "quentai": "quentar",
    "quentais": "quentar",
    "quentam": "quentar",
    "quentamo": "quentar",
    "quentamos": "quentar",
    "quentando": "quentar",
    "quentara": "quentar",
    "quentaram": "quentar",
    "quentaras": "quentar",
    "quentarde": "quentar",
    "quentardes": "quentar",
    "quentare": "quentar",
    "quentarei": "quentar",
    "quentareis": "quentar",
    "quentarem": "quentar",
    "quentaremos": "quentar",
    "quentares": "quentar",
    "quentaria": "quentar",
    "quentariam": "quentar",
    "quentarias": "quentar",
    "quentarmo": "quentar",
    "quentarmos": "quentar",
    "quentará": "quentar",
    "quentarás": "quentar",
    "quentarão": "quentar",
    "quentaríamos": "quentar",
    "quentaríeis": "quentar",
    "quentas": "quentar",
    "quentasse": "quentar",
    "quentassem": "quentar",
    "quentasses": "quentar",
    "quentaste": "quentar",
    "quentastes": "quentar",
    "quentava": "quentar",
    "quentavam": "quentar",
    "quentavas": "quentar",
    "quente": "quentar",
    "quentei": "quentar",
    "quenteis": "quentar",
    "quentem": "quentar",
    "quentemo": "quentar",
    "quentemos": "quentar",
    "quentes": "quente",
    "quentezinha": "quente",
    "quentezinhas": "quente",
    "quentezinho": "quente",
    "quentezinhos": "quente",
    "quentezita": "quente",
    "quentezitas": "quente",
    "quentezito": "quente",
    "quentezitos": "quente",
    "quentinha": "quente",
    "quentinhas": "quente",
    "quentinho": "quente",
    "quentinhos": "quente",
    "quentita": "quente",
    "quentitas": "quente",
    "quentito": "quente",
    "quentitos": "quente",
    "quento": "quentar",
    "quentou": "quentar",
    "quenturas": "quentura",
    "quentá": "quentar",
    "quentámo": "quentar",
    "quentámos": "quentar",
    "quentáramo": "quentar",
    "quentáramos": "quentar",
    "quentárei": "quentar",
    "quentáreis": "quentar",
    "quentásseis": "quentar",
    "quentássemos": "quentar",
    "quentávamo": "quentar",
    "quentávamos": "quentar",
    "quentávei": "quentar",
    "quentáveis": "quentar",
    "quentíssima": "quente",
    "quentíssimas": "quente",
    "quentíssimo": "quente",
    "quentíssimos": "quente",
    "queques": "queque",
    "quequezinha": "queque",
    "quequezinhas": "queque",
    "quequezinho": "queque",
    "quequezinhos": "queque",
    "quequezita": "queque",
    "quequezitas": "queque",
    "quequezito": "queque",
    "quequezitos": "queque",
    "quequinha": "queque",
    "quequinhas": "queque",
    "quequinho": "queque",
    "quequinhos": "queque",
    "quequita": "queque",
    "quequitas": "queque",
    "quequito": "queque",
    "quequitos": "queque",
    "quequíssima": "queque",
    "quequíssimas": "queque",
    "quequíssimo": "queque",
    "quequíssimos": "queque",
    "quer": "querer",
    "quercinas": "quercina",
    "quercites": "quercite",
    "quercitrinas": "quercitrina",
    "quercos": "querco",
    "quere": "querer",
    "querei": "querer",
    "quereis": "querer",
    "querela": "querelar",
    "querelada": "querelar",
    "quereladas": "querelar",
    "querelado": "querelar",
    "quereladora": "querelador",
    "quereladoras": "querelador",
    "quereladores": "querelador",
    "querelados": "querelar",
    "querelai": "querelar",
    "querelais": "querelar",
    "querelam": "querelar",
    "querelamo": "querelar",
    "querelamos": "querelar",
    "querelando": "querelar",
    "querelantes": "querelante",
    "querelara": "querelar",
    "querelaram": "querelar",
    "querelaras": "querelar",
    "querelardes": "querelar",
    "querelarei": "querelar",
    "querelareis": "querelar",
    "querelarem": "querelar",
    "querelaremos": "querelar",
    "querelares": "querelar",
    "querelaria": "querelar",
    "querelariam": "querelar",
    "querelarias": "querelar",
    "querelarmo": "querelar",
    "querelarmos": "querelar",
    "querelará": "querelar",
    "querelarás": "querelar",
    "querelarão": "querelar",
    "querelaríamos": "querelar",
    "querelaríeis": "querelar",
    "querelas": "querelar",
    "querelasse": "querelar",
    "querelassem": "querelar",
    "querelasses": "querelar",
    "querelaste": "querelar",
    "querelastes": "querelar",
    "querelava": "querelar",
    "querelavam": "querelar",
    "querelavas": "querelar",
    "querele": "querelar",
    "querelei": "querelar",
    "quereleis": "querelar",
    "querelem": "querelar",
    "querelemo": "querelar",
    "querelemos": "querelar",
    "quereles": "querelar",
    "querelo": "querelar",
    "querelosa": "quereloso",
    "querelosas": "quereloso",
    "querelosos": "quereloso",
    "querelou": "querelar",
    "querelámo": "querelar",
    "querelámos": "querelar",
    "quereláramo": "querelar",
    "quereláramos": "querelar",
    "quereláreis": "querelar",
    "querelásseis": "querelar",
    "querelássemos": "querelar",
    "querelávamo": "querelar",
    "querelávamos": "querelar",
    "quereláveis": "querelar",
    "querem": "querer",
    "queremo": "querer",
    "queremos": "querer",
    "querena": "querenar",
    "querenada": "querenar",
    "querenadas": "querenar",
    "querenado": "querenar",
    "querenados": "querenar",
    "querenai": "querenar",
    "querenais": "querenar",
    "querenam": "querenar",
    "querenamo": "querenar",
    "querenamos": "querenar",
    "querenando": "querenar",
    "querenara": "querenar",
    "querenaram": "querenar",
    "querenaras": "querenar",
    "querenarde": "querenar",
    "querenardes": "querenar",
    "querenare": "querenar",
    "querenarei": "querenar",
    "querenareis": "querenar",
    "querenarem": "querenar",
    "querenaremos": "querenar",
    "querenares": "querenar",
    "querenaria": "querenar",
    "querenariam": "querenar",
    "querenarias": "querenar",
    "querenarmo": "querenar",
    "querenarmos": "querenar",
    "querenará": "querenar",
    "querenarás": "querenar",
    "querenarão": "querenar",
    "querenaríamos": "querenar",
    "querenaríeis": "querenar",
    "querenas": "querenar",
    "querenasse": "querenar",
    "querenassem": "querenar",
    "querenasses": "querenar",
    "querenaste": "querenar",
    "querenastes": "querenar",
    "querenava": "querenar",
    "querenavam": "querenar",
    "querenavas": "querenar",
    "querencia": "querenciar",
    "querenciada": "querenciar",
    "querenciadas": "querenciar",
    "querenciado": "querenciar",
    "querenciados": "querenciar",
    "querenciai": "querenciar",
    "querenciais": "querenciar",
    "querenciam": "querenciar",
    "querenciamo": "querenciar",
    "querenciamos": "querenciar",
    "querenciando": "querenciar",
    "querenciara": "querenciar",
    "querenciaram": "querenciar",
    "querenciaras": "querenciar",
    "querenciarde": "querenciar",
    "querenciardes": "querenciar",
    "querenciare": "querenciar",
    "querenciarei": "querenciar",
    "querenciareis": "querenciar",
    "querenciarem": "querenciar",
    "querenciaremos": "querenciar",
    "querenciares": "querenciar",
    "querenciaria": "querenciar",
    "querenciariam": "querenciar",
    "querenciarias": "querenciar",
    "querenciarmo": "querenciar",
    "querenciarmos": "querenciar",
    "querenciará": "querenciar",
    "querenciarás": "querenciar",
    "querenciarão": "querenciar",
    "querenciaríamos": "querenciar",
    "querenciaríeis": "querenciar",
    "querencias": "querenciar",
    "querenciasse": "querenciar",
    "querenciassem": "querenciar",
    "querenciasses": "querenciar",
    "querenciaste": "querenciar",
    "querenciastes": "querenciar",
    "querenciava": "querenciar",
    "querenciavam": "querenciar",
    "querenciavas": "querenciar",
    "querencie": "querenciar",
    "querenciei": "querenciar",
    "querencieis": "querenciar",
    "querenciem": "querenciar",
    "querenciemo": "querenciar",
    "querenciemos": "querenciar",
    "querencies": "querenciar",
    "querencio": "querenciar",
    "querenciou": "querenciar",
    "querenciá": "querenciar",
    "querenciámo": "querenciar",
    "querenciámos": "querenciar",
    "querenciáramo": "querenciar",
    "querenciáramos": "querenciar",
    "querenciárei": "querenciar",
    "querenciáreis": "querenciar",
    "querenciásseis": "querenciar",
    "querenciássemos": "querenciar",
    "querenciávamo": "querenciar",
    "querenciávamos": "querenciar",
    "querenciávei": "querenciar",
    "querenciáveis": "querenciar",
    "querendo": "querer",
    "querene": "querenar",
    "querenei": "querenar",
    "quereneis": "querenar",
    "querenem": "querenar",
    "querenemo": "querenar",
    "querenemos": "querenar",
    "querenes": "querenar",
    "quereno": "querenar",
    "querenou": "querenar",
    "querentes": "querente",
    "querená": "querenar",
    "querenámo": "querenar",
    "querenámos": "querenar",
    "querenáramo": "querenar",
    "querenáramos": "querenar",
    "querenárei": "querenar",
    "querenáreis": "querenar",
    "querenásseis": "querenar",
    "querenássemos": "querenar",
    "querenávamo": "querenar",
    "querenávamos": "querenar",
    "querenávei": "querenar",
    "querenáveis": "querenar",
    "querenças": "querença",
    "querençosa": "querençoso",
    "querençosas": "querençoso",
    "querençosos": "querençoso",
    "quererde": "querer",
    "quererdes": "querer",
    "querere": "querer",
    "quererei": "querer",
    "querereis": "querer",
    "quererem": "querer",
    "quereremos": "querer",
    "quereres": "querer",
    "quereria": "querer",
    "quereriam": "querer",
    "quererias": "querer",
    "querermo": "querer",
    "querermos": "querer",
    "quererá": "querer",
    "quererás": "querer",
    "quererão": "querer",
    "quereríamos": "querer",
    "quereríeis": "querer",
    "queres": "querer",
    "queria": "querer",
    "queriam": "querer",
    "querias": "querer",
    "querida": "querido",
    "queridas": "querido",
    "queridazinha": "querido",
    "queridazinhas": "querido",
    "queridazita": "querido",
    "queridazitas": "querido",
    "queridinha": "querido",
    "queridinhas": "querido",
    "queridinho": "querido",
    "queridinhos": "querido",
    "queridita": "querido",
    "queriditas": "querido",
    "queridito": "querido",
    "queriditos": "querido",
    "querido": "querer",
    "queridos": "querido",
    "queridozinho": "querido",
    "queridozinhos": "querido",
    "queridozito": "querido",
    "queridozitos": "querido",
    "queridíssima": "querido",
    "queridíssimas": "querido",
    "queridíssimo": "querido",
    "queridíssimos": "querido",
    "queridões": "queridão",
    "quermesites": "quermesite",
    "quermesses": "quermesse",
    "quermesídeos": "quermesídeo",
    "quermésidas": "quermésida",
    "quernites": "quernite",
    "quero": "querer",
    "querosenes": "querosene",
    "querubins": "querubim",
    "querubínica": "querubínico",
    "querubínicas": "querubínico",
    "querubínicos": "querubínico",
    "querê": "querer",
    "querências": "querência",
    "queríamo": "querer",
    "queríamos": "querer",
    "queríei": "querer",
    "queríeis": "querer",
    "quesitos": "quesito",
    "questiona": "questionar",
    "questionabilidades": "questionabilidade",
    "questionada": "questionar",
    "questionadas": "questionar",
    "questionado": "questionar",
    "questionadora": "questionador",
    "questionadoras": "questionador",
    "questionadores": "questionador",
    "questionados": "questionar",
    "questionai": "questionar",
    "questionais": "questionar",
    "questionam": "questionar",
    "questionamentos": "questionamento",
    "questionamo": "questionar",
    "questionamos": "questionar",
    "questionando": "questionar",
    "questionara": "questionar",
    "questionaram": "questionar",
    "questionaras": "questionar",
    "questionarde": "questionar",
    "questionardes": "questionar",
    "questionare": "questionar",
    "questionarei": "questionar",
    "questionareis": "questionar",
    "questionarem": "questionar",
    "questionaremos": "questionar",
    "questionares": "questionar",
    "questionaria": "questionar",
    "questionariam": "questionar",
    "questionarias": "questionar",
    "questionarmo": "questionar",
    "questionarmos": "questionar",
    "questionará": "questionar",
    "questionarás": "questionar",
    "questionarão": "questionar",
    "questionaríamos": "questionar",
    "questionaríeis": "questionar",
    "questionas": "questionar",
    "questionasse": "questionar",
    "questionassem": "questionar",
    "questionasses": "questionar",
    "questionaste": "questionar",
    "questionastes": "questionar",
    "questionava": "questionar",
    "questionavam": "questionar",
    "questionavas": "questionar",
    "questione": "questionar",
    "questionei": "questionar",
    "questioneis": "questionar",
    "questionem": "questionar",
    "questionemo": "questionar",
    "questionemos": "questionar",
    "questiones": "questionar",
    "questiono": "questionar",
    "questionou": "questionar",
    "questioná": "questionar",
    "questionámo": "questionar",
    "questionámos": "questionar",
    "questionáramo": "questionar",
    "questionáramos": "questionar",
    "questionárei": "questionar",
    "questionáreis": "questionar",
    "questionários": "questionário",
    "questionásseis": "questionar",
    "questionássemos": "questionar",
    "questionávamo": "questionar",
    "questionávamos": "questionar",
    "questionávei": "questionar",
    "questionáveis": "questionável",
    "questiúnculas": "questiúncula",
    "questorada": "questorado",
    "questoradas": "questorado",
    "questorados": "questorado",
    "questores": "questor",
    "questuosa": "questuoso",
    "questuosas": "questuoso",
    "questuosos": "questuoso",
    "questuras": "questura",
    "questuária": "questuário",
    "questuárias": "questuário",
    "questuários": "questuário",
    "questória": "questório",
    "questórias": "questório",
    "questórios": "questório",
    "questões": "questão",
    "quetzais": "quetzal",
    "quetçais": "quetçal",
    "quetígera": "quetígero",
    "quetígeras": "quetígero",
    "quetígeros": "quetígero",
    "quetópodes": "quetópode",
    "queveis": "quevel",
    "quezas": "queza",
    "quezila": "quezilar",
    "quezilada": "quezilar",
    "queziladas": "quezilar",
    "quezilado": "quezilar",
    "quezilados": "quezilar",
    "quezilai": "quezilar",
    "quezilais": "quezilar",
    "quezilam": "quezilar",
    "quezilamo": "quezilar",
    "quezilamos": "quezilar",
    "quezilando": "quezilar",
    "quezilara": "quezilar",
    "quezilaram": "quezilar",
    "quezilaras": "quezilar",
    "quezilarde": "quezilar",
    "quezilardes": "quezilar",
    "quezilare": "quezilar",
    "quezilarei": "quezilar",
    "quezilareis": "quezilar",
    "quezilarem": "quezilar",
    "quezilaremos": "quezilar",
    "quezilares": "quezilar",
    "quezilaria": "quezilar",
    "quezilariam": "quezilar",
    "quezilarias": "quezilar",
    "quezilarmo": "quezilar",
    "quezilarmos": "quezilar",
    "quezilará": "quezilar",
    "quezilarás": "quezilar",
    "quezilarão": "quezilar",
    "quezilaríamos": "quezilar",
    "quezilaríeis": "quezilar",
    "quezilas": "quezilar",
    "quezilasse": "quezilar",
    "quezilassem": "quezilar",
    "quezilasses": "quezilar",
    "quezilaste": "quezilar",
    "quezilastes": "quezilar",
    "quezilava": "quezilar",
    "quezilavam": "quezilar",
    "quezilavas": "quezilar",
    "quezile": "quezilar",
    "quezilei": "quezilar",
    "quezileis": "quezilar",
    "quezilem": "quezilar",
    "quezilemo": "quezilar",
    "quezilemos": "quezilar",
    "quezilenta": "quezilento",
    "quezilentas": "quezilento",
    "quezilentos": "quezilento",
    "queziles": "quezilar",
    "quezilo": "quezilar",
    "quezilou": "quezilar",
    "quezilá": "quezilar",
    "quezilámo": "quezilar",
    "quezilámos": "quezilar",
    "queziláramo": "quezilar",
    "queziláramos": "quezilar",
    "quezilárei": "quezilar",
    "queziláreis": "quezilar",
    "quezilásseis": "quezilar",
    "quezilássemos": "quezilar",
    "quezilávamo": "quezilar",
    "quezilávamos": "quezilar",
    "quezilávei": "quezilar",
    "queziláveis": "quezilar",
    "quezílias": "quezília",
    "quiabeiros": "quiabeiro",
    "quiabos": "quiabo",
    "quiasmas": "quiasma",
    "quiasmos": "quiasmo",
    "quiastros": "quiastro",
    "quiastólitos": "quiastólito",
    "quiatolites": "quiatolite",
    "quibanda": "quibandar",
    "quibandada": "quibandar",
    "quibandadas": "quibandar",
    "quibandado": "quibandar",
    "quibandados": "quibandar",
    "quibandai": "quibandar",
    "quibandais": "quibandar",
    "quibandam": "quibandar",
    "quibandamo": "quibandar",
    "quibandamos": "quibandar",
    "quibandando": "quibandar",
    "quibandara": "quibandar",
    "quibandaram": "quibandar",
    "quibandaras": "quibandar",
    "quibandarde": "quibandar",
    "quibandardes": "quibandar",
    "quibandare": "quibandar",
    "quibandarei": "quibandar",
    "quibandareis": "quibandar",
    "quibandarem": "quibandar",
    "quibandaremos": "quibandar",
    "quibandares": "quibandar",
    "quibandaria": "quibandar",
    "quibandariam": "quibandar",
    "quibandarias": "quibandar",
    "quibandarmo": "quibandar",
    "quibandarmos": "quibandar",
    "quibandará": "quibandar",
    "quibandarás": "quibandar",
    "quibandarão": "quibandar",
    "quibandaríamos": "quibandar",
    "quibandaríeis": "quibandar",
    "quibandas": "quibandar",
    "quibandasse": "quibandar",
    "quibandassem": "quibandar",
    "quibandasses": "quibandar",
    "quibandaste": "quibandar",
    "quibandastes": "quibandar",
    "quibandava": "quibandar",
    "quibandavam": "quibandar",
    "quibandavas": "quibandar",
    "quibande": "quibandar",
    "quibandei": "quibandar",
    "quibandeis": "quibandar",
    "quibandem": "quibandar",
    "quibandemo": "quibandar",
    "quibandemos": "quibandar",
    "quibandes": "quibandar",
    "quibando": "quibandar",
    "quibandos": "quibando",
    "quibandou": "quibandar",
    "quibandá": "quibandar",
    "quibandámo": "quibandar",
    "quibandámos": "quibandar",
    "quibandáramo": "quibandar",
    "quibandáramos": "quibandar",
    "quibandárei": "quibandar",
    "quibandáreis": "quibandar",
    "quibandásseis": "quibandar",
    "quibandássemos": "quibandar",
    "quibandávamo": "quibandar",
    "quibandávamos": "quibandar",
    "quibandávei": "quibandar",
    "quibandáveis": "quibandar",
    "quibebes": "quibebe",
    "quibucas": "quibuca",
    "quibumbos": "quibumbo",
    "quiches": "quiche",
    "quicos": "quico",
    "quididades": "quididade",
    "quididativa": "quididativo",
    "quididativas": "quididativo",
    "quididativos": "quididativo",
    "quiescentes": "quiescente",
    "quieta": "quieto",
    "quietada": "quietar",
    "quietadas": "quietar",
    "quietado": "quietar",
    "quietados": "quietar",
    "quietai": "quietar",
    "quietais": "quietar",
    "quietam": "quietar",
    "quietamo": "quietar",
    "quietamos": "quietar",
    "quietando": "quietar",
    "quietara": "quietar",
    "quietaram": "quietar",
    "quietaras": "quietar",
    "quietarde": "quietar",
    "quietardes": "quietar",
    "quietare": "quietar",
    "quietarei": "quietar",
    "quietareis": "quietar",
    "quietarem": "quietar",
    "quietaremos": "quietar",
    "quietares": "quietar",
    "quietaria": "quietar",
    "quietariam": "quietar",
    "quietarias": "quietar",
    "quietarmo": "quietar",
    "quietarmos": "quietar",
    "quietará": "quietar",
    "quietarás": "quietar",
    "quietarão": "quietar",
    "quietaríamos": "quietar",
    "quietaríeis": "quietar",
    "quietas": "quieto",
    "quietasse": "quietar",
    "quietassem": "quietar",
    "quietasses": "quietar",
    "quietaste": "quietar",
    "quietastes": "quietar",
    "quietava": "quietar",
    "quietavam": "quietar",
    "quietavas": "quietar",
    "quietazinha": "quieto",
    "quietazinhas": "quieto",
    "quietazita": "quieto",
    "quietazitas": "quieto",
    "quietações": "quietação",
    "quiete": "quietar",
    "quietei": "quietar",
    "quieteis": "quietar",
    "quietem": "quietar",
    "quietemo": "quietar",
    "quietemos": "quietar",
    "quietes": "quietar",
    "quietinha": "quieto",
    "quietinhas": "quieto",
    "quietinho": "quieto",
    "quietinhos": "quieto",
    "quietismos": "quietismo",
    "quietistas": "quietista",
    "quietita": "quieto",
    "quietitas": "quieto",
    "quietito": "quieto",
    "quietitos": "quieto",
    "quieto": "quietar",
    "quietos": "quieto",
    "quietou": "quietar",
    "quietozinho": "quieto",
    "quietozinhos": "quieto",
    "quietozito": "quieto",
    "quietozitos": "quieto",
    "quietudes": "quietude",
    "quietá": "quietar",
    "quietámo": "quietar",
    "quietámos": "quietar",
    "quietáramo": "quietar",
    "quietáramos": "quietar",
    "quietárei": "quietar",
    "quietáreis": "quietar",
    "quietásseis": "quietar",
    "quietássemos": "quietar",
    "quietávamo": "quietar",
    "quietávamos": "quietar",
    "quietávei": "quietar",
    "quietáveis": "quietar",
    "quietíssima": "quieto",
    "quietíssimas": "quieto",
    "quietíssimo": "quieto",
    "quietíssimos": "quieto",
    "quigombós": "quigombó",
    "quilata": "quilatar",
    "quilatada": "quilatar",
    "quilatadas": "quilatar",
    "quilatado": "quilatar",
    "quilatadora": "quilatador",
    "quilatadoras": "quilatador",
    "quilatadores": "quilatador",
    "quilatados": "quilatar",
    "quilatai": "quilatar",
    "quilatais": "quilatar",
    "quilatam": "quilatar",
    "quilatamo": "quilatar",
    "quilatamos": "quilatar",
    "quilatando": "quilatar",
    "quilatara": "quilatar",
    "quilataram": "quilatar",
    "quilataras": "quilatar",
    "quilatarde": "quilatar",
    "quilatardes": "quilatar",
    "quilatare": "quilatar",
    "quilatarei": "quilatar",
    "quilatareis": "quilatar",
    "quilatarem": "quilatar",
    "quilataremos": "quilatar",
    "quilatares": "quilatar",
    "quilataria": "quilatar",
    "quilatariam": "quilatar",
    "quilatarias": "quilatar",
    "quilatarmo": "quilatar",
    "quilatarmos": "quilatar",
    "quilatará": "quilatar",
    "quilatarás": "quilatar",
    "quilatarão": "quilatar",
    "quilataríamos": "quilatar",
    "quilataríeis": "quilatar",
    "quilatas": "quilatar",
    "quilatasse": "quilatar",
    "quilatassem": "quilatar",
    "quilatasses": "quilatar",
    "quilataste": "quilatar",
    "quilatastes": "quilatar",
    "quilatava": "quilatar",
    "quilatavam": "quilatar",
    "quilatavas": "quilatar",
    "quilatações": "quilatação",
    "quilate": "quilatar",
    "quilatei": "quilatar",
    "quilateiras": "quilateira",
    "quilateis": "quilatar",
    "quilatem": "quilatar",
    "quilatemo": "quilatar",
    "quilatemos": "quilatar",
    "quilates": "quilate",
    "quilato": "quilatar",
    "quilatou": "quilatar",
    "quilatá": "quilatar",
    "quilatámo": "quilatar",
    "quilatámos": "quilatar",
    "quilatáramo": "quilatar",
    "quilatáramos": "quilatar",
    "quilatárei": "quilatar",
    "quilatáreis": "quilatar",
    "quilatásseis": "quilatar",
    "quilatássemos": "quilatar",
    "quilatávamo": "quilatar",
    "quilatávamos": "quilatar",
    "quilatávei": "quilatar",
    "quilatáveis": "quilatar",
    "quilha": "quilhar",
    "quilhada": "quilhar",
    "quilhadas": "quilhar",
    "quilhado": "quilhar",
    "quilhados": "quilhar",
    "quilhai": "quilhar",
    "quilhais": "quilhar",
    "quilham": "quilhar",
    "quilhamo": "quilhar",
    "quilhamos": "quilhar",
    "quilhando": "quilhar",
    "quilhara": "quilhar",
    "quilharam": "quilhar",
    "quilharas": "quilhar",
    "quilharde": "quilhar",
    "quilhardes": "quilhar",
    "quilhare": "quilhar",
    "quilharei": "quilhar",
    "quilhareis": "quilhar",
    "quilharem": "quilhar",
    "quilharemos": "quilhar",
    "quilhares": "quilhar",
    "quilharia": "quilhar",
    "quilhariam": "quilhar",
    "quilharias": "quilhar",
    "quilharmo": "quilhar",
    "quilharmos": "quilhar",
    "quilhará": "quilhar",
    "quilharás": "quilhar",
    "quilharão": "quilhar",
    "quilharíamos": "quilhar",
    "quilharíeis": "quilhar",
    "quilhas": "quilhar",
    "quilhasse": "quilhar",
    "quilhassem": "quilhar",
    "quilhasses": "quilhar",
    "quilhaste": "quilhar",
    "quilhastes": "quilhar",
    "quilhava": "quilhar",
    "quilhavam": "quilhar",
    "quilhavas": "quilhar",
    "quilhe": "quilhar",
    "quilhei": "quilhar",
    "quilheis": "quilhar",
    "quilhem": "quilhar",
    "quilhemo": "quilhar",
    "quilhemos": "quilhar",
    "quilhes": "quilhar",
    "quilho": "quilhar",
    "quilhou": "quilhar",
    "quilhá": "quilhar",
    "quilhámo": "quilhar",
    "quilhámos": "quilhar",
    "quilháramo": "quilhar",
    "quilháramos": "quilhar",
    "quilhárei": "quilhar",
    "quilháreis": "quilhar",
    "quilhásseis": "quilhar",
    "quilhássemos": "quilhar",
    "quilhávamo": "quilhar",
    "quilhávamos": "quilhar",
    "quilhávei": "quilhar",
    "quilháveis": "quilhar",
    "quiliares": "quiliare",
    "quiliarquias": "quiliarquia",
    "quilifica": "quilificar",
    "quilificada": "quilificar",
    "quilificadas": "quilificar",
    "quilificado": "quilificar",
    "quilificados": "quilificar",
    "quilificai": "quilificar",
    "quilificais": "quilificar",
    "quilificam": "quilificar",
    "quilificamo": "quilificar",
    "quilificamos": "quilificar",
    "quilificando": "quilificar",
    "quilificara": "quilificar",
    "quilificaram": "quilificar",
    "quilificaras": "quilificar",
    "quilificarde": "quilificar",
    "quilificardes": "quilificar",
    "quilificare": "quilificar",
    "quilificarei": "quilificar",
    "quilificareis": "quilificar",
    "quilificarem": "quilificar",
    "quilificaremos": "quilificar",
    "quilificares": "quilificar",
    "quilificaria": "quilificar",
    "quilificariam": "quilificar",
    "quilificarias": "quilificar",
    "quilificarmo": "quilificar",
    "quilificarmos": "quilificar",
    "quilificará": "quilificar",
    "quilificarás": "quilificar",
    "quilificarão": "quilificar",
    "quilificaríamos": "quilificar",
    "quilificaríeis": "quilificar",
    "quilificas": "quilificar",
    "quilificasse": "quilificar",
    "quilificassem": "quilificar",
    "quilificasses": "quilificar",
    "quilificaste": "quilificar",
    "quilificastes": "quilificar",
    "quilificativa": "quilificativo",
    "quilificativas": "quilificativo",
    "quilificativos": "quilificativo",
    "quilificava": "quilificar",
    "quilificavam": "quilificar",
    "quilificavas": "quilificar",
    "quilificações": "quilificação",
    "quilifico": "quilificar",
    "quilificou": "quilificar",
    "quilificá": "quilificar",
    "quilificámo": "quilificar",
    "quilificámos": "quilificar",
    "quilificáramo": "quilificar",
    "quilificáramos": "quilificar",
    "quilificárei": "quilificar",
    "quilificáreis": "quilificar",
    "quilificásseis": "quilificar",
    "quilificássemos": "quilificar",
    "quilificávamo": "quilificar",
    "quilificávamos": "quilificar",
    "quilificávei": "quilificar",
    "quilificáveis": "quilificar",
    "quilifique": "quilificar",
    "quilifiquei": "quilificar",
    "quilifiqueis": "quilificar",
    "quilifiquem": "quilificar",
    "quilifiquemo": "quilificar",
    "quilifiquemos": "quilificar",
    "quilifiques": "quilificar",
    "quilinho": "quilo",
    "quilinhos": "quilo",
    "quilites": "quilite",
    "quilito": "quilo",
    "quilitos": "quilo",
    "quilocalorias": "quilocaloria",
    "quilociclos": "quilociclo",
    "quilodieresias": "quilodieresia",
    "quilofagias": "quilofagia",
    "quilogramas": "quilograma",
    "quilogrâmetros": "quilogrâmetro",
    "quilohertzes": "quilohertz",
    "quilojoules": "quilojoule",
    "quilolitros": "quilolitro",
    "quilombos": "quilombo",
    "quilometra": "quilometrar",
    "quilometrada": "quilometrar",
    "quilometradas": "quilometrar",
    "quilometrado": "quilometrar",
    "quilometrados": "quilometrar",
    "quilometragens": "quilometragem",
    "quilometrai": "quilometrar",
    "quilometrais": "quilometrar",
    "quilometram": "quilometrar",
    "quilometramo": "quilometrar",
    "quilometramos": "quilometrar",
    "quilometrando": "quilometrar",
    "quilometrara": "quilometrar",
    "quilometraram": "quilometrar",
    "quilometraras": "quilometrar",
    "quilometrarde": "quilometrar",
    "quilometrardes": "quilometrar",
    "quilometrare": "quilometrar",
    "quilometrarei": "quilometrar",
    "quilometrareis": "quilometrar",
    "quilometrarem": "quilometrar",
    "quilometraremos": "quilometrar",
    "quilometrares": "quilometrar",
    "quilometraria": "quilometrar",
    "quilometrariam": "quilometrar",
    "quilometrarias": "quilometrar",
    "quilometrarmo": "quilometrar",
    "quilometrarmos": "quilometrar",
    "quilometrará": "quilometrar",
    "quilometrarás": "quilometrar",
    "quilometrarão": "quilometrar",
    "quilometraríamos": "quilometrar",
    "quilometraríeis": "quilometrar",
    "quilometras": "quilometrar",
    "quilometrasse": "quilometrar",
    "quilometrassem": "quilometrar",
    "quilometrasses": "quilometrar",
    "quilometraste": "quilometrar",
    "quilometrastes": "quilometrar",
    "quilometrava": "quilometrar",
    "quilometravam": "quilometrar",
    "quilometravas": "quilometrar",
    "quilometre": "quilometrar",
    "quilometrei": "quilometrar",
    "quilometreis": "quilometrar",
    "quilometrem": "quilometrar",
    "quilometremo": "quilometrar",
    "quilometremos": "quilometrar",
    "quilometres": "quilometrar",
    "quilometro": "quilometrar",
    "quilometrou": "quilometrar",
    "quilometrá": "quilometrar",
    "quilometrámo": "quilometrar",
    "quilometrámos": "quilometrar",
    "quilometráramo": "quilometrar",
    "quilometráramos": "quilometrar",
    "quilometrárei": "quilometrar",
    "quilometráreis": "quilometrar",
    "quilometrásseis": "quilometrar",
    "quilometrássemos": "quilometrar",
    "quilometrávamo": "quilometrar",
    "quilometrávamos": "quilometrar",
    "quilometrávei": "quilometrar",
    "quilometráveis": "quilometrável",
    "quilométrica": "quilométrico",
    "quilométricas": "quilométrico",
    "quilométricos": "quilométrico",
    "quiloplastias": "quiloplastia",
    "quiloplástica": "quiloplástico",
    "quiloplásticas": "quiloplástico",
    "quiloplásticos": "quiloplástico",
    "quilos": "quilo",
    "quiloses": "quilose",
    "quilotoneladas": "quilotonelada",
    "quilovoltes": "quilovolt",
    "quilovátios": "quilovátio",
    "quilowatts": "quilowatt",
    "quilozinho": "quilo",
    "quilozinhos": "quilo",
    "quilozito": "quilo",
    "quilozitos": "quilo",
    "quiluanzas": "quiluanza",
    "quilíadas": "quilíada",
    "quilíades": "quilíade",
    "quilífera": "quilífero",
    "quilíferas": "quilífero",
    "quilíferos": "quilífero",
    "quilógnata": "quilógnato",
    "quilógnatas": "quilógnato",
    "quilógnatos": "quilógnato",
    "quilómetros": "quilómetro",
    "quilópodes": "quilópode",
    "quilúbios": "quilúbio",
    "quilúrias": "quilúria",
    "quimalancas": "quimalanca",
    "quimanas": "quimana",
    "quimangas": "quimanga",
    "quimangatas": "quimangata",
    "quimbembeques": "quimbembeque",
    "quimbembes": "quimbembe",
    "quimbembés": "quimbembé",
    "quimbetes": "quimbete",
    "quimbimbes": "quimbimbe",
    "quimbombos": "quimbombo",
    "quimbundos": "quimbundo",
    "quimeras": "quimera",
    "quimeristas": "quimerista",
    "quimeriza": "quimerizar",
    "quimerizada": "quimerizar",
    "quimerizadas": "quimerizar",
    "quimerizado": "quimerizar",
    "quimerizados": "quimerizar",
    "quimerizai": "quimerizar",
    "quimerizais": "quimerizar",
    "quimerizam": "quimerizar",
    "quimerizamo": "quimerizar",
    "quimerizamos": "quimerizar",
    "quimerizando": "quimerizar",
    "quimerizara": "quimerizar",
    "quimerizaram": "quimerizar",
    "quimerizaras": "quimerizar",
    "quimerizardes": "quimerizar",
    "quimerizarei": "quimerizar",
    "quimerizareis": "quimerizar",
    "quimerizarem": "quimerizar",
    "quimerizaremos": "quimerizar",
    "quimerizares": "quimerizar",
    "quimerizaria": "quimerizar",
    "quimerizariam": "quimerizar",
    "quimerizarias": "quimerizar",
    "quimerizarmo": "quimerizar",
    "quimerizarmos": "quimerizar",
    "quimerizará": "quimerizar",
    "quimerizarás": "quimerizar",
    "quimerizarão": "quimerizar",
    "quimerizaríamos": "quimerizar",
    "quimerizaríeis": "quimerizar",
    "quimerizas": "quimerizar",
    "quimerizasse": "quimerizar",
    "quimerizassem": "quimerizar",
    "quimerizasses": "quimerizar",
    "quimerizaste": "quimerizar",
    "quimerizastes": "quimerizar",
    "quimerizava": "quimerizar",
    "quimerizavam": "quimerizar",
    "quimerizavas": "quimerizar",
    "quimerize": "quimerizar",
    "quimerizei": "quimerizar",
    "quimerizeis": "quimerizar",
    "quimerizem": "quimerizar",
    "quimerizemo": "quimerizar",
    "quimerizemos": "quimerizar",
    "quimerizes": "quimerizar",
    "quimerizo": "quimerizar",
    "quimerizou": "quimerizar",
    "quimerizámo": "quimerizar",
    "quimerizámos": "quimerizar",
    "quimerizáramo": "quimerizar",
    "quimerizáramos": "quimerizar",
    "quimerizáreis": "quimerizar",
    "quimerizásseis": "quimerizar",
    "quimerizássemos": "quimerizar",
    "quimerizávamo": "quimerizar",
    "quimerizávamos": "quimerizar",
    "quimerizáveis": "quimerizar",
    "quimerídeos": "quimerídeo",
    "quimiatrias": "quimiatria",
    "quimifica": "quimificar",
    "quimificada": "quimificar",
    "quimificadas": "quimificar",
    "quimificado": "quimificar",
    "quimificados": "quimificar",
    "quimificai": "quimificar",
    "quimificais": "quimificar",
    "quimificam": "quimificar",
    "quimificamo": "quimificar",
    "quimificamos": "quimificar",
    "quimificando": "quimificar",
    "quimificara": "quimificar",
    "quimificaram": "quimificar",
    "quimificaras": "quimificar",
    "quimificarde": "quimificar",
    "quimificardes": "quimificar",
    "quimificare": "quimificar",
    "quimificarei": "quimificar",
    "quimificareis": "quimificar",
    "quimificarem": "quimificar",
    "quimificaremos": "quimificar",
    "quimificares": "quimificar",
    "quimificaria": "quimificar",
    "quimificariam": "quimificar",
    "quimificarias": "quimificar",
    "quimificarmo": "quimificar",
    "quimificarmos": "quimificar",
    "quimificará": "quimificar",
    "quimificarás": "quimificar",
    "quimificarão": "quimificar",
    "quimificaríamos": "quimificar",
    "quimificaríeis": "quimificar",
    "quimificas": "quimificar",
    "quimificasse": "quimificar",
    "quimificassem": "quimificar",
    "quimificasses": "quimificar",
    "quimificaste": "quimificar",
    "quimificastes": "quimificar",
    "quimificava": "quimificar",
    "quimificavam": "quimificar",
    "quimificavas": "quimificar",
    "quimificações": "quimificação",
    "quimifico": "quimificar",
    "quimificou": "quimificar",
    "quimificá": "quimificar",
    "quimificámo": "quimificar",
    "quimificámos": "quimificar",
    "quimificáramo": "quimificar",
    "quimificáramos": "quimificar",
    "quimificárei": "quimificar",
    "quimificáreis": "quimificar",
    "quimificásseis": "quimificar",
    "quimificássemos": "quimificar",
    "quimificávamo": "quimificar",
    "quimificávamos": "quimificar",
    "quimificávei": "quimificar",
    "quimificáveis": "quimificar",
    "quimifique": "quimificar",
    "quimifiquei": "quimificar",
    "quimifiqueis": "quimificar",
    "quimifiquem": "quimificar",
    "quimifiquemo": "quimificar",
    "quimifiquemos": "quimificar",
    "quimifiques": "quimificar",
    "quimiossínteses": "quimiossíntese",
    "quimiotactismos": "quimiotactismo",
    "quimioterapias": "quimioterapia",
    "quimiotropismos": "quimiotropismo",
    "quimismos": "quimismo",
    "quimitipias": "quimitipia",
    "quimonos": "quimono",
    "quimos": "quimo",
    "quimosinas": "quimosina",
    "quimântica": "quimântico",
    "quimânticas": "quimântico",
    "quimânticos": "quimântico",
    "quimérica": "quimérico",
    "quiméricas": "quimérico",
    "quiméricos": "quimérico",
    "quiméridas": "quimérida",
    "quimés": "quimé",
    "quimões": "quimão",
    "quina": "quinar",
    "quinada": "quinar",
    "quinadas": "quinar",
    "quinadazinha": "quinado",
    "quinadazinhas": "quinado",
    "quinadazita": "quinado",
    "quinadazitas": "quinado",
    "quinadinha": "quinado",
    "quinadinhas": "quinado",
    "quinadinho": "quinado",
    "quinadinhos": "quinado",
    "quinadita": "quinado",
    "quinaditas": "quinado",
    "quinadito": "quinado",
    "quinaditos": "quinado",
    "quinado": "quinar",
    "quinados": "quinar",
    "quinadozinho": "quinado",
    "quinadozinhos": "quinado",
    "quinadozito": "quinado",
    "quinadozitos": "quinado",
    "quinadíssima": "quinado",
    "quinadíssimas": "quinado",
    "quinadíssimo": "quinado",
    "quinadíssimos": "quinado",
    "quinai": "quinar",
    "quinais": "quinar",
    "quinam": "quinar",
    "quinamo": "quinar",
    "quinamos": "quinar",
    "quinando": "quinar",
    "quinantes": "quinante",
    "quinaquinas": "quinaquina",
    "quinara": "quinar",
    "quinaram": "quinar",
    "quinaras": "quinar",
    "quinarde": "quinar",
    "quinardes": "quinar",
    "quinare": "quinar",
    "quinarei": "quinar",
    "quinareis": "quinar",
    "quinarem": "quinar",
    "quinaremos": "quinar",
    "quinares": "quinar",
    "quinaria": "quinar",
    "quinariam": "quinar",
    "quinarias": "quinar",
    "quinarmo": "quinar",
    "quinarmos": "quinar",
    "quinará": "quinar",
    "quinarás": "quinar",
    "quinarão": "quinar",
    "quinaríamos": "quinar",
    "quinaríeis": "quinar",
    "quinas": "quinar",
    "quinasse": "quinar",
    "quinassem": "quinar",
    "quinasses": "quinar",
    "quinaste": "quinar",
    "quinastes": "quinar",
    "quinaus": "quinau",
    "quinava": "quinar",
    "quinavam": "quinar",
    "quinavas": "quinar",
    "quincha": "quinchar",
    "quinchada": "quinchar",
    "quinchadas": "quinchar",
    "quinchado": "quinchar",
    "quinchados": "quinchar",
    "quinchai": "quinchar",
    "quinchais": "quinchar",
    "quincham": "quinchar",
    "quinchamo": "quinchar",
    "quinchamos": "quinchar",
    "quinchando": "quinchar",
    "quinchara": "quinchar",
    "quincharam": "quinchar",
    "quincharas": "quinchar",
    "quincharde": "quinchar",
    "quinchardes": "quinchar",
    "quinchare": "quinchar",
    "quincharei": "quinchar",
    "quinchareis": "quinchar",
    "quincharem": "quinchar",
    "quincharemos": "quinchar",
    "quinchares": "quinchar",
    "quincharia": "quinchar",
    "quinchariam": "quinchar",
    "quincharias": "quinchar",
    "quincharmo": "quinchar",
    "quincharmos": "quinchar",
    "quinchará": "quinchar",
    "quincharás": "quinchar",
    "quincharão": "quinchar",
    "quincharíamos": "quinchar",
    "quincharíeis": "quinchar",
    "quinchas": "quinchar",
    "quinchasse": "quinchar",
    "quinchassem": "quinchar",
    "quinchasses": "quinchar",
    "quinchaste": "quinchar",
    "quinchastes": "quinchar",
    "quinchava": "quinchar",
    "quinchavam": "quinchar",
    "quinchavas": "quinchar",
    "quinche": "quinchar",
    "quinchei": "quinchar",
    "quincheis": "quinchar",
    "quinchem": "quinchar",
    "quinchemo": "quinchar",
    "quinchemos": "quinchar",
    "quinches": "quinchar",
    "quincho": "quinchar",
    "quinchorros": "quinchorro",
    "quinchosos": "quinchoso",
    "quinchou": "quinchar",
    "quinchá": "quinchar",
    "quinchámo": "quinchar",
    "quinchámos": "quinchar",
    "quincháramo": "quinchar",
    "quincháramos": "quinchar",
    "quinchárei": "quinchar",
    "quincháreis": "quinchar",
    "quinchásseis": "quinchar",
    "quinchássemos": "quinchar",
    "quinchávamo": "quinchar",
    "quinchávamos": "quinchar",
    "quinchávei": "quinchar",
    "quincháveis": "quinchar",
    "quincunces": "quincunce",
    "quincunciais": "quincuncial",
    "quincálogos": "quincálogo",
    "quincôncios": "quincôncio",
    "quindecenvirados": "quindecenvirado",
    "quindecenvirais": "quindecenviral",
    "quindecenviratos": "quindecenvirato",
    "quindecágonos": "quindecágono",
    "quindecênviros": "quindecênviro",
    "quindins": "quindim",
    "quindénios": "quindénio",
    "quine": "quinar",
    "quinei": "quinar",
    "quineiras": "quineira",
    "quineis": "quinar",
    "quinem": "quinar",
    "quinemo": "quinar",
    "quinemos": "quinar",
    "quines": "quinar",
    "quinestésica": "quinestésico",
    "quinestésicas": "quinestésico",
    "quinestésicos": "quinestésico",
    "quingentários": "quingentário",
    "quingentésima": "quingentésimo",
    "quingentésimas": "quingentésimo",
    "quingentésimos": "quingentésimo",
    "quingostas": "quingosta",
    "quinhentas": "quinhentos",
    "quinhentismos": "quinhentismo",
    "quinhentistas": "quinhentista",
    "quinhentões": "quinhentão",
    "quinhoa": "quinhoar",
    "quinhoada": "quinhoar",
    "quinhoadas": "quinhoar",
    "quinhoado": "quinhoar",
    "quinhoados": "quinhoar",
    "quinhoai": "quinhoar",
    "quinhoais": "quinhoar",
    "quinhoam": "quinhoar",
    "quinhoamo": "quinhoar",
    "quinhoamos": "quinhoar",
    "quinhoando": "quinhoar",
    "quinhoara": "quinhoar",
    "quinhoaram": "quinhoar",
    "quinhoaras": "quinhoar",
    "quinhoarde": "quinhoar",
    "quinhoardes": "quinhoar",
    "quinhoare": "quinhoar",
    "quinhoarei": "quinhoar",
    "quinhoareis": "quinhoar",
    "quinhoarem": "quinhoar",
    "quinhoaremos": "quinhoar",
    "quinhoares": "quinhoar",
    "quinhoaria": "quinhoar",
    "quinhoariam": "quinhoar",
    "quinhoarias": "quinhoar",
    "quinhoarmo": "quinhoar",
    "quinhoarmos": "quinhoar",
    "quinhoará": "quinhoar",
    "quinhoarás": "quinhoar",
    "quinhoarão": "quinhoar",
    "quinhoaríamos": "quinhoar",
    "quinhoaríeis": "quinhoar",
    "quinhoas": "quinhoar",
    "quinhoasse": "quinhoar",
    "quinhoassem": "quinhoar",
    "quinhoasses": "quinhoar",
    "quinhoaste": "quinhoar",
    "quinhoastes": "quinhoar",
    "quinhoava": "quinhoar",
    "quinhoavam": "quinhoar",
    "quinhoavas": "quinhoar",
    "quinhoe": "quinhoar",
    "quinhoei": "quinhoar",
    "quinhoeira": "quinhoeiro",
    "quinhoeiras": "quinhoeiro",
    "quinhoeiros": "quinhoeiro",
    "quinhoeis": "quinhoar",
    "quinhoem": "quinhoar",
    "quinhoemo": "quinhoar",
    "quinhoemos": "quinhoar",
    "quinhoes": "quinhoar",
    "quinhoo": "quinhoar",
    "quinhoou": "quinhoar",
    "quinhoá": "quinhoar",
    "quinhoámo": "quinhoar",
    "quinhoámos": "quinhoar",
    "quinhoáramo": "quinhoar",
    "quinhoáramos": "quinhoar",
    "quinhoárei": "quinhoar",
    "quinhoáreis": "quinhoar",
    "quinhoásseis": "quinhoar",
    "quinhoássemos": "quinhoar",
    "quinhoávamo": "quinhoar",
    "quinhoávamos": "quinhoar",
    "quinhoávei": "quinhoar",
    "quinhoáveis": "quinhoar",
    "quinhões": "quinhão",
    "quinidinas": "quinidina",
    "quininas": "quinina",
    "quininos": "quinino",
    "quinismos": "quinismo",
    "quino": "quinar",
    "quinoleínas": "quinoleína",
    "quinonas": "quinona",
    "quinores": "quinor",
    "quinos": "quino",
    "quinou": "quinar",
    "quinquagenária": "quinquagenário",
    "quinquagenárias": "quinquagenário",
    "quinquagenários": "quinquagenário",
    "quinquagesimais": "quinquagesimal",
    "quinquagésima": "quinquagésimo",
    "quinquagésimas": "quinquagésimo",
    "quinquagésimos": "quinquagésimo",
    "quinqueangulares": "quinqueangular",
    "quinquecapsulares": "quinquecapsular",
    "quinquecelulares": "quinquecelular",
    "quinquedentada": "quinquedentado",
    "quinquedentadas": "quinquedentado",
    "quinquedentados": "quinquedentado",
    "quinquefoliada": "quinquefoliado",
    "quinquefoliadas": "quinquefoliado",
    "quinquefoliados": "quinquefoliado",
    "quinquefólia": "quinquefólio",
    "quinquefólias": "quinquefólio",
    "quinquefólios": "quinquefólio",
    "quinquenais": "quinquenal",
    "quinquenervada": "quinquenervado",
    "quinquenervadas": "quinquenervado",
    "quinquenervados": "quinquenervado",
    "quinquenária": "quinquenário",
    "quinquenárias": "quinquenário",
    "quinquenários": "quinquenário",
    "quinquerremes": "quinquerreme",
    "quinquevalentes": "quinquevalente",
    "quinquevalvares": "quinquevalvar",
    "quinquevalves": "quinquevalve",
    "quinquevalvulares": "quinquevalvular",
    "quinquevirados": "quinquevirado",
    "quinqueviratos": "quinquevirato",
    "quinquilharias": "quinquilharia",
    "quinquilheira": "quinquilheiro",
    "quinquilheiras": "quinquilheiro",
    "quinquilheiros": "quinquilheiro",
    "quinquiláteros": "quinquilátero",
    "quinquinas": "quinquina",
    "quinquiós": "quinquió",
    "quinquénios": "quinquénio",
    "quinquéviros": "quinquéviro",
    "quinquídios": "quinquídio",
    "quinquíduos": "quinquíduo",
    "quinta": "quinto",
    "quintada": "quintar",
    "quintadas": "quintar",
    "quintado": "quintar",
    "quintadora": "quintador",
    "quintadoras": "quintador",
    "quintadores": "quintador",
    "quintados": "quintar",
    "quintai": "quintar",
    "quintais": "quintar",
    "quintaizinhos": "quintal",
    "quintaizitos": "quintal",
    "quintaladas": "quintalada",
    "quintaleira": "quintaleiro",
    "quintaleiras": "quintaleiro",
    "quintaleiros": "quintaleiro",
    "quintalejos": "quintalejo",
    "quintalinho": "quintal",
    "quintalinhos": "quintal",
    "quintalito": "quintal",
    "quintalitos": "quintal",
    "quintalzinho": "quintal",
    "quintalzito": "quintal",
    "quintalórios": "quintalório",
    "quintalões": "quintalão",
    "quintam": "quintar",
    "quintamo": "quintar",
    "quintamos": "quintar",
    "quintana": "quintano",
    "quintanas": "quintano",
    "quintando": "quintar",
    "quintanistas": "quintanista",
    "quintanos": "quintano",
    "quintara": "quintar",
    "quintaram": "quintar",
    "quintaras": "quintar",
    "quintarde": "quintar",
    "quintardes": "quintar",
    "quintare": "quintar",
    "quintarei": "quintar",
    "quintareis": "quintar",
    "quintarem": "quintar",
    "quintaremos": "quintar",
    "quintares": "quintar",
    "quintaria": "quintar",
    "quintariam": "quintar",
    "quintarias": "quintar",
    "quintarmo": "quintar",
    "quintarmos": "quintar",
    "quintarolas": "quintarola",
    "quintará": "quintar",
    "quintarás": "quintar",
    "quintarão": "quintar",
    "quintaríamos": "quintar",
    "quintaríeis": "quintar",
    "quintas": "quinto",
    "quintasse": "quintar",
    "quintassem": "quintar",
    "quintasses": "quintar",
    "quintaste": "quintar",
    "quintastes": "quintar",
    "quintava": "quintar",
    "quintavam": "quintar",
    "quintavas": "quintar",
    "quinte": "quintar",
    "quintei": "quintar",
    "quinteira": "quinteiro",
    "quinteiras": "quinteiro",
    "quinteiros": "quinteiro",
    "quinteis": "quintar",
    "quintem": "quintar",
    "quintemo": "quintar",
    "quintemos": "quintar",
    "quintes": "quintar",
    "quintessências": "quintessência",
    "quintetos": "quinteto",
    "quintifalanges": "quintifalange",
    "quintifalangetas": "quintifalangeta",
    "quintifalanginhas": "quintifalanginha",
    "quintilhas": "quintilha",
    "quintiliana": "quintiliano",
    "quintilianas": "quintiliano",
    "quintilianos": "quintiliano",
    "quintilionésima": "quintilionésimo",
    "quintilionésimas": "quintilionésimo",
    "quintilionésimos": "quintilionésimo",
    "quintiliões": "quintilião",
    "quintinha": "quinta",
    "quintinhas": "quinta",
    "quintis": "quintil",
    "quintisseculares": "quintissecular",
    "quintita": "quinta",
    "quintitas": "quinta",
    "quinto": "quintar",
    "quintos": "quinto",
    "quintou": "quintar",
    "quintupletas": "quintupleta",
    "quintuplica": "quintuplicar",
    "quintuplicada": "quintuplicar",
    "quintuplicadas": "quintuplicar",
    "quintuplicado": "quintuplicar",
    "quintuplicadora": "quintuplicador",
    "quintuplicadoras": "quintuplicador",
    "quintuplicadores": "quintuplicador",
    "quintuplicados": "quintuplicar",
    "quintuplicai": "quintuplicar",
    "quintuplicais": "quintuplicar",
    "quintuplicam": "quintuplicar",
    "quintuplicamo": "quintuplicar",
    "quintuplicamos": "quintuplicar",
    "quintuplicando": "quintuplicar",
    "quintuplicara": "quintuplicar",
    "quintuplicaram": "quintuplicar",
    "quintuplicaras": "quintuplicar",
    "quintuplicarde": "quintuplicar",
    "quintuplicardes": "quintuplicar",
    "quintuplicare": "quintuplicar",
    "quintuplicarei": "quintuplicar",
    "quintuplicareis": "quintuplicar",
    "quintuplicarem": "quintuplicar",
    "quintuplicaremos": "quintuplicar",
    "quintuplicares": "quintuplicar",
    "quintuplicaria": "quintuplicar",
    "quintuplicariam": "quintuplicar",
    "quintuplicarias": "quintuplicar",
    "quintuplicarmo": "quintuplicar",
    "quintuplicarmos": "quintuplicar",
    "quintuplicará": "quintuplicar",
    "quintuplicarás": "quintuplicar",
    "quintuplicarão": "quintuplicar",
    "quintuplicaríamos": "quintuplicar",
    "quintuplicaríeis": "quintuplicar",
    "quintuplicas": "quintuplicar",
    "quintuplicasse": "quintuplicar",
    "quintuplicassem": "quintuplicar",
    "quintuplicasses": "quintuplicar",
    "quintuplicaste": "quintuplicar",
    "quintuplicastes": "quintuplicar",
    "quintuplicava": "quintuplicar",
    "quintuplicavam": "quintuplicar",
    "quintuplicavas": "quintuplicar",
    "quintuplicações": "quintuplicação",
    "quintuplico": "quintuplicar",
    "quintuplicou": "quintuplicar",
    "quintuplicá": "quintuplicar",
    "quintuplicámo": "quintuplicar",
    "quintuplicámos": "quintuplicar",
    "quintuplicáramo": "quintuplicar",
    "quintuplicáramos": "quintuplicar",
    "quintuplicárei": "quintuplicar",
    "quintuplicáreis": "quintuplicar",
    "quintuplicásseis": "quintuplicar",
    "quintuplicássemos": "quintuplicar",
    "quintuplicávamo": "quintuplicar",
    "quintuplicávamos": "quintuplicar",
    "quintuplicávei": "quintuplicar",
    "quintuplicáveis": "quintuplicável",
    "quintuplique": "quintuplicar",
    "quintupliquei": "quintuplicar",
    "quintupliqueis": "quintuplicar",
    "quintupliquem": "quintuplicar",
    "quintupliquemo": "quintuplicar",
    "quintupliquemos": "quintuplicar",
    "quintupliques": "quintuplicar",
    "quintá": "quintar",
    "quintámo": "quintar",
    "quintámos": "quintar",
    "quintáramo": "quintar",
    "quintáramos": "quintar",
    "quintárei": "quintar",
    "quintáreis": "quintar",
    "quintásseis": "quintar",
    "quintássemos": "quintar",
    "quintávamo": "quintar",
    "quintávamos": "quintar",
    "quintávei": "quintar",
    "quintáveis": "quintar",
    "quintã": "quintão",
    "quintãos": "quintão",
    "quintãs": "quintão",
    "quintões": "quintão",
    "quinzenais": "quinzenal",
    "quinzenas": "quinzena",
    "quinzenários": "quinzenário",
    "quiná": "quinar",
    "quinámo": "quinar",
    "quinámos": "quinar",
    "quináramo": "quinar",
    "quináramos": "quinar",
    "quinárei": "quinar",
    "quináreis": "quinar",
    "quinária": "quinário",
    "quinárias": "quinário",
    "quinários": "quinário",
    "quinásseis": "quinar",
    "quinássemos": "quinar",
    "quinávamo": "quinar",
    "quinávamos": "quinar",
    "quinávei": "quinar",
    "quináveis": "quinar",
    "quinóloga": "quinólogo",
    "quinólogas": "quinólogo",
    "quinólogos": "quinólogo",
    "quiosqueira": "quiosqueiro",
    "quiosqueiras": "quiosqueiro",
    "quiosqueiros": "quiosqueiro",
    "quiosques": "quiosque",
    "quiproquós": "quiproquó",
    "quiquiriquis": "quiquiriqui",
    "quiragras": "quiragra",
    "quirais": "quiral",
    "quiralgias": "quiralgia",
    "quiralidades": "quiralidade",
    "quiranas": "quirana",
    "quiratos": "quirato",
    "quirguizes": "quirguiz",
    "quirieleisones": "quirieleison",
    "quirieleisons": "quirieleison",
    "quirieleisões": "quirieleisão",
    "quirirus": "quiriru",
    "quirites": "quirite",
    "quiritária": "quiritário",
    "quiritárias": "quiritário",
    "quiritários": "quiritário",
    "quirogas": "quiroga",
    "quirografa": "quirografar",
    "quirografada": "quirografar",
    "quirografadas": "quirografar",
    "quirografado": "quirografar",
    "quirografados": "quirografar",
    "quirografai": "quirografar",
    "quirografais": "quirografar",
    "quirografam": "quirografar",
    "quirografamo": "quirografar",
    "quirografamos": "quirografar",
    "quirografando": "quirografar",
    "quirografara": "quirografar",
    "quirografaram": "quirografar",
    "quirografaras": "quirografar",
    "quirografarde": "quirografar",
    "quirografardes": "quirografar",
    "quirografare": "quirografar",
    "quirografarei": "quirografar",
    "quirografareis": "quirografar",
    "quirografarem": "quirografar",
    "quirografaremos": "quirografar",
    "quirografares": "quirografar",
    "quirografaria": "quirografar",
    "quirografariam": "quirografar",
    "quirografarias": "quirografar",
    "quirografarmo": "quirografar",
    "quirografarmos": "quirografar",
    "quirografará": "quirografar",
    "quirografarás": "quirografar",
    "quirografarão": "quirografar",
    "quirografaríamos": "quirografar",
    "quirografaríeis": "quirografar",
    "quirografas": "quirografar",
    "quirografasse": "quirografar",
    "quirografassem": "quirografar",
    "quirografasses": "quirografar",
    "quirografaste": "quirografar",
    "quirografastes": "quirografar",
    "quirografava": "quirografar",
    "quirografavam": "quirografar",
    "quirografavas": "quirografar",
    "quirografe": "quirografar",
    "quirografei": "quirografar",
    "quirografeis": "quirografar",
    "quirografem": "quirografar",
    "quirografemo": "quirografar",
    "quirografemos": "quirografar",
    "quirografes": "quirografar",
    "quirografo": "quirografar",
    "quirografou": "quirografar",
    "quirografá": "quirografar",
    "quirografámo": "quirografar",
    "quirografámos": "quirografar",
    "quirografáramo": "quirografar",
    "quirografáramos": "quirografar",
    "quirografárei": "quirografar",
    "quirografáreis": "quirografar",
    "quirografásseis": "quirografar",
    "quirografássemos": "quirografar",
    "quirografávamo": "quirografar",
    "quirografávamos": "quirografar",
    "quirografávei": "quirografar",
    "quirografáveis": "quirografar",
    "quirográfica": "quirográfico",
    "quirográficas": "quirográfico",
    "quirográficos": "quirográfico",
    "quirologias": "quirologia",
    "quirológica": "quirológico",
    "quirológicas": "quirológico",
    "quirológicos": "quirológico",
    "quiromancias": "quiromancia",
    "quiromantes": "quiromante",
    "quironomias": "quironomia",
    "quironomídeos": "quironomídeo",
    "quironómidas": "quironómida",
    "quiroplastos": "quiroplasto",
    "quiropodias": "quiropodia",
    "quiropodistas": "quiropodista",
    "quiroscopias": "quiroscopia",
    "quirotonias": "quirotonia",
    "quirotribias": "quirotribia",
    "quirálgica": "quirálgico",
    "quirálgicas": "quirálgico",
    "quirálgicos": "quirálgico",
    "quirógrafos": "quirógrafo",
    "quirómetros": "quirómetro",
    "quirónomos": "quirónomo",
    "quirópteros": "quiróptero",
    "quis": "querer",
    "quisemo": "querer",
    "quisemos": "querer",
    "quiser": "querer",
    "quisera": "querer",
    "quiseram": "querer",
    "quiseras": "querer",
    "quiserdes": "querer",
    "quiserem": "querer",
    "quiseres": "querer",
    "quisermos": "querer",
    "quisesse": "querer",
    "quisessem": "querer",
    "quisesses": "querer",
    "quiseste": "querer",
    "quisestes": "querer",
    "quissarros": "quissarro",
    "quista": "quisto",
    "quistas": "quisto",
    "quistos": "quisto",
    "quistosa": "quistoso",
    "quistosas": "quistoso",
    "quistosos": "quistoso",
    "quiséramo": "querer",
    "quiséramos": "querer",
    "quisérei": "querer",
    "quiséreis": "querer",
    "quisésseis": "querer",
    "quiséssemos": "querer",
    "quita": "quitar",
    "quitada": "quitar",
    "quitadas": "quitar",
    "quitado": "quitar",
    "quitadora": "quitador",
    "quitadoras": "quitador",
    "quitadores": "quitador",
    "quitados": "quitar",
    "quitai": "quitar",
    "quitais": "quitar",
    "quitam": "quitar",
    "quitamentos": "quitamento",
    "quitamo": "quitar",
    "quitamos": "quitar",
    "quitanda": "quitandar",
    "quitandada": "quitandar",
    "quitandadas": "quitandar",
    "quitandado": "quitandar",
    "quitandados": "quitandar",
    "quitandai": "quitandar",
    "quitandais": "quitandar",
    "quitandam": "quitandar",
    "quitandamo": "quitandar",
    "quitandamos": "quitandar",
    "quitandando": "quitandar",
    "quitandara": "quitandar",
    "quitandaram": "quitandar",
    "quitandaras": "quitandar",
    "quitandardes": "quitandar",
    "quitandarei": "quitandar",
    "quitandareis": "quitandar",
    "quitandarem": "quitandar",
    "quitandaremos": "quitandar",
    "quitandares": "quitandar",
    "quitandaria": "quitandar",
    "quitandariam": "quitandar",
    "quitandarias": "quitandar",
    "quitandarmo": "quitandar",
    "quitandarmos": "quitandar",
    "quitandará": "quitandar",
    "quitandarás": "quitandar",
    "quitandarão": "quitandar",
    "quitandaríamos": "quitandar",
    "quitandaríeis": "quitandar",
    "quitandas": "quitandar",
    "quitandasse": "quitandar",
    "quitandassem": "quitandar",
    "quitandasses": "quitandar",
    "quitandaste": "quitandar",
    "quitandastes": "quitandar",
    "quitandava": "quitandar",
    "quitandavam": "quitandar",
    "quitandavas": "quitandar",
    "quitande": "quitandar",
    "quitandei": "quitandar",
    "quitandeira": "quitandeiro",
    "quitandeiras": "quitandeiro",
    "quitandeiros": "quitandeiro",
    "quitandeis": "quitandar",
    "quitandem": "quitandar",
    "quitandemo": "quitandar",
    "quitandemos": "quitandar",
    "quitandes": "quitandar",
    "quitando": "quitar",
    "quitandou": "quitandar",
    "quitandámo": "quitandar",
    "quitandámos": "quitandar",
    "quitandáramo": "quitandar",
    "quitandáramos": "quitandar",
    "quitandáreis": "quitandar",
    "quitandásseis": "quitandar",
    "quitandássemos": "quitandar",
    "quitandávamo": "quitandar",
    "quitandávamos": "quitandar",
    "quitandáveis": "quitandar",
    "quitangas": "quitanga",
    "quitara": "quitar",
    "quitaram": "quitar",
    "quitaras": "quitar",
    "quitarde": "quitar",
    "quitardes": "quitar",
    "quitare": "quitar",
    "quitarei": "quitar",
    "quitareis": "quitar",
    "quitarem": "quitar",
    "quitaremos": "quitar",
    "quitares": "quitar",
    "quitaria": "quitar",
    "quitariam": "quitar",
    "quitarias": "quitar",
    "quitarmo": "quitar",
    "quitarmos": "quitar",
    "quitará": "quitar",
    "quitarás": "quitar",
    "quitarão": "quitar",
    "quitaríamos": "quitar",
    "quitaríeis": "quitar",
    "quitas": "quitar",
    "quitasse": "quitar",
    "quitassem": "quitar",
    "quitasses": "quitar",
    "quitaste": "quitar",
    "quitastes": "quitar",
    "quitava": "quitar",
    "quitavam": "quitar",
    "quitavas": "quitar",
    "quitações": "quitação",
    "quite": "quitar",
    "quitei": "quitar",
    "quiteis": "quitar",
    "quitem": "quitar",
    "quitemo": "quitar",
    "quitemos": "quitar",
    "quites": "quite",
    "quitinas": "quitina",
    "quitinosa": "quitinoso",
    "quitinosas": "quitinoso",
    "quitinosos": "quitinoso",
    "quitinóforos": "quitinóforo",
    "quito": "quitar",
    "quitou": "quitar",
    "quituras": "quitura",
    "quitutes": "quitute",
    "quitá": "quitar",
    "quitámo": "quitar",
    "quitámos": "quitar",
    "quitáramo": "quitar",
    "quitáramos": "quitar",
    "quitárei": "quitar",
    "quitáreis": "quitar",
    "quitásseis": "quitar",
    "quitássemos": "quitar",
    "quitávamo": "quitar",
    "quitávamos": "quitar",
    "quitávei": "quitar",
    "quitáveis": "quitar",
    "quitós": "quitó",
    "quitões": "quitão",
    "quivis": "quivi",
    "quixotadas": "quixotada",
    "quixotesca": "quixotesco",
    "quixotescas": "quixotesco",
    "quixotescos": "quixotesco",
    "quixotices": "quixotice",
    "quixotismos": "quixotismo",
    "quizílias": "quizília",
    "quiálteras": "quiáltera",
    "quiços": "quiço",
    "quocientes": "quociente",
    "quodores": "quodore",
    "quodórios": "quodório",
    "quoruns": "quorum",
    "quotas": "quota",
    "quotidiana": "quotidiano",
    "quotidianas": "quotidiano",
    "quotidianos": "quotidiano",
    "quotiliquês": "quotiliquê",
    "quotiza": "quotizar",
    "quotizada": "quotizar",
    "quotizadas": "quotizar",
    "quotizado": "quotizar",
    "quotizados": "quotizar",
    "quotizai": "quotizar",
    "quotizais": "quotizar",
    "quotizam": "quotizar",
    "quotizamo": "quotizar",
    "quotizamos": "quotizar",
    "quotizando": "quotizar",
    "quotizara": "quotizar",
    "quotizaram": "quotizar",
    "quotizaras": "quotizar",
    "quotizarde": "quotizar",
    "quotizardes": "quotizar",
    "quotizare": "quotizar",
    "quotizarei": "quotizar",
    "quotizareis": "quotizar",
    "quotizarem": "quotizar",
    "quotizaremos": "quotizar",
    "quotizares": "quotizar",
    "quotizaria": "quotizar",
    "quotizariam": "quotizar",
    "quotizarias": "quotizar",
    "quotizarmo": "quotizar",
    "quotizarmos": "quotizar",
    "quotizará": "quotizar",
    "quotizarás": "quotizar",
    "quotizarão": "quotizar",
    "quotizaríamos": "quotizar",
    "quotizaríeis": "quotizar",
    "quotizas": "quotizar",
    "quotizasse": "quotizar",
    "quotizassem": "quotizar",
    "quotizasses": "quotizar",
    "quotizaste": "quotizar",
    "quotizastes": "quotizar",
    "quotizava": "quotizar",
    "quotizavam": "quotizar",
    "quotizavas": "quotizar",
    "quotizações": "quotização",
    "quotize": "quotizar",
    "quotizei": "quotizar",
    "quotizeis": "quotizar",
    "quotizem": "quotizar",
    "quotizemo": "quotizar",
    "quotizemos": "quotizar",
    "quotizes": "quotizar",
    "quotizo": "quotizar",
    "quotizou": "quotizar",
    "quotizá": "quotizar",
    "quotizámo": "quotizar",
    "quotizámos": "quotizar",
    "quotizáramo": "quotizar",
    "quotizáramos": "quotizar",
    "quotizárei": "quotizar",
    "quotizáreis": "quotizar",
    "quotizásseis": "quotizar",
    "quotizássemos": "quotizar",
    "quotizávamo": "quotizar",
    "quotizávamos": "quotizar",
    "quotizávei": "quotizar",
    "quotizáveis": "quotizável",
    "quádricas": "quádrica",
    "quádrobros": "quádrobro",
    "quádrupla": "quádruplo",
    "quádruplos": "quádruplo",
    "quárticas": "quártica",
    "quássias": "quássia",
    "quântica": "quântico",
    "quânticas": "quântico",
    "quânticos": "quântico",
    "quépis": "quépi",
    "quérula": "quérulo",
    "quérulas": "quérulo",
    "quérulos": "quérulo",
    "quês": "quê",
    "quíchas": "quícha",
    "quíchuas": "quíchua",
    "quícios": "quício",
    "química": "químico",
    "químicas": "químico",
    "químicos": "químico",
    "quínios": "quínio",
    "quíntupla": "quíntuplo",
    "quíntuplas": "quíntuplo",
    "quíntuplos": "quíntuplo",
    "quíperes": "quíper",
    "quíscalos": "quíscalo",
    "quística": "quístico",
    "quísticas": "quístico",
    "quísticos": "quístico",
    "raa": "raer",
    "raais": "raer",
    "raam": "raer",
    "raamo": "raer",
    "raamos": "raer",
    "raas": "raer",
    "rababes": "rababe",
    "rabaceira": "rabaceiro",
    "rabaceiras": "rabaceiro",
    "rabaceiros": "rabaceiro",
    "rabacholas": "rabachola",
    "rabadas": "rabada",
    "rabadelas": "rabadela",
    "rabadilhas": "rabadilha",
    "rabadões": "rabadão",
    "rabalva": "rabalvo",
    "rabalvas": "rabalvo",
    "rabalvos": "rabalvo",
    "rabana": "rabanar",
    "rabanada": "rabanar",
    "rabanadas": "rabanar",
    "rabanado": "rabanar",
    "rabanados": "rabanar",
    "rabanai": "rabanar",
    "rabanais": "rabanar",
    "rabanam": "rabanar",
    "rabanamo": "rabanar",
    "rabanamos": "rabanar",
    "rabanando": "rabanar",
    "rabanara": "rabanar",
    "rabanaram": "rabanar",
    "rabanaras": "rabanar",
    "rabanarde": "rabanar",
    "rabanardes": "rabanar",
    "rabanare": "rabanar",
    "rabanarei": "rabanar",
    "rabanareis": "rabanar",
    "rabanarem": "rabanar",
    "rabanaremos": "rabanar",
    "rabanares": "rabanar",
    "rabanaria": "rabanar",
    "rabanariam": "rabanar",
    "rabanarias": "rabanar",
    "rabanarmo": "rabanar",
    "rabanarmos": "rabanar",
    "rabanará": "rabanar",
    "rabanarás": "rabanar",
    "rabanarão": "rabanar",
    "rabanaríamos": "rabanar",
    "rabanaríeis": "rabanar",
    "rabanas": "rabanar",
    "rabanasse": "rabanar",
    "rabanassem": "rabanar",
    "rabanasses": "rabanar",
    "rabanaste": "rabanar",
    "rabanastes": "rabanar",
    "rabanava": "rabanar",
    "rabanavam": "rabanar",
    "rabanavas": "rabanar",
    "rabane": "rabanar",
    "rabaneada": "rabanear",
    "rabaneadas": "rabanear",
    "rabaneadeiras": "rabaneadeira",
    "rabaneado": "rabanear",
    "rabaneados": "rabanear",
    "rabaneai": "rabanear",
    "rabaneais": "rabanear",
    "rabaneamo": "rabanear",
    "rabaneamos": "rabanear",
    "rabaneando": "rabanear",
    "rabaneara": "rabanear",
    "rabanearam": "rabanear",
    "rabanearas": "rabanear",
    "rabanearde": "rabanear",
    "rabaneardes": "rabanear",
    "rabaneare": "rabanear",
    "rabanearei": "rabanear",
    "rabaneareis": "rabanear",
    "rabanearem": "rabanear",
    "rabanearemos": "rabanear",
    "rabaneares": "rabanear",
    "rabanearia": "rabanear",
    "rabaneariam": "rabanear",
    "rabanearias": "rabanear",
    "rabanearmo": "rabanear",
    "rabanearmos": "rabanear",
    "rabaneará": "rabanear",
    "rabanearás": "rabanear",
    "rabanearão": "rabanear",
    "rabanearíamos": "rabanear",
    "rabanearíeis": "rabanear",
    "rabaneasse": "rabanear",
    "rabaneassem": "rabanear",
    "rabaneasses": "rabanear",
    "rabaneaste": "rabanear",
    "rabaneastes": "rabanear",
    "rabaneava": "rabanear",
    "rabaneavam": "rabanear",
    "rabaneavas": "rabanear",
    "rabaneações": "rabaneação",
    "rabaneei": "rabanear",
    "rabaneeis": "rabanear",
    "rabaneemo": "rabanear",
    "rabaneemos": "rabanear",
    "rabanei": "rabanar",
    "rabaneia": "rabanear",
    "rabaneiam": "rabanear",
    "rabaneias": "rabanear",
    "rabaneie": "rabanear",
    "rabaneiem": "rabanear",
    "rabaneies": "rabanear",
    "rabaneio": "rabanear",
    "rabaneis": "rabanar",
    "rabanem": "rabanar",
    "rabanemo": "rabanar",
    "rabanemos": "rabanar",
    "rabaneou": "rabanear",
    "rabanes": "rabanar",
    "rabanetes": "rabanete",
    "rabaneá": "rabanear",
    "rabaneámo": "rabanear",
    "rabaneámos": "rabanear",
    "rabaneáramo": "rabanear",
    "rabaneáramos": "rabanear",
    "rabaneárei": "rabanear",
    "rabaneáreis": "rabanear",
    "rabaneásseis": "rabanear",
    "rabaneássemos": "rabanear",
    "rabaneávamo": "rabanear",
    "rabaneávamos": "rabanear",
    "rabaneávei": "rabanear",
    "rabaneáveis": "rabanear",
    "rabanhos": "rabanho",
    "rabano": "rabanar",
    "rabanou": "rabanar",
    "rabaná": "rabanar",
    "rabanámo": "rabanar",
    "rabanámos": "rabanar",
    "rabanáramo": "rabanar",
    "rabanáramos": "rabanar",
    "rabanárei": "rabanar",
    "rabanáreis": "rabanar",
    "rabanásseis": "rabanar",
    "rabanássemos": "rabanar",
    "rabanávamo": "rabanar",
    "rabanávamos": "rabanar",
    "rabanávei": "rabanar",
    "rabanáveis": "rabanar",
    "rabaventa": "rabavento",
    "rabaventas": "rabavento",
    "rabaventos": "rabavento",
    "rabazes": "rabaz",
    "rabaçais": "rabaçal",
    "rabaçarias": "rabaçaria",
    "rabaças": "rabaça",
    "rabdites": "rabdite",
    "rabditiformes": "rabditiforme",
    "rabditóides": "rabditóide",
    "rabdocéleos": "rabdocéleo",
    "rabdologias": "rabdologia",
    "rabdológica": "rabdológico",
    "rabdológicas": "rabdológico",
    "rabdológicos": "rabdológico",
    "rabdomancias": "rabdomancia",
    "rabdomantes": "rabdomante",
    "rabdomântica": "rabdomântico",
    "rabdomânticas": "rabdomântico",
    "rabdomânticos": "rabdomântico",
    "rabdossomas": "rabdossoma",
    "rabdossómica": "rabdossómico",
    "rabdossómicas": "rabdossómico",
    "rabdossómicos": "rabdossómico",
    "rabeada": "rabear",
    "rabeadas": "rabear",
    "rabeado": "rabear",
    "rabeadora": "rabeador",
    "rabeadoras": "rabeador",
    "rabeadores": "rabeador",
    "rabeados": "rabear",
    "rabeaduras": "rabeadura",
    "rabeai": "rabear",
    "rabeais": "rabear",
    "rabeamo": "rabear",
    "rabeamos": "rabear",
    "rabeando": "rabear",
    "rabeara": "rabear",
    "rabearam": "rabear",
    "rabearas": "rabear",
    "rabeardes": "rabear",
    "rabearei": "rabear",
    "rabeareis": "rabear",
    "rabearem": "rabear",
    "rabearemos": "rabear",
    "rabeares": "rabear",
    "rabearia": "rabear",
    "rabeariam": "rabear",
    "rabearias": "rabear",
    "rabearmo": "rabear",
    "rabearmos": "rabear",
    "rabeará": "rabear",
    "rabearás": "rabear",
    "rabearão": "rabear",
    "rabearíamos": "rabear",
    "rabearíeis": "rabear",
    "rabeasse": "rabear",
    "rabeassem": "rabear",
    "rabeasses": "rabear",
    "rabeaste": "rabear",
    "rabeastes": "rabear",
    "rabeava": "rabear",
    "rabeavam": "rabear",
    "rabeavas": "rabear",
    "rabecadas": "rabecada",
    "rabecas": "rabeca",
    "rabecos": "rabeco",
    "rabecões": "rabecão",
    "rabeei": "rabear",
    "rabeeis": "rabear",
    "rabeemo": "rabear",
    "rabeemos": "rabear",
    "rabeia": "rabear",
    "rabeiam": "rabear",
    "rabeias": "rabear",
    "rabeie": "rabear",
    "rabeiem": "rabear",
    "rabeies": "rabear",
    "rabeio": "rabear",
    "rabeios": "rabeio",
    "rabeira": "rabeiro",
    "rabeiradas": "rabeirada",
    "rabeiras": "rabeiro",
    "rabeiros": "rabeiro",
    "rabeis": "rabel",
    "rabeja": "rabejar",
    "rabejada": "rabejar",
    "rabejadas": "rabejar",
    "rabejado": "rabejar",
    "rabejadora": "rabejador",
    "rabejadoras": "rabejador",
    "rabejadores": "rabejador",
    "rabejados": "rabejar",
    "rabejai": "rabejar",
    "rabejais": "rabejar",
    "rabejam": "rabejar",
    "rabejamo": "rabejar",
    "rabejamos": "rabejar",
    "rabejando": "rabejar",
    "rabejara": "rabejar",
    "rabejaram": "rabejar",
    "rabejaras": "rabejar",
    "rabejarde": "rabejar",
    "rabejardes": "rabejar",
    "rabejare": "rabejar",
    "rabejarei": "rabejar",
    "rabejareis": "rabejar",
    "rabejarem": "rabejar",
    "rabejaremos": "rabejar",
    "rabejares": "rabejar",
    "rabejaria": "rabejar",
    "rabejariam": "rabejar",
    "rabejarias": "rabejar",
    "rabejarmo": "rabejar",
    "rabejarmos": "rabejar",
    "rabejará": "rabejar",
    "rabejarás": "rabejar",
    "rabejarão": "rabejar",
    "rabejaríamos": "rabejar",
    "rabejaríeis": "rabejar",
    "rabejas": "rabejar",
    "rabejasse": "rabejar",
    "rabejassem": "rabejar",
    "rabejasses": "rabejar",
    "rabejaste": "rabejar",
    "rabejastes": "rabejar",
    "rabejava": "rabejar",
    "rabejavam": "rabejar",
    "rabejavas": "rabejar",
    "rabeje": "rabejar",
    "rabejei": "rabejar",
    "rabejeis": "rabejar",
    "rabejem": "rabejar",
    "rabejemo": "rabejar",
    "rabejemos": "rabejar",
    "rabejes": "rabejar",
    "rabejo": "rabejar",
    "rabejou": "rabejar",
    "rabejá": "rabejar",
    "rabejámo": "rabejar",
    "rabejámos": "rabejar",
    "rabejáramo": "rabejar",
    "rabejáramos": "rabejar",
    "rabejárei": "rabejar",
    "rabejáreis": "rabejar",
    "rabejásseis": "rabejar",
    "rabejássemos": "rabejar",
    "rabejávamo": "rabejar",
    "rabejávamos": "rabejar",
    "rabejávei": "rabejar",
    "rabejáveis": "rabejar",
    "rabela": "rabelo",
    "rabelaica": "rabelaico",
    "rabelaicas": "rabelaico",
    "rabelaicos": "rabelaico",
    "rabelaisiana": "rabelaisiano",
    "rabelaisianas": "rabelaisiano",
    "rabelaisianos": "rabelaisiano",
    "rabelas": "rabelo",
    "rabelos": "rabelo",
    "rabeou": "rabear",
    "rabequeada": "rabequear",
    "rabequeadas": "rabequear",
    "rabequeado": "rabequear",
    "rabequeados": "rabequear",
    "rabequeai": "rabequear",
    "rabequeais": "rabequear",
    "rabequeamo": "rabequear",
    "rabequeamos": "rabequear",
    "rabequeando": "rabequear",
    "rabequeara": "rabequear",
    "rabequearam": "rabequear",
    "rabequearas": "rabequear",
    "rabequeardes": "rabequear",
    "rabequearei": "rabequear",
    "rabequeareis": "rabequear",
    "rabequearem": "rabequear",
    "rabequearemos": "rabequear",
    "rabequeares": "rabequear",
    "rabequearia": "rabequear",
    "rabequeariam": "rabequear",
    "rabequearias": "rabequear",
    "rabequearmo": "rabequear",
    "rabequearmos": "rabequear",
    "rabequeará": "rabequear",
    "rabequearás": "rabequear",
    "rabequearão": "rabequear",
    "rabequearíamos": "rabequear",
    "rabequearíeis": "rabequear",
    "rabequeasse": "rabequear",
    "rabequeassem": "rabequear",
    "rabequeasses": "rabequear",
    "rabequeaste": "rabequear",
    "rabequeastes": "rabequear",
    "rabequeava": "rabequear",
    "rabequeavam": "rabequear",
    "rabequeavas": "rabequear",
    "rabequeei": "rabequear",
    "rabequeeis": "rabequear",
    "rabequeemo": "rabequear",
    "rabequeemos": "rabequear",
    "rabequeia": "rabequear",
    "rabequeiam": "rabequear",
    "rabequeias": "rabequear",
    "rabequeie": "rabequear",
    "rabequeiem": "rabequear",
    "rabequeies": "rabequear",
    "rabequeio": "rabequear",
    "rabequeou": "rabequear",
    "rabequeámo": "rabequear",
    "rabequeámos": "rabequear",
    "rabequeáramo": "rabequear",
    "rabequeáramos": "rabequear",
    "rabequeáreis": "rabequear",
    "rabequeásseis": "rabequear",
    "rabequeássemos": "rabequear",
    "rabequeávamo": "rabequear",
    "rabequeávamos": "rabequear",
    "rabequeáveis": "rabequear",
    "rabequinhas": "rabequinha",
    "rabequistas": "rabequista",
    "rabetas": "rabeta",
    "rabeámo": "rabear",
    "rabeámos": "rabear",
    "rabeáramo": "rabear",
    "rabeáramos": "rabear",
    "rabeáreis": "rabear",
    "rabeásseis": "rabear",
    "rabeássemos": "rabear",
    "rabeávamo": "rabear",
    "rabeávamos": "rabear",
    "rabeáveis": "rabear",
    "rabia": "rabiar",
    "rabiacoelhas": "rabiacoelha",
    "rabiada": "rabiar",
    "rabiadas": "rabiar",
    "rabiado": "rabiar",
    "rabiados": "rabiar",
    "rabiai": "rabiar",
    "rabiais": "rabiar",
    "rabialva": "rabialvo",
    "rabialvas": "rabialvo",
    "rabialvos": "rabialvo",
    "rabiam": "rabiar",
    "rabiamo": "rabiar",
    "rabiamos": "rabiar",
    "rabiando": "rabiar",
    "rabiara": "rabiar",
    "rabiaram": "rabiar",
    "rabiaras": "rabiar",
    "rabiardes": "rabiar",
    "rabiarei": "rabiar",
    "rabiareis": "rabiar",
    "rabiarem": "rabiar",
    "rabiaremos": "rabiar",
    "rabiares": "rabiar",
    "rabiaria": "rabiar",
    "rabiariam": "rabiar",
    "rabiarias": "rabiar",
    "rabiarmo": "rabiar",
    "rabiarmos": "rabiar",
    "rabiará": "rabiar",
    "rabiarás": "rabiar",
    "rabiarão": "rabiar",
    "rabiaríamos": "rabiar",
    "rabiaríeis": "rabiar",
    "rabias": "rabiar",
    "rabiasse": "rabiar",
    "rabiassem": "rabiar",
    "rabiasses": "rabiar",
    "rabiaste": "rabiar",
    "rabiastes": "rabiar",
    "rabiava": "rabiar",
    "rabiavam": "rabiar",
    "rabiavas": "rabiar",
    "rabicha": "rabicho",
    "rabichas": "rabicho",
    "rabicheiras": "rabicheira",
    "rabichos": "rabicho",
    "rabichões": "rabichão",
    "rabicoa": "rabicão",
    "rabicoas": "rabicão",
    "rabicurta": "rabicurto",
    "rabicurtas": "rabicurto",
    "rabicurtos": "rabicurto",
    "rabicões": "rabicão",
    "rabie": "rabiar",
    "rabiei": "rabiar",
    "rabieis": "rabiar",
    "rabiem": "rabiar",
    "rabiemo": "rabiar",
    "rabiemos": "rabiar",
    "rabies": "rabiar",
    "rabifurcada": "rabifurcado",
    "rabifurcadas": "rabifurcado",
    "rabifurcados": "rabifurcado",
    "rabiga": "rabigo",
    "rabigas": "rabigo",
    "rabigatos": "rabigato",
    "rabigos": "rabigo",
    "rabijuncos": "rabijunco",
    "rabilas": "rabila",
    "rabileira": "rabileiro",
    "rabileiras": "rabileiro",
    "rabileiros": "rabileiro",
    "rabilhas": "rabilha",
    "rabilonga": "rabilongo",
    "rabilongas": "rabilongo",
    "rabilongos": "rabilongo",
    "rabina": "rabino",
    "rabinados": "rabinado",
    "rabinas": "rabino",
    "rabinho": "rabo",
    "rabinhos": "rabo",
    "rabinices": "rabinice",
    "rabinismos": "rabinismo",
    "rabinos": "rabino",
    "rabio": "rabiar",
    "rabiosa": "rabioso",
    "rabiosas": "rabioso",
    "rabioscas": "rabiosca",
    "rabiosos": "rabioso",
    "rabiosques": "rabiosque",
    "rabiostes": "rabioste",
    "rabiotes": "rabiote",
    "rabiou": "rabiar",
    "rabipreta": "rabipreto",
    "rabipretas": "rabipreto",
    "rabipretos": "rabipreto",
    "rabirruivas": "rabirruiva",
    "rabirruivos": "rabirruivo",
    "rabis": "rabil",
    "rabisca": "rabiscar",
    "rabiscada": "rabiscar",
    "rabiscadas": "rabiscar",
    "rabiscadeira": "rabiscador",
    "rabiscadeiras": "rabiscador",
    "rabiscado": "rabiscar",
    "rabiscadora": "rabiscador",
    "rabiscadoras": "rabiscador",
    "rabiscadores": "rabiscador",
    "rabiscados": "rabiscar",
    "rabiscadíssima": "rabiscado",
    "rabiscadíssimas": "rabiscado",
    "rabiscadíssimo": "rabiscado",
    "rabiscadíssimos": "rabiscado",
    "rabiscais": "rabiscar",
    "rabiscam": "rabiscar",
    "rabiscamo": "rabiscar",
    "rabiscamos": "rabiscar",
    "rabiscando": "rabiscar",
    "rabiscara": "rabiscar",
    "rabiscaram": "rabiscar",
    "rabiscaras": "rabiscar",
    "rabiscardes": "rabiscar",
    "rabiscarei": "rabiscar",
    "rabiscareis": "rabiscar",
    "rabiscarem": "rabiscar",
    "rabiscaremos": "rabiscar",
    "rabiscares": "rabiscar",
    "rabiscaria": "rabiscar",
    "rabiscariam": "rabiscar",
    "rabiscarias": "rabiscar",
    "rabiscarmo": "rabiscar",
    "rabiscarmos": "rabiscar",
    "rabiscará": "rabiscar",
    "rabiscarás": "rabiscar",
    "rabiscarão": "rabiscar",
    "rabiscaríamos": "rabiscar",
    "rabiscaríeis": "rabiscar",
    "rabiscas": "rabiscar",
    "rabiscasse": "rabiscar",
    "rabiscassem": "rabiscar",
    "rabiscasses": "rabiscar",
    "rabiscaste": "rabiscar",
    "rabiscastes": "rabiscar",
    "rabiscava": "rabiscar",
    "rabiscavam": "rabiscar",
    "rabiscavas": "rabiscar",
    "rabisco": "rabiscar",
    "rabiscoelhas": "rabiscoelha",
    "rabiscos": "rabisco",
    "rabiscou": "rabiscar",
    "rabiscámo": "rabiscar",
    "rabiscámos": "rabiscar",
    "rabiscáramo": "rabiscar",
    "rabiscáramos": "rabiscar",
    "rabiscáreis": "rabiscar",
    "rabiscásseis": "rabiscar",
    "rabiscássemos": "rabiscar",
    "rabiscávamo": "rabiscar",
    "rabiscávamos": "rabiscar",
    "rabiscáveis": "rabiscar",
    "rabisque": "rabiscar",
    "rabisquei": "rabiscar",
    "rabisqueis": "rabiscar",
    "rabisquem": "rabiscar",
    "rabisquemos": "rabiscar",
    "rabisques": "rabiscar",
    "rabisseca": "rabisseco",
    "rabissecas": "rabisseco",
    "rabissecos": "rabisseco",
    "rabistecos": "rabisteco",
    "rabisteis": "rabistel",
    "rabitas": "rabita",
    "rabito": "rabo",
    "rabitos": "rabo",
    "rabiámo": "rabiar",
    "rabiámos": "rabiar",
    "rabiáramo": "rabiar",
    "rabiáramos": "rabiar",
    "rabiáreis": "rabiar",
    "rabiásseis": "rabiar",
    "rabiássemos": "rabiar",
    "rabiávamo": "rabiar",
    "rabiávamos": "rabiar",
    "rabiáveis": "rabiar",
    "rabiças": "rabiça",
    "rabiçolas": "rabiçola",
    "rabiçolos": "rabiçolo",
    "rabocoelhas": "rabocoelha",
    "rabodarvelas": "rabodarvela",
    "rabona": "rabão",
    "rabonas": "rabona",
    "rabos": "rabo",
    "rabosa": "raboso",
    "rabosalhos": "rabosalho",
    "rabosana": "rabosano",
    "rabosanas": "rabosano",
    "rabosanos": "rabosano",
    "rabosas": "raboso",
    "rabosos": "raboso",
    "rabota": "raboto",
    "rabotada": "rabotar",
    "rabotadas": "rabotar",
    "rabotado": "rabotar",
    "rabotados": "rabotar",
    "rabotai": "rabotar",
    "rabotais": "rabotar",
    "rabotam": "rabotar",
    "rabotamo": "rabotar",
    "rabotamos": "rabotar",
    "rabotando": "rabotar",
    "rabotara": "rabotar",
    "rabotaram": "rabotar",
    "rabotaras": "rabotar",
    "rabotarde": "rabotar",
    "rabotardes": "rabotar",
    "rabotare": "rabotar",
    "rabotarei": "rabotar",
    "rabotareis": "rabotar",
    "rabotarem": "rabotar",
    "rabotaremos": "rabotar",
    "rabotares": "rabotar",
    "rabotaria": "rabotar",
    "rabotariam": "rabotar",
    "rabotarias": "rabotar",
    "rabotarmo": "rabotar",
    "rabotarmos": "rabotar",
    "rabotará": "rabotar",
    "rabotarás": "rabotar",
    "rabotarão": "rabotar",
    "rabotaríamos": "rabotar",
    "rabotaríeis": "rabotar",
    "rabotas": "raboto",
    "rabotasse": "rabotar",
    "rabotassem": "rabotar",
    "rabotasses": "rabotar",
    "rabotaste": "rabotar",
    "rabotastes": "rabotar",
    "rabotava": "rabotar",
    "rabotavam": "rabotar",
    "rabotavas": "rabotar",
    "rabote": "rabotar",
    "rabotei": "rabotar",
    "raboteis": "rabotar",
    "rabotem": "rabotar",
    "rabotemo": "rabotar",
    "rabotemos": "rabotar",
    "rabotes": "rabote",
    "raboto": "rabotar",
    "rabotos": "raboto",
    "rabotou": "rabotar",
    "rabotá": "rabotar",
    "rabotámo": "rabotar",
    "rabotámos": "rabotar",
    "rabotáramo": "rabotar",
    "rabotáramos": "rabotar",
    "rabotárei": "rabotar",
    "rabotáreis": "rabotar",
    "rabotásseis": "rabotar",
    "rabotássemos": "rabotar",
    "rabotávamo": "rabotar",
    "rabotávamos": "rabotar",
    "rabotávei": "rabotar",
    "rabotáveis": "rabotar",
    "rabuda": "rabudo",
    "rabudas": "rabudo",
    "rabudazinha": "rabudo",
    "rabudazinhas": "rabudo",
    "rabudazita": "rabudo",
    "rabudazitas": "rabudo",
    "rabudinha": "rabudo",
    "rabudinhas": "rabudo",
    "rabudinho": "rabudo",
    "rabudinhos": "rabudo",
    "rabudita": "rabudo",
    "rabuditas": "rabudo",
    "rabudito": "rabudo",
    "rabuditos": "rabudo",
    "rabudos": "rabudo",
    "rabudozinho": "rabudo",
    "rabudozinhos": "rabudo",
    "rabudozito": "rabudo",
    "rabudozitos": "rabudo",
    "rabugeiras": "rabugeira",
    "rabugens": "rabugem",
    "rabugenta": "rabugento",
    "rabugentas": "rabugento",
    "rabugentos": "rabugento",
    "rabuges": "rabuge",
    "rabugices": "rabugice",
    "rabuja": "rabujar",
    "rabujada": "rabujar",
    "rabujadas": "rabujar",
    "rabujado": "rabujar",
    "rabujados": "rabujar",
    "rabujai": "rabujar",
    "rabujais": "rabujar",
    "rabujam": "rabujar",
    "rabujamo": "rabujar",
    "rabujamos": "rabujar",
    "rabujando": "rabujar",
    "rabujara": "rabujar",
    "rabujaram": "rabujar",
    "rabujaras": "rabujar",
    "rabujardes": "rabujar",
    "rabujarei": "rabujar",
    "rabujareis": "rabujar",
    "rabujarem": "rabujar",
    "rabujaremos": "rabujar",
    "rabujares": "rabujar",
    "rabujaria": "rabujar",
    "rabujariam": "rabujar",
    "rabujarias": "rabujaria",
    "rabujarmo": "rabujar",
    "rabujarmos": "rabujar",
    "rabujará": "rabujar",
    "rabujarás": "rabujar",
    "rabujarão": "rabujar",
    "rabujaríamos": "rabujar",
    "rabujaríeis": "rabujar",
    "rabujas": "rabujar",
    "rabujasse": "rabujar",
    "rabujassem": "rabujar",
    "rabujasses": "rabujar",
    "rabujaste": "rabujar",
    "rabujastes": "rabujar",
    "rabujava": "rabujar",
    "rabujavam": "rabujar",
    "rabujavas": "rabujar",
    "rabuje": "rabujar",
    "rabujei": "rabujar",
    "rabujeis": "rabujar",
    "rabujem": "rabujar",
    "rabujemo": "rabujar",
    "rabujemos": "rabujar",
    "rabujes": "rabujar",
    "rabujo": "rabujar",
    "rabujou": "rabujar",
    "rabujámo": "rabujar",
    "rabujámos": "rabujar",
    "rabujáramo": "rabujar",
    "rabujáramos": "rabujar",
    "rabujáreis": "rabujar",
    "rabujásseis": "rabujar",
    "rabujássemos": "rabujar",
    "rabujávamo": "rabujar",
    "rabujávamos": "rabujar",
    "rabujáveis": "rabujar",
    "rabujões": "rabujão",
    "rabula": "rabular",
    "rabulada": "rabular",
    "rabuladas": "rabular",
    "rabulado": "rabular",
    "rabulados": "rabular",
    "rabulai": "rabular",
    "rabulais": "rabular",
    "rabulam": "rabular",
    "rabulamo": "rabular",
    "rabulamos": "rabular",
    "rabulando": "rabular",
    "rabulara": "rabular",
    "rabularam": "rabular",
    "rabularas": "rabular",
    "rabulardes": "rabular",
    "rabularei": "rabular",
    "rabulareis": "rabular",
    "rabularem": "rabular",
    "rabularemos": "rabular",
    "rabulares": "rabular",
    "rabularia": "rabular",
    "rabulariam": "rabular",
    "rabularias": "rabularia",
    "rabularmo": "rabular",
    "rabularmos": "rabular",
    "rabulará": "rabular",
    "rabularás": "rabular",
    "rabularão": "rabular",
    "rabularíamos": "rabular",
    "rabularíeis": "rabular",
    "rabulas": "rabular",
    "rabulasse": "rabular",
    "rabulassem": "rabular",
    "rabulasses": "rabular",
    "rabulaste": "rabular",
    "rabulastes": "rabular",
    "rabulava": "rabular",
    "rabulavam": "rabular",
    "rabulavas": "rabular",
    "rabule": "rabular",
    "rabulei": "rabular",
    "rabuleis": "rabular",
    "rabulem": "rabular",
    "rabulemo": "rabular",
    "rabulemos": "rabular",
    "rabules": "rabular",
    "rabulices": "rabulice",
    "rabulistas": "rabulista",
    "rabulo": "rabular",
    "rabulona": "rabulão",
    "rabulonas": "rabulão",
    "rabulou": "rabular",
    "rabulámo": "rabular",
    "rabulámos": "rabular",
    "rabuláramo": "rabular",
    "rabuláramos": "rabular",
    "rabuláreis": "rabular",
    "rabulásseis": "rabular",
    "rabulássemos": "rabular",
    "rabulávamo": "rabular",
    "rabulávamos": "rabular",
    "rabuláveis": "rabular",
    "rabulões": "rabulão",
    "rabuna": "rabunar",
    "rabunada": "rabunar",
    "rabunadas": "rabunar",
    "rabunado": "rabunar",
    "rabunadora": "rabunador",
    "rabunadoras": "rabunador",
    "rabunadores": "rabunador",
    "rabunados": "rabunar",
    "rabunai": "rabunar",
    "rabunais": "rabunar",
    "rabunam": "rabunar",
    "rabunamo": "rabunar",
    "rabunamos": "rabunar",
    "rabunando": "rabunar",
    "rabunara": "rabunar",
    "rabunaram": "rabunar",
    "rabunaras": "rabunar",
    "rabunarde": "rabunar",
    "rabunardes": "rabunar",
    "rabunare": "rabunar",
    "rabunarei": "rabunar",
    "rabunareis": "rabunar",
    "rabunarem": "rabunar",
    "rabunaremos": "rabunar",
    "rabunares": "rabunar",
    "rabunaria": "rabunar",
    "rabunariam": "rabunar",
    "rabunarias": "rabunar",
    "rabunarmo": "rabunar",
    "rabunarmos": "rabunar",
    "rabunará": "rabunar",
    "rabunarás": "rabunar",
    "rabunarão": "rabunar",
    "rabunaríamos": "rabunar",
    "rabunaríeis": "rabunar",
    "rabunas": "rabunar",
    "rabunasse": "rabunar",
    "rabunassem": "rabunar",
    "rabunasses": "rabunar",
    "rabunaste": "rabunar",
    "rabunastes": "rabunar",
    "rabunava": "rabunar",
    "rabunavam": "rabunar",
    "rabunavas": "rabunar",
    "rabune": "rabunar",
    "rabunei": "rabunar",
    "rabuneis": "rabunar",
    "rabunem": "rabunar",
    "rabunemo": "rabunar",
    "rabunemos": "rabunar",
    "rabunes": "rabunar",
    "rabuno": "rabunar",
    "rabunou": "rabunar",
    "rabuná": "rabunar",
    "rabunámo": "rabunar",
    "rabunámos": "rabunar",
    "rabunáramo": "rabunar",
    "rabunáramos": "rabunar",
    "rabunárei": "rabunar",
    "rabunáreis": "rabunar",
    "rabunásseis": "rabunar",
    "rabunássemos": "rabunar",
    "rabunávamo": "rabunar",
    "rabunávamos": "rabunar",
    "rabunávei": "rabunar",
    "rabunáveis": "rabunar",
    "rabínica": "rabínico",
    "rabínicas": "rabínico",
    "rabínicos": "rabínico",
    "rabões": "rabão",
    "racemiformes": "racemiforme",
    "racemiza": "racemizar",
    "racemizada": "racemizar",
    "racemizadas": "racemizar",
    "racemizado": "racemizar",
    "racemizados": "racemizar",
    "racemizai": "racemizar",
    "racemizais": "racemizar",
    "racemizam": "racemizar",
    "racemizamo": "racemizar",
    "racemizamos": "racemizar",
    "racemizando": "racemizar",
    "racemizara": "racemizar",
    "racemizaram": "racemizar",
    "racemizaras": "racemizar",
    "racemizarde": "racemizar",
    "racemizardes": "racemizar",
    "racemizare": "racemizar",
    "racemizarei": "racemizar",
    "racemizareis": "racemizar",
    "racemizarem": "racemizar",
    "racemizaremos": "racemizar",
    "racemizares": "racemizar",
    "racemizaria": "racemizar",
    "racemizariam": "racemizar",
    "racemizarias": "racemizar",
    "racemizarmo": "racemizar",
    "racemizarmos": "racemizar",
    "racemizará": "racemizar",
    "racemizarás": "racemizar",
    "racemizarão": "racemizar",
    "racemizaríamos": "racemizar",
    "racemizaríeis": "racemizar",
    "racemizas": "racemizar",
    "racemizasse": "racemizar",
    "racemizassem": "racemizar",
    "racemizasses": "racemizar",
    "racemizaste": "racemizar",
    "racemizastes": "racemizar",
    "racemizava": "racemizar",
    "racemizavam": "racemizar",
    "racemizavas": "racemizar",
    "racemizações": "racemização",
    "racemize": "racemizar",
    "racemizei": "racemizar",
    "racemizeis": "racemizar",
    "racemizem": "racemizar",
    "racemizemo": "racemizar",
    "racemizemos": "racemizar",
    "racemizes": "racemizar",
    "racemizo": "racemizar",
    "racemizou": "racemizar",
    "racemizá": "racemizar",
    "racemizámo": "racemizar",
    "racemizámos": "racemizar",
    "racemizáramo": "racemizar",
    "racemizáramos": "racemizar",
    "racemizárei": "racemizar",
    "racemizáreis": "racemizar",
    "racemizásseis": "racemizar",
    "racemizássemos": "racemizar",
    "racemizávamo": "racemizar",
    "racemizávamos": "racemizar",
    "racemizávei": "racemizar",
    "racemizáveis": "racemizar",
    "racemos": "racemo",
    "racemosa": "racemoso",
    "racemosas": "racemoso",
    "racemosos": "racemoso",
    "racemífera": "racemífero",
    "racemíferas": "racemífero",
    "racemíferos": "racemífero",
    "racha": "rachar",
    "rachada": "rachar",
    "rachadas": "rachar",
    "rachadeiras": "rachadeira",
    "rachadelas": "rachadela",
    "rachado": "rachar",
    "rachadora": "rachador",
    "rachadoras": "rachador",
    "rachadores": "rachador",
    "rachados": "rachar",
    "rachaduras": "rachadura",
    "rachai": "rachar",
    "rachais": "rachar",
    "racham": "rachar",
    "rachamo": "rachar",
    "rachamos": "rachar",
    "rachando": "rachar",
    "rachara": "rachar",
    "racharam": "rachar",
    "racharas": "rachar",
    "racharde": "rachar",
    "rachardes": "rachar",
    "rachare": "rachar",
    "racharei": "rachar",
    "rachareis": "rachar",
    "racharem": "rachar",
    "racharemos": "rachar",
    "rachares": "rachar",
    "racharia": "rachar",
    "rachariam": "rachar",
    "racharias": "rachar",
    "racharmo": "rachar",
    "racharmos": "rachar",
    "rachará": "rachar",
    "racharás": "rachar",
    "racharão": "rachar",
    "racharíamos": "rachar",
    "racharíeis": "rachar",
    "rachas": "rachar",
    "rachasse": "rachar",
    "rachassem": "rachar",
    "rachasses": "rachar",
    "rachaste": "rachar",
    "rachastes": "rachar",
    "rachava": "rachar",
    "rachavam": "rachar",
    "rachavas": "rachar",
    "rache": "rachar",
    "racheada": "rachear",
    "racheadas": "rachear",
    "racheado": "rachear",
    "racheados": "rachear",
    "racheai": "rachear",
    "racheais": "rachear",
    "racheamo": "rachear",
    "racheamos": "rachear",
    "racheando": "rachear",
    "racheara": "rachear",
    "rachearam": "rachear",
    "rachearas": "rachear",
    "rachearde": "rachear",
    "racheardes": "rachear",
    "racheare": "rachear",
    "rachearei": "rachear",
    "racheareis": "rachear",
    "rachearem": "rachear",
    "rachearemos": "rachear",
    "racheares": "rachear",
    "rachearia": "rachear",
    "racheariam": "rachear",
    "rachearias": "rachear",
    "rachearmo": "rachear",
    "rachearmos": "rachear",
    "racheará": "rachear",
    "rachearás": "rachear",
    "rachearão": "rachear",
    "rachearíamos": "rachear",
    "rachearíeis": "rachear",
    "racheasse": "rachear",
    "racheassem": "rachear",
    "racheasses": "rachear",
    "racheaste": "rachear",
    "racheastes": "rachear",
    "racheava": "rachear",
    "racheavam": "rachear",
    "racheavas": "rachear",
    "rachedos": "rachedo",
    "racheei": "rachear",
    "racheeis": "rachear",
    "racheemo": "rachear",
    "racheemos": "rachear",
    "rachei": "rachar",
    "racheia": "rachear",
    "racheiam": "rachear",
    "racheias": "rachear",
    "racheie": "rachear",
    "racheiem": "rachear",
    "racheies": "rachear",
    "racheio": "rachear",
    "racheis": "rachar",
    "rachem": "rachar",
    "rachemo": "rachar",
    "rachemos": "rachar",
    "racheou": "rachear",
    "raches": "rachar",
    "rachetas": "racheta",
    "racheá": "rachear",
    "racheámo": "rachear",
    "racheámos": "rachear",
    "racheáramo": "rachear",
    "racheáramos": "rachear",
    "racheárei": "rachear",
    "racheáreis": "rachear",
    "racheásseis": "rachear",
    "racheássemos": "rachear",
    "racheávamo": "rachear",
    "racheávamos": "rachear",
    "racheávei": "rachear",
    "racheáveis": "rachear",
    "rachinha": "racha",
    "rachinhas": "racha",
    "rachita": "racha",
    "rachitas": "racha",
    "racho": "rachar",
    "rachou": "rachar",
    "rachá": "rachar",
    "rachámo": "rachar",
    "rachámos": "rachar",
    "racháramo": "rachar",
    "racháramos": "rachar",
    "rachárei": "rachar",
    "racháreis": "rachar",
    "rachásseis": "rachar",
    "rachássemos": "rachar",
    "rachávamo": "rachar",
    "rachávamos": "rachar",
    "rachávei": "rachar",
    "racháveis": "rachar",
    "rachões": "rachão",
    "raciais": "racial",
    "racimada": "racimado",
    "racimadas": "racimado",
    "racimados": "racimado",
    "racimiformes": "racimiforme",
    "racimos": "racimo",
    "racimosa": "racimoso",
    "racimosas": "racimoso",
    "racimosos": "racimoso",
    "racimífera": "racimífero",
    "racimíferas": "racimífero",
    "racimíferos": "racimífero",
    "raciocina": "raciocinar",
    "raciocinada": "raciocinar",
    "raciocinadas": "raciocinar",
    "raciocinado": "raciocinar",
    "raciocinadora": "raciocinador",
    "raciocinadoras": "raciocinador",
    "raciocinadores": "raciocinador",
    "raciocinados": "raciocinar",
    "raciocinai": "raciocinar",
    "raciocinais": "raciocinar",
    "raciocinam": "raciocinar",
    "raciocinamo": "raciocinar",
    "raciocinamos": "raciocinar",
    "raciocinando": "raciocinar",
    "raciocinara": "raciocinar",
    "raciocinaram": "raciocinar",
    "raciocinaras": "raciocinar",
    "raciocinardes": "raciocinar",
    "raciocinarei": "raciocinar",
    "raciocinareis": "raciocinar",
    "raciocinarem": "raciocinar",
    "raciocinaremos": "raciocinar",
    "raciocinares": "raciocinar",
    "raciocinaria": "raciocinar",
    "raciocinariam": "raciocinar",
    "raciocinarias": "raciocinar",
    "raciocinarmo": "raciocinar",
    "raciocinarmos": "raciocinar",
    "raciocinará": "raciocinar",
    "raciocinarás": "raciocinar",
    "raciocinarão": "raciocinar",
    "raciocinaríamos": "raciocinar",
    "raciocinaríeis": "raciocinar",
    "raciocinas": "raciocinar",
    "raciocinasse": "raciocinar",
    "raciocinassem": "raciocinar",
    "raciocinasses": "raciocinar",
    "raciocinaste": "raciocinar",
    "raciocinastes": "raciocinar",
    "raciocinativa": "raciocinativo",
    "raciocinativas": "raciocinativo",
    "raciocinativos": "raciocinativo",
    "raciocinava": "raciocinar",
    "raciocinavam": "raciocinar",
    "raciocinavas": "raciocinar",
    "raciocinações": "raciocinação",
    "raciocine": "raciocinar",
    "raciocinei": "raciocinar",
    "raciocineis": "raciocinar",
    "raciocinem": "raciocinar",
    "raciocinemo": "raciocinar",
    "raciocinemos": "raciocinar",
    "raciocines": "raciocinar",
    "raciocino": "raciocinar",
    "raciocinou": "raciocinar",
    "raciocinámo": "raciocinar",
    "raciocinámos": "raciocinar",
    "raciocináramo": "raciocinar",
    "raciocináramos": "raciocinar",
    "raciocináreis": "raciocinar",
    "raciocinásseis": "raciocinar",
    "raciocinássemos": "raciocinar",
    "raciocinávamo": "raciocinar",
    "raciocinávamos": "raciocinar",
    "raciocináveis": "raciocinar",
    "raciocínios": "raciocínio",
    "raciona": "racionar",
    "racionabilidades": "racionabilidade",
    "racionada": "racionar",
    "racionadas": "racionar",
    "racionado": "racionar",
    "racionados": "racionar",
    "racionai": "racionar",
    "racionais": "racionar",
    "racionalidades": "racionalidade",
    "racionalismos": "racionalismo",
    "racionalistas": "racionalista",
    "racionalistazinha": "racionalista",
    "racionalistazinhas": "racionalista",
    "racionalistazinho": "racionalista",
    "racionalistazinhos": "racionalista",
    "racionalistazita": "racionalista",
    "racionalistazitas": "racionalista",
    "racionalistazito": "racionalista",
    "racionalistazitos": "racionalista",
    "racionaliza": "racionalizar",
    "racionalizada": "racionalizar",
    "racionalizadas": "racionalizar",
    "racionalizado": "racionalizar",
    "racionalizados": "racionalizar",
    "racionalizai": "racionalizar",
    "racionalizais": "racionalizar",
    "racionalizam": "racionalizar",
    "racionalizamo": "racionalizar",
    "racionalizamos": "racionalizar",
    "racionalizando": "racionalizar",
    "racionalizantes": "racionalizante",
    "racionalizara": "racionalizar",
    "racionalizaram": "racionalizar",
    "racionalizaras": "racionalizar",
    "racionalizarde": "racionalizar",
    "racionalizardes": "racionalizar",
    "racionalizare": "racionalizar",
    "racionalizarei": "racionalizar",
    "racionalizareis": "racionalizar",
    "racionalizarem": "racionalizar",
    "racionalizaremos": "racionalizar",
    "racionalizares": "racionalizar",
    "racionalizaria": "racionalizar",
    "racionalizariam": "racionalizar",
    "racionalizarias": "racionalizar",
    "racionalizarmo": "racionalizar",
    "racionalizarmos": "racionalizar",
    "racionalizará": "racionalizar",
    "racionalizarás": "racionalizar",
    "racionalizarão": "racionalizar",
    "racionalizaríamos": "racionalizar",
    "racionalizaríeis": "racionalizar",
    "racionalizas": "racionalizar",
    "racionalizasse": "racionalizar",
    "racionalizassem": "racionalizar",
    "racionalizasses": "racionalizar",
    "racionalizaste": "racionalizar",
    "racionalizastes": "racionalizar",
    "racionalizava": "racionalizar",
    "racionalizavam": "racionalizar",
    "racionalizavas": "racionalizar",
    "racionalizações": "racionalização",
    "racionalize": "racionalizar",
    "racionalizei": "racionalizar",
    "racionalizeis": "racionalizar",
    "racionalizem": "racionalizar",
    "racionalizemo": "racionalizar",
    "racionalizemos": "racionalizar",
    "racionalizes": "racionalizar",
    "racionalizo": "racionalizar",
    "racionalizou": "racionalizar",
    "racionalizá": "racionalizar",
    "racionalizámo": "racionalizar",
    "racionalizámos": "racionalizar",
    "racionalizáramo": "racionalizar",
    "racionalizáramos": "racionalizar",
    "racionalizárei": "racionalizar",
    "racionalizáreis": "racionalizar",
    "racionalizásseis": "racionalizar",
    "racionalizássemos": "racionalizar",
    "racionalizávamo": "racionalizar",
    "racionalizávamos": "racionalizar",
    "racionalizávei": "racionalizar",
    "racionalizáveis": "racionalizável",
    "racionam": "racionar",
    "racionamentos": "racionamento",
    "racionamo": "racionar",
    "racionamos": "racionar",
    "racionando": "racionar",
    "racionara": "racionar",
    "racionaram": "racionar",
    "racionaras": "racionar",
    "racionarde": "racionar",
    "racionardes": "racionar",
    "racionare": "racionar",
    "racionarei": "racionar",
    "racionareis": "racionar",
    "racionarem": "racionar",
    "racionaremos": "racionar",
    "racionares": "racionar",
    "racionaria": "racionar",
    "racionariam": "racionar",
    "racionarias": "racionar",
    "racionarmo": "racionar",
    "racionarmos": "racionar",
    "racionará": "racionar",
    "racionarás": "racionar",
    "racionarão": "racionar",
    "racionaríamos": "racionar",
    "racionaríeis": "racionar",
    "racionas": "racionar",
    "racionasse": "racionar",
    "racionassem": "racionar",
    "racionasses": "racionar",
    "racionaste": "racionar",
    "racionastes": "racionar",
    "racionava": "racionar",
    "racionavam": "racionar",
    "racionavas": "racionar",
    "racione": "racionar",
    "racionei": "racionar",
    "racioneira": "racioneiro",
    "racioneiras": "racioneiro",
    "racioneiros": "racioneiro",
    "racioneis": "racionar",
    "racionem": "racionar",
    "racionemo": "racionar",
    "racionemos": "racionar",
    "raciones": "racionar",
    "raciono": "racionar",
    "racionou": "racionar",
    "racioná": "racionar",
    "racionámo": "racionar",
    "racionámos": "racionar",
    "racionáramo": "racionar",
    "racionáramos": "racionar",
    "racionárei": "racionar",
    "racionáreis": "racionar",
    "racionásseis": "racionar",
    "racionássemos": "racionar",
    "racionávamo": "racionar",
    "racionávamos": "racionar",
    "racionávei": "racionar",
    "racionáveis": "racionável",
    "racismos": "racismo",
    "racistas": "racista",
    "racistazinha": "racista",
    "racistazinhas": "racista",
    "racistazinho": "racista",
    "racistazinhos": "racista",
    "racistazita": "racista",
    "racistazitas": "racista",
    "racistazito": "racista",
    "racistazitos": "racista",
    "racontos": "raconto",
    "ractificações": "ractificação",
    "racémica": "racémico",
    "racémicas": "racémico",
    "racémicos": "racémico",
    "radares": "radar",
    "radas": "rada",
    "rades": "rad",
    "radia": "radiar",
    "radiactiva": "radiactivo",
    "radiactivas": "radiactivo",
    "radiactividades": "radiactividade",
    "radiactivos": "radiactivo",
    "radiada": "radiar",
    "radiadas": "radiar",
    "radiado": "radiar",
    "radiadora": "radiador",
    "radiadoras": "radiador",
    "radiadores": "radiador",
    "radiados": "radiar",
    "radiai": "radiar",
    "radiais": "radiar",
    "radiam": "radiar",
    "radiamo": "radiar",
    "radiamos": "radiar",
    "radiando": "radiar",
    "radianos": "radiano",
    "radiantes": "radiante",
    "radiara": "radiar",
    "radiaram": "radiar",
    "radiaras": "radiar",
    "radiardes": "radiar",
    "radiarei": "radiar",
    "radiareis": "radiar",
    "radiarem": "radiar",
    "radiaremos": "radiar",
    "radiares": "radiar",
    "radiaria": "radiar",
    "radiariam": "radiar",
    "radiarias": "radiar",
    "radiarmo": "radiar",
    "radiarmos": "radiar",
    "radiará": "radiar",
    "radiarás": "radiar",
    "radiarão": "radiar",
    "radiaríamos": "radiar",
    "radiaríeis": "radiar",
    "radias": "radiar",
    "radiasse": "radiar",
    "radiassem": "radiar",
    "radiasses": "radiar",
    "radiaste": "radiar",
    "radiastes": "radiar",
    "radiastronomias": "radiastronomia",
    "radiativa": "radiativo",
    "radiativas": "radiativo",
    "radiativos": "radiativo",
    "radiava": "radiar",
    "radiavam": "radiar",
    "radiavas": "radiar",
    "radiações": "radiação",
    "radica": "radicar",
    "radicada": "radicar",
    "radicadas": "radicar",
    "radicado": "radicar",
    "radicados": "radicar",
    "radicais": "radicar",
    "radicalidades": "radicalidade",
    "radicalismos": "radicalismo",
    "radicalistas": "radicalista",
    "radicaliza": "radicalizar",
    "radicalizada": "radicalizar",
    "radicalizadas": "radicalizar",
    "radicalizado": "radicalizar",
    "radicalizados": "radicalizar",
    "radicalizai": "radicalizar",
    "radicalizais": "radicalizar",
    "radicalizam": "radicalizar",
    "radicalizamo": "radicalizar",
    "radicalizamos": "radicalizar",
    "radicalizando": "radicalizar",
    "radicalizara": "radicalizar",
    "radicalizaram": "radicalizar",
    "radicalizaras": "radicalizar",
    "radicalizarde": "radicalizar",
    "radicalizardes": "radicalizar",
    "radicalizare": "radicalizar",
    "radicalizarei": "radicalizar",
    "radicalizareis": "radicalizar",
    "radicalizarem": "radicalizar",
    "radicalizaremos": "radicalizar",
    "radicalizares": "radicalizar",
    "radicalizaria": "radicalizar",
    "radicalizariam": "radicalizar",
    "radicalizarias": "radicalizar",
    "radicalizarmo": "radicalizar",
    "radicalizarmos": "radicalizar",
    "radicalizará": "radicalizar",
    "radicalizarás": "radicalizar",
    "radicalizarão": "radicalizar",
    "radicalizaríamos": "radicalizar",
    "radicalizaríeis": "radicalizar",
    "radicalizas": "radicalizar",
    "radicalizasse": "radicalizar",
    "radicalizassem": "radicalizar",
    "radicalizasses": "radicalizar",
    "radicalizaste": "radicalizar",
    "radicalizastes": "radicalizar",
    "radicalizava": "radicalizar",
    "radicalizavam": "radicalizar",
    "radicalizavas": "radicalizar",
    "radicalizações": "radicalização",
    "radicalize": "radicalizar",
    "radicalizei": "radicalizar",
    "radicalizeis": "radicalizar",
    "radicalizem": "radicalizar",
    "radicalizemo": "radicalizar",
    "radicalizemos": "radicalizar",
    "radicalizes": "radicalizar",
    "radicalizo": "radicalizar",
    "radicalizou": "radicalizar",
    "radicalizá": "radicalizar",
    "radicalizámo": "radicalizar",
    "radicalizámos": "radicalizar",
    "radicalizáramo": "radicalizar",
    "radicalizáramos": "radicalizar",
    "radicalizárei": "radicalizar",
    "radicalizáreis": "radicalizar",
    "radicalizásseis": "radicalizar",
    "radicalizássemos": "radicalizar",
    "radicalizávamo": "radicalizar",
    "radicalizávamos": "radicalizar",
    "radicalizávei": "radicalizar",
    "radicalizáveis": "radicalizável",
    "radicam": "radicar",
    "radicamo": "radicar",
    "radicamos": "radicar",
    "radicanda": "radicando",
    "radicandas": "radicando",
    "radicando": "radicar",
    "radicandos": "radicando",
    "radicantes": "radicante",
    "radicara": "radicar",
    "radicaram": "radicar",
    "radicaras": "radicar",
    "radicardes": "radicar",
    "radicarei": "radicar",
    "radicareis": "radicar",
    "radicarem": "radicar",
    "radicaremos": "radicar",
    "radicares": "radicar",
    "radicaria": "radicar",
    "radicariam": "radicar",
    "radicarias": "radicar",
    "radicarmo": "radicar",
    "radicarmos": "radicar",
    "radicará": "radicar",
    "radicarás": "radicar",
    "radicarão": "radicar",
    "radicaríamos": "radicar",
    "radicaríeis": "radicar",
    "radicas": "radicar",
    "radicasse": "radicar",
    "radicassem": "radicar",
    "radicasses": "radicar",
    "radicaste": "radicar",
    "radicastes": "radicar",
    "radicava": "radicar",
    "radicavam": "radicar",
    "radicavas": "radicar",
    "radicações": "radicação",
    "radiciações": "radiciação",
    "radiciformes": "radiciforme",
    "radico": "radicar",
    "radicosa": "radicoso",
    "radicosas": "radicoso",
    "radicosos": "radicoso",
    "radicotomias": "radicotomia",
    "radicotómica": "radicotómico",
    "radicotómicas": "radicotómico",
    "radicotómicos": "radicotómico",
    "radicou": "radicar",
    "radiculada": "radiculado",
    "radiculadas": "radiculado",
    "radiculados": "radiculado",
    "radiculalgias": "radiculalgia",
    "radiculares": "radicular",
    "radiculálgica": "radiculálgico",
    "radiculálgicas": "radiculálgico",
    "radiculálgicos": "radiculálgico",
    "radicámo": "radicar",
    "radicámos": "radicar",
    "radicáramo": "radicar",
    "radicáramos": "radicar",
    "radicáreis": "radicar",
    "radicásseis": "radicar",
    "radicássemos": "radicar",
    "radicávamo": "radicar",
    "radicávamos": "radicar",
    "radicáveis": "radicar",
    "radicícolas": "radicícola",
    "radicívora": "radicívoro",
    "radicívoras": "radicívoro",
    "radicívoros": "radicívoro",
    "radicóforos": "radicóforo",
    "radie": "radiar",
    "radiei": "radiar",
    "radieis": "radiar",
    "radielectricidades": "radielectricidade",
    "radielementos": "radielemento",
    "radieléctrica": "radieléctrico",
    "radieléctricas": "radieléctrico",
    "radieléctricos": "radieléctrico",
    "radiem": "radiar",
    "radiemissores": "radiemissor",
    "radiemissões": "radiemissão",
    "radiemita": "radiemitir",
    "radiemitais": "radiemitir",
    "radiemitam": "radiemitir",
    "radiemitamo": "radiemitir",
    "radiemitamos": "radiemitir",
    "radiemitas": "radiemitir",
    "radiemite": "radiemitir",
    "radiemitem": "radiemitir",
    "radiemites": "radiemitir",
    "radiemiti": "radiemitir",
    "radiemitia": "radiemitir",
    "radiemitiam": "radiemitir",
    "radiemitias": "radiemitir",
    "radiemitida": "radiemitir",
    "radiemitidas": "radiemitir",
    "radiemitido": "radiemitir",
    "radiemitidos": "radiemitir",
    "radiemitimo": "radiemitir",
    "radiemitimos": "radiemitir",
    "radiemitindo": "radiemitir",
    "radiemitira": "radiemitir",
    "radiemitiram": "radiemitir",
    "radiemitiras": "radiemitir",
    "radiemitirde": "radiemitir",
    "radiemitirdes": "radiemitir",
    "radiemitire": "radiemitir",
    "radiemitirei": "radiemitir",
    "radiemitireis": "radiemitir",
    "radiemitirem": "radiemitir",
    "radiemitiremos": "radiemitir",
    "radiemitires": "radiemitir",
    "radiemitiria": "radiemitir",
    "radiemitiriam": "radiemitir",
    "radiemitirias": "radiemitir",
    "radiemitirmo": "radiemitir",
    "radiemitirmos": "radiemitir",
    "radiemitirá": "radiemitir",
    "radiemitirás": "radiemitir",
    "radiemitirão": "radiemitir",
    "radiemitiríamos": "radiemitir",
    "radiemitiríeis": "radiemitir",
    "radiemitis": "radiemitir",
    "radiemitisse": "radiemitir",
    "radiemitissem": "radiemitir",
    "radiemitisses": "radiemitir",
    "radiemitiste": "radiemitir",
    "radiemitistes": "radiemitir",
    "radiemitiu": "radiemitir",
    "radiemito": "radiemitir",
    "radiemitíamo": "radiemitir",
    "radiemitíamos": "radiemitir",
    "radiemitíei": "radiemitir",
    "radiemitíeis": "radiemitir",
    "radiemitíramo": "radiemitir",
    "radiemitíramos": "radiemitir",
    "radiemitírei": "radiemitir",
    "radiemitíreis": "radiemitir",
    "radiemitísseis": "radiemitir",
    "radiemitíssemos": "radiemitir",
    "radiemo": "radiar",
    "radiemos": "radiar",
    "radies": "radiar",
    "radiestesias": "radiestesia",
    "radiestesistas": "radiestesista",
    "radiestésica": "radiestésico",
    "radiestésicas": "radiestésico",
    "radiestésicos": "radiestésico",
    "radiisótopos": "radiisótopo",
    "radio": "radiar",
    "radioactiva": "radioactivo",
    "radioactivas": "radioactivo",
    "radioactividades": "radioactividade",
    "radioactivos": "radioactivo",
    "radioamadora": "radioamador",
    "radioamadoras": "radioamador",
    "radioamadores": "radioamador",
    "radioastronomias": "radioastronomia",
    "radiobiologias": "radiobiologia",
    "radiocarbonos": "radiocarbono",
    "radiocomandada": "radiocomandado",
    "radiocomandadas": "radiocomandado",
    "radiocomandados": "radiocomandado",
    "radiocomunicações": "radiocomunicação",
    "radiocondutibilidades": "radiocondutibilidade",
    "radiocondutividades": "radiocondutividade",
    "radiocondutores": "radiocondutor",
    "radioculturas": "radiocultura",
    "radiodermites": "radiodermite",
    "radiodiagnósticos": "radiodiagnóstico",
    "radiodifunda": "radiodifundir",
    "radiodifundais": "radiodifundir",
    "radiodifundam": "radiodifundir",
    "radiodifundamo": "radiodifundir",
    "radiodifundamos": "radiodifundir",
    "radiodifundas": "radiodifundir",
    "radiodifunde": "radiodifundir",
    "radiodifundem": "radiodifundir",
    "radiodifundes": "radiodifundir",
    "radiodifundi": "radiodifundir",
    "radiodifundia": "radiodifundir",
    "radiodifundiam": "radiodifundir",
    "radiodifundias": "radiodifundir",
    "radiodifundida": "radiodifundir",
    "radiodifundidas": "radiodifundir",
    "radiodifundido": "radiodifundir",
    "radiodifundidos": "radiodifundir",
    "radiodifundimo": "radiodifundir",
    "radiodifundimos": "radiodifundir",
    "radiodifundindo": "radiodifundir",
    "radiodifundira": "radiodifundir",
    "radiodifundiram": "radiodifundir",
    "radiodifundiras": "radiodifundir",
    "radiodifundirde": "radiodifundir",
    "radiodifundirdes": "radiodifundir",
    "radiodifundire": "radiodifundir",
    "radiodifundirei": "radiodifundir",
    "radiodifundireis": "radiodifundir",
    "radiodifundirem": "radiodifundir",
    "radiodifundiremos": "radiodifundir",
    "radiodifundires": "radiodifundir",
    "radiodifundiria": "radiodifundir",
    "radiodifundiriam": "radiodifundir",
    "radiodifundirias": "radiodifundir",
    "radiodifundirmo": "radiodifundir",
    "radiodifundirmos": "radiodifundir",
    "radiodifundirá": "radiodifundir",
    "radiodifundirás": "radiodifundir",
    "radiodifundirão": "radiodifundir",
    "radiodifundiríamos": "radiodifundir",
    "radiodifundiríeis": "radiodifundir",
    "radiodifundis": "radiodifundir",
    "radiodifundisse": "radiodifundir",
    "radiodifundissem": "radiodifundir",
    "radiodifundisses": "radiodifundir",
    "radiodifundiste": "radiodifundir",
    "radiodifundistes": "radiodifundir",
    "radiodifundiu": "radiodifundir",
    "radiodifundo": "radiodifundir",
    "radiodifundíamo": "radiodifundir",
    "radiodifundíamos": "radiodifundir",
    "radiodifundíei": "radiodifundir",
    "radiodifundíeis": "radiodifundir",
    "radiodifundíramo": "radiodifundir",
    "radiodifundíramos": "radiodifundir",
    "radiodifundírei": "radiodifundir",
    "radiodifundíreis": "radiodifundir",
    "radiodifundísseis": "radiodifundir",
    "radiodifundíssemos": "radiodifundir",
    "radiodifundíveis": "radiodifundível",
    "radiodifusões": "radiodifusão",
    "radioelectricidades": "radioelectricidade",
    "radioelementos": "radioelemento",
    "radioemissoras": "radioemissora",
    "radioemissores": "radioemissor",
    "radioemissões": "radioemissão",
    "radioemita": "radioemitir",
    "radioemitais": "radioemitir",
    "radioemitam": "radioemitir",
    "radioemitamo": "radioemitir",
    "radioemitamos": "radioemitir",
    "radioemitas": "radioemitir",
    "radioemite": "radioemitir",
    "radioemitem": "radioemitir",
    "radioemites": "radioemitir",
    "radioemiti": "radioemitir",
    "radioemitia": "radioemitir",
    "radioemitiam": "radioemitir",
    "radioemitias": "radioemitir",
    "radioemitida": "radioemitir",
    "radioemitidas": "radioemitir",
    "radioemitido": "radioemitir",
    "radioemitidos": "radioemitir",
    "radioemitimo": "radioemitir",
    "radioemitimos": "radioemitir",
    "radioemitindo": "radioemitir",
    "radioemitira": "radioemitir",
    "radioemitiram": "radioemitir",
    "radioemitiras": "radioemitir",
    "radioemitirde": "radioemitir",
    "radioemitirdes": "radioemitir",
    "radioemitire": "radioemitir",
    "radioemitirei": "radioemitir",
    "radioemitireis": "radioemitir",
    "radioemitirem": "radioemitir",
    "radioemitiremos": "radioemitir",
    "radioemitires": "radioemitir",
    "radioemitiria": "radioemitir",
    "radioemitiriam": "radioemitir",
    "radioemitirias": "radioemitir",
    "radioemitirmo": "radioemitir",
    "radioemitirmos": "radioemitir",
    "radioemitirá": "radioemitir",
    "radioemitirás": "radioemitir",
    "radioemitirão": "radioemitir",
    "radioemitiríamos": "radioemitir",
    "radioemitiríeis": "radioemitir",
    "radioemitis": "radioemitir",
    "radioemitisse": "radioemitir",
    "radioemitissem": "radioemitir",
    "radioemitisses": "radioemitir",
    "radioemitiste": "radioemitir",
    "radioemitistes": "radioemitir",
    "radioemitiu": "radioemitir",
    "radioemito": "radioemitir",
    "radioemitíamo": "radioemitir",
    "radioemitíamos": "radioemitir",
    "radioemitíei": "radioemitir",
    "radioemitíeis": "radioemitir",
    "radioemitíramo": "radioemitir",
    "radioemitíramos": "radioemitir",
    "radioemitírei": "radioemitir",
    "radioemitíreis": "radioemitir",
    "radioemitísseis": "radioemitir",
    "radioemitíssemos": "radioemitir",
    "radioestesias": "radioestesia",
    "radioestrelas": "radioestrela",
    "radioestésica": "radioestésico",
    "radioestésicas": "radioestésico",
    "radioestésicos": "radioestésico",
    "radiofaróis": "radiofarol",
    "radiofones": "radiofone",
    "radiofonias": "radiofonia",
    "radiofrequências": "radiofrequência",
    "radiofónica": "radiofónico",
    "radiofónicas": "radiofónico",
    "radiofónicos": "radiofónico",
    "radiogoniometrias": "radiogoniometria",
    "radiogoniométrica": "radiogoniométrico",
    "radiogoniométricas": "radiogoniométrico",
    "radiogoniométricos": "radiogoniométrico",
    "radiogoniómetros": "radiogoniómetro",
    "radiografa": "radiografar",
    "radiografada": "radiografar",
    "radiografadas": "radiografar",
    "radiografado": "radiografar",
    "radiografados": "radiografar",
    "radiografai": "radiografar",
    "radiografais": "radiografar",
    "radiografam": "radiografar",
    "radiografamo": "radiografar",
    "radiografamos": "radiografar",
    "radiografando": "radiografar",
    "radiografara": "radiografar",
    "radiografaram": "radiografar",
    "radiografaras": "radiografar",
    "radiografarde": "radiografar",
    "radiografardes": "radiografar",
    "radiografare": "radiografar",
    "radiografarei": "radiografar",
    "radiografareis": "radiografar",
    "radiografarem": "radiografar",
    "radiografaremos": "radiografar",
    "radiografares": "radiografar",
    "radiografaria": "radiografar",
    "radiografariam": "radiografar",
    "radiografarias": "radiografar",
    "radiografarmo": "radiografar",
    "radiografarmos": "radiografar",
    "radiografará": "radiografar",
    "radiografarás": "radiografar",
    "radiografarão": "radiografar",
    "radiografaríamos": "radiografar",
    "radiografaríeis": "radiografar",
    "radiografas": "radiografar",
    "radiografasse": "radiografar",
    "radiografassem": "radiografar",
    "radiografasses": "radiografar",
    "radiografaste": "radiografar",
    "radiografastes": "radiografar",
    "radiografava": "radiografar",
    "radiografavam": "radiografar",
    "radiografavas": "radiografar",
    "radiografe": "radiografar",
    "radiografei": "radiografar",
    "radiografeis": "radiografar",
    "radiografem": "radiografar",
    "radiografemo": "radiografar",
    "radiografemos": "radiografar",
    "radiografes": "radiografar",
    "radiografias": "radiografia",
    "radiografo": "radiografar",
    "radiografou": "radiografar",
    "radiografá": "radiografar",
    "radiografámo": "radiografar",
    "radiografámos": "radiografar",
    "radiografáramo": "radiografar",
    "radiografáramos": "radiografar",
    "radiografárei": "radiografar",
    "radiografáreis": "radiografar",
    "radiografásseis": "radiografar",
    "radiografássemos": "radiografar",
    "radiografávamo": "radiografar",
    "radiografávamos": "radiografar",
    "radiografávei": "radiografar",
    "radiografáveis": "radiografável",
    "radiogramas": "radiograma",
    "radiográfica": "radiográfico",
    "radiográficas": "radiográfico",
    "radiográficos": "radiográfico",
    "radiogénica": "radiogénico",
    "radiogénicas": "radiogénico",
    "radiogénicos": "radiogénico",
    "radioisótopos": "radioisótopo",
    "radiojornais": "radiojornal",
    "radiolarites": "radiolarite",
    "radiolaritos": "radiolarito",
    "radiolas": "radiola",
    "radiologias": "radiologia",
    "radiologistas": "radiologista",
    "radioluminescentes": "radioluminescente",
    "radioluminescências": "radioluminescência",
    "radioluxes": "radiolux",
    "radiolários": "radiolário",
    "radiológica": "radiológico",
    "radiológicas": "radiológico",
    "radiológicos": "radiológico",
    "radiomensagens": "radiomensagem",
    "radiometrias": "radiometria",
    "radiomicrométrica": "radiomicrométrico",
    "radiomicrométricas": "radiomicrométrico",
    "radiomicrométricos": "radiomicrométrico",
    "radiomicrómetros": "radiomicrómetro",
    "radiométrica": "radiométrico",
    "radiométricas": "radiométrico",
    "radiométricos": "radiométrico",
    "radionavegações": "radionavegação",
    "radionuclídeos": "radionuclídeo",
    "radiopatias": "radiopatia",
    "radiopatrulhas": "radiopatrulha",
    "radiopática": "radiopático",
    "radiopáticas": "radiopático",
    "radiopáticos": "radiopático",
    "radioquímica": "radioquímico",
    "radioquímicas": "radioquímico",
    "radioquímicos": "radioquímico",
    "radiorrastreios": "radiorrastreio",
    "radiorreportagens": "radiorreportagem",
    "radiorrepórteres": "radiorrepórter",
    "radiosa": "radioso",
    "radiosas": "radioso",
    "radioscopias": "radioscopia",
    "radioscópica": "radioscópico",
    "radioscópicas": "radioscópico",
    "radioscópicos": "radioscópico",
    "radiosos": "radioso",
    "radiossensibilidades": "radiossensibilidade",
    "radiossensíveis": "radiossensível",
    "radiossondas": "radiossonda",
    "radiotelefones": "radiotelefone",
    "radiotelefonias": "radiotelefonia",
    "radiotelefónica": "radiotelefónico",
    "radiotelefónicas": "radiotelefónico",
    "radiotelefónicos": "radiotelefónico",
    "radiotelegrafias": "radiotelegrafia",
    "radiotelegrafistas": "radiotelegrafista",
    "radiotelegramas": "radiotelegrama",
    "radiotelegráfica": "radiotelegráfico",
    "radiotelegráficas": "radiotelegráfico",
    "radiotelegráficos": "radiotelegráfico",
    "radiotelescópica": "radiotelescópico",
    "radiotelescópicas": "radiotelescópico",
    "radiotelescópicos": "radiotelescópico",
    "radiotelescópios": "radiotelescópio",
    "radiotelevisada": "radiotelevisado",
    "radiotelevisadas": "radiotelevisado",
    "radiotelevisados": "radiotelevisado",
    "radiotelevisores": "radiotelevisor",
    "radiotelevisões": "radiotelevisão",
    "radioterapias": "radioterapia",
    "radioterapêutica": "radioterapêutico",
    "radioterapêuticas": "radioterapêutico",
    "radioterapêuticos": "radioterapêutico",
    "radiotáxis": "radiotáxi",
    "radiotécnica": "radiotécnico",
    "radiotécnicas": "radiotécnico",
    "radiotécnicos": "radiotécnico",
    "radiou": "radiar",
    "radiouvintes": "radiouvinte",
    "radique": "radicar",
    "radiquei": "radicar",
    "radiqueis": "radicar",
    "radiquem": "radicar",
    "radiquemos": "radicar",
    "radiques": "radicar",
    "radiámo": "radiar",
    "radiámos": "radiar",
    "radiáramo": "radiar",
    "radiáramos": "radiar",
    "radiáreis": "radiar",
    "radiários": "radiário",
    "radiásseis": "radiar",
    "radiássemos": "radiar",
    "radiávamo": "radiar",
    "radiávamos": "radiar",
    "radiáveis": "radiar",
    "radiâncias": "radiância",
    "radiólises": "radiólise",
    "radiómetros": "radiómetro",
    "rads": "rad",
    "radícolas": "radícola",
    "radículas": "radícula",
    "radíolas": "radíola",
    "radões": "radão",
    "rae": "raer",
    "raei": "raer",
    "raeis": "raer",
    "raem": "raer",
    "raemo": "raer",
    "raemos": "raer",
    "raendo": "raer",
    "raera": "raer",
    "raeram": "raer",
    "raeras": "raer",
    "raerde": "raer",
    "raerdes": "raer",
    "raere": "raer",
    "raerei": "raer",
    "raereis": "raer",
    "raerem": "raer",
    "raeremos": "raer",
    "raeres": "raer",
    "raeria": "raer",
    "raeriam": "raer",
    "raerias": "raer",
    "raermo": "raer",
    "raermos": "raer",
    "raerá": "raer",
    "raerás": "raer",
    "raerão": "raer",
    "raeríamos": "raer",
    "raeríeis": "raer",
    "raes": "raer",
    "raesse": "raer",
    "raessem": "raer",
    "raesses": "raer",
    "raeste": "raer",
    "raestes": "raer",
    "raeu": "raer",
    "rafa": "rafar",
    "rafada": "rafar",
    "rafadas": "rafar",
    "rafado": "rafar",
    "rafados": "rafar",
    "rafaelesca": "rafaelesco",
    "rafaelescas": "rafaelesco",
    "rafaelescos": "rafaelesco",
    "rafaelismos": "rafaelismo",
    "rafaelistas": "rafaelista",
    "rafai": "rafar",
    "rafais": "rafar",
    "rafam": "rafar",
    "rafamo": "rafar",
    "rafamos": "rafar",
    "rafando": "rafar",
    "rafara": "rafar",
    "rafaram": "rafar",
    "rafaras": "rafar",
    "rafarde": "rafar",
    "rafardes": "rafar",
    "rafare": "rafar",
    "rafarei": "rafar",
    "rafareis": "rafar",
    "rafarem": "rafar",
    "rafaremos": "rafar",
    "rafares": "rafar",
    "rafaria": "rafar",
    "rafariam": "rafar",
    "rafarias": "rafar",
    "rafarmo": "rafar",
    "rafarmos": "rafar",
    "rafará": "rafar",
    "rafarás": "rafar",
    "rafarão": "rafar",
    "rafaríamos": "rafar",
    "rafaríeis": "rafar",
    "rafas": "rafar",
    "rafasse": "rafar",
    "rafassem": "rafar",
    "rafasses": "rafar",
    "rafaste": "rafar",
    "rafastes": "rafar",
    "rafava": "rafar",
    "rafavam": "rafar",
    "rafavas": "rafar",
    "rafe": "rafar",
    "rafei": "rafar",
    "rafeirinho": "rafeiro",
    "rafeirinhos": "rafeiro",
    "rafeirito": "rafeiro",
    "rafeiritos": "rafeiro",
    "rafeiros": "rafeiro",
    "rafeirozinho": "rafeiro",
    "rafeirozinhos": "rafeiro",
    "rafeirozito": "rafeiro",
    "rafeirozitos": "rafeiro",
    "rafeis": "rafar",
    "rafem": "rafar",
    "rafemo": "rafar",
    "rafemos": "rafar",
    "rafes": "rafe",
    "rafidografias": "rafidografia",
    "rafidográfica": "rafidográfico",
    "rafidográficas": "rafidográfico",
    "rafidográficos": "rafidográfico",
    "rafidógrafos": "rafidógrafo",
    "rafigrafias": "rafigrafia",
    "rafigráfica": "rafigráfico",
    "rafigráficas": "rafigráfico",
    "rafigráficos": "rafigráfico",
    "raflesiáceas": "raflesiácea",
    "rafo": "rafar",
    "rafou": "rafar",
    "rafá": "rafar",
    "rafámo": "rafar",
    "rafámos": "rafar",
    "rafáramo": "rafar",
    "rafáramos": "rafar",
    "rafárei": "rafar",
    "rafáreis": "rafar",
    "rafásseis": "rafar",
    "rafássemos": "rafar",
    "rafávamo": "rafar",
    "rafávamos": "rafar",
    "rafávei": "rafar",
    "rafáveis": "rafar",
    "rafígrafos": "rafígrafo",
    "ragus": "ragu",
    "ragóides": "ragóide",
    "rai": "raer",
    "raia": "raiar",
    "raiada": "raiar",
    "raiadas": "raiar",
    "raiado": "raiar",
    "raiados": "raiar",
    "raiai": "raiar",
    "raiais": "raiar",
    "raiam": "raiar",
    "raiamo": "raiar",
    "raiamos": "raiar",
    "raiana": "raiano",
    "raianas": "raiano",
    "raiando": "raiar",
    "raianos": "raiano",
    "raiara": "raiar",
    "raiaram": "raiar",
    "raiaras": "raiar",
    "raiardes": "raiar",
    "raiarei": "raiar",
    "raiareis": "raiar",
    "raiarem": "raiar",
    "raiaremos": "raiar",
    "raiares": "raiar",
    "raiaria": "raiar",
    "raiariam": "raiar",
    "raiarias": "raiar",
    "raiarmo": "raiar",
    "raiarmos": "raiar",
    "raiará": "raiar",
    "raiarás": "raiar",
    "raiarão": "raiar",
    "raiaríamos": "raiar",
    "raiaríeis": "raiar",
    "raias": "raiar",
    "raiasse": "raiar",
    "raiassem": "raiar",
    "raiasses": "raiar",
    "raiaste": "raiar",
    "raiastes": "raiar",
    "raiava": "raiar",
    "raiavam": "raiar",
    "raiavas": "raiar",
    "raida": "raer",
    "raidas": "raer",
    "raides": "raide",
    "raido": "raer",
    "raidos": "raer",
    "raids": "raid",
    "raie": "raiar",
    "raiei": "raiar",
    "raieis": "raiar",
    "raiem": "raiar",
    "raiemo": "raiar",
    "raiemos": "raiar",
    "raies": "raiar",
    "raigotas": "raigota",
    "raigotosa": "raigotoso",
    "raigotosas": "raigotoso",
    "raigotosos": "raigotoso",
    "raigráses": "raigrás",
    "railes": "rail",
    "rails": "rail",
    "rainetas": "raineta",
    "rainha": "rei",
    "rainhas": "rei",
    "rainhos": "rainho",
    "rainúnculos": "rainúnculo",
    "raio": "raiar",
    "raiolas": "raiola",
    "raios": "raio",
    "raiou": "raiar",
    "raiozinho": "raio",
    "raiozinhos": "raio",
    "raiozito": "raio",
    "raiozitos": "raio",
    "raiunas": "raiuna",
    "raiva": "raivar",
    "raivada": "raivar",
    "raivadas": "raivar",
    "raivado": "raivar",
    "raivados": "raivar",
    "raivai": "raivar",
    "raivais": "raivar",
    "raivam": "raivar",
    "raivamo": "raivar",
    "raivamos": "raivar",
    "raivando": "raivar",
    "raivara": "raivar",
    "raivaram": "raivar",
    "raivaras": "raivar",
    "raivardes": "raivar",
    "raivarei": "raivar",
    "raivareis": "raivar",
    "raivarem": "raivar",
    "raivaremos": "raivar",
    "raivares": "raivar",
    "raivaria": "raivar",
    "raivariam": "raivar",
    "raivarias": "raivar",
    "raivarmo": "raivar",
    "raivarmos": "raivar",
    "raivará": "raivar",
    "raivarás": "raivar",
    "raivarão": "raivar",
    "raivaríamos": "raivar",
    "raivaríeis": "raivar",
    "raivas": "raivar",
    "raivasse": "raivar",
    "raivassem": "raivar",
    "raivasses": "raivar",
    "raivaste": "raivar",
    "raivastes": "raivar",
    "raivava": "raivar",
    "raivavam": "raivar",
    "raivavas": "raivar",
    "raive": "raivar",
    "raivece": "raivecer",
    "raivecei": "raivecer",
    "raiveceis": "raivecer",
    "raivecem": "raivecer",
    "raivecemo": "raivecer",
    "raivecemos": "raivecer",
    "raivecendo": "raivecer",
    "raivecera": "raivecer",
    "raiveceram": "raivecer",
    "raiveceras": "raivecer",
    "raivecerdes": "raivecer",
    "raivecerei": "raivecer",
    "raivecereis": "raivecer",
    "raivecerem": "raivecer",
    "raiveceremos": "raivecer",
    "raiveceres": "raivecer",
    "raiveceria": "raivecer",
    "raiveceriam": "raivecer",
    "raivecerias": "raivecer",
    "raivecermo": "raivecer",
    "raivecermos": "raivecer",
    "raivecerá": "raivecer",
    "raivecerás": "raivecer",
    "raivecerão": "raivecer",
    "raiveceríamos": "raivecer",
    "raiveceríeis": "raivecer",
    "raiveces": "raivecer",
    "raivecesse": "raivecer",
    "raivecessem": "raivecer",
    "raivecesses": "raivecer",
    "raiveceste": "raivecer",
    "raivecestes": "raivecer",
    "raiveceu": "raivecer",
    "raiveci": "raivecer",
    "raivecia": "raivecer",
    "raiveciam": "raivecer",
    "raivecias": "raivecer",
    "raivecida": "raivecer",
    "raivecidas": "raivecer",
    "raivecido": "raivecer",
    "raivecidos": "raivecer",
    "raivecêramo": "raivecer",
    "raivecêramos": "raivecer",
    "raivecêreis": "raivecer",
    "raivecêsseis": "raivecer",
    "raivecêssemos": "raivecer",
    "raivecíamo": "raivecer",
    "raivecíamos": "raivecer",
    "raivecíeis": "raivecer",
    "raivei": "raivar",
    "raiveis": "raivel",
    "raiveja": "raivejar",
    "raivejada": "raivejar",
    "raivejadas": "raivejar",
    "raivejado": "raivejar",
    "raivejados": "raivejar",
    "raivejai": "raivejar",
    "raivejais": "raivejar",
    "raivejam": "raivejar",
    "raivejamo": "raivejar",
    "raivejamos": "raivejar",
    "raivejando": "raivejar",
    "raivejara": "raivejar",
    "raivejaram": "raivejar",
    "raivejaras": "raivejar",
    "raivejardes": "raivejar",
    "raivejarei": "raivejar",
    "raivejareis": "raivejar",
    "raivejarem": "raivejar",
    "raivejaremos": "raivejar",
    "raivejares": "raivejar",
    "raivejaria": "raivejar",
    "raivejariam": "raivejar",
    "raivejarias": "raivejar",
    "raivejarmo": "raivejar",
    "raivejarmos": "raivejar",
    "raivejará": "raivejar",
    "raivejarás": "raivejar",
    "raivejarão": "raivejar",
    "raivejaríamos": "raivejar",
    "raivejaríeis": "raivejar",
    "raivejas": "raivejar",
    "raivejasse": "raivejar",
    "raivejassem": "raivejar",
    "raivejasses": "raivejar",
    "raivejaste": "raivejar",
    "raivejastes": "raivejar",
    "raivejava": "raivejar",
    "raivejavam": "raivejar",
    "raivejavas": "raivejar",
    "raiveje": "raivejar",
    "raivejei": "raivejar",
    "raivejeis": "raivejar",
    "raivejem": "raivejar",
    "raivejemo": "raivejar",
    "raivejemos": "raivejar",
    "raivejes": "raivejar",
    "raivejo": "raivejar",
    "raivejou": "raivejar",
    "raivejámo": "raivejar",
    "raivejámos": "raivejar",
    "raivejáramo": "raivejar",
    "raivejáramos": "raivejar",
    "raivejáreis": "raivejar",
    "raivejásseis": "raivejar",
    "raivejássemos": "raivejar",
    "raivejávamo": "raivejar",
    "raivejávamos": "raivejar",
    "raivejáveis": "raivejar",
    "raivem": "raivar",
    "raivemo": "raivar",
    "raivemos": "raivar",
    "raiventa": "raivento",
    "raiventas": "raivento",
    "raiventos": "raivento",
    "raivenças": "raivença",
    "raives": "raivar",
    "raiveça": "raivecer",
    "raiveçais": "raivecer",
    "raiveçam": "raivecer",
    "raiveçamo": "raivecer",
    "raiveçamos": "raivecer",
    "raiveças": "raivecer",
    "raiveço": "raivecer",
    "raivinha": "raiva",
    "raivinhas": "raiva",
    "raivita": "raiva",
    "raivitas": "raiva",
    "raivo": "raivar",
    "raivosa": "raivoso",
    "raivosas": "raivoso",
    "raivosos": "raivoso",
    "raivosíssima": "raivoso",
    "raivosíssimas": "raivoso",
    "raivosíssimo": "raivoso",
    "raivosíssimos": "raivoso",
    "raivou": "raivar",
    "raivámo": "raivar",
    "raivámos": "raivar",
    "raiváramo": "raivar",
    "raiváramos": "raivar",
    "raiváreis": "raivar",
    "raivásseis": "raivar",
    "raivássemos": "raivar",
    "raivávamo": "raivar",
    "raivávamos": "raivar",
    "raiváveis": "raivar",
    "raivós": "raivó",
    "raizadas": "raizada",
    "raizames": "raizame",
    "raizeiras": "raizeira",
    "raizeiros": "raizeiro",
    "raiámo": "raiar",
    "raiámos": "raiar",
    "raiáramo": "raiar",
    "raiáramos": "raiar",
    "raiáreis": "raiar",
    "raiásseis": "raiar",
    "raiássemos": "raiar",
    "raiávamo": "raiar",
    "raiávamos": "raiar",
    "raiáveis": "raiar",
    "raiídeos": "raiídeo",
    "raja": "rajar",
    "rajada": "rajar",
    "rajadas": "rajar",
    "rajado": "rajar",
    "rajados": "rajar",
    "rajai": "rajar",
    "rajais": "rajar",
    "rajam": "rajar",
    "rajamo": "rajar",
    "rajamos": "rajar",
    "rajando": "rajar",
    "rajara": "rajar",
    "rajaram": "rajar",
    "rajaras": "rajar",
    "rajarde": "rajar",
    "rajardes": "rajar",
    "rajare": "rajar",
    "rajarei": "rajar",
    "rajareis": "rajar",
    "rajarem": "rajar",
    "rajaremos": "rajar",
    "rajares": "rajar",
    "rajaria": "rajar",
    "rajariam": "rajar",
    "rajarias": "rajar",
    "rajarmo": "rajar",
    "rajarmos": "rajar",
    "rajará": "rajar",
    "rajarás": "rajar",
    "rajarão": "rajar",
    "rajaríamos": "rajar",
    "rajaríeis": "rajar",
    "rajas": "rajar",
    "rajasse": "rajar",
    "rajassem": "rajar",
    "rajasses": "rajar",
    "rajaste": "rajar",
    "rajastes": "rajar",
    "rajava": "rajar",
    "rajavam": "rajar",
    "rajavas": "rajar",
    "raje": "rajar",
    "rajei": "rajar",
    "rajeiras": "rajeira",
    "rajeis": "rajar",
    "rajem": "rajar",
    "rajemo": "rajar",
    "rajemos": "rajar",
    "rajes": "rajar",
    "rajo": "rajar",
    "rajos": "rajo",
    "rajou": "rajar",
    "rajá": "rajar",
    "rajámo": "rajar",
    "rajámos": "rajar",
    "rajáramo": "rajar",
    "rajáramos": "rajar",
    "rajárei": "rajar",
    "rajáreis": "rajar",
    "rajás": "rajá",
    "rajásseis": "rajar",
    "rajássemos": "rajar",
    "rajávamo": "rajar",
    "rajávamos": "rajar",
    "rajávei": "rajar",
    "rajáveis": "rajar",
    "rajões": "rajão",
    "rala": "ralo",
    "ralada": "ralar",
    "raladas": "ralar",
    "ralado": "ralar",
    "raladora": "ralador",
    "raladoras": "ralador",
    "raladores": "ralador",
    "ralados": "ralar",
    "raladuras": "raladura",
    "ralai": "ralar",
    "ralais": "ralar",
    "ralam": "ralar",
    "ralamo": "ralar",
    "ralamos": "ralar",
    "ralando": "ralar",
    "ralara": "ralar",
    "ralaram": "ralar",
    "ralaras": "ralar",
    "ralarde": "ralar",
    "ralardes": "ralar",
    "ralare": "ralar",
    "ralarei": "ralar",
    "ralareis": "ralar",
    "ralarem": "ralar",
    "ralaremos": "ralar",
    "ralares": "ralar",
    "ralaria": "ralar",
    "ralariam": "ralar",
    "ralarias": "ralar",
    "ralarmo": "ralar",
    "ralarmos": "ralar",
    "ralará": "ralar",
    "ralarás": "ralar",
    "ralarão": "ralar",
    "ralaríamos": "ralar",
    "ralaríeis": "ralar",
    "ralas": "ralo",
    "ralassa": "ralasso",
    "ralassas": "ralasso",
    "ralasse": "ralar",
    "ralassem": "ralar",
    "ralasses": "ralar",
    "ralassos": "ralasso",
    "ralaste": "ralar",
    "ralastes": "ralar",
    "ralava": "ralar",
    "ralavam": "ralar",
    "ralavas": "ralar",
    "ralazinha": "ralo",
    "ralazinhas": "ralo",
    "ralazita": "ralo",
    "ralazitas": "ralo",
    "ralações": "ralação",
    "rale": "ralar",
    "raleada": "ralear",
    "raleadas": "ralear",
    "raleado": "ralear",
    "raleados": "ralear",
    "raleaduras": "raleadura",
    "raleai": "ralear",
    "raleais": "ralear",
    "raleamentos": "raleamento",
    "raleamo": "ralear",
    "raleamos": "ralear",
    "raleando": "ralear",
    "raleara": "ralear",
    "ralearam": "ralear",
    "ralearas": "ralear",
    "ralearde": "ralear",
    "raleardes": "ralear",
    "raleare": "ralear",
    "ralearei": "ralear",
    "raleareis": "ralear",
    "ralearem": "ralear",
    "ralearemos": "ralear",
    "raleares": "ralear",
    "ralearia": "ralear",
    "raleariam": "ralear",
    "ralearias": "ralear",
    "ralearmo": "ralear",
    "ralearmos": "ralear",
    "raleará": "ralear",
    "ralearás": "ralear",
    "ralearão": "ralear",
    "ralearíamos": "ralear",
    "ralearíeis": "ralear",
    "raleasse": "ralear",
    "raleassem": "ralear",
    "raleasses": "ralear",
    "raleaste": "ralear",
    "raleastes": "ralear",
    "raleava": "ralear",
    "raleavam": "ralear",
    "raleavas": "ralear",
    "raleei": "ralear",
    "raleeis": "ralear",
    "raleemo": "ralear",
    "raleemos": "ralear",
    "ralei": "ralar",
    "raleia": "ralear",
    "raleiam": "ralear",
    "raleias": "raleia",
    "raleie": "ralear",
    "raleiem": "ralear",
    "raleies": "ralear",
    "raleio": "ralear",
    "raleiras": "raleira",
    "raleiros": "raleiro",
    "raleis": "ralar",
    "ralem": "ralar",
    "ralemo": "ralar",
    "ralemos": "ralar",
    "ralenta": "ralentar",
    "ralentada": "ralentar",
    "ralentadas": "ralentar",
    "ralentado": "ralentar",
    "ralentados": "ralentar",
    "ralentai": "ralentar",
    "ralentais": "ralentar",
    "ralentam": "ralentar",
    "ralentamo": "ralentar",
    "ralentamos": "ralentar",
    "ralentando": "ralentar",
    "ralentara": "ralentar",
    "ralentaram": "ralentar",
    "ralentaras": "ralentar",
    "ralentarde": "ralentar",
    "ralentardes": "ralentar",
    "ralentare": "ralentar",
    "ralentarei": "ralentar",
    "ralentareis": "ralentar",
    "ralentarem": "ralentar",
    "ralentaremos": "ralentar",
    "ralentares": "ralentar",
    "ralentaria": "ralentar",
    "ralentariam": "ralentar",
    "ralentarias": "ralentar",
    "ralentarmo": "ralentar",
    "ralentarmos": "ralentar",
    "ralentará": "ralentar",
    "ralentarás": "ralentar",
    "ralentarão": "ralentar",
    "ralentaríamos": "ralentar",
    "ralentaríeis": "ralentar",
    "ralentas": "ralentar",
    "ralentasse": "ralentar",
    "ralentassem": "ralentar",
    "ralentasses": "ralentar",
    "ralentaste": "ralentar",
    "ralentastes": "ralentar",
    "ralentava": "ralentar",
    "ralentavam": "ralentar",
    "ralentavas": "ralentar",
    "ralente": "ralentar",
    "ralentei": "ralentar",
    "ralenteis": "ralentar",
    "ralentem": "ralentar",
    "ralentemo": "ralentar",
    "ralentemos": "ralentar",
    "ralentes": "ralentar",
    "ralentis": "ralenti",
    "ralento": "ralentar",
    "ralentou": "ralentar",
    "ralentá": "ralentar",
    "ralentámo": "ralentar",
    "ralentámos": "ralentar",
    "ralentáramo": "ralentar",
    "ralentáramos": "ralentar",
    "ralentárei": "ralentar",
    "ralentáreis": "ralentar",
    "ralentásseis": "ralentar",
    "ralentássemos": "ralentar",
    "ralentávamo": "ralentar",
    "ralentávamos": "ralentar",
    "ralentávei": "ralentar",
    "ralentáveis": "ralentar",
    "raleou": "ralear",
    "rales": "ralar",
    "raleá": "ralear",
    "raleámo": "ralear",
    "raleámos": "ralear",
    "raleáramo": "ralear",
    "raleáramos": "ralear",
    "raleárei": "ralear",
    "raleáreis": "ralear",
    "raleásseis": "ralear",
    "raleássemos": "ralear",
    "raleávamo": "ralear",
    "raleávamos": "ralear",
    "raleávei": "ralear",
    "raleáveis": "ralear",
    "ralha": "ralhar",
    "ralhada": "ralhar",
    "ralhadas": "ralhar",
    "ralhado": "ralhar",
    "ralhadora": "ralhador",
    "ralhadoras": "ralhador",
    "ralhadores": "ralhador",
    "ralhados": "ralhar",
    "ralhai": "ralhar",
    "ralhais": "ralhar",
    "ralham": "ralhar",
    "ralhamo": "ralhar",
    "ralhamos": "ralhar",
    "ralhando": "ralhar",
    "ralhara": "ralhar",
    "ralharam": "ralhar",
    "ralharas": "ralhar",
    "ralhardes": "ralhar",
    "ralharei": "ralhar",
    "ralhareis": "ralhar",
    "ralharem": "ralhar",
    "ralharemos": "ralhar",
    "ralhares": "ralhar",
    "ralharia": "ralhar",
    "ralhariam": "ralhar",
    "ralharias": "ralhar",
    "ralharmo": "ralhar",
    "ralharmos": "ralhar",
    "ralhará": "ralhar",
    "ralharás": "ralhar",
    "ralharão": "ralhar",
    "ralharíamos": "ralhar",
    "ralharíeis": "ralhar",
    "ralhas": "ralhar",
    "ralhasse": "ralhar",
    "ralhassem": "ralhar",
    "ralhasses": "ralhar",
    "ralhaste": "ralhar",
    "ralhastes": "ralhar",
    "ralhava": "ralhar",
    "ralhavam": "ralhar",
    "ralhavas": "ralhar",
    "ralhações": "ralhação",
    "ralhe": "ralhar",
    "ralhei": "ralhar",
    "ralheis": "ralhar",
    "ralhem": "ralhar",
    "ralhemo": "ralhar",
    "ralhemos": "ralhar",
    "ralhes": "ralhar",
    "ralhetas": "ralheta",
    "ralhetes": "ralhete",
    "ralho": "ralhar",
    "ralhona": "ralhão",
    "ralhonas": "ralhão",
    "ralhos": "ralho",
    "ralhou": "ralhar",
    "ralhámo": "ralhar",
    "ralhámos": "ralhar",
    "ralháramo": "ralhar",
    "ralháramos": "ralhar",
    "ralháreis": "ralhar",
    "ralhásseis": "ralhar",
    "ralhássemos": "ralhar",
    "ralhávamo": "ralhar",
    "ralhávamos": "ralhar",
    "ralháveis": "ralhar",
    "ralhões": "ralhão",
    "ralicas": "ralica",
    "ralices": "ralice",
    "ralinha": "ralo",
    "ralinhas": "ralo",
    "ralinho": "ralo",
    "ralinhos": "ralo",
    "ralis": "rali",
    "ralita": "ralo",
    "ralitas": "ralo",
    "ralito": "ralo",
    "ralitos": "ralo",
    "rallies": "rally",
    "ralo": "ralar",
    "ralos": "ralo",
    "ralou": "ralar",
    "ralozinho": "ralo",
    "ralozinhos": "ralo",
    "ralozito": "ralo",
    "ralozitos": "ralo",
    "ralá": "ralar",
    "ralámo": "ralar",
    "ralámos": "ralar",
    "raláramo": "ralar",
    "raláramos": "ralar",
    "ralárei": "ralar",
    "raláreis": "ralar",
    "ralásseis": "ralar",
    "ralássemos": "ralar",
    "ralávamo": "ralar",
    "ralávamos": "ralar",
    "ralávei": "ralar",
    "raláveis": "ralar",
    "ralés": "ralé",
    "ralídeos": "ralídeo",
    "ralíssima": "ralo",
    "ralíssimas": "ralo",
    "ralíssimo": "ralo",
    "ralíssimos": "ralo",
    "ralões": "ralão",
    "ramada": "ramado",
    "ramadas": "ramado",
    "ramadazinha": "ramada",
    "ramadazinhas": "ramada",
    "ramadazita": "ramada",
    "ramadazitas": "ramada",
    "ramados": "ramado",
    "ramadãs": "ramadã",
    "ramadões": "ramadão",
    "ramagens": "ramagem",
    "ramais": "ramal",
    "ramaldeiras": "ramaldeira",
    "ramalha": "ramalhar",
    "ramalhada": "ramalhar",
    "ramalhadas": "ramalhar",
    "ramalhado": "ramalhar",
    "ramalhados": "ramalhar",
    "ramalhai": "ramalhar",
    "ramalhais": "ramalhar",
    "ramalham": "ramalhar",
    "ramalhamo": "ramalhar",
    "ramalhamos": "ramalhar",
    "ramalhando": "ramalhar",
    "ramalhara": "ramalhar",
    "ramalharam": "ramalhar",
    "ramalharas": "ramalhar",
    "ramalhardes": "ramalhar",
    "ramalharei": "ramalhar",
    "ramalhareis": "ramalhar",
    "ramalharem": "ramalhar",
    "ramalharemos": "ramalhar",
    "ramalhares": "ramalhar",
    "ramalharia": "ramalhar",
    "ramalhariam": "ramalhar",
    "ramalharias": "ramalhar",
    "ramalharmo": "ramalhar",
    "ramalharmos": "ramalhar",
    "ramalhará": "ramalhar",
    "ramalharás": "ramalhar",
    "ramalharão": "ramalhar",
    "ramalharíamos": "ramalhar",
    "ramalharíeis": "ramalhar",
    "ramalhas": "ramalhar",
    "ramalhasse": "ramalhar",
    "ramalhassem": "ramalhar",
    "ramalhasses": "ramalhar",
    "ramalhaste": "ramalhar",
    "ramalhastes": "ramalhar",
    "ramalhava": "ramalhar",
    "ramalhavam": "ramalhar",
    "ramalhavas": "ramalhar",
    "ramalhe": "ramalhar",
    "ramalhei": "ramalhar",
    "ramalheiras": "ramalheira",
    "ramalheiros": "ramalheiro",
    "ramalheis": "ramalhar",
    "ramalhem": "ramalhar",
    "ramalhemo": "ramalhar",
    "ramalhemos": "ramalhar",
    "ramalhes": "ramalhar",
    "ramalheteiras": "ramalheteira",
    "ramalhetes": "ramalhete",
    "ramalho": "ramalhar",
    "ramalhona": "ramalhão",
    "ramalhonas": "ramalhão",
    "ramalhos": "ramalho",
    "ramalhosa": "ramalhoso",
    "ramalhosas": "ramalhoso",
    "ramalhosos": "ramalhoso",
    "ramalhou": "ramalhar",
    "ramalhoças": "ramalhoça",
    "ramalhuda": "ramalhudo",
    "ramalhudas": "ramalhudo",
    "ramalhudos": "ramalhudo",
    "ramalhámo": "ramalhar",
    "ramalhámos": "ramalhar",
    "ramalháramo": "ramalhar",
    "ramalháramos": "ramalhar",
    "ramalháreis": "ramalhar",
    "ramalhásseis": "ramalhar",
    "ramalhássemos": "ramalhar",
    "ramalhávamo": "ramalhar",
    "ramalhávamos": "ramalhar",
    "ramalháveis": "ramalhar",
    "ramalhões": "ramalhão",
    "ramarias": "ramaria",
    "ramas": "rama",
    "ramblas": "rambla",
    "rambóias": "rambóia",
    "rameira": "rameiro",
    "rameiras": "rameiro",
    "rameiros": "rameiro",
    "ramelas": "ramela",
    "ramelinha": "ramela",
    "ramelinhas": "ramela",
    "ramelita": "ramela",
    "ramelitas": "ramela",
    "ramelosa": "rameloso",
    "ramelosas": "rameloso",
    "ramelosos": "rameloso",
    "ramerrames": "ramerrame",
    "ramerraneira": "ramerraneiro",
    "ramerraneiras": "ramerraneiro",
    "ramerraneiros": "ramerraneiro",
    "ramerranesca": "ramerranesco",
    "ramerranescas": "ramerranesco",
    "ramerranescos": "ramerranesco",
    "ramerrões": "ramerrão",
    "ramifica": "ramificar",
    "ramificada": "ramificar",
    "ramificadas": "ramificar",
    "ramificado": "ramificar",
    "ramificados": "ramificar",
    "ramificai": "ramificar",
    "ramificais": "ramificar",
    "ramificam": "ramificar",
    "ramificamo": "ramificar",
    "ramificamos": "ramificar",
    "ramificando": "ramificar",
    "ramificara": "ramificar",
    "ramificaram": "ramificar",
    "ramificaras": "ramificar",
    "ramificarde": "ramificar",
    "ramificardes": "ramificar",
    "ramificare": "ramificar",
    "ramificarei": "ramificar",
    "ramificareis": "ramificar",
    "ramificarem": "ramificar",
    "ramificaremos": "ramificar",
    "ramificares": "ramificar",
    "ramificaria": "ramificar",
    "ramificariam": "ramificar",
    "ramificarias": "ramificar",
    "ramificarmo": "ramificar",
    "ramificarmos": "ramificar",
    "ramificará": "ramificar",
    "ramificarás": "ramificar",
    "ramificarão": "ramificar",
    "ramificaríamos": "ramificar",
    "ramificaríeis": "ramificar",
    "ramificas": "ramificar",
    "ramificasse": "ramificar",
    "ramificassem": "ramificar",
    "ramificasses": "ramificar",
    "ramificaste": "ramificar",
    "ramificastes": "ramificar",
    "ramificava": "ramificar",
    "ramificavam": "ramificar",
    "ramificavas": "ramificar",
    "ramificações": "ramificação",
    "ramifico": "ramificar",
    "ramificou": "ramificar",
    "ramificá": "ramificar",
    "ramificámo": "ramificar",
    "ramificámos": "ramificar",
    "ramificáramo": "ramificar",
    "ramificáramos": "ramificar",
    "ramificárei": "ramificar",
    "ramificáreis": "ramificar",
    "ramificásseis": "ramificar",
    "ramificássemos": "ramificar",
    "ramificávamo": "ramificar",
    "ramificávamos": "ramificar",
    "ramificávei": "ramificar",
    "ramificáveis": "ramificável",
    "ramifique": "ramificar",
    "ramifiquei": "ramificar",
    "ramifiqueis": "ramificar",
    "ramifiquem": "ramificar",
    "ramifiquemo": "ramificar",
    "ramifiquemos": "ramificar",
    "ramifiques": "ramificar",
    "ramiformes": "ramiforme",
    "ramilhetes": "ramilhete",
    "ramilhos": "ramilho",
    "raminha": "rama",
    "raminhas": "rama",
    "raminho": "ramo",
    "raminhos": "ramo",
    "ramita": "rama",
    "ramitas": "rama",
    "ramito": "ramo",
    "ramitos": "ramo",
    "ramnáceas": "ramnácea",
    "ramonadeiras": "ramonadeira",
    "ramos": "ramo",
    "ramosa": "ramoso",
    "ramosas": "ramoso",
    "ramosidades": "ramosidade",
    "ramosos": "ramoso",
    "rampantes": "rampante",
    "rampas": "rampa",
    "rampeada": "rampear",
    "rampeadas": "rampear",
    "rampeado": "rampear",
    "rampeados": "rampear",
    "rampeai": "rampear",
    "rampeais": "rampear",
    "rampeamo": "rampear",
    "rampeamos": "rampear",
    "rampeando": "rampear",
    "rampeara": "rampear",
    "rampearam": "rampear",
    "rampearas": "rampear",
    "rampearde": "rampear",
    "rampeardes": "rampear",
    "rampeare": "rampear",
    "rampearei": "rampear",
    "rampeareis": "rampear",
    "rampearem": "rampear",
    "rampearemos": "rampear",
    "rampeares": "rampear",
    "rampearia": "rampear",
    "rampeariam": "rampear",
    "rampearias": "rampear",
    "rampearmo": "rampear",
    "rampearmos": "rampear",
    "rampeará": "rampear",
    "rampearás": "rampear",
    "rampearão": "rampear",
    "rampearíamos": "rampear",
    "rampearíeis": "rampear",
    "rampeasse": "rampear",
    "rampeassem": "rampear",
    "rampeasses": "rampear",
    "rampeaste": "rampear",
    "rampeastes": "rampear",
    "rampeava": "rampear",
    "rampeavam": "rampear",
    "rampeavas": "rampear",
    "rampeei": "rampear",
    "rampeeis": "rampear",
    "rampeemo": "rampear",
    "rampeemos": "rampear",
    "rampeia": "rampear",
    "rampeiam": "rampear",
    "rampeias": "rampear",
    "rampeie": "rampear",
    "rampeiem": "rampear",
    "rampeies": "rampear",
    "rampeio": "rampear",
    "rampeou": "rampear",
    "rampeá": "rampear",
    "rampeámo": "rampear",
    "rampeámos": "rampear",
    "rampeáramo": "rampear",
    "rampeáramos": "rampear",
    "rampeárei": "rampear",
    "rampeáreis": "rampear",
    "rampeásseis": "rampear",
    "rampeássemos": "rampear",
    "rampeávamo": "rampear",
    "rampeávamos": "rampear",
    "rampeávei": "rampear",
    "rampeáveis": "rampear",
    "ramuda": "ramudo",
    "ramudas": "ramudo",
    "ramudos": "ramudo",
    "ramípara": "ramíparo",
    "ramíparas": "ramíparo",
    "ramíparos": "ramíparo",
    "ramúsculos": "ramúsculo",
    "rancalhos": "rancalho",
    "rancas": "ranca",
    "rance": "rançar",
    "rancei": "rançar",
    "ranceis": "rançar",
    "rancem": "rançar",
    "rancemo": "rançar",
    "rancemos": "rançar",
    "rances": "rançar",
    "rancesce": "rancescer",
    "rancescei": "rancescer",
    "rancesceis": "rancescer",
    "rancescem": "rancescer",
    "rancescemo": "rancescer",
    "rancescemos": "rancescer",
    "rancescendo": "rancescer",
    "rancescera": "rancescer",
    "rancesceram": "rancescer",
    "rancesceras": "rancescer",
    "rancescerdes": "rancescer",
    "rancescerei": "rancescer",
    "rancescereis": "rancescer",
    "rancescerem": "rancescer",
    "rancesceremos": "rancescer",
    "rancesceres": "rancescer",
    "rancesceria": "rancescer",
    "rancesceriam": "rancescer",
    "rancescerias": "rancescer",
    "rancescermo": "rancescer",
    "rancescermos": "rancescer",
    "rancescerá": "rancescer",
    "rancescerás": "rancescer",
    "rancescerão": "rancescer",
    "rancesceríamos": "rancescer",
    "rancesceríeis": "rancescer",
    "rancesces": "rancescer",
    "rancescesse": "rancescer",
    "rancescessem": "rancescer",
    "rancescesses": "rancescer",
    "rancesceste": "rancescer",
    "rancescestes": "rancescer",
    "rancesceu": "rancescer",
    "rancesci": "rancescer",
    "rancescia": "rancescer",
    "rancesciam": "rancescer",
    "rancescias": "rancescer",
    "rancescida": "rancescer",
    "rancescidas": "rancescer",
    "rancescido": "rancescer",
    "rancescidos": "rancescer",
    "rancescêramo": "rancescer",
    "rancescêramos": "rancescer",
    "rancescêreis": "rancescer",
    "rancescêsseis": "rancescer",
    "rancescêssemos": "rancescer",
    "rancescíamo": "rancescer",
    "rancescíamos": "rancescer",
    "rancescíeis": "rancescer",
    "rancesça": "rancescer",
    "rancesçais": "rancescer",
    "rancesçam": "rancescer",
    "rancesçamo": "rancescer",
    "rancesçamos": "rancescer",
    "rancesças": "rancescer",
    "rancesço": "rancescer",
    "ranchadas": "ranchada",
    "rancheira": "rancheiro",
    "rancheiras": "rancheiro",
    "rancheiros": "rancheiro",
    "rancheis": "ranchel",
    "ranchinho": "rancho",
    "ranchinhos": "rancho",
    "ranchito": "rancho",
    "ranchitos": "rancho",
    "ranchos": "rancho",
    "rancidezes": "rancidez",
    "rancolha": "rancolho",
    "rancolhas": "rancolho",
    "rancolhos": "rancolho",
    "rancores": "rancor",
    "rancorosa": "rancoroso",
    "rancorosas": "rancoroso",
    "rancorosos": "rancoroso",
    "randes": "rand",
    "rands": "rand",
    "ranes": "rane",
    "ranfastídeos": "ranfastídeo",
    "ranfos": "ranfo",
    "ranfástidas": "ranfástida",
    "ranfóides": "ranfóide",
    "range": "ranger",
    "rangedeira": "rangedor",
    "rangedeiras": "rangedor",
    "rangedora": "rangedor",
    "rangedoras": "rangedor",
    "rangedores": "rangedor",
    "rangei": "ranger",
    "rangeis": "ranger",
    "rangem": "ranger",
    "rangemo": "ranger",
    "rangemos": "ranger",
    "rangendo": "ranger",
    "rangentes": "rangente",
    "rangera": "ranger",
    "rangeram": "ranger",
    "rangeras": "ranger",
    "rangerdes": "ranger",
    "rangerei": "ranger",
    "rangereis": "ranger",
    "rangerem": "ranger",
    "rangeremos": "ranger",
    "rangeres": "ranger",
    "rangeria": "ranger",
    "rangeriam": "ranger",
    "rangerias": "ranger",
    "rangermo": "ranger",
    "rangermos": "ranger",
    "rangerá": "ranger",
    "rangerás": "ranger",
    "rangerão": "ranger",
    "rangeríamos": "ranger",
    "rangeríeis": "ranger",
    "ranges": "ranger",
    "rangesse": "ranger",
    "rangessem": "ranger",
    "rangesses": "ranger",
    "rangeste": "ranger",
    "rangestes": "ranger",
    "rangeu": "ranger",
    "rangi": "ranger",
    "rangia": "ranger",
    "rangiam": "ranger",
    "rangias": "ranger",
    "rangida": "ranger",
    "rangidas": "ranger",
    "rangido": "ranger",
    "rangidos": "rangido",
    "ranguinha": "ranguinhar",
    "ranguinhada": "ranguinhar",
    "ranguinhadas": "ranguinhar",
    "ranguinhado": "ranguinhar",
    "ranguinhados": "ranguinhar",
    "ranguinhai": "ranguinhar",
    "ranguinhais": "ranguinhar",
    "ranguinham": "ranguinhar",
    "ranguinhamo": "ranguinhar",
    "ranguinhamos": "ranguinhar",
    "ranguinhando": "ranguinhar",
    "ranguinhara": "ranguinhar",
    "ranguinharam": "ranguinhar",
    "ranguinharas": "ranguinhar",
    "ranguinhardes": "ranguinhar",
    "ranguinharei": "ranguinhar",
    "ranguinhareis": "ranguinhar",
    "ranguinharem": "ranguinhar",
    "ranguinharemos": "ranguinhar",
    "ranguinhares": "ranguinhar",
    "ranguinharia": "ranguinhar",
    "ranguinhariam": "ranguinhar",
    "ranguinharias": "ranguinhar",
    "ranguinharmo": "ranguinhar",
    "ranguinharmos": "ranguinhar",
    "ranguinhará": "ranguinhar",
    "ranguinharás": "ranguinhar",
    "ranguinharão": "ranguinhar",
    "ranguinharíamos": "ranguinhar",
    "ranguinharíeis": "ranguinhar",
    "ranguinhas": "ranguinhar",
    "ranguinhasse": "ranguinhar",
    "ranguinhassem": "ranguinhar",
    "ranguinhasses": "ranguinhar",
    "ranguinhaste": "ranguinhar",
    "ranguinhastes": "ranguinhar",
    "ranguinhava": "ranguinhar",
    "ranguinhavam": "ranguinhar",
    "ranguinhavas": "ranguinhar",
    "ranguinhe": "ranguinhar",
    "ranguinhei": "ranguinhar",
    "ranguinheis": "ranguinhar",
    "ranguinhem": "ranguinhar",
    "ranguinhemo": "ranguinhar",
    "ranguinhemos": "ranguinhar",
    "ranguinhes": "ranguinhar",
    "ranguinho": "ranguinhar",
    "ranguinhou": "ranguinhar",
    "ranguinhámo": "ranguinhar",
    "ranguinhámos": "ranguinhar",
    "ranguinháramo": "ranguinhar",
    "ranguinháramos": "ranguinhar",
    "ranguinháreis": "ranguinhar",
    "ranguinhásseis": "ranguinhar",
    "ranguinhássemos": "ranguinhar",
    "ranguinhávamo": "ranguinhar",
    "ranguinhávamos": "ranguinhar",
    "ranguinháveis": "ranguinhar",
    "rangêramo": "ranger",
    "rangêramos": "ranger",
    "rangêreis": "ranger",
    "rangêsseis": "ranger",
    "rangêssemos": "ranger",
    "rangíamo": "ranger",
    "rangíamos": "ranger",
    "rangíeis": "ranger",
    "rangíferes": "rangífer",
    "rangíferos": "rangífero",
    "ranha": "ranhar",
    "ranhada": "ranhar",
    "ranhadas": "ranhar",
    "ranhado": "ranhar",
    "ranhados": "ranhar",
    "ranhai": "ranhar",
    "ranhais": "ranhar",
    "ranham": "ranhar",
    "ranhamo": "ranhar",
    "ranhamos": "ranhar",
    "ranhando": "ranhar",
    "ranhara": "ranhar",
    "ranharam": "ranhar",
    "ranharas": "ranhar",
    "ranharde": "ranhar",
    "ranhardes": "ranhar",
    "ranhare": "ranhar",
    "ranharei": "ranhar",
    "ranhareis": "ranhar",
    "ranharem": "ranhar",
    "ranharemos": "ranhar",
    "ranhares": "ranhar",
    "ranharia": "ranhar",
    "ranhariam": "ranhar",
    "ranharias": "ranhar",
    "ranharmo": "ranhar",
    "ranharmos": "ranhar",
    "ranhará": "ranhar",
    "ranharás": "ranhar",
    "ranharão": "ranhar",
    "ranharíamos": "ranhar",
    "ranharíeis": "ranhar",
    "ranhas": "ranhar",
    "ranhasse": "ranhar",
    "ranhassem": "ranhar",
    "ranhasses": "ranhar",
    "ranhaste": "ranhar",
    "ranhastes": "ranhar",
    "ranhava": "ranhar",
    "ranhavam": "ranhar",
    "ranhavas": "ranhar",
    "ranhe": "ranhar",
    "ranhei": "ranhar",
    "ranheis": "ranhar",
    "ranhem": "ranhar",
    "ranhemo": "ranhar",
    "ranhemos": "ranhar",
    "ranhes": "ranhar",
    "ranhetas": "ranheta",
    "ranho": "ranhar",
    "ranhos": "ranho",
    "ranhosa": "ranhoso",
    "ranhosas": "ranhoso",
    "ranhosazinha": "ranhoso",
    "ranhosazinhas": "ranhoso",
    "ranhosazita": "ranhoso",
    "ranhosazitas": "ranhoso",
    "ranhosinha": "ranhoso",
    "ranhosinhas": "ranhoso",
    "ranhosinho": "ranhoso",
    "ranhosinhos": "ranhoso",
    "ranhosita": "ranhoso",
    "ranhositas": "ranhoso",
    "ranhosito": "ranhoso",
    "ranhositos": "ranhoso",
    "ranhosos": "ranhoso",
    "ranhosozinho": "ranhoso",
    "ranhosozinhos": "ranhoso",
    "ranhosozito": "ranhoso",
    "ranhosozitos": "ranhoso",
    "ranhosíssima": "ranhoso",
    "ranhosíssimas": "ranhoso",
    "ranhosíssimo": "ranhoso",
    "ranhosíssimos": "ranhoso",
    "ranhou": "ranhar",
    "ranhuras": "ranhura",
    "ranhá": "ranhar",
    "ranhámo": "ranhar",
    "ranhámos": "ranhar",
    "ranháramo": "ranhar",
    "ranháramos": "ranhar",
    "ranhárei": "ranhar",
    "ranháreis": "ranhar",
    "ranhásseis": "ranhar",
    "ranhássemos": "ranhar",
    "ranhávamo": "ranhar",
    "ranhávamos": "ranhar",
    "ranhávei": "ranhar",
    "ranháveis": "ranhar",
    "ranicultora": "ranicultor",
    "ranicultoras": "ranicultor",
    "ranicultores": "ranicultor",
    "raniculturas": "ranicultura",
    "ranilhas": "ranilha",
    "ranja": "ranger",
    "ranjais": "ranger",
    "ranjam": "ranger",
    "ranjamo": "ranger",
    "ranjamos": "ranger",
    "ranjas": "ranger",
    "ranjo": "ranger",
    "rankings": "ranking",
    "ranunculácea": "ranunculáceo",
    "ranunculáceas": "ranunculáceo",
    "ranunculáceos": "ranunculáceo",
    "ranzais": "ranzal",
    "ranzinzas": "ranzinza",
    "ranários": "ranário",
    "rança": "ranço",
    "rançada": "rançar",
    "rançadas": "rançar",
    "rançado": "rançar",
    "rançados": "rançar",
    "rançai": "rançar",
    "rançais": "rançar",
    "rançam": "rançar",
    "rançamo": "rançar",
    "rançamos": "rançar",
    "rançando": "rançar",
    "rançara": "rançar",
    "rançaram": "rançar",
    "rançaras": "rançar",
    "rançardes": "rançar",
    "rançarei": "rançar",
    "rançareis": "rançar",
    "rançarem": "rançar",
    "rançaremos": "rançar",
    "rançares": "rançar",
    "rançaria": "rançar",
    "rançariam": "rançar",
    "rançarias": "rançar",
    "rançarmo": "rançar",
    "rançarmos": "rançar",
    "rançará": "rançar",
    "rançarás": "rançar",
    "rançarão": "rançar",
    "rançaríamos": "rançar",
    "rançaríeis": "rançar",
    "ranças": "ranço",
    "rançasse": "rançar",
    "rançassem": "rançar",
    "rançasses": "rançar",
    "rançaste": "rançar",
    "rançastes": "rançar",
    "rançava": "rançar",
    "rançavam": "rançar",
    "rançavas": "rançar",
    "ranço": "rançar",
    "ranços": "ranço",
    "rançosa": "rançoso",
    "rançosas": "rançoso",
    "rançosos": "rançoso",
    "rançou": "rançar",
    "rançámo": "rançar",
    "rançámos": "rançar",
    "rançáramo": "rançar",
    "rançáramos": "rançar",
    "rançáreis": "rançar",
    "rançásseis": "rançar",
    "rançássemos": "rançar",
    "rançávamo": "rançar",
    "rançávamos": "rançar",
    "rançáveis": "rançar",
    "ranídeos": "ranídeo",
    "ranúnculos": "ranúnculo",
    "rao": "raer",
    "rapa": "rapar",
    "rapaces": "rapace",
    "rapacidades": "rapacidade",
    "rapada": "rapar",
    "rapadas": "rapar",
    "rapadeiras": "rapadeira",
    "rapadelas": "rapadela",
    "rapadelazinha": "rapadela",
    "rapadelazinhas": "rapadela",
    "rapadelazita": "rapadela",
    "rapadelazitas": "rapadela",
    "rapado": "rapar",
    "rapadoiras": "rapadoira",
    "rapadora": "rapador",
    "rapadoras": "rapador",
    "rapadores": "rapador",
    "rapados": "rapar",
    "rapadouras": "rapadoura",
    "rapaduras": "rapadura",
    "rapagões": "rapagão",
    "rapai": "rapar",
    "rapais": "rapar",
    "rapam": "rapar",
    "rapamo": "rapar",
    "rapamos": "rapar",
    "rapando": "rapar",
    "rapantes": "rapante",
    "rapapés": "rapapé",
    "rapara": "rapar",
    "raparam": "rapar",
    "raparas": "rapar",
    "raparde": "rapar",
    "rapardes": "rapar",
    "rapare": "rapar",
    "raparei": "rapar",
    "rapareis": "rapar",
    "raparem": "rapar",
    "raparemos": "rapar",
    "rapares": "rapar",
    "raparia": "rapar",
    "rapariam": "rapar",
    "raparias": "rapar",
    "rapariga": "rapaz",
    "raparigadas": "raparigada",
    "raparigas": "rapaz",
    "raparigaças": "raparigaça",
    "raparigos": "raparigo",
    "raparigotas": "raparigota",
    "rapariguinha": "rapaz",
    "rapariguinhas": "rapaz",
    "rapariguita": "rapaz",
    "rapariguitas": "rapaz",
    "raparigões": "raparigão",
    "raparmo": "rapar",
    "raparmos": "rapar",
    "rapará": "rapar",
    "raparás": "rapar",
    "raparão": "rapar",
    "raparíamos": "rapar",
    "raparíeis": "rapar",
    "rapas": "rapar",
    "rapasse": "rapar",
    "rapassem": "rapar",
    "rapasses": "rapar",
    "rapaste": "rapar",
    "rapastes": "rapar",
    "rapava": "rapar",
    "rapavam": "rapar",
    "rapavas": "rapar",
    "rapazadas": "rapazada",
    "rapazelhos": "rapazelho",
    "rapazes": "rapaz",
    "rapazetes": "rapazete",
    "rapaziadas": "rapaziada",
    "rapazices": "rapazice",
    "rapazinho": "rapaz",
    "rapazinhos": "rapazinho",
    "rapazios": "rapazio",
    "rapazito": "rapaz",
    "rapazitos": "rapaz",
    "rapazolas": "rapazola",
    "rapazonas": "rapazona",
    "rapazotes": "rapazote",
    "rape": "rapar",
    "rapei": "rapar",
    "rapeiras": "rapeira",
    "rapeis": "rapar",
    "rapelhas": "rapelha",
    "rapelhos": "rapelho",
    "rapem": "rapar",
    "rapemo": "rapar",
    "rapemos": "rapar",
    "rapes": "rapar",
    "rapicheis": "rapichel",
    "rapidazinha": "rápido",
    "rapidazinhas": "rápido",
    "rapidazita": "rápido",
    "rapidazitas": "rápido",
    "rapidezes": "rapidez",
    "rapidozinho": "rápido",
    "rapidozinhos": "rápido",
    "rapidozito": "rápido",
    "rapidozitos": "rápido",
    "rapidíssima": "rápido",
    "rapidíssimas": "rápido",
    "rapidíssimo": "rápido",
    "rapidíssimos": "rápido",
    "rapilhos": "rapilho",
    "rapina": "rapinar",
    "rapinada": "rapinar",
    "rapinadas": "rapinar",
    "rapinado": "rapinar",
    "rapinadora": "rapinador",
    "rapinadoras": "rapinador",
    "rapinadores": "rapinador",
    "rapinados": "rapinar",
    "rapinagens": "rapinagem",
    "rapinai": "rapinar",
    "rapinais": "rapinar",
    "rapinam": "rapinar",
    "rapinamo": "rapinar",
    "rapinamos": "rapinar",
    "rapinando": "rapinar",
    "rapinantes": "rapinante",
    "rapinanças": "rapinança",
    "rapinanços": "rapinanço",
    "rapinara": "rapinar",
    "rapinaram": "rapinar",
    "rapinaras": "rapinar",
    "rapinarde": "rapinar",
    "rapinardes": "rapinar",
    "rapinare": "rapinar",
    "rapinarei": "rapinar",
    "rapinareis": "rapinar",
    "rapinarem": "rapinar",
    "rapinaremos": "rapinar",
    "rapinares": "rapinar",
    "rapinaria": "rapinar",
    "rapinariam": "rapinar",
    "rapinarias": "rapinar",
    "rapinarmo": "rapinar",
    "rapinarmos": "rapinar",
    "rapinará": "rapinar",
    "rapinarás": "rapinar",
    "rapinarão": "rapinar",
    "rapinaríamos": "rapinar",
    "rapinaríeis": "rapinar",
    "rapinas": "rapinar",
    "rapinasse": "rapinar",
    "rapinassem": "rapinar",
    "rapinasses": "rapinar",
    "rapinaste": "rapinar",
    "rapinastes": "rapinar",
    "rapinava": "rapinar",
    "rapinavam": "rapinar",
    "rapinavas": "rapinar",
    "rapinações": "rapinação",
    "rapine": "rapinar",
    "rapinei": "rapinar",
    "rapineira": "rapineiro",
    "rapineiras": "rapineiro",
    "rapineiros": "rapineiro",
    "rapineis": "rapinar",
    "rapinem": "rapinar",
    "rapinemo": "rapinar",
    "rapinemos": "rapinar",
    "rapines": "rapinar",
    "rapinha": "rapinhar",
    "rapinhada": "rapinhar",
    "rapinhadas": "rapinhar",
    "rapinhado": "rapinhar",
    "rapinhados": "rapinhar",
    "rapinhai": "rapinhar",
    "rapinhais": "rapinhar",
    "rapinham": "rapinhar",
    "rapinhamo": "rapinhar",
    "rapinhamos": "rapinhar",
    "rapinhando": "rapinhar",
    "rapinhara": "rapinhar",
    "rapinharam": "rapinhar",
    "rapinharas": "rapinhar",
    "rapinharde": "rapinhar",
    "rapinhardes": "rapinhar",
    "rapinhare": "rapinhar",
    "rapinharei": "rapinhar",
    "rapinhareis": "rapinhar",
    "rapinharem": "rapinhar",
    "rapinharemos": "rapinhar",
    "rapinhares": "rapinhar",
    "rapinharia": "rapinhar",
    "rapinhariam": "rapinhar",
    "rapinharias": "rapinhar",
    "rapinharmo": "rapinhar",
    "rapinharmos": "rapinhar",
    "rapinhará": "rapinhar",
    "rapinharás": "rapinhar",
    "rapinharão": "rapinhar",
    "rapinharíamos": "rapinhar",
    "rapinharíeis": "rapinhar",
    "rapinhas": "rapinhar",
    "rapinhasse": "rapinhar",
    "rapinhassem": "rapinhar",
    "rapinhasses": "rapinhar",
    "rapinhaste": "rapinhar",
    "rapinhastes": "rapinhar",
    "rapinhava": "rapinhar",
    "rapinhavam": "rapinhar",
    "rapinhavas": "rapinhar",
    "rapinhe": "rapinhar",
    "rapinhei": "rapinhar",
    "rapinheis": "rapinhar",
    "rapinhem": "rapinhar",
    "rapinhemo": "rapinhar",
    "rapinhemos": "rapinhar",
    "rapinhes": "rapinhar",
    "rapinho": "rapinhar",
    "rapinhou": "rapinhar",
    "rapinhá": "rapinhar",
    "rapinhámo": "rapinhar",
    "rapinhámos": "rapinhar",
    "rapinháramo": "rapinhar",
    "rapinháramos": "rapinhar",
    "rapinhárei": "rapinhar",
    "rapinháreis": "rapinhar",
    "rapinhásseis": "rapinhar",
    "rapinhássemos": "rapinhar",
    "rapinhávamo": "rapinhar",
    "rapinhávamos": "rapinhar",
    "rapinhávei": "rapinhar",
    "rapinháveis": "rapinhar",
    "rapinices": "rapinice",
    "rapino": "rapinar",
    "rapinos": "rapino",
    "rapinou": "rapinar",
    "rapiná": "rapinar",
    "rapinámo": "rapinar",
    "rapinámos": "rapinar",
    "rapináramo": "rapinar",
    "rapináramos": "rapinar",
    "rapinárei": "rapinar",
    "rapináreis": "rapinar",
    "rapinásseis": "rapinar",
    "rapinássemos": "rapinar",
    "rapinávamo": "rapinar",
    "rapinávamos": "rapinar",
    "rapinávei": "rapinar",
    "rapináveis": "rapinar",
    "rapinâncias": "rapinância",
    "rapiocas": "rapioca",
    "rapioqueira": "rapioqueiro",
    "rapioqueiras": "rapioqueiro",
    "rapioqueiros": "rapioqueiro",
    "rapiscos": "rapisco",
    "rapistros": "rapistro",
    "rapo": "rapar",
    "raponços": "raponço",
    "raposa": "raposar",
    "raposada": "raposar",
    "raposadas": "raposar",
    "raposado": "raposar",
    "raposados": "raposar",
    "raposai": "raposar",
    "raposais": "raposar",
    "raposam": "raposar",
    "raposamo": "raposar",
    "raposamos": "raposar",
    "raposando": "raposar",
    "raposara": "raposar",
    "raposaram": "raposar",
    "raposaras": "raposar",
    "raposardes": "raposar",
    "raposarei": "raposar",
    "raposareis": "raposar",
    "raposarem": "raposar",
    "raposaremos": "raposar",
    "raposares": "raposar",
    "raposaria": "raposar",
    "raposariam": "raposar",
    "raposarias": "raposar",
    "raposarmo": "raposar",
    "raposarmos": "raposar",
    "raposará": "raposar",
    "raposarás": "raposar",
    "raposarão": "raposar",
    "raposaríamos": "raposar",
    "raposaríeis": "raposar",
    "raposas": "raposar",
    "raposasse": "raposar",
    "raposassem": "raposar",
    "raposasses": "raposar",
    "raposaste": "raposar",
    "raposastes": "raposar",
    "raposava": "raposar",
    "raposavam": "raposar",
    "raposavas": "raposar",
    "rapose": "raposar",
    "raposei": "raposar",
    "raposeira": "raposeiro",
    "raposeiras": "raposeiro",
    "raposeiros": "raposeiro",
    "raposeis": "raposar",
    "raposem": "raposar",
    "raposemo": "raposar",
    "raposemos": "raposar",
    "raposes": "raposar",
    "raposias": "raposia",
    "raposices": "raposice",
    "raposina": "raposino",
    "raposinas": "raposino",
    "raposinha": "raposinhar",
    "raposinhada": "raposinhar",
    "raposinhadas": "raposinhar",
    "raposinhado": "raposinhar",
    "raposinhados": "raposinhar",
    "raposinhai": "raposinhar",
    "raposinhais": "raposinhar",
    "raposinham": "raposinhar",
    "raposinhamo": "raposinhar",
    "raposinhamos": "raposinhar",
    "raposinhando": "raposinhar",
    "raposinhara": "raposinhar",
    "raposinharam": "raposinhar",
    "raposinharas": "raposinhar",
    "raposinhardes": "raposinhar",
    "raposinharei": "raposinhar",
    "raposinhareis": "raposinhar",
    "raposinharem": "raposinhar",
    "raposinharemos": "raposinhar",
    "raposinhares": "raposinhar",
    "raposinharia": "raposinhar",
    "raposinhariam": "raposinhar",
    "raposinharias": "raposinhar",
    "raposinharmo": "raposinhar",
    "raposinharmos": "raposinhar",
    "raposinhará": "raposinhar",
    "raposinharás": "raposinhar",
    "raposinharão": "raposinhar",
    "raposinharíamos": "raposinhar",
    "raposinharíeis": "raposinhar",
    "raposinhas": "raposinhar",
    "raposinhasse": "raposinhar",
    "raposinhassem": "raposinhar",
    "raposinhasses": "raposinhar",
    "raposinhaste": "raposinhar",
    "raposinhastes": "raposinhar",
    "raposinhava": "raposinhar",
    "raposinhavam": "raposinhar",
    "raposinhavas": "raposinhar",
    "raposinhe": "raposinhar",
    "raposinhei": "raposinhar",
    "raposinheis": "raposinhar",
    "raposinhem": "raposinhar",
    "raposinhemo": "raposinhar",
    "raposinhemos": "raposinhar",
    "raposinhes": "raposinhar",
    "raposinho": "raposinhar",
    "raposinhos": "raposinho",
    "raposinhou": "raposinhar",
    "raposinhámo": "raposinhar",
    "raposinhámos": "raposinhar",
    "raposinháramo": "raposinhar",
    "raposinháramos": "raposinhar",
    "raposinháreis": "raposinhar",
    "raposinhásseis": "raposinhar",
    "raposinhássemos": "raposinhar",
    "raposinhávamo": "raposinhar",
    "raposinhávamos": "raposinhar",
    "raposinháveis": "raposinhar",
    "raposinos": "raposino",
    "raposita": "raposa",
    "rapositas": "raposa",
    "raposo": "raposar",
    "raposos": "raposo",
    "raposou": "raposar",
    "raposámo": "raposar",
    "raposámos": "raposar",
    "raposáramo": "raposar",
    "raposáramos": "raposar",
    "raposáreis": "raposar",
    "raposásseis": "raposar",
    "raposássemos": "raposar",
    "raposávamo": "raposar",
    "raposávamos": "raposar",
    "raposáveis": "raposar",
    "rapou": "rapar",
    "rappers": "rapper",
    "raps": "rap",
    "rapsodistas": "rapsodista",
    "rapsodomancias": "rapsodomancia",
    "rapsodomantes": "rapsodomante",
    "rapsodos": "rapsodo",
    "rapsomântica": "rapsomântico",
    "rapsomânticas": "rapsomântico",
    "rapsomânticos": "rapsomântico",
    "rapsódias": "rapsódia",
    "rapsódica": "rapsódico",
    "rapsódicas": "rapsódico",
    "rapsódicos": "rapsódico",
    "rapta": "raptar",
    "raptada": "raptar",
    "raptadas": "raptar",
    "raptado": "raptar",
    "raptadora": "raptador",
    "raptadoras": "raptador",
    "raptadores": "raptador",
    "raptados": "raptar",
    "raptai": "raptar",
    "raptais": "raptar",
    "raptam": "raptar",
    "raptamo": "raptar",
    "raptamos": "raptar",
    "raptando": "raptar",
    "raptara": "raptar",
    "raptaram": "raptar",
    "raptaras": "raptar",
    "raptarde": "raptar",
    "raptardes": "raptar",
    "raptare": "raptar",
    "raptarei": "raptar",
    "raptareis": "raptar",
    "raptarem": "raptar",
    "raptaremos": "raptar",
    "raptares": "raptar",
    "raptaria": "raptar",
    "raptariam": "raptar",
    "raptarias": "raptar",
    "raptarmo": "raptar",
    "raptarmos": "raptar",
    "raptará": "raptar",
    "raptarás": "raptar",
    "raptarão": "raptar",
    "raptaríamos": "raptar",
    "raptaríeis": "raptar",
    "raptas": "raptar",
    "raptasse": "raptar",
    "raptassem": "raptar",
    "raptasses": "raptar",
    "raptaste": "raptar",
    "raptastes": "raptar",
    "raptava": "raptar",
    "raptavam": "raptar",
    "raptavas": "raptar",
    "rapte": "raptar",
    "raptei": "raptar",
    "rapteis": "raptar",
    "raptem": "raptar",
    "raptemo": "raptar",
    "raptemos": "raptar",
    "raptes": "raptar",
    "rapto": "raptar",
    "raptora": "raptor",
    "raptoras": "raptor",
    "raptores": "raptor",
    "raptos": "rapto",
    "raptou": "raptar",
    "raptá": "raptar",
    "raptámo": "raptar",
    "raptámos": "raptar",
    "raptáramo": "raptar",
    "raptáramos": "raptar",
    "raptárei": "raptar",
    "raptáreis": "raptar",
    "raptásseis": "raptar",
    "raptássemos": "raptar",
    "raptávamo": "raptar",
    "raptávamos": "raptar",
    "raptávei": "raptar",
    "raptáveis": "raptável",
    "rapá": "rapar",
    "rapámo": "rapar",
    "rapámos": "rapar",
    "rapáramo": "rapar",
    "rapáramos": "rapar",
    "rapárei": "rapar",
    "rapáreis": "rapar",
    "rapásseis": "rapar",
    "rapássemos": "rapar",
    "rapávamo": "rapar",
    "rapávamos": "rapar",
    "rapávei": "rapar",
    "rapáveis": "rapar",
    "rapés": "rapé",
    "rapôncios": "rapôncio",
    "rapônticos": "rapôntico",
    "rapões": "rapão",
    "rapúncios": "rapúncio",
    "raques": "raque",
    "raquetadas": "raquetada",
    "raquetas": "raqueta",
    "raquetes": "raquete",
    "raquialgias": "raquialgia",
    "raquiana": "raquiano",
    "raquianas": "raquiano",
    "raquianos": "raquiano",
    "raquidiana": "raquidiano",
    "raquidianas": "raquidiano",
    "raquidianos": "raquidiano",
    "raquiotomias": "raquiotomia",
    "raquiotómica": "raquiotómico",
    "raquiotómicas": "raquiotómico",
    "raquiotómicos": "raquiotómico",
    "raquitismos": "raquitismo",
    "raquiálgica": "raquiálgico",
    "raquiálgicas": "raquiálgico",
    "raquiálgicos": "raquiálgico",
    "raquídea": "raquídeo",
    "raquídeas": "raquídeo",
    "raquídeos": "raquídeo",
    "raquítica": "raquítico",
    "raquíticas": "raquítico",
    "raquíticos": "raquítico",
    "rara": "raro",
    "raras": "raro",
    "rareada": "rarear",
    "rareadas": "rarear",
    "rareado": "rarear",
    "rareados": "rarear",
    "rareai": "rarear",
    "rareais": "rarear",
    "rareamentos": "rareamento",
    "rareamo": "rarear",
    "rareamos": "rarear",
    "rareando": "rarear",
    "rareara": "rarear",
    "rarearam": "rarear",
    "rarearas": "rarear",
    "rarearde": "rarear",
    "rareardes": "rarear",
    "rareare": "rarear",
    "rarearei": "rarear",
    "rareareis": "rarear",
    "rarearem": "rarear",
    "rarearemos": "rarear",
    "rareares": "rarear",
    "rarearia": "rarear",
    "rareariam": "rarear",
    "rarearias": "rarear",
    "rarearmo": "rarear",
    "rarearmos": "rarear",
    "rareará": "rarear",
    "rarearás": "rarear",
    "rarearão": "rarear",
    "rarearíamos": "rarear",
    "rarearíeis": "rarear",
    "rareasse": "rarear",
    "rareassem": "rarear",
    "rareasses": "rarear",
    "rareaste": "rarear",
    "rareastes": "rarear",
    "rareava": "rarear",
    "rareavam": "rarear",
    "rareavas": "rarear",
    "rareei": "rarear",
    "rareeis": "rarear",
    "rareemo": "rarear",
    "rareemos": "rarear",
    "rarefacientes": "rarefaciente",
    "rarefacta": "rarefacto",
    "rarefactas": "rarefacto",
    "rarefactiva": "rarefactivo",
    "rarefactivas": "rarefactivo",
    "rarefactivos": "rarefactivo",
    "rarefactora": "rarefactor",
    "rarefactoras": "rarefactor",
    "rarefactores": "rarefactor",
    "rarefactos": "rarefacto",
    "rarefactíveis": "rarefactível",
    "rarefacções": "rarefacção",
    "rarefarei": "rarefazer",
    "rarefareis": "rarefazer",
    "rarefaremos": "rarefazer",
    "rarefaria": "rarefazer",
    "rarefariam": "rarefazer",
    "rarefarias": "rarefazer",
    "rarefará": "rarefazer",
    "rarefarás": "rarefazer",
    "rarefarão": "rarefazer",
    "rarefaríamos": "rarefazer",
    "rarefaríeis": "rarefazer",
    "rarefaz": "rarefazer",
    "rarefaze": "rarefazer",
    "rarefazei": "rarefazer",
    "rarefazeis": "rarefazer",
    "rarefazem": "rarefazer",
    "rarefazemo": "rarefazer",
    "rarefazemos": "rarefazer",
    "rarefazendo": "rarefazer",
    "rarefazerde": "rarefazer",
    "rarefazerdes": "rarefazer",
    "rarefazere": "rarefazer",
    "rarefazerem": "rarefazer",
    "rarefazeres": "rarefazer",
    "rarefazermo": "rarefazer",
    "rarefazermos": "rarefazer",
    "rarefazes": "rarefazer",
    "rarefazia": "rarefazer",
    "rarefaziam": "rarefazer",
    "rarefazias": "rarefazer",
    "rarefazê": "rarefazer",
    "rarefazíamo": "rarefazer",
    "rarefazíamos": "rarefazer",
    "rarefazíei": "rarefazer",
    "rarefazíeis": "rarefazer",
    "rarefaça": "rarefazer",
    "rarefaçais": "rarefazer",
    "rarefaçam": "rarefazer",
    "rarefaçamo": "rarefazer",
    "rarefaçamos": "rarefazer",
    "rarefaças": "rarefazer",
    "rarefaço": "rarefazer",
    "rarefeita": "rarefeito",
    "rarefeitas": "rarefeito",
    "rarefeito": "rarefazer",
    "rarefeitos": "rarefeito",
    "rarefez": "rarefazer",
    "rarefi": "rarefazer",
    "rarefiz": "rarefazer",
    "rarefizemo": "rarefazer",
    "rarefizemos": "rarefazer",
    "rarefizer": "rarefazer",
    "rarefizera": "rarefazer",
    "rarefizeram": "rarefazer",
    "rarefizeras": "rarefazer",
    "rarefizerdes": "rarefazer",
    "rarefizerem": "rarefazer",
    "rarefizeres": "rarefazer",
    "rarefizermos": "rarefazer",
    "rarefizesse": "rarefazer",
    "rarefizessem": "rarefazer",
    "rarefizesses": "rarefazer",
    "rarefizeste": "rarefazer",
    "rarefizestes": "rarefazer",
    "rarefizéramo": "rarefazer",
    "rarefizéramos": "rarefazer",
    "rarefizérei": "rarefazer",
    "rarefizéreis": "rarefazer",
    "rarefizésseis": "rarefazer",
    "rarefizéssemos": "rarefazer",
    "rarefá": "rarefazer",
    "rarefê": "rarefazer",
    "rareia": "rarear",
    "rareiam": "rarear",
    "rareias": "rarear",
    "rareie": "rarear",
    "rareiem": "rarear",
    "rareies": "rarear",
    "rareio": "rarear",
    "rareou": "rarear",
    "rarescentes": "rarescente",
    "rarescências": "rarescência",
    "rarezas": "rareza",
    "rareá": "rarear",
    "rareámo": "rarear",
    "rareámos": "rarear",
    "rareáramo": "rarear",
    "rareáramos": "rarear",
    "rareárei": "rarear",
    "rareáreis": "rarear",
    "rareásseis": "rarear",
    "rareássemos": "rarear",
    "rareávamo": "rarear",
    "rareávamos": "rarear",
    "rareávei": "rarear",
    "rareáveis": "rarear",
    "rarfólia": "rarfólio",
    "rarfólias": "rarfólio",
    "rarfólios": "rarfólio",
    "raridades": "raridade",
    "rariflora": "rarifloro",
    "rarifloras": "rarifloro",
    "rarifloros": "rarifloro",
    "rarifoliada": "rarifoliado",
    "rarifoliadas": "rarifoliado",
    "rarifoliados": "rarifoliado",
    "raros": "raro",
    "rarípila": "rarípilo",
    "rarípilas": "rarípilo",
    "rarípilos": "rarípilo",
    "raríssima": "raro",
    "raríssimas": "raro",
    "raríssimo": "raro",
    "raríssimos": "raro",
    "rasa": "raso",
    "rasada": "rasar",
    "rasadas": "rasar",
    "rasado": "rasar",
    "rasados": "rasar",
    "rasaduras": "rasadura",
    "rasai": "rasar",
    "rasais": "rasar",
    "rasam": "rasar",
    "rasamo": "rasar",
    "rasamos": "rasar",
    "rasando": "rasar",
    "rasantes": "rasante",
    "rasara": "rasar",
    "rasaram": "rasar",
    "rasaras": "rasar",
    "rasarde": "rasar",
    "rasardes": "rasar",
    "rasare": "rasar",
    "rasarei": "rasar",
    "rasareis": "rasar",
    "rasarem": "rasar",
    "rasaremos": "rasar",
    "rasares": "rasar",
    "rasaria": "rasar",
    "rasariam": "rasar",
    "rasarias": "rasar",
    "rasarmo": "rasar",
    "rasarmos": "rasar",
    "rasará": "rasar",
    "rasarás": "rasar",
    "rasarão": "rasar",
    "rasaríamos": "rasar",
    "rasaríeis": "rasar",
    "rasas": "raso",
    "rasasse": "rasar",
    "rasassem": "rasar",
    "rasasses": "rasar",
    "rasaste": "rasar",
    "rasastes": "rasar",
    "rasava": "rasar",
    "rasavam": "rasar",
    "rasavas": "rasar",
    "rasca": "rascar",
    "rascada": "rascar",
    "rascadas": "rascar",
    "rascado": "rascar",
    "rascadores": "rascador",
    "rascados": "rascar",
    "rascaduras": "rascadura",
    "rascai": "rascar",
    "rascais": "rascar",
    "rascam": "rascar",
    "rascamo": "rascar",
    "rascamos": "rascar",
    "rascando": "rascar",
    "rascantes": "rascante",
    "rascara": "rascar",
    "rascaram": "rascar",
    "rascaras": "rascar",
    "rascarde": "rascar",
    "rascardes": "rascar",
    "rascare": "rascar",
    "rascarei": "rascar",
    "rascareis": "rascar",
    "rascarem": "rascar",
    "rascaremos": "rascar",
    "rascares": "rascar",
    "rascaria": "rascar",
    "rascariam": "rascar",
    "rascarias": "rascar",
    "rascarmo": "rascar",
    "rascarmos": "rascar",
    "rascará": "rascar",
    "rascarás": "rascar",
    "rascarão": "rascar",
    "rascaríamos": "rascar",
    "rascaríeis": "rascar",
    "rascas": "rascar",
    "rascasse": "rascar",
    "rascassem": "rascar",
    "rascasses": "rascar",
    "rascassos": "rascasso",
    "rascaste": "rascar",
    "rascastes": "rascar",
    "rascava": "rascar",
    "rascavam": "rascar",
    "rascavas": "rascar",
    "rasco": "rascar",
    "rascoa": "rascão",
    "rascoas": "rascoa",
    "rascoeiras": "rascoeira",
    "rascoeiros": "rascoeiro",
    "rascou": "rascar",
    "rascoíces": "rascoíce",
    "rascunha": "rascunhar",
    "rascunhada": "rascunhar",
    "rascunhadas": "rascunhar",
    "rascunhado": "rascunhar",
    "rascunhados": "rascunhar",
    "rascunhadíssima": "rascunhado",
    "rascunhadíssimas": "rascunhado",
    "rascunhadíssimo": "rascunhado",
    "rascunhadíssimos": "rascunhado",
    "rascunhai": "rascunhar",
    "rascunhais": "rascunhar",
    "rascunham": "rascunhar",
    "rascunhamo": "rascunhar",
    "rascunhamos": "rascunhar",
    "rascunhando": "rascunhar",
    "rascunhara": "rascunhar",
    "rascunharam": "rascunhar",
    "rascunharas": "rascunhar",
    "rascunharde": "rascunhar",
    "rascunhardes": "rascunhar",
    "rascunhare": "rascunhar",
    "rascunharei": "rascunhar",
    "rascunhareis": "rascunhar",
    "rascunharem": "rascunhar",
    "rascunharemos": "rascunhar",
    "rascunhares": "rascunhar",
    "rascunharia": "rascunhar",
    "rascunhariam": "rascunhar",
    "rascunharias": "rascunhar",
    "rascunharmo": "rascunhar",
    "rascunharmos": "rascunhar",
    "rascunhará": "rascunhar",
    "rascunharás": "rascunhar",
    "rascunharão": "rascunhar",
    "rascunharíamos": "rascunhar",
    "rascunharíeis": "rascunhar",
    "rascunhas": "rascunhar",
    "rascunhasse": "rascunhar",
    "rascunhassem": "rascunhar",
    "rascunhasses": "rascunhar",
    "rascunhaste": "rascunhar",
    "rascunhastes": "rascunhar",
    "rascunhava": "rascunhar",
    "rascunhavam": "rascunhar",
    "rascunhavas": "rascunhar",
    "rascunhe": "rascunhar",
    "rascunhei": "rascunhar",
    "rascunheis": "rascunhar",
    "rascunhem": "rascunhar",
    "rascunhemo": "rascunhar",
    "rascunhemos": "rascunhar",
    "rascunhes": "rascunhar",
    "rascunho": "rascunhar",
    "rascunhos": "rascunho",
    "rascunhou": "rascunhar",
    "rascunhá": "rascunhar",
    "rascunhámo": "rascunhar",
    "rascunhámos": "rascunhar",
    "rascunháramo": "rascunhar",
    "rascunháramos": "rascunhar",
    "rascunhárei": "rascunhar",
    "rascunháreis": "rascunhar",
    "rascunhásseis": "rascunhar",
    "rascunhássemos": "rascunhar",
    "rascunhávamo": "rascunhar",
    "rascunhávamos": "rascunhar",
    "rascunhávei": "rascunhar",
    "rascunháveis": "rascunhar",
    "rascá": "rascar",
    "rascámo": "rascar",
    "rascámos": "rascar",
    "rascáramo": "rascar",
    "rascáramos": "rascar",
    "rascárei": "rascar",
    "rascáreis": "rascar",
    "rascásseis": "rascar",
    "rascássemos": "rascar",
    "rascávamo": "rascar",
    "rascávamos": "rascar",
    "rascávei": "rascar",
    "rascáveis": "rascar",
    "rascâncias": "rascância",
    "rascões": "rascão",
    "rase": "rasar",
    "rasei": "rasar",
    "raseira": "raseiro",
    "raseiras": "raseiro",
    "raseiros": "raseiro",
    "raseis": "rasar",
    "rasem": "rasar",
    "rasemo": "rasar",
    "rasemos": "rasar",
    "rases": "rasar",
    "rasga": "rasgar",
    "rasgada": "rasgar",
    "rasgadas": "rasgar",
    "rasgadazinha": "rasgado",
    "rasgadazinhas": "rasgado",
    "rasgadazita": "rasgado",
    "rasgadazitas": "rasgado",
    "rasgadelas": "rasgadela",
    "rasgadinha": "rasgado",
    "rasgadinhas": "rasgado",
    "rasgadinho": "rasgado",
    "rasgadinhos": "rasgado",
    "rasgadita": "rasgado",
    "rasgaditas": "rasgado",
    "rasgadito": "rasgado",
    "rasgaditos": "rasgado",
    "rasgado": "rasgar",
    "rasgadora": "rasgador",
    "rasgadoras": "rasgador",
    "rasgadores": "rasgador",
    "rasgados": "rasgar",
    "rasgadozinho": "rasgado",
    "rasgadozinhos": "rasgado",
    "rasgadozito": "rasgado",
    "rasgadozitos": "rasgado",
    "rasgaduras": "rasgadura",
    "rasgadíssima": "rasgado",
    "rasgadíssimas": "rasgado",
    "rasgadíssimo": "rasgado",
    "rasgadíssimos": "rasgado",
    "rasgai": "rasgar",
    "rasgais": "rasgar",
    "rasgam": "rasgar",
    "rasgamentos": "rasgamento",
    "rasgamo": "rasgar",
    "rasgamos": "rasgar",
    "rasgando": "rasgar",
    "rasgara": "rasgar",
    "rasgaram": "rasgar",
    "rasgaras": "rasgar",
    "rasgarde": "rasgar",
    "rasgardes": "rasgar",
    "rasgare": "rasgar",
    "rasgarei": "rasgar",
    "rasgareis": "rasgar",
    "rasgarem": "rasgar",
    "rasgaremos": "rasgar",
    "rasgares": "rasgar",
    "rasgaria": "rasgar",
    "rasgariam": "rasgar",
    "rasgarias": "rasgar",
    "rasgarmo": "rasgar",
    "rasgarmos": "rasgar",
    "rasgará": "rasgar",
    "rasgarás": "rasgar",
    "rasgarão": "rasgar",
    "rasgaríamos": "rasgar",
    "rasgaríeis": "rasgar",
    "rasgas": "rasgar",
    "rasgasse": "rasgar",
    "rasgassem": "rasgar",
    "rasgasses": "rasgar",
    "rasgaste": "rasgar",
    "rasgastes": "rasgar",
    "rasgava": "rasgar",
    "rasgavam": "rasgar",
    "rasgavas": "rasgar",
    "rasgo": "rasgar",
    "rasgos": "rasgo",
    "rasgou": "rasgar",
    "rasgue": "rasgar",
    "rasguei": "rasgar",
    "rasgueis": "rasgar",
    "rasguem": "rasgar",
    "rasguemo": "rasgar",
    "rasguemos": "rasgar",
    "rasgues": "rasgue",
    "rasgá": "rasgar",
    "rasgámo": "rasgar",
    "rasgámos": "rasgar",
    "rasgáramo": "rasgar",
    "rasgáramos": "rasgar",
    "rasgárei": "rasgar",
    "rasgáreis": "rasgar",
    "rasgásseis": "rasgar",
    "rasgássemos": "rasgar",
    "rasgávamo": "rasgar",
    "rasgávamos": "rasgar",
    "rasgávei": "rasgar",
    "rasgáveis": "rasgável",
    "rasgões": "rasgão",
    "rasinha": "raso",
    "rasinhas": "raso",
    "rasinho": "raso",
    "rasinhos": "raso",
    "rasita": "raso",
    "rasitas": "raso",
    "rasito": "raso",
    "rasitos": "raso",
    "raso": "rasar",
    "rasoira": "rasoirar",
    "rasoirada": "rasoirar",
    "rasoiradas": "rasoirar",
    "rasoirado": "rasoirar",
    "rasoirados": "rasoirar",
    "rasoirai": "rasoirar",
    "rasoirais": "rasoirar",
    "rasoiram": "rasoirar",
    "rasoiramo": "rasoirar",
    "rasoiramos": "rasoirar",
    "rasoirando": "rasoirar",
    "rasoirara": "rasoirar",
    "rasoiraram": "rasoirar",
    "rasoiraras": "rasoirar",
    "rasoirarde": "rasoirar",
    "rasoirardes": "rasoirar",
    "rasoirare": "rasoirar",
    "rasoirarei": "rasoirar",
    "rasoirareis": "rasoirar",
    "rasoirarem": "rasoirar",
    "rasoiraremos": "rasoirar",
    "rasoirares": "rasoirar",
    "rasoiraria": "rasoirar",
    "rasoirariam": "rasoirar",
    "rasoirarias": "rasoirar",
    "rasoirarmo": "rasoirar",
    "rasoirarmos": "rasoirar",
    "rasoirará": "rasoirar",
    "rasoirarás": "rasoirar",
    "rasoirarão": "rasoirar",
    "rasoiraríamos": "rasoirar",
    "rasoiraríeis": "rasoirar",
    "rasoiras": "rasoirar",
    "rasoirasse": "rasoirar",
    "rasoirassem": "rasoirar",
    "rasoirasses": "rasoirar",
    "rasoiraste": "rasoirar",
    "rasoirastes": "rasoirar",
    "rasoirava": "rasoirar",
    "rasoiravam": "rasoirar",
    "rasoiravas": "rasoirar",
    "rasoire": "rasoirar",
    "rasoirei": "rasoirar",
    "rasoireis": "rasoirar",
    "rasoirem": "rasoirar",
    "rasoiremo": "rasoirar",
    "rasoiremos": "rasoirar",
    "rasoires": "rasoirar",
    "rasoiro": "rasoirar",
    "rasoirou": "rasoirar",
    "rasoirá": "rasoirar",
    "rasoirámo": "rasoirar",
    "rasoirámos": "rasoirar",
    "rasoiráramo": "rasoirar",
    "rasoiráramos": "rasoirar",
    "rasoirárei": "rasoirar",
    "rasoiráreis": "rasoirar",
    "rasoirásseis": "rasoirar",
    "rasoirássemos": "rasoirar",
    "rasoirávamo": "rasoirar",
    "rasoirávamos": "rasoirar",
    "rasoirávei": "rasoirar",
    "rasoiráveis": "rasoirar",
    "rasos": "raso",
    "rasou": "rasar",
    "rasouras": "rasoura",
    "raspa": "raspar",
    "raspada": "raspar",
    "raspadas": "raspar",
    "raspadeiras": "raspadeira",
    "raspadelas": "raspadela",
    "raspadinhas": "raspadinha",
    "raspado": "raspar",
    "raspadora": "raspador",
    "raspadoras": "raspador",
    "raspadores": "raspador",
    "raspados": "raspar",
    "raspaduras": "raspadura",
    "raspagens": "raspagem",
    "raspai": "raspar",
    "raspais": "raspar",
    "raspam": "raspar",
    "raspamo": "raspar",
    "raspamos": "raspar",
    "raspando": "raspar",
    "raspanetes": "raspanete",
    "raspanças": "raspança",
    "raspanços": "raspanço",
    "raspara": "raspar",
    "rasparam": "raspar",
    "rasparas": "raspar",
    "rasparde": "raspar",
    "raspardes": "raspar",
    "raspare": "raspar",
    "rasparei": "raspar",
    "raspareis": "raspar",
    "rasparem": "raspar",
    "rasparemos": "raspar",
    "raspares": "raspar",
    "rasparia": "raspar",
    "raspariam": "raspar",
    "rasparias": "raspar",
    "rasparmo": "raspar",
    "rasparmos": "raspar",
    "raspará": "raspar",
    "rasparás": "raspar",
    "rasparão": "raspar",
    "rasparíamos": "raspar",
    "rasparíeis": "raspar",
    "raspas": "raspar",
    "raspasse": "raspar",
    "raspassem": "raspar",
    "raspasses": "raspar",
    "raspaste": "raspar",
    "raspastes": "raspar",
    "raspava": "raspar",
    "raspavam": "raspar",
    "raspavas": "raspar",
    "raspe": "raspar",
    "raspei": "raspar",
    "raspeis": "raspar",
    "raspem": "raspar",
    "raspemo": "raspar",
    "raspemos": "raspar",
    "raspes": "raspar",
    "raspilhas": "raspilha",
    "raspinhadeiras": "raspinhadeira",
    "raspo": "raspar",
    "raspou": "raspar",
    "raspá": "raspar",
    "raspámo": "raspar",
    "raspámos": "raspar",
    "raspáramo": "raspar",
    "raspáramos": "raspar",
    "raspárei": "raspar",
    "raspáreis": "raspar",
    "raspásseis": "raspar",
    "raspássemos": "raspar",
    "raspávamo": "raspar",
    "raspávamos": "raspar",
    "raspávei": "raspar",
    "raspáveis": "raspável",
    "raspões": "raspão",
    "rasque": "rascar",
    "rasquei": "rascar",
    "rasqueis": "rascar",
    "rasquem": "rascar",
    "rasquemo": "rascar",
    "rasquemos": "rascar",
    "rasques": "rascar",
    "rasquetas": "rasqueta",
    "rasquinha": "rasca",
    "rasquinhas": "rasca",
    "rasquita": "rasca",
    "rasquitas": "rasca",
    "rasquíssima": "rasca",
    "rasquíssimas": "rasca",
    "rasquíssimo": "rasca",
    "rasquíssimos": "rasca",
    "rasteada": "rastear",
    "rasteadas": "rastear",
    "rasteado": "rastear",
    "rasteados": "rastear",
    "rasteai": "rastear",
    "rasteais": "rastear",
    "rasteamo": "rastear",
    "rasteamos": "rastear",
    "rasteando": "rastear",
    "rasteara": "rastear",
    "rastearam": "rastear",
    "rastearas": "rastear",
    "rasteardes": "rastear",
    "rastearei": "rastear",
    "rasteareis": "rastear",
    "rastearem": "rastear",
    "rastearemos": "rastear",
    "rasteares": "rastear",
    "rastearia": "rastear",
    "rasteariam": "rastear",
    "rastearias": "rastear",
    "rastearmo": "rastear",
    "rastearmos": "rastear",
    "rasteará": "rastear",
    "rastearás": "rastear",
    "rastearão": "rastear",
    "rastearíamos": "rastear",
    "rastearíeis": "rastear",
    "rasteasse": "rastear",
    "rasteassem": "rastear",
    "rasteasses": "rastear",
    "rasteaste": "rastear",
    "rasteastes": "rastear",
    "rasteava": "rastear",
    "rasteavam": "rastear",
    "rasteavas": "rastear",
    "rasteei": "rastear",
    "rasteeis": "rastear",
    "rasteemo": "rastear",
    "rasteemos": "rastear",
    "rasteia": "rastear",
    "rasteiam": "rastear",
    "rasteias": "rastear",
    "rasteie": "rastear",
    "rasteiem": "rastear",
    "rasteies": "rastear",
    "rasteio": "rastear",
    "rasteira": "rasteiro",
    "rasteirada": "rasteirado",
    "rasteiradas": "rasteirado",
    "rasteirados": "rasteirado",
    "rasteiras": "rasteiro",
    "rasteirinhas": "rasteirinha",
    "rasteiros": "rasteiro",
    "rasteja": "rastejar",
    "rastejada": "rastejar",
    "rastejadas": "rastejar",
    "rastejado": "rastejar",
    "rastejadora": "rastejador",
    "rastejadoras": "rastejador",
    "rastejadores": "rastejador",
    "rastejados": "rastejar",
    "rastejaduras": "rastejadura",
    "rastejai": "rastejar",
    "rastejais": "rastejar",
    "rastejam": "rastejar",
    "rastejamentos": "rastejamento",
    "rastejamo": "rastejar",
    "rastejamos": "rastejar",
    "rastejando": "rastejar",
    "rastejantes": "rastejante",
    "rastejara": "rastejar",
    "rastejaram": "rastejar",
    "rastejaras": "rastejar",
    "rastejarde": "rastejar",
    "rastejardes": "rastejar",
    "rastejare": "rastejar",
    "rastejarei": "rastejar",
    "rastejareis": "rastejar",
    "rastejarem": "rastejar",
    "rastejaremos": "rastejar",
    "rastejares": "rastejar",
    "rastejaria": "rastejar",
    "rastejariam": "rastejar",
    "rastejarias": "rastejar",
    "rastejarmo": "rastejar",
    "rastejarmos": "rastejar",
    "rastejará": "rastejar",
    "rastejarás": "rastejar",
    "rastejarão": "rastejar",
    "rastejaríamos": "rastejar",
    "rastejaríeis": "rastejar",
    "rastejas": "rastejar",
    "rastejasse": "rastejar",
    "rastejassem": "rastejar",
    "rastejasses": "rastejar",
    "rastejaste": "rastejar",
    "rastejastes": "rastejar",
    "rastejava": "rastejar",
    "rastejavam": "rastejar",
    "rastejavas": "rastejar",
    "rasteje": "rastejar",
    "rastejei": "rastejar",
    "rastejeis": "rastejar",
    "rastejem": "rastejar",
    "rastejemo": "rastejar",
    "rastejemos": "rastejar",
    "rastejes": "rastejar",
    "rastejo": "rastejar",
    "rastejos": "rastejo",
    "rastejou": "rastejar",
    "rastejá": "rastejar",
    "rastejámo": "rastejar",
    "rastejámos": "rastejar",
    "rastejáramo": "rastejar",
    "rastejáramos": "rastejar",
    "rastejárei": "rastejar",
    "rastejáreis": "rastejar",
    "rastejásseis": "rastejar",
    "rastejássemos": "rastejar",
    "rastejávamo": "rastejar",
    "rastejávamos": "rastejar",
    "rastejávei": "rastejar",
    "rastejáveis": "rastejar",
    "rastelos": "rastelo",
    "rasteou": "rastear",
    "rasteámo": "rastear",
    "rasteámos": "rastear",
    "rasteáramo": "rastear",
    "rasteáramos": "rastear",
    "rasteáreis": "rastear",
    "rasteásseis": "rastear",
    "rasteássemos": "rastear",
    "rasteávamo": "rastear",
    "rasteávamos": "rastear",
    "rasteáveis": "rastear",
    "rastilha": "rastilhar",
    "rastilhada": "rastilhar",
    "rastilhadas": "rastilhar",
    "rastilhado": "rastilhar",
    "rastilhados": "rastilhar",
    "rastilhai": "rastilhar",
    "rastilhais": "rastilhar",
    "rastilham": "rastilhar",
    "rastilhamo": "rastilhar",
    "rastilhamos": "rastilhar",
    "rastilhando": "rastilhar",
    "rastilhara": "rastilhar",
    "rastilharam": "rastilhar",
    "rastilharas": "rastilhar",
    "rastilharde": "rastilhar",
    "rastilhardes": "rastilhar",
    "rastilhare": "rastilhar",
    "rastilharei": "rastilhar",
    "rastilhareis": "rastilhar",
    "rastilharem": "rastilhar",
    "rastilharemos": "rastilhar",
    "rastilhares": "rastilhar",
    "rastilharia": "rastilhar",
    "rastilhariam": "rastilhar",
    "rastilharias": "rastilhar",
    "rastilharmo": "rastilhar",
    "rastilharmos": "rastilhar",
    "rastilhará": "rastilhar",
    "rastilharás": "rastilhar",
    "rastilharão": "rastilhar",
    "rastilharíamos": "rastilhar",
    "rastilharíeis": "rastilhar",
    "rastilhas": "rastilhar",
    "rastilhasse": "rastilhar",
    "rastilhassem": "rastilhar",
    "rastilhasses": "rastilhar",
    "rastilhaste": "rastilhar",
    "rastilhastes": "rastilhar",
    "rastilhava": "rastilhar",
    "rastilhavam": "rastilhar",
    "rastilhavas": "rastilhar",
    "rastilhe": "rastilhar",
    "rastilhei": "rastilhar",
    "rastilheis": "rastilhar",
    "rastilhem": "rastilhar",
    "rastilhemo": "rastilhar",
    "rastilhemos": "rastilhar",
    "rastilhes": "rastilhar",
    "rastilho": "rastilhar",
    "rastilhos": "rastilho",
    "rastilhou": "rastilhar",
    "rastilhá": "rastilhar",
    "rastilhámo": "rastilhar",
    "rastilhámos": "rastilhar",
    "rastilháramo": "rastilhar",
    "rastilháramos": "rastilhar",
    "rastilhárei": "rastilhar",
    "rastilháreis": "rastilhar",
    "rastilhásseis": "rastilhar",
    "rastilhássemos": "rastilhar",
    "rastilhávamo": "rastilhar",
    "rastilhávamos": "rastilhar",
    "rastilhávei": "rastilhar",
    "rastilháveis": "rastilhar",
    "rastolha": "rastolhar",
    "rastolhada": "rastolhar",
    "rastolhadas": "rastolhar",
    "rastolhado": "rastolhar",
    "rastolhados": "rastolhar",
    "rastolhai": "rastolhar",
    "rastolhais": "rastolhar",
    "rastolham": "rastolhar",
    "rastolhamo": "rastolhar",
    "rastolhamos": "rastolhar",
    "rastolhando": "rastolhar",
    "rastolhara": "rastolhar",
    "rastolharam": "rastolhar",
    "rastolharas": "rastolhar",
    "rastolhardes": "rastolhar",
    "rastolharei": "rastolhar",
    "rastolhareis": "rastolhar",
    "rastolharem": "rastolhar",
    "rastolharemos": "rastolhar",
    "rastolhares": "rastolhar",
    "rastolharia": "rastolhar",
    "rastolhariam": "rastolhar",
    "rastolharias": "rastolhar",
    "rastolharmo": "rastolhar",
    "rastolharmos": "rastolhar",
    "rastolhará": "rastolhar",
    "rastolharás": "rastolhar",
    "rastolharão": "rastolhar",
    "rastolharíamos": "rastolhar",
    "rastolharíeis": "rastolhar",
    "rastolhas": "rastolhar",
    "rastolhasse": "rastolhar",
    "rastolhassem": "rastolhar",
    "rastolhasses": "rastolhar",
    "rastolhaste": "rastolhar",
    "rastolhastes": "rastolhar",
    "rastolhava": "rastolhar",
    "rastolhavam": "rastolhar",
    "rastolhavas": "rastolhar",
    "rastolhe": "rastolhar",
    "rastolhei": "rastolhar",
    "rastolheis": "rastolhar",
    "rastolhem": "rastolhar",
    "rastolhemo": "rastolhar",
    "rastolhemos": "rastolhar",
    "rastolhes": "rastolhar",
    "rastolho": "rastolhar",
    "rastolhos": "rastolho",
    "rastolhou": "rastolhar",
    "rastolhámo": "rastolhar",
    "rastolhámos": "rastolhar",
    "rastolháramo": "rastolhar",
    "rastolháramos": "rastolhar",
    "rastolháreis": "rastolhar",
    "rastolhásseis": "rastolhar",
    "rastolhássemos": "rastolhar",
    "rastolhávamo": "rastolhar",
    "rastolhávamos": "rastolhar",
    "rastolháveis": "rastolhar",
    "rastos": "rasto",
    "rastras": "rastra",
    "rastreada": "rastrear",
    "rastreadas": "rastrear",
    "rastreado": "rastrear",
    "rastreados": "rastrear",
    "rastreai": "rastrear",
    "rastreais": "rastrear",
    "rastreamo": "rastrear",
    "rastreamos": "rastrear",
    "rastreando": "rastrear",
    "rastreara": "rastrear",
    "rastrearam": "rastrear",
    "rastrearas": "rastrear",
    "rastrearde": "rastrear",
    "rastreardes": "rastrear",
    "rastreare": "rastrear",
    "rastrearei": "rastrear",
    "rastreareis": "rastrear",
    "rastrearem": "rastrear",
    "rastrearemos": "rastrear",
    "rastreares": "rastrear",
    "rastrearia": "rastrear",
    "rastreariam": "rastrear",
    "rastrearias": "rastrear",
    "rastrearmo": "rastrear",
    "rastrearmos": "rastrear",
    "rastreará": "rastrear",
    "rastrearás": "rastrear",
    "rastrearão": "rastrear",
    "rastrearíamos": "rastrear",
    "rastrearíeis": "rastrear",
    "rastreasse": "rastrear",
    "rastreassem": "rastrear",
    "rastreasses": "rastrear",
    "rastreaste": "rastrear",
    "rastreastes": "rastrear",
    "rastreava": "rastrear",
    "rastreavam": "rastrear",
    "rastreavas": "rastrear",
    "rastreei": "rastrear",
    "rastreeis": "rastrear",
    "rastreemo": "rastrear",
    "rastreemos": "rastrear",
    "rastreia": "rastrear",
    "rastreiam": "rastrear",
    "rastreias": "rastrear",
    "rastreie": "rastrear",
    "rastreiem": "rastrear",
    "rastreies": "rastrear",
    "rastreio": "rastrear",
    "rastreios": "rastreio",
    "rastreira": "rastreiro",
    "rastreiras": "rastreiro",
    "rastreirazinha": "rastreiro",
    "rastreirazinhas": "rastreiro",
    "rastreirazita": "rastreiro",
    "rastreirazitas": "rastreiro",
    "rastreirinha": "rastreiro",
    "rastreirinhas": "rastreiro",
    "rastreirinho": "rastreiro",
    "rastreirinhos": "rastreiro",
    "rastreirita": "rastreiro",
    "rastreiritas": "rastreiro",
    "rastreirito": "rastreiro",
    "rastreiritos": "rastreiro",
    "rastreiros": "rastreiro",
    "rastreirozinho": "rastreiro",
    "rastreirozinhos": "rastreiro",
    "rastreirozito": "rastreiro",
    "rastreirozitos": "rastreiro",
    "rastreiríssima": "rastreiro",
    "rastreiríssimas": "rastreiro",
    "rastreiríssimo": "rastreiro",
    "rastreiríssimos": "rastreiro",
    "rastreja": "rastrejar",
    "rastrejada": "rastrejar",
    "rastrejadas": "rastrejar",
    "rastrejado": "rastrejar",
    "rastrejados": "rastrejar",
    "rastrejai": "rastrejar",
    "rastrejais": "rastrejar",
    "rastrejam": "rastrejar",
    "rastrejamo": "rastrejar",
    "rastrejamos": "rastrejar",
    "rastrejando": "rastrejar",
    "rastrejara": "rastrejar",
    "rastrejaram": "rastrejar",
    "rastrejaras": "rastrejar",
    "rastrejardes": "rastrejar",
    "rastrejarei": "rastrejar",
    "rastrejareis": "rastrejar",
    "rastrejarem": "rastrejar",
    "rastrejaremos": "rastrejar",
    "rastrejares": "rastrejar",
    "rastrejaria": "rastrejar",
    "rastrejariam": "rastrejar",
    "rastrejarias": "rastrejar",
    "rastrejarmo": "rastrejar",
    "rastrejarmos": "rastrejar",
    "rastrejará": "rastrejar",
    "rastrejarás": "rastrejar",
    "rastrejarão": "rastrejar",
    "rastrejaríamos": "rastrejar",
    "rastrejaríeis": "rastrejar",
    "rastrejas": "rastrejar",
    "rastrejasse": "rastrejar",
    "rastrejassem": "rastrejar",
    "rastrejasses": "rastrejar",
    "rastrejaste": "rastrejar",
    "rastrejastes": "rastrejar",
    "rastrejava": "rastrejar",
    "rastrejavam": "rastrejar",
    "rastrejavas": "rastrejar",
    "rastreje": "rastrejar",
    "rastrejei": "rastrejar",
    "rastrejeis": "rastrejar",
    "rastrejem": "rastrejar",
    "rastrejemo": "rastrejar",
    "rastrejemos": "rastrejar",
    "rastrejes": "rastrejar",
    "rastrejo": "rastrejar",
    "rastrejou": "rastrejar",
    "rastrejámo": "rastrejar",
    "rastrejámos": "rastrejar",
    "rastrejáramo": "rastrejar",
    "rastrejáramos": "rastrejar",
    "rastrejáreis": "rastrejar",
    "rastrejásseis": "rastrejar",
    "rastrejássemos": "rastrejar",
    "rastrejávamo": "rastrejar",
    "rastrejávamos": "rastrejar",
    "rastrejáveis": "rastrejar",
    "rastreou": "rastrear",
    "rastreá": "rastrear",
    "rastreámo": "rastrear",
    "rastreámos": "rastrear",
    "rastreáramo": "rastrear",
    "rastreáramos": "rastrear",
    "rastreárei": "rastrear",
    "rastreáreis": "rastrear",
    "rastreásseis": "rastrear",
    "rastreássemos": "rastrear",
    "rastreávamo": "rastrear",
    "rastreávamos": "rastrear",
    "rastreávei": "rastrear",
    "rastreáveis": "rastrear",
    "rastros": "rastro",
    "rastões": "rastão",
    "rasura": "rasurar",
    "rasurada": "rasurar",
    "rasuradas": "rasurar",
    "rasurado": "rasurar",
    "rasurados": "rasurar",
    "rasuradíssima": "rasurado",
    "rasuradíssimas": "rasurado",
    "rasuradíssimo": "rasurado",
    "rasuradíssimos": "rasurado",
    "rasurai": "rasurar",
    "rasurais": "rasurar",
    "rasuram": "rasurar",
    "rasuramo": "rasurar",
    "rasuramos": "rasurar",
    "rasurando": "rasurar",
    "rasurara": "rasurar",
    "rasuraram": "rasurar",
    "rasuraras": "rasurar",
    "rasurarde": "rasurar",
    "rasurardes": "rasurar",
    "rasurare": "rasurar",
    "rasurarei": "rasurar",
    "rasurareis": "rasurar",
    "rasurarem": "rasurar",
    "rasuraremos": "rasurar",
    "rasurares": "rasurar",
    "rasuraria": "rasurar",
    "rasurariam": "rasurar",
    "rasurarias": "rasurar",
    "rasurarmo": "rasurar",
    "rasurarmos": "rasurar",
    "rasurará": "rasurar",
    "rasurarás": "rasurar",
    "rasurarão": "rasurar",
    "rasuraríamos": "rasurar",
    "rasuraríeis": "rasurar",
    "rasuras": "rasurar",
    "rasurasse": "rasurar",
    "rasurassem": "rasurar",
    "rasurasses": "rasurar",
    "rasuraste": "rasurar",
    "rasurastes": "rasurar",
    "rasurava": "rasurar",
    "rasuravam": "rasurar",
    "rasuravas": "rasurar",
    "rasure": "rasurar",
    "rasurei": "rasurar",
    "rasureis": "rasurar",
    "rasurem": "rasurar",
    "rasuremo": "rasurar",
    "rasuremos": "rasurar",
    "rasures": "rasurar",
    "rasuro": "rasurar",
    "rasurou": "rasurar",
    "rasurá": "rasurar",
    "rasurámo": "rasurar",
    "rasurámos": "rasurar",
    "rasuráramo": "rasurar",
    "rasuráramos": "rasurar",
    "rasurárei": "rasurar",
    "rasuráreis": "rasurar",
    "rasurásseis": "rasurar",
    "rasurássemos": "rasurar",
    "rasurávamo": "rasurar",
    "rasurávamos": "rasurar",
    "rasurávei": "rasurar",
    "rasuráveis": "rasurável",
    "rasá": "rasar",
    "rasámo": "rasar",
    "rasámos": "rasar",
    "rasáramo": "rasar",
    "rasáramos": "rasar",
    "rasárei": "rasar",
    "rasáreis": "rasar",
    "rasásseis": "rasar",
    "rasássemos": "rasar",
    "rasávamo": "rasar",
    "rasávamos": "rasar",
    "rasávei": "rasar",
    "rasáveis": "rasar",
    "rasíssima": "raso",
    "rasíssimas": "raso",
    "rasíssimo": "raso",
    "rasíssimos": "raso",
    "rasões": "rasão",
    "rata": "rato",
    "ratada": "ratar",
    "ratadas": "ratar",
    "ratadinha": "ratado",
    "ratadinhas": "ratado",
    "ratadinho": "ratado",
    "ratadinhos": "ratado",
    "ratadita": "ratado",
    "rataditas": "ratado",
    "ratadito": "ratado",
    "rataditos": "ratado",
    "ratado": "ratar",
    "ratados": "ratar",
    "ratadíssima": "ratado",
    "ratadíssimas": "ratado",
    "ratadíssimo": "ratado",
    "ratadíssimos": "ratado",
    "ratafias": "ratafia",
    "ratai": "ratar",
    "ratais": "ratar",
    "ratam": "ratar",
    "ratamo": "ratar",
    "ratamos": "ratar",
    "ratando": "ratar",
    "rataplãs": "rataplã",
    "rataplões": "rataplão",
    "ratara": "ratar",
    "rataram": "ratar",
    "rataras": "ratar",
    "ratarde": "ratar",
    "ratardes": "ratar",
    "ratare": "ratar",
    "ratarei": "ratar",
    "ratareis": "ratar",
    "ratarem": "ratar",
    "rataremos": "ratar",
    "ratares": "ratar",
    "rataria": "ratar",
    "ratariam": "ratar",
    "ratarias": "rataria",
    "ratarmo": "ratar",
    "ratarmos": "ratar",
    "ratará": "ratar",
    "ratarás": "ratar",
    "ratarão": "ratar",
    "rataríamos": "ratar",
    "rataríeis": "ratar",
    "ratas": "rato",
    "ratasse": "ratar",
    "ratassem": "ratar",
    "ratasses": "ratar",
    "rataste": "ratar",
    "ratastes": "ratar",
    "ratatãs": "ratatã",
    "ratava": "ratar",
    "ratavam": "ratar",
    "ratavas": "ratar",
    "ratazana": "ratazanar",
    "ratazanada": "ratazanar",
    "ratazanadas": "ratazanar",
    "ratazanado": "ratazanar",
    "ratazanados": "ratazanar",
    "ratazanai": "ratazanar",
    "ratazanais": "ratazanar",
    "ratazanam": "ratazanar",
    "ratazanamo": "ratazanar",
    "ratazanamos": "ratazanar",
    "ratazanando": "ratazanar",
    "ratazanara": "ratazanar",
    "ratazanaram": "ratazanar",
    "ratazanaras": "ratazanar",
    "ratazanarde": "ratazanar",
    "ratazanardes": "ratazanar",
    "ratazanare": "ratazanar",
    "ratazanarei": "ratazanar",
    "ratazanareis": "ratazanar",
    "ratazanarem": "ratazanar",
    "ratazanaremos": "ratazanar",
    "ratazanares": "ratazanar",
    "ratazanaria": "ratazanar",
    "ratazanariam": "ratazanar",
    "ratazanarias": "ratazanar",
    "ratazanarmo": "ratazanar",
    "ratazanarmos": "ratazanar",
    "ratazanará": "ratazanar",
    "ratazanarás": "ratazanar",
    "ratazanarão": "ratazanar",
    "ratazanaríamos": "ratazanar",
    "ratazanaríeis": "ratazanar",
    "ratazanas": "ratazanar",
    "ratazanasse": "ratazanar",
    "ratazanassem": "ratazanar",
    "ratazanasses": "ratazanar",
    "ratazanaste": "ratazanar",
    "ratazanastes": "ratazanar",
    "ratazanava": "ratazanar",
    "ratazanavam": "ratazanar",
    "ratazanavas": "ratazanar",
    "ratazane": "ratazanar",
    "ratazanei": "ratazanar",
    "ratazaneis": "ratazanar",
    "ratazanem": "ratazanar",
    "ratazanemo": "ratazanar",
    "ratazanemos": "ratazanar",
    "ratazanes": "ratazanar",
    "ratazano": "ratazanar",
    "ratazanou": "ratazanar",
    "ratazaná": "ratazanar",
    "ratazanámo": "ratazanar",
    "ratazanámos": "ratazanar",
    "ratazanáramo": "ratazanar",
    "ratazanáramos": "ratazanar",
    "ratazanárei": "ratazanar",
    "ratazanáreis": "ratazanar",
    "ratazanásseis": "ratazanar",
    "ratazanássemos": "ratazanar",
    "ratazanávamo": "ratazanar",
    "ratazanávamos": "ratazanar",
    "ratazanávei": "ratazanar",
    "ratazanáveis": "ratazanar",
    "rate": "ratar",
    "rateada": "ratear",
    "rateadas": "ratear",
    "rateado": "ratear",
    "rateadora": "rateador",
    "rateadoras": "rateador",
    "rateadores": "rateador",
    "rateados": "ratear",
    "rateai": "ratear",
    "rateais": "ratear",
    "rateamentos": "rateamento",
    "rateamo": "ratear",
    "rateamos": "ratear",
    "rateando": "ratear",
    "rateara": "ratear",
    "ratearam": "ratear",
    "ratearas": "ratear",
    "ratearde": "ratear",
    "rateardes": "ratear",
    "rateare": "ratear",
    "ratearei": "ratear",
    "rateareis": "ratear",
    "ratearem": "ratear",
    "ratearemos": "ratear",
    "rateares": "ratear",
    "ratearia": "ratear",
    "rateariam": "ratear",
    "ratearias": "ratear",
    "ratearmo": "ratear",
    "ratearmos": "ratear",
    "rateará": "ratear",
    "ratearás": "ratear",
    "ratearão": "ratear",
    "ratearíamos": "ratear",
    "ratearíeis": "ratear",
    "rateasse": "ratear",
    "rateassem": "ratear",
    "rateasses": "ratear",
    "rateaste": "ratear",
    "rateastes": "ratear",
    "rateava": "ratear",
    "rateavam": "ratear",
    "rateavas": "ratear",
    "rateações": "rateação",
    "rateei": "ratear",
    "rateeis": "ratear",
    "rateemo": "ratear",
    "rateemos": "ratear",
    "ratei": "ratar",
    "rateia": "ratear",
    "rateiam": "ratear",
    "rateias": "ratear",
    "rateie": "ratear",
    "rateiem": "ratear",
    "rateies": "ratear",
    "rateio": "ratear",
    "rateios": "rateio",
    "rateira": "rateiro",
    "rateiras": "rateiro",
    "rateiros": "rateiro",
    "rateis": "ratel",
    "ratem": "ratar",
    "ratemo": "ratar",
    "ratemos": "ratar",
    "rateou": "ratear",
    "rates": "ratar",
    "rateá": "ratear",
    "rateámo": "ratear",
    "rateámos": "ratear",
    "rateáramo": "ratear",
    "rateáramos": "ratear",
    "rateárei": "ratear",
    "rateáreis": "ratear",
    "rateásseis": "ratear",
    "rateássemos": "ratear",
    "rateávamo": "ratear",
    "rateávamos": "ratear",
    "rateávei": "ratear",
    "rateáveis": "ratear",
    "ratices": "ratice",
    "raticidas": "raticida",
    "raticídios": "raticídio",
    "ratifica": "ratificar",
    "ratificada": "ratificar",
    "ratificadas": "ratificar",
    "ratificado": "ratificar",
    "ratificados": "ratificar",
    "ratificai": "ratificar",
    "ratificais": "ratificar",
    "ratificam": "ratificar",
    "ratificamo": "ratificar",
    "ratificamos": "ratificar",
    "ratificando": "ratificar",
    "ratificara": "ratificar",
    "ratificaram": "ratificar",
    "ratificaras": "ratificar",
    "ratificarde": "ratificar",
    "ratificardes": "ratificar",
    "ratificare": "ratificar",
    "ratificarei": "ratificar",
    "ratificareis": "ratificar",
    "ratificarem": "ratificar",
    "ratificaremos": "ratificar",
    "ratificares": "ratificar",
    "ratificaria": "ratificar",
    "ratificariam": "ratificar",
    "ratificarias": "ratificar",
    "ratificarmo": "ratificar",
    "ratificarmos": "ratificar",
    "ratificará": "ratificar",
    "ratificarás": "ratificar",
    "ratificarão": "ratificar",
    "ratificaríamos": "ratificar",
    "ratificaríeis": "ratificar",
    "ratificas": "ratificar",
    "ratificasse": "ratificar",
    "ratificassem": "ratificar",
    "ratificasses": "ratificar",
    "ratificaste": "ratificar",
    "ratificastes": "ratificar",
    "ratificava": "ratificar",
    "ratificavam": "ratificar",
    "ratificavas": "ratificar",
    "ratificações": "ratificação",
    "ratifico": "ratificar",
    "ratificou": "ratificar",
    "ratificá": "ratificar",
    "ratificámo": "ratificar",
    "ratificámos": "ratificar",
    "ratificáramo": "ratificar",
    "ratificáramos": "ratificar",
    "ratificárei": "ratificar",
    "ratificáreis": "ratificar",
    "ratificásseis": "ratificar",
    "ratificássemos": "ratificar",
    "ratificávamo": "ratificar",
    "ratificávamos": "ratificar",
    "ratificávei": "ratificar",
    "ratificáveis": "ratificável",
    "ratifique": "ratificar",
    "ratifiquei": "ratificar",
    "ratifiqueis": "ratificar",
    "ratifiquem": "ratificar",
    "ratifiquemo": "ratificar",
    "ratifiquemos": "ratificar",
    "ratifiques": "ratificar",
    "ratiformes": "ratiforme",
    "ratina": "ratinar",
    "ratinada": "ratinar",
    "ratinadas": "ratinar",
    "ratinado": "ratinar",
    "ratinadoras": "ratinadora",
    "ratinados": "ratinar",
    "ratinai": "ratinar",
    "ratinais": "ratinar",
    "ratinam": "ratinar",
    "ratinamo": "ratinar",
    "ratinamos": "ratinar",
    "ratinando": "ratinar",
    "ratinara": "ratinar",
    "ratinaram": "ratinar",
    "ratinaras": "ratinar",
    "ratinarde": "ratinar",
    "ratinardes": "ratinar",
    "ratinare": "ratinar",
    "ratinarei": "ratinar",
    "ratinareis": "ratinar",
    "ratinarem": "ratinar",
    "ratinaremos": "ratinar",
    "ratinares": "ratinar",
    "ratinaria": "ratinar",
    "ratinariam": "ratinar",
    "ratinarias": "ratinar",
    "ratinarmo": "ratinar",
    "ratinarmos": "ratinar",
    "ratinará": "ratinar",
    "ratinarás": "ratinar",
    "ratinarão": "ratinar",
    "ratinaríamos": "ratinar",
    "ratinaríeis": "ratinar",
    "ratinas": "ratinar",
    "ratinasse": "ratinar",
    "ratinassem": "ratinar",
    "ratinasses": "ratinar",
    "ratinaste": "ratinar",
    "ratinastes": "ratinar",
    "ratinava": "ratinar",
    "ratinavam": "ratinar",
    "ratinavas": "ratinar",
    "ratine": "ratinar",
    "ratinei": "ratinar",
    "ratineis": "ratinar",
    "ratinem": "ratinar",
    "ratinemo": "ratinar",
    "ratinemos": "ratinar",
    "ratines": "ratinar",
    "ratinha": "rato",
    "ratinhada": "ratinhar",
    "ratinhadas": "ratinhar",
    "ratinhado": "ratinhar",
    "ratinhados": "ratinhar",
    "ratinhai": "ratinhar",
    "ratinhais": "ratinhar",
    "ratinham": "ratinhar",
    "ratinhamo": "ratinhar",
    "ratinhamos": "ratinhar",
    "ratinhando": "ratinhar",
    "ratinhara": "ratinhar",
    "ratinharam": "ratinhar",
    "ratinharas": "ratinhar",
    "ratinharde": "ratinhar",
    "ratinhardes": "ratinhar",
    "ratinhare": "ratinhar",
    "ratinharei": "ratinhar",
    "ratinhareis": "ratinhar",
    "ratinharem": "ratinhar",
    "ratinharemos": "ratinhar",
    "ratinhares": "ratinhar",
    "ratinharia": "ratinhar",
    "ratinhariam": "ratinhar",
    "ratinharias": "ratinhar",
    "ratinharmo": "ratinhar",
    "ratinharmos": "ratinhar",
    "ratinhará": "ratinhar",
    "ratinharás": "ratinhar",
    "ratinharão": "ratinhar",
    "ratinharíamos": "ratinhar",
    "ratinharíeis": "ratinhar",
    "ratinhas": "rato",
    "ratinhasse": "ratinhar",
    "ratinhassem": "ratinhar",
    "ratinhasses": "ratinhar",
    "ratinhaste": "ratinhar",
    "ratinhastes": "ratinhar",
    "ratinhava": "ratinhar",
    "ratinhavam": "ratinhar",
    "ratinhavas": "ratinhar",
    "ratinhe": "ratinhar",
    "ratinhei": "ratinhar",
    "ratinheira": "ratinheiro",
    "ratinheiras": "ratinheiro",
    "ratinheiros": "ratinheiro",
    "ratinheis": "ratinhar",
    "ratinhem": "ratinhar",
    "ratinhemo": "ratinhar",
    "ratinhemos": "ratinhar",
    "ratinhes": "ratinhar",
    "ratinho": "rato",
    "ratinhos": "rato",
    "ratinhou": "ratinhar",
    "ratinhá": "ratinhar",
    "ratinhámo": "ratinhar",
    "ratinhámos": "ratinhar",
    "ratinháramo": "ratinhar",
    "ratinháramos": "ratinhar",
    "ratinhárei": "ratinhar",
    "ratinháreis": "ratinhar",
    "ratinhásseis": "ratinhar",
    "ratinhássemos": "ratinhar",
    "ratinhávamo": "ratinhar",
    "ratinhávamos": "ratinhar",
    "ratinhávei": "ratinhar",
    "ratinháveis": "ratinhar",
    "ratino": "ratinar",
    "ratinou": "ratinar",
    "ratiná": "ratinar",
    "ratinámo": "ratinar",
    "ratinámos": "ratinar",
    "ratináramo": "ratinar",
    "ratináramos": "ratinar",
    "ratinárei": "ratinar",
    "ratináreis": "ratinar",
    "ratinásseis": "ratinar",
    "ratinássemos": "ratinar",
    "ratinávamo": "ratinar",
    "ratinávamos": "ratinar",
    "ratinávei": "ratinar",
    "ratináveis": "ratinar",
    "ratita": "rato",
    "ratitas": "rato",
    "ratites": "ratite",
    "ratito": "rato",
    "ratitos": "rato",
    "rato": "ratar",
    "ratoeiras": "ratoeira",
    "ratona": "ratonar",
    "ratonada": "ratonar",
    "ratonadas": "ratonar",
    "ratonado": "ratonar",
    "ratonados": "ratonar",
    "ratonai": "ratonar",
    "ratonais": "ratonar",
    "ratonam": "ratonar",
    "ratonamo": "ratonar",
    "ratonamos": "ratonar",
    "ratonando": "ratonar",
    "ratonara": "ratonar",
    "ratonaram": "ratonar",
    "ratonaras": "ratonar",
    "ratonardes": "ratonar",
    "ratonarei": "ratonar",
    "ratonareis": "ratonar",
    "ratonarem": "ratonar",
    "ratonaremos": "ratonar",
    "ratonares": "ratonar",
    "ratonaria": "ratonar",
    "ratonariam": "ratonar",
    "ratonarias": "ratonar",
    "ratonarmo": "ratonar",
    "ratonarmos": "ratonar",
    "ratonará": "ratonar",
    "ratonarás": "ratonar",
    "ratonarão": "ratonar",
    "ratonaríamos": "ratonar",
    "ratonaríeis": "ratonar",
    "ratonas": "ratonar",
    "ratonasse": "ratonar",
    "ratonassem": "ratonar",
    "ratonasses": "ratonar",
    "ratonaste": "ratonar",
    "ratonastes": "ratonar",
    "ratonava": "ratonar",
    "ratonavam": "ratonar",
    "ratonavas": "ratonar",
    "ratone": "ratonar",
    "ratoneada": "ratonear",
    "ratoneadas": "ratonear",
    "ratoneado": "ratonear",
    "ratoneados": "ratonear",
    "ratoneai": "ratonear",
    "ratoneais": "ratonear",
    "ratoneamo": "ratonear",
    "ratoneamos": "ratonear",
    "ratoneando": "ratonear",
    "ratoneara": "ratonear",
    "ratonearam": "ratonear",
    "ratonearas": "ratonear",
    "ratoneardes": "ratonear",
    "ratonearei": "ratonear",
    "ratoneareis": "ratonear",
    "ratonearem": "ratonear",
    "ratonearemos": "ratonear",
    "ratoneares": "ratonear",
    "ratonearia": "ratonear",
    "ratoneariam": "ratonear",
    "ratonearias": "ratonear",
    "ratonearmo": "ratonear",
    "ratonearmos": "ratonear",
    "ratoneará": "ratonear",
    "ratonearás": "ratonear",
    "ratonearão": "ratonear",
    "ratonearíamos": "ratonear",
    "ratonearíeis": "ratonear",
    "ratoneasse": "ratonear",
    "ratoneassem": "ratonear",
    "ratoneasses": "ratonear",
    "ratoneaste": "ratonear",
    "ratoneastes": "ratonear",
    "ratoneava": "ratonear",
    "ratoneavam": "ratonear",
    "ratoneavas": "ratonear",
    "ratoneei": "ratonear",
    "ratoneeis": "ratonear",
    "ratoneemo": "ratonear",
    "ratoneemos": "ratonear",
    "ratonei": "ratonar",
    "ratoneia": "ratonear",
    "ratoneiam": "ratonear",
    "ratoneias": "ratonear",
    "ratoneie": "ratonear",
    "ratoneiem": "ratonear",
    "ratoneies": "ratonear",
    "ratoneio": "ratonear",
    "ratoneira": "ratoneiro",
    "ratoneiras": "ratoneiro",
    "ratoneiros": "ratoneiro",
    "ratoneis": "ratonar",
    "ratonem": "ratonar",
    "ratonemo": "ratonar",
    "ratonemos": "ratonar",
    "ratoneou": "ratonear",
    "ratones": "ratonar",
    "ratoneámo": "ratonear",
    "ratoneámos": "ratonear",
    "ratoneáramo": "ratonear",
    "ratoneáramos": "ratonear",
    "ratoneáreis": "ratonear",
    "ratoneásseis": "ratonear",
    "ratoneássemos": "ratonear",
    "ratoneávamo": "ratonear",
    "ratoneávamos": "ratonear",
    "ratoneáveis": "ratonear",
    "ratonices": "ratonice",
    "ratono": "ratonar",
    "ratonou": "ratonar",
    "ratonámo": "ratonar",
    "ratonámos": "ratonar",
    "ratonáramo": "ratonar",
    "ratonáramos": "ratonar",
    "ratonáreis": "ratonar",
    "ratonásseis": "ratonar",
    "ratonássemos": "ratonar",
    "ratonávamo": "ratonar",
    "ratonávamos": "ratonar",
    "ratonáveis": "ratonar",
    "ratos": "rato",
    "ratou": "ratar",
    "ratá": "ratar",
    "ratámo": "ratar",
    "ratámos": "ratar",
    "ratáramo": "ratar",
    "ratáramos": "ratar",
    "ratárei": "ratar",
    "ratáreis": "ratar",
    "ratásseis": "ratar",
    "ratássemos": "ratar",
    "ratávamo": "ratar",
    "ratávamos": "ratar",
    "ratávei": "ratar",
    "ratáveis": "ratar",
    "ratívora": "ratívoro",
    "ratívoras": "ratívoro",
    "ratívoros": "ratívoro",
    "ratões": "ratão",
    "raucitroantes": "raucitroante",
    "raucíssona": "raucíssono",
    "raucíssonas": "raucíssono",
    "raucíssonos": "raucíssono",
    "raudões": "raudão",
    "rauracianos": "rauraciano",
    "ravasca": "ravasco",
    "ravascas": "ravasco",
    "ravascos": "ravasco",
    "ravessas": "ravessa",
    "ravinada": "ravinado",
    "ravinadas": "ravinado",
    "ravinados": "ravinado",
    "ravinas": "ravina",
    "ravinosa": "ravinoso",
    "ravinosas": "ravinoso",
    "ravinosos": "ravinoso",
    "raviolis": "ravioli",
    "ravióis": "raviol",
    "raxas": "raxa",
    "raxetas": "raxeta",
    "razantes": "razante",
    "razia": "raziar",
    "raziada": "raziar",
    "raziadas": "raziar",
    "raziado": "raziar",
    "raziados": "raziar",
    "raziai": "raziar",
    "raziais": "raziar",
    "raziam": "raziar",
    "raziamo": "raziar",
    "raziamos": "raziar",
    "raziando": "raziar",
    "raziara": "raziar",
    "raziaram": "raziar",
    "raziaras": "raziar",
    "raziarde": "raziar",
    "raziardes": "raziar",
    "raziare": "raziar",
    "raziarei": "raziar",
    "raziareis": "raziar",
    "raziarem": "raziar",
    "raziaremos": "raziar",
    "raziares": "raziar",
    "raziaria": "raziar",
    "raziariam": "raziar",
    "raziarias": "raziar",
    "raziarmo": "raziar",
    "raziarmos": "raziar",
    "raziará": "raziar",
    "raziarás": "raziar",
    "raziarão": "raziar",
    "raziaríamos": "raziar",
    "raziaríeis": "raziar",
    "razias": "raziar",
    "raziasse": "raziar",
    "raziassem": "raziar",
    "raziasses": "raziar",
    "raziaste": "raziar",
    "raziastes": "raziar",
    "raziava": "raziar",
    "raziavam": "raziar",
    "raziavas": "raziar",
    "razie": "raziar",
    "raziei": "raziar",
    "razieis": "raziar",
    "raziem": "raziar",
    "raziemo": "raziar",
    "raziemos": "raziar",
    "razies": "raziar",
    "razio": "raziar",
    "raziou": "raziar",
    "raziá": "raziar",
    "raziámo": "raziar",
    "raziámos": "raziar",
    "raziáramo": "raziar",
    "raziáramos": "raziar",
    "raziárei": "raziar",
    "raziáreis": "raziar",
    "raziásseis": "raziar",
    "raziássemos": "raziar",
    "raziávamo": "raziar",
    "raziávamos": "raziar",
    "raziávei": "raziar",
    "raziáveis": "raziar",
    "razoa": "razoar",
    "razoabilidades": "razoabilidade",
    "razoada": "razoar",
    "razoadas": "razoar",
    "razoado": "razoar",
    "razoadora": "razoador",
    "razoadoras": "razoador",
    "razoadores": "razoador",
    "razoados": "razoar",
    "razoai": "razoar",
    "razoais": "razoar",
    "razoam": "razoar",
    "razoamentos": "razoamento",
    "razoamo": "razoar",
    "razoamos": "razoar",
    "razoando": "razoar",
    "razoara": "razoar",
    "razoaram": "razoar",
    "razoaras": "razoar",
    "razoardes": "razoar",
    "razoarei": "razoar",
    "razoareis": "razoar",
    "razoarem": "razoar",
    "razoaremos": "razoar",
    "razoares": "razoar",
    "razoaria": "razoar",
    "razoariam": "razoar",
    "razoarias": "razoar",
    "razoarmo": "razoar",
    "razoarmos": "razoar",
    "razoará": "razoar",
    "razoarás": "razoar",
    "razoarão": "razoar",
    "razoaríamos": "razoar",
    "razoaríeis": "razoar",
    "razoas": "razoar",
    "razoasse": "razoar",
    "razoassem": "razoar",
    "razoasses": "razoar",
    "razoaste": "razoar",
    "razoastes": "razoar",
    "razoava": "razoar",
    "razoavam": "razoar",
    "razoavas": "razoar",
    "razoe": "razoar",
    "razoei": "razoar",
    "razoeis": "razoar",
    "razoem": "razoar",
    "razoemo": "razoar",
    "razoemos": "razoar",
    "razoes": "razoar",
    "razoo": "razoar",
    "razoou": "razoar",
    "razoámo": "razoar",
    "razoámos": "razoar",
    "razoáramo": "razoar",
    "razoáramos": "razoar",
    "razoáreis": "razoar",
    "razoásseis": "razoar",
    "razoássemos": "razoar",
    "razoávamo": "razoar",
    "razoávamos": "razoar",
    "razoáveis": "razoável",
    "razões": "razão",
    "raças": "raça",
    "raçoa": "raçoar",
    "raçoada": "raçoar",
    "raçoadas": "raçoar",
    "raçoado": "raçoar",
    "raçoados": "raçoar",
    "raçoai": "raçoar",
    "raçoais": "raçoar",
    "raçoam": "raçoar",
    "raçoamo": "raçoar",
    "raçoamos": "raçoar",
    "raçoando": "raçoar",
    "raçoara": "raçoar",
    "raçoaram": "raçoar",
    "raçoaras": "raçoar",
    "raçoarde": "raçoar",
    "raçoardes": "raçoar",
    "raçoare": "raçoar",
    "raçoarei": "raçoar",
    "raçoareis": "raçoar",
    "raçoarem": "raçoar",
    "raçoaremos": "raçoar",
    "raçoares": "raçoar",
    "raçoaria": "raçoar",
    "raçoariam": "raçoar",
    "raçoarias": "raçoar",
    "raçoarmo": "raçoar",
    "raçoarmos": "raçoar",
    "raçoará": "raçoar",
    "raçoarás": "raçoar",
    "raçoarão": "raçoar",
    "raçoaríamos": "raçoar",
    "raçoaríeis": "raçoar",
    "raçoas": "raçoar",
    "raçoasse": "raçoar",
    "raçoassem": "raçoar",
    "raçoasses": "raçoar",
    "raçoaste": "raçoar",
    "raçoastes": "raçoar",
    "raçoava": "raçoar",
    "raçoavam": "raçoar",
    "raçoavas": "raçoar",
    "raçoe": "raçoar",
    "raçoei": "raçoar",
    "raçoeira": "raçoeiro",
    "raçoeiras": "raçoeiro",
    "raçoeiros": "raçoeiro",
    "raçoeis": "raçoar",
    "raçoem": "raçoar",
    "raçoemo": "raçoar",
    "raçoemos": "raçoar",
    "raçoes": "raçoar",
    "raçoo": "raçoar",
    "raçoou": "raçoar",
    "raçoá": "raçoar",
    "raçoámo": "raçoar",
    "raçoámos": "raçoar",
    "raçoáramo": "raçoar",
    "raçoáramos": "raçoar",
    "raçoárei": "raçoar",
    "raçoáreis": "raçoar",
    "raçoásseis": "raçoar",
    "raçoássemos": "raçoar",
    "raçoávamo": "raçoar",
    "raçoávamos": "raçoar",
    "raçoávei": "raçoar",
    "raçoáveis": "raçoar",
    "rações": "ração",
    "raê": "raer",
    "raêramo": "raer",
    "raêramos": "raer",
    "raêrei": "raer",
    "raêreis": "raer",
    "raêsseis": "raer",
    "raêssemos": "raer",
    "raíamo": "raer",
    "raíamos": "raer",
    "raíei": "raer",
    "raíeis": "raer",
    "raíidas": "raíida",
    "raízes": "raiz",
    "reabastece": "reabastecer",
    "reabastecei": "reabastecer",
    "reabasteceis": "reabastecer",
    "reabastecem": "reabastecer",
    "reabastecemo": "reabastecer",
    "reabastecemos": "reabastecer",
    "reabastecendo": "reabastecer",
    "reabastecera": "reabastecer",
    "reabasteceram": "reabastecer",
    "reabasteceras": "reabastecer",
    "reabastecerde": "reabastecer",
    "reabastecerdes": "reabastecer",
    "reabastecere": "reabastecer",
    "reabastecerei": "reabastecer",
    "reabastecereis": "reabastecer",
    "reabastecerem": "reabastecer",
    "reabasteceremos": "reabastecer",
    "reabasteceres": "reabastecer",
    "reabasteceria": "reabastecer",
    "reabasteceriam": "reabastecer",
    "reabastecerias": "reabastecer",
    "reabastecermo": "reabastecer",
    "reabastecermos": "reabastecer",
    "reabastecerá": "reabastecer",
    "reabastecerás": "reabastecer",
    "reabastecerão": "reabastecer",
    "reabasteceríamos": "reabastecer",
    "reabasteceríeis": "reabastecer",
    "reabasteces": "reabastecer",
    "reabastecesse": "reabastecer",
    "reabastecessem": "reabastecer",
    "reabastecesses": "reabastecer",
    "reabasteceste": "reabastecer",
    "reabastecestes": "reabastecer",
    "reabasteceu": "reabastecer",
    "reabasteci": "reabastecer",
    "reabastecia": "reabastecer",
    "reabasteciam": "reabastecer",
    "reabastecias": "reabastecer",
    "reabastecida": "reabastecido",
    "reabastecidas": "reabastecido",
    "reabastecido": "reabastecer",
    "reabastecidos": "reabastecido",
    "reabastecimentos": "reabastecimento",
    "reabastecê": "reabastecer",
    "reabastecêramo": "reabastecer",
    "reabastecêramos": "reabastecer",
    "reabastecêrei": "reabastecer",
    "reabastecêreis": "reabastecer",
    "reabastecêsseis": "reabastecer",
    "reabastecêssemos": "reabastecer",
    "reabastecíamo": "reabastecer",
    "reabastecíamos": "reabastecer",
    "reabastecíei": "reabastecer",
    "reabastecíeis": "reabastecer",
    "reabasteça": "reabastecer",
    "reabasteçais": "reabastecer",
    "reabasteçam": "reabastecer",
    "reabasteçamo": "reabastecer",
    "reabasteçamos": "reabastecer",
    "reabasteças": "reabastecer",
    "reabasteço": "reabastecer",
    "reaberta": "reaberto",
    "reabertas": "reaberto",
    "reabertos": "reaberto",
    "reaberturas": "reabertura",
    "reabilita": "reabilitar",
    "reabilitada": "reabilitar",
    "reabilitadas": "reabilitar",
    "reabilitado": "reabilitar",
    "reabilitadora": "reabilitador",
    "reabilitadoras": "reabilitador",
    "reabilitadores": "reabilitador",
    "reabilitados": "reabilitar",
    "reabilitai": "reabilitar",
    "reabilitais": "reabilitar",
    "reabilitam": "reabilitar",
    "reabilitamo": "reabilitar",
    "reabilitamos": "reabilitar",
    "reabilitando": "reabilitar",
    "reabilitara": "reabilitar",
    "reabilitaram": "reabilitar",
    "reabilitaras": "reabilitar",
    "reabilitarde": "reabilitar",
    "reabilitardes": "reabilitar",
    "reabilitare": "reabilitar",
    "reabilitarei": "reabilitar",
    "reabilitareis": "reabilitar",
    "reabilitarem": "reabilitar",
    "reabilitaremos": "reabilitar",
    "reabilitares": "reabilitar",
    "reabilitaria": "reabilitar",
    "reabilitariam": "reabilitar",
    "reabilitarias": "reabilitar",
    "reabilitarmo": "reabilitar",
    "reabilitarmos": "reabilitar",
    "reabilitará": "reabilitar",
    "reabilitarás": "reabilitar",
    "reabilitarão": "reabilitar",
    "reabilitaríamos": "reabilitar",
    "reabilitaríeis": "reabilitar",
    "reabilitas": "reabilitar",
    "reabilitasse": "reabilitar",
    "reabilitassem": "reabilitar",
    "reabilitasses": "reabilitar",
    "reabilitaste": "reabilitar",
    "reabilitastes": "reabilitar",
    "reabilitativa": "reabilitativo",
    "reabilitativas": "reabilitativo",
    "reabilitativos": "reabilitativo",
    "reabilitava": "reabilitar",
    "reabilitavam": "reabilitar",
    "reabilitavas": "reabilitar",
    "reabilitações": "reabilitação",
    "reabilite": "reabilitar",
    "reabilitei": "reabilitar",
    "reabiliteis": "reabilitar",
    "reabilitem": "reabilitar",
    "reabilitemo": "reabilitar",
    "reabilitemos": "reabilitar",
    "reabilites": "reabilitar",
    "reabilito": "reabilitar",
    "reabilitou": "reabilitar",
    "reabilitá": "reabilitar",
    "reabilitámo": "reabilitar",
    "reabilitámos": "reabilitar",
    "reabilitáramo": "reabilitar",
    "reabilitáramos": "reabilitar",
    "reabilitárei": "reabilitar",
    "reabilitáreis": "reabilitar",
    "reabilitásseis": "reabilitar",
    "reabilitássemos": "reabilitar",
    "reabilitávamo": "reabilitar",
    "reabilitávamos": "reabilitar",
    "reabilitávei": "reabilitar",
    "reabilitáveis": "reabilitável",
    "reabita": "reabitar",
    "reabitada": "reabitar",
    "reabitadas": "reabitar",
    "reabitado": "reabitar",
    "reabitados": "reabitar",
    "reabitai": "reabitar",
    "reabitais": "reabitar",
    "reabitam": "reabitar",
    "reabitamo": "reabitar",
    "reabitamos": "reabitar",
    "reabitando": "reabitar",
    "reabitara": "reabitar",
    "reabitaram": "reabitar",
    "reabitaras": "reabitar",
    "reabitarde": "reabitar",
    "reabitardes": "reabitar",
    "reabitare": "reabitar",
    "reabitarei": "reabitar",
    "reabitareis": "reabitar",
    "reabitarem": "reabitar",
    "reabitaremos": "reabitar",
    "reabitares": "reabitar",
    "reabitaria": "reabitar",
    "reabitariam": "reabitar",
    "reabitarias": "reabitar",
    "reabitarmo": "reabitar",
    "reabitarmos": "reabitar",
    "reabitará": "reabitar",
    "reabitarás": "reabitar",
    "reabitarão": "reabitar",
    "reabitaríamos": "reabitar",
    "reabitaríeis": "reabitar",
    "reabitas": "reabitar",
    "reabitasse": "reabitar",
    "reabitassem": "reabitar",
    "reabitasses": "reabitar",
    "reabitaste": "reabitar",
    "reabitastes": "reabitar",
    "reabitava": "reabitar",
    "reabitavam": "reabitar",
    "reabitavas": "reabitar",
    "reabitações": "reabitação",
    "reabite": "reabitar",
    "reabitei": "reabitar",
    "reabiteis": "reabitar",
    "reabitem": "reabitar",
    "reabitemo": "reabitar",
    "reabitemos": "reabitar",
    "reabites": "reabitar",
    "reabito": "reabitar",
    "reabitou": "reabitar",
    "reabitua": "reabituar",
    "reabituada": "reabituar",
    "reabituadas": "reabituar",
    "reabituado": "reabituar",
    "reabituados": "reabituar",
    "reabituai": "reabituar",
    "reabituais": "reabituar",
    "reabituam": "reabituar",
    "reabituamo": "reabituar",
    "reabituamos": "reabituar",
    "reabituando": "reabituar",
    "reabituara": "reabituar",
    "reabituaram": "reabituar",
    "reabituaras": "reabituar",
    "reabituarde": "reabituar",
    "reabituardes": "reabituar",
    "reabituare": "reabituar",
    "reabituarei": "reabituar",
    "reabituareis": "reabituar",
    "reabituarem": "reabituar",
    "reabituaremos": "reabituar",
    "reabituares": "reabituar",
    "reabituaria": "reabituar",
    "reabituariam": "reabituar",
    "reabituarias": "reabituar",
    "reabituarmo": "reabituar",
    "reabituarmos": "reabituar",
    "reabituará": "reabituar",
    "reabituarás": "reabituar",
    "reabituarão": "reabituar",
    "reabituaríamos": "reabituar",
    "reabituaríeis": "reabituar",
    "reabituas": "reabituar",
    "reabituasse": "reabituar",
    "reabituassem": "reabituar",
    "reabituasses": "reabituar",
    "reabituaste": "reabituar",
    "reabituastes": "reabituar",
    "reabituava": "reabituar",
    "reabituavam": "reabituar",
    "reabituavas": "reabituar",
    "reabitue": "reabituar",
    "reabituei": "reabituar",
    "reabitueis": "reabituar",
    "reabituem": "reabituar",
    "reabituemo": "reabituar",
    "reabituemos": "reabituar",
    "reabitues": "reabituar",
    "reabituo": "reabituar",
    "reabituou": "reabituar",
    "reabituá": "reabituar",
    "reabituámo": "reabituar",
    "reabituámos": "reabituar",
    "reabituáramo": "reabituar",
    "reabituáramos": "reabituar",
    "reabituárei": "reabituar",
    "reabituáreis": "reabituar",
    "reabituásseis": "reabituar",
    "reabituássemos": "reabituar",
    "reabituávamo": "reabituar",
    "reabituávamos": "reabituar",
    "reabituávei": "reabituar",
    "reabituáveis": "reabituar",
    "reabitá": "reabitar",
    "reabitámo": "reabitar",
    "reabitámos": "reabitar",
    "reabitáramo": "reabitar",
    "reabitáramos": "reabitar",
    "reabitárei": "reabitar",
    "reabitáreis": "reabitar",
    "reabitásseis": "reabitar",
    "reabitássemos": "reabitar",
    "reabitávamo": "reabitar",
    "reabitávamos": "reabitar",
    "reabitávei": "reabitar",
    "reabitáveis": "reabitar",
    "reabotoa": "reabotoar",
    "reabotoada": "reabotoar",
    "reabotoadas": "reabotoar",
    "reabotoado": "reabotoar",
    "reabotoados": "reabotoar",
    "reabotoai": "reabotoar",
    "reabotoais": "reabotoar",
    "reabotoam": "reabotoar",
    "reabotoamo": "reabotoar",
    "reabotoamos": "reabotoar",
    "reabotoando": "reabotoar",
    "reabotoara": "reabotoar",
    "reabotoaram": "reabotoar",
    "reabotoaras": "reabotoar",
    "reabotoarde": "reabotoar",
    "reabotoardes": "reabotoar",
    "reabotoare": "reabotoar",
    "reabotoarei": "reabotoar",
    "reabotoareis": "reabotoar",
    "reabotoarem": "reabotoar",
    "reabotoaremos": "reabotoar",
    "reabotoares": "reabotoar",
    "reabotoaria": "reabotoar",
    "reabotoariam": "reabotoar",
    "reabotoarias": "reabotoar",
    "reabotoarmo": "reabotoar",
    "reabotoarmos": "reabotoar",
    "reabotoará": "reabotoar",
    "reabotoarás": "reabotoar",
    "reabotoarão": "reabotoar",
    "reabotoaríamos": "reabotoar",
    "reabotoaríeis": "reabotoar",
    "reabotoas": "reabotoar",
    "reabotoasse": "reabotoar",
    "reabotoassem": "reabotoar",
    "reabotoasses": "reabotoar",
    "reabotoaste": "reabotoar",
    "reabotoastes": "reabotoar",
    "reabotoava": "reabotoar",
    "reabotoavam": "reabotoar",
    "reabotoavas": "reabotoar",
    "reabotoe": "reabotoar",
    "reabotoei": "reabotoar",
    "reabotoeis": "reabotoar",
    "reabotoem": "reabotoar",
    "reabotoemo": "reabotoar",
    "reabotoemos": "reabotoar",
    "reabotoes": "reabotoar",
    "reabotoo": "reabotoar",
    "reabotoou": "reabotoar",
    "reabotoá": "reabotoar",
    "reabotoámo": "reabotoar",
    "reabotoámos": "reabotoar",
    "reabotoáramo": "reabotoar",
    "reabotoáramos": "reabotoar",
    "reabotoárei": "reabotoar",
    "reabotoáreis": "reabotoar",
    "reabotoásseis": "reabotoar",
    "reabotoássemos": "reabotoar",
    "reabotoávamo": "reabotoar",
    "reabotoávamos": "reabotoar",
    "reabotoávei": "reabotoar",
    "reabotoáveis": "reabotoar",
    "reabra": "reabrir",
    "reabrace": "reabraçar",
    "reabracei": "reabraçar",
    "reabraceis": "reabraçar",
    "reabracem": "reabraçar",
    "reabracemo": "reabraçar",
    "reabracemos": "reabraçar",
    "reabraces": "reabraçar",
    "reabrais": "reabrir",
    "reabram": "reabrir",
    "reabramo": "reabrir",
    "reabramos": "reabrir",
    "reabras": "reabrir",
    "reabraça": "reabraçar",
    "reabraçada": "reabraçar",
    "reabraçadas": "reabraçar",
    "reabraçado": "reabraçar",
    "reabraçados": "reabraçar",
    "reabraçai": "reabraçar",
    "reabraçais": "reabraçar",
    "reabraçam": "reabraçar",
    "reabraçamo": "reabraçar",
    "reabraçamos": "reabraçar",
    "reabraçando": "reabraçar",
    "reabraçara": "reabraçar",
    "reabraçaram": "reabraçar",
    "reabraçaras": "reabraçar",
    "reabraçarde": "reabraçar",
    "reabraçardes": "reabraçar",
    "reabraçare": "reabraçar",
    "reabraçarei": "reabraçar",
    "reabraçareis": "reabraçar",
    "reabraçarem": "reabraçar",
    "reabraçaremos": "reabraçar",
    "reabraçares": "reabraçar",
    "reabraçaria": "reabraçar",
    "reabraçariam": "reabraçar",
    "reabraçarias": "reabraçar",
    "reabraçarmo": "reabraçar",
    "reabraçarmos": "reabraçar",
    "reabraçará": "reabraçar",
    "reabraçarás": "reabraçar",
    "reabraçarão": "reabraçar",
    "reabraçaríamos": "reabraçar",
    "reabraçaríeis": "reabraçar",
    "reabraças": "reabraçar",
    "reabraçasse": "reabraçar",
    "reabraçassem": "reabraçar",
    "reabraçasses": "reabraçar",
    "reabraçaste": "reabraçar",
    "reabraçastes": "reabraçar",
    "reabraçava": "reabraçar",
    "reabraçavam": "reabraçar",
    "reabraçavas": "reabraçar",
    "reabraço": "reabraçar",
    "reabraçou": "reabraçar",
    "reabraçá": "reabraçar",
    "reabraçámo": "reabraçar",
    "reabraçámos": "reabraçar",
    "reabraçáramo": "reabraçar",
    "reabraçáramos": "reabraçar",
    "reabraçárei": "reabraçar",
    "reabraçáreis": "reabraçar",
    "reabraçásseis": "reabraçar",
    "reabraçássemos": "reabraçar",
    "reabraçávamo": "reabraçar",
    "reabraçávamos": "reabraçar",
    "reabraçávei": "reabraçar",
    "reabraçáveis": "reabraçar",
    "reabre": "reabrir",
    "reabrem": "reabrir",
    "reabres": "reabrir",
    "reabri": "reabrir",
    "reabria": "reabrir",
    "reabriam": "reabrir",
    "reabrias": "reabrir",
    "reabrida": "reabrir",
    "reabridas": "reabrir",
    "reabrido": "reabrir",
    "reabridos": "reabrir",
    "reabrimo": "reabrir",
    "reabrimos": "reabrir",
    "reabrindo": "reabrir",
    "reabrira": "reabrir",
    "reabriram": "reabrir",
    "reabriras": "reabrir",
    "reabrirde": "reabrir",
    "reabrirdes": "reabrir",
    "reabrire": "reabrir",
    "reabrirei": "reabrir",
    "reabrireis": "reabrir",
    "reabrirem": "reabrir",
    "reabriremos": "reabrir",
    "reabrires": "reabrir",
    "reabriria": "reabrir",
    "reabririam": "reabrir",
    "reabririas": "reabrir",
    "reabrirmo": "reabrir",
    "reabrirmos": "reabrir",
    "reabrirá": "reabrir",
    "reabrirás": "reabrir",
    "reabrirão": "reabrir",
    "reabriríamos": "reabrir",
    "reabriríeis": "reabrir",
    "reabris": "reabrir",
    "reabrisse": "reabrir",
    "reabrissem": "reabrir",
    "reabrisses": "reabrir",
    "reabriste": "reabrir",
    "reabristes": "reabrir",
    "reabriu": "reabrir",
    "reabro": "reabrir",
    "reabríamo": "reabrir",
    "reabríamos": "reabrir",
    "reabríei": "reabrir",
    "reabríeis": "reabrir",
    "reabríramo": "reabrir",
    "reabríramos": "reabrir",
    "reabrírei": "reabrir",
    "reabríreis": "reabrir",
    "reabrísseis": "reabrir",
    "reabríssemos": "reabrir",
    "reabsorva": "reabsorver",
    "reabsorvais": "reabsorver",
    "reabsorvam": "reabsorver",
    "reabsorvamo": "reabsorver",
    "reabsorvamos": "reabsorver",
    "reabsorvas": "reabsorver",
    "reabsorve": "reabsorver",
    "reabsorvei": "reabsorver",
    "reabsorveis": "reabsorver",
    "reabsorvem": "reabsorver",
    "reabsorvemo": "reabsorver",
    "reabsorvemos": "reabsorver",
    "reabsorvendo": "reabsorver",
    "reabsorvera": "reabsorver",
    "reabsorveram": "reabsorver",
    "reabsorveras": "reabsorver",
    "reabsorverde": "reabsorver",
    "reabsorverdes": "reabsorver",
    "reabsorvere": "reabsorver",
    "reabsorverei": "reabsorver",
    "reabsorvereis": "reabsorver",
    "reabsorverem": "reabsorver",
    "reabsorveremos": "reabsorver",
    "reabsorveres": "reabsorver",
    "reabsorveria": "reabsorver",
    "reabsorveriam": "reabsorver",
    "reabsorverias": "reabsorver",
    "reabsorvermo": "reabsorver",
    "reabsorvermos": "reabsorver",
    "reabsorverá": "reabsorver",
    "reabsorverás": "reabsorver",
    "reabsorverão": "reabsorver",
    "reabsorveríamos": "reabsorver",
    "reabsorveríeis": "reabsorver",
    "reabsorves": "reabsorver",
    "reabsorvesse": "reabsorver",
    "reabsorvessem": "reabsorver",
    "reabsorvesses": "reabsorver",
    "reabsorveste": "reabsorver",
    "reabsorvestes": "reabsorver",
    "reabsorveu": "reabsorver",
    "reabsorvi": "reabsorver",
    "reabsorvia": "reabsorver",
    "reabsorviam": "reabsorver",
    "reabsorvias": "reabsorver",
    "reabsorvida": "reabsorvido",
    "reabsorvidas": "reabsorvido",
    "reabsorvido": "reabsorver",
    "reabsorvidos": "reabsorvido",
    "reabsorvo": "reabsorver",
    "reabsorvê": "reabsorver",
    "reabsorvêramo": "reabsorver",
    "reabsorvêramos": "reabsorver",
    "reabsorvêrei": "reabsorver",
    "reabsorvêreis": "reabsorver",
    "reabsorvêsseis": "reabsorver",
    "reabsorvêssemos": "reabsorver",
    "reabsorvíamo": "reabsorver",
    "reabsorvíamos": "reabsorver",
    "reabsorvíei": "reabsorver",
    "reabsorvíeis": "reabsorver",
    "reabsorvíveis": "reabsorvível",
    "reabsorções": "reabsorção",
    "reaccionais": "reaccional",
    "reaccionarismos": "reaccionarismo",
    "reaccionaristas": "reaccionarista",
    "reaccionária": "reaccionário",
    "reaccionárias": "reaccionário",
    "reaccionários": "reaccionário",
    "reacenda": "reacender",
    "reacendais": "reacender",
    "reacendam": "reacender",
    "reacendamo": "reacender",
    "reacendamos": "reacender",
    "reacendas": "reacender",
    "reacende": "reacender",
    "reacendei": "reacender",
    "reacendeis": "reacender",
    "reacendem": "reacender",
    "reacendemo": "reacender",
    "reacendemos": "reacender",
    "reacendendo": "reacender",
    "reacendera": "reacender",
    "reacenderam": "reacender",
    "reacenderas": "reacender",
    "reacenderde": "reacender",
    "reacenderdes": "reacender",
    "reacendere": "reacender",
    "reacenderei": "reacender",
    "reacendereis": "reacender",
    "reacenderem": "reacender",
    "reacenderemos": "reacender",
    "reacenderes": "reacender",
    "reacenderia": "reacender",
    "reacenderiam": "reacender",
    "reacenderias": "reacender",
    "reacendermo": "reacender",
    "reacendermos": "reacender",
    "reacenderá": "reacender",
    "reacenderás": "reacender",
    "reacenderão": "reacender",
    "reacenderíamos": "reacender",
    "reacenderíeis": "reacender",
    "reacendes": "reacender",
    "reacendesse": "reacender",
    "reacendessem": "reacender",
    "reacendesses": "reacender",
    "reacendeste": "reacender",
    "reacendestes": "reacender",
    "reacendeu": "reacender",
    "reacendi": "reacender",
    "reacendia": "reacender",
    "reacendiam": "reacender",
    "reacendias": "reacender",
    "reacendida": "reacender",
    "reacendidas": "reacender",
    "reacendido": "reacender",
    "reacendidos": "reacender",
    "reacendimentos": "reacendimento",
    "reacendo": "reacender",
    "reacendê": "reacender",
    "reacendêramo": "reacender",
    "reacendêramos": "reacender",
    "reacendêrei": "reacender",
    "reacendêreis": "reacender",
    "reacendêsseis": "reacender",
    "reacendêssemos": "reacender",
    "reacendíamo": "reacender",
    "reacendíamos": "reacender",
    "reacendíei": "reacender",
    "reacendíeis": "reacender",
    "reacendíveis": "reacendível",
    "reacesa": "reaceso",
    "reacesas": "reaceso",
    "reacesos": "reaceso",
    "reactiva": "reactivo",
    "reactivada": "reactivar",
    "reactivadas": "reactivar",
    "reactivado": "reactivar",
    "reactivados": "reactivar",
    "reactivai": "reactivar",
    "reactivais": "reactivar",
    "reactivam": "reactivar",
    "reactivamo": "reactivar",
    "reactivamos": "reactivar",
    "reactivando": "reactivar",
    "reactivara": "reactivar",
    "reactivaram": "reactivar",
    "reactivaras": "reactivar",
    "reactivarde": "reactivar",
    "reactivardes": "reactivar",
    "reactivare": "reactivar",
    "reactivarei": "reactivar",
    "reactivareis": "reactivar",
    "reactivarem": "reactivar",
    "reactivaremos": "reactivar",
    "reactivares": "reactivar",
    "reactivaria": "reactivar",
    "reactivariam": "reactivar",
    "reactivarias": "reactivar",
    "reactivarmo": "reactivar",
    "reactivarmos": "reactivar",
    "reactivará": "reactivar",
    "reactivarás": "reactivar",
    "reactivarão": "reactivar",
    "reactivaríamos": "reactivar",
    "reactivaríeis": "reactivar",
    "reactivas": "reactivo",
    "reactivasse": "reactivar",
    "reactivassem": "reactivar",
    "reactivasses": "reactivar",
    "reactivaste": "reactivar",
    "reactivastes": "reactivar",
    "reactivava": "reactivar",
    "reactivavam": "reactivar",
    "reactivavas": "reactivar",
    "reactivações": "reactivação",
    "reactive": "reactivar",
    "reactivei": "reactivar",
    "reactiveis": "reactivar",
    "reactivem": "reactivar",
    "reactivemo": "reactivar",
    "reactivemos": "reactivar",
    "reactives": "reactivar",
    "reactivo": "reactivar",
    "reactivos": "reactivo",
    "reactivou": "reactivar",
    "reactivá": "reactivar",
    "reactivámo": "reactivar",
    "reactivámos": "reactivar",
    "reactiváramo": "reactivar",
    "reactiváramos": "reactivar",
    "reactivárei": "reactivar",
    "reactiváreis": "reactivar",
    "reactivásseis": "reactivar",
    "reactivássemos": "reactivar",
    "reactivávamo": "reactivar",
    "reactivávamos": "reactivar",
    "reactivávei": "reactivar",
    "reactiváveis": "reactivável",
    "reactora": "reactor",
    "reactoras": "reactor",
    "reactorazinha": "reactor",
    "reactorazinhas": "reactor",
    "reactorazita": "reactor",
    "reactorazitas": "reactor",
    "reactores": "reactor",
    "reactorzinho": "reactor",
    "reactorzinhos": "reactor",
    "reactorzito": "reactor",
    "reactorzitos": "reactor",
    "reactualiza": "reactualizar",
    "reactualizada": "reactualizar",
    "reactualizadas": "reactualizar",
    "reactualizado": "reactualizar",
    "reactualizados": "reactualizar",
    "reactualizai": "reactualizar",
    "reactualizais": "reactualizar",
    "reactualizam": "reactualizar",
    "reactualizamo": "reactualizar",
    "reactualizamos": "reactualizar",
    "reactualizando": "reactualizar",
    "reactualizara": "reactualizar",
    "reactualizaram": "reactualizar",
    "reactualizaras": "reactualizar",
    "reactualizarde": "reactualizar",
    "reactualizardes": "reactualizar",
    "reactualizare": "reactualizar",
    "reactualizarei": "reactualizar",
    "reactualizareis": "reactualizar",
    "reactualizarem": "reactualizar",
    "reactualizaremos": "reactualizar",
    "reactualizares": "reactualizar",
    "reactualizaria": "reactualizar",
    "reactualizariam": "reactualizar",
    "reactualizarias": "reactualizar",
    "reactualizarmo": "reactualizar",
    "reactualizarmos": "reactualizar",
    "reactualizará": "reactualizar",
    "reactualizarás": "reactualizar",
    "reactualizarão": "reactualizar",
    "reactualizaríamos": "reactualizar",
    "reactualizaríeis": "reactualizar",
    "reactualizas": "reactualizar",
    "reactualizasse": "reactualizar",
    "reactualizassem": "reactualizar",
    "reactualizasses": "reactualizar",
    "reactualizaste": "reactualizar",
    "reactualizastes": "reactualizar",
    "reactualizava": "reactualizar",
    "reactualizavam": "reactualizar",
    "reactualizavas": "reactualizar",
    "reactualize": "reactualizar",
    "reactualizei": "reactualizar",
    "reactualizeis": "reactualizar",
    "reactualizem": "reactualizar",
    "reactualizemo": "reactualizar",
    "reactualizemos": "reactualizar",
    "reactualizes": "reactualizar",
    "reactualizo": "reactualizar",
    "reactualizou": "reactualizar",
    "reactualizá": "reactualizar",
    "reactualizámo": "reactualizar",
    "reactualizámos": "reactualizar",
    "reactualizáramo": "reactualizar",
    "reactualizáramos": "reactualizar",
    "reactualizárei": "reactualizar",
    "reactualizáreis": "reactualizar",
    "reactualizásseis": "reactualizar",
    "reactualizássemos": "reactualizar",
    "reactualizávamo": "reactualizar",
    "reactualizávamos": "reactualizar",
    "reactualizávei": "reactualizar",
    "reactualizáveis": "reactualizável",
    "reactâncias": "reactância",
    "reacusa": "reacusar",
    "reacusada": "reacusar",
    "reacusadas": "reacusar",
    "reacusado": "reacusar",
    "reacusados": "reacusar",
    "reacusai": "reacusar",
    "reacusais": "reacusar",
    "reacusam": "reacusar",
    "reacusamo": "reacusar",
    "reacusamos": "reacusar",
    "reacusando": "reacusar",
    "reacusara": "reacusar",
    "reacusaram": "reacusar",
    "reacusaras": "reacusar",
    "reacusarde": "reacusar",
    "reacusardes": "reacusar",
    "reacusare": "reacusar",
    "reacusarei": "reacusar",
    "reacusareis": "reacusar",
    "reacusarem": "reacusar",
    "reacusaremos": "reacusar",
    "reacusares": "reacusar",
    "reacusaria": "reacusar",
    "reacusariam": "reacusar",
    "reacusarias": "reacusar",
    "reacusarmo": "reacusar",
    "reacusarmos": "reacusar",
    "reacusará": "reacusar",
    "reacusarás": "reacusar",
    "reacusarão": "reacusar",
    "reacusaríamos": "reacusar",
    "reacusaríeis": "reacusar",
    "reacusas": "reacusar",
    "reacusasse": "reacusar",
    "reacusassem": "reacusar",
    "reacusasses": "reacusar",
    "reacusaste": "reacusar",
    "reacusastes": "reacusar",
    "reacusava": "reacusar",
    "reacusavam": "reacusar",
    "reacusavas": "reacusar",
    "reacusações": "reacusação",
    "reacuse": "reacusar",
    "reacusei": "reacusar",
    "reacuseis": "reacusar",
    "reacusem": "reacusar",
    "reacusemo": "reacusar",
    "reacusemos": "reacusar",
    "reacuses": "reacusar",
    "reacuso": "reacusar",
    "reacusou": "reacusar",
    "reacusá": "reacusar",
    "reacusámo": "reacusar",
    "reacusámos": "reacusar",
    "reacusáramo": "reacusar",
    "reacusáramos": "reacusar",
    "reacusárei": "reacusar",
    "reacusáreis": "reacusar",
    "reacusásseis": "reacusar",
    "reacusássemos": "reacusar",
    "reacusávamo": "reacusar",
    "reacusávamos": "reacusar",
    "reacusávei": "reacusar",
    "reacusáveis": "reacusar",
    "reacções": "reacção",
    "readapta": "readaptar",
    "readaptabilidades": "readaptabilidade",
    "readaptada": "readaptar",
    "readaptadas": "readaptar",
    "readaptado": "readaptar",
    "readaptados": "readaptar",
    "readaptai": "readaptar",
    "readaptais": "readaptar",
    "readaptam": "readaptar",
    "readaptamo": "readaptar",
    "readaptamos": "readaptar",
    "readaptando": "readaptar",
    "readaptara": "readaptar",
    "readaptaram": "readaptar",
    "readaptaras": "readaptar",
    "readaptarde": "readaptar",
    "readaptardes": "readaptar",
    "readaptare": "readaptar",
    "readaptarei": "readaptar",
    "readaptareis": "readaptar",
    "readaptarem": "readaptar",
    "readaptaremos": "readaptar",
    "readaptares": "readaptar",
    "readaptaria": "readaptar",
    "readaptariam": "readaptar",
    "readaptarias": "readaptar",
    "readaptarmo": "readaptar",
    "readaptarmos": "readaptar",
    "readaptará": "readaptar",
    "readaptarás": "readaptar",
    "readaptarão": "readaptar",
    "readaptaríamos": "readaptar",
    "readaptaríeis": "readaptar",
    "readaptas": "readaptar",
    "readaptasse": "readaptar",
    "readaptassem": "readaptar",
    "readaptasses": "readaptar",
    "readaptaste": "readaptar",
    "readaptastes": "readaptar",
    "readaptava": "readaptar",
    "readaptavam": "readaptar",
    "readaptavas": "readaptar",
    "readaptações": "readaptação",
    "readapte": "readaptar",
    "readaptei": "readaptar",
    "readapteis": "readaptar",
    "readaptem": "readaptar",
    "readaptemo": "readaptar",
    "readaptemos": "readaptar",
    "readaptes": "readaptar",
    "readapto": "readaptar",
    "readaptou": "readaptar",
    "readaptá": "readaptar",
    "readaptámo": "readaptar",
    "readaptámos": "readaptar",
    "readaptáramo": "readaptar",
    "readaptáramos": "readaptar",
    "readaptárei": "readaptar",
    "readaptáreis": "readaptar",
    "readaptásseis": "readaptar",
    "readaptássemos": "readaptar",
    "readaptávamo": "readaptar",
    "readaptávamos": "readaptar",
    "readaptávei": "readaptar",
    "readaptáveis": "readaptar",
    "readequações": "readequação",
    "readmissíveis": "readmissível",
    "readmissões": "readmissão",
    "readmita": "readmitir",
    "readmitais": "readmitir",
    "readmitam": "readmitir",
    "readmitamo": "readmitir",
    "readmitamos": "readmitir",
    "readmitas": "readmitir",
    "readmite": "readmitir",
    "readmitem": "readmitir",
    "readmites": "readmitir",
    "readmiti": "readmitir",
    "readmitia": "readmitir",
    "readmitiam": "readmitir",
    "readmitias": "readmitir",
    "readmitida": "readmitir",
    "readmitidas": "readmitir",
    "readmitido": "readmitir",
    "readmitidos": "readmitir",
    "readmitimo": "readmitir",
    "readmitimos": "readmitir",
    "readmitindo": "readmitir",
    "readmitira": "readmitir",
    "readmitiram": "readmitir",
    "readmitiras": "readmitir",
    "readmitirde": "readmitir",
    "readmitirdes": "readmitir",
    "readmitire": "readmitir",
    "readmitirei": "readmitir",
    "readmitireis": "readmitir",
    "readmitirem": "readmitir",
    "readmitiremos": "readmitir",
    "readmitires": "readmitir",
    "readmitiria": "readmitir",
    "readmitiriam": "readmitir",
    "readmitirias": "readmitir",
    "readmitirmo": "readmitir",
    "readmitirmos": "readmitir",
    "readmitirá": "readmitir",
    "readmitirás": "readmitir",
    "readmitirão": "readmitir",
    "readmitiríamos": "readmitir",
    "readmitiríeis": "readmitir",
    "readmitis": "readmitir",
    "readmitisse": "readmitir",
    "readmitissem": "readmitir",
    "readmitisses": "readmitir",
    "readmitiste": "readmitir",
    "readmitistes": "readmitir",
    "readmitiu": "readmitir",
    "readmito": "readmitir",
    "readmitíamo": "readmitir",
    "readmitíamos": "readmitir",
    "readmitíei": "readmitir",
    "readmitíeis": "readmitir",
    "readmitíramo": "readmitir",
    "readmitíramos": "readmitir",
    "readmitírei": "readmitir",
    "readmitíreis": "readmitir",
    "readmitísseis": "readmitir",
    "readmitíssemos": "readmitir",
    "readopta": "readoptar",
    "readoptada": "readoptar",
    "readoptadas": "readoptar",
    "readoptado": "readoptar",
    "readoptados": "readoptar",
    "readoptai": "readoptar",
    "readoptais": "readoptar",
    "readoptam": "readoptar",
    "readoptamo": "readoptar",
    "readoptamos": "readoptar",
    "readoptando": "readoptar",
    "readoptara": "readoptar",
    "readoptaram": "readoptar",
    "readoptaras": "readoptar",
    "readoptarde": "readoptar",
    "readoptardes": "readoptar",
    "readoptare": "readoptar",
    "readoptarei": "readoptar",
    "readoptareis": "readoptar",
    "readoptarem": "readoptar",
    "readoptaremos": "readoptar",
    "readoptares": "readoptar",
    "readoptaria": "readoptar",
    "readoptariam": "readoptar",
    "readoptarias": "readoptar",
    "readoptarmo": "readoptar",
    "readoptarmos": "readoptar",
    "readoptará": "readoptar",
    "readoptarás": "readoptar",
    "readoptarão": "readoptar",
    "readoptaríamos": "readoptar",
    "readoptaríeis": "readoptar",
    "readoptas": "readoptar",
    "readoptasse": "readoptar",
    "readoptassem": "readoptar",
    "readoptasses": "readoptar",
    "readoptaste": "readoptar",
    "readoptastes": "readoptar",
    "readoptava": "readoptar",
    "readoptavam": "readoptar",
    "readoptavas": "readoptar",
    "readopte": "readoptar",
    "readoptei": "readoptar",
    "readopteis": "readoptar",
    "readoptem": "readoptar",
    "readoptemo": "readoptar",
    "readoptemos": "readoptar",
    "readoptes": "readoptar",
    "readopto": "readoptar",
    "readoptou": "readoptar",
    "readoptá": "readoptar",
    "readoptámo": "readoptar",
    "readoptámos": "readoptar",
    "readoptáramo": "readoptar",
    "readoptáramos": "readoptar",
    "readoptárei": "readoptar",
    "readoptáreis": "readoptar",
    "readoptásseis": "readoptar",
    "readoptássemos": "readoptar",
    "readoptávamo": "readoptar",
    "readoptávamos": "readoptar",
    "readoptávei": "readoptar",
    "readoptáveis": "readoptar",
    "readopções": "readopção",
    "readormece": "readormecer",
    "readormecei": "readormecer",
    "readormeceis": "readormecer",
    "readormecem": "readormecer",
    "readormecemo": "readormecer",
    "readormecemos": "readormecer",
    "readormecendo": "readormecer",
    "readormecera": "readormecer",
    "readormeceram": "readormecer",
    "readormeceras": "readormecer",
    "readormecerdes": "readormecer",
    "readormecerei": "readormecer",
    "readormecereis": "readormecer",
    "readormecerem": "readormecer",
    "readormeceremos": "readormecer",
    "readormeceres": "readormecer",
    "readormeceria": "readormecer",
    "readormeceriam": "readormecer",
    "readormecerias": "readormecer",
    "readormecermo": "readormecer",
    "readormecermos": "readormecer",
    "readormecerá": "readormecer",
    "readormecerás": "readormecer",
    "readormecerão": "readormecer",
    "readormeceríamos": "readormecer",
    "readormeceríeis": "readormecer",
    "readormeces": "readormecer",
    "readormecesse": "readormecer",
    "readormecessem": "readormecer",
    "readormecesses": "readormecer",
    "readormeceste": "readormecer",
    "readormecestes": "readormecer",
    "readormeceu": "readormecer",
    "readormeci": "readormecer",
    "readormecia": "readormecer",
    "readormeciam": "readormecer",
    "readormecias": "readormecer",
    "readormecida": "readormecer",
    "readormecidas": "readormecer",
    "readormecido": "readormecer",
    "readormecidos": "readormecer",
    "readormecêramo": "readormecer",
    "readormecêramos": "readormecer",
    "readormecêreis": "readormecer",
    "readormecêsseis": "readormecer",
    "readormecêssemos": "readormecer",
    "readormecíamo": "readormecer",
    "readormecíamos": "readormecer",
    "readormecíeis": "readormecer",
    "readormeça": "readormecer",
    "readormeçais": "readormecer",
    "readormeçam": "readormecer",
    "readormeçamo": "readormecer",
    "readormeçamos": "readormecer",
    "readormeças": "readormecer",
    "readormeço": "readormecer",
    "readquira": "readquirir",
    "readquirais": "readquirir",
    "readquiram": "readquirir",
    "readquiramo": "readquirir",
    "readquiramos": "readquirir",
    "readquiras": "readquirir",
    "readquire": "readquirir",
    "readquirem": "readquirir",
    "readquires": "readquirir",
    "readquiri": "readquirir",
    "readquiria": "readquirir",
    "readquiriam": "readquirir",
    "readquirias": "readquirir",
    "readquirida": "readquirir",
    "readquiridas": "readquirir",
    "readquirido": "readquirir",
    "readquiridos": "readquirir",
    "readquirimo": "readquirir",
    "readquirimos": "readquirir",
    "readquirindo": "readquirir",
    "readquirira": "readquirir",
    "readquiriram": "readquirir",
    "readquiriras": "readquirir",
    "readquirirde": "readquirir",
    "readquirirdes": "readquirir",
    "readquirire": "readquirir",
    "readquirirei": "readquirir",
    "readquirireis": "readquirir",
    "readquirirem": "readquirir",
    "readquiriremos": "readquirir",
    "readquirires": "readquirir",
    "readquiriria": "readquirir",
    "readquiririam": "readquirir",
    "readquiririas": "readquirir",
    "readquirirmo": "readquirir",
    "readquirirmos": "readquirir",
    "readquirirá": "readquirir",
    "readquirirás": "readquirir",
    "readquirirão": "readquirir",
    "readquiriríamos": "readquirir",
    "readquiriríeis": "readquirir",
    "readquiris": "readquirir",
    "readquirisse": "readquirir",
    "readquirissem": "readquirir",
    "readquirisses": "readquirir",
    "readquiriste": "readquirir",
    "readquiristes": "readquirir",
    "readquiriu": "readquirir",
    "readquirições": "readquirição",
    "readquiro": "readquirir",
    "readquiríamo": "readquirir",
    "readquiríamos": "readquirir",
    "readquiríei": "readquirir",
    "readquiríeis": "readquirir",
    "readquiríramo": "readquirir",
    "readquiríramos": "readquirir",
    "readquirírei": "readquirir",
    "readquiríreis": "readquirir",
    "readquirísseis": "readquirir",
    "readquiríssemos": "readquirir",
    "readquiríveis": "readquirível",
    "reafecta": "reafectar",
    "reafectada": "reafectar",
    "reafectadas": "reafectar",
    "reafectado": "reafectar",
    "reafectados": "reafectar",
    "reafectai": "reafectar",
    "reafectais": "reafectar",
    "reafectam": "reafectar",
    "reafectamo": "reafectar",
    "reafectamos": "reafectar",
    "reafectando": "reafectar",
    "reafectara": "reafectar",
    "reafectaram": "reafectar",
    "reafectaras": "reafectar",
    "reafectarde": "reafectar",
    "reafectardes": "reafectar",
    "reafectare": "reafectar",
    "reafectarei": "reafectar",
    "reafectareis": "reafectar",
    "reafectarem": "reafectar",
    "reafectaremos": "reafectar",
    "reafectares": "reafectar",
    "reafectaria": "reafectar",
    "reafectariam": "reafectar",
    "reafectarias": "reafectar",
    "reafectarmo": "reafectar",
    "reafectarmos": "reafectar",
    "reafectará": "reafectar",
    "reafectarás": "reafectar",
    "reafectarão": "reafectar",
    "reafectaríamos": "reafectar",
    "reafectaríeis": "reafectar",
    "reafectas": "reafectar",
    "reafectasse": "reafectar",
    "reafectassem": "reafectar",
    "reafectasses": "reafectar",
    "reafectaste": "reafectar",
    "reafectastes": "reafectar",
    "reafectava": "reafectar",
    "reafectavam": "reafectar",
    "reafectavas": "reafectar",
    "reafectações": "reafectação",
    "reafecte": "reafectar",
    "reafectei": "reafectar",
    "reafecteis": "reafectar",
    "reafectem": "reafectar",
    "reafectemo": "reafectar",
    "reafectemos": "reafectar",
    "reafectes": "reafectar",
    "reafecto": "reafectar",
    "reafectou": "reafectar",
    "reafectá": "reafectar",
    "reafectámo": "reafectar",
    "reafectámos": "reafectar",
    "reafectáramo": "reafectar",
    "reafectáramos": "reafectar",
    "reafectárei": "reafectar",
    "reafectáreis": "reafectar",
    "reafectásseis": "reafectar",
    "reafectássemos": "reafectar",
    "reafectávamo": "reafectar",
    "reafectávamos": "reafectar",
    "reafectávei": "reafectar",
    "reafectáveis": "reafectar",
    "reafima": "reafimar",
    "reafimada": "reafimar",
    "reafimadas": "reafimar",
    "reafimado": "reafimar",
    "reafimados": "reafimar",
    "reafimai": "reafimar",
    "reafimais": "reafimar",
    "reafimam": "reafimar",
    "reafimamo": "reafimar",
    "reafimamos": "reafimar",
    "reafimando": "reafimar",
    "reafimara": "reafimar",
    "reafimaram": "reafimar",
    "reafimaras": "reafimar",
    "reafimarde": "reafimar",
    "reafimardes": "reafimar",
    "reafimare": "reafimar",
    "reafimarei": "reafimar",
    "reafimareis": "reafimar",
    "reafimarem": "reafimar",
    "reafimaremos": "reafimar",
    "reafimares": "reafimar",
    "reafimaria": "reafimar",
    "reafimariam": "reafimar",
    "reafimarias": "reafimar",
    "reafimarmo": "reafimar",
    "reafimarmos": "reafimar",
    "reafimará": "reafimar",
    "reafimarás": "reafimar",
    "reafimarão": "reafimar",
    "reafimaríamos": "reafimar",
    "reafimaríeis": "reafimar",
    "reafimas": "reafimar",
    "reafimasse": "reafimar",
    "reafimassem": "reafimar",
    "reafimasses": "reafimar",
    "reafimaste": "reafimar",
    "reafimastes": "reafimar",
    "reafimava": "reafimar",
    "reafimavam": "reafimar",
    "reafimavas": "reafimar",
    "reafime": "reafimar",
    "reafimei": "reafimar",
    "reafimeis": "reafimar",
    "reafimem": "reafimar",
    "reafimemo": "reafimar",
    "reafimemos": "reafimar",
    "reafimes": "reafimar",
    "reafimo": "reafimar",
    "reafimou": "reafimar",
    "reafimá": "reafimar",
    "reafimámo": "reafimar",
    "reafimámos": "reafimar",
    "reafimáramo": "reafimar",
    "reafimáramos": "reafimar",
    "reafimárei": "reafimar",
    "reafimáreis": "reafimar",
    "reafimásseis": "reafimar",
    "reafimássemos": "reafimar",
    "reafimávamo": "reafimar",
    "reafimávamos": "reafimar",
    "reafimávei": "reafimar",
    "reafimáveis": "reafimar",
    "reafina": "reafinar",
    "reafinada": "reafinar",
    "reafinadas": "reafinar",
    "reafinado": "reafinar",
    "reafinados": "reafinar",
    "reafinai": "reafinar",
    "reafinais": "reafinar",
    "reafinam": "reafinar",
    "reafinamo": "reafinar",
    "reafinamos": "reafinar",
    "reafinando": "reafinar",
    "reafinara": "reafinar",
    "reafinaram": "reafinar",
    "reafinaras": "reafinar",
    "reafinarde": "reafinar",
    "reafinardes": "reafinar",
    "reafinare": "reafinar",
    "reafinarei": "reafinar",
    "reafinareis": "reafinar",
    "reafinarem": "reafinar",
    "reafinaremos": "reafinar",
    "reafinares": "reafinar",
    "reafinaria": "reafinar",
    "reafinariam": "reafinar",
    "reafinarias": "reafinar",
    "reafinarmo": "reafinar",
    "reafinarmos": "reafinar",
    "reafinará": "reafinar",
    "reafinarás": "reafinar",
    "reafinarão": "reafinar",
    "reafinaríamos": "reafinar",
    "reafinaríeis": "reafinar",
    "reafinas": "reafinar",
    "reafinasse": "reafinar",
    "reafinassem": "reafinar",
    "reafinasses": "reafinar",
    "reafinaste": "reafinar",
    "reafinastes": "reafinar",
    "reafinava": "reafinar",
    "reafinavam": "reafinar",
    "reafinavas": "reafinar",
    "reafine": "reafinar",
    "reafinei": "reafinar",
    "reafineis": "reafinar",
    "reafinem": "reafinar",
    "reafinemo": "reafinar",
    "reafinemos": "reafinar",
    "reafines": "reafinar",
    "reafino": "reafinar",
    "reafinou": "reafinar",
    "reafiná": "reafinar",
    "reafinámo": "reafinar",
    "reafinámos": "reafinar",
    "reafináramo": "reafinar",
    "reafináramos": "reafinar",
    "reafinárei": "reafinar",
    "reafináreis": "reafinar",
    "reafinásseis": "reafinar",
    "reafinássemos": "reafinar",
    "reafinávamo": "reafinar",
    "reafinávamos": "reafinar",
    "reafinávei": "reafinar",
    "reafináveis": "reafinar",
    "reafirma": "reafirmar",
    "reafirmada": "reafirmar",
    "reafirmadas": "reafirmar",
    "reafirmado": "reafirmar",
    "reafirmados": "reafirmar",
    "reafirmai": "reafirmar",
    "reafirmais": "reafirmar",
    "reafirmam": "reafirmar",
    "reafirmamo": "reafirmar",
    "reafirmamos": "reafirmar",
    "reafirmando": "reafirmar",
    "reafirmara": "reafirmar",
    "reafirmaram": "reafirmar",
    "reafirmaras": "reafirmar",
    "reafirmarde": "reafirmar",
    "reafirmardes": "reafirmar",
    "reafirmare": "reafirmar",
    "reafirmarei": "reafirmar",
    "reafirmareis": "reafirmar",
    "reafirmarem": "reafirmar",
    "reafirmaremos": "reafirmar",
    "reafirmares": "reafirmar",
    "reafirmaria": "reafirmar",
    "reafirmariam": "reafirmar",
    "reafirmarias": "reafirmar",
    "reafirmarmo": "reafirmar",
    "reafirmarmos": "reafirmar",
    "reafirmará": "reafirmar",
    "reafirmarás": "reafirmar",
    "reafirmarão": "reafirmar",
    "reafirmaríamos": "reafirmar",
    "reafirmaríeis": "reafirmar",
    "reafirmas": "reafirmar",
    "reafirmasse": "reafirmar",
    "reafirmassem": "reafirmar",
    "reafirmasses": "reafirmar",
    "reafirmaste": "reafirmar",
    "reafirmastes": "reafirmar",
    "reafirmava": "reafirmar",
    "reafirmavam": "reafirmar",
    "reafirmavas": "reafirmar",
    "reafirmações": "reafirmação",
    "reafirme": "reafirmar",
    "reafirmei": "reafirmar",
    "reafirmeis": "reafirmar",
    "reafirmem": "reafirmar",
    "reafirmemo": "reafirmar",
    "reafirmemos": "reafirmar",
    "reafirmes": "reafirmar",
    "reafirmo": "reafirmar",
    "reafirmou": "reafirmar",
    "reafirmá": "reafirmar",
    "reafirmámo": "reafirmar",
    "reafirmámos": "reafirmar",
    "reafirmáramo": "reafirmar",
    "reafirmáramos": "reafirmar",
    "reafirmárei": "reafirmar",
    "reafirmáreis": "reafirmar",
    "reafirmásseis": "reafirmar",
    "reafirmássemos": "reafirmar",
    "reafirmávamo": "reafirmar",
    "reafirmávamos": "reafirmar",
    "reafirmávei": "reafirmar",
    "reafirmáveis": "reafirmar",
    "reafundamentos": "reafundamento",
    "reage": "reagir",
    "reagem": "reagir",
    "reagentes": "reagente",
    "reagentezinha": "reagente",
    "reagentezinhas": "reagente",
    "reagentezinho": "reagente",
    "reagentezinhos": "reagente",
    "reagentezita": "reagente",
    "reagentezitas": "reagente",
    "reagentezito": "reagente",
    "reagentezitos": "reagente",
    "reages": "reagir",
    "reagi": "reagir",
    "reagia": "reagir",
    "reagiam": "reagir",
    "reagias": "reagir",
    "reagida": "reagir",
    "reagidas": "reagir",
    "reagido": "reagir",
    "reagidos": "reagir",
    "reagimo": "reagir",
    "reagimos": "reagir",
    "reagindo": "reagir",
    "reagira": "reagir",
    "reagiram": "reagir",
    "reagiras": "reagir",
    "reagirdes": "reagir",
    "reagirei": "reagir",
    "reagireis": "reagir",
    "reagirem": "reagir",
    "reagiremos": "reagir",
    "reagires": "reagir",
    "reagiria": "reagir",
    "reagiriam": "reagir",
    "reagirias": "reagir",
    "reagirmo": "reagir",
    "reagirmos": "reagir",
    "reagirá": "reagir",
    "reagirás": "reagir",
    "reagirão": "reagir",
    "reagiríamos": "reagir",
    "reagiríeis": "reagir",
    "reagis": "reagir",
    "reagisse": "reagir",
    "reagissem": "reagir",
    "reagisses": "reagir",
    "reagiste": "reagir",
    "reagistes": "reagir",
    "reagiu": "reagir",
    "reagradece": "reagradecer",
    "reagradecei": "reagradecer",
    "reagradeceis": "reagradecer",
    "reagradecem": "reagradecer",
    "reagradecemo": "reagradecer",
    "reagradecemos": "reagradecer",
    "reagradecendo": "reagradecer",
    "reagradecera": "reagradecer",
    "reagradeceram": "reagradecer",
    "reagradeceras": "reagradecer",
    "reagradecerde": "reagradecer",
    "reagradecerdes": "reagradecer",
    "reagradecere": "reagradecer",
    "reagradecerei": "reagradecer",
    "reagradecereis": "reagradecer",
    "reagradecerem": "reagradecer",
    "reagradeceremos": "reagradecer",
    "reagradeceres": "reagradecer",
    "reagradeceria": "reagradecer",
    "reagradeceriam": "reagradecer",
    "reagradecerias": "reagradecer",
    "reagradecermo": "reagradecer",
    "reagradecermos": "reagradecer",
    "reagradecerá": "reagradecer",
    "reagradecerás": "reagradecer",
    "reagradecerão": "reagradecer",
    "reagradeceríamos": "reagradecer",
    "reagradeceríeis": "reagradecer",
    "reagradeces": "reagradecer",
    "reagradecesse": "reagradecer",
    "reagradecessem": "reagradecer",
    "reagradecesses": "reagradecer",
    "reagradeceste": "reagradecer",
    "reagradecestes": "reagradecer",
    "reagradeceu": "reagradecer",
    "reagradeci": "reagradecer",
    "reagradecia": "reagradecer",
    "reagradeciam": "reagradecer",
    "reagradecias": "reagradecer",
    "reagradecida": "reagradecer",
    "reagradecidas": "reagradecer",
    "reagradecido": "reagradecer",
    "reagradecidos": "reagradecer",
    "reagradecê": "reagradecer",
    "reagradecêramo": "reagradecer",
    "reagradecêramos": "reagradecer",
    "reagradecêrei": "reagradecer",
    "reagradecêreis": "reagradecer",
    "reagradecêsseis": "reagradecer",
    "reagradecêssemos": "reagradecer",
    "reagradecíamo": "reagradecer",
    "reagradecíamos": "reagradecer",
    "reagradecíei": "reagradecer",
    "reagradecíeis": "reagradecer",
    "reagradeça": "reagradecer",
    "reagradeçais": "reagradecer",
    "reagradeçam": "reagradecer",
    "reagradeçamo": "reagradecer",
    "reagradeçamos": "reagradecer",
    "reagradeças": "reagradecer",
    "reagradeço": "reagradecer",
    "reagrava": "reagravar",
    "reagravada": "reagravar",
    "reagravadas": "reagravar",
    "reagravado": "reagravar",
    "reagravados": "reagravar",
    "reagravai": "reagravar",
    "reagravais": "reagravar",
    "reagravam": "reagravar",
    "reagravamo": "reagravar",
    "reagravamos": "reagravar",
    "reagravando": "reagravar",
    "reagravara": "reagravar",
    "reagravaram": "reagravar",
    "reagravaras": "reagravar",
    "reagravarde": "reagravar",
    "reagravardes": "reagravar",
    "reagravare": "reagravar",
    "reagravarei": "reagravar",
    "reagravareis": "reagravar",
    "reagravarem": "reagravar",
    "reagravaremos": "reagravar",
    "reagravares": "reagravar",
    "reagravaria": "reagravar",
    "reagravariam": "reagravar",
    "reagravarias": "reagravar",
    "reagravarmo": "reagravar",
    "reagravarmos": "reagravar",
    "reagravará": "reagravar",
    "reagravarás": "reagravar",
    "reagravarão": "reagravar",
    "reagravaríamos": "reagravar",
    "reagravaríeis": "reagravar",
    "reagravas": "reagravar",
    "reagravasse": "reagravar",
    "reagravassem": "reagravar",
    "reagravasses": "reagravar",
    "reagravaste": "reagravar",
    "reagravastes": "reagravar",
    "reagravava": "reagravar",
    "reagravavam": "reagravar",
    "reagravavas": "reagravar",
    "reagrave": "reagravar",
    "reagravei": "reagravar",
    "reagraveis": "reagravar",
    "reagravem": "reagravar",
    "reagravemo": "reagravar",
    "reagravemos": "reagravar",
    "reagraves": "reagravar",
    "reagravo": "reagravar",
    "reagravou": "reagravar",
    "reagravá": "reagravar",
    "reagravámo": "reagravar",
    "reagravámos": "reagravar",
    "reagraváramo": "reagravar",
    "reagraváramos": "reagravar",
    "reagravárei": "reagravar",
    "reagraváreis": "reagravar",
    "reagravásseis": "reagravar",
    "reagravássemos": "reagravar",
    "reagravávamo": "reagravar",
    "reagravávamos": "reagravar",
    "reagravávei": "reagravar",
    "reagraváveis": "reagravar",
    "reagrupa": "reagrupar",
    "reagrupada": "reagrupar",
    "reagrupadas": "reagrupar",
    "reagrupado": "reagrupar",
    "reagrupados": "reagrupar",
    "reagrupai": "reagrupar",
    "reagrupais": "reagrupar",
    "reagrupam": "reagrupar",
    "reagrupamentos": "reagrupamento",
    "reagrupamo": "reagrupar",
    "reagrupamos": "reagrupar",
    "reagrupando": "reagrupar",
    "reagrupara": "reagrupar",
    "reagruparam": "reagrupar",
    "reagruparas": "reagrupar",
    "reagruparde": "reagrupar",
    "reagrupardes": "reagrupar",
    "reagrupare": "reagrupar",
    "reagruparei": "reagrupar",
    "reagrupareis": "reagrupar",
    "reagruparem": "reagrupar",
    "reagruparemos": "reagrupar",
    "reagrupares": "reagrupar",
    "reagruparia": "reagrupar",
    "reagrupariam": "reagrupar",
    "reagruparias": "reagrupar",
    "reagruparmo": "reagrupar",
    "reagruparmos": "reagrupar",
    "reagrupará": "reagrupar",
    "reagruparás": "reagrupar",
    "reagruparão": "reagrupar",
    "reagruparíamos": "reagrupar",
    "reagruparíeis": "reagrupar",
    "reagrupas": "reagrupar",
    "reagrupasse": "reagrupar",
    "reagrupassem": "reagrupar",
    "reagrupasses": "reagrupar",
    "reagrupaste": "reagrupar",
    "reagrupastes": "reagrupar",
    "reagrupava": "reagrupar",
    "reagrupavam": "reagrupar",
    "reagrupavas": "reagrupar",
    "reagrupe": "reagrupar",
    "reagrupei": "reagrupar",
    "reagrupeis": "reagrupar",
    "reagrupem": "reagrupar",
    "reagrupemo": "reagrupar",
    "reagrupemos": "reagrupar",
    "reagrupes": "reagrupar",
    "reagrupo": "reagrupar",
    "reagrupou": "reagrupar",
    "reagrupá": "reagrupar",
    "reagrupámo": "reagrupar",
    "reagrupámos": "reagrupar",
    "reagrupáramo": "reagrupar",
    "reagrupáramos": "reagrupar",
    "reagrupárei": "reagrupar",
    "reagrupáreis": "reagrupar",
    "reagrupásseis": "reagrupar",
    "reagrupássemos": "reagrupar",
    "reagrupávamo": "reagrupar",
    "reagrupávamos": "reagrupar",
    "reagrupávei": "reagrupar",
    "reagrupáveis": "reagrupável",
    "reagíamo": "reagir",
    "reagíamos": "reagir",
    "reagíeis": "reagir",
    "reagíramo": "reagir",
    "reagíramos": "reagir",
    "reagíreis": "reagir",
    "reagísseis": "reagir",
    "reagíssemos": "reagir",
    "reais": "real",
    "reaja": "reagir",
    "reajais": "reagir",
    "reajam": "reagir",
    "reajamo": "reagir",
    "reajamos": "reagir",
    "reajas": "reagir",
    "reajo": "reagir",
    "reajusta": "reajustar",
    "reajustada": "reajustar",
    "reajustadas": "reajustar",
    "reajustado": "reajustar",
    "reajustados": "reajustar",
    "reajustai": "reajustar",
    "reajustais": "reajustar",
    "reajustam": "reajustar",
    "reajustamentos": "reajustamento",
    "reajustamo": "reajustar",
    "reajustamos": "reajustar",
    "reajustando": "reajustar",
    "reajustara": "reajustar",
    "reajustaram": "reajustar",
    "reajustaras": "reajustar",
    "reajustarde": "reajustar",
    "reajustardes": "reajustar",
    "reajustare": "reajustar",
    "reajustarei": "reajustar",
    "reajustareis": "reajustar",
    "reajustarem": "reajustar",
    "reajustaremos": "reajustar",
    "reajustares": "reajustar",
    "reajustaria": "reajustar",
    "reajustariam": "reajustar",
    "reajustarias": "reajustar",
    "reajustarmo": "reajustar",
    "reajustarmos": "reajustar",
    "reajustará": "reajustar",
    "reajustarás": "reajustar",
    "reajustarão": "reajustar",
    "reajustaríamos": "reajustar",
    "reajustaríeis": "reajustar",
    "reajustas": "reajustar",
    "reajustasse": "reajustar",
    "reajustassem": "reajustar",
    "reajustasses": "reajustar",
    "reajustaste": "reajustar",
    "reajustastes": "reajustar",
    "reajustava": "reajustar",
    "reajustavam": "reajustar",
    "reajustavas": "reajustar",
    "reajuste": "reajustar",
    "reajustei": "reajustar",
    "reajusteis": "reajustar",
    "reajustem": "reajustar",
    "reajustemo": "reajustar",
    "reajustemos": "reajustar",
    "reajustes": "reajuste",
    "reajusto": "reajustar",
    "reajustou": "reajustar",
    "reajustá": "reajustar",
    "reajustámo": "reajustar",
    "reajustámos": "reajustar",
    "reajustáramo": "reajustar",
    "reajustáramos": "reajustar",
    "reajustárei": "reajustar",
    "reajustáreis": "reajustar",
    "reajustásseis": "reajustar",
    "reajustássemos": "reajustar",
    "reajustávamo": "reajustar",
    "reajustávamos": "reajustar",
    "reajustávei": "reajustar",
    "reajustáveis": "reajustável",
    "realce": "realçar",
    "realcei": "realçar",
    "realceis": "realçar",
    "realcem": "realçar",
    "realcemo": "realçar",
    "realcemos": "realçar",
    "realces": "realce",
    "realegra": "realegrar",
    "realegrada": "realegrar",
    "realegradas": "realegrar",
    "realegrado": "realegrar",
    "realegrados": "realegrar",
    "realegrai": "realegrar",
    "realegrais": "realegrar",
    "realegram": "realegrar",
    "realegramo": "realegrar",
    "realegramos": "realegrar",
    "realegrando": "realegrar",
    "realegrara": "realegrar",
    "realegraram": "realegrar",
    "realegraras": "realegrar",
    "realegrarde": "realegrar",
    "realegrardes": "realegrar",
    "realegrare": "realegrar",
    "realegrarei": "realegrar",
    "realegrareis": "realegrar",
    "realegrarem": "realegrar",
    "realegraremos": "realegrar",
    "realegrares": "realegrar",
    "realegraria": "realegrar",
    "realegrariam": "realegrar",
    "realegrarias": "realegrar",
    "realegrarmo": "realegrar",
    "realegrarmos": "realegrar",
    "realegrará": "realegrar",
    "realegrarás": "realegrar",
    "realegrarão": "realegrar",
    "realegraríamos": "realegrar",
    "realegraríeis": "realegrar",
    "realegras": "realegrar",
    "realegrasse": "realegrar",
    "realegrassem": "realegrar",
    "realegrasses": "realegrar",
    "realegraste": "realegrar",
    "realegrastes": "realegrar",
    "realegrava": "realegrar",
    "realegravam": "realegrar",
    "realegravas": "realegrar",
    "realegre": "realegrar",
    "realegrei": "realegrar",
    "realegreis": "realegrar",
    "realegrem": "realegrar",
    "realegremo": "realegrar",
    "realegremos": "realegrar",
    "realegres": "realegrar",
    "realegro": "realegrar",
    "realegrou": "realegrar",
    "realegrá": "realegrar",
    "realegrámo": "realegrar",
    "realegrámos": "realegrar",
    "realegráramo": "realegrar",
    "realegráramos": "realegrar",
    "realegrárei": "realegrar",
    "realegráreis": "realegrar",
    "realegrásseis": "realegrar",
    "realegrássemos": "realegrar",
    "realegrávamo": "realegrar",
    "realegrávamos": "realegrar",
    "realegrávei": "realegrar",
    "realegráveis": "realegrar",
    "realejos": "realejo",
    "realenga": "realengo",
    "realengas": "realengo",
    "realengos": "realengo",
    "realenta": "realentar",
    "realentada": "realentar",
    "realentadas": "realentar",
    "realentado": "realentar",
    "realentados": "realentar",
    "realentai": "realentar",
    "realentais": "realentar",
    "realentam": "realentar",
    "realentamo": "realentar",
    "realentamos": "realentar",
    "realentando": "realentar",
    "realentara": "realentar",
    "realentaram": "realentar",
    "realentaras": "realentar",
    "realentarde": "realentar",
    "realentardes": "realentar",
    "realentare": "realentar",
    "realentarei": "realentar",
    "realentareis": "realentar",
    "realentarem": "realentar",
    "realentaremos": "realentar",
    "realentares": "realentar",
    "realentaria": "realentar",
    "realentariam": "realentar",
    "realentarias": "realentar",
    "realentarmo": "realentar",
    "realentarmos": "realentar",
    "realentará": "realentar",
    "realentarás": "realentar",
    "realentarão": "realentar",
    "realentaríamos": "realentar",
    "realentaríeis": "realentar",
    "realentas": "realentar",
    "realentasse": "realentar",
    "realentassem": "realentar",
    "realentasses": "realentar",
    "realentaste": "realentar",
    "realentastes": "realentar",
    "realentava": "realentar",
    "realentavam": "realentar",
    "realentavas": "realentar",
    "realente": "realentar",
    "realentei": "realentar",
    "realenteis": "realentar",
    "realentem": "realentar",
    "realentemo": "realentar",
    "realentemos": "realentar",
    "realentes": "realentar",
    "realento": "realentar",
    "realentou": "realentar",
    "realentá": "realentar",
    "realentámo": "realentar",
    "realentámos": "realentar",
    "realentáramo": "realentar",
    "realentáramos": "realentar",
    "realentárei": "realentar",
    "realentáreis": "realentar",
    "realentásseis": "realentar",
    "realentássemos": "realentar",
    "realentávamo": "realentar",
    "realentávamos": "realentar",
    "realentávei": "realentar",
    "realentáveis": "realentar",
    "realezas": "realeza",
    "realidades": "realidade",
    "realimentações": "realimentação",
    "realinha": "realinhar",
    "realinhada": "realinhar",
    "realinhadas": "realinhar",
    "realinhado": "realinhar",
    "realinhados": "realinhar",
    "realinhai": "realinhar",
    "realinhais": "realinhar",
    "realinham": "realinhar",
    "realinhamentos": "realinhamento",
    "realinhamo": "realinhar",
    "realinhamos": "realinhar",
    "realinhando": "realinhar",
    "realinhara": "realinhar",
    "realinharam": "realinhar",
    "realinharas": "realinhar",
    "realinharde": "realinhar",
    "realinhardes": "realinhar",
    "realinhare": "realinhar",
    "realinharei": "realinhar",
    "realinhareis": "realinhar",
    "realinharem": "realinhar",
    "realinharemos": "realinhar",
    "realinhares": "realinhar",
    "realinharia": "realinhar",
    "realinhariam": "realinhar",
    "realinharias": "realinhar",
    "realinharmo": "realinhar",
    "realinharmos": "realinhar",
    "realinhará": "realinhar",
    "realinharás": "realinhar",
    "realinharão": "realinhar",
    "realinharíamos": "realinhar",
    "realinharíeis": "realinhar",
    "realinhas": "realinhar",
    "realinhasse": "realinhar",
    "realinhassem": "realinhar",
    "realinhasses": "realinhar",
    "realinhaste": "realinhar",
    "realinhastes": "realinhar",
    "realinhava": "realinhar",
    "realinhavam": "realinhar",
    "realinhavas": "realinhar",
    "realinhe": "realinhar",
    "realinhei": "realinhar",
    "realinheis": "realinhar",
    "realinhem": "realinhar",
    "realinhemo": "realinhar",
    "realinhemos": "realinhar",
    "realinhes": "realinhar",
    "realinho": "realinhar",
    "realinhou": "realinhar",
    "realinhá": "realinhar",
    "realinhámo": "realinhar",
    "realinhámos": "realinhar",
    "realinháramo": "realinhar",
    "realinháramos": "realinhar",
    "realinhárei": "realinhar",
    "realinháreis": "realinhar",
    "realinhásseis": "realinhar",
    "realinhássemos": "realinhar",
    "realinhávamo": "realinhar",
    "realinhávamos": "realinhar",
    "realinhávei": "realinhar",
    "realinháveis": "realinhar",
    "realismos": "realismo",
    "realista": "realistar",
    "realistada": "realistar",
    "realistadas": "realistar",
    "realistado": "realistar",
    "realistados": "realistar",
    "realistai": "realistar",
    "realistais": "realistar",
    "realistam": "realistar",
    "realistamo": "realistar",
    "realistamos": "realistar",
    "realistando": "realistar",
    "realistara": "realistar",
    "realistaram": "realistar",
    "realistaras": "realistar",
    "realistarde": "realistar",
    "realistardes": "realistar",
    "realistare": "realistar",
    "realistarei": "realistar",
    "realistareis": "realistar",
    "realistarem": "realistar",
    "realistaremos": "realistar",
    "realistares": "realistar",
    "realistaria": "realistar",
    "realistariam": "realistar",
    "realistarias": "realistar",
    "realistarmo": "realistar",
    "realistarmos": "realistar",
    "realistará": "realistar",
    "realistarás": "realistar",
    "realistarão": "realistar",
    "realistaríamos": "realistar",
    "realistaríeis": "realistar",
    "realistas": "realistar",
    "realistasse": "realistar",
    "realistassem": "realistar",
    "realistasses": "realistar",
    "realistaste": "realistar",
    "realistastes": "realistar",
    "realistava": "realistar",
    "realistavam": "realistar",
    "realistavas": "realistar",
    "realiste": "realistar",
    "realistei": "realistar",
    "realisteis": "realistar",
    "realistem": "realistar",
    "realistemo": "realistar",
    "realistemos": "realistar",
    "realistes": "realistar",
    "realisto": "realistar",
    "realistou": "realistar",
    "realistá": "realistar",
    "realistámo": "realistar",
    "realistámos": "realistar",
    "realistáramo": "realistar",
    "realistáramos": "realistar",
    "realistárei": "realistar",
    "realistáreis": "realistar",
    "realistásseis": "realistar",
    "realistássemos": "realistar",
    "realistávamo": "realistar",
    "realistávamos": "realistar",
    "realistávei": "realistar",
    "realistáveis": "realistável",
    "realiza": "realizar",
    "realizabilidades": "realizabilidade",
    "realizada": "realizar",
    "realizadas": "realizar",
    "realizado": "realizar",
    "realizadora": "realizador",
    "realizadoras": "realizador",
    "realizadorazinha": "realizador",
    "realizadorazinhas": "realizador",
    "realizadorazita": "realizador",
    "realizadorazitas": "realizador",
    "realizadores": "realizador",
    "realizadorzinho": "realizador",
    "realizadorzinhos": "realizador",
    "realizadorzito": "realizador",
    "realizadorzitos": "realizador",
    "realizados": "realizar",
    "realizai": "realizar",
    "realizais": "realizar",
    "realizam": "realizar",
    "realizamo": "realizar",
    "realizamos": "realizar",
    "realizando": "realizar",
    "realizara": "realizar",
    "realizaram": "realizar",
    "realizaras": "realizar",
    "realizarde": "realizar",
    "realizardes": "realizar",
    "realizare": "realizar",
    "realizarei": "realizar",
    "realizareis": "realizar",
    "realizarem": "realizar",
    "realizaremos": "realizar",
    "realizares": "realizar",
    "realizaria": "realizar",
    "realizariam": "realizar",
    "realizarias": "realizar",
    "realizarmo": "realizar",
    "realizarmos": "realizar",
    "realizará": "realizar",
    "realizarás": "realizar",
    "realizarão": "realizar",
    "realizaríamos": "realizar",
    "realizaríeis": "realizar",
    "realizas": "realizar",
    "realizasse": "realizar",
    "realizassem": "realizar",
    "realizasses": "realizar",
    "realizaste": "realizar",
    "realizastes": "realizar",
    "realizava": "realizar",
    "realizavam": "realizar",
    "realizavas": "realizar",
    "realizações": "realização",
    "realize": "realizar",
    "realizei": "realizar",
    "realizeis": "realizar",
    "realizem": "realizar",
    "realizemo": "realizar",
    "realizemos": "realizar",
    "realizes": "realizar",
    "realizo": "realizar",
    "realizou": "realizar",
    "realizá": "realizar",
    "realizámo": "realizar",
    "realizámos": "realizar",
    "realizáramo": "realizar",
    "realizáramos": "realizar",
    "realizárei": "realizar",
    "realizáreis": "realizar",
    "realizásseis": "realizar",
    "realizássemos": "realizar",
    "realizávamo": "realizar",
    "realizávamos": "realizar",
    "realizávei": "realizar",
    "realizáveis": "realizável",
    "realoja": "realojar",
    "realojada": "realojar",
    "realojadas": "realojar",
    "realojado": "realojar",
    "realojados": "realojar",
    "realojai": "realojar",
    "realojais": "realojar",
    "realojam": "realojar",
    "realojamentos": "realojamento",
    "realojamo": "realojar",
    "realojamos": "realojar",
    "realojando": "realojar",
    "realojara": "realojar",
    "realojaram": "realojar",
    "realojaras": "realojar",
    "realojarde": "realojar",
    "realojardes": "realojar",
    "realojare": "realojar",
    "realojarei": "realojar",
    "realojareis": "realojar",
    "realojarem": "realojar",
    "realojaremos": "realojar",
    "realojares": "realojar",
    "realojaria": "realojar",
    "realojariam": "realojar",
    "realojarias": "realojar",
    "realojarmo": "realojar",
    "realojarmos": "realojar",
    "realojará": "realojar",
    "realojarás": "realojar",
    "realojarão": "realojar",
    "realojaríamos": "realojar",
    "realojaríeis": "realojar",
    "realojas": "realojar",
    "realojasse": "realojar",
    "realojassem": "realojar",
    "realojasses": "realojar",
    "realojaste": "realojar",
    "realojastes": "realojar",
    "realojava": "realojar",
    "realojavam": "realojar",
    "realojavas": "realojar",
    "realoje": "realojar",
    "realojei": "realojar",
    "realojeis": "realojar",
    "realojem": "realojar",
    "realojemo": "realojar",
    "realojemos": "realojar",
    "realojes": "realojar",
    "realojo": "realojar",
    "realojou": "realojar",
    "realojá": "realojar",
    "realojámo": "realojar",
    "realojámos": "realojar",
    "realojáramo": "realojar",
    "realojáramos": "realojar",
    "realojárei": "realojar",
    "realojáreis": "realojar",
    "realojásseis": "realojar",
    "realojássemos": "realojar",
    "realojávamo": "realojar",
    "realojávamos": "realojar",
    "realojávei": "realojar",
    "realojáveis": "realojar",
    "realça": "realçar",
    "realçada": "realçar",
    "realçadas": "realçar",
    "realçado": "realçar",
    "realçados": "realçar",
    "realçai": "realçar",
    "realçais": "realçar",
    "realçam": "realçar",
    "realçamo": "realçar",
    "realçamos": "realçar",
    "realçando": "realçar",
    "realçara": "realçar",
    "realçaram": "realçar",
    "realçaras": "realçar",
    "realçarde": "realçar",
    "realçardes": "realçar",
    "realçare": "realçar",
    "realçarei": "realçar",
    "realçareis": "realçar",
    "realçarem": "realçar",
    "realçaremos": "realçar",
    "realçares": "realçar",
    "realçaria": "realçar",
    "realçariam": "realçar",
    "realçarias": "realçar",
    "realçarmo": "realçar",
    "realçarmos": "realçar",
    "realçará": "realçar",
    "realçarás": "realçar",
    "realçarão": "realçar",
    "realçaríamos": "realçar",
    "realçaríeis": "realçar",
    "realças": "realçar",
    "realçasse": "realçar",
    "realçassem": "realçar",
    "realçasses": "realçar",
    "realçaste": "realçar",
    "realçastes": "realçar",
    "realçava": "realçar",
    "realçavam": "realçar",
    "realçavas": "realçar",
    "realço": "realçar",
    "realços": "realço",
    "realçou": "realçar",
    "realçá": "realçar",
    "realçámo": "realçar",
    "realçámos": "realçar",
    "realçáramo": "realçar",
    "realçáramos": "realçar",
    "realçárei": "realçar",
    "realçáreis": "realçar",
    "realçásseis": "realçar",
    "realçássemos": "realçar",
    "realçávamo": "realçar",
    "realçávamos": "realçar",
    "realçávei": "realçar",
    "realçáveis": "realçável",
    "realística": "realístico",
    "realísticas": "realístico",
    "realísticos": "realístico",
    "reamanhece": "reamanhecer",
    "reamanhecei": "reamanhecer",
    "reamanheceis": "reamanhecer",
    "reamanhecem": "reamanhecer",
    "reamanhecemo": "reamanhecer",
    "reamanhecemos": "reamanhecer",
    "reamanhecendo": "reamanhecer",
    "reamanhecera": "reamanhecer",
    "reamanheceram": "reamanhecer",
    "reamanheceras": "reamanhecer",
    "reamanhecerdes": "reamanhecer",
    "reamanhecerei": "reamanhecer",
    "reamanhecereis": "reamanhecer",
    "reamanhecerem": "reamanhecer",
    "reamanheceremos": "reamanhecer",
    "reamanheceres": "reamanhecer",
    "reamanheceria": "reamanhecer",
    "reamanheceriam": "reamanhecer",
    "reamanhecerias": "reamanhecer",
    "reamanhecermo": "reamanhecer",
    "reamanhecermos": "reamanhecer",
    "reamanhecerá": "reamanhecer",
    "reamanhecerás": "reamanhecer",
    "reamanhecerão": "reamanhecer",
    "reamanheceríamos": "reamanhecer",
    "reamanheceríeis": "reamanhecer",
    "reamanheces": "reamanhecer",
    "reamanhecesse": "reamanhecer",
    "reamanhecessem": "reamanhecer",
    "reamanhecesses": "reamanhecer",
    "reamanheceste": "reamanhecer",
    "reamanhecestes": "reamanhecer",
    "reamanheceu": "reamanhecer",
    "reamanheci": "reamanhecer",
    "reamanhecia": "reamanhecer",
    "reamanheciam": "reamanhecer",
    "reamanhecias": "reamanhecer",
    "reamanhecida": "reamanhecer",
    "reamanhecidas": "reamanhecer",
    "reamanhecido": "reamanhecer",
    "reamanhecidos": "reamanhecer",
    "reamanhecêramo": "reamanhecer",
    "reamanhecêramos": "reamanhecer",
    "reamanhecêreis": "reamanhecer",
    "reamanhecêsseis": "reamanhecer",
    "reamanhecêssemos": "reamanhecer",
    "reamanhecíamo": "reamanhecer",
    "reamanhecíamos": "reamanhecer",
    "reamanhecíeis": "reamanhecer",
    "reamanheça": "reamanhecer",
    "reamanheçais": "reamanhecer",
    "reamanheçam": "reamanhecer",
    "reamanheçamo": "reamanhecer",
    "reamanheçamos": "reamanhecer",
    "reamanheças": "reamanhecer",
    "reamanheço": "reamanhecer",
    "reanalisa": "reanalisar",
    "reanalisada": "reanalisar",
    "reanalisadas": "reanalisar",
    "reanalisado": "reanalisar",
    "reanalisados": "reanalisar",
    "reanalisai": "reanalisar",
    "reanalisais": "reanalisar",
    "reanalisam": "reanalisar",
    "reanalisamo": "reanalisar",
    "reanalisamos": "reanalisar",
    "reanalisando": "reanalisar",
    "reanalisara": "reanalisar",
    "reanalisaram": "reanalisar",
    "reanalisaras": "reanalisar",
    "reanalisarde": "reanalisar",
    "reanalisardes": "reanalisar",
    "reanalisare": "reanalisar",
    "reanalisarei": "reanalisar",
    "reanalisareis": "reanalisar",
    "reanalisarem": "reanalisar",
    "reanalisaremos": "reanalisar",
    "reanalisares": "reanalisar",
    "reanalisaria": "reanalisar",
    "reanalisariam": "reanalisar",
    "reanalisarias": "reanalisar",
    "reanalisarmo": "reanalisar",
    "reanalisarmos": "reanalisar",
    "reanalisará": "reanalisar",
    "reanalisarás": "reanalisar",
    "reanalisarão": "reanalisar",
    "reanalisaríamos": "reanalisar",
    "reanalisaríeis": "reanalisar",
    "reanalisas": "reanalisar",
    "reanalisasse": "reanalisar",
    "reanalisassem": "reanalisar",
    "reanalisasses": "reanalisar",
    "reanalisaste": "reanalisar",
    "reanalisastes": "reanalisar",
    "reanalisava": "reanalisar",
    "reanalisavam": "reanalisar",
    "reanalisavas": "reanalisar",
    "reanalise": "reanalisar",
    "reanalisei": "reanalisar",
    "reanaliseis": "reanalisar",
    "reanalisem": "reanalisar",
    "reanalisemo": "reanalisar",
    "reanalisemos": "reanalisar",
    "reanalises": "reanalisar",
    "reanaliso": "reanalisar",
    "reanalisou": "reanalisar",
    "reanalisá": "reanalisar",
    "reanalisámo": "reanalisar",
    "reanalisámos": "reanalisar",
    "reanalisáramo": "reanalisar",
    "reanalisáramos": "reanalisar",
    "reanalisárei": "reanalisar",
    "reanalisáreis": "reanalisar",
    "reanalisásseis": "reanalisar",
    "reanalisássemos": "reanalisar",
    "reanalisávamo": "reanalisar",
    "reanalisávamos": "reanalisar",
    "reanalisávei": "reanalisar",
    "reanalisáveis": "reanalisar",
    "reanda": "reandar",
    "reandada": "reandar",
    "reandadas": "reandar",
    "reandado": "reandar",
    "reandados": "reandar",
    "reandai": "reandar",
    "reandais": "reandar",
    "reandam": "reandar",
    "reandamo": "reandar",
    "reandamos": "reandar",
    "reandando": "reandar",
    "reandara": "reandar",
    "reandaram": "reandar",
    "reandaras": "reandar",
    "reandarde": "reandar",
    "reandardes": "reandar",
    "reandare": "reandar",
    "reandarei": "reandar",
    "reandareis": "reandar",
    "reandarem": "reandar",
    "reandaremos": "reandar",
    "reandares": "reandar",
    "reandaria": "reandar",
    "reandariam": "reandar",
    "reandarias": "reandar",
    "reandarmo": "reandar",
    "reandarmos": "reandar",
    "reandará": "reandar",
    "reandarás": "reandar",
    "reandarão": "reandar",
    "reandaríamos": "reandar",
    "reandaríeis": "reandar",
    "reandas": "reandar",
    "reandasse": "reandar",
    "reandassem": "reandar",
    "reandasses": "reandar",
    "reandaste": "reandar",
    "reandastes": "reandar",
    "reandava": "reandar",
    "reandavam": "reandar",
    "reandavas": "reandar",
    "reande": "reandar",
    "reandei": "reandar",
    "reandeis": "reandar",
    "reandem": "reandar",
    "reandemo": "reandar",
    "reandemos": "reandar",
    "reandes": "reandar",
    "reando": "reandar",
    "reandou": "reandar",
    "reandá": "reandar",
    "reandámo": "reandar",
    "reandámos": "reandar",
    "reandáramo": "reandar",
    "reandáramos": "reandar",
    "reandárei": "reandar",
    "reandáreis": "reandar",
    "reandásseis": "reandar",
    "reandássemos": "reandar",
    "reandávamo": "reandar",
    "reandávamos": "reandar",
    "reandávei": "reandar",
    "reandáveis": "reandar",
    "reanima": "reanimar",
    "reanimada": "reanimar",
    "reanimadas": "reanimar",
    "reanimado": "reanimar",
    "reanimadora": "reanimador",
    "reanimadoras": "reanimador",
    "reanimadores": "reanimador",
    "reanimados": "reanimar",
    "reanimai": "reanimar",
    "reanimais": "reanimar",
    "reanimam": "reanimar",
    "reanimamo": "reanimar",
    "reanimamos": "reanimar",
    "reanimando": "reanimar",
    "reanimara": "reanimar",
    "reanimaram": "reanimar",
    "reanimaras": "reanimar",
    "reanimarde": "reanimar",
    "reanimardes": "reanimar",
    "reanimare": "reanimar",
    "reanimarei": "reanimar",
    "reanimareis": "reanimar",
    "reanimarem": "reanimar",
    "reanimaremos": "reanimar",
    "reanimares": "reanimar",
    "reanimaria": "reanimar",
    "reanimariam": "reanimar",
    "reanimarias": "reanimar",
    "reanimarmo": "reanimar",
    "reanimarmos": "reanimar",
    "reanimará": "reanimar",
    "reanimarás": "reanimar",
    "reanimarão": "reanimar",
    "reanimaríamos": "reanimar",
    "reanimaríeis": "reanimar",
    "reanimas": "reanimar",
    "reanimasse": "reanimar",
    "reanimassem": "reanimar",
    "reanimasses": "reanimar",
    "reanimaste": "reanimar",
    "reanimastes": "reanimar",
    "reanimava": "reanimar",
    "reanimavam": "reanimar",
    "reanimavas": "reanimar",
    "reanimações": "reanimação",
    "reanime": "reanimar",
    "reanimei": "reanimar",
    "reanimeis": "reanimar",
    "reanimem": "reanimar",
    "reanimemo": "reanimar",
    "reanimemos": "reanimar",
    "reanimes": "reanimar",
    "reanimo": "reanimar",
    "reanimou": "reanimar",
    "reanimá": "reanimar",
    "reanimámo": "reanimar",
    "reanimámos": "reanimar",
    "reanimáramo": "reanimar",
    "reanimáramos": "reanimar",
    "reanimárei": "reanimar",
    "reanimáreis": "reanimar",
    "reanimásseis": "reanimar",
    "reanimássemos": "reanimar",
    "reanimávamo": "reanimar",
    "reanimávamos": "reanimar",
    "reanimávei": "reanimar",
    "reanimáveis": "reanimável",
    "reanálises": "reanálise",
    "reaparece": "reaparecer",
    "reaparecei": "reaparecer",
    "reapareceis": "reaparecer",
    "reaparecem": "reaparecer",
    "reaparecemo": "reaparecer",
    "reaparecemos": "reaparecer",
    "reaparecendo": "reaparecer",
    "reaparecera": "reaparecer",
    "reapareceram": "reaparecer",
    "reapareceras": "reaparecer",
    "reaparecerdes": "reaparecer",
    "reaparecerei": "reaparecer",
    "reaparecereis": "reaparecer",
    "reaparecerem": "reaparecer",
    "reapareceremos": "reaparecer",
    "reapareceres": "reaparecer",
    "reapareceria": "reaparecer",
    "reapareceriam": "reaparecer",
    "reaparecerias": "reaparecer",
    "reaparecermo": "reaparecer",
    "reaparecermos": "reaparecer",
    "reaparecerá": "reaparecer",
    "reaparecerás": "reaparecer",
    "reaparecerão": "reaparecer",
    "reapareceríamos": "reaparecer",
    "reapareceríeis": "reaparecer",
    "reapareces": "reaparecer",
    "reaparecesse": "reaparecer",
    "reaparecessem": "reaparecer",
    "reaparecesses": "reaparecer",
    "reapareceste": "reaparecer",
    "reaparecestes": "reaparecer",
    "reapareceu": "reaparecer",
    "reapareci": "reaparecer",
    "reaparecia": "reaparecer",
    "reapareciam": "reaparecer",
    "reaparecias": "reaparecer",
    "reaparecida": "reaparecido",
    "reaparecidas": "reaparecido",
    "reaparecido": "reaparecer",
    "reaparecidos": "reaparecido",
    "reaparecimentos": "reaparecimento",
    "reaparecêramo": "reaparecer",
    "reaparecêramos": "reaparecer",
    "reaparecêreis": "reaparecer",
    "reaparecêsseis": "reaparecer",
    "reaparecêssemos": "reaparecer",
    "reaparecíamo": "reaparecer",
    "reaparecíamos": "reaparecer",
    "reaparecíeis": "reaparecer",
    "reapareça": "reaparecer",
    "reapareçais": "reaparecer",
    "reapareçam": "reaparecer",
    "reapareçamo": "reaparecer",
    "reapareçamos": "reaparecer",
    "reapareças": "reaparecer",
    "reapareço": "reaparecer",
    "reaparições": "reaparição",
    "reapetrechamentos": "reapetrechamento",
    "reapodera": "reapoderar",
    "reapoderada": "reapoderar",
    "reapoderadas": "reapoderar",
    "reapoderado": "reapoderar",
    "reapoderados": "reapoderar",
    "reapoderai": "reapoderar",
    "reapoderais": "reapoderar",
    "reapoderam": "reapoderar",
    "reapoderamo": "reapoderar",
    "reapoderamos": "reapoderar",
    "reapoderando": "reapoderar",
    "reapoderara": "reapoderar",
    "reapoderaram": "reapoderar",
    "reapoderaras": "reapoderar",
    "reapoderarde": "reapoderar",
    "reapoderardes": "reapoderar",
    "reapoderare": "reapoderar",
    "reapoderarei": "reapoderar",
    "reapoderareis": "reapoderar",
    "reapoderarem": "reapoderar",
    "reapoderaremos": "reapoderar",
    "reapoderares": "reapoderar",
    "reapoderaria": "reapoderar",
    "reapoderariam": "reapoderar",
    "reapoderarias": "reapoderar",
    "reapoderarmo": "reapoderar",
    "reapoderarmos": "reapoderar",
    "reapoderará": "reapoderar",
    "reapoderarás": "reapoderar",
    "reapoderarão": "reapoderar",
    "reapoderaríamos": "reapoderar",
    "reapoderaríeis": "reapoderar",
    "reapoderas": "reapoderar",
    "reapoderasse": "reapoderar",
    "reapoderassem": "reapoderar",
    "reapoderasses": "reapoderar",
    "reapoderaste": "reapoderar",
    "reapoderastes": "reapoderar",
    "reapoderava": "reapoderar",
    "reapoderavam": "reapoderar",
    "reapoderavas": "reapoderar",
    "reapodere": "reapoderar",
    "reapoderei": "reapoderar",
    "reapodereis": "reapoderar",
    "reapoderem": "reapoderar",
    "reapoderemo": "reapoderar",
    "reapoderemos": "reapoderar",
    "reapoderes": "reapoderar",
    "reapodero": "reapoderar",
    "reapoderou": "reapoderar",
    "reapoderá": "reapoderar",
    "reapoderámo": "reapoderar",
    "reapoderámos": "reapoderar",
    "reapoderáramo": "reapoderar",
    "reapoderáramos": "reapoderar",
    "reapoderárei": "reapoderar",
    "reapoderáreis": "reapoderar",
    "reapoderásseis": "reapoderar",
    "reapoderássemos": "reapoderar",
    "reapoderávamo": "reapoderar",
    "reapoderávamos": "reapoderar",
    "reapoderávei": "reapoderar",
    "reapoderáveis": "reapoderar",
    "reapossa": "reapossar",
    "reapossada": "reapossar",
    "reapossadas": "reapossar",
    "reapossado": "reapossar",
    "reapossados": "reapossar",
    "reapossai": "reapossar",
    "reapossais": "reapossar",
    "reapossam": "reapossar",
    "reapossamo": "reapossar",
    "reapossamos": "reapossar",
    "reapossando": "reapossar",
    "reapossara": "reapossar",
    "reapossaram": "reapossar",
    "reapossaras": "reapossar",
    "reapossarde": "reapossar",
    "reapossardes": "reapossar",
    "reapossare": "reapossar",
    "reapossarei": "reapossar",
    "reapossareis": "reapossar",
    "reapossarem": "reapossar",
    "reapossaremos": "reapossar",
    "reapossares": "reapossar",
    "reapossaria": "reapossar",
    "reapossariam": "reapossar",
    "reapossarias": "reapossar",
    "reapossarmo": "reapossar",
    "reapossarmos": "reapossar",
    "reapossará": "reapossar",
    "reapossarás": "reapossar",
    "reapossarão": "reapossar",
    "reapossaríamos": "reapossar",
    "reapossaríeis": "reapossar",
    "reapossas": "reapossar",
    "reapossasse": "reapossar",
    "reapossassem": "reapossar",
    "reapossasses": "reapossar",
    "reapossaste": "reapossar",
    "reapossastes": "reapossar",
    "reapossava": "reapossar",
    "reapossavam": "reapossar",
    "reapossavas": "reapossar",
    "reaposse": "reapossar",
    "reapossei": "reapossar",
    "reaposseis": "reapossar",
    "reapossem": "reapossar",
    "reapossemo": "reapossar",
    "reapossemos": "reapossar",
    "reaposses": "reapossar",
    "reaposso": "reapossar",
    "reapossou": "reapossar",
    "reapossá": "reapossar",
    "reapossámo": "reapossar",
    "reapossámos": "reapossar",
    "reapossáramo": "reapossar",
    "reapossáramos": "reapossar",
    "reapossárei": "reapossar",
    "reapossáreis": "reapossar",
    "reapossásseis": "reapossar",
    "reapossássemos": "reapossar",
    "reapossávamo": "reapossar",
    "reapossávamos": "reapossar",
    "reapossávei": "reapossar",
    "reapossáveis": "reapossar",
    "reaprecia": "reapreciar",
    "reapreciada": "reapreciar",
    "reapreciadas": "reapreciar",
    "reapreciado": "reapreciar",
    "reapreciados": "reapreciar",
    "reapreciai": "reapreciar",
    "reapreciais": "reapreciar",
    "reapreciam": "reapreciar",
    "reapreciamo": "reapreciar",
    "reapreciamos": "reapreciar",
    "reapreciando": "reapreciar",
    "reapreciara": "reapreciar",
    "reapreciaram": "reapreciar",
    "reapreciaras": "reapreciar",
    "reapreciarde": "reapreciar",
    "reapreciardes": "reapreciar",
    "reapreciare": "reapreciar",
    "reapreciarei": "reapreciar",
    "reapreciareis": "reapreciar",
    "reapreciarem": "reapreciar",
    "reapreciaremos": "reapreciar",
    "reapreciares": "reapreciar",
    "reapreciaria": "reapreciar",
    "reapreciariam": "reapreciar",
    "reapreciarias": "reapreciar",
    "reapreciarmo": "reapreciar",
    "reapreciarmos": "reapreciar",
    "reapreciará": "reapreciar",
    "reapreciarás": "reapreciar",
    "reapreciarão": "reapreciar",
    "reapreciaríamos": "reapreciar",
    "reapreciaríeis": "reapreciar",
    "reaprecias": "reapreciar",
    "reapreciasse": "reapreciar",
    "reapreciassem": "reapreciar",
    "reapreciasses": "reapreciar",
    "reapreciaste": "reapreciar",
    "reapreciastes": "reapreciar",
    "reapreciava": "reapreciar",
    "reapreciavam": "reapreciar",
    "reapreciavas": "reapreciar",
    "reapreciações": "reapreciação",
    "reaprecie": "reapreciar",
    "reapreciei": "reapreciar",
    "reaprecieis": "reapreciar",
    "reapreciem": "reapreciar",
    "reapreciemo": "reapreciar",
    "reapreciemos": "reapreciar",
    "reaprecies": "reapreciar",
    "reaprecio": "reapreciar",
    "reapreciou": "reapreciar",
    "reapreciá": "reapreciar",
    "reapreciámo": "reapreciar",
    "reapreciámos": "reapreciar",
    "reapreciáramo": "reapreciar",
    "reapreciáramos": "reapreciar",
    "reapreciárei": "reapreciar",
    "reapreciáreis": "reapreciar",
    "reapreciásseis": "reapreciar",
    "reapreciássemos": "reapreciar",
    "reapreciávamo": "reapreciar",
    "reapreciávamos": "reapreciar",
    "reapreciávei": "reapreciar",
    "reapreciáveis": "reapreciar",
    "reaprenda": "reaprender",
    "reaprendais": "reaprender",
    "reaprendam": "reaprender",
    "reaprendamo": "reaprender",
    "reaprendamos": "reaprender",
    "reaprendas": "reaprender",
    "reaprende": "reaprender",
    "reaprendei": "reaprender",
    "reaprendeis": "reaprender",
    "reaprendem": "reaprender",
    "reaprendemo": "reaprender",
    "reaprendemos": "reaprender",
    "reaprendendo": "reaprender",
    "reaprendera": "reaprender",
    "reaprenderam": "reaprender",
    "reaprenderas": "reaprender",
    "reaprenderde": "reaprender",
    "reaprenderdes": "reaprender",
    "reaprendere": "reaprender",
    "reaprenderei": "reaprender",
    "reaprendereis": "reaprender",
    "reaprenderem": "reaprender",
    "reaprenderemos": "reaprender",
    "reaprenderes": "reaprender",
    "reaprenderia": "reaprender",
    "reaprenderiam": "reaprender",
    "reaprenderias": "reaprender",
    "reaprendermo": "reaprender",
    "reaprendermos": "reaprender",
    "reaprenderá": "reaprender",
    "reaprenderás": "reaprender",
    "reaprenderão": "reaprender",
    "reaprenderíamos": "reaprender",
    "reaprenderíeis": "reaprender",
    "reaprendes": "reaprender",
    "reaprendesse": "reaprender",
    "reaprendessem": "reaprender",
    "reaprendesses": "reaprender",
    "reaprendeste": "reaprender",
    "reaprendestes": "reaprender",
    "reaprendeu": "reaprender",
    "reaprendi": "reaprender",
    "reaprendia": "reaprender",
    "reaprendiam": "reaprender",
    "reaprendias": "reaprender",
    "reaprendida": "reaprender",
    "reaprendidas": "reaprender",
    "reaprendido": "reaprender",
    "reaprendidos": "reaprender",
    "reaprendizados": "reaprendizado",
    "reaprendizagens": "reaprendizagem",
    "reaprendo": "reaprender",
    "reaprendê": "reaprender",
    "reaprendêramo": "reaprender",
    "reaprendêramos": "reaprender",
    "reaprendêrei": "reaprender",
    "reaprendêreis": "reaprender",
    "reaprendêsseis": "reaprender",
    "reaprendêssemos": "reaprender",
    "reaprendíamo": "reaprender",
    "reaprendíamos": "reaprender",
    "reaprendíei": "reaprender",
    "reaprendíeis": "reaprender",
    "reapresentações": "reapresentação",
    "reapropriações": "reapropriação",
    "reaproveita": "reaproveitar",
    "reaproveitada": "reaproveitar",
    "reaproveitadas": "reaproveitar",
    "reaproveitado": "reaproveitar",
    "reaproveitados": "reaproveitar",
    "reaproveitai": "reaproveitar",
    "reaproveitais": "reaproveitar",
    "reaproveitam": "reaproveitar",
    "reaproveitamentos": "reaproveitamento",
    "reaproveitamo": "reaproveitar",
    "reaproveitamos": "reaproveitar",
    "reaproveitando": "reaproveitar",
    "reaproveitara": "reaproveitar",
    "reaproveitaram": "reaproveitar",
    "reaproveitaras": "reaproveitar",
    "reaproveitarde": "reaproveitar",
    "reaproveitardes": "reaproveitar",
    "reaproveitare": "reaproveitar",
    "reaproveitarei": "reaproveitar",
    "reaproveitareis": "reaproveitar",
    "reaproveitarem": "reaproveitar",
    "reaproveitaremos": "reaproveitar",
    "reaproveitares": "reaproveitar",
    "reaproveitaria": "reaproveitar",
    "reaproveitariam": "reaproveitar",
    "reaproveitarias": "reaproveitar",
    "reaproveitarmo": "reaproveitar",
    "reaproveitarmos": "reaproveitar",
    "reaproveitará": "reaproveitar",
    "reaproveitarás": "reaproveitar",
    "reaproveitarão": "reaproveitar",
    "reaproveitaríamos": "reaproveitar",
    "reaproveitaríeis": "reaproveitar",
    "reaproveitas": "reaproveitar",
    "reaproveitasse": "reaproveitar",
    "reaproveitassem": "reaproveitar",
    "reaproveitasses": "reaproveitar",
    "reaproveitaste": "reaproveitar",
    "reaproveitastes": "reaproveitar",
    "reaproveitava": "reaproveitar",
    "reaproveitavam": "reaproveitar",
    "reaproveitavas": "reaproveitar",
    "reaproveite": "reaproveitar",
    "reaproveitei": "reaproveitar",
    "reaproveiteis": "reaproveitar",
    "reaproveitem": "reaproveitar",
    "reaproveitemo": "reaproveitar",
    "reaproveitemos": "reaproveitar",
    "reaproveites": "reaproveitar",
    "reaproveito": "reaproveitar",
    "reaproveitou": "reaproveitar",
    "reaproveitá": "reaproveitar",
    "reaproveitámo": "reaproveitar",
    "reaproveitámos": "reaproveitar",
    "reaproveitáramo": "reaproveitar",
    "reaproveitáramos": "reaproveitar",
    "reaproveitárei": "reaproveitar",
    "reaproveitáreis": "reaproveitar",
    "reaproveitásseis": "reaproveitar",
    "reaproveitássemos": "reaproveitar",
    "reaproveitávamo": "reaproveitar",
    "reaproveitávamos": "reaproveitar",
    "reaproveitávei": "reaproveitar",
    "reaproveitáveis": "reaproveitável",
    "reaproxima": "reaproximar",
    "reaproximada": "reaproximar",
    "reaproximadas": "reaproximar",
    "reaproximado": "reaproximar",
    "reaproximados": "reaproximar",
    "reaproximai": "reaproximar",
    "reaproximais": "reaproximar",
    "reaproximam": "reaproximar",
    "reaproximamo": "reaproximar",
    "reaproximamos": "reaproximar",
    "reaproximando": "reaproximar",
    "reaproximara": "reaproximar",
    "reaproximaram": "reaproximar",
    "reaproximaras": "reaproximar",
    "reaproximarde": "reaproximar",
    "reaproximardes": "reaproximar",
    "reaproximare": "reaproximar",
    "reaproximarei": "reaproximar",
    "reaproximareis": "reaproximar",
    "reaproximarem": "reaproximar",
    "reaproximaremos": "reaproximar",
    "reaproximares": "reaproximar",
    "reaproximaria": "reaproximar",
    "reaproximariam": "reaproximar",
    "reaproximarias": "reaproximar",
    "reaproximarmo": "reaproximar",
    "reaproximarmos": "reaproximar",
    "reaproximará": "reaproximar",
    "reaproximarás": "reaproximar",
    "reaproximarão": "reaproximar",
    "reaproximaríamos": "reaproximar",
    "reaproximaríeis": "reaproximar",
    "reaproximas": "reaproximar",
    "reaproximasse": "reaproximar",
    "reaproximassem": "reaproximar",
    "reaproximasses": "reaproximar",
    "reaproximaste": "reaproximar",
    "reaproximastes": "reaproximar",
    "reaproximava": "reaproximar",
    "reaproximavam": "reaproximar",
    "reaproximavas": "reaproximar",
    "reaproximações": "reaproximação",
    "reaproxime": "reaproximar",
    "reaproximei": "reaproximar",
    "reaproximeis": "reaproximar",
    "reaproximem": "reaproximar",
    "reaproximemo": "reaproximar",
    "reaproximemos": "reaproximar",
    "reaproximes": "reaproximar",
    "reaproximo": "reaproximar",
    "reaproximou": "reaproximar",
    "reaproximá": "reaproximar",
    "reaproximámo": "reaproximar",
    "reaproximámos": "reaproximar",
    "reaproximáramo": "reaproximar",
    "reaproximáramos": "reaproximar",
    "reaproximárei": "reaproximar",
    "reaproximáreis": "reaproximar",
    "reaproximásseis": "reaproximar",
    "reaproximássemos": "reaproximar",
    "reaproximávamo": "reaproximar",
    "reaproximávamos": "reaproximar",
    "reaproximávei": "reaproximar",
    "reaproximáveis": "reaproximar",
    "reaquisições": "reaquisição",
    "rearborizações": "rearborização",
    "rearma": "rearmar",
    "rearmada": "rearmar",
    "rearmadas": "rearmar",
    "rearmado": "rearmar",
    "rearmados": "rearmar",
    "rearmai": "rearmar",
    "rearmais": "rearmar",
    "rearmam": "rearmar",
    "rearmamentos": "rearmamento",
    "rearmamo": "rearmar",
    "rearmamos": "rearmar",
    "rearmando": "rearmar",
    "rearmara": "rearmar",
    "rearmaram": "rearmar",
    "rearmaras": "rearmar",
    "rearmarde": "rearmar",
    "rearmardes": "rearmar",
    "rearmare": "rearmar",
    "rearmarei": "rearmar",
    "rearmareis": "rearmar",
    "rearmarem": "rearmar",
    "rearmaremos": "rearmar",
    "rearmares": "rearmar",
    "rearmaria": "rearmar",
    "rearmariam": "rearmar",
    "rearmarias": "rearmar",
    "rearmarmo": "rearmar",
    "rearmarmos": "rearmar",
    "rearmará": "rearmar",
    "rearmarás": "rearmar",
    "rearmarão": "rearmar",
    "rearmaríamos": "rearmar",
    "rearmaríeis": "rearmar",
    "rearmas": "rearmar",
    "rearmasse": "rearmar",
    "rearmassem": "rearmar",
    "rearmasses": "rearmar",
    "rearmaste": "rearmar",
    "rearmastes": "rearmar",
    "rearmava": "rearmar",
    "rearmavam": "rearmar",
    "rearmavas": "rearmar",
    "rearme": "rearmar",
    "rearmei": "rearmar",
    "rearmeis": "rearmar",
    "rearmem": "rearmar",
    "rearmemo": "rearmar",
    "rearmemos": "rearmar",
    "rearmes": "rearmar",
    "rearmo": "rearmar",
    "rearmou": "rearmar",
    "rearmá": "rearmar",
    "rearmámo": "rearmar",
    "rearmámos": "rearmar",
    "rearmáramo": "rearmar",
    "rearmáramos": "rearmar",
    "rearmárei": "rearmar",
    "rearmáreis": "rearmar",
    "rearmásseis": "rearmar",
    "rearmássemos": "rearmar",
    "rearmávamo": "rearmar",
    "rearmávamos": "rearmar",
    "rearmávei": "rearmar",
    "rearmáveis": "rearmar",
    "rearranjos": "rearranjo",
    "rearranques": "rearranque",
    "rearruma": "rearrumar",
    "rearrumada": "rearrumar",
    "rearrumadas": "rearrumar",
    "rearrumado": "rearrumar",
    "rearrumados": "rearrumar",
    "rearrumai": "rearrumar",
    "rearrumais": "rearrumar",
    "rearrumam": "rearrumar",
    "rearrumamo": "rearrumar",
    "rearrumamos": "rearrumar",
    "rearrumando": "rearrumar",
    "rearrumara": "rearrumar",
    "rearrumaram": "rearrumar",
    "rearrumaras": "rearrumar",
    "rearrumarde": "rearrumar",
    "rearrumardes": "rearrumar",
    "rearrumare": "rearrumar",
    "rearrumarei": "rearrumar",
    "rearrumareis": "rearrumar",
    "rearrumarem": "rearrumar",
    "rearrumaremos": "rearrumar",
    "rearrumares": "rearrumar",
    "rearrumaria": "rearrumar",
    "rearrumariam": "rearrumar",
    "rearrumarias": "rearrumar",
    "rearrumarmo": "rearrumar",
    "rearrumarmos": "rearrumar",
    "rearrumará": "rearrumar",
    "rearrumarás": "rearrumar",
    "rearrumarão": "rearrumar",
    "rearrumaríamos": "rearrumar",
    "rearrumaríeis": "rearrumar",
    "rearrumas": "rearrumar",
    "rearrumasse": "rearrumar",
    "rearrumassem": "rearrumar",
    "rearrumasses": "rearrumar",
    "rearrumaste": "rearrumar",
    "rearrumastes": "rearrumar",
    "rearrumava": "rearrumar",
    "rearrumavam": "rearrumar",
    "rearrumavas": "rearrumar",
    "rearrumações": "rearrumação",
    "rearrume": "rearrumar",
    "rearrumei": "rearrumar",
    "rearrumeis": "rearrumar",
    "rearrumem": "rearrumar",
    "rearrumemo": "rearrumar",
    "rearrumemos": "rearrumar",
    "rearrumes": "rearrumar",
    "rearrumo": "rearrumar",
    "rearrumou": "rearrumar",
    "rearrumá": "rearrumar",
    "rearrumámo": "rearrumar",
    "rearrumámos": "rearrumar",
    "rearrumáramo": "rearrumar",
    "rearrumáramos": "rearrumar",
    "rearrumárei": "rearrumar",
    "rearrumáreis": "rearrumar",
    "rearrumásseis": "rearrumar",
    "rearrumássemos": "rearrumar",
    "rearrumávamo": "rearrumar",
    "rearrumávamos": "rearrumar",
    "rearrumávei": "rearrumar",
    "rearrumáveis": "rearrumar",
    "reascenda": "reascender",
    "reascendais": "reascender",
    "reascendam": "reascender",
    "reascendamo": "reascender",
    "reascendamos": "reascender",
    "reascendas": "reascender",
    "reascende": "reascender",
    "reascendei": "reascender",
    "reascendeis": "reascender",
    "reascendem": "reascender",
    "reascendemo": "reascender",
    "reascendemos": "reascender",
    "reascendendo": "reascender",
    "reascendera": "reascender",
    "reascenderam": "reascender",
    "reascenderas": "reascender",
    "reascenderde": "reascender",
    "reascenderdes": "reascender",
    "reascendere": "reascender",
    "reascenderei": "reascender",
    "reascendereis": "reascender",
    "reascenderem": "reascender",
    "reascenderemos": "reascender",
    "reascenderes": "reascender",
    "reascenderia": "reascender",
    "reascenderiam": "reascender",
    "reascenderias": "reascender",
    "reascendermo": "reascender",
    "reascendermos": "reascender",
    "reascenderá": "reascender",
    "reascenderás": "reascender",
    "reascenderão": "reascender",
    "reascenderíamos": "reascender",
    "reascenderíeis": "reascender",
    "reascendes": "reascender",
    "reascendesse": "reascender",
    "reascendessem": "reascender",
    "reascendesses": "reascender",
    "reascendeste": "reascender",
    "reascendestes": "reascender",
    "reascendeu": "reascender",
    "reascendi": "reascender",
    "reascendia": "reascender",
    "reascendiam": "reascender",
    "reascendias": "reascender",
    "reascendida": "reascender",
    "reascendidas": "reascender",
    "reascendido": "reascender",
    "reascendidos": "reascender",
    "reascendo": "reascender",
    "reascendê": "reascender",
    "reascendêramo": "reascender",
    "reascendêramos": "reascender",
    "reascendêrei": "reascender",
    "reascendêreis": "reascender",
    "reascendêsseis": "reascender",
    "reascendêssemos": "reascender",
    "reascendíamo": "reascender",
    "reascendíamos": "reascender",
    "reascendíei": "reascender",
    "reascendíeis": "reascender",
    "reassegura": "reassegurar",
    "reassegurada": "reassegurar",
    "reasseguradas": "reassegurar",
    "reassegurado": "reassegurar",
    "reassegurados": "reassegurar",
    "reassegurai": "reassegurar",
    "reassegurais": "reassegurar",
    "reasseguram": "reassegurar",
    "reasseguramo": "reassegurar",
    "reasseguramos": "reassegurar",
    "reassegurando": "reassegurar",
    "reassegurara": "reassegurar",
    "reasseguraram": "reassegurar",
    "reasseguraras": "reassegurar",
    "reassegurarde": "reassegurar",
    "reassegurardes": "reassegurar",
    "reassegurare": "reassegurar",
    "reassegurarei": "reassegurar",
    "reassegurareis": "reassegurar",
    "reassegurarem": "reassegurar",
    "reasseguraremos": "reassegurar",
    "reassegurares": "reassegurar",
    "reasseguraria": "reassegurar",
    "reassegurariam": "reassegurar",
    "reassegurarias": "reassegurar",
    "reassegurarmo": "reassegurar",
    "reassegurarmos": "reassegurar",
    "reassegurará": "reassegurar",
    "reassegurarás": "reassegurar",
    "reassegurarão": "reassegurar",
    "reasseguraríamos": "reassegurar",
    "reasseguraríeis": "reassegurar",
    "reasseguras": "reassegurar",
    "reassegurasse": "reassegurar",
    "reassegurassem": "reassegurar",
    "reassegurasses": "reassegurar",
    "reasseguraste": "reassegurar",
    "reassegurastes": "reassegurar",
    "reassegurava": "reassegurar",
    "reasseguravam": "reassegurar",
    "reasseguravas": "reassegurar",
    "reassegure": "reassegurar",
    "reassegurei": "reassegurar",
    "reassegureis": "reassegurar",
    "reassegurem": "reassegurar",
    "reasseguremo": "reassegurar",
    "reasseguremos": "reassegurar",
    "reassegures": "reassegurar",
    "reasseguro": "reassegurar",
    "reassegurou": "reassegurar",
    "reassegurá": "reassegurar",
    "reassegurámo": "reassegurar",
    "reassegurámos": "reassegurar",
    "reasseguráramo": "reassegurar",
    "reasseguráramos": "reassegurar",
    "reassegurárei": "reassegurar",
    "reasseguráreis": "reassegurar",
    "reassegurásseis": "reassegurar",
    "reassegurássemos": "reassegurar",
    "reassegurávamo": "reassegurar",
    "reassegurávamos": "reassegurar",
    "reassegurávei": "reassegurar",
    "reasseguráveis": "reassegurar",
    "reassenhoreada": "reassenhorear",
    "reassenhoreadas": "reassenhorear",
    "reassenhoreado": "reassenhorear",
    "reassenhoreados": "reassenhorear",
    "reassenhoreai": "reassenhorear",
    "reassenhoreais": "reassenhorear",
    "reassenhoreamo": "reassenhorear",
    "reassenhoreamos": "reassenhorear",
    "reassenhoreando": "reassenhorear",
    "reassenhoreara": "reassenhorear",
    "reassenhorearam": "reassenhorear",
    "reassenhorearas": "reassenhorear",
    "reassenhorearde": "reassenhorear",
    "reassenhoreardes": "reassenhorear",
    "reassenhoreare": "reassenhorear",
    "reassenhorearei": "reassenhorear",
    "reassenhoreareis": "reassenhorear",
    "reassenhorearem": "reassenhorear",
    "reassenhorearemos": "reassenhorear",
    "reassenhoreares": "reassenhorear",
    "reassenhorearia": "reassenhorear",
    "reassenhoreariam": "reassenhorear",
    "reassenhorearias": "reassenhorear",
    "reassenhorearmo": "reassenhorear",
    "reassenhorearmos": "reassenhorear",
    "reassenhoreará": "reassenhorear",
    "reassenhorearás": "reassenhorear",
    "reassenhorearão": "reassenhorear",
    "reassenhorearíamos": "reassenhorear",
    "reassenhorearíeis": "reassenhorear",
    "reassenhoreasse": "reassenhorear",
    "reassenhoreassem": "reassenhorear",
    "reassenhoreasses": "reassenhorear",
    "reassenhoreaste": "reassenhorear",
    "reassenhoreastes": "reassenhorear",
    "reassenhoreava": "reassenhorear",
    "reassenhoreavam": "reassenhorear",
    "reassenhoreavas": "reassenhorear",
    "reassenhoreei": "reassenhorear",
    "reassenhoreeis": "reassenhorear",
    "reassenhoreemo": "reassenhorear",
    "reassenhoreemos": "reassenhorear",
    "reassenhoreia": "reassenhorear",
    "reassenhoreiam": "reassenhorear",
    "reassenhoreias": "reassenhorear",
    "reassenhoreie": "reassenhorear",
    "reassenhoreiem": "reassenhorear",
    "reassenhoreies": "reassenhorear",
    "reassenhoreio": "reassenhorear",
    "reassenhoreou": "reassenhorear",
    "reassenhoreá": "reassenhorear",
    "reassenhoreámo": "reassenhorear",
    "reassenhoreámos": "reassenhorear",
    "reassenhoreáramo": "reassenhorear",
    "reassenhoreáramos": "reassenhorear",
    "reassenhoreárei": "reassenhorear",
    "reassenhoreáreis": "reassenhorear",
    "reassenhoreásseis": "reassenhorear",
    "reassenhoreássemos": "reassenhorear",
    "reassenhoreávamo": "reassenhorear",
    "reassenhoreávamos": "reassenhorear",
    "reassenhoreávei": "reassenhorear",
    "reassenhoreáveis": "reassenhorear",
    "reassentamentos": "reassentamento",
    "reassuma": "reassumir",
    "reassumais": "reassumir",
    "reassumam": "reassumir",
    "reassumamo": "reassumir",
    "reassumamos": "reassumir",
    "reassumas": "reassumir",
    "reassume": "reassumir",
    "reassumem": "reassumir",
    "reassumes": "reassumir",
    "reassumi": "reassumir",
    "reassumia": "reassumir",
    "reassumiam": "reassumir",
    "reassumias": "reassumir",
    "reassumida": "reassumir",
    "reassumidas": "reassumir",
    "reassumido": "reassumir",
    "reassumidos": "reassumir",
    "reassumimo": "reassumir",
    "reassumimos": "reassumir",
    "reassumindo": "reassumir",
    "reassumira": "reassumir",
    "reassumiram": "reassumir",
    "reassumiras": "reassumir",
    "reassumirde": "reassumir",
    "reassumirdes": "reassumir",
    "reassumire": "reassumir",
    "reassumirei": "reassumir",
    "reassumireis": "reassumir",
    "reassumirem": "reassumir",
    "reassumiremos": "reassumir",
    "reassumires": "reassumir",
    "reassumiria": "reassumir",
    "reassumiriam": "reassumir",
    "reassumirias": "reassumir",
    "reassumirmo": "reassumir",
    "reassumirmos": "reassumir",
    "reassumirá": "reassumir",
    "reassumirás": "reassumir",
    "reassumirão": "reassumir",
    "reassumiríamos": "reassumir",
    "reassumiríeis": "reassumir",
    "reassumis": "reassumir",
    "reassumisse": "reassumir",
    "reassumissem": "reassumir",
    "reassumisses": "reassumir",
    "reassumiste": "reassumir",
    "reassumistes": "reassumir",
    "reassumiu": "reassumir",
    "reassumo": "reassumir",
    "reassumíamo": "reassumir",
    "reassumíamos": "reassumir",
    "reassumíei": "reassumir",
    "reassumíeis": "reassumir",
    "reassumíramo": "reassumir",
    "reassumíramos": "reassumir",
    "reassumírei": "reassumir",
    "reassumíreis": "reassumir",
    "reassumísseis": "reassumir",
    "reassumíssemos": "reassumir",
    "reassumíveis": "reassumível",
    "reassunções": "reassunção",
    "reata": "reatar",
    "reatada": "reatar",
    "reatadas": "reatar",
    "reatado": "reatar",
    "reatados": "reatar",
    "reatai": "reatar",
    "reatais": "reatar",
    "reatam": "reatar",
    "reatamentos": "reatamento",
    "reatamo": "reatar",
    "reatamos": "reatar",
    "reatando": "reatar",
    "reatara": "reatar",
    "reataram": "reatar",
    "reataras": "reatar",
    "reatarde": "reatar",
    "reatardes": "reatar",
    "reatare": "reatar",
    "reatarei": "reatar",
    "reatareis": "reatar",
    "reatarem": "reatar",
    "reataremos": "reatar",
    "reatares": "reatar",
    "reataria": "reatar",
    "reatariam": "reatar",
    "reatarias": "reatar",
    "reatarmo": "reatar",
    "reatarmos": "reatar",
    "reatará": "reatar",
    "reatarás": "reatar",
    "reatarão": "reatar",
    "reataríamos": "reatar",
    "reataríeis": "reatar",
    "reatas": "reatar",
    "reatasse": "reatar",
    "reatassem": "reatar",
    "reatasses": "reatar",
    "reataste": "reatar",
    "reatastes": "reatar",
    "reatava": "reatar",
    "reatavam": "reatar",
    "reatavas": "reatar",
    "reate": "reatar",
    "reatei": "reatar",
    "reateis": "reatar",
    "reatem": "reatar",
    "reatemo": "reatar",
    "reatemos": "reatar",
    "reates": "reatar",
    "reatesta": "reatestar",
    "reatestada": "reatestar",
    "reatestadas": "reatestar",
    "reatestado": "reatestar",
    "reatestados": "reatestar",
    "reatestai": "reatestar",
    "reatestais": "reatestar",
    "reatestam": "reatestar",
    "reatestamo": "reatestar",
    "reatestamos": "reatestar",
    "reatestando": "reatestar",
    "reatestara": "reatestar",
    "reatestaram": "reatestar",
    "reatestaras": "reatestar",
    "reatestarde": "reatestar",
    "reatestardes": "reatestar",
    "reatestare": "reatestar",
    "reatestarei": "reatestar",
    "reatestareis": "reatestar",
    "reatestarem": "reatestar",
    "reatestaremos": "reatestar",
    "reatestares": "reatestar",
    "reatestaria": "reatestar",
    "reatestariam": "reatestar",
    "reatestarias": "reatestar",
    "reatestarmo": "reatestar",
    "reatestarmos": "reatestar",
    "reatestará": "reatestar",
    "reatestarás": "reatestar",
    "reatestarão": "reatestar",
    "reatestaríamos": "reatestar",
    "reatestaríeis": "reatestar",
    "reatestas": "reatestar",
    "reatestasse": "reatestar",
    "reatestassem": "reatestar",
    "reatestasses": "reatestar",
    "reatestaste": "reatestar",
    "reatestastes": "reatestar",
    "reatestava": "reatestar",
    "reatestavam": "reatestar",
    "reatestavas": "reatestar",
    "reateste": "reatestar",
    "reatestei": "reatestar",
    "reatesteis": "reatestar",
    "reatestem": "reatestar",
    "reatestemo": "reatestar",
    "reatestemos": "reatestar",
    "reatestes": "reatestar",
    "reatesto": "reatestar",
    "reatestou": "reatestar",
    "reatestá": "reatestar",
    "reatestámo": "reatestar",
    "reatestámos": "reatestar",
    "reatestáramo": "reatestar",
    "reatestáramos": "reatestar",
    "reatestárei": "reatestar",
    "reatestáreis": "reatestar",
    "reatestásseis": "reatestar",
    "reatestássemos": "reatestar",
    "reatestávamo": "reatestar",
    "reatestávamos": "reatestar",
    "reatestávei": "reatestar",
    "reatestáveis": "reatestar",
    "reato": "reatar",
    "reatos": "reato",
    "reatou": "reatar",
    "reatá": "reatar",
    "reatámo": "reatar",
    "reatámos": "reatar",
    "reatáramo": "reatar",
    "reatáramos": "reatar",
    "reatárei": "reatar",
    "reatáreis": "reatar",
    "reatásseis": "reatar",
    "reatássemos": "reatar",
    "reatávamo": "reatar",
    "reatávamos": "reatar",
    "reatávei": "reatar",
    "reatáveis": "reatável",
    "reavalia": "reavaliar",
    "reavaliada": "reavaliar",
    "reavaliadas": "reavaliar",
    "reavaliado": "reavaliar",
    "reavaliados": "reavaliar",
    "reavaliai": "reavaliar",
    "reavaliais": "reavaliar",
    "reavaliam": "reavaliar",
    "reavaliamo": "reavaliar",
    "reavaliamos": "reavaliar",
    "reavaliando": "reavaliar",
    "reavaliara": "reavaliar",
    "reavaliaram": "reavaliar",
    "reavaliaras": "reavaliar",
    "reavaliarde": "reavaliar",
    "reavaliardes": "reavaliar",
    "reavaliare": "reavaliar",
    "reavaliarei": "reavaliar",
    "reavaliareis": "reavaliar",
    "reavaliarem": "reavaliar",
    "reavaliaremos": "reavaliar",
    "reavaliares": "reavaliar",
    "reavaliaria": "reavaliar",
    "reavaliariam": "reavaliar",
    "reavaliarias": "reavaliar",
    "reavaliarmo": "reavaliar",
    "reavaliarmos": "reavaliar",
    "reavaliará": "reavaliar",
    "reavaliarás": "reavaliar",
    "reavaliarão": "reavaliar",
    "reavaliaríamos": "reavaliar",
    "reavaliaríeis": "reavaliar",
    "reavalias": "reavaliar",
    "reavaliasse": "reavaliar",
    "reavaliassem": "reavaliar",
    "reavaliasses": "reavaliar",
    "reavaliaste": "reavaliar",
    "reavaliastes": "reavaliar",
    "reavaliava": "reavaliar",
    "reavaliavam": "reavaliar",
    "reavaliavas": "reavaliar",
    "reavaliações": "reavaliação",
    "reavalie": "reavaliar",
    "reavaliei": "reavaliar",
    "reavalieis": "reavaliar",
    "reavaliem": "reavaliar",
    "reavaliemo": "reavaliar",
    "reavaliemos": "reavaliar",
    "reavalies": "reavaliar",
    "reavalio": "reavaliar",
    "reavaliou": "reavaliar",
    "reavaliá": "reavaliar",
    "reavaliámo": "reavaliar",
    "reavaliámos": "reavaliar",
    "reavaliáramo": "reavaliar",
    "reavaliáramos": "reavaliar",
    "reavaliárei": "reavaliar",
    "reavaliáreis": "reavaliar",
    "reavaliásseis": "reavaliar",
    "reavaliássemos": "reavaliar",
    "reavaliávamo": "reavaliar",
    "reavaliávamos": "reavaliar",
    "reavaliávei": "reavaliar",
    "reavaliáveis": "reavaliar",
    "reavei": "reaver",
    "reaveis": "reaver",
    "reaveja": "reaver",
    "reavejais": "reaver",
    "reavejam": "reaver",
    "reavejamo": "reaver",
    "reavejamos": "reaver",
    "reavejas": "reaver",
    "reavejo": "reaver",
    "reavemo": "reaver",
    "reavemos": "reaver",
    "reavendo": "reaver",
    "reaverde": "reaver",
    "reaverdes": "reaver",
    "reavere": "reaver",
    "reaverei": "reaver",
    "reavereis": "reaver",
    "reaverem": "reaver",
    "reaveremos": "reaver",
    "reaveres": "reaver",
    "reaveria": "reaver",
    "reaveriam": "reaver",
    "reaverias": "reaver",
    "reavermo": "reaver",
    "reavermos": "reaver",
    "reaverá": "reaver",
    "reaverás": "reaver",
    "reaverão": "reaver",
    "reaveríamos": "reaver",
    "reaveríeis": "reaver",
    "reavia": "reaviar",
    "reaviada": "reaviar",
    "reaviadas": "reaviar",
    "reaviado": "reaviar",
    "reaviados": "reaviar",
    "reaviai": "reaviar",
    "reaviais": "reaviar",
    "reaviam": "reaviar",
    "reaviamo": "reaviar",
    "reaviamos": "reaviar",
    "reaviando": "reaviar",
    "reaviara": "reaviar",
    "reaviaram": "reaviar",
    "reaviaras": "reaviar",
    "reaviarde": "reaviar",
    "reaviardes": "reaviar",
    "reaviare": "reaviar",
    "reaviarei": "reaviar",
    "reaviareis": "reaviar",
    "reaviarem": "reaviar",
    "reaviaremos": "reaviar",
    "reaviares": "reaviar",
    "reaviaria": "reaviar",
    "reaviariam": "reaviar",
    "reaviarias": "reaviar",
    "reaviarmo": "reaviar",
    "reaviarmos": "reaviar",
    "reaviará": "reaviar",
    "reaviarás": "reaviar",
    "reaviarão": "reaviar",
    "reaviaríamos": "reaviar",
    "reaviaríeis": "reaviar",
    "reavias": "reaviar",
    "reaviasse": "reaviar",
    "reaviassem": "reaviar",
    "reaviasses": "reaviar",
    "reaviaste": "reaviar",
    "reaviastes": "reaviar",
    "reaviava": "reaviar",
    "reaviavam": "reaviar",
    "reaviavas": "reaviar",
    "reavida": "reaver",
    "reavidas": "reaver",
    "reavido": "reaver",
    "reavidos": "reaver",
    "reavie": "reaviar",
    "reaviei": "reaviar",
    "reavieis": "reaviar",
    "reaviem": "reaviar",
    "reaviemo": "reaviar",
    "reaviemos": "reaviar",
    "reavies": "reaviar",
    "reavio": "reaviar",
    "reaviou": "reaviar",
    "reavisa": "reavisar",
    "reavisada": "reavisar",
    "reavisadas": "reavisar",
    "reavisado": "reavisar",
    "reavisados": "reavisar",
    "reavisai": "reavisar",
    "reavisais": "reavisar",
    "reavisam": "reavisar",
    "reavisamo": "reavisar",
    "reavisamos": "reavisar",
    "reavisando": "reavisar",
    "reavisara": "reavisar",
    "reavisaram": "reavisar",
    "reavisaras": "reavisar",
    "reavisarde": "reavisar",
    "reavisardes": "reavisar",
    "reavisare": "reavisar",
    "reavisarei": "reavisar",
    "reavisareis": "reavisar",
    "reavisarem": "reavisar",
    "reavisaremos": "reavisar",
    "reavisares": "reavisar",
    "reavisaria": "reavisar",
    "reavisariam": "reavisar",
    "reavisarias": "reavisar",
    "reavisarmo": "reavisar",
    "reavisarmos": "reavisar",
    "reavisará": "reavisar",
    "reavisarás": "reavisar",
    "reavisarão": "reavisar",
    "reavisaríamos": "reavisar",
    "reavisaríeis": "reavisar",
    "reavisas": "reavisar",
    "reavisasse": "reavisar",
    "reavisassem": "reavisar",
    "reavisasses": "reavisar",
    "reavisaste": "reavisar",
    "reavisastes": "reavisar",
    "reavisava": "reavisar",
    "reavisavam": "reavisar",
    "reavisavas": "reavisar",
    "reavise": "reavisar",
    "reavisei": "reavisar",
    "reaviseis": "reavisar",
    "reavisem": "reavisar",
    "reavisemo": "reavisar",
    "reavisemos": "reavisar",
    "reavises": "reavisar",
    "reaviso": "reavisar",
    "reavisos": "reaviso",
    "reavisou": "reavisar",
    "reavista": "reavistar",
    "reavistada": "reavistar",
    "reavistadas": "reavistar",
    "reavistado": "reavistar",
    "reavistados": "reavistar",
    "reavistai": "reavistar",
    "reavistais": "reavistar",
    "reavistam": "reavistar",
    "reavistamo": "reavistar",
    "reavistamos": "reavistar",
    "reavistando": "reavistar",
    "reavistara": "reavistar",
    "reavistaram": "reavistar",
    "reavistaras": "reavistar",
    "reavistarde": "reavistar",
    "reavistardes": "reavistar",
    "reavistare": "reavistar",
    "reavistarei": "reavistar",
    "reavistareis": "reavistar",
    "reavistarem": "reavistar",
    "reavistaremos": "reavistar",
    "reavistares": "reavistar",
    "reavistaria": "reavistar",
    "reavistariam": "reavistar",
    "reavistarias": "reavistar",
    "reavistarmo": "reavistar",
    "reavistarmos": "reavistar",
    "reavistará": "reavistar",
    "reavistarás": "reavistar",
    "reavistarão": "reavistar",
    "reavistaríamos": "reavistar",
    "reavistaríeis": "reavistar",
    "reavistas": "reavistar",
    "reavistasse": "reavistar",
    "reavistassem": "reavistar",
    "reavistasses": "reavistar",
    "reavistaste": "reavistar",
    "reavistastes": "reavistar",
    "reavistava": "reavistar",
    "reavistavam": "reavistar",
    "reavistavas": "reavistar",
    "reaviste": "reavistar",
    "reavistei": "reavistar",
    "reavisteis": "reavistar",
    "reavistem": "reavistar",
    "reavistemo": "reavistar",
    "reavistemos": "reavistar",
    "reavistes": "reavistar",
    "reavisto": "reavistar",
    "reavistou": "reavistar",
    "reavistá": "reavistar",
    "reavistámo": "reavistar",
    "reavistámos": "reavistar",
    "reavistáramo": "reavistar",
    "reavistáramos": "reavistar",
    "reavistárei": "reavistar",
    "reavistáreis": "reavistar",
    "reavistásseis": "reavistar",
    "reavistássemos": "reavistar",
    "reavistávamo": "reavistar",
    "reavistávamos": "reavistar",
    "reavistávei": "reavistar",
    "reavistáveis": "reavistar",
    "reavisá": "reavisar",
    "reavisámo": "reavisar",
    "reavisámos": "reavisar",
    "reavisáramo": "reavisar",
    "reavisáramos": "reavisar",
    "reavisárei": "reavisar",
    "reavisáreis": "reavisar",
    "reavisásseis": "reavisar",
    "reavisássemos": "reavisar",
    "reavisávamo": "reavisar",
    "reavisávamos": "reavisar",
    "reavisávei": "reavisar",
    "reavisáveis": "reavisar",
    "reaviva": "reavivar",
    "reavivada": "reavivar",
    "reavivadas": "reavivar",
    "reavivado": "reavivar",
    "reavivados": "reavivar",
    "reavivai": "reavivar",
    "reavivais": "reavivar",
    "reavivam": "reavivar",
    "reavivamentos": "reavivamento",
    "reavivamo": "reavivar",
    "reavivamos": "reavivar",
    "reavivando": "reavivar",
    "reavivara": "reavivar",
    "reavivaram": "reavivar",
    "reavivaras": "reavivar",
    "reavivarde": "reavivar",
    "reavivardes": "reavivar",
    "reavivare": "reavivar",
    "reavivarei": "reavivar",
    "reavivareis": "reavivar",
    "reavivarem": "reavivar",
    "reavivaremos": "reavivar",
    "reavivares": "reavivar",
    "reavivaria": "reavivar",
    "reavivariam": "reavivar",
    "reavivarias": "reavivar",
    "reavivarmo": "reavivar",
    "reavivarmos": "reavivar",
    "reavivará": "reavivar",
    "reavivarás": "reavivar",
    "reavivarão": "reavivar",
    "reavivaríamos": "reavivar",
    "reavivaríeis": "reavivar",
    "reavivas": "reavivar",
    "reavivasse": "reavivar",
    "reavivassem": "reavivar",
    "reavivasses": "reavivar",
    "reavivaste": "reavivar",
    "reavivastes": "reavivar",
    "reavivava": "reavivar",
    "reavivavam": "reavivar",
    "reavivavas": "reavivar",
    "reavive": "reavivar",
    "reavivei": "reavivar",
    "reaviveis": "reavivar",
    "reavivem": "reavivar",
    "reavivemo": "reavivar",
    "reavivemos": "reavivar",
    "reavives": "reavivar",
    "reavivo": "reavivar",
    "reavivou": "reavivar",
    "reavivá": "reavivar",
    "reavivámo": "reavivar",
    "reavivámos": "reavivar",
    "reaviváramo": "reavivar",
    "reaviváramos": "reavivar",
    "reavivárei": "reavivar",
    "reaviváreis": "reavivar",
    "reavivásseis": "reavivar",
    "reavivássemos": "reavivar",
    "reavivávamo": "reavivar",
    "reavivávamos": "reavivar",
    "reavivávei": "reavivar",
    "reaviváveis": "reavivar",
    "reaviá": "reaviar",
    "reaviámo": "reaviar",
    "reaviámos": "reaviar",
    "reaviáramo": "reaviar",
    "reaviáramos": "reaviar",
    "reaviárei": "reaviar",
    "reaviáreis": "reaviar",
    "reaviásseis": "reaviar",
    "reaviássemos": "reaviar",
    "reaviávamo": "reaviar",
    "reaviávamos": "reaviar",
    "reaviávei": "reaviar",
    "reaviáveis": "reaviar",
    "reavê": "reaver",
    "reavêem": "reaver",
    "reavês": "reaver",
    "reavíamo": "reaver",
    "reavíamos": "reaver",
    "reavíei": "reaver",
    "reavíeis": "reaver",
    "reaças": "reaça",
    "reba": "rebar",
    "rebada": "rebar",
    "rebadas": "rebar",
    "rebado": "rebar",
    "rebados": "rebar",
    "rebai": "rebar",
    "rebais": "rebar",
    "rebaixa": "rebaixar",
    "rebaixada": "rebaixar",
    "rebaixadas": "rebaixar",
    "rebaixadazinha": "rebaixado",
    "rebaixadazinhas": "rebaixado",
    "rebaixadazita": "rebaixado",
    "rebaixadazitas": "rebaixado",
    "rebaixadinha": "rebaixado",
    "rebaixadinhas": "rebaixado",
    "rebaixadinho": "rebaixado",
    "rebaixadinhos": "rebaixado",
    "rebaixadita": "rebaixado",
    "rebaixaditas": "rebaixado",
    "rebaixadito": "rebaixado",
    "rebaixaditos": "rebaixado",
    "rebaixado": "rebaixar",
    "rebaixados": "rebaixar",
    "rebaixadozinho": "rebaixado",
    "rebaixadozinhos": "rebaixado",
    "rebaixadozito": "rebaixado",
    "rebaixadozitos": "rebaixado",
    "rebaixadíssima": "rebaixado",
    "rebaixadíssimas": "rebaixado",
    "rebaixadíssimo": "rebaixado",
    "rebaixadíssimos": "rebaixado",
    "rebaixai": "rebaixar",
    "rebaixais": "rebaixar",
    "rebaixam": "rebaixar",
    "rebaixamentos": "rebaixamento",
    "rebaixamo": "rebaixar",
    "rebaixamos": "rebaixar",
    "rebaixando": "rebaixar",
    "rebaixara": "rebaixar",
    "rebaixaram": "rebaixar",
    "rebaixaras": "rebaixar",
    "rebaixarde": "rebaixar",
    "rebaixardes": "rebaixar",
    "rebaixare": "rebaixar",
    "rebaixarei": "rebaixar",
    "rebaixareis": "rebaixar",
    "rebaixarem": "rebaixar",
    "rebaixaremos": "rebaixar",
    "rebaixares": "rebaixar",
    "rebaixaria": "rebaixar",
    "rebaixariam": "rebaixar",
    "rebaixarias": "rebaixar",
    "rebaixarmo": "rebaixar",
    "rebaixarmos": "rebaixar",
    "rebaixará": "rebaixar",
    "rebaixarás": "rebaixar",
    "rebaixarão": "rebaixar",
    "rebaixaríamos": "rebaixar",
    "rebaixaríeis": "rebaixar",
    "rebaixas": "rebaixar",
    "rebaixasse": "rebaixar",
    "rebaixassem": "rebaixar",
    "rebaixasses": "rebaixar",
    "rebaixaste": "rebaixar",
    "rebaixastes": "rebaixar",
    "rebaixava": "rebaixar",
    "rebaixavam": "rebaixar",
    "rebaixavas": "rebaixar",
    "rebaixe": "rebaixar",
    "rebaixei": "rebaixar",
    "rebaixeis": "rebaixar",
    "rebaixem": "rebaixar",
    "rebaixemo": "rebaixar",
    "rebaixemos": "rebaixar",
    "rebaixes": "rebaixe",
    "rebaixo": "rebaixar",
    "rebaixos": "rebaixo",
    "rebaixou": "rebaixar",
    "rebaixá": "rebaixar",
    "rebaixámo": "rebaixar",
    "rebaixámos": "rebaixar",
    "rebaixáramo": "rebaixar",
    "rebaixáramos": "rebaixar",
    "rebaixárei": "rebaixar",
    "rebaixáreis": "rebaixar",
    "rebaixásseis": "rebaixar",
    "rebaixássemos": "rebaixar",
    "rebaixávamo": "rebaixar",
    "rebaixávamos": "rebaixar",
    "rebaixávei": "rebaixar",
    "rebaixáveis": "rebaixável",
    "rebaldarias": "rebaldaria",
    "rebalsa": "rebalsar",
    "rebalsada": "rebalsar",
    "rebalsadas": "rebalsar",
    "rebalsado": "rebalsar",
    "rebalsados": "rebalsar",
    "rebalsai": "rebalsar",
    "rebalsais": "rebalsar",
    "rebalsam": "rebalsar",
    "rebalsamo": "rebalsar",
    "rebalsamos": "rebalsar",
    "rebalsando": "rebalsar",
    "rebalsara": "rebalsar",
    "rebalsaram": "rebalsar",
    "rebalsaras": "rebalsar",
    "rebalsarde": "rebalsar",
    "rebalsardes": "rebalsar",
    "rebalsare": "rebalsar",
    "rebalsarei": "rebalsar",
    "rebalsareis": "rebalsar",
    "rebalsarem": "rebalsar",
    "rebalsaremos": "rebalsar",
    "rebalsares": "rebalsar",
    "rebalsaria": "rebalsar",
    "rebalsariam": "rebalsar",
    "rebalsarias": "rebalsar",
    "rebalsarmo": "rebalsar",
    "rebalsarmos": "rebalsar",
    "rebalsará": "rebalsar",
    "rebalsarás": "rebalsar",
    "rebalsarão": "rebalsar",
    "rebalsaríamos": "rebalsar",
    "rebalsaríeis": "rebalsar",
    "rebalsas": "rebalsar",
    "rebalsasse": "rebalsar",
    "rebalsassem": "rebalsar",
    "rebalsasses": "rebalsar",
    "rebalsaste": "rebalsar",
    "rebalsastes": "rebalsar",
    "rebalsava": "rebalsar",
    "rebalsavam": "rebalsar",
    "rebalsavas": "rebalsar",
    "rebalse": "rebalsar",
    "rebalsei": "rebalsar",
    "rebalseis": "rebalsar",
    "rebalsem": "rebalsar",
    "rebalsemo": "rebalsar",
    "rebalsemos": "rebalsar",
    "rebalses": "rebalsar",
    "rebalso": "rebalsar",
    "rebalsou": "rebalsar",
    "rebalsá": "rebalsar",
    "rebalsámo": "rebalsar",
    "rebalsámos": "rebalsar",
    "rebalsáramo": "rebalsar",
    "rebalsáramos": "rebalsar",
    "rebalsárei": "rebalsar",
    "rebalsáreis": "rebalsar",
    "rebalsásseis": "rebalsar",
    "rebalsássemos": "rebalsar",
    "rebalsávamo": "rebalsar",
    "rebalsávamos": "rebalsar",
    "rebalsávei": "rebalsar",
    "rebalsáveis": "rebalsar",
    "rebam": "rebar",
    "rebamo": "rebar",
    "rebamos": "rebar",
    "rebando": "rebar",
    "rebanha": "rebanhar",
    "rebanhada": "rebanhar",
    "rebanhadas": "rebanhar",
    "rebanhado": "rebanhar",
    "rebanhados": "rebanhar",
    "rebanhai": "rebanhar",
    "rebanhais": "rebanhar",
    "rebanham": "rebanhar",
    "rebanhamo": "rebanhar",
    "rebanhamos": "rebanhar",
    "rebanhando": "rebanhar",
    "rebanhara": "rebanhar",
    "rebanharam": "rebanhar",
    "rebanharas": "rebanhar",
    "rebanharde": "rebanhar",
    "rebanhardes": "rebanhar",
    "rebanhare": "rebanhar",
    "rebanharei": "rebanhar",
    "rebanhareis": "rebanhar",
    "rebanharem": "rebanhar",
    "rebanharemos": "rebanhar",
    "rebanhares": "rebanhar",
    "rebanharia": "rebanhar",
    "rebanhariam": "rebanhar",
    "rebanharias": "rebanhar",
    "rebanharmo": "rebanhar",
    "rebanharmos": "rebanhar",
    "rebanhará": "rebanhar",
    "rebanharás": "rebanhar",
    "rebanharão": "rebanhar",
    "rebanharíamos": "rebanhar",
    "rebanharíeis": "rebanhar",
    "rebanhas": "rebanhar",
    "rebanhasse": "rebanhar",
    "rebanhassem": "rebanhar",
    "rebanhasses": "rebanhar",
    "rebanhaste": "rebanhar",
    "rebanhastes": "rebanhar",
    "rebanhava": "rebanhar",
    "rebanhavam": "rebanhar",
    "rebanhavas": "rebanhar",
    "rebanhe": "rebanhar",
    "rebanhei": "rebanhar",
    "rebanheis": "rebanhar",
    "rebanhem": "rebanhar",
    "rebanhemo": "rebanhar",
    "rebanhemos": "rebanhar",
    "rebanhes": "rebanhar",
    "rebanhia": "rebanhio",
    "rebanhias": "rebanhio",
    "rebanhios": "rebanhio",
    "rebanho": "rebanhar",
    "rebanhos": "rebanho",
    "rebanhou": "rebanhar",
    "rebanhá": "rebanhar",
    "rebanhámo": "rebanhar",
    "rebanhámos": "rebanhar",
    "rebanháramo": "rebanhar",
    "rebanháramos": "rebanhar",
    "rebanhárei": "rebanhar",
    "rebanháreis": "rebanhar",
    "rebanhásseis": "rebanhar",
    "rebanhássemos": "rebanhar",
    "rebanhávamo": "rebanhar",
    "rebanhávamos": "rebanhar",
    "rebanhávei": "rebanhar",
    "rebanháveis": "rebanhar",
    "rebaptismos": "rebaptismo",
    "rebaptiza": "rebaptizar",
    "rebaptizada": "rebaptizar",
    "rebaptizadas": "rebaptizar",
    "rebaptizado": "rebaptizar",
    "rebaptizados": "rebaptizar",
    "rebaptizai": "rebaptizar",
    "rebaptizais": "rebaptizar",
    "rebaptizam": "rebaptizar",
    "rebaptizamo": "rebaptizar",
    "rebaptizamos": "rebaptizar",
    "rebaptizando": "rebaptizar",
    "rebaptizara": "rebaptizar",
    "rebaptizaram": "rebaptizar",
    "rebaptizaras": "rebaptizar",
    "rebaptizarde": "rebaptizar",
    "rebaptizardes": "rebaptizar",
    "rebaptizare": "rebaptizar",
    "rebaptizarei": "rebaptizar",
    "rebaptizareis": "rebaptizar",
    "rebaptizarem": "rebaptizar",
    "rebaptizaremos": "rebaptizar",
    "rebaptizares": "rebaptizar",
    "rebaptizaria": "rebaptizar",
    "rebaptizariam": "rebaptizar",
    "rebaptizarias": "rebaptizar",
    "rebaptizarmo": "rebaptizar",
    "rebaptizarmos": "rebaptizar",
    "rebaptizará": "rebaptizar",
    "rebaptizarás": "rebaptizar",
    "rebaptizarão": "rebaptizar",
    "rebaptizaríamos": "rebaptizar",
    "rebaptizaríeis": "rebaptizar",
    "rebaptizas": "rebaptizar",
    "rebaptizasse": "rebaptizar",
    "rebaptizassem": "rebaptizar",
    "rebaptizasses": "rebaptizar",
    "rebaptizaste": "rebaptizar",
    "rebaptizastes": "rebaptizar",
    "rebaptizava": "rebaptizar",
    "rebaptizavam": "rebaptizar",
    "rebaptizavas": "rebaptizar",
    "rebaptizações": "rebaptização",
    "rebaptize": "rebaptizar",
    "rebaptizei": "rebaptizar",
    "rebaptizeis": "rebaptizar",
    "rebaptizem": "rebaptizar",
    "rebaptizemo": "rebaptizar",
    "rebaptizemos": "rebaptizar",
    "rebaptizes": "rebaptizar",
    "rebaptizo": "rebaptizar",
    "rebaptizou": "rebaptizar",
    "rebaptizá": "rebaptizar",
    "rebaptizámo": "rebaptizar",
    "rebaptizámos": "rebaptizar",
    "rebaptizáramo": "rebaptizar",
    "rebaptizáramos": "rebaptizar",
    "rebaptizárei": "rebaptizar",
    "rebaptizáreis": "rebaptizar",
    "rebaptizásseis": "rebaptizar",
    "rebaptizássemos": "rebaptizar",
    "rebaptizávamo": "rebaptizar",
    "rebaptizávamos": "rebaptizar",
    "rebaptizávei": "rebaptizar",
    "rebaptizáveis": "rebaptizar",
    "rebara": "rebar",
    "rebaram": "rebar",
    "rebaras": "rebar",
    "rebarba": "rebarbar",
    "rebarbada": "rebarbar",
    "rebarbadas": "rebarbar",
    "rebarbado": "rebarbar",
    "rebarbadora": "rebarbador",
    "rebarbadoras": "rebarbadora",
    "rebarbadores": "rebarbador",
    "rebarbados": "rebarbar",
    "rebarbai": "rebarbar",
    "rebarbais": "rebarbar",
    "rebarbam": "rebarbar",
    "rebarbamo": "rebarbar",
    "rebarbamos": "rebarbar",
    "rebarbando": "rebarbar",
    "rebarbara": "rebarbar",
    "rebarbaram": "rebarbar",
    "rebarbaras": "rebarbar",
    "rebarbarde": "rebarbar",
    "rebarbardes": "rebarbar",
    "rebarbare": "rebarbar",
    "rebarbarei": "rebarbar",
    "rebarbareis": "rebarbar",
    "rebarbarem": "rebarbar",
    "rebarbaremos": "rebarbar",
    "rebarbares": "rebarbar",
    "rebarbaria": "rebarbar",
    "rebarbariam": "rebarbar",
    "rebarbarias": "rebarbar",
    "rebarbarmo": "rebarbar",
    "rebarbarmos": "rebarbar",
    "rebarbará": "rebarbar",
    "rebarbarás": "rebarbar",
    "rebarbarão": "rebarbar",
    "rebarbaríamos": "rebarbar",
    "rebarbaríeis": "rebarbar",
    "rebarbas": "rebarbar",
    "rebarbasse": "rebarbar",
    "rebarbassem": "rebarbar",
    "rebarbasses": "rebarbar",
    "rebarbaste": "rebarbar",
    "rebarbastes": "rebarbar",
    "rebarbativa": "rebarbativo",
    "rebarbativas": "rebarbativo",
    "rebarbativos": "rebarbativo",
    "rebarbava": "rebarbar",
    "rebarbavam": "rebarbar",
    "rebarbavas": "rebarbar",
    "rebarbe": "rebarbar",
    "rebarbei": "rebarbar",
    "rebarbeis": "rebarbar",
    "rebarbem": "rebarbar",
    "rebarbemo": "rebarbar",
    "rebarbemos": "rebarbar",
    "rebarbes": "rebarbar",
    "rebarbo": "rebarbar",
    "rebarbou": "rebarbar",
    "rebarbá": "rebarbar",
    "rebarbámo": "rebarbar",
    "rebarbámos": "rebarbar",
    "rebarbáramo": "rebarbar",
    "rebarbáramos": "rebarbar",
    "rebarbárei": "rebarbar",
    "rebarbáreis": "rebarbar",
    "rebarbásseis": "rebarbar",
    "rebarbássemos": "rebarbar",
    "rebarbávamo": "rebarbar",
    "rebarbávamos": "rebarbar",
    "rebarbávei": "rebarbar",
    "rebarbáveis": "rebarbar",
    "rebarde": "rebar",
    "rebardes": "rebar",
    "rebare": "rebar",
    "rebarei": "rebar",
    "rebareis": "rebar",
    "rebarem": "rebar",
    "rebaremos": "rebar",
    "rebares": "rebar",
    "rebaria": "rebar",
    "rebariam": "rebar",
    "rebarias": "rebar",
    "rebarmo": "rebar",
    "rebarmos": "rebar",
    "rebará": "rebar",
    "rebarás": "rebar",
    "rebarão": "rebar",
    "rebaríamos": "rebar",
    "rebaríeis": "rebar",
    "rebas": "rebar",
    "rebasse": "rebar",
    "rebassem": "rebar",
    "rebasses": "rebar",
    "rebaste": "rebar",
    "rebastes": "rebar",
    "rebata": "rebater",
    "rebatais": "rebater",
    "rebatam": "rebater",
    "rebatamo": "rebater",
    "rebatamos": "rebater",
    "rebatas": "rebater",
    "rebate": "rebater",
    "rebatedora": "rebatedor",
    "rebatedoras": "rebatedor",
    "rebatedores": "rebatedor",
    "rebatei": "rebater",
    "rebateis": "rebater",
    "rebatem": "rebater",
    "rebatemo": "rebater",
    "rebatemos": "rebater",
    "rebatendo": "rebater",
    "rebatera": "rebater",
    "rebateram": "rebater",
    "rebateras": "rebater",
    "rebaterde": "rebater",
    "rebaterdes": "rebater",
    "rebatere": "rebater",
    "rebaterei": "rebater",
    "rebatereis": "rebater",
    "rebaterem": "rebater",
    "rebateremos": "rebater",
    "rebateres": "rebater",
    "rebateria": "rebater",
    "rebateriam": "rebater",
    "rebaterias": "rebater",
    "rebatermo": "rebater",
    "rebatermos": "rebater",
    "rebaterá": "rebater",
    "rebaterás": "rebater",
    "rebaterão": "rebater",
    "rebateríamos": "rebater",
    "rebateríeis": "rebater",
    "rebates": "rebater",
    "rebatesse": "rebater",
    "rebatessem": "rebater",
    "rebatesses": "rebater",
    "rebateste": "rebater",
    "rebatestes": "rebater",
    "rebateu": "rebater",
    "rebati": "rebater",
    "rebatia": "rebater",
    "rebatiam": "rebater",
    "rebatias": "rebater",
    "rebatida": "rebatido",
    "rebatidas": "rebatido",
    "rebatido": "rebater",
    "rebatidos": "rebatido",
    "rebatimentos": "rebatimento",
    "rebatinhas": "rebatinha",
    "rebato": "rebater",
    "rebatos": "rebato",
    "rebatê": "rebater",
    "rebatêramo": "rebater",
    "rebatêramos": "rebater",
    "rebatêrei": "rebater",
    "rebatêreis": "rebater",
    "rebatêsseis": "rebater",
    "rebatêssemos": "rebater",
    "rebatíamo": "rebater",
    "rebatíamos": "rebater",
    "rebatíei": "rebater",
    "rebatíeis": "rebater",
    "rebatíveis": "rebatível",
    "rebava": "rebar",
    "rebavam": "rebar",
    "rebavas": "rebar",
    "rebe": "rebar",
    "rebecas": "rebeca",
    "rebei": "rebar",
    "rebeija": "rebeijar",
    "rebeijada": "rebeijar",
    "rebeijadas": "rebeijar",
    "rebeijado": "rebeijar",
    "rebeijados": "rebeijar",
    "rebeijai": "rebeijar",
    "rebeijais": "rebeijar",
    "rebeijam": "rebeijar",
    "rebeijamo": "rebeijar",
    "rebeijamos": "rebeijar",
    "rebeijando": "rebeijar",
    "rebeijara": "rebeijar",
    "rebeijaram": "rebeijar",
    "rebeijaras": "rebeijar",
    "rebeijarde": "rebeijar",
    "rebeijardes": "rebeijar",
    "rebeijare": "rebeijar",
    "rebeijarei": "rebeijar",
    "rebeijareis": "rebeijar",
    "rebeijarem": "rebeijar",
    "rebeijaremos": "rebeijar",
    "rebeijares": "rebeijar",
    "rebeijaria": "rebeijar",
    "rebeijariam": "rebeijar",
    "rebeijarias": "rebeijar",
    "rebeijarmo": "rebeijar",
    "rebeijarmos": "rebeijar",
    "rebeijará": "rebeijar",
    "rebeijarás": "rebeijar",
    "rebeijarão": "rebeijar",
    "rebeijaríamos": "rebeijar",
    "rebeijaríeis": "rebeijar",
    "rebeijas": "rebeijar",
    "rebeijasse": "rebeijar",
    "rebeijassem": "rebeijar",
    "rebeijasses": "rebeijar",
    "rebeijaste": "rebeijar",
    "rebeijastes": "rebeijar",
    "rebeijava": "rebeijar",
    "rebeijavam": "rebeijar",
    "rebeijavas": "rebeijar",
    "rebeije": "rebeijar",
    "rebeijei": "rebeijar",
    "rebeijeis": "rebeijar",
    "rebeijem": "rebeijar",
    "rebeijemo": "rebeijar",
    "rebeijemos": "rebeijar",
    "rebeijes": "rebeijar",
    "rebeijo": "rebeijar",
    "rebeijou": "rebeijar",
    "rebeijá": "rebeijar",
    "rebeijámo": "rebeijar",
    "rebeijámos": "rebeijar",
    "rebeijáramo": "rebeijar",
    "rebeijáramos": "rebeijar",
    "rebeijárei": "rebeijar",
    "rebeijáreis": "rebeijar",
    "rebeijásseis": "rebeijar",
    "rebeijássemos": "rebeijar",
    "rebeijávamo": "rebeijar",
    "rebeijávamos": "rebeijar",
    "rebeijávei": "rebeijar",
    "rebeijáveis": "rebeijar",
    "rebeis": "rebel",
    "rebela": "rebelo",
    "rebelada": "rebelar",
    "rebeladas": "rebelar",
    "rebelado": "rebelar",
    "rebelados": "rebelar",
    "rebelai": "rebelar",
    "rebelais": "rebelar",
    "rebelam": "rebelar",
    "rebelamo": "rebelar",
    "rebelamos": "rebelar",
    "rebelando": "rebelar",
    "rebelara": "rebelar",
    "rebelaram": "rebelar",
    "rebelaras": "rebelar",
    "rebelarde": "rebelar",
    "rebelardes": "rebelar",
    "rebelare": "rebelar",
    "rebelarei": "rebelar",
    "rebelareis": "rebelar",
    "rebelarem": "rebelar",
    "rebelaremos": "rebelar",
    "rebelares": "rebelar",
    "rebelaria": "rebelar",
    "rebelariam": "rebelar",
    "rebelarias": "rebelar",
    "rebelarmo": "rebelar",
    "rebelarmos": "rebelar",
    "rebelará": "rebelar",
    "rebelarás": "rebelar",
    "rebelarão": "rebelar",
    "rebelaríamos": "rebelar",
    "rebelaríeis": "rebelar",
    "rebelas": "rebelo",
    "rebelasse": "rebelar",
    "rebelassem": "rebelar",
    "rebelasses": "rebelar",
    "rebelaste": "rebelar",
    "rebelastes": "rebelar",
    "rebelava": "rebelar",
    "rebelavam": "rebelar",
    "rebelavas": "rebelar",
    "rebeldes": "rebelde",
    "rebeldezinha": "rebelde",
    "rebeldezinhas": "rebelde",
    "rebeldezinho": "rebelde",
    "rebeldezinhos": "rebelde",
    "rebeldezita": "rebelde",
    "rebeldezitas": "rebelde",
    "rebeldezito": "rebelde",
    "rebeldezitos": "rebelde",
    "rebeldias": "rebeldia",
    "rebeldismos": "rebeldismo",
    "rebele": "rebelar",
    "rebelei": "rebelar",
    "rebeleis": "rebelar",
    "rebelem": "rebelar",
    "rebelemo": "rebelar",
    "rebelemos": "rebelar",
    "rebeles": "rebelar",
    "rebeliona": "rebelionar",
    "rebelionada": "rebelionar",
    "rebelionadas": "rebelionar",
    "rebelionado": "rebelionar",
    "rebelionados": "rebelionar",
    "rebelionai": "rebelionar",
    "rebelionais": "rebelionar",
    "rebelionam": "rebelionar",
    "rebelionamo": "rebelionar",
    "rebelionamos": "rebelionar",
    "rebelionando": "rebelionar",
    "rebelionara": "rebelionar",
    "rebelionaram": "rebelionar",
    "rebelionaras": "rebelionar",
    "rebelionarde": "rebelionar",
    "rebelionardes": "rebelionar",
    "rebelionare": "rebelionar",
    "rebelionarei": "rebelionar",
    "rebelionareis": "rebelionar",
    "rebelionarem": "rebelionar",
    "rebelionaremos": "rebelionar",
    "rebelionares": "rebelionar",
    "rebelionaria": "rebelionar",
    "rebelionariam": "rebelionar",
    "rebelionarias": "rebelionar",
    "rebelionarmo": "rebelionar",
    "rebelionarmos": "rebelionar",
    "rebelionará": "rebelionar",
    "rebelionarás": "rebelionar",
    "rebelionarão": "rebelionar",
    "rebelionaríamos": "rebelionar",
    "rebelionaríeis": "rebelionar",
    "rebelionas": "rebelionar",
    "rebelionasse": "rebelionar",
    "rebelionassem": "rebelionar",
    "rebelionasses": "rebelionar",
    "rebelionaste": "rebelionar",
    "rebelionastes": "rebelionar",
    "rebelionava": "rebelionar",
    "rebelionavam": "rebelionar",
    "rebelionavas": "rebelionar",
    "rebelione": "rebelionar",
    "rebelionei": "rebelionar",
    "rebelioneis": "rebelionar",
    "rebelionem": "rebelionar",
    "rebelionemo": "rebelionar",
    "rebelionemos": "rebelionar",
    "rebeliones": "rebelionar",
    "rebeliono": "rebelionar",
    "rebelionou": "rebelionar",
    "rebelioná": "rebelionar",
    "rebelionámo": "rebelionar",
    "rebelionámos": "rebelionar",
    "rebelionáramo": "rebelionar",
    "rebelionáramos": "rebelionar",
    "rebelionárei": "rebelionar",
    "rebelionáreis": "rebelionar",
    "rebelionásseis": "rebelionar",
    "rebelionássemos": "rebelionar",
    "rebelionávamo": "rebelionar",
    "rebelionávamos": "rebelionar",
    "rebelionávei": "rebelionar",
    "rebelionáveis": "rebelionar",
    "rebeliões": "rebelião",
    "rebelo": "rebelar",
    "rebelona": "rebelão",
    "rebelonas": "rebelão",
    "rebelos": "rebelo",
    "rebelou": "rebelar",
    "rebelá": "rebelar",
    "rebelámo": "rebelar",
    "rebelámos": "rebelar",
    "rebeláramo": "rebelar",
    "rebeláramos": "rebelar",
    "rebelárei": "rebelar",
    "rebeláreis": "rebelar",
    "rebelásseis": "rebelar",
    "rebelássemos": "rebelar",
    "rebelávamo": "rebelar",
    "rebelávamos": "rebelar",
    "rebelávei": "rebelar",
    "rebeláveis": "rebelar",
    "rebelões": "rebelão",
    "rebem": "rebar",
    "rebemo": "rebar",
    "rebemos": "rebar",
    "rebenta": "rebentar",
    "rebentada": "rebentar",
    "rebentadas": "rebentar",
    "rebentado": "rebentar",
    "rebentados": "rebentar",
    "rebentai": "rebentar",
    "rebentais": "rebentar",
    "rebentam": "rebentar",
    "rebentamentos": "rebentamento",
    "rebentamo": "rebentar",
    "rebentamos": "rebentar",
    "rebentando": "rebentar",
    "rebentara": "rebentar",
    "rebentaram": "rebentar",
    "rebentaras": "rebentar",
    "rebentarde": "rebentar",
    "rebentardes": "rebentar",
    "rebentare": "rebentar",
    "rebentarei": "rebentar",
    "rebentareis": "rebentar",
    "rebentarem": "rebentar",
    "rebentaremos": "rebentar",
    "rebentares": "rebentar",
    "rebentaria": "rebentar",
    "rebentariam": "rebentar",
    "rebentarias": "rebentar",
    "rebentarmo": "rebentar",
    "rebentarmos": "rebentar",
    "rebentará": "rebentar",
    "rebentarás": "rebentar",
    "rebentarão": "rebentar",
    "rebentaríamos": "rebentar",
    "rebentaríeis": "rebentar",
    "rebentas": "rebentar",
    "rebentasse": "rebentar",
    "rebentassem": "rebentar",
    "rebentasses": "rebentar",
    "rebentaste": "rebentar",
    "rebentastes": "rebentar",
    "rebentava": "rebentar",
    "rebentavam": "rebentar",
    "rebentavas": "rebentar",
    "rebentações": "rebentação",
    "rebente": "rebentar",
    "rebentei": "rebentar",
    "rebenteis": "rebentar",
    "rebentem": "rebentar",
    "rebentemo": "rebentar",
    "rebentemos": "rebentar",
    "rebentes": "rebentar",
    "rebentinas": "rebentina",
    "rebentinhas": "rebentinha",
    "rebentinho": "rebento",
    "rebentinhos": "rebento",
    "rebentito": "rebento",
    "rebentitos": "rebento",
    "rebento": "rebentar",
    "rebentos": "rebento",
    "rebentou": "rebentar",
    "rebentá": "rebentar",
    "rebentámo": "rebentar",
    "rebentámos": "rebentar",
    "rebentáramo": "rebentar",
    "rebentáramos": "rebentar",
    "rebentárei": "rebentar",
    "rebentáreis": "rebentar",
    "rebentásseis": "rebentar",
    "rebentássemos": "rebentar",
    "rebentávamo": "rebentar",
    "rebentávamos": "rebentar",
    "rebentávei": "rebentar",
    "rebentáveis": "rebentável",
    "rebentãozais": "rebentãozal",
    "rebentões": "rebentão",
    "rebes": "rebar",
    "rebimba": "rebimbar",
    "rebimbada": "rebimbar",
    "rebimbadas": "rebimbar",
    "rebimbado": "rebimbar",
    "rebimbados": "rebimbar",
    "rebimbai": "rebimbar",
    "rebimbais": "rebimbar",
    "rebimbam": "rebimbar",
    "rebimbamo": "rebimbar",
    "rebimbamos": "rebimbar",
    "rebimbando": "rebimbar",
    "rebimbara": "rebimbar",
    "rebimbaram": "rebimbar",
    "rebimbaras": "rebimbar",
    "rebimbardes": "rebimbar",
    "rebimbarei": "rebimbar",
    "rebimbareis": "rebimbar",
    "rebimbarem": "rebimbar",
    "rebimbaremos": "rebimbar",
    "rebimbares": "rebimbar",
    "rebimbaria": "rebimbar",
    "rebimbariam": "rebimbar",
    "rebimbarias": "rebimbar",
    "rebimbarmo": "rebimbar",
    "rebimbarmos": "rebimbar",
    "rebimbará": "rebimbar",
    "rebimbarás": "rebimbar",
    "rebimbarão": "rebimbar",
    "rebimbaríamos": "rebimbar",
    "rebimbaríeis": "rebimbar",
    "rebimbas": "rebimbar",
    "rebimbasse": "rebimbar",
    "rebimbassem": "rebimbar",
    "rebimbasses": "rebimbar",
    "rebimbaste": "rebimbar",
    "rebimbastes": "rebimbar",
    "rebimbava": "rebimbar",
    "rebimbavam": "rebimbar",
    "rebimbavas": "rebimbar",
    "rebimbe": "rebimbar",
    "rebimbei": "rebimbar",
    "rebimbeis": "rebimbar",
    "rebimbem": "rebimbar",
    "rebimbemo": "rebimbar",
    "rebimbemos": "rebimbar",
    "rebimbes": "rebimbar",
    "rebimbo": "rebimbar",
    "rebimbou": "rebimbar",
    "rebimbámo": "rebimbar",
    "rebimbámos": "rebimbar",
    "rebimbáramo": "rebimbar",
    "rebimbáramos": "rebimbar",
    "rebimbáreis": "rebimbar",
    "rebimbásseis": "rebimbar",
    "rebimbássemos": "rebimbar",
    "rebimbávamo": "rebimbar",
    "rebimbávamos": "rebimbar",
    "rebimbáveis": "rebimbar",
    "rebiques": "rebique",
    "rebita": "rebitar",
    "rebitada": "rebitar",
    "rebitadas": "rebitar",
    "rebitado": "rebitar",
    "rebitados": "rebitar",
    "rebitagens": "rebitagem",
    "rebitai": "rebitar",
    "rebitais": "rebitar",
    "rebitam": "rebitar",
    "rebitamo": "rebitar",
    "rebitamos": "rebitar",
    "rebitando": "rebitar",
    "rebitara": "rebitar",
    "rebitaram": "rebitar",
    "rebitaras": "rebitar",
    "rebitarde": "rebitar",
    "rebitardes": "rebitar",
    "rebitare": "rebitar",
    "rebitarei": "rebitar",
    "rebitareis": "rebitar",
    "rebitarem": "rebitar",
    "rebitaremos": "rebitar",
    "rebitares": "rebitar",
    "rebitaria": "rebitar",
    "rebitariam": "rebitar",
    "rebitarias": "rebitar",
    "rebitarmo": "rebitar",
    "rebitarmos": "rebitar",
    "rebitará": "rebitar",
    "rebitarás": "rebitar",
    "rebitarão": "rebitar",
    "rebitaríamos": "rebitar",
    "rebitaríeis": "rebitar",
    "rebitas": "rebitar",
    "rebitasse": "rebitar",
    "rebitassem": "rebitar",
    "rebitasses": "rebitar",
    "rebitaste": "rebitar",
    "rebitastes": "rebitar",
    "rebitava": "rebitar",
    "rebitavam": "rebitar",
    "rebitavas": "rebitar",
    "rebite": "rebitar",
    "rebitei": "rebitar",
    "rebiteis": "rebitar",
    "rebitem": "rebitar",
    "rebitemo": "rebitar",
    "rebitemos": "rebitar",
    "rebites": "rebite",
    "rebito": "rebitar",
    "rebitou": "rebitar",
    "rebitá": "rebitar",
    "rebitámo": "rebitar",
    "rebitámos": "rebitar",
    "rebitáramo": "rebitar",
    "rebitáramos": "rebitar",
    "rebitárei": "rebitar",
    "rebitáreis": "rebitar",
    "rebitásseis": "rebitar",
    "rebitássemos": "rebitar",
    "rebitávamo": "rebitar",
    "rebitávamos": "rebitar",
    "rebitávei": "rebitar",
    "rebitáveis": "rebitar",
    "rebo": "rebar",
    "reboa": "reboar",
    "reboada": "reboar",
    "reboadas": "reboar",
    "reboado": "reboar",
    "reboados": "reboar",
    "reboai": "reboar",
    "reboais": "reboar",
    "reboam": "reboar",
    "reboamo": "reboar",
    "reboamos": "reboar",
    "reboando": "reboar",
    "reboantes": "reboante",
    "reboara": "reboar",
    "reboaram": "reboar",
    "reboaras": "reboar",
    "reboardes": "reboar",
    "reboarei": "reboar",
    "reboareis": "reboar",
    "reboarem": "reboar",
    "reboaremos": "reboar",
    "reboares": "reboar",
    "reboaria": "reboar",
    "reboariam": "reboar",
    "reboarias": "reboar",
    "reboarmo": "reboar",
    "reboarmos": "reboar",
    "reboará": "reboar",
    "reboarás": "reboar",
    "reboarão": "reboar",
    "reboaríamos": "reboar",
    "reboaríeis": "reboar",
    "reboas": "reboar",
    "reboasse": "reboar",
    "reboassem": "reboar",
    "reboasses": "reboar",
    "reboaste": "reboar",
    "reboastes": "reboar",
    "reboava": "reboar",
    "reboavam": "reboar",
    "reboavas": "reboar",
    "rebobina": "rebobinar",
    "rebobinada": "rebobinar",
    "rebobinadas": "rebobinar",
    "rebobinadeiras": "rebobinadeira",
    "rebobinado": "rebobinar",
    "rebobinados": "rebobinar",
    "rebobinai": "rebobinar",
    "rebobinais": "rebobinar",
    "rebobinam": "rebobinar",
    "rebobinamo": "rebobinar",
    "rebobinamos": "rebobinar",
    "rebobinando": "rebobinar",
    "rebobinara": "rebobinar",
    "rebobinaram": "rebobinar",
    "rebobinaras": "rebobinar",
    "rebobinarde": "rebobinar",
    "rebobinardes": "rebobinar",
    "rebobinare": "rebobinar",
    "rebobinarei": "rebobinar",
    "rebobinareis": "rebobinar",
    "rebobinarem": "rebobinar",
    "rebobinaremos": "rebobinar",
    "rebobinares": "rebobinar",
    "rebobinaria": "rebobinar",
    "rebobinariam": "rebobinar",
    "rebobinarias": "rebobinar",
    "rebobinarmo": "rebobinar",
    "rebobinarmos": "rebobinar",
    "rebobinará": "rebobinar",
    "rebobinarás": "rebobinar",
    "rebobinarão": "rebobinar",
    "rebobinaríamos": "rebobinar",
    "rebobinaríeis": "rebobinar",
    "rebobinas": "rebobinar",
    "rebobinasse": "rebobinar",
    "rebobinassem": "rebobinar",
    "rebobinasses": "rebobinar",
    "rebobinaste": "rebobinar",
    "rebobinastes": "rebobinar",
    "rebobinava": "rebobinar",
    "rebobinavam": "rebobinar",
    "rebobinavas": "rebobinar",
    "rebobine": "rebobinar",
    "rebobinei": "rebobinar",
    "rebobineis": "rebobinar",
    "rebobinem": "rebobinar",
    "rebobinemo": "rebobinar",
    "rebobinemos": "rebobinar",
    "rebobines": "rebobinar",
    "rebobino": "rebobinar",
    "rebobinou": "rebobinar",
    "rebobiná": "rebobinar",
    "rebobinámo": "rebobinar",
    "rebobinámos": "rebobinar",
    "rebobináramo": "rebobinar",
    "rebobináramos": "rebobinar",
    "rebobinárei": "rebobinar",
    "rebobináreis": "rebobinar",
    "rebobinásseis": "rebobinar",
    "rebobinássemos": "rebobinar",
    "rebobinávamo": "rebobinar",
    "rebobinávamos": "rebobinar",
    "rebobinávei": "rebobinar",
    "rebobináveis": "rebobinar",
    "reboca": "rebocar",
    "rebocada": "rebocar",
    "rebocadas": "rebocar",
    "rebocado": "rebocar",
    "rebocadora": "rebocador",
    "rebocadoras": "rebocador",
    "rebocadorazinha": "rebocador",
    "rebocadorazinhas": "rebocador",
    "rebocadorazita": "rebocador",
    "rebocadorazitas": "rebocador",
    "rebocadores": "rebocador",
    "rebocadorzinho": "rebocador",
    "rebocadorzinhos": "rebocador",
    "rebocadorzito": "rebocador",
    "rebocadorzitos": "rebocador",
    "rebocados": "rebocar",
    "rebocaduras": "rebocadura",
    "rebocai": "rebocar",
    "rebocais": "rebocar",
    "rebocam": "rebocar",
    "rebocamo": "rebocar",
    "rebocamos": "rebocar",
    "rebocando": "rebocar",
    "rebocara": "rebocar",
    "rebocaram": "rebocar",
    "rebocaras": "rebocar",
    "rebocarde": "rebocar",
    "rebocardes": "rebocar",
    "rebocare": "rebocar",
    "rebocarei": "rebocar",
    "rebocareis": "rebocar",
    "rebocarem": "rebocar",
    "rebocaremos": "rebocar",
    "rebocares": "rebocar",
    "rebocaria": "rebocar",
    "rebocariam": "rebocar",
    "rebocarias": "rebocar",
    "rebocarmo": "rebocar",
    "rebocarmos": "rebocar",
    "rebocará": "rebocar",
    "rebocarás": "rebocar",
    "rebocarão": "rebocar",
    "rebocaríamos": "rebocar",
    "rebocaríeis": "rebocar",
    "rebocas": "rebocar",
    "rebocasse": "rebocar",
    "rebocassem": "rebocar",
    "rebocasses": "rebocar",
    "rebocaste": "rebocar",
    "rebocastes": "rebocar",
    "rebocava": "rebocar",
    "rebocavam": "rebocar",
    "rebocavas": "rebocar",
    "reboco": "rebocar",
    "rebocos": "reboco",
    "rebocou": "rebocar",
    "rebocá": "rebocar",
    "rebocámo": "rebocar",
    "rebocámos": "rebocar",
    "rebocáramo": "rebocar",
    "rebocáramos": "rebocar",
    "rebocárei": "rebocar",
    "rebocáreis": "rebocar",
    "rebocásseis": "rebocar",
    "rebocássemos": "rebocar",
    "rebocávamo": "rebocar",
    "rebocávamos": "rebocar",
    "rebocávei": "rebocar",
    "rebocáveis": "rebocar",
    "reboe": "reboar",
    "reboei": "reboar",
    "reboeis": "reboar",
    "reboem": "reboar",
    "reboemo": "reboar",
    "reboemos": "reboar",
    "reboes": "reboar",
    "rebola": "rebolo",
    "rebolada": "rebolar",
    "reboladas": "rebolar",
    "reboladazinha": "rebolado",
    "reboladazinhas": "rebolado",
    "reboladazita": "rebolado",
    "reboladazitas": "rebolado",
    "reboladinha": "rebolado",
    "reboladinhas": "rebolado",
    "reboladinho": "rebolado",
    "reboladinhos": "rebolado",
    "reboladita": "rebolado",
    "reboladitas": "rebolado",
    "reboladito": "rebolado",
    "reboladitos": "rebolado",
    "rebolado": "rebolar",
    "rebolados": "rebolar",
    "reboladozinho": "rebolado",
    "reboladozinhos": "rebolado",
    "reboladozito": "rebolado",
    "reboladozitos": "rebolado",
    "reboladíssima": "rebolado",
    "reboladíssimas": "rebolado",
    "reboladíssimo": "rebolado",
    "reboladíssimos": "rebolado",
    "rebolai": "rebolar",
    "rebolais": "rebolir",
    "rebolam": "rebolir",
    "rebolamo": "rebolir",
    "rebolamos": "rebolir",
    "rebolando": "rebolar",
    "rebolara": "rebolar",
    "rebolaram": "rebolar",
    "rebolaras": "rebolar",
    "rebolarde": "rebolar",
    "rebolardes": "rebolar",
    "rebolare": "rebolar",
    "rebolarei": "rebolar",
    "rebolareis": "rebolar",
    "rebolarem": "rebolar",
    "rebolaremos": "rebolar",
    "rebolares": "rebolar",
    "rebolaria": "rebolar",
    "rebolariam": "rebolar",
    "rebolarias": "rebolaria",
    "rebolarmo": "rebolar",
    "rebolarmos": "rebolar",
    "rebolará": "rebolar",
    "rebolarás": "rebolar",
    "rebolarão": "rebolar",
    "rebolaríamos": "rebolar",
    "rebolaríeis": "rebolar",
    "rebolas": "rebolo",
    "rebolasse": "rebolar",
    "rebolassem": "rebolar",
    "rebolasses": "rebolar",
    "rebolaste": "rebolar",
    "rebolastes": "rebolar",
    "rebolava": "rebolar",
    "rebolavam": "rebolar",
    "rebolavas": "rebolar",
    "rebole": "rebolir",
    "reboleada": "rebolear",
    "reboleadas": "rebolear",
    "reboleado": "rebolear",
    "reboleados": "rebolear",
    "reboleai": "rebolear",
    "reboleais": "rebolear",
    "reboleamo": "rebolear",
    "reboleamos": "rebolear",
    "reboleando": "rebolear",
    "reboleara": "rebolear",
    "rebolearam": "rebolear",
    "rebolearas": "rebolear",
    "rebolearde": "rebolear",
    "reboleardes": "rebolear",
    "reboleare": "rebolear",
    "rebolearei": "rebolear",
    "reboleareis": "rebolear",
    "rebolearem": "rebolear",
    "rebolearemos": "rebolear",
    "reboleares": "rebolear",
    "rebolearia": "rebolear",
    "reboleariam": "rebolear",
    "rebolearias": "rebolear",
    "rebolearmo": "rebolear",
    "rebolearmos": "rebolear",
    "reboleará": "rebolear",
    "rebolearás": "rebolear",
    "rebolearão": "rebolear",
    "rebolearíamos": "rebolear",
    "rebolearíeis": "rebolear",
    "reboleasse": "rebolear",
    "reboleassem": "rebolear",
    "reboleasses": "rebolear",
    "reboleaste": "rebolear",
    "reboleastes": "rebolear",
    "reboleava": "rebolear",
    "reboleavam": "rebolear",
    "reboleavas": "rebolear",
    "reboleei": "rebolear",
    "reboleeis": "rebolear",
    "reboleemo": "rebolear",
    "reboleemos": "rebolear",
    "rebolei": "rebolar",
    "reboleia": "rebolear",
    "reboleiam": "rebolear",
    "reboleias": "rebolear",
    "reboleie": "rebolear",
    "reboleiem": "rebolear",
    "reboleies": "rebolear",
    "reboleio": "rebolear",
    "reboleira": "reboleiro",
    "reboleiras": "reboleiro",
    "reboleiros": "reboleiro",
    "reboleis": "rebolar",
    "rebolem": "rebolir",
    "rebolemo": "rebolar",
    "rebolemos": "rebolar",
    "reboleou": "rebolear",
    "reboles": "rebolir",
    "reboletas": "reboleta",
    "reboleá": "rebolear",
    "reboleámo": "rebolear",
    "reboleámos": "rebolear",
    "reboleáramo": "rebolear",
    "reboleáramos": "rebolear",
    "reboleárei": "rebolear",
    "reboleáreis": "rebolear",
    "reboleásseis": "rebolear",
    "reboleássemos": "rebolear",
    "reboleávamo": "rebolear",
    "reboleávamos": "rebolear",
    "reboleávei": "rebolear",
    "reboleáveis": "rebolear",
    "reboli": "rebolir",
    "rebolia": "rebolir",
    "reboliam": "rebolir",
    "rebolias": "rebolir",
    "rebolida": "rebolir",
    "rebolidas": "rebolir",
    "rebolido": "rebolir",
    "rebolidos": "rebolir",
    "rebolimo": "rebolir",
    "rebolimos": "rebolir",
    "rebolindo": "rebolir",
    "rebolira": "rebolir",
    "reboliram": "rebolir",
    "reboliras": "rebolir",
    "rebolirde": "rebolir",
    "rebolirdes": "rebolir",
    "rebolire": "rebolir",
    "rebolirei": "rebolir",
    "rebolireis": "rebolir",
    "rebolirem": "rebolir",
    "reboliremos": "rebolir",
    "rebolires": "rebolir",
    "reboliria": "rebolir",
    "reboliriam": "rebolir",
    "rebolirias": "rebolir",
    "rebolirmo": "rebolir",
    "rebolirmos": "rebolir",
    "rebolirá": "rebolir",
    "rebolirás": "rebolir",
    "rebolirão": "rebolir",
    "reboliríamos": "rebolir",
    "reboliríeis": "rebolir",
    "rebolis": "rebolir",
    "rebolisse": "rebolir",
    "rebolissem": "rebolir",
    "rebolisses": "rebolir",
    "reboliste": "rebolir",
    "rebolistes": "rebolir",
    "reboliu": "rebolir",
    "reboliça": "reboliço",
    "reboliças": "reboliço",
    "reboliços": "reboliço",
    "rebolo": "rebolir",
    "rebolona": "rebolão",
    "rebolonas": "rebolão",
    "rebolos": "rebolo",
    "rebolou": "rebolar",
    "reboluda": "reboludo",
    "reboludas": "reboludo",
    "reboludos": "reboludo",
    "rebolá": "rebolar",
    "rebolámo": "rebolar",
    "rebolámos": "rebolar",
    "reboláramo": "rebolar",
    "reboláramos": "rebolar",
    "rebolárei": "rebolar",
    "reboláreis": "rebolar",
    "rebolásseis": "rebolar",
    "rebolássemos": "rebolar",
    "rebolávamo": "rebolar",
    "rebolávamos": "rebolar",
    "rebolávei": "rebolar",
    "reboláveis": "rebolar",
    "rebolíamo": "rebolir",
    "rebolíamos": "rebolir",
    "rebolíei": "rebolir",
    "rebolíeis": "rebolir",
    "rebolíramo": "rebolir",
    "rebolíramos": "rebolir",
    "rebolírei": "rebolir",
    "rebolíreis": "rebolir",
    "rebolísseis": "rebolir",
    "rebolíssemos": "rebolir",
    "rebolões": "rebolão",
    "rebomba": "rebombar",
    "rebombada": "rebombar",
    "rebombadas": "rebombar",
    "rebombado": "rebombar",
    "rebombados": "rebombar",
    "rebombai": "rebombar",
    "rebombais": "rebombar",
    "rebombam": "rebombar",
    "rebombamo": "rebombar",
    "rebombamos": "rebombar",
    "rebombando": "rebombar",
    "rebombara": "rebombar",
    "rebombaram": "rebombar",
    "rebombaras": "rebombar",
    "rebombardes": "rebombar",
    "rebombarei": "rebombar",
    "rebombareis": "rebombar",
    "rebombarem": "rebombar",
    "rebombaremos": "rebombar",
    "rebombares": "rebombar",
    "rebombaria": "rebombar",
    "rebombariam": "rebombar",
    "rebombarias": "rebombar",
    "rebombarmo": "rebombar",
    "rebombarmos": "rebombar",
    "rebombará": "rebombar",
    "rebombarás": "rebombar",
    "rebombarão": "rebombar",
    "rebombaríamos": "rebombar",
    "rebombaríeis": "rebombar",
    "rebombas": "rebombar",
    "rebombasse": "rebombar",
    "rebombassem": "rebombar",
    "rebombasses": "rebombar",
    "rebombaste": "rebombar",
    "rebombastes": "rebombar",
    "rebombava": "rebombar",
    "rebombavam": "rebombar",
    "rebombavas": "rebombar",
    "rebombe": "rebombar",
    "rebombei": "rebombar",
    "rebombeis": "rebombar",
    "rebombem": "rebombar",
    "rebombemo": "rebombar",
    "rebombemos": "rebombar",
    "rebombes": "rebombar",
    "rebombo": "rebombar",
    "rebombos": "rebombo",
    "rebombou": "rebombar",
    "rebombámo": "rebombar",
    "rebombámos": "rebombar",
    "rebombáramo": "rebombar",
    "rebombáramos": "rebombar",
    "rebombáreis": "rebombar",
    "rebombásseis": "rebombar",
    "rebombássemos": "rebombar",
    "rebombávamo": "rebombar",
    "rebombávamos": "rebombar",
    "rebombáveis": "rebombar",
    "reboo": "reboar",
    "reboos": "reboo",
    "reboou": "reboar",
    "reboque": "rebocar",
    "reboqueada": "reboquear",
    "reboqueadas": "reboquear",
    "reboqueado": "reboquear",
    "reboqueados": "reboquear",
    "reboqueai": "reboquear",
    "reboqueais": "reboquear",
    "reboqueamo": "reboquear",
    "reboqueamos": "reboquear",
    "reboqueando": "reboquear",
    "reboqueara": "reboquear",
    "reboquearam": "reboquear",
    "reboquearas": "reboquear",
    "reboquearde": "reboquear",
    "reboqueardes": "reboquear",
    "reboqueare": "reboquear",
    "reboquearei": "reboquear",
    "reboqueareis": "reboquear",
    "reboquearem": "reboquear",
    "reboquearemos": "reboquear",
    "reboqueares": "reboquear",
    "reboquearia": "reboquear",
    "reboqueariam": "reboquear",
    "reboquearias": "reboquear",
    "reboquearmo": "reboquear",
    "reboquearmos": "reboquear",
    "reboqueará": "reboquear",
    "reboquearás": "reboquear",
    "reboquearão": "reboquear",
    "reboquearíamos": "reboquear",
    "reboquearíeis": "reboquear",
    "reboqueasse": "reboquear",
    "reboqueassem": "reboquear",
    "reboqueasses": "reboquear",
    "reboqueaste": "reboquear",
    "reboqueastes": "reboquear",
    "reboqueava": "reboquear",
    "reboqueavam": "reboquear",
    "reboqueavas": "reboquear",
    "reboqueei": "reboquear",
    "reboqueeis": "reboquear",
    "reboqueemo": "reboquear",
    "reboqueemos": "reboquear",
    "reboquei": "rebocar",
    "reboqueia": "reboquear",
    "reboqueiam": "reboquear",
    "reboqueias": "reboquear",
    "reboqueie": "reboquear",
    "reboqueiem": "reboquear",
    "reboqueies": "reboquear",
    "reboqueio": "reboquear",
    "reboqueis": "rebocar",
    "reboquem": "rebocar",
    "reboquemo": "rebocar",
    "reboquemos": "rebocar",
    "reboqueou": "reboquear",
    "reboques": "reboque",
    "reboqueá": "reboquear",
    "reboqueámo": "reboquear",
    "reboqueámos": "reboquear",
    "reboqueáramo": "reboquear",
    "reboqueáramos": "reboquear",
    "reboqueárei": "reboquear",
    "reboqueáreis": "reboquear",
    "reboqueásseis": "reboquear",
    "reboqueássemos": "reboquear",
    "reboqueávamo": "reboquear",
    "reboqueávamos": "reboquear",
    "reboqueávei": "reboquear",
    "reboqueáveis": "reboquear",
    "reboras": "rebora",
    "reborações": "reboração",
    "reborda": "rebordar",
    "rebordada": "rebordar",
    "rebordadas": "rebordar",
    "rebordado": "rebordar",
    "rebordados": "rebordar",
    "rebordagens": "rebordagem",
    "rebordai": "rebordar",
    "rebordais": "rebordar",
    "rebordam": "rebordar",
    "rebordamo": "rebordar",
    "rebordamos": "rebordar",
    "rebordando": "rebordar",
    "rebordara": "rebordar",
    "rebordaram": "rebordar",
    "rebordaras": "rebordar",
    "rebordarde": "rebordar",
    "rebordardes": "rebordar",
    "rebordare": "rebordar",
    "rebordarei": "rebordar",
    "rebordareis": "rebordar",
    "rebordarem": "rebordar",
    "rebordaremos": "rebordar",
    "rebordares": "rebordar",
    "rebordaria": "rebordar",
    "rebordariam": "rebordar",
    "rebordarias": "rebordar",
    "rebordarmo": "rebordar",
    "rebordarmos": "rebordar",
    "rebordará": "rebordar",
    "rebordarás": "rebordar",
    "rebordarão": "rebordar",
    "rebordaríamos": "rebordar",
    "rebordaríeis": "rebordar",
    "rebordas": "rebordar",
    "rebordasse": "rebordar",
    "rebordassem": "rebordar",
    "rebordasses": "rebordar",
    "rebordaste": "rebordar",
    "rebordastes": "rebordar",
    "rebordava": "rebordar",
    "rebordavam": "rebordar",
    "rebordavas": "rebordar",
    "reborde": "rebordar",
    "rebordei": "rebordar",
    "rebordeis": "rebordar",
    "rebordem": "rebordar",
    "rebordemo": "rebordar",
    "rebordemos": "rebordar",
    "rebordes": "rebordar",
    "rebordo": "rebordar",
    "rebordona": "rebordão",
    "rebordonas": "rebordão",
    "rebordos": "rebordo",
    "rebordou": "rebordar",
    "rebordá": "rebordar",
    "rebordámo": "rebordar",
    "rebordámos": "rebordar",
    "rebordáramo": "rebordar",
    "rebordáramos": "rebordar",
    "rebordárei": "rebordar",
    "rebordáreis": "rebordar",
    "rebordásseis": "rebordar",
    "rebordássemos": "rebordar",
    "rebordávamo": "rebordar",
    "rebordávamos": "rebordar",
    "rebordávei": "rebordar",
    "rebordáveis": "rebordar",
    "rebordões": "rebordão",
    "rebos": "rebo",
    "rebota": "reboto",
    "rebotada": "rebotar",
    "rebotadas": "rebotar",
    "rebotado": "rebotar",
    "rebotados": "rebotar",
    "rebotai": "rebotar",
    "rebotais": "rebotar",
    "rebotalhos": "rebotalho",
    "rebotam": "rebotar",
    "rebotamo": "rebotar",
    "rebotamos": "rebotar",
    "rebotando": "rebotar",
    "rebotara": "rebotar",
    "rebotaram": "rebotar",
    "rebotaras": "rebotar",
    "rebotarde": "rebotar",
    "rebotardes": "rebotar",
    "rebotare": "rebotar",
    "rebotarei": "rebotar",
    "rebotareis": "rebotar",
    "rebotarem": "rebotar",
    "rebotaremos": "rebotar",
    "rebotares": "rebotar",
    "rebotaria": "rebotar",
    "rebotariam": "rebotar",
    "rebotarias": "rebotar",
    "rebotarmo": "rebotar",
    "rebotarmos": "rebotar",
    "rebotará": "rebotar",
    "rebotarás": "rebotar",
    "rebotarão": "rebotar",
    "rebotaríamos": "rebotar",
    "rebotaríeis": "rebotar",
    "rebotas": "reboto",
    "rebotasse": "rebotar",
    "rebotassem": "rebotar",
    "rebotasses": "rebotar",
    "rebotaste": "rebotar",
    "rebotastes": "rebotar",
    "rebotava": "rebotar",
    "rebotavam": "rebotar",
    "rebotavas": "rebotar",
    "rebote": "rebotar",
    "rebotei": "rebotar",
    "reboteis": "rebotar",
    "rebotem": "rebotar",
    "rebotemo": "rebotar",
    "rebotemos": "rebotar",
    "rebotes": "rebote",
    "reboto": "rebotar",
    "rebotos": "reboto",
    "rebotou": "rebotar",
    "rebotá": "rebotar",
    "rebotámo": "rebotar",
    "rebotámos": "rebotar",
    "rebotáramo": "rebotar",
    "rebotáramos": "rebotar",
    "rebotárei": "rebotar",
    "rebotáreis": "rebotar",
    "rebotásseis": "rebotar",
    "rebotássemos": "rebotar",
    "rebotávamo": "rebotar",
    "rebotávamos": "rebotar",
    "rebotávei": "rebotar",
    "rebotáveis": "rebotar",
    "rebou": "rebar",
    "reboámo": "reboar",
    "reboámos": "reboar",
    "reboáramo": "reboar",
    "reboáramos": "reboar",
    "reboáreis": "reboar",
    "reboásseis": "reboar",
    "reboássemos": "reboar",
    "reboávamo": "reboar",
    "reboávamos": "reboar",
    "reboáveis": "reboar",
    "rebrama": "rebramir",
    "rebramada": "rebramar",
    "rebramadas": "rebramar",
    "rebramado": "rebramar",
    "rebramados": "rebramar",
    "rebramai": "rebramar",
    "rebramais": "rebramir",
    "rebramam": "rebramir",
    "rebramamo": "rebramir",
    "rebramamos": "rebramir",
    "rebramando": "rebramar",
    "rebramara": "rebramar",
    "rebramaram": "rebramar",
    "rebramaras": "rebramar",
    "rebramardes": "rebramar",
    "rebramarei": "rebramar",
    "rebramareis": "rebramar",
    "rebramarem": "rebramar",
    "rebramaremos": "rebramar",
    "rebramares": "rebramar",
    "rebramaria": "rebramar",
    "rebramariam": "rebramar",
    "rebramarias": "rebramar",
    "rebramarmo": "rebramar",
    "rebramarmos": "rebramar",
    "rebramará": "rebramar",
    "rebramarás": "rebramar",
    "rebramarão": "rebramar",
    "rebramaríamos": "rebramar",
    "rebramaríeis": "rebramar",
    "rebramas": "rebramir",
    "rebramasse": "rebramar",
    "rebramassem": "rebramar",
    "rebramasses": "rebramar",
    "rebramaste": "rebramar",
    "rebramastes": "rebramar",
    "rebramava": "rebramar",
    "rebramavam": "rebramar",
    "rebramavas": "rebramar",
    "rebrame": "rebramir",
    "rebramei": "rebramar",
    "rebrameis": "rebramar",
    "rebramem": "rebramir",
    "rebramemo": "rebramar",
    "rebramemos": "rebramar",
    "rebrames": "rebramir",
    "rebrami": "rebramir",
    "rebramia": "rebramir",
    "rebramiam": "rebramir",
    "rebramias": "rebramir",
    "rebramida": "rebramir",
    "rebramidas": "rebramir",
    "rebramido": "rebramir",
    "rebramidos": "rebramir",
    "rebramimo": "rebramir",
    "rebramimos": "rebramir",
    "rebramindo": "rebramir",
    "rebramira": "rebramir",
    "rebramiram": "rebramir",
    "rebramiras": "rebramir",
    "rebramirdes": "rebramir",
    "rebramirei": "rebramir",
    "rebramireis": "rebramir",
    "rebramirem": "rebramir",
    "rebramiremos": "rebramir",
    "rebramires": "rebramir",
    "rebramiria": "rebramir",
    "rebramiriam": "rebramir",
    "rebramirias": "rebramir",
    "rebramirmo": "rebramir",
    "rebramirmos": "rebramir",
    "rebramirá": "rebramir",
    "rebramirás": "rebramir",
    "rebramirão": "rebramir",
    "rebramiríamos": "rebramir",
    "rebramiríeis": "rebramir",
    "rebramis": "rebramir",
    "rebramisse": "rebramir",
    "rebramissem": "rebramir",
    "rebramisses": "rebramir",
    "rebramiste": "rebramir",
    "rebramistes": "rebramir",
    "rebramiu": "rebramir",
    "rebramo": "rebramir",
    "rebramou": "rebramar",
    "rebramámo": "rebramar",
    "rebramámos": "rebramar",
    "rebramáramo": "rebramar",
    "rebramáramos": "rebramar",
    "rebramáreis": "rebramar",
    "rebramásseis": "rebramar",
    "rebramássemos": "rebramar",
    "rebramávamo": "rebramar",
    "rebramávamos": "rebramar",
    "rebramáveis": "rebramar",
    "rebramíamo": "rebramir",
    "rebramíamos": "rebramir",
    "rebramíeis": "rebramir",
    "rebramíramo": "rebramir",
    "rebramíramos": "rebramir",
    "rebramíreis": "rebramir",
    "rebramísseis": "rebramir",
    "rebramíssemos": "rebramir",
    "rebraços": "rebraço",
    "rebrilha": "rebrilhar",
    "rebrilhada": "rebrilhar",
    "rebrilhadas": "rebrilhar",
    "rebrilhado": "rebrilhar",
    "rebrilhados": "rebrilhar",
    "rebrilhai": "rebrilhar",
    "rebrilhais": "rebrilhar",
    "rebrilham": "rebrilhar",
    "rebrilhamo": "rebrilhar",
    "rebrilhamos": "rebrilhar",
    "rebrilhando": "rebrilhar",
    "rebrilhantes": "rebrilhante",
    "rebrilhara": "rebrilhar",
    "rebrilharam": "rebrilhar",
    "rebrilharas": "rebrilhar",
    "rebrilhardes": "rebrilhar",
    "rebrilharei": "rebrilhar",
    "rebrilhareis": "rebrilhar",
    "rebrilharem": "rebrilhar",
    "rebrilharemos": "rebrilhar",
    "rebrilhares": "rebrilhar",
    "rebrilharia": "rebrilhar",
    "rebrilhariam": "rebrilhar",
    "rebrilharias": "rebrilhar",
    "rebrilharmo": "rebrilhar",
    "rebrilharmos": "rebrilhar",
    "rebrilhará": "rebrilhar",
    "rebrilharás": "rebrilhar",
    "rebrilharão": "rebrilhar",
    "rebrilharíamos": "rebrilhar",
    "rebrilharíeis": "rebrilhar",
    "rebrilhas": "rebrilhar",
    "rebrilhasse": "rebrilhar",
    "rebrilhassem": "rebrilhar",
    "rebrilhasses": "rebrilhar",
    "rebrilhaste": "rebrilhar",
    "rebrilhastes": "rebrilhar",
    "rebrilhava": "rebrilhar",
    "rebrilhavam": "rebrilhar",
    "rebrilhavas": "rebrilhar",
    "rebrilhe": "rebrilhar",
    "rebrilhei": "rebrilhar",
    "rebrilheis": "rebrilhar",
    "rebrilhem": "rebrilhar",
    "rebrilhemo": "rebrilhar",
    "rebrilhemos": "rebrilhar",
    "rebrilhes": "rebrilhar",
    "rebrilho": "rebrilhar",
    "rebrilhos": "rebrilho",
    "rebrilhou": "rebrilhar",
    "rebrilhámo": "rebrilhar",
    "rebrilhámos": "rebrilhar",
    "rebrilháramo": "rebrilhar",
    "rebrilháramos": "rebrilhar",
    "rebrilháreis": "rebrilhar",
    "rebrilhásseis": "rebrilhar",
    "rebrilhássemos": "rebrilhar",
    "rebrilhávamo": "rebrilhar",
    "rebrilhávamos": "rebrilhar",
    "rebrilháveis": "rebrilhar",
    "rebula": "rebulir",
    "rebulais": "rebulir",
    "rebulam": "rebulir",
    "rebulamo": "rebulir",
    "rebulamos": "rebulir",
    "rebulas": "rebulir",
    "rebule": "rebulir",
    "rebulem": "rebulir",
    "rebules": "rebulir",
    "rebulha": "rebulhar",
    "rebulhada": "rebulhar",
    "rebulhadas": "rebulhar",
    "rebulhado": "rebulhar",
    "rebulhados": "rebulhar",
    "rebulhai": "rebulhar",
    "rebulhais": "rebulhar",
    "rebulham": "rebulhar",
    "rebulhamo": "rebulhar",
    "rebulhamos": "rebulhar",
    "rebulhando": "rebulhar",
    "rebulhara": "rebulhar",
    "rebulharam": "rebulhar",
    "rebulharas": "rebulhar",
    "rebulharde": "rebulhar",
    "rebulhardes": "rebulhar",
    "rebulhare": "rebulhar",
    "rebulharei": "rebulhar",
    "rebulhareis": "rebulhar",
    "rebulharem": "rebulhar",
    "rebulharemos": "rebulhar",
    "rebulhares": "rebulhar",
    "rebulharia": "rebulhar",
    "rebulhariam": "rebulhar",
    "rebulharias": "rebulhar",
    "rebulharmo": "rebulhar",
    "rebulharmos": "rebulhar",
    "rebulhará": "rebulhar",
    "rebulharás": "rebulhar",
    "rebulharão": "rebulhar",
    "rebulharíamos": "rebulhar",
    "rebulharíeis": "rebulhar",
    "rebulhas": "rebulhar",
    "rebulhasse": "rebulhar",
    "rebulhassem": "rebulhar",
    "rebulhasses": "rebulhar",
    "rebulhaste": "rebulhar",
    "rebulhastes": "rebulhar",
    "rebulhava": "rebulhar",
    "rebulhavam": "rebulhar",
    "rebulhavas": "rebulhar",
    "rebulhe": "rebulhar",
    "rebulhei": "rebulhar",
    "rebulheis": "rebulhar",
    "rebulhem": "rebulhar",
    "rebulhemo": "rebulhar",
    "rebulhemos": "rebulhar",
    "rebulhes": "rebulhar",
    "rebulho": "rebulhar",
    "rebulhou": "rebulhar",
    "rebulhá": "rebulhar",
    "rebulhámo": "rebulhar",
    "rebulhámos": "rebulhar",
    "rebulháramo": "rebulhar",
    "rebulháramos": "rebulhar",
    "rebulhárei": "rebulhar",
    "rebulháreis": "rebulhar",
    "rebulhásseis": "rebulhar",
    "rebulhássemos": "rebulhar",
    "rebulhávamo": "rebulhar",
    "rebulhávamos": "rebulhar",
    "rebulhávei": "rebulhar",
    "rebulháveis": "rebulhar",
    "rebuli": "rebulir",
    "rebulia": "rebulir",
    "rebuliam": "rebulir",
    "rebulias": "rebulir",
    "rebulida": "rebulir",
    "rebulidas": "rebulir",
    "rebulido": "rebulir",
    "rebulidos": "rebulir",
    "rebulimo": "rebulir",
    "rebulimos": "rebulir",
    "rebulindo": "rebulir",
    "rebulira": "rebulir",
    "rebuliram": "rebulir",
    "rebuliras": "rebulir",
    "rebulirde": "rebulir",
    "rebulirdes": "rebulir",
    "rebulire": "rebulir",
    "rebulirei": "rebulir",
    "rebulireis": "rebulir",
    "rebulirem": "rebulir",
    "rebuliremos": "rebulir",
    "rebulires": "rebulir",
    "rebuliria": "rebulir",
    "rebuliriam": "rebulir",
    "rebulirias": "rebulir",
    "rebulirmo": "rebulir",
    "rebulirmos": "rebulir",
    "rebulirá": "rebulir",
    "rebulirás": "rebulir",
    "rebulirão": "rebulir",
    "rebuliríamos": "rebulir",
    "rebuliríeis": "rebulir",
    "rebulis": "rebulir",
    "rebulisse": "rebulir",
    "rebulissem": "rebulir",
    "rebulisses": "rebulir",
    "rebuliste": "rebulir",
    "rebulistes": "rebulir",
    "rebuliu": "rebulir",
    "rebuliços": "rebuliço",
    "rebulo": "rebulir",
    "rebulíamo": "rebulir",
    "rebulíamos": "rebulir",
    "rebulícios": "rebulício",
    "rebulíei": "rebulir",
    "rebulíeis": "rebulir",
    "rebulíramo": "rebulir",
    "rebulíramos": "rebulir",
    "rebulírei": "rebulir",
    "rebulíreis": "rebulir",
    "rebulísseis": "rebulir",
    "rebulíssemos": "rebulir",
    "rebusca": "rebuscar",
    "rebuscada": "rebuscar",
    "rebuscadas": "rebuscar",
    "rebuscadazinha": "rebuscado",
    "rebuscadazinhas": "rebuscado",
    "rebuscadazita": "rebuscado",
    "rebuscadazitas": "rebuscado",
    "rebuscadinha": "rebuscado",
    "rebuscadinhas": "rebuscado",
    "rebuscadinho": "rebuscado",
    "rebuscadinhos": "rebuscado",
    "rebuscadita": "rebuscado",
    "rebuscaditas": "rebuscado",
    "rebuscadito": "rebuscado",
    "rebuscaditos": "rebuscado",
    "rebuscado": "rebuscar",
    "rebuscados": "rebuscar",
    "rebuscadozinho": "rebuscado",
    "rebuscadozinhos": "rebuscado",
    "rebuscadozito": "rebuscado",
    "rebuscadozitos": "rebuscado",
    "rebuscadíssima": "rebuscado",
    "rebuscadíssimas": "rebuscado",
    "rebuscadíssimo": "rebuscado",
    "rebuscadíssimos": "rebuscado",
    "rebuscai": "rebuscar",
    "rebuscais": "rebuscar",
    "rebuscam": "rebuscar",
    "rebuscamo": "rebuscar",
    "rebuscamos": "rebuscar",
    "rebuscando": "rebuscar",
    "rebuscara": "rebuscar",
    "rebuscaram": "rebuscar",
    "rebuscaras": "rebuscar",
    "rebuscarde": "rebuscar",
    "rebuscardes": "rebuscar",
    "rebuscare": "rebuscar",
    "rebuscarei": "rebuscar",
    "rebuscareis": "rebuscar",
    "rebuscarem": "rebuscar",
    "rebuscaremos": "rebuscar",
    "rebuscares": "rebuscar",
    "rebuscaria": "rebuscar",
    "rebuscariam": "rebuscar",
    "rebuscarias": "rebuscar",
    "rebuscarmo": "rebuscar",
    "rebuscarmos": "rebuscar",
    "rebuscará": "rebuscar",
    "rebuscarás": "rebuscar",
    "rebuscarão": "rebuscar",
    "rebuscaríamos": "rebuscar",
    "rebuscaríeis": "rebuscar",
    "rebuscas": "rebuscar",
    "rebuscasse": "rebuscar",
    "rebuscassem": "rebuscar",
    "rebuscasses": "rebuscar",
    "rebuscaste": "rebuscar",
    "rebuscastes": "rebuscar",
    "rebuscava": "rebuscar",
    "rebuscavam": "rebuscar",
    "rebuscavas": "rebuscar",
    "rebusco": "rebuscar",
    "rebuscos": "rebusco",
    "rebuscou": "rebuscar",
    "rebuscá": "rebuscar",
    "rebuscámo": "rebuscar",
    "rebuscámos": "rebuscar",
    "rebuscáramo": "rebuscar",
    "rebuscáramos": "rebuscar",
    "rebuscárei": "rebuscar",
    "rebuscáreis": "rebuscar",
    "rebuscásseis": "rebuscar",
    "rebuscássemos": "rebuscar",
    "rebuscávamo": "rebuscar",
    "rebuscávamos": "rebuscar",
    "rebuscávei": "rebuscar",
    "rebuscáveis": "rebuscar",
    "rebusna": "rebusnar",
    "rebusnada": "rebusnar",
    "rebusnadas": "rebusnar",
    "rebusnado": "rebusnar",
    "rebusnados": "rebusnar",
    "rebusnai": "rebusnar",
    "rebusnais": "rebusnar",
    "rebusnam": "rebusnar",
    "rebusnamo": "rebusnar",
    "rebusnamos": "rebusnar",
    "rebusnando": "rebusnar",
    "rebusnara": "rebusnar",
    "rebusnaram": "rebusnar",
    "rebusnaras": "rebusnar",
    "rebusnardes": "rebusnar",
    "rebusnarei": "rebusnar",
    "rebusnareis": "rebusnar",
    "rebusnarem": "rebusnar",
    "rebusnaremos": "rebusnar",
    "rebusnares": "rebusnar",
    "rebusnaria": "rebusnar",
    "rebusnariam": "rebusnar",
    "rebusnarias": "rebusnar",
    "rebusnarmo": "rebusnar",
    "rebusnarmos": "rebusnar",
    "rebusnará": "rebusnar",
    "rebusnarás": "rebusnar",
    "rebusnarão": "rebusnar",
    "rebusnaríamos": "rebusnar",
    "rebusnaríeis": "rebusnar",
    "rebusnas": "rebusnar",
    "rebusnasse": "rebusnar",
    "rebusnassem": "rebusnar",
    "rebusnasses": "rebusnar",
    "rebusnaste": "rebusnar",
    "rebusnastes": "rebusnar",
    "rebusnava": "rebusnar",
    "rebusnavam": "rebusnar",
    "rebusnavas": "rebusnar",
    "rebusne": "rebusnar",
    "rebusnei": "rebusnar",
    "rebusneis": "rebusnar",
    "rebusnem": "rebusnar",
    "rebusnemo": "rebusnar",
    "rebusnemos": "rebusnar",
    "rebusnes": "rebusnar",
    "rebusno": "rebusnar",
    "rebusnos": "rebusno",
    "rebusnou": "rebusnar",
    "rebusnámo": "rebusnar",
    "rebusnámos": "rebusnar",
    "rebusnáramo": "rebusnar",
    "rebusnáramos": "rebusnar",
    "rebusnáreis": "rebusnar",
    "rebusnásseis": "rebusnar",
    "rebusnássemos": "rebusnar",
    "rebusnávamo": "rebusnar",
    "rebusnávamos": "rebusnar",
    "rebusnáveis": "rebusnar",
    "rebusque": "rebuscar",
    "rebusquei": "rebuscar",
    "rebusqueira": "rebusqueiro",
    "rebusqueiras": "rebusqueiro",
    "rebusqueiros": "rebusqueiro",
    "rebusqueis": "rebuscar",
    "rebusquem": "rebuscar",
    "rebusquemo": "rebuscar",
    "rebusquemos": "rebuscar",
    "rebusques": "rebuscar",
    "rebuçada": "rebuçado",
    "rebuçadas": "rebuçado",
    "rebuçadinho": "rebuçado",
    "rebuçadinhos": "rebuçado",
    "rebuçadito": "rebuçado",
    "rebuçaditos": "rebuçado",
    "rebuçados": "rebuçado",
    "rebuços": "rebuço",
    "rebá": "rebar",
    "rebámo": "rebar",
    "rebámos": "rebar",
    "rebáramo": "rebar",
    "rebáramos": "rebar",
    "rebárei": "rebar",
    "rebáreis": "rebar",
    "rebásseis": "rebar",
    "rebássemos": "rebar",
    "rebávamo": "rebar",
    "rebávamos": "rebar",
    "rebávei": "rebar",
    "rebáveis": "rebar",
    "rebéns": "rebém",
    "recacha": "recachar",
    "recachada": "recachar",
    "recachadas": "recachar",
    "recachado": "recachar",
    "recachados": "recachar",
    "recachai": "recachar",
    "recachais": "recachar",
    "recacham": "recachar",
    "recachamo": "recachar",
    "recachamos": "recachar",
    "recachando": "recachar",
    "recachara": "recachar",
    "recacharam": "recachar",
    "recacharas": "recachar",
    "recacharde": "recachar",
    "recachardes": "recachar",
    "recachare": "recachar",
    "recacharei": "recachar",
    "recachareis": "recachar",
    "recacharem": "recachar",
    "recacharemos": "recachar",
    "recachares": "recachar",
    "recacharia": "recachar",
    "recachariam": "recachar",
    "recacharias": "recachar",
    "recacharmo": "recachar",
    "recacharmos": "recachar",
    "recachará": "recachar",
    "recacharás": "recachar",
    "recacharão": "recachar",
    "recacharíamos": "recachar",
    "recacharíeis": "recachar",
    "recachas": "recachar",
    "recachasse": "recachar",
    "recachassem": "recachar",
    "recachasses": "recachar",
    "recachaste": "recachar",
    "recachastes": "recachar",
    "recachava": "recachar",
    "recachavam": "recachar",
    "recachavas": "recachar",
    "recache": "recachar",
    "recachei": "recachar",
    "recacheis": "recachar",
    "recachem": "recachar",
    "recachemo": "recachar",
    "recachemos": "recachar",
    "recaches": "recachar",
    "recacho": "recachar",
    "recachos": "recacho",
    "recachou": "recachar",
    "recachá": "recachar",
    "recachámo": "recachar",
    "recachámos": "recachar",
    "recacháramo": "recachar",
    "recacháramos": "recachar",
    "recachárei": "recachar",
    "recacháreis": "recachar",
    "recachásseis": "recachar",
    "recachássemos": "recachar",
    "recachávamo": "recachar",
    "recachávamos": "recachar",
    "recachávei": "recachar",
    "recacháveis": "recachar",
    "recada": "recadar",
    "recadada": "recadar",
    "recadadas": "recadar",
    "recadado": "recadar",
    "recadados": "recadar",
    "recadai": "recadar",
    "recadais": "recadar",
    "recadam": "recadar",
    "recadamo": "recadar",
    "recadamos": "recadar",
    "recadando": "recadar",
    "recadara": "recadar",
    "recadaram": "recadar",
    "recadaras": "recadar",
    "recadarde": "recadar",
    "recadardes": "recadar",
    "recadare": "recadar",
    "recadarei": "recadar",
    "recadareis": "recadar",
    "recadarem": "recadar",
    "recadaremos": "recadar",
    "recadares": "recadar",
    "recadaria": "recadar",
    "recadariam": "recadar",
    "recadarias": "recadar",
    "recadarmo": "recadar",
    "recadarmos": "recadar",
    "recadará": "recadar",
    "recadarás": "recadar",
    "recadarão": "recadar",
    "recadaríamos": "recadar",
    "recadaríeis": "recadar",
    "recadas": "recadar",
    "recadasse": "recadar",
    "recadassem": "recadar",
    "recadasses": "recadar",
    "recadaste": "recadar",
    "recadastes": "recadar",
    "recadava": "recadar",
    "recadavam": "recadar",
    "recadavas": "recadar",
    "recade": "recadar",
    "recadeada": "recadear",
    "recadeadas": "recadear",
    "recadeado": "recadear",
    "recadeados": "recadear",
    "recadeai": "recadear",
    "recadeais": "recadear",
    "recadeamo": "recadear",
    "recadeamos": "recadear",
    "recadeando": "recadear",
    "recadeara": "recadear",
    "recadearam": "recadear",
    "recadearas": "recadear",
    "recadeardes": "recadear",
    "recadearei": "recadear",
    "recadeareis": "recadear",
    "recadearem": "recadear",
    "recadearemos": "recadear",
    "recadeares": "recadear",
    "recadearia": "recadear",
    "recadeariam": "recadear",
    "recadearias": "recadear",
    "recadearmo": "recadear",
    "recadearmos": "recadear",
    "recadeará": "recadear",
    "recadearás": "recadear",
    "recadearão": "recadear",
    "recadearíamos": "recadear",
    "recadearíeis": "recadear",
    "recadeasse": "recadear",
    "recadeassem": "recadear",
    "recadeasses": "recadear",
    "recadeaste": "recadear",
    "recadeastes": "recadear",
    "recadeava": "recadear",
    "recadeavam": "recadear",
    "recadeavas": "recadear",
    "recadeei": "recadear",
    "recadeeis": "recadear",
    "recadeemo": "recadear",
    "recadeemos": "recadear",
    "recadei": "recadar",
    "recadeia": "recadear",
    "recadeiam": "recadear",
    "recadeias": "recadear",
    "recadeie": "recadear",
    "recadeiem": "recadear",
    "recadeies": "recadear",
    "recadeio": "recadear",
    "recadeira": "recadeiro",
    "recadeiras": "recadeiro",
    "recadeiros": "recadeiro",
    "recadeis": "recadar",
    "recadem": "recadar",
    "recademo": "recadar",
    "recademos": "recadar",
    "recadeou": "recadear",
    "recades": "recadar",
    "recadetes": "recadete",
    "recadeámo": "recadear",
    "recadeámos": "recadear",
    "recadeáramo": "recadear",
    "recadeáramos": "recadear",
    "recadeáreis": "recadear",
    "recadeásseis": "recadear",
    "recadeássemos": "recadear",
    "recadeávamo": "recadear",
    "recadeávamos": "recadear",
    "recadeáveis": "recadear",
    "recadinho": "recado",
    "recadinhos": "recado",
    "recadistas": "recadista",
    "recadito": "recado",
    "recaditos": "recado",
    "recado": "recadar",
    "recados": "recado",
    "recadou": "recadar",
    "recadá": "recadar",
    "recadámo": "recadar",
    "recadámos": "recadar",
    "recadáramo": "recadar",
    "recadáramos": "recadar",
    "recadárei": "recadar",
    "recadáreis": "recadar",
    "recadásseis": "recadar",
    "recadássemos": "recadar",
    "recadávamo": "recadar",
    "recadávamos": "recadar",
    "recadávei": "recadar",
    "recadáveis": "recadar",
    "recadéns": "recadém",
    "recaem": "recair",
    "recai": "recair",
    "recaia": "recair",
    "recaiais": "recair",
    "recaiam": "recair",
    "recaiamo": "recair",
    "recaiamos": "recair",
    "recaias": "recair",
    "recaidazinha": "recaída",
    "recaidazinhas": "recaída",
    "recaidazita": "recaída",
    "recaidazitas": "recaída",
    "recaidiça": "recaidiço",
    "recaidiças": "recaidiço",
    "recaidiços": "recaidiço",
    "recaimentos": "recaimento",
    "recaimões": "recaimão",
    "recaindo": "recair",
    "recaio": "recair",
    "recairdes": "recair",
    "recairei": "recair",
    "recaireis": "recair",
    "recairemos": "recair",
    "recairia": "recair",
    "recairiam": "recair",
    "recairias": "recair",
    "recairmo": "recair",
    "recairmos": "recair",
    "recairá": "recair",
    "recairás": "recair",
    "recairão": "recair",
    "recairíamos": "recair",
    "recairíeis": "recair",
    "recais": "recair",
    "recaiu": "recair",
    "recalca": "recalcar",
    "recalcada": "recalcar",
    "recalcadas": "recalcar",
    "recalcado": "recalcar",
    "recalcadora": "recalcador",
    "recalcadoras": "recalcador",
    "recalcadores": "recalcador",
    "recalcados": "recalcar",
    "recalcadíssima": "recalcado",
    "recalcadíssimas": "recalcado",
    "recalcadíssimo": "recalcado",
    "recalcadíssimos": "recalcado",
    "recalcai": "recalcar",
    "recalcais": "recalcar",
    "recalcam": "recalcar",
    "recalcamentos": "recalcamento",
    "recalcamo": "recalcar",
    "recalcamos": "recalcar",
    "recalcando": "recalcar",
    "recalcara": "recalcar",
    "recalcaram": "recalcar",
    "recalcaras": "recalcar",
    "recalcarde": "recalcar",
    "recalcardes": "recalcar",
    "recalcare": "recalcar",
    "recalcarei": "recalcar",
    "recalcareis": "recalcar",
    "recalcarem": "recalcar",
    "recalcaremos": "recalcar",
    "recalcares": "recalcar",
    "recalcaria": "recalcar",
    "recalcariam": "recalcar",
    "recalcarias": "recalcar",
    "recalcarmo": "recalcar",
    "recalcarmos": "recalcar",
    "recalcará": "recalcar",
    "recalcarás": "recalcar",
    "recalcarão": "recalcar",
    "recalcaríamos": "recalcar",
    "recalcaríeis": "recalcar",
    "recalcas": "recalcar",
    "recalcasse": "recalcar",
    "recalcassem": "recalcar",
    "recalcasses": "recalcar",
    "recalcaste": "recalcar",
    "recalcastes": "recalcar",
    "recalcava": "recalcar",
    "recalcavam": "recalcar",
    "recalcavas": "recalcar",
    "recalcifica": "recalcificar",
    "recalcificada": "recalcificar",
    "recalcificadas": "recalcificar",
    "recalcificado": "recalcificar",
    "recalcificadora": "recalcificador",
    "recalcificadoras": "recalcificador",
    "recalcificadores": "recalcificador",
    "recalcificados": "recalcificar",
    "recalcificai": "recalcificar",
    "recalcificais": "recalcificar",
    "recalcificam": "recalcificar",
    "recalcificamo": "recalcificar",
    "recalcificamos": "recalcificar",
    "recalcificando": "recalcificar",
    "recalcificantes": "recalcificante",
    "recalcificara": "recalcificar",
    "recalcificaram": "recalcificar",
    "recalcificaras": "recalcificar",
    "recalcificarde": "recalcificar",
    "recalcificardes": "recalcificar",
    "recalcificare": "recalcificar",
    "recalcificarei": "recalcificar",
    "recalcificareis": "recalcificar",
    "recalcificarem": "recalcificar",
    "recalcificaremos": "recalcificar",
    "recalcificares": "recalcificar",
    "recalcificaria": "recalcificar",
    "recalcificariam": "recalcificar",
    "recalcificarias": "recalcificar",
    "recalcificarmo": "recalcificar",
    "recalcificarmos": "recalcificar",
    "recalcificará": "recalcificar",
    "recalcificarás": "recalcificar",
    "recalcificarão": "recalcificar",
    "recalcificaríamos": "recalcificar",
    "recalcificaríeis": "recalcificar",
    "recalcificas": "recalcificar",
    "recalcificasse": "recalcificar",
    "recalcificassem": "recalcificar",
    "recalcificasses": "recalcificar",
    "recalcificaste": "recalcificar",
    "recalcificastes": "recalcificar",
    "recalcificava": "recalcificar",
    "recalcificavam": "recalcificar",
    "recalcificavas": "recalcificar",
    "recalcificações": "recalcificação",
    "recalcifico": "recalcificar",
    "recalcificou": "recalcificar",
    "recalcificá": "recalcificar",
    "recalcificámo": "recalcificar",
    "recalcificámos": "recalcificar",
    "recalcificáramo": "recalcificar",
    "recalcificáramos": "recalcificar",
    "recalcificárei": "recalcificar",
    "recalcificáreis": "recalcificar",
    "recalcificásseis": "recalcificar",
    "recalcificássemos": "recalcificar",
    "recalcificávamo": "recalcificar",
    "recalcificávamos": "recalcificar",
    "recalcificávei": "recalcificar",
    "recalcificáveis": "recalcificar",
    "recalcifique": "recalcificar",
    "recalcifiquei": "recalcificar",
    "recalcifiqueis": "recalcificar",
    "recalcifiquem": "recalcificar",
    "recalcifiquemo": "recalcificar",
    "recalcifiquemos": "recalcificar",
    "recalcifiques": "recalcificar",
    "recalcitra": "recalcitrar",
    "recalcitrada": "recalcitrar",
    "recalcitradas": "recalcitrar",
    "recalcitrado": "recalcitrar",
    "recalcitrados": "recalcitrar",
    "recalcitrai": "recalcitrar",
    "recalcitrais": "recalcitrar",
    "recalcitram": "recalcitrar",
    "recalcitramo": "recalcitrar",
    "recalcitramos": "recalcitrar",
    "recalcitrando": "recalcitrar",
    "recalcitrantes": "recalcitrante",
    "recalcitrara": "recalcitrar",
    "recalcitraram": "recalcitrar",
    "recalcitraras": "recalcitrar",
    "recalcitrardes": "recalcitrar",
    "recalcitrarei": "recalcitrar",
    "recalcitrareis": "recalcitrar",
    "recalcitrarem": "recalcitrar",
    "recalcitraremos": "recalcitrar",
    "recalcitrares": "recalcitrar",
    "recalcitraria": "recalcitrar",
    "recalcitrariam": "recalcitrar",
    "recalcitrarias": "recalcitrar",
    "recalcitrarmo": "recalcitrar",
    "recalcitrarmos": "recalcitrar",
    "recalcitrará": "recalcitrar",
    "recalcitrarás": "recalcitrar",
    "recalcitrarão": "recalcitrar",
    "recalcitraríamos": "recalcitrar",
    "recalcitraríeis": "recalcitrar",
    "recalcitras": "recalcitrar",
    "recalcitrasse": "recalcitrar",
    "recalcitrassem": "recalcitrar",
    "recalcitrasses": "recalcitrar",
    "recalcitraste": "recalcitrar",
    "recalcitrastes": "recalcitrar",
    "recalcitrava": "recalcitrar",
    "recalcitravam": "recalcitrar",
    "recalcitravas": "recalcitrar",
    "recalcitrações": "recalcitração",
    "recalcitre": "recalcitrar",
    "recalcitrei": "recalcitrar",
    "recalcitreis": "recalcitrar",
    "recalcitrem": "recalcitrar",
    "recalcitremo": "recalcitrar",
    "recalcitremos": "recalcitrar",
    "recalcitres": "recalcitrar",
    "recalcitro": "recalcitrar",
    "recalcitrou": "recalcitrar",
    "recalcitrámo": "recalcitrar",
    "recalcitrámos": "recalcitrar",
    "recalcitráramo": "recalcitrar",
    "recalcitráramos": "recalcitrar",
    "recalcitráreis": "recalcitrar",
    "recalcitrásseis": "recalcitrar",
    "recalcitrássemos": "recalcitrar",
    "recalcitrávamo": "recalcitrar",
    "recalcitrávamos": "recalcitrar",
    "recalcitráveis": "recalcitrar",
    "recalco": "recalcar",
    "recalcou": "recalcar",
    "recalcula": "recalcular",
    "recalculada": "recalcular",
    "recalculadas": "recalcular",
    "recalculado": "recalcular",
    "recalculados": "recalcular",
    "recalculai": "recalcular",
    "recalculais": "recalcular",
    "recalculam": "recalcular",
    "recalculamo": "recalcular",
    "recalculamos": "recalcular",
    "recalculando": "recalcular",
    "recalculara": "recalcular",
    "recalcularam": "recalcular",
    "recalcularas": "recalcular",
    "recalcularde": "recalcular",
    "recalculardes": "recalcular",
    "recalculare": "recalcular",
    "recalcularei": "recalcular",
    "recalculareis": "recalcular",
    "recalcularem": "recalcular",
    "recalcularemos": "recalcular",
    "recalculares": "recalcular",
    "recalcularia": "recalcular",
    "recalculariam": "recalcular",
    "recalcularias": "recalcular",
    "recalcularmo": "recalcular",
    "recalcularmos": "recalcular",
    "recalculará": "recalcular",
    "recalcularás": "recalcular",
    "recalcularão": "recalcular",
    "recalcularíamos": "recalcular",
    "recalcularíeis": "recalcular",
    "recalculas": "recalcular",
    "recalculasse": "recalcular",
    "recalculassem": "recalcular",
    "recalculasses": "recalcular",
    "recalculaste": "recalcular",
    "recalculastes": "recalcular",
    "recalculava": "recalcular",
    "recalculavam": "recalcular",
    "recalculavas": "recalcular",
    "recalcule": "recalcular",
    "recalculei": "recalcular",
    "recalculeis": "recalcular",
    "recalculem": "recalcular",
    "recalculemo": "recalcular",
    "recalculemos": "recalcular",
    "recalcules": "recalcular",
    "recalculo": "recalcular",
    "recalculou": "recalcular",
    "recalculá": "recalcular",
    "recalculámo": "recalcular",
    "recalculámos": "recalcular",
    "recalculáramo": "recalcular",
    "recalculáramos": "recalcular",
    "recalculárei": "recalcular",
    "recalculáreis": "recalcular",
    "recalculásseis": "recalcular",
    "recalculássemos": "recalcular",
    "recalculávamo": "recalcular",
    "recalculávamos": "recalcular",
    "recalculávei": "recalcular",
    "recalculáveis": "recalcular",
    "recalcá": "recalcar",
    "recalcámo": "recalcar",
    "recalcámos": "recalcar",
    "recalcáramo": "recalcar",
    "recalcáramos": "recalcar",
    "recalcárei": "recalcar",
    "recalcáreis": "recalcar",
    "recalcásseis": "recalcar",
    "recalcássemos": "recalcar",
    "recalcávamo": "recalcar",
    "recalcávamos": "recalcar",
    "recalcávei": "recalcar",
    "recalcáveis": "recalcável",
    "recaldeada": "recaldear",
    "recaldeadas": "recaldear",
    "recaldeado": "recaldear",
    "recaldeados": "recaldear",
    "recaldeai": "recaldear",
    "recaldeais": "recaldear",
    "recaldeamo": "recaldear",
    "recaldeamos": "recaldear",
    "recaldeando": "recaldear",
    "recaldeara": "recaldear",
    "recaldearam": "recaldear",
    "recaldearas": "recaldear",
    "recaldearde": "recaldear",
    "recaldeardes": "recaldear",
    "recaldeare": "recaldear",
    "recaldearei": "recaldear",
    "recaldeareis": "recaldear",
    "recaldearem": "recaldear",
    "recaldearemos": "recaldear",
    "recaldeares": "recaldear",
    "recaldearia": "recaldear",
    "recaldeariam": "recaldear",
    "recaldearias": "recaldear",
    "recaldearmo": "recaldear",
    "recaldearmos": "recaldear",
    "recaldeará": "recaldear",
    "recaldearás": "recaldear",
    "recaldearão": "recaldear",
    "recaldearíamos": "recaldear",
    "recaldearíeis": "recaldear",
    "recaldeasse": "recaldear",
    "recaldeassem": "recaldear",
    "recaldeasses": "recaldear",
    "recaldeaste": "recaldear",
    "recaldeastes": "recaldear",
    "recaldeava": "recaldear",
    "recaldeavam": "recaldear",
    "recaldeavas": "recaldear",
    "recaldeei": "recaldear",
    "recaldeeis": "recaldear",
    "recaldeemo": "recaldear",
    "recaldeemos": "recaldear",
    "recaldeia": "recaldear",
    "recaldeiam": "recaldear",
    "recaldeias": "recaldear",
    "recaldeie": "recaldear",
    "recaldeiem": "recaldear",
    "recaldeies": "recaldear",
    "recaldeio": "recaldear",
    "recaldeou": "recaldear",
    "recaldeá": "recaldear",
    "recaldeámo": "recaldear",
    "recaldeámos": "recaldear",
    "recaldeáramo": "recaldear",
    "recaldeáramos": "recaldear",
    "recaldeárei": "recaldear",
    "recaldeáreis": "recaldear",
    "recaldeásseis": "recaldear",
    "recaldeássemos": "recaldear",
    "recaldeávamo": "recaldear",
    "recaldeávamos": "recaldear",
    "recaldeávei": "recaldear",
    "recaldeáveis": "recaldear",
    "recalendarizações": "recalendarização",
    "recalescentes": "recalescente",
    "recalescências": "recalescência",
    "recalmões": "recalmão",
    "recalque": "recalcar",
    "recalquei": "recalcar",
    "recalqueis": "recalcar",
    "recalquem": "recalcar",
    "recalquemo": "recalcar",
    "recalquemos": "recalcar",
    "recalques": "recalque",
    "recama": "recamar",
    "recamada": "recamar",
    "recamadas": "recamar",
    "recamado": "recamar",
    "recamadora": "recamador",
    "recamadoras": "recamador",
    "recamadores": "recamador",
    "recamados": "recamar",
    "recamaduras": "recamadura",
    "recamai": "recamar",
    "recamais": "recamar",
    "recamam": "recamar",
    "recamamo": "recamar",
    "recamamos": "recamar",
    "recamando": "recamar",
    "recamara": "recamar",
    "recamaram": "recamar",
    "recamaras": "recamar",
    "recamarde": "recamar",
    "recamardes": "recamar",
    "recamare": "recamar",
    "recamarei": "recamar",
    "recamareis": "recamar",
    "recamarem": "recamar",
    "recamaremos": "recamar",
    "recamares": "recamar",
    "recamaria": "recamar",
    "recamariam": "recamar",
    "recamarias": "recamar",
    "recamarmo": "recamar",
    "recamarmos": "recamar",
    "recamará": "recamar",
    "recamarás": "recamar",
    "recamarão": "recamar",
    "recamaríamos": "recamar",
    "recamaríeis": "recamar",
    "recamas": "recamar",
    "recamasse": "recamar",
    "recamassem": "recamar",
    "recamasses": "recamar",
    "recamaste": "recamar",
    "recamastes": "recamar",
    "recamava": "recamar",
    "recamavam": "recamar",
    "recamavas": "recamar",
    "recambia": "recambiar",
    "recambiada": "recambiar",
    "recambiadas": "recambiar",
    "recambiado": "recambiar",
    "recambiados": "recambiar",
    "recambiai": "recambiar",
    "recambiais": "recambiar",
    "recambiam": "recambiar",
    "recambiamo": "recambiar",
    "recambiamos": "recambiar",
    "recambiando": "recambiar",
    "recambiara": "recambiar",
    "recambiaram": "recambiar",
    "recambiaras": "recambiar",
    "recambiarde": "recambiar",
    "recambiardes": "recambiar",
    "recambiare": "recambiar",
    "recambiarei": "recambiar",
    "recambiareis": "recambiar",
    "recambiarem": "recambiar",
    "recambiaremos": "recambiar",
    "recambiares": "recambiar",
    "recambiaria": "recambiar",
    "recambiariam": "recambiar",
    "recambiarias": "recambiar",
    "recambiarmo": "recambiar",
    "recambiarmos": "recambiar",
    "recambiará": "recambiar",
    "recambiarás": "recambiar",
    "recambiarão": "recambiar",
    "recambiaríamos": "recambiar",
    "recambiaríeis": "recambiar",
    "recambias": "recambiar",
    "recambiasse": "recambiar",
    "recambiassem": "recambiar",
    "recambiasses": "recambiar",
    "recambiaste": "recambiar",
    "recambiastes": "recambiar",
    "recambiava": "recambiar",
    "recambiavam": "recambiar",
    "recambiavas": "recambiar",
    "recambie": "recambiar",
    "recambiei": "recambiar",
    "recambieis": "recambiar",
    "recambiem": "recambiar",
    "recambiemo": "recambiar",
    "recambiemos": "recambiar",
    "recambies": "recambiar",
    "recambio": "recambiar",
    "recambiou": "recambiar",
    "recambiá": "recambiar",
    "recambiámo": "recambiar",
    "recambiámos": "recambiar",
    "recambiáramo": "recambiar",
    "recambiáramos": "recambiar",
    "recambiárei": "recambiar",
    "recambiáreis": "recambiar",
    "recambiásseis": "recambiar",
    "recambiássemos": "recambiar",
    "recambiávamo": "recambiar",
    "recambiávamos": "recambiar",
    "recambiávei": "recambiar",
    "recambiáveis": "recambiável",
    "recambós": "recambó",
    "recame": "recamar",
    "recamei": "recamar",
    "recameis": "recamar",
    "recamem": "recamar",
    "recamemo": "recamar",
    "recamemos": "recamar",
    "recames": "recamar",
    "recamo": "recamar",
    "recamos": "recamo",
    "recamou": "recamar",
    "recamá": "recamar",
    "recamámo": "recamar",
    "recamámos": "recamar",
    "recamáramo": "recamar",
    "recamáramos": "recamar",
    "recamárei": "recamar",
    "recamáreis": "recamar",
    "recamásseis": "recamar",
    "recamássemos": "recamar",
    "recamávamo": "recamar",
    "recamávamos": "recamar",
    "recamávei": "recamar",
    "recamáveis": "recamar",
    "recandidata": "recandidatar",
    "recandidatada": "recandidatar",
    "recandidatadas": "recandidatar",
    "recandidatado": "recandidatar",
    "recandidatados": "recandidatar",
    "recandidatai": "recandidatar",
    "recandidatais": "recandidatar",
    "recandidatam": "recandidatar",
    "recandidatamo": "recandidatar",
    "recandidatamos": "recandidatar",
    "recandidatando": "recandidatar",
    "recandidatara": "recandidatar",
    "recandidataram": "recandidatar",
    "recandidataras": "recandidatar",
    "recandidatarde": "recandidatar",
    "recandidatardes": "recandidatar",
    "recandidatare": "recandidatar",
    "recandidatarei": "recandidatar",
    "recandidatareis": "recandidatar",
    "recandidatarem": "recandidatar",
    "recandidataremos": "recandidatar",
    "recandidatares": "recandidatar",
    "recandidataria": "recandidatar",
    "recandidatariam": "recandidatar",
    "recandidatarias": "recandidatar",
    "recandidatarmo": "recandidatar",
    "recandidatarmos": "recandidatar",
    "recandidatará": "recandidatar",
    "recandidatarás": "recandidatar",
    "recandidatarão": "recandidatar",
    "recandidataríamos": "recandidatar",
    "recandidataríeis": "recandidatar",
    "recandidatas": "recandidatar",
    "recandidatasse": "recandidatar",
    "recandidatassem": "recandidatar",
    "recandidatasses": "recandidatar",
    "recandidataste": "recandidatar",
    "recandidatastes": "recandidatar",
    "recandidatava": "recandidatar",
    "recandidatavam": "recandidatar",
    "recandidatavas": "recandidatar",
    "recandidate": "recandidatar",
    "recandidatei": "recandidatar",
    "recandidateis": "recandidatar",
    "recandidatem": "recandidatar",
    "recandidatemo": "recandidatar",
    "recandidatemos": "recandidatar",
    "recandidates": "recandidatar",
    "recandidato": "recandidatar",
    "recandidatou": "recandidatar",
    "recandidaturas": "recandidatura",
    "recandidatá": "recandidatar",
    "recandidatámo": "recandidatar",
    "recandidatámos": "recandidatar",
    "recandidatáramo": "recandidatar",
    "recandidatáramos": "recandidatar",
    "recandidatárei": "recandidatar",
    "recandidatáreis": "recandidatar",
    "recandidatásseis": "recandidatar",
    "recandidatássemos": "recandidatar",
    "recandidatávamo": "recandidatar",
    "recandidatávamos": "recandidatar",
    "recandidatávei": "recandidatar",
    "recandidatáveis": "recandidatar",
    "recanta": "recantar",
    "recantada": "recantar",
    "recantadas": "recantar",
    "recantado": "recantar",
    "recantados": "recantar",
    "recantai": "recantar",
    "recantais": "recantar",
    "recantam": "recantar",
    "recantamo": "recantar",
    "recantamos": "recantar",
    "recantando": "recantar",
    "recantara": "recantar",
    "recantaram": "recantar",
    "recantaras": "recantar",
    "recantardes": "recantar",
    "recantarei": "recantar",
    "recantareis": "recantar",
    "recantarem": "recantar",
    "recantaremos": "recantar",
    "recantares": "recantar",
    "recantaria": "recantar",
    "recantariam": "recantar",
    "recantarias": "recantar",
    "recantarmo": "recantar",
    "recantarmos": "recantar",
    "recantará": "recantar",
    "recantarás": "recantar",
    "recantarão": "recantar",
    "recantaríamos": "recantar",
    "recantaríeis": "recantar",
    "recantas": "recantar",
    "recantasse": "recantar",
    "recantassem": "recantar",
    "recantasses": "recantar",
    "recantaste": "recantar",
    "recantastes": "recantar",
    "recantava": "recantar",
    "recantavam": "recantar",
    "recantavas": "recantar",
    "recantações": "recantação",
    "recante": "recantar",
    "recantei": "recantar",
    "recanteis": "recantar",
    "recantem": "recantar",
    "recantemo": "recantar",
    "recantemos": "recantar",
    "recantes": "recantar",
    "recanto": "recantar",
    "recantos": "recanto",
    "recantou": "recantar",
    "recantozinho": "recanto",
    "recantozinhos": "recanto",
    "recantozito": "recanto",
    "recantozitos": "recanto",
    "recantámo": "recantar",
    "recantámos": "recantar",
    "recantáramo": "recantar",
    "recantáramos": "recantar",
    "recantáreis": "recantar",
    "recantásseis": "recantar",
    "recantássemos": "recantar",
    "recantávamo": "recantar",
    "recantávamos": "recantar",
    "recantáveis": "recantar",
    "recapagens": "recapagem",
    "recapeamentos": "recapeamento",
    "recapitalizações": "recapitalização",
    "recapitula": "recapitular",
    "recapitulada": "recapitular",
    "recapituladas": "recapitular",
    "recapitulado": "recapitular",
    "recapitulados": "recapitular",
    "recapitulai": "recapitular",
    "recapitulais": "recapitular",
    "recapitulam": "recapitular",
    "recapitulamo": "recapitular",
    "recapitulamos": "recapitular",
    "recapitulando": "recapitular",
    "recapitulara": "recapitular",
    "recapitularam": "recapitular",
    "recapitularas": "recapitular",
    "recapitularde": "recapitular",
    "recapitulardes": "recapitular",
    "recapitulare": "recapitular",
    "recapitularei": "recapitular",
    "recapitulareis": "recapitular",
    "recapitularem": "recapitular",
    "recapitularemos": "recapitular",
    "recapitulares": "recapitular",
    "recapitularia": "recapitular",
    "recapitulariam": "recapitular",
    "recapitularias": "recapitular",
    "recapitularmo": "recapitular",
    "recapitularmos": "recapitular",
    "recapitulará": "recapitular",
    "recapitularás": "recapitular",
    "recapitularão": "recapitular",
    "recapitularíamos": "recapitular",
    "recapitularíeis": "recapitular",
    "recapitulas": "recapitular",
    "recapitulasse": "recapitular",
    "recapitulassem": "recapitular",
    "recapitulasses": "recapitular",
    "recapitulaste": "recapitular",
    "recapitulastes": "recapitular",
    "recapitulava": "recapitular",
    "recapitulavam": "recapitular",
    "recapitulavas": "recapitular",
    "recapitulações": "recapitulação",
    "recapitule": "recapitular",
    "recapitulei": "recapitular",
    "recapituleis": "recapitular",
    "recapitulem": "recapitular",
    "recapitulemo": "recapitular",
    "recapitulemos": "recapitular",
    "recapitules": "recapitular",
    "recapitulo": "recapitular",
    "recapitulou": "recapitular",
    "recapitulá": "recapitular",
    "recapitulámo": "recapitular",
    "recapitulámos": "recapitular",
    "recapituláramo": "recapitular",
    "recapituláramos": "recapitular",
    "recapitulárei": "recapitular",
    "recapituláreis": "recapitular",
    "recapitulásseis": "recapitular",
    "recapitulássemos": "recapitular",
    "recapitulávamo": "recapitular",
    "recapitulávamos": "recapitular",
    "recapitulávei": "recapitular",
    "recapituláveis": "recapitular",
    "recaptura": "recapturar",
    "recapturada": "recapturar",
    "recapturadas": "recapturar",
    "recapturado": "recapturar",
    "recapturados": "recapturar",
    "recapturai": "recapturar",
    "recapturais": "recapturar",
    "recapturam": "recapturar",
    "recapturamo": "recapturar",
    "recapturamos": "recapturar",
    "recapturando": "recapturar",
    "recapturara": "recapturar",
    "recapturaram": "recapturar",
    "recapturaras": "recapturar",
    "recapturarde": "recapturar",
    "recapturardes": "recapturar",
    "recapturare": "recapturar",
    "recapturarei": "recapturar",
    "recapturareis": "recapturar",
    "recapturarem": "recapturar",
    "recapturaremos": "recapturar",
    "recapturares": "recapturar",
    "recapturaria": "recapturar",
    "recapturariam": "recapturar",
    "recapturarias": "recapturar",
    "recapturarmo": "recapturar",
    "recapturarmos": "recapturar",
    "recapturará": "recapturar",
    "recapturarás": "recapturar",
    "recapturarão": "recapturar",
    "recapturaríamos": "recapturar",
    "recapturaríeis": "recapturar",
    "recapturas": "recapturar",
    "recapturasse": "recapturar",
    "recapturassem": "recapturar",
    "recapturasses": "recapturar",
    "recapturaste": "recapturar",
    "recapturastes": "recapturar",
    "recapturava": "recapturar",
    "recapturavam": "recapturar",
    "recapturavas": "recapturar",
    "recapture": "recapturar",
    "recapturei": "recapturar",
    "recaptureis": "recapturar",
    "recapturem": "recapturar",
    "recapturemo": "recapturar",
    "recapturemos": "recapturar",
    "recaptures": "recapturar",
    "recapturo": "recapturar",
    "recapturou": "recapturar",
    "recapturá": "recapturar",
    "recapturámo": "recapturar",
    "recapturámos": "recapturar",
    "recapturáramo": "recapturar",
    "recapturáramos": "recapturar",
    "recapturárei": "recapturar",
    "recapturáreis": "recapturar",
    "recapturásseis": "recapturar",
    "recapturássemos": "recapturar",
    "recapturávamo": "recapturar",
    "recapturávamos": "recapturar",
    "recapturávei": "recapturar",
    "recapturáveis": "recapturar",
    "recarga": "recargar",
    "recargada": "recargar",
    "recargadas": "recargar",
    "recargado": "recargar",
    "recargados": "recargar",
    "recargai": "recargar",
    "recargais": "recargar",
    "recargam": "recargar",
    "recargamo": "recargar",
    "recargamos": "recargar",
    "recargando": "recargar",
    "recargara": "recargar",
    "recargaram": "recargar",
    "recargaras": "recargar",
    "recargarde": "recargar",
    "recargardes": "recargar",
    "recargare": "recargar",
    "recargarei": "recargar",
    "recargareis": "recargar",
    "recargarem": "recargar",
    "recargaremos": "recargar",
    "recargares": "recargar",
    "recargaria": "recargar",
    "recargariam": "recargar",
    "recargarias": "recargar",
    "recargarmo": "recargar",
    "recargarmos": "recargar",
    "recargará": "recargar",
    "recargarás": "recargar",
    "recargarão": "recargar",
    "recargaríamos": "recargar",
    "recargaríeis": "recargar",
    "recargas": "recargar",
    "recargasse": "recargar",
    "recargassem": "recargar",
    "recargasses": "recargar",
    "recargaste": "recargar",
    "recargastes": "recargar",
    "recargava": "recargar",
    "recargavam": "recargar",
    "recargavas": "recargar",
    "recargo": "recargar",
    "recargou": "recargar",
    "recargue": "recargar",
    "recarguei": "recargar",
    "recargueis": "recargar",
    "recarguem": "recargar",
    "recarguemo": "recargar",
    "recarguemos": "recargar",
    "recargues": "recargar",
    "recargá": "recargar",
    "recargámo": "recargar",
    "recargámos": "recargar",
    "recargáramo": "recargar",
    "recargáramos": "recargar",
    "recargárei": "recargar",
    "recargáreis": "recargar",
    "recargásseis": "recargar",
    "recargássemos": "recargar",
    "recargávamo": "recargar",
    "recargávamos": "recargar",
    "recargávei": "recargar",
    "recargáveis": "recargável",
    "recarrega": "recarregar",
    "recarregada": "recarregar",
    "recarregadas": "recarregar",
    "recarregado": "recarregar",
    "recarregados": "recarregar",
    "recarregai": "recarregar",
    "recarregais": "recarregar",
    "recarregam": "recarregar",
    "recarregamo": "recarregar",
    "recarregamos": "recarregar",
    "recarregando": "recarregar",
    "recarregara": "recarregar",
    "recarregaram": "recarregar",
    "recarregaras": "recarregar",
    "recarregarde": "recarregar",
    "recarregardes": "recarregar",
    "recarregare": "recarregar",
    "recarregarei": "recarregar",
    "recarregareis": "recarregar",
    "recarregarem": "recarregar",
    "recarregaremos": "recarregar",
    "recarregares": "recarregar",
    "recarregaria": "recarregar",
    "recarregariam": "recarregar",
    "recarregarias": "recarregar",
    "recarregarmo": "recarregar",
    "recarregarmos": "recarregar",
    "recarregará": "recarregar",
    "recarregarás": "recarregar",
    "recarregarão": "recarregar",
    "recarregaríamos": "recarregar",
    "recarregaríeis": "recarregar",
    "recarregas": "recarregar",
    "recarregasse": "recarregar",
    "recarregassem": "recarregar",
    "recarregasses": "recarregar",
    "recarregaste": "recarregar",
    "recarregastes": "recarregar",
    "recarregava": "recarregar",
    "recarregavam": "recarregar",
    "recarregavas": "recarregar",
    "recarrego": "recarregar",
    "recarregou": "recarregar",
    "recarregue": "recarregar",
    "recarreguei": "recarregar",
    "recarregueis": "recarregar",
    "recarreguem": "recarregar",
    "recarreguemo": "recarregar",
    "recarreguemos": "recarregar",
    "recarregues": "recarregar",
    "recarregá": "recarregar",
    "recarregámo": "recarregar",
    "recarregámos": "recarregar",
    "recarregáramo": "recarregar",
    "recarregáramos": "recarregar",
    "recarregárei": "recarregar",
    "recarregáreis": "recarregar",
    "recarregásseis": "recarregar",
    "recarregássemos": "recarregar",
    "recarregávamo": "recarregar",
    "recarregávamos": "recarregar",
    "recarregávei": "recarregar",
    "recarregáveis": "recarregável",
    "recasa": "recasar",
    "recasada": "recasar",
    "recasadas": "recasar",
    "recasado": "recasar",
    "recasados": "recasar",
    "recasai": "recasar",
    "recasais": "recasar",
    "recasam": "recasar",
    "recasamo": "recasar",
    "recasamos": "recasar",
    "recasando": "recasar",
    "recasara": "recasar",
    "recasaram": "recasar",
    "recasaras": "recasar",
    "recasarde": "recasar",
    "recasardes": "recasar",
    "recasare": "recasar",
    "recasarei": "recasar",
    "recasareis": "recasar",
    "recasarem": "recasar",
    "recasaremos": "recasar",
    "recasares": "recasar",
    "recasaria": "recasar",
    "recasariam": "recasar",
    "recasarias": "recasar",
    "recasarmo": "recasar",
    "recasarmos": "recasar",
    "recasará": "recasar",
    "recasarás": "recasar",
    "recasarão": "recasar",
    "recasaríamos": "recasar",
    "recasaríeis": "recasar",
    "recasas": "recasar",
    "recasasse": "recasar",
    "recasassem": "recasar",
    "recasasses": "recasar",
    "recasaste": "recasar",
    "recasastes": "recasar",
    "recasava": "recasar",
    "recasavam": "recasar",
    "recasavas": "recasar",
    "recase": "recasar",
    "recasei": "recasar",
    "recaseis": "recasar",
    "recasem": "recasar",
    "recasemo": "recasar",
    "recasemos": "recasar",
    "recases": "recasar",
    "recaso": "recasar",
    "recasou": "recasar",
    "recasá": "recasar",
    "recasámo": "recasar",
    "recasámos": "recasar",
    "recasáramo": "recasar",
    "recasáramos": "recasar",
    "recasárei": "recasar",
    "recasáreis": "recasar",
    "recasásseis": "recasar",
    "recasássemos": "recasar",
    "recasávamo": "recasar",
    "recasávamos": "recasar",
    "recasávei": "recasar",
    "recasáveis": "recasar",
    "recata": "recatar",
    "recatada": "recatar",
    "recatadas": "recatar",
    "recatadazinha": "recatado",
    "recatadazinhas": "recatado",
    "recatadazita": "recatado",
    "recatadazitas": "recatado",
    "recatadinha": "recatado",
    "recatadinhas": "recatado",
    "recatadinho": "recatado",
    "recatadinhos": "recatado",
    "recatadita": "recatado",
    "recataditas": "recatado",
    "recatadito": "recatado",
    "recataditos": "recatado",
    "recatado": "recatar",
    "recatados": "recatar",
    "recatadozinho": "recatado",
    "recatadozinhos": "recatado",
    "recatadozito": "recatado",
    "recatadozitos": "recatado",
    "recatadíssima": "recatado",
    "recatadíssimas": "recatado",
    "recatadíssimo": "recatado",
    "recatadíssimos": "recatado",
    "recatai": "recatar",
    "recatais": "recatar",
    "recatam": "recatar",
    "recatamo": "recatar",
    "recatamos": "recatar",
    "recatando": "recatar",
    "recatara": "recatar",
    "recataram": "recatar",
    "recataras": "recatar",
    "recatarde": "recatar",
    "recatardes": "recatar",
    "recatare": "recatar",
    "recatarei": "recatar",
    "recatareis": "recatar",
    "recatarem": "recatar",
    "recataremos": "recatar",
    "recatares": "recatar",
    "recataria": "recatar",
    "recatariam": "recatar",
    "recatarias": "recatar",
    "recatarmo": "recatar",
    "recatarmos": "recatar",
    "recatará": "recatar",
    "recatarás": "recatar",
    "recatarão": "recatar",
    "recataríamos": "recatar",
    "recataríeis": "recatar",
    "recatas": "recatar",
    "recatasse": "recatar",
    "recatassem": "recatar",
    "recatasses": "recatar",
    "recataste": "recatar",
    "recatastes": "recatar",
    "recatava": "recatar",
    "recatavam": "recatar",
    "recatavas": "recatar",
    "recate": "recatar",
    "recatei": "recatar",
    "recateis": "recatar",
    "recatem": "recatar",
    "recatemo": "recatar",
    "recatemos": "recatar",
    "recates": "recatar",
    "recato": "recatar",
    "recatos": "recato",
    "recatou": "recatar",
    "recatá": "recatar",
    "recatámo": "recatar",
    "recatámos": "recatar",
    "recatáramo": "recatar",
    "recatáramos": "recatar",
    "recatárei": "recatar",
    "recatáreis": "recatar",
    "recatásseis": "recatar",
    "recatássemos": "recatar",
    "recatávamo": "recatar",
    "recatávamos": "recatar",
    "recatávei": "recatar",
    "recatáveis": "recatar",
    "recauchuta": "recauchutar",
    "recauchutada": "recauchutar",
    "recauchutadas": "recauchutar",
    "recauchutado": "recauchutar",
    "recauchutadoras": "recauchutadora",
    "recauchutados": "recauchutar",
    "recauchutagens": "recauchutagem",
    "recauchutai": "recauchutar",
    "recauchutais": "recauchutar",
    "recauchutam": "recauchutar",
    "recauchutamo": "recauchutar",
    "recauchutamos": "recauchutar",
    "recauchutando": "recauchutar",
    "recauchutara": "recauchutar",
    "recauchutaram": "recauchutar",
    "recauchutaras": "recauchutar",
    "recauchutarde": "recauchutar",
    "recauchutardes": "recauchutar",
    "recauchutare": "recauchutar",
    "recauchutarei": "recauchutar",
    "recauchutareis": "recauchutar",
    "recauchutarem": "recauchutar",
    "recauchutaremos": "recauchutar",
    "recauchutares": "recauchutar",
    "recauchutaria": "recauchutar",
    "recauchutariam": "recauchutar",
    "recauchutarias": "recauchutar",
    "recauchutarmo": "recauchutar",
    "recauchutarmos": "recauchutar",
    "recauchutará": "recauchutar",
    "recauchutarás": "recauchutar",
    "recauchutarão": "recauchutar",
    "recauchutaríamos": "recauchutar",
    "recauchutaríeis": "recauchutar",
    "recauchutas": "recauchutar",
    "recauchutasse": "recauchutar",
    "recauchutassem": "recauchutar",
    "recauchutasses": "recauchutar",
    "recauchutaste": "recauchutar",
    "recauchutastes": "recauchutar",
    "recauchutava": "recauchutar",
    "recauchutavam": "recauchutar",
    "recauchutavas": "recauchutar",
    "recauchute": "recauchutar",
    "recauchutei": "recauchutar",
    "recauchuteis": "recauchutar",
    "recauchutem": "recauchutar",
    "recauchutemo": "recauchutar",
    "recauchutemos": "recauchutar",
    "recauchutes": "recauchutar",
    "recauchuto": "recauchutar",
    "recauchutou": "recauchutar",
    "recauchutá": "recauchutar",
    "recauchutámo": "recauchutar",
    "recauchutámos": "recauchutar",
    "recauchutáramo": "recauchutar",
    "recauchutáramos": "recauchutar",
    "recauchutárei": "recauchutar",
    "recauchutáreis": "recauchutar",
    "recauchutásseis": "recauchutar",
    "recauchutássemos": "recauchutar",
    "recauchutávamo": "recauchutar",
    "recauchutávamos": "recauchutar",
    "recauchutávei": "recauchutar",
    "recauchutáveis": "recauchutável",
    "recava": "recavar",
    "recavada": "recavar",
    "recavadas": "recavar",
    "recavado": "recavar",
    "recavados": "recavar",
    "recavai": "recavar",
    "recavais": "recavar",
    "recavam": "recavar",
    "recavamo": "recavar",
    "recavamos": "recavar",
    "recavando": "recavar",
    "recavara": "recavar",
    "recavaram": "recavar",
    "recavaras": "recavar",
    "recavarde": "recavar",
    "recavardes": "recavar",
    "recavare": "recavar",
    "recavarei": "recavar",
    "recavareis": "recavar",
    "recavarem": "recavar",
    "recavaremos": "recavar",
    "recavares": "recavar",
    "recavaria": "recavar",
    "recavariam": "recavar",
    "recavarias": "recavar",
    "recavarmo": "recavar",
    "recavarmos": "recavar",
    "recavará": "recavar",
    "recavarás": "recavar",
    "recavarão": "recavar",
    "recavaríamos": "recavar",
    "recavaríeis": "recavar",
    "recavas": "recavar",
    "recavasse": "recavar",
    "recavassem": "recavar",
    "recavasses": "recavar",
    "recavaste": "recavar",
    "recavastes": "recavar",
    "recavava": "recavar",
    "recavavam": "recavar",
    "recavavas": "recavar",
    "recave": "recavar",
    "recavei": "recavar",
    "recaveis": "recavar",
    "recavem": "recavar",
    "recavemo": "recavar",
    "recavemos": "recavar",
    "recaves": "recavar",
    "recavo": "recavar",
    "recavou": "recavar",
    "recavá": "recavar",
    "recavámo": "recavar",
    "recavámos": "recavar",
    "recaváramo": "recavar",
    "recaváramos": "recavar",
    "recavárei": "recavar",
    "recaváreis": "recavar",
    "recavásseis": "recavar",
    "recavássemos": "recavar",
    "recavávamo": "recavar",
    "recavávamos": "recavar",
    "recavávei": "recavar",
    "recaváveis": "recavar",
    "recavéns": "recavém",
    "recaí": "recair",
    "recaía": "recair",
    "recaíam": "recair",
    "recaíamo": "recair",
    "recaíamos": "recair",
    "recaías": "recair",
    "recaída": "recair",
    "recaídas": "recair",
    "recaído": "recair",
    "recaídos": "recair",
    "recaíeis": "recair",
    "recaímo": "recair",
    "recaímos": "recair",
    "recaíra": "recair",
    "recaíram": "recair",
    "recaíramo": "recair",
    "recaíramos": "recair",
    "recaíras": "recair",
    "recaíreis": "recair",
    "recaírem": "recair",
    "recaíres": "recair",
    "recaís": "recair",
    "recaísse": "recair",
    "recaísseis": "recair",
    "recaíssem": "recair",
    "recaíssemos": "recair",
    "recaísses": "recair",
    "recaíste": "recair",
    "recaístes": "recair",
    "receada": "recear",
    "receadas": "recear",
    "receado": "recear",
    "receados": "recear",
    "receai": "recear",
    "receais": "recear",
    "receamo": "recear",
    "receamos": "recear",
    "receando": "recear",
    "receara": "recear",
    "recearam": "recear",
    "recearas": "recear",
    "recearde": "recear",
    "receardes": "recear",
    "receare": "recear",
    "recearei": "recear",
    "receareis": "recear",
    "recearem": "recear",
    "recearemos": "recear",
    "receares": "recear",
    "recearia": "recear",
    "receariam": "recear",
    "recearias": "recear",
    "recearmo": "recear",
    "recearmos": "recear",
    "receará": "recear",
    "recearás": "recear",
    "recearão": "recear",
    "recearíamos": "recear",
    "recearíeis": "recear",
    "receasse": "recear",
    "receassem": "recear",
    "receasses": "recear",
    "receaste": "recear",
    "receastes": "recear",
    "receava": "recear",
    "receavam": "recear",
    "receavas": "recear",
    "receba": "receber",
    "recebais": "receber",
    "recebam": "receber",
    "recebamo": "receber",
    "recebamos": "receber",
    "recebas": "receber",
    "recebe": "receber",
    "recebedora": "recebedor",
    "recebedoras": "recebedor",
    "recebedores": "recebedor",
    "recebedorias": "recebedoria",
    "recebei": "receber",
    "recebeis": "receber",
    "recebem": "receber",
    "recebemo": "receber",
    "recebemos": "receber",
    "recebendo": "receber",
    "recebera": "receber",
    "receberam": "receber",
    "receberas": "receber",
    "receberde": "receber",
    "receberdes": "receber",
    "recebere": "receber",
    "receberei": "receber",
    "recebereis": "receber",
    "receberem": "receber",
    "receberemos": "receber",
    "receberes": "receber",
    "receberia": "receber",
    "receberiam": "receber",
    "receberias": "receber",
    "recebermo": "receber",
    "recebermos": "receber",
    "receberá": "receber",
    "receberás": "receber",
    "receberão": "receber",
    "receberíamos": "receber",
    "receberíeis": "receber",
    "recebes": "receber",
    "recebesse": "receber",
    "recebessem": "receber",
    "recebesses": "receber",
    "recebeste": "receber",
    "recebestes": "receber",
    "recebeu": "receber",
    "recebi": "receber",
    "recebia": "receber",
    "recebiam": "receber",
    "recebias": "receber",
    "recebida": "recebido",
    "recebidas": "recebido",
    "recebido": "receber",
    "recebidos": "recebido",
    "recebimentos": "recebimento",
    "recebo": "receber",
    "recebê": "receber",
    "recebêramo": "receber",
    "recebêramos": "receber",
    "recebêrei": "receber",
    "recebêreis": "receber",
    "recebêsseis": "receber",
    "recebêssemos": "receber",
    "recebíamo": "receber",
    "recebíamos": "receber",
    "recebíei": "receber",
    "recebíeis": "receber",
    "receei": "recear",
    "receeis": "recear",
    "receemo": "recear",
    "receemos": "recear",
    "receia": "recear",
    "receiam": "recear",
    "receias": "recear",
    "receie": "recear",
    "receiem": "recear",
    "receies": "recear",
    "receio": "recear",
    "receios": "receio",
    "receita": "receitar",
    "receitada": "receitar",
    "receitadas": "receitar",
    "receitado": "receitar",
    "receitados": "receitar",
    "receitai": "receitar",
    "receitais": "receitar",
    "receitam": "receitar",
    "receitamo": "receitar",
    "receitamos": "receitar",
    "receitando": "receitar",
    "receitara": "receitar",
    "receitaram": "receitar",
    "receitaras": "receitar",
    "receitarde": "receitar",
    "receitardes": "receitar",
    "receitare": "receitar",
    "receitarei": "receitar",
    "receitareis": "receitar",
    "receitarem": "receitar",
    "receitaremos": "receitar",
    "receitares": "receitar",
    "receitaria": "receitar",
    "receitariam": "receitar",
    "receitarias": "receitar",
    "receitarmo": "receitar",
    "receitarmos": "receitar",
    "receitará": "receitar",
    "receitarás": "receitar",
    "receitarão": "receitar",
    "receitaríamos": "receitar",
    "receitaríeis": "receitar",
    "receitas": "receitar",
    "receitasse": "receitar",
    "receitassem": "receitar",
    "receitasses": "receitar",
    "receitaste": "receitar",
    "receitastes": "receitar",
    "receitava": "receitar",
    "receitavam": "receitar",
    "receitavas": "receitar",
    "receite": "receitar",
    "receitei": "receitar",
    "receiteis": "receitar",
    "receitem": "receitar",
    "receitemo": "receitar",
    "receitemos": "receitar",
    "receites": "receitar",
    "receito": "receitar",
    "receitou": "receitar",
    "receituários": "receituário",
    "receitá": "receitar",
    "receitámo": "receitar",
    "receitámos": "receitar",
    "receitáramo": "receitar",
    "receitáramos": "receitar",
    "receitárei": "receitar",
    "receitáreis": "receitar",
    "receitários": "receitário",
    "receitásseis": "receitar",
    "receitássemos": "receitar",
    "receitávamo": "receitar",
    "receitávamos": "receitar",
    "receitávei": "receitar",
    "receitáveis": "receitar",
    "recena": "recenar",
    "recenada": "recenar",
    "recenadas": "recenar",
    "recenado": "recenar",
    "recenados": "recenar",
    "recenai": "recenar",
    "recenais": "recenar",
    "recenam": "recenar",
    "recenamo": "recenar",
    "recenamos": "recenar",
    "recenando": "recenar",
    "recenara": "recenar",
    "recenaram": "recenar",
    "recenaras": "recenar",
    "recenarde": "recenar",
    "recenardes": "recenar",
    "recenare": "recenar",
    "recenarei": "recenar",
    "recenareis": "recenar",
    "recenarem": "recenar",
    "recenaremos": "recenar",
    "recenares": "recenar",
    "recenaria": "recenar",
    "recenariam": "recenar",
    "recenarias": "recenar",
    "recenarmo": "recenar",
    "recenarmos": "recenar",
    "recenará": "recenar",
    "recenarás": "recenar",
    "recenarão": "recenar",
    "recenaríamos": "recenar",
    "recenaríeis": "recenar",
    "recenas": "recenar",
    "recenasse": "recenar",
    "recenassem": "recenar",
    "recenasses": "recenar",
    "recenaste": "recenar",
    "recenastes": "recenar",
    "recenava": "recenar",
    "recenavam": "recenar",
    "recenavas": "recenar",
    "recenda": "recender",
    "recendais": "recender",
    "recendam": "recender",
    "recendamo": "recender",
    "recendamos": "recender",
    "recendas": "recender",
    "recende": "recender",
    "recendei": "recender",
    "recendeis": "recender",
    "recendem": "recender",
    "recendemo": "recender",
    "recendemos": "recender",
    "recendendo": "recender",
    "recendentes": "recendente",
    "recendera": "recender",
    "recenderam": "recender",
    "recenderas": "recender",
    "recenderdes": "recender",
    "recenderei": "recender",
    "recendereis": "recender",
    "recenderem": "recender",
    "recenderemos": "recender",
    "recenderes": "recender",
    "recenderia": "recender",
    "recenderiam": "recender",
    "recenderias": "recender",
    "recendermo": "recender",
    "recendermos": "recender",
    "recenderá": "recender",
    "recenderás": "recender",
    "recenderão": "recender",
    "recenderíamos": "recender",
    "recenderíeis": "recender",
    "recendes": "recender",
    "recendesse": "recender",
    "recendessem": "recender",
    "recendesses": "recender",
    "recendeste": "recender",
    "recendestes": "recender",
    "recendeu": "recender",
    "recendi": "recender",
    "recendia": "recender",
    "recendiam": "recender",
    "recendias": "recender",
    "recendida": "recender",
    "recendidas": "recender",
    "recendido": "recender",
    "recendidos": "recender",
    "recendo": "recender",
    "recendências": "recendência",
    "recendêramo": "recender",
    "recendêramos": "recender",
    "recendêreis": "recender",
    "recendêsseis": "recender",
    "recendêssemos": "recender",
    "recendíamo": "recender",
    "recendíamos": "recender",
    "recendíeis": "recender",
    "recene": "recenar",
    "recenei": "recenar",
    "receneis": "recenar",
    "recenem": "recenar",
    "recenemo": "recenar",
    "recenemos": "recenar",
    "recenes": "recenar",
    "receno": "recenar",
    "recenou": "recenar",
    "recenseada": "recensear",
    "recenseadas": "recensear",
    "recenseado": "recensear",
    "recenseadora": "recenseador",
    "recenseadoras": "recenseador",
    "recenseadores": "recenseador",
    "recenseados": "recensear",
    "recenseai": "recensear",
    "recenseais": "recensear",
    "recenseamentos": "recenseamento",
    "recenseamo": "recensear",
    "recenseamos": "recensear",
    "recenseando": "recensear",
    "recenseara": "recensear",
    "recensearam": "recensear",
    "recensearas": "recensear",
    "recensearde": "recensear",
    "recenseardes": "recensear",
    "recenseare": "recensear",
    "recensearei": "recensear",
    "recenseareis": "recensear",
    "recensearem": "recensear",
    "recensearemos": "recensear",
    "recenseares": "recensear",
    "recensearia": "recensear",
    "recenseariam": "recensear",
    "recensearias": "recensear",
    "recensearmo": "recensear",
    "recensearmos": "recensear",
    "recenseará": "recensear",
    "recensearás": "recensear",
    "recensearão": "recensear",
    "recensearíamos": "recensear",
    "recensearíeis": "recensear",
    "recenseasse": "recensear",
    "recenseassem": "recensear",
    "recenseasses": "recensear",
    "recenseaste": "recensear",
    "recenseastes": "recensear",
    "recenseava": "recensear",
    "recenseavam": "recensear",
    "recenseavas": "recensear",
    "recenseei": "recensear",
    "recenseeis": "recensear",
    "recenseemo": "recensear",
    "recenseemos": "recensear",
    "recenseia": "recensear",
    "recenseiam": "recensear",
    "recenseias": "recensear",
    "recenseie": "recensear",
    "recenseiem": "recensear",
    "recenseies": "recensear",
    "recenseio": "recensear",
    "recenseios": "recenseio",
    "recenseou": "recensear",
    "recenseá": "recensear",
    "recenseámo": "recensear",
    "recenseámos": "recensear",
    "recenseáramo": "recensear",
    "recenseáramos": "recensear",
    "recenseárei": "recensear",
    "recenseáreis": "recensear",
    "recenseásseis": "recensear",
    "recenseássemos": "recensear",
    "recenseávamo": "recensear",
    "recenseávamos": "recensear",
    "recenseávei": "recensear",
    "recenseáveis": "recenseável",
    "recensões": "recensão",
    "recentais": "recental",
    "recentes": "recente",
    "recentezinha": "recente",
    "recentezinhas": "recente",
    "recentezinho": "recente",
    "recentezinhos": "recente",
    "recentezita": "recente",
    "recentezitas": "recente",
    "recentezito": "recente",
    "recentezitos": "recente",
    "recentra": "recentrar",
    "recentrada": "recentrar",
    "recentradas": "recentrar",
    "recentrado": "recentrar",
    "recentrados": "recentrar",
    "recentrai": "recentrar",
    "recentrais": "recentrar",
    "recentram": "recentrar",
    "recentramo": "recentrar",
    "recentramos": "recentrar",
    "recentrando": "recentrar",
    "recentrara": "recentrar",
    "recentraram": "recentrar",
    "recentraras": "recentrar",
    "recentrarde": "recentrar",
    "recentrardes": "recentrar",
    "recentrare": "recentrar",
    "recentrarei": "recentrar",
    "recentrareis": "recentrar",
    "recentrarem": "recentrar",
    "recentraremos": "recentrar",
    "recentrares": "recentrar",
    "recentraria": "recentrar",
    "recentrariam": "recentrar",
    "recentrarias": "recentrar",
    "recentrarmo": "recentrar",
    "recentrarmos": "recentrar",
    "recentrará": "recentrar",
    "recentrarás": "recentrar",
    "recentrarão": "recentrar",
    "recentraríamos": "recentrar",
    "recentraríeis": "recentrar",
    "recentras": "recentrar",
    "recentrasse": "recentrar",
    "recentrassem": "recentrar",
    "recentrasses": "recentrar",
    "recentraste": "recentrar",
    "recentrastes": "recentrar",
    "recentrava": "recentrar",
    "recentravam": "recentrar",
    "recentravas": "recentrar",
    "recentre": "recentrar",
    "recentrei": "recentrar",
    "recentreis": "recentrar",
    "recentrem": "recentrar",
    "recentremo": "recentrar",
    "recentremos": "recentrar",
    "recentres": "recentrar",
    "recentro": "recentrar",
    "recentrou": "recentrar",
    "recentrá": "recentrar",
    "recentrámo": "recentrar",
    "recentrámos": "recentrar",
    "recentráramo": "recentrar",
    "recentráramos": "recentrar",
    "recentrárei": "recentrar",
    "recentráreis": "recentrar",
    "recentrásseis": "recentrar",
    "recentrássemos": "recentrar",
    "recentrávamo": "recentrar",
    "recentrávamos": "recentrar",
    "recentrávei": "recentrar",
    "recentráveis": "recentrar",
    "recentíssima": "recente",
    "recentíssimas": "recente",
    "recentíssimo": "recente",
    "recentíssimos": "recente",
    "recená": "recenar",
    "recenámo": "recenar",
    "recenámos": "recenar",
    "recenáramo": "recenar",
    "recenáramos": "recenar",
    "recenárei": "recenar",
    "recenáreis": "recenar",
    "recenásseis": "recenar",
    "recenássemos": "recenar",
    "recenávamo": "recenar",
    "recenávamos": "recenar",
    "recenávei": "recenar",
    "recenáveis": "recenar",
    "receosa": "receoso",
    "receosas": "receoso",
    "receosazinha": "receoso",
    "receosazinhas": "receoso",
    "receosazita": "receoso",
    "receosazitas": "receoso",
    "receosinha": "receoso",
    "receosinhas": "receoso",
    "receosinho": "receoso",
    "receosinhos": "receoso",
    "receosita": "receoso",
    "receositas": "receoso",
    "receosito": "receoso",
    "receositos": "receoso",
    "receosos": "receoso",
    "receosozinho": "receoso",
    "receosozinhos": "receoso",
    "receosozito": "receoso",
    "receosozitos": "receoso",
    "receosíssima": "receoso",
    "receosíssimas": "receoso",
    "receosíssimo": "receoso",
    "receosíssimos": "receoso",
    "receou": "recear",
    "recepagens": "recepagem",
    "recepcionistas": "recepcionista",
    "recepta": "receptar",
    "receptaculares": "receptacular",
    "receptada": "receptar",
    "receptadas": "receptar",
    "receptado": "receptar",
    "receptadora": "receptador",
    "receptadoras": "receptador",
    "receptadores": "receptador",
    "receptados": "receptar",
    "receptai": "receptar",
    "receptais": "receptar",
    "receptam": "receptar",
    "receptamo": "receptar",
    "receptamos": "receptar",
    "receptando": "receptar",
    "receptara": "receptar",
    "receptaram": "receptar",
    "receptaras": "receptar",
    "receptarde": "receptar",
    "receptardes": "receptar",
    "receptare": "receptar",
    "receptarei": "receptar",
    "receptareis": "receptar",
    "receptarem": "receptar",
    "receptaremos": "receptar",
    "receptares": "receptar",
    "receptaria": "receptar",
    "receptariam": "receptar",
    "receptarias": "receptar",
    "receptarmo": "receptar",
    "receptarmos": "receptar",
    "receptará": "receptar",
    "receptarás": "receptar",
    "receptarão": "receptar",
    "receptaríamos": "receptar",
    "receptaríeis": "receptar",
    "receptas": "receptar",
    "receptasse": "receptar",
    "receptassem": "receptar",
    "receptasses": "receptar",
    "receptaste": "receptar",
    "receptastes": "receptar",
    "receptava": "receptar",
    "receptavam": "receptar",
    "receptavas": "receptar",
    "receptações": "receptação",
    "recepte": "receptar",
    "receptei": "receptar",
    "recepteis": "receptar",
    "receptem": "receptar",
    "receptemo": "receptar",
    "receptemos": "receptar",
    "receptes": "receptar",
    "receptibilidades": "receptibilidade",
    "receptiva": "receptivo",
    "receptivas": "receptivo",
    "receptividades": "receptividade",
    "receptivos": "receptivo",
    "recepto": "receptar",
    "receptora": "receptor",
    "receptoras": "receptor",
    "receptores": "receptor",
    "receptou": "receptar",
    "receptá": "receptar",
    "receptáculos": "receptáculo",
    "receptámo": "receptar",
    "receptámos": "receptar",
    "receptáramo": "receptar",
    "receptáramos": "receptar",
    "receptárei": "receptar",
    "receptáreis": "receptar",
    "receptásseis": "receptar",
    "receptássemos": "receptar",
    "receptávamo": "receptar",
    "receptávamos": "receptar",
    "receptávei": "receptar",
    "receptáveis": "receptar",
    "receptíveis": "receptível",
    "recepções": "recepção",
    "recessa": "recesso",
    "recessas": "recesso",
    "recessiva": "recessivo",
    "recessivas": "recessivo",
    "recessividades": "recessividade",
    "recessivos": "recessivo",
    "recessos": "recesso",
    "recessões": "recessão",
    "receá": "recear",
    "receámo": "recear",
    "receámos": "recear",
    "receáramo": "recear",
    "receáramos": "recear",
    "receárei": "recear",
    "receáreis": "recear",
    "receásseis": "recear",
    "receássemos": "recear",
    "receávamo": "recear",
    "receávamos": "recear",
    "receávei": "recear",
    "receáveis": "recear",
    "rechace": "rechaçar",
    "rechacei": "rechaçar",
    "rechaceis": "rechaçar",
    "rechacem": "rechaçar",
    "rechacemo": "rechaçar",
    "rechacemos": "rechaçar",
    "rechaces": "rechaçar",
    "rechapa": "rechapar",
    "rechapada": "rechapar",
    "rechapadas": "rechapar",
    "rechapado": "rechapar",
    "rechapados": "rechapar",
    "rechapagens": "rechapagem",
    "rechapai": "rechapar",
    "rechapais": "rechapar",
    "rechapam": "rechapar",
    "rechapamo": "rechapar",
    "rechapamos": "rechapar",
    "rechapando": "rechapar",
    "rechapara": "rechapar",
    "rechaparam": "rechapar",
    "rechaparas": "rechapar",
    "rechaparde": "rechapar",
    "rechapardes": "rechapar",
    "rechapare": "rechapar",
    "rechaparei": "rechapar",
    "rechapareis": "rechapar",
    "rechaparem": "rechapar",
    "rechaparemos": "rechapar",
    "rechapares": "rechapar",
    "rechaparia": "rechapar",
    "rechapariam": "rechapar",
    "rechaparias": "rechapar",
    "rechaparmo": "rechapar",
    "rechaparmos": "rechapar",
    "rechapará": "rechapar",
    "rechaparás": "rechapar",
    "rechaparão": "rechapar",
    "rechaparíamos": "rechapar",
    "rechaparíeis": "rechapar",
    "rechapas": "rechapar",
    "rechapasse": "rechapar",
    "rechapassem": "rechapar",
    "rechapasses": "rechapar",
    "rechapaste": "rechapar",
    "rechapastes": "rechapar",
    "rechapava": "rechapar",
    "rechapavam": "rechapar",
    "rechapavas": "rechapar",
    "rechape": "rechapar",
    "rechapei": "rechapar",
    "rechapeis": "rechapar",
    "rechapem": "rechapar",
    "rechapemo": "rechapar",
    "rechapemos": "rechapar",
    "rechapes": "rechapar",
    "rechapo": "rechapar",
    "rechapou": "rechapar",
    "rechapá": "rechapar",
    "rechapámo": "rechapar",
    "rechapámos": "rechapar",
    "rechapáramo": "rechapar",
    "rechapáramos": "rechapar",
    "rechapárei": "rechapar",
    "rechapáreis": "rechapar",
    "rechapásseis": "rechapar",
    "rechapássemos": "rechapar",
    "rechapávamo": "rechapar",
    "rechapávamos": "rechapar",
    "rechapávei": "rechapar",
    "rechapáveis": "rechapar",
    "rechaça": "rechaçar",
    "rechaçada": "rechaçar",
    "rechaçadas": "rechaçar",
    "rechaçado": "rechaçar",
    "rechaçados": "rechaçar",
    "rechaçai": "rechaçar",
    "rechaçais": "rechaçar",
    "rechaçam": "rechaçar",
    "rechaçamo": "rechaçar",
    "rechaçamos": "rechaçar",
    "rechaçando": "rechaçar",
    "rechaçara": "rechaçar",
    "rechaçaram": "rechaçar",
    "rechaçaras": "rechaçar",
    "rechaçarde": "rechaçar",
    "rechaçardes": "rechaçar",
    "rechaçare": "rechaçar",
    "rechaçarei": "rechaçar",
    "rechaçareis": "rechaçar",
    "rechaçarem": "rechaçar",
    "rechaçaremos": "rechaçar",
    "rechaçares": "rechaçar",
    "rechaçaria": "rechaçar",
    "rechaçariam": "rechaçar",
    "rechaçarias": "rechaçar",
    "rechaçarmo": "rechaçar",
    "rechaçarmos": "rechaçar",
    "rechaçará": "rechaçar",
    "rechaçarás": "rechaçar",
    "rechaçarão": "rechaçar",
    "rechaçaríamos": "rechaçar",
    "rechaçaríeis": "rechaçar",
    "rechaças": "rechaçar",
    "rechaçasse": "rechaçar",
    "rechaçassem": "rechaçar",
    "rechaçasses": "rechaçar",
    "rechaçaste": "rechaçar",
    "rechaçastes": "rechaçar",
    "rechaçava": "rechaçar",
    "rechaçavam": "rechaçar",
    "rechaçavas": "rechaçar",
    "rechaço": "rechaçar",
    "rechaços": "rechaço",
    "rechaçou": "rechaçar",
    "rechaçá": "rechaçar",
    "rechaçámo": "rechaçar",
    "rechaçámos": "rechaçar",
    "rechaçáramo": "rechaçar",
    "rechaçáramos": "rechaçar",
    "rechaçárei": "rechaçar",
    "rechaçáreis": "rechaçar",
    "rechaçásseis": "rechaçar",
    "rechaçássemos": "rechaçar",
    "rechaçávamo": "rechaçar",
    "rechaçávamos": "rechaçar",
    "rechaçávei": "rechaçar",
    "rechaçáveis": "rechaçável",
    "recheada": "rechear",
    "recheadas": "rechear",
    "recheadazinha": "recheado",
    "recheadazinhas": "recheado",
    "recheadazita": "recheado",
    "recheadazitas": "recheado",
    "recheadinha": "recheado",
    "recheadinhas": "recheado",
    "recheadinho": "recheado",
    "recheadinhos": "recheado",
    "recheadita": "recheado",
    "recheaditas": "recheado",
    "recheadito": "recheado",
    "recheaditos": "recheado",
    "recheado": "rechear",
    "recheados": "rechear",
    "recheadozinho": "recheado",
    "recheadozinhos": "recheado",
    "recheadozito": "recheado",
    "recheadozitos": "recheado",
    "recheaduras": "recheadura",
    "recheadíssima": "recheado",
    "recheadíssimas": "recheado",
    "recheadíssimo": "recheado",
    "recheadíssimos": "recheado",
    "recheai": "rechear",
    "recheais": "rechear",
    "recheamo": "rechear",
    "recheamos": "rechear",
    "recheando": "rechear",
    "recheara": "rechear",
    "rechearam": "rechear",
    "rechearas": "rechear",
    "rechearde": "rechear",
    "recheardes": "rechear",
    "recheare": "rechear",
    "rechearei": "rechear",
    "recheareis": "rechear",
    "rechearem": "rechear",
    "rechearemos": "rechear",
    "recheares": "rechear",
    "rechearia": "rechear",
    "recheariam": "rechear",
    "rechearias": "rechear",
    "rechearmo": "rechear",
    "rechearmos": "rechear",
    "recheará": "rechear",
    "rechearás": "rechear",
    "rechearão": "rechear",
    "rechearíamos": "rechear",
    "rechearíeis": "rechear",
    "recheasse": "rechear",
    "recheassem": "rechear",
    "recheasses": "rechear",
    "recheaste": "rechear",
    "recheastes": "rechear",
    "recheava": "rechear",
    "recheavam": "rechear",
    "recheavas": "rechear",
    "recheei": "rechear",
    "recheeis": "rechear",
    "recheemo": "rechear",
    "recheemos": "rechear",
    "rechegas": "rechega",
    "rechegos": "rechego",
    "recheia": "rechear",
    "recheiam": "rechear",
    "recheias": "rechear",
    "recheie": "rechear",
    "recheiem": "rechear",
    "recheies": "rechear",
    "recheio": "rechear",
    "recheios": "recheio",
    "recheou": "rechear",
    "recheá": "rechear",
    "recheámo": "rechear",
    "recheámos": "rechear",
    "recheáramo": "rechear",
    "recheáramos": "rechear",
    "recheárei": "rechear",
    "recheáreis": "rechear",
    "recheásseis": "rechear",
    "recheássemos": "rechear",
    "recheávamo": "rechear",
    "recheávamos": "rechear",
    "recheávei": "rechear",
    "recheáveis": "rechear",
    "rechia": "rechiar",
    "rechiada": "rechiar",
    "rechiadas": "rechiar",
    "rechiado": "rechiar",
    "rechiados": "rechiar",
    "rechiai": "rechiar",
    "rechiais": "rechiar",
    "rechiam": "rechiar",
    "rechiamo": "rechiar",
    "rechiamos": "rechiar",
    "rechiando": "rechiar",
    "rechiara": "rechiar",
    "rechiaram": "rechiar",
    "rechiaras": "rechiar",
    "rechiardes": "rechiar",
    "rechiarei": "rechiar",
    "rechiareis": "rechiar",
    "rechiarem": "rechiar",
    "rechiaremos": "rechiar",
    "rechiares": "rechiar",
    "rechiaria": "rechiar",
    "rechiariam": "rechiar",
    "rechiarias": "rechiar",
    "rechiarmo": "rechiar",
    "rechiarmos": "rechiar",
    "rechiará": "rechiar",
    "rechiarás": "rechiar",
    "rechiarão": "rechiar",
    "rechiaríamos": "rechiar",
    "rechiaríeis": "rechiar",
    "rechias": "rechiar",
    "rechiasse": "rechiar",
    "rechiassem": "rechiar",
    "rechiasses": "rechiar",
    "rechiaste": "rechiar",
    "rechiastes": "rechiar",
    "rechiava": "rechiar",
    "rechiavam": "rechiar",
    "rechiavas": "rechiar",
    "rechie": "rechiar",
    "rechiei": "rechiar",
    "rechieis": "rechiar",
    "rechiem": "rechiar",
    "rechiemo": "rechiar",
    "rechiemos": "rechiar",
    "rechies": "rechiar",
    "rechina": "rechinar",
    "rechinada": "rechinar",
    "rechinadas": "rechinar",
    "rechinado": "rechinar",
    "rechinados": "rechinar",
    "rechinai": "rechinar",
    "rechinais": "rechinar",
    "rechinam": "rechinar",
    "rechinamo": "rechinar",
    "rechinamos": "rechinar",
    "rechinando": "rechinar",
    "rechinantes": "rechinante",
    "rechinara": "rechinar",
    "rechinaram": "rechinar",
    "rechinaras": "rechinar",
    "rechinardes": "rechinar",
    "rechinarei": "rechinar",
    "rechinareis": "rechinar",
    "rechinarem": "rechinar",
    "rechinaremos": "rechinar",
    "rechinares": "rechinar",
    "rechinaria": "rechinar",
    "rechinariam": "rechinar",
    "rechinarias": "rechinar",
    "rechinarmo": "rechinar",
    "rechinarmos": "rechinar",
    "rechinará": "rechinar",
    "rechinarás": "rechinar",
    "rechinarão": "rechinar",
    "rechinaríamos": "rechinar",
    "rechinaríeis": "rechinar",
    "rechinas": "rechinar",
    "rechinasse": "rechinar",
    "rechinassem": "rechinar",
    "rechinasses": "rechinar",
    "rechinaste": "rechinar",
    "rechinastes": "rechinar",
    "rechinava": "rechinar",
    "rechinavam": "rechinar",
    "rechinavas": "rechinar",
    "rechine": "rechinar",
    "rechinei": "rechinar",
    "rechineis": "rechinar",
    "rechinem": "rechinar",
    "rechinemo": "rechinar",
    "rechinemos": "rechinar",
    "rechines": "rechinar",
    "rechino": "rechinar",
    "rechinos": "rechino",
    "rechinou": "rechinar",
    "rechinámo": "rechinar",
    "rechinámos": "rechinar",
    "rechináramo": "rechinar",
    "rechináramos": "rechinar",
    "rechináreis": "rechinar",
    "rechinásseis": "rechinar",
    "rechinássemos": "rechinar",
    "rechinávamo": "rechinar",
    "rechinávamos": "rechinar",
    "rechináveis": "rechinar",
    "rechio": "rechiar",
    "rechiou": "rechiar",
    "rechiámo": "rechiar",
    "rechiámos": "rechiar",
    "rechiáramo": "rechiar",
    "rechiáramos": "rechiar",
    "rechiáreis": "rechiar",
    "rechiásseis": "rechiar",
    "rechiássemos": "rechiar",
    "rechiávamo": "rechiar",
    "rechiávamos": "rechiar",
    "rechiáveis": "rechiar",
    "rechoncha": "rechonchar",
    "rechonchada": "rechonchar",
    "rechonchadas": "rechonchar",
    "rechonchado": "rechonchar",
    "rechonchados": "rechonchar",
    "rechonchai": "rechonchar",
    "rechonchais": "rechonchar",
    "rechoncham": "rechonchar",
    "rechonchamo": "rechonchar",
    "rechonchamos": "rechonchar",
    "rechonchando": "rechonchar",
    "rechonchara": "rechonchar",
    "rechoncharam": "rechonchar",
    "rechoncharas": "rechonchar",
    "rechonchardes": "rechonchar",
    "rechoncharei": "rechonchar",
    "rechonchareis": "rechonchar",
    "rechoncharem": "rechonchar",
    "rechoncharemos": "rechonchar",
    "rechonchares": "rechonchar",
    "rechoncharia": "rechonchar",
    "rechonchariam": "rechonchar",
    "rechoncharias": "rechonchar",
    "rechoncharmo": "rechonchar",
    "rechoncharmos": "rechonchar",
    "rechonchará": "rechonchar",
    "rechoncharás": "rechonchar",
    "rechoncharão": "rechonchar",
    "rechoncharíamos": "rechonchar",
    "rechoncharíeis": "rechonchar",
    "rechonchas": "rechonchar",
    "rechonchasse": "rechonchar",
    "rechonchassem": "rechonchar",
    "rechonchasses": "rechonchar",
    "rechonchaste": "rechonchar",
    "rechonchastes": "rechonchar",
    "rechonchava": "rechonchar",
    "rechonchavam": "rechonchar",
    "rechonchavas": "rechonchar",
    "rechonche": "rechonchar",
    "rechonchei": "rechonchar",
    "rechoncheis": "rechonchar",
    "rechonchem": "rechonchar",
    "rechonchemo": "rechonchar",
    "rechonchemos": "rechonchar",
    "rechonches": "rechonchar",
    "rechoncho": "rechonchar",
    "rechonchou": "rechonchar",
    "rechonchuda": "rechonchudo",
    "rechonchudas": "rechonchudo",
    "rechonchudazinha": "rechonchudo",
    "rechonchudazinhas": "rechonchudo",
    "rechonchudazita": "rechonchudo",
    "rechonchudazitas": "rechonchudo",
    "rechonchudinha": "rechonchudo",
    "rechonchudinhas": "rechonchudo",
    "rechonchudinho": "rechonchudo",
    "rechonchudinhos": "rechonchudo",
    "rechonchudita": "rechonchudo",
    "rechonchuditas": "rechonchudo",
    "rechonchudito": "rechonchudo",
    "rechonchuditos": "rechonchudo",
    "rechonchudos": "rechonchudo",
    "rechonchudozinho": "rechonchudo",
    "rechonchudozinhos": "rechonchudo",
    "rechonchudozito": "rechonchudo",
    "rechonchudozitos": "rechonchudo",
    "rechonchudíssima": "rechonchudo",
    "rechonchudíssimas": "rechonchudo",
    "rechonchudíssimo": "rechonchudo",
    "rechonchudíssimos": "rechonchudo",
    "rechonchámo": "rechonchar",
    "rechonchámos": "rechonchar",
    "rechoncháramo": "rechonchar",
    "rechoncháramos": "rechonchar",
    "rechoncháreis": "rechonchar",
    "rechonchásseis": "rechonchar",
    "rechonchássemos": "rechonchar",
    "rechonchávamo": "rechonchar",
    "rechonchávamos": "rechonchar",
    "rechoncháveis": "rechonchar",
    "rechãs": "rechã",
    "recianos": "reciano",
    "recibos": "recibo",
    "recicla": "reciclar",
    "reciclada": "reciclar",
    "recicladas": "reciclar",
    "reciclado": "reciclar",
    "reciclados": "reciclar",
    "reciclagens": "reciclagem",
    "reciclai": "reciclar",
    "reciclais": "reciclar",
    "reciclam": "reciclar",
    "reciclamo": "reciclar",
    "reciclamos": "reciclar",
    "reciclando": "reciclar",
    "reciclara": "reciclar",
    "reciclaram": "reciclar",
    "reciclaras": "reciclar",
    "reciclarde": "reciclar",
    "reciclardes": "reciclar",
    "reciclare": "reciclar",
    "reciclarei": "reciclar",
    "reciclareis": "reciclar",
    "reciclarem": "reciclar",
    "reciclaremos": "reciclar",
    "reciclares": "reciclar",
    "reciclaria": "reciclar",
    "reciclariam": "reciclar",
    "reciclarias": "reciclar",
    "reciclarmo": "reciclar",
    "reciclarmos": "reciclar",
    "reciclará": "reciclar",
    "reciclarás": "reciclar",
    "reciclarão": "reciclar",
    "reciclaríamos": "reciclar",
    "reciclaríeis": "reciclar",
    "reciclas": "reciclar",
    "reciclasse": "reciclar",
    "reciclassem": "reciclar",
    "reciclasses": "reciclar",
    "reciclaste": "reciclar",
    "reciclastes": "reciclar",
    "reciclava": "reciclar",
    "reciclavam": "reciclar",
    "reciclavas": "reciclar",
    "recicle": "reciclar",
    "reciclei": "reciclar",
    "recicleis": "reciclar",
    "reciclem": "reciclar",
    "reciclemo": "reciclar",
    "reciclemos": "reciclar",
    "recicles": "reciclar",
    "reciclo": "reciclar",
    "reciclou": "reciclar",
    "reciclá": "reciclar",
    "reciclámo": "reciclar",
    "reciclámos": "reciclar",
    "recicláramo": "reciclar",
    "recicláramos": "reciclar",
    "reciclárei": "reciclar",
    "recicláreis": "reciclar",
    "reciclásseis": "reciclar",
    "reciclássemos": "reciclar",
    "reciclávamo": "reciclar",
    "reciclávamos": "reciclar",
    "reciclávei": "reciclar",
    "recicláveis": "reciclável",
    "recidiva": "recidivo",
    "recidivada": "recidivar",
    "recidivadas": "recidivar",
    "recidivado": "recidivar",
    "recidivados": "recidivar",
    "recidivai": "recidivar",
    "recidivais": "recidivar",
    "recidivam": "recidivar",
    "recidivamo": "recidivar",
    "recidivamos": "recidivar",
    "recidivando": "recidivar",
    "recidivara": "recidivar",
    "recidivaram": "recidivar",
    "recidivaras": "recidivar",
    "recidivardes": "recidivar",
    "recidivarei": "recidivar",
    "recidivareis": "recidivar",
    "recidivarem": "recidivar",
    "recidivaremos": "recidivar",
    "recidivares": "recidivar",
    "recidivaria": "recidivar",
    "recidivariam": "recidivar",
    "recidivarias": "recidivar",
    "recidivarmo": "recidivar",
    "recidivarmos": "recidivar",
    "recidivará": "recidivar",
    "recidivarás": "recidivar",
    "recidivarão": "recidivar",
    "recidivaríamos": "recidivar",
    "recidivaríeis": "recidivar",
    "recidivas": "recidivo",
    "recidivasse": "recidivar",
    "recidivassem": "recidivar",
    "recidivasses": "recidivar",
    "recidivaste": "recidivar",
    "recidivastes": "recidivar",
    "recidivava": "recidivar",
    "recidivavam": "recidivar",
    "recidivavas": "recidivar",
    "recidive": "recidivar",
    "recidivei": "recidivar",
    "recidiveis": "recidivar",
    "recidivem": "recidivar",
    "recidivemo": "recidivar",
    "recidivemos": "recidivar",
    "recidives": "recidivar",
    "recidividades": "recidividade",
    "recidivo": "recidivar",
    "recidivos": "recidivo",
    "recidivou": "recidivar",
    "recidivámo": "recidivar",
    "recidivámos": "recidivar",
    "recidiváramo": "recidivar",
    "recidiváramos": "recidivar",
    "recidiváreis": "recidivar",
    "recidivásseis": "recidivar",
    "recidivássemos": "recidivar",
    "recidivávamo": "recidivar",
    "recidivávamos": "recidivar",
    "recidiváveis": "recidivar",
    "recifenses": "recifense",
    "recifes": "recife",
    "recifosa": "recifoso",
    "recifosas": "recifoso",
    "recifosos": "recifoso",
    "recinge": "recingir",
    "recingem": "recingir",
    "recinges": "recingir",
    "recingi": "recingir",
    "recingia": "recingir",
    "recingiam": "recingir",
    "recingias": "recingir",
    "recingida": "recingir",
    "recingidas": "recingir",
    "recingido": "recingir",
    "recingidos": "recingir",
    "recingimo": "recingir",
    "recingimos": "recingir",
    "recingindo": "recingir",
    "recingira": "recingir",
    "recingiram": "recingir",
    "recingiras": "recingir",
    "recingirde": "recingir",
    "recingirdes": "recingir",
    "recingire": "recingir",
    "recingirei": "recingir",
    "recingireis": "recingir",
    "recingirem": "recingir",
    "recingiremos": "recingir",
    "recingires": "recingir",
    "recingiria": "recingir",
    "recingiriam": "recingir",
    "recingirias": "recingir",
    "recingirmo": "recingir",
    "recingirmos": "recingir",
    "recingirá": "recingir",
    "recingirás": "recingir",
    "recingirão": "recingir",
    "recingiríamos": "recingir",
    "recingiríeis": "recingir",
    "recingis": "recingir",
    "recingisse": "recingir",
    "recingissem": "recingir",
    "recingisses": "recingir",
    "recingiste": "recingir",
    "recingistes": "recingir",
    "recingiu": "recingir",
    "recingíamo": "recingir",
    "recingíamos": "recingir",
    "recingíei": "recingir",
    "recingíeis": "recingir",
    "recingíramo": "recingir",
    "recingíramos": "recingir",
    "recingírei": "recingir",
    "recingíreis": "recingir",
    "recingísseis": "recingir",
    "recingíssemos": "recingir",
    "recinja": "recingir",
    "recinjais": "recingir",
    "recinjam": "recingir",
    "recinjamo": "recingir",
    "recinjamos": "recingir",
    "recinjas": "recingir",
    "recinjo": "recingir",
    "recintos": "recinto",
    "recipiendária": "recipiendário",
    "recipiendárias": "recipiendário",
    "recipiendários": "recipiendário",
    "recipientes": "recipiente",
    "reciproca": "reciprocar",
    "reciprocada": "reciprocar",
    "reciprocadas": "reciprocar",
    "reciprocado": "reciprocar",
    "reciprocados": "reciprocar",
    "reciprocais": "reciprocar",
    "reciprocam": "reciprocar",
    "reciprocamo": "reciprocar",
    "reciprocamos": "reciprocar",
    "reciprocando": "reciprocar",
    "reciprocara": "reciprocar",
    "reciprocaram": "reciprocar",
    "reciprocaras": "reciprocar",
    "reciprocardes": "reciprocar",
    "reciprocarei": "reciprocar",
    "reciprocareis": "reciprocar",
    "reciprocarem": "reciprocar",
    "reciprocaremos": "reciprocar",
    "reciprocares": "reciprocar",
    "reciprocaria": "reciprocar",
    "reciprocariam": "reciprocar",
    "reciprocarias": "reciprocar",
    "reciprocarmo": "reciprocar",
    "reciprocarmos": "reciprocar",
    "reciprocará": "reciprocar",
    "reciprocarás": "reciprocar",
    "reciprocarão": "reciprocar",
    "reciprocaríamos": "reciprocar",
    "reciprocaríeis": "reciprocar",
    "reciprocas": "reciprocar",
    "reciprocasse": "reciprocar",
    "reciprocassem": "reciprocar",
    "reciprocasses": "reciprocar",
    "reciprocaste": "reciprocar",
    "reciprocastes": "reciprocar",
    "reciprocava": "reciprocar",
    "reciprocavam": "reciprocar",
    "reciprocavas": "reciprocar",
    "reciprocidades": "reciprocidade",
    "reciproco": "reciprocar",
    "reciprocou": "reciprocar",
    "reciprocámo": "reciprocar",
    "reciprocámos": "reciprocar",
    "reciprocáramo": "reciprocar",
    "reciprocáramos": "reciprocar",
    "reciprocáreis": "reciprocar",
    "reciprocásseis": "reciprocar",
    "reciprocássemos": "reciprocar",
    "reciprocávamo": "reciprocar",
    "reciprocávamos": "reciprocar",
    "reciprocáveis": "reciprocar",
    "reciproque": "reciprocar",
    "reciproquei": "reciprocar",
    "reciproqueis": "reciprocar",
    "reciproquem": "reciprocar",
    "reciproquemos": "reciprocar",
    "reciproques": "reciprocar",
    "recita": "recitar",
    "recitada": "recitar",
    "recitadas": "recitar",
    "recitado": "recitar",
    "recitadora": "recitador",
    "recitadoras": "recitador",
    "recitadores": "recitador",
    "recitados": "recitar",
    "recitai": "recitar",
    "recitais": "recitar",
    "recitam": "recitar",
    "recitamo": "recitar",
    "recitamos": "recitar",
    "recitando": "recitar",
    "recitantes": "recitante",
    "recitara": "recitar",
    "recitaram": "recitar",
    "recitaras": "recitar",
    "recitarde": "recitar",
    "recitardes": "recitar",
    "recitare": "recitar",
    "recitarei": "recitar",
    "recitareis": "recitar",
    "recitarem": "recitar",
    "recitaremos": "recitar",
    "recitares": "recitar",
    "recitaria": "recitar",
    "recitariam": "recitar",
    "recitarias": "recitar",
    "recitarmo": "recitar",
    "recitarmos": "recitar",
    "recitará": "recitar",
    "recitarás": "recitar",
    "recitarão": "recitar",
    "recitaríamos": "recitar",
    "recitaríeis": "recitar",
    "recitas": "recitar",
    "recitasse": "recitar",
    "recitassem": "recitar",
    "recitasses": "recitar",
    "recitaste": "recitar",
    "recitastes": "recitar",
    "recitativa": "recitativo",
    "recitativas": "recitativo",
    "recitativos": "recitativo",
    "recitava": "recitar",
    "recitavam": "recitar",
    "recitavas": "recitar",
    "recitações": "recitação",
    "recite": "recitar",
    "recitei": "recitar",
    "reciteis": "recitar",
    "recitem": "recitar",
    "recitemo": "recitar",
    "recitemos": "recitar",
    "recites": "recitar",
    "recito": "recitar",
    "recitou": "recitar",
    "recitá": "recitar",
    "recitámo": "recitar",
    "recitámos": "recitar",
    "recitáramo": "recitar",
    "recitáramos": "recitar",
    "recitárei": "recitar",
    "recitáreis": "recitar",
    "recitásseis": "recitar",
    "recitássemos": "recitar",
    "recitávamo": "recitar",
    "recitávamos": "recitar",
    "recitávei": "recitar",
    "recitáveis": "recitar",
    "recivilizada": "recivilizado",
    "recivilizadas": "recivilizado",
    "recivilizados": "recivilizado",
    "recivistas": "recivista",
    "reciários": "reciário",
    "reclama": "reclamar",
    "reclamada": "reclamar",
    "reclamadas": "reclamar",
    "reclamado": "reclamar",
    "reclamadora": "reclamador",
    "reclamadoras": "reclamador",
    "reclamadores": "reclamador",
    "reclamados": "reclamar",
    "reclamai": "reclamar",
    "reclamais": "reclamar",
    "reclamam": "reclamar",
    "reclamamo": "reclamar",
    "reclamamos": "reclamar",
    "reclamando": "reclamar",
    "reclamantes": "reclamante",
    "reclamara": "reclamar",
    "reclamaram": "reclamar",
    "reclamaras": "reclamar",
    "reclamarde": "reclamar",
    "reclamardes": "reclamar",
    "reclamare": "reclamar",
    "reclamarei": "reclamar",
    "reclamareis": "reclamar",
    "reclamarem": "reclamar",
    "reclamaremos": "reclamar",
    "reclamares": "reclamar",
    "reclamaria": "reclamar",
    "reclamariam": "reclamar",
    "reclamarias": "reclamar",
    "reclamarmo": "reclamar",
    "reclamarmos": "reclamar",
    "reclamará": "reclamar",
    "reclamarás": "reclamar",
    "reclamarão": "reclamar",
    "reclamaríamos": "reclamar",
    "reclamaríeis": "reclamar",
    "reclamas": "reclamar",
    "reclamasse": "reclamar",
    "reclamassem": "reclamar",
    "reclamasses": "reclamar",
    "reclamaste": "reclamar",
    "reclamastes": "reclamar",
    "reclamava": "reclamar",
    "reclamavam": "reclamar",
    "reclamavas": "reclamar",
    "reclamações": "reclamação",
    "reclame": "reclamar",
    "reclamei": "reclamar",
    "reclameis": "reclamar",
    "reclamem": "reclamar",
    "reclamemo": "reclamar",
    "reclamemos": "reclamar",
    "reclames": "reclame",
    "reclamistas": "reclamista",
    "reclamo": "reclamar",
    "reclamos": "reclamo",
    "reclamou": "reclamar",
    "reclamá": "reclamar",
    "reclamámo": "reclamar",
    "reclamámos": "reclamar",
    "reclamáramo": "reclamar",
    "reclamáramos": "reclamar",
    "reclamárei": "reclamar",
    "reclamáreis": "reclamar",
    "reclamásseis": "reclamar",
    "reclamássemos": "reclamar",
    "reclamávamo": "reclamar",
    "reclamávamos": "reclamar",
    "reclamávei": "reclamar",
    "reclamáveis": "reclamável",
    "reclassifica": "reclassificar",
    "reclassificada": "reclassificar",
    "reclassificadas": "reclassificar",
    "reclassificado": "reclassificar",
    "reclassificados": "reclassificar",
    "reclassificai": "reclassificar",
    "reclassificais": "reclassificar",
    "reclassificam": "reclassificar",
    "reclassificamo": "reclassificar",
    "reclassificamos": "reclassificar",
    "reclassificando": "reclassificar",
    "reclassificara": "reclassificar",
    "reclassificaram": "reclassificar",
    "reclassificaras": "reclassificar",
    "reclassificarde": "reclassificar",
    "reclassificardes": "reclassificar",
    "reclassificare": "reclassificar",
    "reclassificarei": "reclassificar",
    "reclassificareis": "reclassificar",
    "reclassificarem": "reclassificar",
    "reclassificaremos": "reclassificar",
    "reclassificares": "reclassificar",
    "reclassificaria": "reclassificar",
    "reclassificariam": "reclassificar",
    "reclassificarias": "reclassificar",
    "reclassificarmo": "reclassificar",
    "reclassificarmos": "reclassificar",
    "reclassificará": "reclassificar",
    "reclassificarás": "reclassificar",
    "reclassificarão": "reclassificar",
    "reclassificaríamos": "reclassificar",
    "reclassificaríeis": "reclassificar",
    "reclassificas": "reclassificar",
    "reclassificasse": "reclassificar",
    "reclassificassem": "reclassificar",
    "reclassificasses": "reclassificar",
    "reclassificaste": "reclassificar",
    "reclassificastes": "reclassificar",
    "reclassificava": "reclassificar",
    "reclassificavam": "reclassificar",
    "reclassificavas": "reclassificar",
    "reclassificações": "reclassificação",
    "reclassifico": "reclassificar",
    "reclassificou": "reclassificar",
    "reclassificá": "reclassificar",
    "reclassificámo": "reclassificar",
    "reclassificámos": "reclassificar",
    "reclassificáramo": "reclassificar",
    "reclassificáramos": "reclassificar",
    "reclassificárei": "reclassificar",
    "reclassificáreis": "reclassificar",
    "reclassificásseis": "reclassificar",
    "reclassificássemos": "reclassificar",
    "reclassificávamo": "reclassificar",
    "reclassificávamos": "reclassificar",
    "reclassificávei": "reclassificar",
    "reclassificáveis": "reclassificar",
    "reclassifique": "reclassificar",
    "reclassifiquei": "reclassificar",
    "reclassifiqueis": "reclassificar",
    "reclassifiquem": "reclassificar",
    "reclassifiquemo": "reclassificar",
    "reclassifiquemos": "reclassificar",
    "reclassifiques": "reclassificar",
    "reclina": "reclinar",
    "reclinada": "reclinar",
    "reclinadas": "reclinar",
    "reclinado": "reclinar",
    "reclinados": "reclinar",
    "reclinai": "reclinar",
    "reclinais": "reclinar",
    "reclinam": "reclinar",
    "reclinamo": "reclinar",
    "reclinamos": "reclinar",
    "reclinando": "reclinar",
    "reclinara": "reclinar",
    "reclinaram": "reclinar",
    "reclinaras": "reclinar",
    "reclinarde": "reclinar",
    "reclinardes": "reclinar",
    "reclinare": "reclinar",
    "reclinarei": "reclinar",
    "reclinareis": "reclinar",
    "reclinarem": "reclinar",
    "reclinaremos": "reclinar",
    "reclinares": "reclinar",
    "reclinaria": "reclinar",
    "reclinariam": "reclinar",
    "reclinarias": "reclinar",
    "reclinarmo": "reclinar",
    "reclinarmos": "reclinar",
    "reclinará": "reclinar",
    "reclinarás": "reclinar",
    "reclinarão": "reclinar",
    "reclinaríamos": "reclinar",
    "reclinaríeis": "reclinar",
    "reclinas": "reclinar",
    "reclinasse": "reclinar",
    "reclinassem": "reclinar",
    "reclinasses": "reclinar",
    "reclinaste": "reclinar",
    "reclinastes": "reclinar",
    "reclinatórios": "reclinatório",
    "reclinava": "reclinar",
    "reclinavam": "reclinar",
    "reclinavas": "reclinar",
    "reclinações": "reclinação",
    "recline": "reclinar",
    "reclinei": "reclinar",
    "reclineis": "reclinar",
    "reclinem": "reclinar",
    "reclinemo": "reclinar",
    "reclinemos": "reclinar",
    "reclines": "reclinar",
    "reclino": "reclinar",
    "reclinou": "reclinar",
    "recliná": "reclinar",
    "reclinámo": "reclinar",
    "reclinámos": "reclinar",
    "reclináramo": "reclinar",
    "reclináramos": "reclinar",
    "reclinárei": "reclinar",
    "reclináreis": "reclinar",
    "reclinásseis": "reclinar",
    "reclinássemos": "reclinar",
    "reclinávamo": "reclinar",
    "reclinávamos": "reclinar",
    "reclinávei": "reclinar",
    "reclináveis": "reclinar",
    "reclua": "recluir",
    "recluais": "recluir",
    "recluam": "recluir",
    "recluamo": "recluir",
    "recluamos": "recluir",
    "recluas": "recluir",
    "recluem": "recluir",
    "reclui": "recluir",
    "recluindo": "recluir",
    "recluirde": "recluir",
    "recluirdes": "recluir",
    "recluirei": "recluir",
    "recluireis": "recluir",
    "recluiremos": "recluir",
    "recluiria": "recluir",
    "recluiriam": "recluir",
    "recluirias": "recluir",
    "recluirmo": "recluir",
    "recluirmos": "recluir",
    "recluirá": "recluir",
    "recluirás": "recluir",
    "recluirão": "recluir",
    "recluiríamos": "recluir",
    "recluiríeis": "recluir",
    "recluis": "recluir",
    "recluiu": "recluir",
    "recluo": "recluir",
    "reclusa": "recluso",
    "reclusas": "recluso",
    "reclusos": "recluso",
    "reclusões": "reclusão",
    "recluí": "recluir",
    "recluía": "recluir",
    "recluíam": "recluir",
    "recluíamo": "recluir",
    "recluíamos": "recluir",
    "recluías": "recluir",
    "recluída": "recluir",
    "recluídas": "recluir",
    "recluído": "recluir",
    "recluídos": "recluir",
    "recluíei": "recluir",
    "recluíeis": "recluir",
    "recluímo": "recluir",
    "recluímos": "recluir",
    "recluíra": "recluir",
    "recluíram": "recluir",
    "recluíramo": "recluir",
    "recluíramos": "recluir",
    "recluíras": "recluir",
    "recluíre": "recluir",
    "recluírei": "recluir",
    "recluíreis": "recluir",
    "recluírem": "recluir",
    "recluíres": "recluir",
    "recluís": "recluir",
    "recluísse": "recluir",
    "recluísseis": "recluir",
    "recluíssem": "recluir",
    "recluíssemos": "recluir",
    "recluísses": "recluir",
    "recluíste": "recluir",
    "recluístes": "recluir",
    "recoberta": "recobrir",
    "recobertas": "recobrir",
    "recoberto": "recobrir",
    "recobertos": "recobrir",
    "recobra": "recobrar",
    "recobrada": "recobrar",
    "recobradas": "recobrar",
    "recobrado": "recobrar",
    "recobrados": "recobrar",
    "recobrai": "recobrar",
    "recobrais": "recobrar",
    "recobram": "recobrar",
    "recobramo": "recobrar",
    "recobramos": "recobrar",
    "recobrando": "recobrar",
    "recobrara": "recobrar",
    "recobraram": "recobrar",
    "recobraras": "recobrar",
    "recobrarde": "recobrar",
    "recobrardes": "recobrar",
    "recobrare": "recobrar",
    "recobrarei": "recobrar",
    "recobrareis": "recobrar",
    "recobrarem": "recobrar",
    "recobraremos": "recobrar",
    "recobrares": "recobrar",
    "recobraria": "recobrar",
    "recobrariam": "recobrar",
    "recobrarias": "recobrar",
    "recobrarmo": "recobrar",
    "recobrarmos": "recobrar",
    "recobrará": "recobrar",
    "recobrarás": "recobrar",
    "recobrarão": "recobrar",
    "recobraríamos": "recobrar",
    "recobraríeis": "recobrar",
    "recobras": "recobrar",
    "recobrasse": "recobrar",
    "recobrassem": "recobrar",
    "recobrasses": "recobrar",
    "recobraste": "recobrar",
    "recobrastes": "recobrar",
    "recobrava": "recobrar",
    "recobravam": "recobrar",
    "recobravas": "recobrar",
    "recobre": "recobrir",
    "recobrei": "recobrar",
    "recobreis": "recobrar",
    "recobrem": "recobrir",
    "recobremo": "recobrar",
    "recobremos": "recobrar",
    "recobres": "recobrir",
    "recobri": "recobrir",
    "recobria": "recobrir",
    "recobriam": "recobrir",
    "recobrias": "recobrir",
    "recobrida": "recobrir",
    "recobridas": "recobrir",
    "recobrido": "recobrir",
    "recobridos": "recobrir",
    "recobrimentos": "recobrimento",
    "recobrimo": "recobrir",
    "recobrimos": "recobrir",
    "recobrindo": "recobrir",
    "recobrira": "recobrir",
    "recobriram": "recobrir",
    "recobriras": "recobrir",
    "recobrirde": "recobrir",
    "recobrirdes": "recobrir",
    "recobrire": "recobrir",
    "recobrirei": "recobrir",
    "recobrireis": "recobrir",
    "recobrirem": "recobrir",
    "recobriremos": "recobrir",
    "recobrires": "recobrir",
    "recobriria": "recobrir",
    "recobririam": "recobrir",
    "recobririas": "recobrir",
    "recobrirmo": "recobrir",
    "recobrirmos": "recobrir",
    "recobrirá": "recobrir",
    "recobrirás": "recobrir",
    "recobrirão": "recobrir",
    "recobriríamos": "recobrir",
    "recobriríeis": "recobrir",
    "recobris": "recobrir",
    "recobrisse": "recobrir",
    "recobrissem": "recobrir",
    "recobrisses": "recobrir",
    "recobriste": "recobrir",
    "recobristes": "recobrir",
    "recobriu": "recobrir",
    "recobro": "recobrar",
    "recobros": "recobro",
    "recobrou": "recobrar",
    "recobrá": "recobrar",
    "recobrámo": "recobrar",
    "recobrámos": "recobrar",
    "recobráramo": "recobrar",
    "recobráramos": "recobrar",
    "recobrárei": "recobrar",
    "recobráreis": "recobrar",
    "recobrásseis": "recobrar",
    "recobrássemos": "recobrar",
    "recobrávamo": "recobrar",
    "recobrávamos": "recobrar",
    "recobrávei": "recobrar",
    "recobráveis": "recobrável",
    "recobríamo": "recobrir",
    "recobríamos": "recobrir",
    "recobríei": "recobrir",
    "recobríeis": "recobrir",
    "recobríramo": "recobrir",
    "recobríramos": "recobrir",
    "recobrírei": "recobrir",
    "recobríreis": "recobrir",
    "recobrísseis": "recobrir",
    "recobríssemos": "recobrir",
    "recogita": "recogitar",
    "recogitada": "recogitar",
    "recogitadas": "recogitar",
    "recogitado": "recogitar",
    "recogitados": "recogitar",
    "recogitai": "recogitar",
    "recogitais": "recogitar",
    "recogitam": "recogitar",
    "recogitamo": "recogitar",
    "recogitamos": "recogitar",
    "recogitando": "recogitar",
    "recogitara": "recogitar",
    "recogitaram": "recogitar",
    "recogitaras": "recogitar",
    "recogitardes": "recogitar",
    "recogitarei": "recogitar",
    "recogitareis": "recogitar",
    "recogitarem": "recogitar",
    "recogitaremos": "recogitar",
    "recogitares": "recogitar",
    "recogitaria": "recogitar",
    "recogitariam": "recogitar",
    "recogitarias": "recogitar",
    "recogitarmo": "recogitar",
    "recogitarmos": "recogitar",
    "recogitará": "recogitar",
    "recogitarás": "recogitar",
    "recogitarão": "recogitar",
    "recogitaríamos": "recogitar",
    "recogitaríeis": "recogitar",
    "recogitas": "recogitar",
    "recogitasse": "recogitar",
    "recogitassem": "recogitar",
    "recogitasses": "recogitar",
    "recogitaste": "recogitar",
    "recogitastes": "recogitar",
    "recogitava": "recogitar",
    "recogitavam": "recogitar",
    "recogitavas": "recogitar",
    "recogite": "recogitar",
    "recogitei": "recogitar",
    "recogiteis": "recogitar",
    "recogitem": "recogitar",
    "recogitemo": "recogitar",
    "recogitemos": "recogitar",
    "recogites": "recogitar",
    "recogito": "recogitar",
    "recogitou": "recogitar",
    "recogitámo": "recogitar",
    "recogitámos": "recogitar",
    "recogitáramo": "recogitar",
    "recogitáramos": "recogitar",
    "recogitáreis": "recogitar",
    "recogitásseis": "recogitar",
    "recogitássemos": "recogitar",
    "recogitávamo": "recogitar",
    "recogitávamos": "recogitar",
    "recogitáveis": "recogitar",
    "recognitiva": "recognitivo",
    "recognitivas": "recognitivo",
    "recognitivos": "recognitivo",
    "recognições": "recognição",
    "recognoscíveis": "recognoscível",
    "recoita": "recoito",
    "recoitada": "recoitar",
    "recoitadas": "recoitar",
    "recoitado": "recoitar",
    "recoitados": "recoitar",
    "recoitai": "recoitar",
    "recoitais": "recoitar",
    "recoitam": "recoitar",
    "recoitamo": "recoitar",
    "recoitamos": "recoitar",
    "recoitando": "recoitar",
    "recoitara": "recoitar",
    "recoitaram": "recoitar",
    "recoitaras": "recoitar",
    "recoitarde": "recoitar",
    "recoitardes": "recoitar",
    "recoitare": "recoitar",
    "recoitarei": "recoitar",
    "recoitareis": "recoitar",
    "recoitarem": "recoitar",
    "recoitaremos": "recoitar",
    "recoitares": "recoitar",
    "recoitaria": "recoitar",
    "recoitariam": "recoitar",
    "recoitarias": "recoitar",
    "recoitarmo": "recoitar",
    "recoitarmos": "recoitar",
    "recoitará": "recoitar",
    "recoitarás": "recoitar",
    "recoitarão": "recoitar",
    "recoitaríamos": "recoitar",
    "recoitaríeis": "recoitar",
    "recoitas": "recoito",
    "recoitasse": "recoitar",
    "recoitassem": "recoitar",
    "recoitasses": "recoitar",
    "recoitaste": "recoitar",
    "recoitastes": "recoitar",
    "recoitava": "recoitar",
    "recoitavam": "recoitar",
    "recoitavas": "recoitar",
    "recoite": "recoitar",
    "recoitei": "recoitar",
    "recoiteis": "recoitar",
    "recoitem": "recoitar",
    "recoitemo": "recoitar",
    "recoitemos": "recoitar",
    "recoites": "recoitar",
    "recoito": "recoitar",
    "recoitos": "recoito",
    "recoitou": "recoitar",
    "recoitá": "recoitar",
    "recoitámo": "recoitar",
    "recoitámos": "recoitar",
    "recoitáramo": "recoitar",
    "recoitáramos": "recoitar",
    "recoitárei": "recoitar",
    "recoitáreis": "recoitar",
    "recoitásseis": "recoitar",
    "recoitássemos": "recoitar",
    "recoitávamo": "recoitar",
    "recoitávamos": "recoitar",
    "recoitávei": "recoitar",
    "recoitáveis": "recoitar",
    "recola": "recolar",
    "recolada": "recolar",
    "recoladas": "recolar",
    "recolado": "recolar",
    "recolados": "recolar",
    "recolagens": "recolagem",
    "recolai": "recolar",
    "recolais": "recolar",
    "recolam": "recolar",
    "recolamo": "recolar",
    "recolamos": "recolar",
    "recolando": "recolar",
    "recolara": "recolar",
    "recolaram": "recolar",
    "recolaras": "recolar",
    "recolarde": "recolar",
    "recolardes": "recolar",
    "recolare": "recolar",
    "recolarei": "recolar",
    "recolareis": "recolar",
    "recolarem": "recolar",
    "recolaremos": "recolar",
    "recolares": "recolar",
    "recolaria": "recolar",
    "recolariam": "recolar",
    "recolarias": "recolar",
    "recolarmo": "recolar",
    "recolarmos": "recolar",
    "recolará": "recolar",
    "recolarás": "recolar",
    "recolarão": "recolar",
    "recolaríamos": "recolar",
    "recolaríeis": "recolar",
    "recolas": "recolar",
    "recolasse": "recolar",
    "recolassem": "recolar",
    "recolasses": "recolar",
    "recolaste": "recolar",
    "recolastes": "recolar",
    "recolava": "recolar",
    "recolavam": "recolar",
    "recolavas": "recolar",
    "recole": "recolar",
    "recolecções": "recolecção",
    "recolei": "recolar",
    "recoleis": "recolar",
    "recolem": "recolar",
    "recolemo": "recolar",
    "recolemos": "recolar",
    "recoles": "recolar",
    "recolha": "recolher",
    "recolhais": "recolher",
    "recolham": "recolher",
    "recolhamo": "recolher",
    "recolhamos": "recolher",
    "recolhas": "recolher",
    "recolhe": "recolher",
    "recolhei": "recolher",
    "recolheis": "recolher",
    "recolheitas": "recolheita",
    "recolhem": "recolher",
    "recolhemo": "recolher",
    "recolhemos": "recolher",
    "recolhendo": "recolher",
    "recolhera": "recolher",
    "recolheram": "recolher",
    "recolheras": "recolher",
    "recolherde": "recolher",
    "recolherdes": "recolher",
    "recolhere": "recolher",
    "recolherei": "recolher",
    "recolhereis": "recolher",
    "recolherem": "recolher",
    "recolheremos": "recolher",
    "recolheres": "recolher",
    "recolheria": "recolher",
    "recolheriam": "recolher",
    "recolherias": "recolher",
    "recolhermo": "recolher",
    "recolhermos": "recolher",
    "recolherá": "recolher",
    "recolherás": "recolher",
    "recolherão": "recolher",
    "recolheríamos": "recolher",
    "recolheríeis": "recolher",
    "recolhes": "recolher",
    "recolhesse": "recolher",
    "recolhessem": "recolher",
    "recolhesses": "recolher",
    "recolheste": "recolher",
    "recolhestes": "recolher",
    "recolheu": "recolher",
    "recolhi": "recolher",
    "recolhia": "recolher",
    "recolhiam": "recolher",
    "recolhias": "recolher",
    "recolhida": "recolhido",
    "recolhidas": "recolhido",
    "recolhidazinha": "recolhido",
    "recolhidazinhas": "recolhido",
    "recolhidazita": "recolhido",
    "recolhidazitas": "recolhido",
    "recolhidinha": "recolhido",
    "recolhidinhas": "recolhido",
    "recolhidinho": "recolhido",
    "recolhidinhos": "recolhido",
    "recolhidita": "recolhido",
    "recolhiditas": "recolhido",
    "recolhidito": "recolhido",
    "recolhiditos": "recolhido",
    "recolhido": "recolher",
    "recolhidos": "recolhido",
    "recolhidozinho": "recolhido",
    "recolhidozinhos": "recolhido",
    "recolhidozito": "recolhido",
    "recolhidozitos": "recolhido",
    "recolhidíssima": "recolhido",
    "recolhidíssimas": "recolhido",
    "recolhidíssimo": "recolhido",
    "recolhidíssimos": "recolhido",
    "recolhimentos": "recolhimento",
    "recolho": "recolher",
    "recolhos": "recolho",
    "recolhê": "recolher",
    "recolhêramo": "recolher",
    "recolhêramos": "recolher",
    "recolhêrei": "recolher",
    "recolhêreis": "recolher",
    "recolhêsseis": "recolher",
    "recolhêssemos": "recolher",
    "recolhíamo": "recolher",
    "recolhíamos": "recolher",
    "recolhíei": "recolher",
    "recolhíeis": "recolher",
    "recolo": "recolar",
    "recoloca": "recolocar",
    "recolocada": "recolocar",
    "recolocadas": "recolocar",
    "recolocado": "recolocar",
    "recolocados": "recolocar",
    "recolocai": "recolocar",
    "recolocais": "recolocar",
    "recolocam": "recolocar",
    "recolocamo": "recolocar",
    "recolocamos": "recolocar",
    "recolocando": "recolocar",
    "recolocara": "recolocar",
    "recolocaram": "recolocar",
    "recolocaras": "recolocar",
    "recolocarde": "recolocar",
    "recolocardes": "recolocar",
    "recolocare": "recolocar",
    "recolocarei": "recolocar",
    "recolocareis": "recolocar",
    "recolocarem": "recolocar",
    "recolocaremos": "recolocar",
    "recolocares": "recolocar",
    "recolocaria": "recolocar",
    "recolocariam": "recolocar",
    "recolocarias": "recolocar",
    "recolocarmo": "recolocar",
    "recolocarmos": "recolocar",
    "recolocará": "recolocar",
    "recolocarás": "recolocar",
    "recolocarão": "recolocar",
    "recolocaríamos": "recolocar",
    "recolocaríeis": "recolocar",
    "recolocas": "recolocar",
    "recolocasse": "recolocar",
    "recolocassem": "recolocar",
    "recolocasses": "recolocar",
    "recolocaste": "recolocar",
    "recolocastes": "recolocar",
    "recolocava": "recolocar",
    "recolocavam": "recolocar",
    "recolocavas": "recolocar",
    "recolocações": "recolocação",
    "recoloco": "recolocar",
    "recolocou": "recolocar",
    "recolocá": "recolocar",
    "recolocámo": "recolocar",
    "recolocámos": "recolocar",
    "recolocáramo": "recolocar",
    "recolocáramos": "recolocar",
    "recolocárei": "recolocar",
    "recolocáreis": "recolocar",
    "recolocásseis": "recolocar",
    "recolocássemos": "recolocar",
    "recolocávamo": "recolocar",
    "recolocávamos": "recolocar",
    "recolocávei": "recolocar",
    "recolocáveis": "recolocar",
    "recolonizações": "recolonização",
    "recoloque": "recolocar",
    "recoloquei": "recolocar",
    "recoloqueis": "recolocar",
    "recoloquem": "recolocar",
    "recoloquemo": "recolocar",
    "recoloquemos": "recolocar",
    "recoloques": "recolocar",
    "recolou": "recolar",
    "recolta": "recoltar",
    "recoltada": "recoltar",
    "recoltadas": "recoltar",
    "recoltado": "recoltar",
    "recoltados": "recoltar",
    "recoltai": "recoltar",
    "recoltais": "recoltar",
    "recoltam": "recoltar",
    "recoltamo": "recoltar",
    "recoltamos": "recoltar",
    "recoltando": "recoltar",
    "recoltara": "recoltar",
    "recoltaram": "recoltar",
    "recoltaras": "recoltar",
    "recoltarde": "recoltar",
    "recoltardes": "recoltar",
    "recoltare": "recoltar",
    "recoltarei": "recoltar",
    "recoltareis": "recoltar",
    "recoltarem": "recoltar",
    "recoltaremos": "recoltar",
    "recoltares": "recoltar",
    "recoltaria": "recoltar",
    "recoltariam": "recoltar",
    "recoltarias": "recoltar",
    "recoltarmo": "recoltar",
    "recoltarmos": "recoltar",
    "recoltará": "recoltar",
    "recoltarás": "recoltar",
    "recoltarão": "recoltar",
    "recoltaríamos": "recoltar",
    "recoltaríeis": "recoltar",
    "recoltas": "recoltar",
    "recoltasse": "recoltar",
    "recoltassem": "recoltar",
    "recoltasses": "recoltar",
    "recoltaste": "recoltar",
    "recoltastes": "recoltar",
    "recoltava": "recoltar",
    "recoltavam": "recoltar",
    "recoltavas": "recoltar",
    "recolte": "recoltar",
    "recoltei": "recoltar",
    "recolteis": "recoltar",
    "recoltem": "recoltar",
    "recoltemo": "recoltar",
    "recoltemos": "recoltar",
    "recoltes": "recoltar",
    "recolto": "recoltar",
    "recoltou": "recoltar",
    "recoltá": "recoltar",
    "recoltámo": "recoltar",
    "recoltámos": "recoltar",
    "recoltáramo": "recoltar",
    "recoltáramos": "recoltar",
    "recoltárei": "recoltar",
    "recoltáreis": "recoltar",
    "recoltásseis": "recoltar",
    "recoltássemos": "recoltar",
    "recoltávamo": "recoltar",
    "recoltávamos": "recoltar",
    "recoltávei": "recoltar",
    "recoltáveis": "recoltar",
    "recolá": "recolar",
    "recolámo": "recolar",
    "recolámos": "recolar",
    "recoláramo": "recolar",
    "recoláramos": "recolar",
    "recolárei": "recolar",
    "recoláreis": "recolar",
    "recolásseis": "recolar",
    "recolássemos": "recolar",
    "recolávamo": "recolar",
    "recolávamos": "recolar",
    "recolávei": "recolar",
    "recoláveis": "recolar",
    "recombinações": "recombinação",
    "recomece": "recomeçar",
    "recomecei": "recomeçar",
    "recomeceis": "recomeçar",
    "recomecem": "recomeçar",
    "recomecemo": "recomeçar",
    "recomecemos": "recomeçar",
    "recomeces": "recomeçar",
    "recomenda": "recomendar",
    "recomendada": "recomendar",
    "recomendadas": "recomendar",
    "recomendado": "recomendar",
    "recomendados": "recomendar",
    "recomendadíssima": "recomendado",
    "recomendadíssimas": "recomendado",
    "recomendadíssimo": "recomendado",
    "recomendadíssimos": "recomendado",
    "recomendai": "recomendar",
    "recomendais": "recomendar",
    "recomendam": "recomendar",
    "recomendamo": "recomendar",
    "recomendamos": "recomendar",
    "recomendando": "recomendar",
    "recomendara": "recomendar",
    "recomendaram": "recomendar",
    "recomendaras": "recomendar",
    "recomendarde": "recomendar",
    "recomendardes": "recomendar",
    "recomendare": "recomendar",
    "recomendarei": "recomendar",
    "recomendareis": "recomendar",
    "recomendarem": "recomendar",
    "recomendaremos": "recomendar",
    "recomendares": "recomendar",
    "recomendaria": "recomendar",
    "recomendariam": "recomendar",
    "recomendarias": "recomendar",
    "recomendarmo": "recomendar",
    "recomendarmos": "recomendar",
    "recomendará": "recomendar",
    "recomendarás": "recomendar",
    "recomendarão": "recomendar",
    "recomendaríamos": "recomendar",
    "recomendaríeis": "recomendar",
    "recomendas": "recomendar",
    "recomendasse": "recomendar",
    "recomendassem": "recomendar",
    "recomendasses": "recomendar",
    "recomendaste": "recomendar",
    "recomendastes": "recomendar",
    "recomendatória": "recomendatório",
    "recomendatórias": "recomendatório",
    "recomendatórios": "recomendatório",
    "recomendava": "recomendar",
    "recomendavam": "recomendar",
    "recomendavas": "recomendar",
    "recomendações": "recomendação",
    "recomende": "recomendar",
    "recomendei": "recomendar",
    "recomendeis": "recomendar",
    "recomendem": "recomendar",
    "recomendemo": "recomendar",
    "recomendemos": "recomendar",
    "recomendes": "recomendar",
    "recomendo": "recomendar",
    "recomendou": "recomendar",
    "recomendá": "recomendar",
    "recomendámo": "recomendar",
    "recomendámos": "recomendar",
    "recomendáramo": "recomendar",
    "recomendáramos": "recomendar",
    "recomendárei": "recomendar",
    "recomendáreis": "recomendar",
    "recomendásseis": "recomendar",
    "recomendássemos": "recomendar",
    "recomendávamo": "recomendar",
    "recomendávamos": "recomendar",
    "recomendávei": "recomendar",
    "recomendáveis": "recomendável",
    "recomeça": "recomeçar",
    "recomeçada": "recomeçar",
    "recomeçadas": "recomeçar",
    "recomeçado": "recomeçar",
    "recomeçados": "recomeçar",
    "recomeçai": "recomeçar",
    "recomeçais": "recomeçar",
    "recomeçam": "recomeçar",
    "recomeçamo": "recomeçar",
    "recomeçamos": "recomeçar",
    "recomeçando": "recomeçar",
    "recomeçara": "recomeçar",
    "recomeçaram": "recomeçar",
    "recomeçaras": "recomeçar",
    "recomeçarde": "recomeçar",
    "recomeçardes": "recomeçar",
    "recomeçare": "recomeçar",
    "recomeçarei": "recomeçar",
    "recomeçareis": "recomeçar",
    "recomeçarem": "recomeçar",
    "recomeçaremos": "recomeçar",
    "recomeçares": "recomeçar",
    "recomeçaria": "recomeçar",
    "recomeçariam": "recomeçar",
    "recomeçarias": "recomeçar",
    "recomeçarmo": "recomeçar",
    "recomeçarmos": "recomeçar",
    "recomeçará": "recomeçar",
    "recomeçarás": "recomeçar",
    "recomeçarão": "recomeçar",
    "recomeçaríamos": "recomeçar",
    "recomeçaríeis": "recomeçar",
    "recomeças": "recomeçar",
    "recomeçasse": "recomeçar",
    "recomeçassem": "recomeçar",
    "recomeçasses": "recomeçar",
    "recomeçaste": "recomeçar",
    "recomeçastes": "recomeçar",
    "recomeçava": "recomeçar",
    "recomeçavam": "recomeçar",
    "recomeçavas": "recomeçar",
    "recomeço": "recomeçar",
    "recomeços": "recomeço",
    "recomeçou": "recomeçar",
    "recomeçá": "recomeçar",
    "recomeçámo": "recomeçar",
    "recomeçámos": "recomeçar",
    "recomeçáramo": "recomeçar",
    "recomeçáramos": "recomeçar",
    "recomeçárei": "recomeçar",
    "recomeçáreis": "recomeçar",
    "recomeçásseis": "recomeçar",
    "recomeçássemos": "recomeçar",
    "recomeçávamo": "recomeçar",
    "recomeçávamos": "recomeçar",
    "recomeçávei": "recomeçar",
    "recomeçáveis": "recomeçar",
    "recompensa": "recompensar",
    "recompensada": "recompensar",
    "recompensadas": "recompensar",
    "recompensado": "recompensar",
    "recompensadora": "recompensador",
    "recompensadoras": "recompensador",
    "recompensadores": "recompensador",
    "recompensados": "recompensar",
    "recompensai": "recompensar",
    "recompensais": "recompensar",
    "recompensam": "recompensar",
    "recompensamo": "recompensar",
    "recompensamos": "recompensar",
    "recompensando": "recompensar",
    "recompensara": "recompensar",
    "recompensaram": "recompensar",
    "recompensaras": "recompensar",
    "recompensarde": "recompensar",
    "recompensardes": "recompensar",
    "recompensare": "recompensar",
    "recompensarei": "recompensar",
    "recompensareis": "recompensar",
    "recompensarem": "recompensar",
    "recompensaremos": "recompensar",
    "recompensares": "recompensar",
    "recompensaria": "recompensar",
    "recompensariam": "recompensar",
    "recompensarias": "recompensar",
    "recompensarmo": "recompensar",
    "recompensarmos": "recompensar",
    "recompensará": "recompensar",
    "recompensarás": "recompensar",
    "recompensarão": "recompensar",
    "recompensaríamos": "recompensar",
    "recompensaríeis": "recompensar",
    "recompensas": "recompensar",
    "recompensasse": "recompensar",
    "recompensassem": "recompensar",
    "recompensasses": "recompensar",
    "recompensaste": "recompensar",
    "recompensastes": "recompensar",
    "recompensava": "recompensar",
    "recompensavam": "recompensar",
    "recompensavas": "recompensar",
    "recompensações": "recompensação",
    "recompense": "recompensar",
    "recompensei": "recompensar",
    "recompenseis": "recompensar",
    "recompensem": "recompensar",
    "recompensemo": "recompensar",
    "recompensemos": "recompensar",
    "recompenses": "recompensar",
    "recompenso": "recompensar",
    "recompensou": "recompensar",
    "recompensá": "recompensar",
    "recompensámo": "recompensar",
    "recompensámos": "recompensar",
    "recompensáramo": "recompensar",
    "recompensáramos": "recompensar",
    "recompensárei": "recompensar",
    "recompensáreis": "recompensar",
    "recompensásseis": "recompensar",
    "recompensássemos": "recompensar",
    "recompensávamo": "recompensar",
    "recompensávamos": "recompensar",
    "recompensávei": "recompensar",
    "recompensáveis": "recompensável",
    "recompila": "recompilar",
    "recompilada": "recompilar",
    "recompiladas": "recompilar",
    "recompilado": "recompilar",
    "recompiladora": "recompilador",
    "recompiladoras": "recompilador",
    "recompiladores": "recompilador",
    "recompilados": "recompilar",
    "recompilai": "recompilar",
    "recompilais": "recompilar",
    "recompilam": "recompilar",
    "recompilamo": "recompilar",
    "recompilamos": "recompilar",
    "recompilando": "recompilar",
    "recompilara": "recompilar",
    "recompilaram": "recompilar",
    "recompilaras": "recompilar",
    "recompilarde": "recompilar",
    "recompilardes": "recompilar",
    "recompilare": "recompilar",
    "recompilarei": "recompilar",
    "recompilareis": "recompilar",
    "recompilarem": "recompilar",
    "recompilaremos": "recompilar",
    "recompilares": "recompilar",
    "recompilaria": "recompilar",
    "recompilariam": "recompilar",
    "recompilarias": "recompilar",
    "recompilarmo": "recompilar",
    "recompilarmos": "recompilar",
    "recompilará": "recompilar",
    "recompilarás": "recompilar",
    "recompilarão": "recompilar",
    "recompilaríamos": "recompilar",
    "recompilaríeis": "recompilar",
    "recompilas": "recompilar",
    "recompilasse": "recompilar",
    "recompilassem": "recompilar",
    "recompilasses": "recompilar",
    "recompilaste": "recompilar",
    "recompilastes": "recompilar",
    "recompilatória": "recompilatório",
    "recompilatórias": "recompilatório",
    "recompilatórios": "recompilatório",
    "recompilava": "recompilar",
    "recompilavam": "recompilar",
    "recompilavas": "recompilar",
    "recompilações": "recompilação",
    "recompile": "recompilar",
    "recompilei": "recompilar",
    "recompileis": "recompilar",
    "recompilem": "recompilar",
    "recompilemo": "recompilar",
    "recompilemos": "recompilar",
    "recompiles": "recompilar",
    "recompilo": "recompilar",
    "recompilou": "recompilar",
    "recompilá": "recompilar",
    "recompilámo": "recompilar",
    "recompilámos": "recompilar",
    "recompiláramo": "recompilar",
    "recompiláramos": "recompilar",
    "recompilárei": "recompilar",
    "recompiláreis": "recompilar",
    "recompilásseis": "recompilar",
    "recompilássemos": "recompilar",
    "recompilávamo": "recompilar",
    "recompilávamos": "recompilar",
    "recompilávei": "recompilar",
    "recompiláveis": "recompilável",
    "recompomo": "recompor",
    "recompomos": "recompor",
    "recomponde": "recompor",
    "recompondes": "recompor",
    "recompondo": "recompor",
    "recomponentes": "recomponente",
    "recomponha": "recompor",
    "recomponhais": "recompor",
    "recomponham": "recompor",
    "recomponhamo": "recompor",
    "recomponhamos": "recompor",
    "recomponhas": "recompor",
    "recomponho": "recompor",
    "recomponíveis": "recomponível",
    "recomporde": "recompor",
    "recompordes": "recompor",
    "recompore": "recompor",
    "recomporei": "recompor",
    "recomporeis": "recompor",
    "recomporem": "recompor",
    "recomporemos": "recompor",
    "recompores": "recompor",
    "recomporia": "recompor",
    "recomporiam": "recompor",
    "recomporias": "recompor",
    "recompormo": "recompor",
    "recompormos": "recompor",
    "recomporá": "recompor",
    "recomporás": "recompor",
    "recomporão": "recompor",
    "recomporíamos": "recompor",
    "recomporíeis": "recompor",
    "recomposições": "recomposição",
    "recomposta": "recomposto",
    "recompostas": "recomposto",
    "recomposto": "recompor",
    "recompostos": "recomposto",
    "recompra": "recomprar",
    "recomprada": "recomprar",
    "recompradas": "recomprar",
    "recomprado": "recomprar",
    "recomprados": "recomprar",
    "recomprai": "recomprar",
    "recomprais": "recomprar",
    "recompram": "recomprar",
    "recompramo": "recomprar",
    "recompramos": "recomprar",
    "recomprando": "recomprar",
    "recomprara": "recomprar",
    "recompraram": "recomprar",
    "recompraras": "recomprar",
    "recomprarde": "recomprar",
    "recomprardes": "recomprar",
    "recomprare": "recomprar",
    "recomprarei": "recomprar",
    "recomprareis": "recomprar",
    "recomprarem": "recomprar",
    "recompraremos": "recomprar",
    "recomprares": "recomprar",
    "recompraria": "recomprar",
    "recomprariam": "recomprar",
    "recomprarias": "recomprar",
    "recomprarmo": "recomprar",
    "recomprarmos": "recomprar",
    "recomprará": "recomprar",
    "recomprarás": "recomprar",
    "recomprarão": "recomprar",
    "recompraríamos": "recomprar",
    "recompraríeis": "recomprar",
    "recompras": "recomprar",
    "recomprasse": "recomprar",
    "recomprassem": "recomprar",
    "recomprasses": "recomprar",
    "recompraste": "recomprar",
    "recomprastes": "recomprar",
    "recomprava": "recomprar",
    "recompravam": "recomprar",
    "recompravas": "recomprar",
    "recompre": "recomprar",
    "recomprei": "recomprar",
    "recompreis": "recomprar",
    "recomprem": "recomprar",
    "recompremo": "recomprar",
    "recompremos": "recomprar",
    "recompres": "recomprar",
    "recompro": "recomprar",
    "recomprou": "recomprar",
    "recomprá": "recomprar",
    "recomprámo": "recomprar",
    "recomprámos": "recomprar",
    "recompráramo": "recomprar",
    "recompráramos": "recomprar",
    "recomprárei": "recomprar",
    "recompráreis": "recomprar",
    "recomprásseis": "recomprar",
    "recomprássemos": "recomprar",
    "recomprávamo": "recomprar",
    "recomprávamos": "recomprar",
    "recomprávei": "recomprar",
    "recompráveis": "recomprável",
    "recompunha": "recompor",
    "recompunham": "recompor",
    "recompunhas": "recompor",
    "recompus": "recompor",
    "recompusemo": "recompor",
    "recompusemos": "recompor",
    "recompuser": "recompor",
    "recompusera": "recompor",
    "recompuseram": "recompor",
    "recompuseras": "recompor",
    "recompuserdes": "recompor",
    "recompuserem": "recompor",
    "recompuseres": "recompor",
    "recompusermos": "recompor",
    "recompusesse": "recompor",
    "recompusessem": "recompor",
    "recompusesses": "recompor",
    "recompuseste": "recompor",
    "recompusestes": "recompor",
    "recompuséramo": "recompor",
    "recompuséramos": "recompor",
    "recompusérei": "recompor",
    "recompuséreis": "recompor",
    "recompusésseis": "recompor",
    "recompuséssemos": "recompor",
    "recompô": "recompor",
    "recompôs": "recompor",
    "recompõe": "recompor",
    "recompõem": "recompor",
    "recompões": "recompor",
    "recompúnhamo": "recompor",
    "recompúnhamos": "recompor",
    "recompúnhei": "recompor",
    "recompúnheis": "recompor",
    "reconcentra": "reconcentrar",
    "reconcentrada": "reconcentrar",
    "reconcentradas": "reconcentrar",
    "reconcentrado": "reconcentrar",
    "reconcentrados": "reconcentrar",
    "reconcentrai": "reconcentrar",
    "reconcentrais": "reconcentrar",
    "reconcentram": "reconcentrar",
    "reconcentramo": "reconcentrar",
    "reconcentramos": "reconcentrar",
    "reconcentrando": "reconcentrar",
    "reconcentrara": "reconcentrar",
    "reconcentraram": "reconcentrar",
    "reconcentraras": "reconcentrar",
    "reconcentrarde": "reconcentrar",
    "reconcentrardes": "reconcentrar",
    "reconcentrare": "reconcentrar",
    "reconcentrarei": "reconcentrar",
    "reconcentrareis": "reconcentrar",
    "reconcentrarem": "reconcentrar",
    "reconcentraremos": "reconcentrar",
    "reconcentrares": "reconcentrar",
    "reconcentraria": "reconcentrar",
    "reconcentrariam": "reconcentrar",
    "reconcentrarias": "reconcentrar",
    "reconcentrarmo": "reconcentrar",
    "reconcentrarmos": "reconcentrar",
    "reconcentrará": "reconcentrar",
    "reconcentrarás": "reconcentrar",
    "reconcentrarão": "reconcentrar",
    "reconcentraríamos": "reconcentrar",
    "reconcentraríeis": "reconcentrar",
    "reconcentras": "reconcentrar",
    "reconcentrasse": "reconcentrar",
    "reconcentrassem": "reconcentrar",
    "reconcentrasses": "reconcentrar",
    "reconcentraste": "reconcentrar",
    "reconcentrastes": "reconcentrar",
    "reconcentrava": "reconcentrar",
    "reconcentravam": "reconcentrar",
    "reconcentravas": "reconcentrar",
    "reconcentrações": "reconcentração",
    "reconcentre": "reconcentrar",
    "reconcentrei": "reconcentrar",
    "reconcentreis": "reconcentrar",
    "reconcentrem": "reconcentrar",
    "reconcentremo": "reconcentrar",
    "reconcentremos": "reconcentrar",
    "reconcentres": "reconcentrar",
    "reconcentro": "reconcentrar",
    "reconcentrou": "reconcentrar",
    "reconcentrá": "reconcentrar",
    "reconcentrámo": "reconcentrar",
    "reconcentrámos": "reconcentrar",
    "reconcentráramo": "reconcentrar",
    "reconcentráramos": "reconcentrar",
    "reconcentrárei": "reconcentrar",
    "reconcentráreis": "reconcentrar",
    "reconcentrásseis": "reconcentrar",
    "reconcentrássemos": "reconcentrar",
    "reconcentrávamo": "reconcentrar",
    "reconcentrávamos": "reconcentrar",
    "reconcentrávei": "reconcentrar",
    "reconcentráveis": "reconcentrar",
    "reconcerta": "reconcertar",
    "reconcertada": "reconcertar",
    "reconcertadas": "reconcertar",
    "reconcertado": "reconcertar",
    "reconcertados": "reconcertar",
    "reconcertai": "reconcertar",
    "reconcertais": "reconcertar",
    "reconcertam": "reconcertar",
    "reconcertamo": "reconcertar",
    "reconcertamos": "reconcertar",
    "reconcertando": "reconcertar",
    "reconcertara": "reconcertar",
    "reconcertaram": "reconcertar",
    "reconcertaras": "reconcertar",
    "reconcertarde": "reconcertar",
    "reconcertardes": "reconcertar",
    "reconcertare": "reconcertar",
    "reconcertarei": "reconcertar",
    "reconcertareis": "reconcertar",
    "reconcertarem": "reconcertar",
    "reconcertaremos": "reconcertar",
    "reconcertares": "reconcertar",
    "reconcertaria": "reconcertar",
    "reconcertariam": "reconcertar",
    "reconcertarias": "reconcertar",
    "reconcertarmo": "reconcertar",
    "reconcertarmos": "reconcertar",
    "reconcertará": "reconcertar",
    "reconcertarás": "reconcertar",
    "reconcertarão": "reconcertar",
    "reconcertaríamos": "reconcertar",
    "reconcertaríeis": "reconcertar",
    "reconcertas": "reconcertar",
    "reconcertasse": "reconcertar",
    "reconcertassem": "reconcertar",
    "reconcertasses": "reconcertar",
    "reconcertaste": "reconcertar",
    "reconcertastes": "reconcertar",
    "reconcertava": "reconcertar",
    "reconcertavam": "reconcertar",
    "reconcertavas": "reconcertar",
    "reconcerte": "reconcertar",
    "reconcertei": "reconcertar",
    "reconcerteis": "reconcertar",
    "reconcertem": "reconcertar",
    "reconcertemo": "reconcertar",
    "reconcertemos": "reconcertar",
    "reconcertes": "reconcertar",
    "reconcerto": "reconcertar",
    "reconcertos": "reconcerto",
    "reconcertou": "reconcertar",
    "reconcertá": "reconcertar",
    "reconcertámo": "reconcertar",
    "reconcertámos": "reconcertar",
    "reconcertáramo": "reconcertar",
    "reconcertáramos": "reconcertar",
    "reconcertárei": "reconcertar",
    "reconcertáreis": "reconcertar",
    "reconcertásseis": "reconcertar",
    "reconcertássemos": "reconcertar",
    "reconcertávamo": "reconcertar",
    "reconcertávamos": "reconcertar",
    "reconcertávei": "reconcertar",
    "reconcertáveis": "reconcertar",
    "reconcilia": "reconciliar",
    "reconciliada": "reconciliar",
    "reconciliadas": "reconciliar",
    "reconciliadazinha": "reconciliado",
    "reconciliadazinhas": "reconciliado",
    "reconciliadazita": "reconciliado",
    "reconciliadazitas": "reconciliado",
    "reconciliadinha": "reconciliado",
    "reconciliadinhas": "reconciliado",
    "reconciliadinho": "reconciliado",
    "reconciliadinhos": "reconciliado",
    "reconciliadita": "reconciliado",
    "reconciliaditas": "reconciliado",
    "reconciliadito": "reconciliado",
    "reconciliaditos": "reconciliado",
    "reconciliado": "reconciliar",
    "reconciliadora": "reconciliador",
    "reconciliadoras": "reconciliador",
    "reconciliadores": "reconciliador",
    "reconciliados": "reconciliar",
    "reconciliadozinho": "reconciliado",
    "reconciliadozinhos": "reconciliado",
    "reconciliadozito": "reconciliado",
    "reconciliadozitos": "reconciliado",
    "reconciliadíssima": "reconciliado",
    "reconciliadíssimas": "reconciliado",
    "reconciliadíssimo": "reconciliado",
    "reconciliadíssimos": "reconciliado",
    "reconciliai": "reconciliar",
    "reconciliais": "reconciliar",
    "reconciliam": "reconciliar",
    "reconciliamo": "reconciliar",
    "reconciliamos": "reconciliar",
    "reconciliando": "reconciliar",
    "reconciliara": "reconciliar",
    "reconciliaram": "reconciliar",
    "reconciliaras": "reconciliar",
    "reconciliarde": "reconciliar",
    "reconciliardes": "reconciliar",
    "reconciliare": "reconciliar",
    "reconciliarei": "reconciliar",
    "reconciliareis": "reconciliar",
    "reconciliarem": "reconciliar",
    "reconciliaremos": "reconciliar",
    "reconciliares": "reconciliar",
    "reconciliaria": "reconciliar",
    "reconciliariam": "reconciliar",
    "reconciliarias": "reconciliar",
    "reconciliarmo": "reconciliar",
    "reconciliarmos": "reconciliar",
    "reconciliará": "reconciliar",
    "reconciliarás": "reconciliar",
    "reconciliarão": "reconciliar",
    "reconciliaríamos": "reconciliar",
    "reconciliaríeis": "reconciliar",
    "reconcilias": "reconciliar",
    "reconciliasse": "reconciliar",
    "reconciliassem": "reconciliar",
    "reconciliasses": "reconciliar",
    "reconciliaste": "reconciliar",
    "reconciliastes": "reconciliar",
    "reconciliatória": "reconciliatório",
    "reconciliatórias": "reconciliatório",
    "reconciliatórios": "reconciliatório",
    "reconciliava": "reconciliar",
    "reconciliavam": "reconciliar",
    "reconciliavas": "reconciliar",
    "reconciliações": "reconciliação",
    "reconcilie": "reconciliar",
    "reconciliei": "reconciliar",
    "reconcilieis": "reconciliar",
    "reconciliem": "reconciliar",
    "reconciliemo": "reconciliar",
    "reconciliemos": "reconciliar",
    "reconcilies": "reconciliar",
    "reconcilio": "reconciliar",
    "reconciliou": "reconciliar",
    "reconciliá": "reconciliar",
    "reconciliámo": "reconciliar",
    "reconciliámos": "reconciliar",
    "reconciliáramo": "reconciliar",
    "reconciliáramos": "reconciliar",
    "reconciliárei": "reconciliar",
    "reconciliáreis": "reconciliar",
    "reconciliásseis": "reconciliar",
    "reconciliássemos": "reconciliar",
    "reconciliávamo": "reconciliar",
    "reconciliávamos": "reconciliar",
    "reconciliávei": "reconciliar",
    "reconciliáveis": "reconciliável",
    "reconditíssima": "recôndito",
    "reconditíssimas": "recôndito",
    "reconditíssimo": "recôndito",
    "reconditíssimos": "recôndito",
    "reconditórios": "reconditório",
    "reconduz": "reconduzir",
    "reconduza": "reconduzir",
    "reconduzais": "reconduzir",
    "reconduzam": "reconduzir",
    "reconduzamo": "reconduzir",
    "reconduzamos": "reconduzir",
    "reconduzas": "reconduzir",
    "reconduze": "reconduzir",
    "reconduzem": "reconduzir",
    "reconduzes": "reconduzir",
    "reconduzi": "reconduzir",
    "reconduzia": "reconduzir",
    "reconduziam": "reconduzir",
    "reconduzias": "reconduzir",
    "reconduzida": "reconduzir",
    "reconduzidas": "reconduzir",
    "reconduzido": "reconduzir",
    "reconduzidos": "reconduzir",
    "reconduzimo": "reconduzir",
    "reconduzimos": "reconduzir",
    "reconduzindo": "reconduzir",
    "reconduzira": "reconduzir",
    "reconduziram": "reconduzir",
    "reconduziras": "reconduzir",
    "reconduzirde": "reconduzir",
    "reconduzirdes": "reconduzir",
    "reconduzire": "reconduzir",
    "reconduzirei": "reconduzir",
    "reconduzireis": "reconduzir",
    "reconduzirem": "reconduzir",
    "reconduziremos": "reconduzir",
    "reconduzires": "reconduzir",
    "reconduziria": "reconduzir",
    "reconduziriam": "reconduzir",
    "reconduzirias": "reconduzir",
    "reconduzirmo": "reconduzir",
    "reconduzirmos": "reconduzir",
    "reconduzirá": "reconduzir",
    "reconduzirás": "reconduzir",
    "reconduzirão": "reconduzir",
    "reconduziríamos": "reconduzir",
    "reconduziríeis": "reconduzir",
    "reconduzis": "reconduzir",
    "reconduzisse": "reconduzir",
    "reconduzissem": "reconduzir",
    "reconduzisses": "reconduzir",
    "reconduziste": "reconduzir",
    "reconduzistes": "reconduzir",
    "reconduziu": "reconduzir",
    "reconduzo": "reconduzir",
    "reconduzíamo": "reconduzir",
    "reconduzíamos": "reconduzir",
    "reconduzíei": "reconduzir",
    "reconduzíeis": "reconduzir",
    "reconduzíramo": "reconduzir",
    "reconduzíramos": "reconduzir",
    "reconduzírei": "reconduzir",
    "reconduzíreis": "reconduzir",
    "reconduzísseis": "reconduzir",
    "reconduzíssemos": "reconduzir",
    "reconduções": "recondução",
    "reconfessa": "reconfessar",
    "reconfessada": "reconfessar",
    "reconfessadas": "reconfessar",
    "reconfessado": "reconfessar",
    "reconfessados": "reconfessar",
    "reconfessai": "reconfessar",
    "reconfessais": "reconfessar",
    "reconfessam": "reconfessar",
    "reconfessamo": "reconfessar",
    "reconfessamos": "reconfessar",
    "reconfessando": "reconfessar",
    "reconfessara": "reconfessar",
    "reconfessaram": "reconfessar",
    "reconfessaras": "reconfessar",
    "reconfessarde": "reconfessar",
    "reconfessardes": "reconfessar",
    "reconfessare": "reconfessar",
    "reconfessarei": "reconfessar",
    "reconfessareis": "reconfessar",
    "reconfessarem": "reconfessar",
    "reconfessaremos": "reconfessar",
    "reconfessares": "reconfessar",
    "reconfessaria": "reconfessar",
    "reconfessariam": "reconfessar",
    "reconfessarias": "reconfessar",
    "reconfessarmo": "reconfessar",
    "reconfessarmos": "reconfessar",
    "reconfessará": "reconfessar",
    "reconfessarás": "reconfessar",
    "reconfessarão": "reconfessar",
    "reconfessaríamos": "reconfessar",
    "reconfessaríeis": "reconfessar",
    "reconfessas": "reconfessar",
    "reconfessasse": "reconfessar",
    "reconfessassem": "reconfessar",
    "reconfessasses": "reconfessar",
    "reconfessaste": "reconfessar",
    "reconfessastes": "reconfessar",
    "reconfessava": "reconfessar",
    "reconfessavam": "reconfessar",
    "reconfessavas": "reconfessar",
    "reconfesse": "reconfessar",
    "reconfessei": "reconfessar",
    "reconfesseis": "reconfessar",
    "reconfessem": "reconfessar",
    "reconfessemo": "reconfessar",
    "reconfessemos": "reconfessar",
    "reconfesses": "reconfessar",
    "reconfesso": "reconfessar",
    "reconfessou": "reconfessar",
    "reconfessá": "reconfessar",
    "reconfessámo": "reconfessar",
    "reconfessámos": "reconfessar",
    "reconfessáramo": "reconfessar",
    "reconfessáramos": "reconfessar",
    "reconfessárei": "reconfessar",
    "reconfessáreis": "reconfessar",
    "reconfessásseis": "reconfessar",
    "reconfessássemos": "reconfessar",
    "reconfessávamo": "reconfessar",
    "reconfessávamos": "reconfessar",
    "reconfessávei": "reconfessar",
    "reconfessáveis": "reconfessar",
    "reconfirma": "reconfirmar",
    "reconfirmada": "reconfirmar",
    "reconfirmadas": "reconfirmar",
    "reconfirmado": "reconfirmar",
    "reconfirmados": "reconfirmar",
    "reconfirmai": "reconfirmar",
    "reconfirmais": "reconfirmar",
    "reconfirmam": "reconfirmar",
    "reconfirmamo": "reconfirmar",
    "reconfirmamos": "reconfirmar",
    "reconfirmando": "reconfirmar",
    "reconfirmara": "reconfirmar",
    "reconfirmaram": "reconfirmar",
    "reconfirmaras": "reconfirmar",
    "reconfirmarde": "reconfirmar",
    "reconfirmardes": "reconfirmar",
    "reconfirmare": "reconfirmar",
    "reconfirmarei": "reconfirmar",
    "reconfirmareis": "reconfirmar",
    "reconfirmarem": "reconfirmar",
    "reconfirmaremos": "reconfirmar",
    "reconfirmares": "reconfirmar",
    "reconfirmaria": "reconfirmar",
    "reconfirmariam": "reconfirmar",
    "reconfirmarias": "reconfirmar",
    "reconfirmarmo": "reconfirmar",
    "reconfirmarmos": "reconfirmar",
    "reconfirmará": "reconfirmar",
    "reconfirmarás": "reconfirmar",
    "reconfirmarão": "reconfirmar",
    "reconfirmaríamos": "reconfirmar",
    "reconfirmaríeis": "reconfirmar",
    "reconfirmas": "reconfirmar",
    "reconfirmasse": "reconfirmar",
    "reconfirmassem": "reconfirmar",
    "reconfirmasses": "reconfirmar",
    "reconfirmaste": "reconfirmar",
    "reconfirmastes": "reconfirmar",
    "reconfirmava": "reconfirmar",
    "reconfirmavam": "reconfirmar",
    "reconfirmavas": "reconfirmar",
    "reconfirmações": "reconfirmação",
    "reconfirme": "reconfirmar",
    "reconfirmei": "reconfirmar",
    "reconfirmeis": "reconfirmar",
    "reconfirmem": "reconfirmar",
    "reconfirmemo": "reconfirmar",
    "reconfirmemos": "reconfirmar",
    "reconfirmes": "reconfirmar",
    "reconfirmo": "reconfirmar",
    "reconfirmou": "reconfirmar",
    "reconfirmá": "reconfirmar",
    "reconfirmámo": "reconfirmar",
    "reconfirmámos": "reconfirmar",
    "reconfirmáramo": "reconfirmar",
    "reconfirmáramos": "reconfirmar",
    "reconfirmárei": "reconfirmar",
    "reconfirmáreis": "reconfirmar",
    "reconfirmásseis": "reconfirmar",
    "reconfirmássemos": "reconfirmar",
    "reconfirmávamo": "reconfirmar",
    "reconfirmávamos": "reconfirmar",
    "reconfirmávei": "reconfirmar",
    "reconfirmáveis": "reconfirmar",
    "reconforta": "reconfortar",
    "reconfortada": "reconfortar",
    "reconfortadas": "reconfortar",
    "reconfortado": "reconfortar",
    "reconfortadora": "reconfortador",
    "reconfortadoras": "reconfortador",
    "reconfortadores": "reconfortador",
    "reconfortados": "reconfortar",
    "reconfortadíssima": "reconfortado",
    "reconfortadíssimas": "reconfortado",
    "reconfortadíssimo": "reconfortado",
    "reconfortadíssimos": "reconfortado",
    "reconfortai": "reconfortar",
    "reconfortais": "reconfortar",
    "reconfortam": "reconfortar",
    "reconfortamo": "reconfortar",
    "reconfortamos": "reconfortar",
    "reconfortando": "reconfortar",
    "reconfortantes": "reconfortante",
    "reconfortara": "reconfortar",
    "reconfortaram": "reconfortar",
    "reconfortaras": "reconfortar",
    "reconfortarde": "reconfortar",
    "reconfortardes": "reconfortar",
    "reconfortare": "reconfortar",
    "reconfortarei": "reconfortar",
    "reconfortareis": "reconfortar",
    "reconfortarem": "reconfortar",
    "reconfortaremos": "reconfortar",
    "reconfortares": "reconfortar",
    "reconfortaria": "reconfortar",
    "reconfortariam": "reconfortar",
    "reconfortarias": "reconfortar",
    "reconfortarmo": "reconfortar",
    "reconfortarmos": "reconfortar",
    "reconfortará": "reconfortar",
    "reconfortarás": "reconfortar",
    "reconfortarão": "reconfortar",
    "reconfortaríamos": "reconfortar",
    "reconfortaríeis": "reconfortar",
    "reconfortas": "reconfortar",
    "reconfortasse": "reconfortar",
    "reconfortassem": "reconfortar",
    "reconfortasses": "reconfortar",
    "reconfortaste": "reconfortar",
    "reconfortastes": "reconfortar",
    "reconfortava": "reconfortar",
    "reconfortavam": "reconfortar",
    "reconfortavas": "reconfortar",
    "reconforte": "reconfortar",
    "reconfortei": "reconfortar",
    "reconforteis": "reconfortar",
    "reconfortem": "reconfortar",
    "reconfortemo": "reconfortar",
    "reconfortemos": "reconfortar",
    "reconfortes": "reconfortar",
    "reconforto": "reconfortar",
    "reconfortos": "reconforto",
    "reconfortou": "reconfortar",
    "reconfortá": "reconfortar",
    "reconfortámo": "reconfortar",
    "reconfortámos": "reconfortar",
    "reconfortáramo": "reconfortar",
    "reconfortáramos": "reconfortar",
    "reconfortárei": "reconfortar",
    "reconfortáreis": "reconfortar",
    "reconfortásseis": "reconfortar",
    "reconfortássemos": "reconfortar",
    "reconfortávamo": "reconfortar",
    "reconfortávamos": "reconfortar",
    "reconfortávei": "reconfortar",
    "reconfortáveis": "reconfortável",
    "recongrace": "recongraçar",
    "recongracei": "recongraçar",
    "recongraceis": "recongraçar",
    "recongracem": "recongraçar",
    "recongracemo": "recongraçar",
    "recongracemos": "recongraçar",
    "recongraces": "recongraçar",
    "recongraça": "recongraçar",
    "recongraçada": "recongraçar",
    "recongraçadas": "recongraçar",
    "recongraçado": "recongraçar",
    "recongraçados": "recongraçar",
    "recongraçai": "recongraçar",
    "recongraçais": "recongraçar",
    "recongraçam": "recongraçar",
    "recongraçamo": "recongraçar",
    "recongraçamos": "recongraçar",
    "recongraçando": "recongraçar",
    "recongraçara": "recongraçar",
    "recongraçaram": "recongraçar",
    "recongraçaras": "recongraçar",
    "recongraçarde": "recongraçar",
    "recongraçardes": "recongraçar",
    "recongraçare": "recongraçar",
    "recongraçarei": "recongraçar",
    "recongraçareis": "recongraçar",
    "recongraçarem": "recongraçar",
    "recongraçaremos": "recongraçar",
    "recongraçares": "recongraçar",
    "recongraçaria": "recongraçar",
    "recongraçariam": "recongraçar",
    "recongraçarias": "recongraçar",
    "recongraçarmo": "recongraçar",
    "recongraçarmos": "recongraçar",
    "recongraçará": "recongraçar",
    "recongraçarás": "recongraçar",
    "recongraçarão": "recongraçar",
    "recongraçaríamos": "recongraçar",
    "recongraçaríeis": "recongraçar",
    "recongraças": "recongraçar",
    "recongraçasse": "recongraçar",
    "recongraçassem": "recongraçar",
    "recongraçasses": "recongraçar",
    "recongraçaste": "recongraçar",
    "recongraçastes": "recongraçar",
    "recongraçava": "recongraçar",
    "recongraçavam": "recongraçar",
    "recongraçavas": "recongraçar",
    "recongraço": "recongraçar",
    "recongraçou": "recongraçar",
    "recongraçá": "recongraçar",
    "recongraçámo": "recongraçar",
    "recongraçámos": "recongraçar",
    "recongraçáramo": "recongraçar",
    "recongraçáramos": "recongraçar",
    "recongraçárei": "recongraçar",
    "recongraçáreis": "recongraçar",
    "recongraçásseis": "recongraçar",
    "recongraçássemos": "recongraçar",
    "recongraçávamo": "recongraçar",
    "recongraçávamos": "recongraçar",
    "recongraçávei": "recongraçar",
    "recongraçáveis": "recongraçar",
    "reconhece": "reconhecer",
    "reconhecei": "reconhecer",
    "reconheceis": "reconhecer",
    "reconhecem": "reconhecer",
    "reconhecemo": "reconhecer",
    "reconhecemos": "reconhecer",
    "reconhecendo": "reconhecer",
    "reconhecera": "reconhecer",
    "reconheceram": "reconhecer",
    "reconheceras": "reconhecer",
    "reconhecerde": "reconhecer",
    "reconhecerdes": "reconhecer",
    "reconhecere": "reconhecer",
    "reconhecerei": "reconhecer",
    "reconhecereis": "reconhecer",
    "reconhecerem": "reconhecer",
    "reconheceremos": "reconhecer",
    "reconheceres": "reconhecer",
    "reconheceria": "reconhecer",
    "reconheceriam": "reconhecer",
    "reconhecerias": "reconhecer",
    "reconhecermo": "reconhecer",
    "reconhecermos": "reconhecer",
    "reconhecerá": "reconhecer",
    "reconhecerás": "reconhecer",
    "reconhecerão": "reconhecer",
    "reconheceríamos": "reconhecer",
    "reconheceríeis": "reconhecer",
    "reconheces": "reconhecer",
    "reconhecesse": "reconhecer",
    "reconhecessem": "reconhecer",
    "reconhecesses": "reconhecer",
    "reconheceste": "reconhecer",
    "reconhecestes": "reconhecer",
    "reconheceu": "reconhecer",
    "reconheci": "reconhecer",
    "reconhecia": "reconhecer",
    "reconheciam": "reconhecer",
    "reconhecias": "reconhecer",
    "reconhecida": "reconhecido",
    "reconhecidas": "reconhecido",
    "reconhecidazinha": "reconhecido",
    "reconhecidazinhas": "reconhecido",
    "reconhecidazita": "reconhecido",
    "reconhecidazitas": "reconhecido",
    "reconhecidinha": "reconhecido",
    "reconhecidinhas": "reconhecido",
    "reconhecidinho": "reconhecido",
    "reconhecidinhos": "reconhecido",
    "reconhecidita": "reconhecido",
    "reconheciditas": "reconhecido",
    "reconhecidito": "reconhecido",
    "reconheciditos": "reconhecido",
    "reconhecido": "reconhecer",
    "reconhecidos": "reconhecido",
    "reconhecidozinho": "reconhecido",
    "reconhecidozinhos": "reconhecido",
    "reconhecidozito": "reconhecido",
    "reconhecidozitos": "reconhecido",
    "reconhecidíssima": "reconhecido",
    "reconhecidíssimas": "reconhecido",
    "reconhecidíssimo": "reconhecido",
    "reconhecidíssimos": "reconhecido",
    "reconhecimentos": "reconhecimento",
    "reconhecê": "reconhecer",
    "reconhecêramo": "reconhecer",
    "reconhecêramos": "reconhecer",
    "reconhecêrei": "reconhecer",
    "reconhecêreis": "reconhecer",
    "reconhecêsseis": "reconhecer",
    "reconhecêssemos": "reconhecer",
    "reconhecíamo": "reconhecer",
    "reconhecíamos": "reconhecer",
    "reconhecíei": "reconhecer",
    "reconhecíeis": "reconhecer",
    "reconhecíveis": "reconhecível",
    "reconheça": "reconhecer",
    "reconheçais": "reconhecer",
    "reconheçam": "reconhecer",
    "reconheçamo": "reconhecer",
    "reconheçamos": "reconhecer",
    "reconheças": "reconhecer",
    "reconheço": "reconhecer",
    "reconquista": "reconquistar",
    "reconquistada": "reconquistar",
    "reconquistadas": "reconquistar",
    "reconquistado": "reconquistar",
    "reconquistados": "reconquistar",
    "reconquistai": "reconquistar",
    "reconquistais": "reconquistar",
    "reconquistam": "reconquistar",
    "reconquistamo": "reconquistar",
    "reconquistamos": "reconquistar",
    "reconquistando": "reconquistar",
    "reconquistara": "reconquistar",
    "reconquistaram": "reconquistar",
    "reconquistaras": "reconquistar",
    "reconquistarde": "reconquistar",
    "reconquistardes": "reconquistar",
    "reconquistare": "reconquistar",
    "reconquistarei": "reconquistar",
    "reconquistareis": "reconquistar",
    "reconquistarem": "reconquistar",
    "reconquistaremos": "reconquistar",
    "reconquistares": "reconquistar",
    "reconquistaria": "reconquistar",
    "reconquistariam": "reconquistar",
    "reconquistarias": "reconquistar",
    "reconquistarmo": "reconquistar",
    "reconquistarmos": "reconquistar",
    "reconquistará": "reconquistar",
    "reconquistarás": "reconquistar",
    "reconquistarão": "reconquistar",
    "reconquistaríamos": "reconquistar",
    "reconquistaríeis": "reconquistar",
    "reconquistas": "reconquistar",
    "reconquistasse": "reconquistar",
    "reconquistassem": "reconquistar",
    "reconquistasses": "reconquistar",
    "reconquistaste": "reconquistar",
    "reconquistastes": "reconquistar",
    "reconquistava": "reconquistar",
    "reconquistavam": "reconquistar",
    "reconquistavas": "reconquistar",
    "reconquiste": "reconquistar",
    "reconquistei": "reconquistar",
    "reconquisteis": "reconquistar",
    "reconquistem": "reconquistar",
    "reconquistemo": "reconquistar",
    "reconquistemos": "reconquistar",
    "reconquistes": "reconquistar",
    "reconquisto": "reconquistar",
    "reconquistou": "reconquistar",
    "reconquistá": "reconquistar",
    "reconquistámo": "reconquistar",
    "reconquistámos": "reconquistar",
    "reconquistáramo": "reconquistar",
    "reconquistáramos": "reconquistar",
    "reconquistárei": "reconquistar",
    "reconquistáreis": "reconquistar",
    "reconquistásseis": "reconquistar",
    "reconquistássemos": "reconquistar",
    "reconquistávamo": "reconquistar",
    "reconquistávamos": "reconquistar",
    "reconquistávei": "reconquistar",
    "reconquistáveis": "reconquistável",
    "reconsagra": "reconsagrar",
    "reconsagrada": "reconsagrar",
    "reconsagradas": "reconsagrar",
    "reconsagrado": "reconsagrar",
    "reconsagrados": "reconsagrar",
    "reconsagrai": "reconsagrar",
    "reconsagrais": "reconsagrar",
    "reconsagram": "reconsagrar",
    "reconsagramo": "reconsagrar",
    "reconsagramos": "reconsagrar",
    "reconsagrando": "reconsagrar",
    "reconsagrara": "reconsagrar",
    "reconsagraram": "reconsagrar",
    "reconsagraras": "reconsagrar",
    "reconsagrarde": "reconsagrar",
    "reconsagrardes": "reconsagrar",
    "reconsagrare": "reconsagrar",
    "reconsagrarei": "reconsagrar",
    "reconsagrareis": "reconsagrar",
    "reconsagrarem": "reconsagrar",
    "reconsagraremos": "reconsagrar",
    "reconsagrares": "reconsagrar",
    "reconsagraria": "reconsagrar",
    "reconsagrariam": "reconsagrar",
    "reconsagrarias": "reconsagrar",
    "reconsagrarmo": "reconsagrar",
    "reconsagrarmos": "reconsagrar",
    "reconsagrará": "reconsagrar",
    "reconsagrarás": "reconsagrar",
    "reconsagrarão": "reconsagrar",
    "reconsagraríamos": "reconsagrar",
    "reconsagraríeis": "reconsagrar",
    "reconsagras": "reconsagrar",
    "reconsagrasse": "reconsagrar",
    "reconsagrassem": "reconsagrar",
    "reconsagrasses": "reconsagrar",
    "reconsagraste": "reconsagrar",
    "reconsagrastes": "reconsagrar",
    "reconsagrava": "reconsagrar",
    "reconsagravam": "reconsagrar",
    "reconsagravas": "reconsagrar",
    "reconsagrações": "reconsagração",
    "reconsagre": "reconsagrar",
    "reconsagrei": "reconsagrar",
    "reconsagreis": "reconsagrar",
    "reconsagrem": "reconsagrar",
    "reconsagremo": "reconsagrar",
    "reconsagremos": "reconsagrar",
    "reconsagres": "reconsagrar",
    "reconsagro": "reconsagrar",
    "reconsagrou": "reconsagrar",
    "reconsagrá": "reconsagrar",
    "reconsagrámo": "reconsagrar",
    "reconsagrámos": "reconsagrar",
    "reconsagráramo": "reconsagrar",
    "reconsagráramos": "reconsagrar",
    "reconsagrárei": "reconsagrar",
    "reconsagráreis": "reconsagrar",
    "reconsagrásseis": "reconsagrar",
    "reconsagrássemos": "reconsagrar",
    "reconsagrávamo": "reconsagrar",
    "reconsagrávamos": "reconsagrar",
    "reconsagrávei": "reconsagrar",
    "reconsagráveis": "reconsagrar",
    "reconserta": "reconsertar",
    "reconsertada": "reconsertar",
    "reconsertadas": "reconsertar",
    "reconsertado": "reconsertar",
    "reconsertados": "reconsertar",
    "reconsertai": "reconsertar",
    "reconsertais": "reconsertar",
    "reconsertam": "reconsertar",
    "reconsertamo": "reconsertar",
    "reconsertamos": "reconsertar",
    "reconsertando": "reconsertar",
    "reconsertara": "reconsertar",
    "reconsertaram": "reconsertar",
    "reconsertaras": "reconsertar",
    "reconsertarde": "reconsertar",
    "reconsertardes": "reconsertar",
    "reconsertare": "reconsertar",
    "reconsertarei": "reconsertar",
    "reconsertareis": "reconsertar",
    "reconsertarem": "reconsertar",
    "reconsertaremos": "reconsertar",
    "reconsertares": "reconsertar",
    "reconsertaria": "reconsertar",
    "reconsertariam": "reconsertar",
    "reconsertarias": "reconsertar",
    "reconsertarmo": "reconsertar",
    "reconsertarmos": "reconsertar",
    "reconsertará": "reconsertar",
    "reconsertarás": "reconsertar",
    "reconsertarão": "reconsertar",
    "reconsertaríamos": "reconsertar",
    "reconsertaríeis": "reconsertar",
    "reconsertas": "reconsertar",
    "reconsertasse": "reconsertar",
    "reconsertassem": "reconsertar",
    "reconsertasses": "reconsertar",
    "reconsertaste": "reconsertar",
    "reconsertastes": "reconsertar",
    "reconsertava": "reconsertar",
    "reconsertavam": "reconsertar",
    "reconsertavas": "reconsertar",
    "reconserte": "reconsertar",
    "reconsertei": "reconsertar",
    "reconserteis": "reconsertar",
    "reconsertem": "reconsertar",
    "reconsertemo": "reconsertar",
    "reconsertemos": "reconsertar",
    "reconsertes": "reconsertar",
    "reconserto": "reconsertar",
    "reconsertos": "reconserto",
    "reconsertou": "reconsertar",
    "reconsertá": "reconsertar",
    "reconsertámo": "reconsertar",
    "reconsertámos": "reconsertar",
    "reconsertáramo": "reconsertar",
    "reconsertáramos": "reconsertar",
    "reconsertárei": "reconsertar",
    "reconsertáreis": "reconsertar",
    "reconsertásseis": "reconsertar",
    "reconsertássemos": "reconsertar",
    "reconsertávamo": "reconsertar",
    "reconsertávamos": "reconsertar",
    "reconsertávei": "reconsertar",
    "reconsertáveis": "reconsertar",
    "reconsidera": "reconsiderar",
    "reconsiderada": "reconsiderar",
    "reconsideradas": "reconsiderar",
    "reconsiderado": "reconsiderar",
    "reconsiderados": "reconsiderar",
    "reconsiderai": "reconsiderar",
    "reconsiderais": "reconsiderar",
    "reconsideram": "reconsiderar",
    "reconsideramo": "reconsiderar",
    "reconsideramos": "reconsiderar",
    "reconsiderando": "reconsiderar",
    "reconsiderara": "reconsiderar",
    "reconsideraram": "reconsiderar",
    "reconsideraras": "reconsiderar",
    "reconsiderarde": "reconsiderar",
    "reconsiderardes": "reconsiderar",
    "reconsiderare": "reconsiderar",
    "reconsiderarei": "reconsiderar",
    "reconsiderareis": "reconsiderar",
    "reconsiderarem": "reconsiderar",
    "reconsideraremos": "reconsiderar",
    "reconsiderares": "reconsiderar",
    "reconsideraria": "reconsiderar",
    "reconsiderariam": "reconsiderar",
    "reconsiderarias": "reconsiderar",
    "reconsiderarmo": "reconsiderar",
    "reconsiderarmos": "reconsiderar",
    "reconsiderará": "reconsiderar",
    "reconsiderarás": "reconsiderar",
    "reconsiderarão": "reconsiderar",
    "reconsideraríamos": "reconsiderar",
    "reconsideraríeis": "reconsiderar",
    "reconsideras": "reconsiderar",
    "reconsiderasse": "reconsiderar",
    "reconsiderassem": "reconsiderar",
    "reconsiderasses": "reconsiderar",
    "reconsideraste": "reconsiderar",
    "reconsiderastes": "reconsiderar",
    "reconsiderava": "reconsiderar",
    "reconsideravam": "reconsiderar",
    "reconsideravas": "reconsiderar",
    "reconsiderações": "reconsideração",
    "reconsidere": "reconsiderar",
    "reconsiderei": "reconsiderar",
    "reconsidereis": "reconsiderar",
    "reconsiderem": "reconsiderar",
    "reconsideremo": "reconsiderar",
    "reconsideremos": "reconsiderar",
    "reconsideres": "reconsiderar",
    "reconsidero": "reconsiderar",
    "reconsiderou": "reconsiderar",
    "reconsiderá": "reconsiderar",
    "reconsiderámo": "reconsiderar",
    "reconsiderámos": "reconsiderar",
    "reconsideráramo": "reconsiderar",
    "reconsideráramos": "reconsiderar",
    "reconsiderárei": "reconsiderar",
    "reconsideráreis": "reconsiderar",
    "reconsiderásseis": "reconsiderar",
    "reconsiderássemos": "reconsiderar",
    "reconsiderávamo": "reconsiderar",
    "reconsiderávamos": "reconsiderar",
    "reconsiderávei": "reconsiderar",
    "reconsideráveis": "reconsiderável",
    "reconsolida": "reconsolidar",
    "reconsolidada": "reconsolidar",
    "reconsolidadas": "reconsolidar",
    "reconsolidado": "reconsolidar",
    "reconsolidados": "reconsolidar",
    "reconsolidai": "reconsolidar",
    "reconsolidais": "reconsolidar",
    "reconsolidam": "reconsolidar",
    "reconsolidamo": "reconsolidar",
    "reconsolidamos": "reconsolidar",
    "reconsolidando": "reconsolidar",
    "reconsolidara": "reconsolidar",
    "reconsolidaram": "reconsolidar",
    "reconsolidaras": "reconsolidar",
    "reconsolidarde": "reconsolidar",
    "reconsolidardes": "reconsolidar",
    "reconsolidare": "reconsolidar",
    "reconsolidarei": "reconsolidar",
    "reconsolidareis": "reconsolidar",
    "reconsolidarem": "reconsolidar",
    "reconsolidaremos": "reconsolidar",
    "reconsolidares": "reconsolidar",
    "reconsolidaria": "reconsolidar",
    "reconsolidariam": "reconsolidar",
    "reconsolidarias": "reconsolidar",
    "reconsolidarmo": "reconsolidar",
    "reconsolidarmos": "reconsolidar",
    "reconsolidará": "reconsolidar",
    "reconsolidarás": "reconsolidar",
    "reconsolidarão": "reconsolidar",
    "reconsolidaríamos": "reconsolidar",
    "reconsolidaríeis": "reconsolidar",
    "reconsolidas": "reconsolidar",
    "reconsolidasse": "reconsolidar",
    "reconsolidassem": "reconsolidar",
    "reconsolidasses": "reconsolidar",
    "reconsolidaste": "reconsolidar",
    "reconsolidastes": "reconsolidar",
    "reconsolidava": "reconsolidar",
    "reconsolidavam": "reconsolidar",
    "reconsolidavas": "reconsolidar",
    "reconsolidações": "reconsolidação",
    "reconsolide": "reconsolidar",
    "reconsolidei": "reconsolidar",
    "reconsolideis": "reconsolidar",
    "reconsolidem": "reconsolidar",
    "reconsolidemo": "reconsolidar",
    "reconsolidemos": "reconsolidar",
    "reconsolides": "reconsolidar",
    "reconsolido": "reconsolidar",
    "reconsolidou": "reconsolidar",
    "reconsolidá": "reconsolidar",
    "reconsolidámo": "reconsolidar",
    "reconsolidámos": "reconsolidar",
    "reconsolidáramo": "reconsolidar",
    "reconsolidáramos": "reconsolidar",
    "reconsolidárei": "reconsolidar",
    "reconsolidáreis": "reconsolidar",
    "reconsolidásseis": "reconsolidar",
    "reconsolidássemos": "reconsolidar",
    "reconsolidávamo": "reconsolidar",
    "reconsolidávamos": "reconsolidar",
    "reconsolidávei": "reconsolidar",
    "reconsolidáveis": "reconsolidável",
    "reconsorcia": "reconsorciar",
    "reconsorciada": "reconsorciar",
    "reconsorciadas": "reconsorciar",
    "reconsorciado": "reconsorciar",
    "reconsorciados": "reconsorciar",
    "reconsorciai": "reconsorciar",
    "reconsorciais": "reconsorciar",
    "reconsorciam": "reconsorciar",
    "reconsorciamo": "reconsorciar",
    "reconsorciamos": "reconsorciar",
    "reconsorciando": "reconsorciar",
    "reconsorciara": "reconsorciar",
    "reconsorciaram": "reconsorciar",
    "reconsorciaras": "reconsorciar",
    "reconsorciarde": "reconsorciar",
    "reconsorciardes": "reconsorciar",
    "reconsorciare": "reconsorciar",
    "reconsorciarei": "reconsorciar",
    "reconsorciareis": "reconsorciar",
    "reconsorciarem": "reconsorciar",
    "reconsorciaremos": "reconsorciar",
    "reconsorciares": "reconsorciar",
    "reconsorciaria": "reconsorciar",
    "reconsorciariam": "reconsorciar",
    "reconsorciarias": "reconsorciar",
    "reconsorciarmo": "reconsorciar",
    "reconsorciarmos": "reconsorciar",
    "reconsorciará": "reconsorciar",
    "reconsorciarás": "reconsorciar",
    "reconsorciarão": "reconsorciar",
    "reconsorciaríamos": "reconsorciar",
    "reconsorciaríeis": "reconsorciar",
    "reconsorcias": "reconsorciar",
    "reconsorciasse": "reconsorciar",
    "reconsorciassem": "reconsorciar",
    "reconsorciasses": "reconsorciar",
    "reconsorciaste": "reconsorciar",
    "reconsorciastes": "reconsorciar",
    "reconsorciava": "reconsorciar",
    "reconsorciavam": "reconsorciar",
    "reconsorciavas": "reconsorciar",
    "reconsorcie": "reconsorciar",
    "reconsorciei": "reconsorciar",
    "reconsorcieis": "reconsorciar",
    "reconsorciem": "reconsorciar",
    "reconsorciemo": "reconsorciar",
    "reconsorciemos": "reconsorciar",
    "reconsorcies": "reconsorciar",
    "reconsorcio": "reconsorciar",
    "reconsorciou": "reconsorciar",
    "reconsorciá": "reconsorciar",
    "reconsorciámo": "reconsorciar",
    "reconsorciámos": "reconsorciar",
    "reconsorciáramo": "reconsorciar",
    "reconsorciáramos": "reconsorciar",
    "reconsorciárei": "reconsorciar",
    "reconsorciáreis": "reconsorciar",
    "reconsorciásseis": "reconsorciar",
    "reconsorciássemos": "reconsorciar",
    "reconsorciávamo": "reconsorciar",
    "reconsorciávamos": "reconsorciar",
    "reconsorciávei": "reconsorciar",
    "reconsorciáveis": "reconsorciar",
    "reconstitua": "reconstituir",
    "reconstituais": "reconstituir",
    "reconstituam": "reconstituir",
    "reconstituamo": "reconstituir",
    "reconstituamos": "reconstituir",
    "reconstituas": "reconstituir",
    "reconstituem": "reconstituir",
    "reconstitui": "reconstituir",
    "reconstituindo": "reconstituir",
    "reconstituintes": "reconstituinte",
    "reconstituirde": "reconstituir",
    "reconstituirdes": "reconstituir",
    "reconstituirei": "reconstituir",
    "reconstituireis": "reconstituir",
    "reconstituiremos": "reconstituir",
    "reconstituiria": "reconstituir",
    "reconstituiriam": "reconstituir",
    "reconstituirias": "reconstituir",
    "reconstituirmo": "reconstituir",
    "reconstituirmos": "reconstituir",
    "reconstituirá": "reconstituir",
    "reconstituirás": "reconstituir",
    "reconstituirão": "reconstituir",
    "reconstituiríamos": "reconstituir",
    "reconstituiríeis": "reconstituir",
    "reconstituis": "reconstituir",
    "reconstituiu": "reconstituir",
    "reconstituições": "reconstituição",
    "reconstituo": "reconstituir",
    "reconstitutiva": "reconstitutivo",
    "reconstitutivas": "reconstitutivo",
    "reconstitutivos": "reconstitutivo",
    "reconstituí": "reconstituir",
    "reconstituía": "reconstituir",
    "reconstituíam": "reconstituir",
    "reconstituíamo": "reconstituir",
    "reconstituíamos": "reconstituir",
    "reconstituías": "reconstituir",
    "reconstituída": "reconstituir",
    "reconstituídas": "reconstituir",
    "reconstituído": "reconstituir",
    "reconstituídos": "reconstituir",
    "reconstituíei": "reconstituir",
    "reconstituíeis": "reconstituir",
    "reconstituímo": "reconstituir",
    "reconstituímos": "reconstituir",
    "reconstituíra": "reconstituir",
    "reconstituíram": "reconstituir",
    "reconstituíramo": "reconstituir",
    "reconstituíramos": "reconstituir",
    "reconstituíras": "reconstituir",
    "reconstituíre": "reconstituir",
    "reconstituírei": "reconstituir",
    "reconstituíreis": "reconstituir",
    "reconstituírem": "reconstituir",
    "reconstituíres": "reconstituir",
    "reconstituís": "reconstituir",
    "reconstituísse": "reconstituir",
    "reconstituísseis": "reconstituir",
    "reconstituíssem": "reconstituir",
    "reconstituíssemos": "reconstituir",
    "reconstituísses": "reconstituir",
    "reconstituíste": "reconstituir",
    "reconstituístes": "reconstituir",
    "reconstituíveis": "reconstituível",
    "reconstri": "reconstruir",
    "reconstroem": "reconstruir",
    "reconstrua": "reconstruir",
    "reconstruais": "reconstruir",
    "reconstruam": "reconstruir",
    "reconstruamo": "reconstruir",
    "reconstruamos": "reconstruir",
    "reconstruas": "reconstruir",
    "reconstruem": "reconstruir",
    "reconstrui": "reconstruir",
    "reconstruindo": "reconstruir",
    "reconstruirde": "reconstruir",
    "reconstruirdes": "reconstruir",
    "reconstruirei": "reconstruir",
    "reconstruireis": "reconstruir",
    "reconstruiremos": "reconstruir",
    "reconstruiria": "reconstruir",
    "reconstruiriam": "reconstruir",
    "reconstruirias": "reconstruir",
    "reconstruirmo": "reconstruir",
    "reconstruirmos": "reconstruir",
    "reconstruirá": "reconstruir",
    "reconstruirás": "reconstruir",
    "reconstruirão": "reconstruir",
    "reconstruiríamos": "reconstruir",
    "reconstruiríeis": "reconstruir",
    "reconstruis": "reconstruir",
    "reconstruiu": "reconstruir",
    "reconstruo": "reconstruir",
    "reconstrutiva": "reconstrutivo",
    "reconstrutivas": "reconstrutivo",
    "reconstrutivos": "reconstrutivo",
    "reconstrutora": "reconstrutor",
    "reconstrutoras": "reconstrutor",
    "reconstrutores": "reconstrutor",
    "reconstruções": "reconstrução",
    "reconstruí": "reconstruir",
    "reconstruía": "reconstruir",
    "reconstruíam": "reconstruir",
    "reconstruíamo": "reconstruir",
    "reconstruíamos": "reconstruir",
    "reconstruías": "reconstruir",
    "reconstruída": "reconstruir",
    "reconstruídas": "reconstruir",
    "reconstruído": "reconstruir",
    "reconstruídos": "reconstruir",
    "reconstruíei": "reconstruir",
    "reconstruíeis": "reconstruir",
    "reconstruímo": "reconstruir",
    "reconstruímos": "reconstruir",
    "reconstruíra": "reconstruir",
    "reconstruíram": "reconstruir",
    "reconstruíramo": "reconstruir",
    "reconstruíramos": "reconstruir",
    "reconstruíras": "reconstruir",
    "reconstruíre": "reconstruir",
    "reconstruírei": "reconstruir",
    "reconstruíreis": "reconstruir",
    "reconstruírem": "reconstruir",
    "reconstruíres": "reconstruir",
    "reconstruís": "reconstruir",
    "reconstruísse": "reconstruir",
    "reconstruísseis": "reconstruir",
    "reconstruíssem": "reconstruir",
    "reconstruíssemos": "reconstruir",
    "reconstruísses": "reconstruir",
    "reconstruíste": "reconstruir",
    "reconstruístes": "reconstruir",
    "reconstruíveis": "reconstruível",
    "reconstrói": "reconstruir",
    "reconstróis": "reconstruir",
    "reconta": "recontar",
    "recontada": "recontar",
    "recontadas": "recontar",
    "recontado": "recontar",
    "recontados": "recontar",
    "recontagens": "recontagem",
    "recontai": "recontar",
    "recontais": "recontar",
    "recontam": "recontar",
    "recontamentos": "recontamento",
    "recontamo": "recontar",
    "recontamos": "recontar",
    "recontando": "recontar",
    "recontara": "recontar",
    "recontaram": "recontar",
    "recontaras": "recontar",
    "recontarde": "recontar",
    "recontardes": "recontar",
    "recontare": "recontar",
    "recontarei": "recontar",
    "recontareis": "recontar",
    "recontarem": "recontar",
    "recontaremos": "recontar",
    "recontares": "recontar",
    "recontaria": "recontar",
    "recontariam": "recontar",
    "recontarias": "recontar",
    "recontarmo": "recontar",
    "recontarmos": "recontar",
    "recontará": "recontar",
    "recontarás": "recontar",
    "recontarão": "recontar",
    "recontaríamos": "recontar",
    "recontaríeis": "recontar",
    "recontas": "recontar",
    "recontasse": "recontar",
    "recontassem": "recontar",
    "recontasses": "recontar",
    "recontaste": "recontar",
    "recontastes": "recontar",
    "recontava": "recontar",
    "recontavam": "recontar",
    "recontavas": "recontar",
    "reconte": "recontar",
    "recontei": "recontar",
    "reconteis": "recontar",
    "recontem": "recontar",
    "recontemo": "recontar",
    "recontemos": "recontar",
    "recontentes": "recontente",
    "recontes": "recontar",
    "reconto": "recontar",
    "recontos": "reconto",
    "recontou": "recontar",
    "recontrata": "recontratar",
    "recontratada": "recontratar",
    "recontratadas": "recontratar",
    "recontratado": "recontratar",
    "recontratados": "recontratar",
    "recontratai": "recontratar",
    "recontratais": "recontratar",
    "recontratam": "recontratar",
    "recontratamo": "recontratar",
    "recontratamos": "recontratar",
    "recontratando": "recontratar",
    "recontratara": "recontratar",
    "recontrataram": "recontratar",
    "recontrataras": "recontratar",
    "recontratarde": "recontratar",
    "recontratardes": "recontratar",
    "recontratare": "recontratar",
    "recontratarei": "recontratar",
    "recontratareis": "recontratar",
    "recontratarem": "recontratar",
    "recontrataremos": "recontratar",
    "recontratares": "recontratar",
    "recontrataria": "recontratar",
    "recontratariam": "recontratar",
    "recontratarias": "recontratar",
    "recontratarmo": "recontratar",
    "recontratarmos": "recontratar",
    "recontratará": "recontratar",
    "recontratarás": "recontratar",
    "recontratarão": "recontratar",
    "recontrataríamos": "recontratar",
    "recontrataríeis": "recontratar",
    "recontratas": "recontratar",
    "recontratasse": "recontratar",
    "recontratassem": "recontratar",
    "recontratasses": "recontratar",
    "recontrataste": "recontratar",
    "recontratastes": "recontratar",
    "recontratava": "recontratar",
    "recontratavam": "recontratar",
    "recontratavas": "recontratar",
    "recontrate": "recontratar",
    "recontratei": "recontratar",
    "recontrateis": "recontratar",
    "recontratem": "recontratar",
    "recontratemo": "recontratar",
    "recontratemos": "recontratar",
    "recontrates": "recontratar",
    "recontrato": "recontratar",
    "recontratos": "recontrato",
    "recontratou": "recontratar",
    "recontratá": "recontratar",
    "recontratámo": "recontratar",
    "recontratámos": "recontratar",
    "recontratáramo": "recontratar",
    "recontratáramos": "recontratar",
    "recontratárei": "recontratar",
    "recontratáreis": "recontratar",
    "recontratásseis": "recontratar",
    "recontratássemos": "recontratar",
    "recontratávamo": "recontratar",
    "recontratávamos": "recontratar",
    "recontratávei": "recontratar",
    "recontratáveis": "recontratar",
    "recontros": "recontro",
    "recontá": "recontar",
    "recontámo": "recontar",
    "recontámos": "recontar",
    "recontáramo": "recontar",
    "recontáramos": "recontar",
    "recontárei": "recontar",
    "recontáreis": "recontar",
    "recontásseis": "recontar",
    "recontássemos": "recontar",
    "recontávamo": "recontar",
    "recontávamos": "recontar",
    "recontávei": "recontar",
    "recontáveis": "recontar",
    "reconvalesce": "reconvalescer",
    "reconvalescei": "reconvalescer",
    "reconvalesceis": "reconvalescer",
    "reconvalescem": "reconvalescer",
    "reconvalescemo": "reconvalescer",
    "reconvalescemos": "reconvalescer",
    "reconvalescendo": "reconvalescer",
    "reconvalescentes": "reconvalescente",
    "reconvalescenças": "reconvalescença",
    "reconvalescera": "reconvalescer",
    "reconvalesceram": "reconvalescer",
    "reconvalesceras": "reconvalescer",
    "reconvalescerdes": "reconvalescer",
    "reconvalescerei": "reconvalescer",
    "reconvalescereis": "reconvalescer",
    "reconvalescerem": "reconvalescer",
    "reconvalesceremos": "reconvalescer",
    "reconvalesceres": "reconvalescer",
    "reconvalesceria": "reconvalescer",
    "reconvalesceriam": "reconvalescer",
    "reconvalescerias": "reconvalescer",
    "reconvalescermo": "reconvalescer",
    "reconvalescermos": "reconvalescer",
    "reconvalescerá": "reconvalescer",
    "reconvalescerás": "reconvalescer",
    "reconvalescerão": "reconvalescer",
    "reconvalesceríamos": "reconvalescer",
    "reconvalesceríeis": "reconvalescer",
    "reconvalesces": "reconvalescer",
    "reconvalescesse": "reconvalescer",
    "reconvalescessem": "reconvalescer",
    "reconvalescesses": "reconvalescer",
    "reconvalesceste": "reconvalescer",
    "reconvalescestes": "reconvalescer",
    "reconvalesceu": "reconvalescer",
    "reconvalesci": "reconvalescer",
    "reconvalescia": "reconvalescer",
    "reconvalesciam": "reconvalescer",
    "reconvalescias": "reconvalescer",
    "reconvalescida": "reconvalescer",
    "reconvalescidas": "reconvalescer",
    "reconvalescido": "reconvalescer",
    "reconvalescidos": "reconvalescer",
    "reconvalescêramo": "reconvalescer",
    "reconvalescêramos": "reconvalescer",
    "reconvalescêreis": "reconvalescer",
    "reconvalescêsseis": "reconvalescer",
    "reconvalescêssemos": "reconvalescer",
    "reconvalescíamo": "reconvalescer",
    "reconvalescíamos": "reconvalescer",
    "reconvalescíeis": "reconvalescer",
    "reconvalesça": "reconvalescer",
    "reconvalesçais": "reconvalescer",
    "reconvalesçam": "reconvalescer",
    "reconvalesçamo": "reconvalescer",
    "reconvalesçamos": "reconvalescer",
    "reconvalesças": "reconvalescer",
    "reconvalesço": "reconvalescer",
    "reconveio": "reconvir",
    "reconvem": "reconvir",
    "reconvenha": "reconvir",
    "reconvenhais": "reconvir",
    "reconvenham": "reconvir",
    "reconvenhamo": "reconvir",
    "reconvenhamos": "reconvir",
    "reconvenhas": "reconvir",
    "reconvenho": "reconvir",
    "reconvenções": "reconvenção",
    "reconversões": "reconversão",
    "reconverta": "reconverter",
    "reconvertais": "reconverter",
    "reconvertam": "reconverter",
    "reconvertamo": "reconverter",
    "reconvertamos": "reconverter",
    "reconvertas": "reconverter",
    "reconverte": "reconverter",
    "reconvertei": "reconverter",
    "reconverteis": "reconverter",
    "reconvertem": "reconverter",
    "reconvertemo": "reconverter",
    "reconvertemos": "reconverter",
    "reconvertendo": "reconverter",
    "reconvertera": "reconverter",
    "reconverteram": "reconverter",
    "reconverteras": "reconverter",
    "reconverterde": "reconverter",
    "reconverterdes": "reconverter",
    "reconvertere": "reconverter",
    "reconverterei": "reconverter",
    "reconvertereis": "reconverter",
    "reconverterem": "reconverter",
    "reconverteremos": "reconverter",
    "reconverteres": "reconverter",
    "reconverteria": "reconverter",
    "reconverteriam": "reconverter",
    "reconverterias": "reconverter",
    "reconvertermo": "reconverter",
    "reconvertermos": "reconverter",
    "reconverterá": "reconverter",
    "reconverterás": "reconverter",
    "reconverterão": "reconverter",
    "reconverteríamos": "reconverter",
    "reconverteríeis": "reconverter",
    "reconvertes": "reconverter",
    "reconvertesse": "reconverter",
    "reconvertessem": "reconverter",
    "reconvertesses": "reconverter",
    "reconverteste": "reconverter",
    "reconvertestes": "reconverter",
    "reconverteu": "reconverter",
    "reconverti": "reconverter",
    "reconvertia": "reconverter",
    "reconvertiam": "reconverter",
    "reconvertias": "reconverter",
    "reconvertida": "reconvertido",
    "reconvertidas": "reconvertido",
    "reconvertido": "reconverter",
    "reconvertidos": "reconvertido",
    "reconverto": "reconverter",
    "reconvertê": "reconverter",
    "reconvertêramo": "reconverter",
    "reconvertêramos": "reconverter",
    "reconvertêrei": "reconverter",
    "reconvertêreis": "reconverter",
    "reconvertêsseis": "reconverter",
    "reconvertêssemos": "reconverter",
    "reconvertíamo": "reconverter",
    "reconvertíamos": "reconverter",
    "reconvertíei": "reconverter",
    "reconvertíeis": "reconverter",
    "reconvertíveis": "reconvertível",
    "reconviemo": "reconvir",
    "reconviemos": "reconvir",
    "reconvier": "reconvir",
    "reconviera": "reconvir",
    "reconvieram": "reconvir",
    "reconvieras": "reconvir",
    "reconvierdes": "reconvir",
    "reconvierem": "reconvir",
    "reconvieres": "reconvir",
    "reconviermos": "reconvir",
    "reconviesse": "reconvir",
    "reconviessem": "reconvir",
    "reconviesses": "reconvir",
    "reconvieste": "reconvir",
    "reconviestes": "reconvir",
    "reconvim": "reconvir",
    "reconvimo": "reconvir",
    "reconvimos": "reconvir",
    "reconvinda": "reconvir",
    "reconvindas": "reconvir",
    "reconvinde": "reconvir",
    "reconvindes": "reconvir",
    "reconvindo": "reconvir",
    "reconvindos": "reconvir",
    "reconvinha": "reconvir",
    "reconvinham": "reconvir",
    "reconvinhas": "reconvir",
    "reconvirdes": "reconvir",
    "reconvirei": "reconvir",
    "reconvireis": "reconvir",
    "reconvirem": "reconvir",
    "reconviremos": "reconvir",
    "reconvires": "reconvir",
    "reconviria": "reconvir",
    "reconviriam": "reconvir",
    "reconvirias": "reconvir",
    "reconvirmo": "reconvir",
    "reconvirmos": "reconvir",
    "reconvirá": "reconvir",
    "reconvirás": "reconvir",
    "reconvirão": "reconvir",
    "reconviríamos": "reconvir",
    "reconviríeis": "reconvir",
    "reconviéramo": "reconvir",
    "reconviéramos": "reconvir",
    "reconviéreis": "reconvir",
    "reconviésseis": "reconvir",
    "reconviéssemos": "reconvir",
    "reconvocações": "reconvocação",
    "reconvém": "reconvir",
    "reconvéns": "reconvir",
    "reconvêm": "reconvir",
    "reconvínhamo": "reconvir",
    "reconvínhamos": "reconvir",
    "reconvínheis": "reconvir",
    "recopia": "recopiar",
    "recopiada": "recopiar",
    "recopiadas": "recopiar",
    "recopiado": "recopiar",
    "recopiados": "recopiar",
    "recopiai": "recopiar",
    "recopiais": "recopiar",
    "recopiam": "recopiar",
    "recopiamo": "recopiar",
    "recopiamos": "recopiar",
    "recopiando": "recopiar",
    "recopiara": "recopiar",
    "recopiaram": "recopiar",
    "recopiaras": "recopiar",
    "recopiarde": "recopiar",
    "recopiardes": "recopiar",
    "recopiare": "recopiar",
    "recopiarei": "recopiar",
    "recopiareis": "recopiar",
    "recopiarem": "recopiar",
    "recopiaremos": "recopiar",
    "recopiares": "recopiar",
    "recopiaria": "recopiar",
    "recopiariam": "recopiar",
    "recopiarias": "recopiar",
    "recopiarmo": "recopiar",
    "recopiarmos": "recopiar",
    "recopiará": "recopiar",
    "recopiarás": "recopiar",
    "recopiarão": "recopiar",
    "recopiaríamos": "recopiar",
    "recopiaríeis": "recopiar",
    "recopias": "recopiar",
    "recopiasse": "recopiar",
    "recopiassem": "recopiar",
    "recopiasses": "recopiar",
    "recopiaste": "recopiar",
    "recopiastes": "recopiar",
    "recopiava": "recopiar",
    "recopiavam": "recopiar",
    "recopiavas": "recopiar",
    "recopie": "recopiar",
    "recopiei": "recopiar",
    "recopieis": "recopiar",
    "recopiem": "recopiar",
    "recopiemo": "recopiar",
    "recopiemos": "recopiar",
    "recopies": "recopiar",
    "recopila": "recopilar",
    "recopilada": "recopilar",
    "recopiladas": "recopilar",
    "recopilado": "recopilar",
    "recopiladora": "recopilador",
    "recopiladoras": "recopilador",
    "recopiladores": "recopilador",
    "recopilados": "recopilar",
    "recopilai": "recopilar",
    "recopilais": "recopilar",
    "recopilam": "recopilar",
    "recopilamo": "recopilar",
    "recopilamos": "recopilar",
    "recopilando": "recopilar",
    "recopilara": "recopilar",
    "recopilaram": "recopilar",
    "recopilaras": "recopilar",
    "recopilarde": "recopilar",
    "recopilardes": "recopilar",
    "recopilare": "recopilar",
    "recopilarei": "recopilar",
    "recopilareis": "recopilar",
    "recopilarem": "recopilar",
    "recopilaremos": "recopilar",
    "recopilares": "recopilar",
    "recopilaria": "recopilar",
    "recopilariam": "recopilar",
    "recopilarias": "recopilar",
    "recopilarmo": "recopilar",
    "recopilarmos": "recopilar",
    "recopilará": "recopilar",
    "recopilarás": "recopilar",
    "recopilarão": "recopilar",
    "recopilaríamos": "recopilar",
    "recopilaríeis": "recopilar",
    "recopilas": "recopilar",
    "recopilasse": "recopilar",
    "recopilassem": "recopilar",
    "recopilasses": "recopilar",
    "recopilaste": "recopilar",
    "recopilastes": "recopilar",
    "recopilava": "recopilar",
    "recopilavam": "recopilar",
    "recopilavas": "recopilar",
    "recopilações": "recopilação",
    "recopile": "recopilar",
    "recopilei": "recopilar",
    "recopileis": "recopilar",
    "recopilem": "recopilar",
    "recopilemo": "recopilar",
    "recopilemos": "recopilar",
    "recopiles": "recopilar",
    "recopilo": "recopilar",
    "recopilou": "recopilar",
    "recopilá": "recopilar",
    "recopilámo": "recopilar",
    "recopilámos": "recopilar",
    "recopiláramo": "recopilar",
    "recopiláramos": "recopilar",
    "recopilárei": "recopilar",
    "recopiláreis": "recopilar",
    "recopilásseis": "recopilar",
    "recopilássemos": "recopilar",
    "recopilávamo": "recopilar",
    "recopilávamos": "recopilar",
    "recopilávei": "recopilar",
    "recopiláveis": "recopilar",
    "recopio": "recopiar",
    "recopiou": "recopiar",
    "recopiá": "recopiar",
    "recopiámo": "recopiar",
    "recopiámos": "recopiar",
    "recopiáramo": "recopiar",
    "recopiáramos": "recopiar",
    "recopiárei": "recopiar",
    "recopiáreis": "recopiar",
    "recopiásseis": "recopiar",
    "recopiássemos": "recopiar",
    "recopiávamo": "recopiar",
    "recopiávamos": "recopiar",
    "recopiávei": "recopiar",
    "recopiáveis": "recopiar",
    "recorda": "recordar",
    "recordada": "recordar",
    "recordadas": "recordar",
    "recordado": "recordar",
    "recordadora": "recordador",
    "recordadoras": "recordador",
    "recordadores": "recordador",
    "recordados": "recordar",
    "recordadíssima": "recordado",
    "recordadíssimas": "recordado",
    "recordadíssimo": "recordado",
    "recordadíssimos": "recordado",
    "recordai": "recordar",
    "recordais": "recordar",
    "recordam": "recordar",
    "recordamo": "recordar",
    "recordamos": "recordar",
    "recordando": "recordar",
    "recordara": "recordar",
    "recordaram": "recordar",
    "recordaras": "recordar",
    "recordarde": "recordar",
    "recordardes": "recordar",
    "recordare": "recordar",
    "recordarei": "recordar",
    "recordareis": "recordar",
    "recordarem": "recordar",
    "recordaremos": "recordar",
    "recordares": "recordar",
    "recordaria": "recordar",
    "recordariam": "recordar",
    "recordarias": "recordar",
    "recordarmo": "recordar",
    "recordarmos": "recordar",
    "recordará": "recordar",
    "recordarás": "recordar",
    "recordarão": "recordar",
    "recordaríamos": "recordar",
    "recordaríeis": "recordar",
    "recordas": "recordar",
    "recordasse": "recordar",
    "recordassem": "recordar",
    "recordasses": "recordar",
    "recordaste": "recordar",
    "recordastes": "recordar",
    "recordativa": "recordativo",
    "recordativas": "recordativo",
    "recordativos": "recordativo",
    "recordatória": "recordatório",
    "recordatórias": "recordatório",
    "recordatórios": "recordatório",
    "recordava": "recordar",
    "recordavam": "recordar",
    "recordavas": "recordar",
    "recordações": "recordação",
    "recorde": "recordar",
    "recordei": "recordar",
    "recordeis": "recordar",
    "recordem": "recordar",
    "recordemo": "recordar",
    "recordemos": "recordar",
    "recordes": "recorde",
    "recordistas": "recordista",
    "recordo": "recordar",
    "recordos": "recordo",
    "recordou": "recordar",
    "recordá": "recordar",
    "recordámo": "recordar",
    "recordámos": "recordar",
    "recordáramo": "recordar",
    "recordáramos": "recordar",
    "recordárei": "recordar",
    "recordáreis": "recordar",
    "recordásseis": "recordar",
    "recordássemos": "recordar",
    "recordávamo": "recordar",
    "recordávamos": "recordar",
    "recordávei": "recordar",
    "recordáveis": "recordável",
    "recoroa": "recoroar",
    "recoroada": "recoroar",
    "recoroadas": "recoroar",
    "recoroado": "recoroar",
    "recoroados": "recoroar",
    "recoroai": "recoroar",
    "recoroais": "recoroar",
    "recoroam": "recoroar",
    "recoroamo": "recoroar",
    "recoroamos": "recoroar",
    "recoroando": "recoroar",
    "recoroara": "recoroar",
    "recoroaram": "recoroar",
    "recoroaras": "recoroar",
    "recoroarde": "recoroar",
    "recoroardes": "recoroar",
    "recoroare": "recoroar",
    "recoroarei": "recoroar",
    "recoroareis": "recoroar",
    "recoroarem": "recoroar",
    "recoroaremos": "recoroar",
    "recoroares": "recoroar",
    "recoroaria": "recoroar",
    "recoroariam": "recoroar",
    "recoroarias": "recoroar",
    "recoroarmo": "recoroar",
    "recoroarmos": "recoroar",
    "recoroará": "recoroar",
    "recoroarás": "recoroar",
    "recoroarão": "recoroar",
    "recoroaríamos": "recoroar",
    "recoroaríeis": "recoroar",
    "recoroas": "recoroar",
    "recoroasse": "recoroar",
    "recoroassem": "recoroar",
    "recoroasses": "recoroar",
    "recoroaste": "recoroar",
    "recoroastes": "recoroar",
    "recoroava": "recoroar",
    "recoroavam": "recoroar",
    "recoroavas": "recoroar",
    "recoroe": "recoroar",
    "recoroei": "recoroar",
    "recoroeis": "recoroar",
    "recoroem": "recoroar",
    "recoroemo": "recoroar",
    "recoroemos": "recoroar",
    "recoroes": "recoroar",
    "recoroo": "recoroar",
    "recoroou": "recoroar",
    "recoroá": "recoroar",
    "recoroámo": "recoroar",
    "recoroámos": "recoroar",
    "recoroáramo": "recoroar",
    "recoroáramos": "recoroar",
    "recoroárei": "recoroar",
    "recoroáreis": "recoroar",
    "recoroásseis": "recoroar",
    "recoroássemos": "recoroar",
    "recoroávamo": "recoroar",
    "recoroávamos": "recoroar",
    "recoroávei": "recoroar",
    "recoroáveis": "recoroar",
    "recorra": "recorrer",
    "recorrais": "recorrer",
    "recorram": "recorrer",
    "recorramo": "recorrer",
    "recorramos": "recorrer",
    "recorras": "recorrer",
    "recorre": "recorrer",
    "recorrei": "recorrer",
    "recorreis": "recorrer",
    "recorrem": "recorrer",
    "recorremo": "recorrer",
    "recorremos": "recorrer",
    "recorrendo": "recorrer",
    "recorrentes": "recorrente",
    "recorrera": "recorrer",
    "recorreram": "recorrer",
    "recorreras": "recorrer",
    "recorrerde": "recorrer",
    "recorrerdes": "recorrer",
    "recorrere": "recorrer",
    "recorrerei": "recorrer",
    "recorrereis": "recorrer",
    "recorrerem": "recorrer",
    "recorreremos": "recorrer",
    "recorreres": "recorrer",
    "recorreria": "recorrer",
    "recorreriam": "recorrer",
    "recorrerias": "recorrer",
    "recorrermo": "recorrer",
    "recorrermos": "recorrer",
    "recorrerá": "recorrer",
    "recorrerás": "recorrer",
    "recorrerão": "recorrer",
    "recorreríamos": "recorrer",
    "recorreríeis": "recorrer",
    "recorres": "recorrer",
    "recorresse": "recorrer",
    "recorressem": "recorrer",
    "recorresses": "recorrer",
    "recorreste": "recorrer",
    "recorrestes": "recorrer",
    "recorreu": "recorrer",
    "recorri": "recorrer",
    "recorria": "recorrer",
    "recorriam": "recorrer",
    "recorrias": "recorrer",
    "recorrida": "recorrido",
    "recorridas": "recorrido",
    "recorrido": "recorrer",
    "recorridos": "recorrido",
    "recorro": "recorrer",
    "recorrê": "recorrer",
    "recorrências": "recorrência",
    "recorrêramo": "recorrer",
    "recorrêramos": "recorrer",
    "recorrêrei": "recorrer",
    "recorrêreis": "recorrer",
    "recorrêsseis": "recorrer",
    "recorrêssemos": "recorrer",
    "recorríamo": "recorrer",
    "recorríamos": "recorrer",
    "recorríei": "recorrer",
    "recorríeis": "recorrer",
    "recorríveis": "recorrível",
    "recorta": "recortar",
    "recortada": "recortar",
    "recortadas": "recortar",
    "recortado": "recortar",
    "recortadora": "recortador",
    "recortadoras": "recortador",
    "recortadores": "recortador",
    "recortados": "recortar",
    "recortai": "recortar",
    "recortais": "recortar",
    "recortam": "recortar",
    "recortamo": "recortar",
    "recortamos": "recortar",
    "recortando": "recortar",
    "recortara": "recortar",
    "recortaram": "recortar",
    "recortaras": "recortar",
    "recortarde": "recortar",
    "recortardes": "recortar",
    "recortare": "recortar",
    "recortarei": "recortar",
    "recortareis": "recortar",
    "recortarem": "recortar",
    "recortaremos": "recortar",
    "recortares": "recortar",
    "recortaria": "recortar",
    "recortariam": "recortar",
    "recortarias": "recortar",
    "recortarmo": "recortar",
    "recortarmos": "recortar",
    "recortará": "recortar",
    "recortarás": "recortar",
    "recortarão": "recortar",
    "recortaríamos": "recortar",
    "recortaríeis": "recortar",
    "recortas": "recortar",
    "recortasse": "recortar",
    "recortassem": "recortar",
    "recortasses": "recortar",
    "recortaste": "recortar",
    "recortastes": "recortar",
    "recortava": "recortar",
    "recortavam": "recortar",
    "recortavas": "recortar",
    "recorte": "recortar",
    "recortei": "recortar",
    "recorteis": "recortar",
    "recortem": "recortar",
    "recortemo": "recortar",
    "recortemos": "recortar",
    "recortes": "recorte",
    "recortilhas": "recortilha",
    "recorto": "recortar",
    "recortou": "recortar",
    "recortá": "recortar",
    "recortámo": "recortar",
    "recortámos": "recortar",
    "recortáramo": "recortar",
    "recortáramos": "recortar",
    "recortárei": "recortar",
    "recortáreis": "recortar",
    "recortásseis": "recortar",
    "recortássemos": "recortar",
    "recortávamo": "recortar",
    "recortávamos": "recortar",
    "recortávei": "recortar",
    "recortáveis": "recortar",
    "recos": "reco",
    "recosa": "recoser",
    "recosais": "recoser",
    "recosam": "recoser",
    "recosamo": "recoser",
    "recosamos": "recoser",
    "recosas": "recoser",
    "recose": "recoser",
    "recosei": "recoser",
    "recoseis": "recoser",
    "recosem": "recoser",
    "recosemo": "recoser",
    "recosemos": "recoser",
    "recosendo": "recoser",
    "recosera": "recoser",
    "recoseram": "recoser",
    "recoseras": "recoser",
    "recoserde": "recoser",
    "recoserdes": "recoser",
    "recosere": "recoser",
    "recoserei": "recoser",
    "recosereis": "recoser",
    "recoserem": "recoser",
    "recoseremos": "recoser",
    "recoseres": "recoser",
    "recoseria": "recoser",
    "recoseriam": "recoser",
    "recoserias": "recoser",
    "recosermo": "recoser",
    "recosermos": "recoser",
    "recoserá": "recoser",
    "recoserás": "recoser",
    "recoserão": "recoser",
    "recoseríamos": "recoser",
    "recoseríeis": "recoser",
    "recoses": "recoser",
    "recosesse": "recoser",
    "recosessem": "recoser",
    "recosesses": "recoser",
    "recoseste": "recoser",
    "recosestes": "recoser",
    "recoseu": "recoser",
    "recosi": "recoser",
    "recosia": "recoser",
    "recosiam": "recoser",
    "recosias": "recoser",
    "recosida": "recoser",
    "recosidas": "recoser",
    "recosido": "recoser",
    "recosidos": "recoser",
    "recoso": "recoser",
    "recosta": "recostar",
    "recostada": "recostar",
    "recostadas": "recostar",
    "recostado": "recostar",
    "recostados": "recostar",
    "recostai": "recostar",
    "recostais": "recostar",
    "recostam": "recostar",
    "recostamo": "recostar",
    "recostamos": "recostar",
    "recostando": "recostar",
    "recostara": "recostar",
    "recostaram": "recostar",
    "recostaras": "recostar",
    "recostarde": "recostar",
    "recostardes": "recostar",
    "recostare": "recostar",
    "recostarei": "recostar",
    "recostareis": "recostar",
    "recostarem": "recostar",
    "recostaremos": "recostar",
    "recostares": "recostar",
    "recostaria": "recostar",
    "recostariam": "recostar",
    "recostarias": "recostar",
    "recostarmo": "recostar",
    "recostarmos": "recostar",
    "recostará": "recostar",
    "recostarás": "recostar",
    "recostarão": "recostar",
    "recostaríamos": "recostar",
    "recostaríeis": "recostar",
    "recostas": "recostar",
    "recostasse": "recostar",
    "recostassem": "recostar",
    "recostasses": "recostar",
    "recostaste": "recostar",
    "recostastes": "recostar",
    "recostava": "recostar",
    "recostavam": "recostar",
    "recostavas": "recostar",
    "recoste": "recostar",
    "recostei": "recostar",
    "recosteis": "recostar",
    "recostem": "recostar",
    "recostemo": "recostar",
    "recostemos": "recostar",
    "recostes": "recostar",
    "recosto": "recostar",
    "recostos": "recosto",
    "recostou": "recostar",
    "recostá": "recostar",
    "recostámo": "recostar",
    "recostámos": "recostar",
    "recostáramo": "recostar",
    "recostáramos": "recostar",
    "recostárei": "recostar",
    "recostáreis": "recostar",
    "recostásseis": "recostar",
    "recostássemos": "recostar",
    "recostávamo": "recostar",
    "recostávamos": "recostar",
    "recostávei": "recostar",
    "recostáveis": "recostar",
    "recosê": "recoser",
    "recosêramo": "recoser",
    "recosêramos": "recoser",
    "recosêrei": "recoser",
    "recosêreis": "recoser",
    "recosêsseis": "recoser",
    "recosêssemos": "recoser",
    "recosíamo": "recoser",
    "recosíamos": "recoser",
    "recosíei": "recoser",
    "recosíeis": "recoser",
    "recova": "recovar",
    "recovada": "recovar",
    "recovadas": "recovar",
    "recovado": "recovar",
    "recovados": "recovar",
    "recovagens": "recovagem",
    "recovai": "recovar",
    "recovais": "recovar",
    "recovam": "recovar",
    "recovamo": "recovar",
    "recovamos": "recovar",
    "recovando": "recovar",
    "recovara": "recovar",
    "recovaram": "recovar",
    "recovaras": "recovar",
    "recovarde": "recovar",
    "recovardes": "recovar",
    "recovare": "recovar",
    "recovarei": "recovar",
    "recovareis": "recovar",
    "recovarem": "recovar",
    "recovaremos": "recovar",
    "recovares": "recovar",
    "recovaria": "recovar",
    "recovariam": "recovar",
    "recovarias": "recovar",
    "recovarmo": "recovar",
    "recovarmos": "recovar",
    "recovará": "recovar",
    "recovarás": "recovar",
    "recovarão": "recovar",
    "recovaríamos": "recovar",
    "recovaríeis": "recovar",
    "recovas": "recovar",
    "recovasse": "recovar",
    "recovassem": "recovar",
    "recovasses": "recovar",
    "recovaste": "recovar",
    "recovastes": "recovar",
    "recovava": "recovar",
    "recovavam": "recovar",
    "recovavas": "recovar",
    "recove": "recovar",
    "recovei": "recovar",
    "recoveira": "recoveiro",
    "recoveiras": "recoveiro",
    "recoveiros": "recoveiro",
    "recoveis": "recovar",
    "recovem": "recovar",
    "recovemo": "recovar",
    "recovemos": "recovar",
    "recoves": "recovar",
    "recovo": "recovar",
    "recovos": "recovo",
    "recovou": "recovar",
    "recová": "recovar",
    "recovámo": "recovar",
    "recovámos": "recovar",
    "recováramo": "recovar",
    "recováramos": "recovar",
    "recovárei": "recovar",
    "recováreis": "recovar",
    "recovásseis": "recovar",
    "recovássemos": "recovar",
    "recovávamo": "recovar",
    "recovávamos": "recovar",
    "recovávei": "recovar",
    "recováveis": "recovar",
    "recoza": "recozer",
    "recozais": "recozer",
    "recozam": "recozer",
    "recozamo": "recozer",
    "recozamos": "recozer",
    "recozas": "recozer",
    "recoze": "recozer",
    "recozeduras": "recozedura",
    "recozei": "recozer",
    "recozeis": "recozer",
    "recozem": "recozer",
    "recozemo": "recozer",
    "recozemos": "recozer",
    "recozendo": "recozer",
    "recozera": "recozer",
    "recozeram": "recozer",
    "recozeras": "recozer",
    "recozerde": "recozer",
    "recozerdes": "recozer",
    "recozere": "recozer",
    "recozerei": "recozer",
    "recozereis": "recozer",
    "recozerem": "recozer",
    "recozeremos": "recozer",
    "recozeres": "recozer",
    "recozeria": "recozer",
    "recozeriam": "recozer",
    "recozerias": "recozer",
    "recozermo": "recozer",
    "recozermos": "recozer",
    "recozerá": "recozer",
    "recozerás": "recozer",
    "recozerão": "recozer",
    "recozeríamos": "recozer",
    "recozeríeis": "recozer",
    "recozes": "recozer",
    "recozesse": "recozer",
    "recozessem": "recozer",
    "recozesses": "recozer",
    "recozeste": "recozer",
    "recozestes": "recozer",
    "recozeu": "recozer",
    "recozi": "recozer",
    "recozia": "recozer",
    "recoziam": "recozer",
    "recozias": "recozer",
    "recozida": "recozido",
    "recozidas": "recozido",
    "recozido": "recozer",
    "recozidos": "recozido",
    "recozimentos": "recozimento",
    "recozo": "recozer",
    "recozê": "recozer",
    "recozêramo": "recozer",
    "recozêramos": "recozer",
    "recozêrei": "recozer",
    "recozêreis": "recozer",
    "recozêsseis": "recozer",
    "recozêssemos": "recozer",
    "recozíamo": "recozer",
    "recozíamos": "recozer",
    "recozíei": "recozer",
    "recozíeis": "recozer",
    "recrava": "recravar",
    "recravada": "recravar",
    "recravadas": "recravar",
    "recravado": "recravar",
    "recravados": "recravar",
    "recravai": "recravar",
    "recravais": "recravar",
    "recravam": "recravar",
    "recravamo": "recravar",
    "recravamos": "recravar",
    "recravando": "recravar",
    "recravara": "recravar",
    "recravaram": "recravar",
    "recravaras": "recravar",
    "recravarde": "recravar",
    "recravardes": "recravar",
    "recravare": "recravar",
    "recravarei": "recravar",
    "recravareis": "recravar",
    "recravarem": "recravar",
    "recravaremos": "recravar",
    "recravares": "recravar",
    "recravaria": "recravar",
    "recravariam": "recravar",
    "recravarias": "recravar",
    "recravarmo": "recravar",
    "recravarmos": "recravar",
    "recravará": "recravar",
    "recravarás": "recravar",
    "recravarão": "recravar",
    "recravaríamos": "recravar",
    "recravaríeis": "recravar",
    "recravas": "recravar",
    "recravasse": "recravar",
    "recravassem": "recravar",
    "recravasses": "recravar",
    "recravaste": "recravar",
    "recravastes": "recravar",
    "recravava": "recravar",
    "recravavam": "recravar",
    "recravavas": "recravar",
    "recrave": "recravar",
    "recravei": "recravar",
    "recraveis": "recravar",
    "recravem": "recravar",
    "recravemo": "recravar",
    "recravemos": "recravar",
    "recraves": "recravar",
    "recravo": "recravar",
    "recravou": "recravar",
    "recravá": "recravar",
    "recravámo": "recravar",
    "recravámos": "recravar",
    "recraváramo": "recravar",
    "recraváramos": "recravar",
    "recravárei": "recravar",
    "recraváreis": "recravar",
    "recravásseis": "recravar",
    "recravássemos": "recravar",
    "recravávamo": "recravar",
    "recravávamos": "recravar",
    "recravávei": "recravar",
    "recraváveis": "recravar",
    "recreada": "recrear",
    "recreadas": "recrear",
    "recreado": "recrear",
    "recreadora": "recreador",
    "recreadoras": "recreador",
    "recreadores": "recreador",
    "recreados": "recrear",
    "recreai": "recrear",
    "recreais": "recrear",
    "recreamo": "recrear",
    "recreamos": "recrear",
    "recreando": "recrear",
    "recreara": "recrear",
    "recrearam": "recrear",
    "recrearas": "recrear",
    "recrearde": "recrear",
    "recreardes": "recrear",
    "recreare": "recrear",
    "recrearei": "recrear",
    "recreareis": "recrear",
    "recrearem": "recrear",
    "recrearemos": "recrear",
    "recreares": "recrear",
    "recrearia": "recrear",
    "recreariam": "recrear",
    "recrearias": "recrear",
    "recrearmo": "recrear",
    "recrearmos": "recrear",
    "recreará": "recrear",
    "recrearás": "recrear",
    "recrearão": "recrear",
    "recrearíamos": "recrear",
    "recrearíeis": "recrear",
    "recreasse": "recrear",
    "recreassem": "recrear",
    "recreasses": "recrear",
    "recreaste": "recrear",
    "recreastes": "recrear",
    "recreativa": "recreativo",
    "recreativas": "recreativo",
    "recreativos": "recreativo",
    "recreatória": "recreatório",
    "recreatórias": "recreatório",
    "recreatórios": "recreatório",
    "recreava": "recrear",
    "recreavam": "recrear",
    "recreavas": "recrear",
    "recreações": "recreação",
    "recredenciais": "recredencial",
    "recreei": "recrear",
    "recreeis": "recrear",
    "recreemo": "recrear",
    "recreemos": "recrear",
    "recreia": "recrear",
    "recreiam": "recrear",
    "recreias": "recrear",
    "recreie": "recrear",
    "recreiem": "recrear",
    "recreies": "recrear",
    "recreio": "recrear",
    "recreios": "recreio",
    "recrementos": "recremento",
    "recrementícia": "recrementício",
    "recrementícias": "recrementício",
    "recrementícios": "recrementício",
    "recreou": "recrear",
    "recresce": "recrescer",
    "recrescei": "recrescer",
    "recresceis": "recrescer",
    "recrescem": "recrescer",
    "recrescemo": "recrescer",
    "recrescemos": "recrescer",
    "recrescendo": "recrescer",
    "recrescentes": "recrescente",
    "recrescera": "recrescer",
    "recresceram": "recrescer",
    "recresceras": "recrescer",
    "recrescerdes": "recrescer",
    "recrescerei": "recrescer",
    "recrescereis": "recrescer",
    "recrescerem": "recrescer",
    "recresceremos": "recrescer",
    "recresceres": "recrescer",
    "recresceria": "recrescer",
    "recresceriam": "recrescer",
    "recrescerias": "recrescer",
    "recrescermo": "recrescer",
    "recrescermos": "recrescer",
    "recrescerá": "recrescer",
    "recrescerás": "recrescer",
    "recrescerão": "recrescer",
    "recresceríamos": "recrescer",
    "recresceríeis": "recrescer",
    "recresces": "recrescer",
    "recrescesse": "recrescer",
    "recrescessem": "recrescer",
    "recrescesses": "recrescer",
    "recresceste": "recrescer",
    "recrescestes": "recrescer",
    "recresceu": "recrescer",
    "recresci": "recrescer",
    "recrescia": "recrescer",
    "recresciam": "recrescer",
    "recrescias": "recrescer",
    "recrescida": "recrescer",
    "recrescidas": "recrescer",
    "recrescido": "recrescer",
    "recrescidos": "recrescer",
    "recrescimentos": "recrescimento",
    "recrescências": "recrescência",
    "recrescêramo": "recrescer",
    "recrescêramos": "recrescer",
    "recrescêreis": "recrescer",
    "recrescêsseis": "recrescer",
    "recrescêssemos": "recrescer",
    "recrescíamo": "recrescer",
    "recrescíamos": "recrescer",
    "recrescíeis": "recrescer",
    "recresta": "recrestar",
    "recrestada": "recrestar",
    "recrestadas": "recrestar",
    "recrestado": "recrestar",
    "recrestados": "recrestar",
    "recrestai": "recrestar",
    "recrestais": "recrestar",
    "recrestam": "recrestar",
    "recrestamo": "recrestar",
    "recrestamos": "recrestar",
    "recrestando": "recrestar",
    "recrestara": "recrestar",
    "recrestaram": "recrestar",
    "recrestaras": "recrestar",
    "recrestarde": "recrestar",
    "recrestardes": "recrestar",
    "recrestare": "recrestar",
    "recrestarei": "recrestar",
    "recrestareis": "recrestar",
    "recrestarem": "recrestar",
    "recrestaremos": "recrestar",
    "recrestares": "recrestar",
    "recrestaria": "recrestar",
    "recrestariam": "recrestar",
    "recrestarias": "recrestar",
    "recrestarmo": "recrestar",
    "recrestarmos": "recrestar",
    "recrestará": "recrestar",
    "recrestarás": "recrestar",
    "recrestarão": "recrestar",
    "recrestaríamos": "recrestar",
    "recrestaríeis": "recrestar",
    "recrestas": "recrestar",
    "recrestasse": "recrestar",
    "recrestassem": "recrestar",
    "recrestasses": "recrestar",
    "recrestaste": "recrestar",
    "recrestastes": "recrestar",
    "recrestava": "recrestar",
    "recrestavam": "recrestar",
    "recrestavas": "recrestar",
    "recreste": "recrestar",
    "recrestei": "recrestar",
    "recresteis": "recrestar",
    "recrestem": "recrestar",
    "recrestemo": "recrestar",
    "recrestemos": "recrestar",
    "recrestes": "recrestar",
    "recresto": "recrestar",
    "recrestou": "recrestar",
    "recrestá": "recrestar",
    "recrestámo": "recrestar",
    "recrestámos": "recrestar",
    "recrestáramo": "recrestar",
    "recrestáramos": "recrestar",
    "recrestárei": "recrestar",
    "recrestáreis": "recrestar",
    "recrestásseis": "recrestar",
    "recrestássemos": "recrestar",
    "recrestávamo": "recrestar",
    "recrestávamos": "recrestar",
    "recrestávei": "recrestar",
    "recrestáveis": "recrestar",
    "recresça": "recrescer",
    "recresçais": "recrescer",
    "recresçam": "recrescer",
    "recresçamo": "recrescer",
    "recresçamos": "recrescer",
    "recresças": "recrescer",
    "recresço": "recrescer",
    "recreá": "recrear",
    "recreámo": "recrear",
    "recreámos": "recrear",
    "recreáramo": "recrear",
    "recreáramos": "recrear",
    "recreárei": "recrear",
    "recreáreis": "recrear",
    "recreásseis": "recrear",
    "recreássemos": "recrear",
    "recreávamo": "recrear",
    "recreávamos": "recrear",
    "recreávei": "recrear",
    "recreáveis": "recrear",
    "recria": "recriar",
    "recriada": "recriar",
    "recriadas": "recriar",
    "recriado": "recriar",
    "recriados": "recriar",
    "recriai": "recriar",
    "recriais": "recriar",
    "recriam": "recriar",
    "recriamo": "recriar",
    "recriamos": "recriar",
    "recriando": "recriar",
    "recriara": "recriar",
    "recriaram": "recriar",
    "recriaras": "recriar",
    "recriarde": "recriar",
    "recriardes": "recriar",
    "recriare": "recriar",
    "recriarei": "recriar",
    "recriareis": "recriar",
    "recriarem": "recriar",
    "recriaremos": "recriar",
    "recriares": "recriar",
    "recriaria": "recriar",
    "recriariam": "recriar",
    "recriarias": "recriar",
    "recriarmo": "recriar",
    "recriarmos": "recriar",
    "recriará": "recriar",
    "recriarás": "recriar",
    "recriarão": "recriar",
    "recriaríamos": "recriar",
    "recriaríeis": "recriar",
    "recrias": "recriar",
    "recriasse": "recriar",
    "recriassem": "recriar",
    "recriasses": "recriar",
    "recriaste": "recriar",
    "recriastes": "recriar",
    "recriava": "recriar",
    "recriavam": "recriar",
    "recriavas": "recriar",
    "recriações": "recriação",
    "recrie": "recriar",
    "recriei": "recriar",
    "recrieis": "recriar",
    "recriem": "recriar",
    "recriemo": "recriar",
    "recriemos": "recriar",
    "recries": "recriar",
    "recrimina": "recriminar",
    "recriminada": "recriminar",
    "recriminadas": "recriminar",
    "recriminado": "recriminar",
    "recriminadora": "recriminador",
    "recriminadoras": "recriminador",
    "recriminadores": "recriminador",
    "recriminados": "recriminar",
    "recriminai": "recriminar",
    "recriminais": "recriminar",
    "recriminam": "recriminar",
    "recriminamo": "recriminar",
    "recriminamos": "recriminar",
    "recriminando": "recriminar",
    "recriminara": "recriminar",
    "recriminaram": "recriminar",
    "recriminaras": "recriminar",
    "recriminarde": "recriminar",
    "recriminardes": "recriminar",
    "recriminare": "recriminar",
    "recriminarei": "recriminar",
    "recriminareis": "recriminar",
    "recriminarem": "recriminar",
    "recriminaremos": "recriminar",
    "recriminares": "recriminar",
    "recriminaria": "recriminar",
    "recriminariam": "recriminar",
    "recriminarias": "recriminar",
    "recriminarmo": "recriminar",
    "recriminarmos": "recriminar",
    "recriminará": "recriminar",
    "recriminarás": "recriminar",
    "recriminarão": "recriminar",
    "recriminaríamos": "recriminar",
    "recriminaríeis": "recriminar",
    "recriminas": "recriminar",
    "recriminasse": "recriminar",
    "recriminassem": "recriminar",
    "recriminasses": "recriminar",
    "recriminaste": "recriminar",
    "recriminastes": "recriminar",
    "recriminatória": "recriminatório",
    "recriminatórias": "recriminatório",
    "recriminatórios": "recriminatório",
    "recriminava": "recriminar",
    "recriminavam": "recriminar",
    "recriminavas": "recriminar",
    "recriminações": "recriminação",
    "recrimine": "recriminar",
    "recriminei": "recriminar",
    "recrimineis": "recriminar",
    "recriminem": "recriminar",
    "recriminemo": "recriminar",
    "recriminemos": "recriminar",
    "recrimines": "recriminar",
    "recrimino": "recriminar",
    "recriminou": "recriminar",
    "recriminá": "recriminar",
    "recriminámo": "recriminar",
    "recriminámos": "recriminar",
    "recrimináramo": "recriminar",
    "recrimináramos": "recriminar",
    "recriminárei": "recriminar",
    "recrimináreis": "recriminar",
    "recriminásseis": "recriminar",
    "recriminássemos": "recriminar",
    "recriminávamo": "recriminar",
    "recriminávamos": "recriminar",
    "recriminávei": "recriminar",
    "recrimináveis": "recriminável",
    "recrio": "recriar",
    "recriou": "recriar",
    "recristalizações": "recristalização",
    "recristianiza": "recristianizar",
    "recristianizada": "recristianizar",
    "recristianizadas": "recristianizar",
    "recristianizado": "recristianizar",
    "recristianizados": "recristianizar",
    "recristianizai": "recristianizar",
    "recristianizais": "recristianizar",
    "recristianizam": "recristianizar",
    "recristianizamo": "recristianizar",
    "recristianizamos": "recristianizar",
    "recristianizando": "recristianizar",
    "recristianizara": "recristianizar",
    "recristianizaram": "recristianizar",
    "recristianizaras": "recristianizar",
    "recristianizarde": "recristianizar",
    "recristianizardes": "recristianizar",
    "recristianizare": "recristianizar",
    "recristianizarei": "recristianizar",
    "recristianizareis": "recristianizar",
    "recristianizarem": "recristianizar",
    "recristianizaremos": "recristianizar",
    "recristianizares": "recristianizar",
    "recristianizaria": "recristianizar",
    "recristianizariam": "recristianizar",
    "recristianizarias": "recristianizar",
    "recristianizarmo": "recristianizar",
    "recristianizarmos": "recristianizar",
    "recristianizará": "recristianizar",
    "recristianizarás": "recristianizar",
    "recristianizarão": "recristianizar",
    "recristianizaríamos": "recristianizar",
    "recristianizaríeis": "recristianizar",
    "recristianizas": "recristianizar",
    "recristianizasse": "recristianizar",
    "recristianizassem": "recristianizar",
    "recristianizasses": "recristianizar",
    "recristianizaste": "recristianizar",
    "recristianizastes": "recristianizar",
    "recristianizava": "recristianizar",
    "recristianizavam": "recristianizar",
    "recristianizavas": "recristianizar",
    "recristianizações": "recristianização",
    "recristianize": "recristianizar",
    "recristianizei": "recristianizar",
    "recristianizeis": "recristianizar",
    "recristianizem": "recristianizar",
    "recristianizemo": "recristianizar",
    "recristianizemos": "recristianizar",
    "recristianizes": "recristianizar",
    "recristianizo": "recristianizar",
    "recristianizou": "recristianizar",
    "recristianizá": "recristianizar",
    "recristianizámo": "recristianizar",
    "recristianizámos": "recristianizar",
    "recristianizáramo": "recristianizar",
    "recristianizáramos": "recristianizar",
    "recristianizárei": "recristianizar",
    "recristianizáreis": "recristianizar",
    "recristianizásseis": "recristianizar",
    "recristianizássemos": "recristianizar",
    "recristianizávamo": "recristianizar",
    "recristianizávamos": "recristianizar",
    "recristianizávei": "recristianizar",
    "recristianizáveis": "recristianizável",
    "recriá": "recriar",
    "recriámo": "recriar",
    "recriámos": "recriar",
    "recriáramo": "recriar",
    "recriáramos": "recriar",
    "recriárei": "recriar",
    "recriáreis": "recriar",
    "recriásseis": "recriar",
    "recriássemos": "recriar",
    "recriávamo": "recriar",
    "recriávamos": "recriar",
    "recriávei": "recriar",
    "recriáveis": "recriável",
    "recrua": "recru",
    "recruas": "recru",
    "recrudesce": "recrudescer",
    "recrudescei": "recrudescer",
    "recrudesceis": "recrudescer",
    "recrudescem": "recrudescer",
    "recrudescemo": "recrudescer",
    "recrudescemos": "recrudescer",
    "recrudescendo": "recrudescer",
    "recrudescentes": "recrudescente",
    "recrudescera": "recrudescer",
    "recrudesceram": "recrudescer",
    "recrudesceras": "recrudescer",
    "recrudescerdes": "recrudescer",
    "recrudescerei": "recrudescer",
    "recrudescereis": "recrudescer",
    "recrudescerem": "recrudescer",
    "recrudesceremos": "recrudescer",
    "recrudesceres": "recrudescer",
    "recrudesceria": "recrudescer",
    "recrudesceriam": "recrudescer",
    "recrudescerias": "recrudescer",
    "recrudescermo": "recrudescer",
    "recrudescermos": "recrudescer",
    "recrudescerá": "recrudescer",
    "recrudescerás": "recrudescer",
    "recrudescerão": "recrudescer",
    "recrudesceríamos": "recrudescer",
    "recrudesceríeis": "recrudescer",
    "recrudesces": "recrudescer",
    "recrudescesse": "recrudescer",
    "recrudescessem": "recrudescer",
    "recrudescesses": "recrudescer",
    "recrudesceste": "recrudescer",
    "recrudescestes": "recrudescer",
    "recrudesceu": "recrudescer",
    "recrudesci": "recrudescer",
    "recrudescia": "recrudescer",
    "recrudesciam": "recrudescer",
    "recrudescias": "recrudescer",
    "recrudescida": "recrudescer",
    "recrudescidas": "recrudescer",
    "recrudescido": "recrudescer",
    "recrudescidos": "recrudescer",
    "recrudescimentos": "recrudescimento",
    "recrudescências": "recrudescência",
    "recrudescêramo": "recrudescer",
    "recrudescêramos": "recrudescer",
    "recrudescêreis": "recrudescer",
    "recrudescêsseis": "recrudescer",
    "recrudescêssemos": "recrudescer",
    "recrudescíamo": "recrudescer",
    "recrudescíamos": "recrudescer",
    "recrudescíeis": "recrudescer",
    "recrudesça": "recrudescer",
    "recrudesçais": "recrudescer",
    "recrudesçam": "recrudescer",
    "recrudesçamo": "recrudescer",
    "recrudesçamos": "recrudescer",
    "recrudesças": "recrudescer",
    "recrudesço": "recrudescer",
    "recrus": "recru",
    "recruta": "recrutar",
    "recrutada": "recrutar",
    "recrutadas": "recrutar",
    "recrutado": "recrutar",
    "recrutadora": "recrutador",
    "recrutadoras": "recrutador",
    "recrutadores": "recrutador",
    "recrutados": "recrutar",
    "recrutai": "recrutar",
    "recrutais": "recrutar",
    "recrutam": "recrutar",
    "recrutamentos": "recrutamento",
    "recrutamo": "recrutar",
    "recrutamos": "recrutar",
    "recrutando": "recrutar",
    "recrutara": "recrutar",
    "recrutaram": "recrutar",
    "recrutaras": "recrutar",
    "recrutarde": "recrutar",
    "recrutardes": "recrutar",
    "recrutare": "recrutar",
    "recrutarei": "recrutar",
    "recrutareis": "recrutar",
    "recrutarem": "recrutar",
    "recrutaremos": "recrutar",
    "recrutares": "recrutar",
    "recrutaria": "recrutar",
    "recrutariam": "recrutar",
    "recrutarias": "recrutar",
    "recrutarmo": "recrutar",
    "recrutarmos": "recrutar",
    "recrutará": "recrutar",
    "recrutarás": "recrutar",
    "recrutarão": "recrutar",
    "recrutaríamos": "recrutar",
    "recrutaríeis": "recrutar",
    "recrutas": "recrutar",
    "recrutasse": "recrutar",
    "recrutassem": "recrutar",
    "recrutasses": "recrutar",
    "recrutaste": "recrutar",
    "recrutastes": "recrutar",
    "recrutava": "recrutar",
    "recrutavam": "recrutar",
    "recrutavas": "recrutar",
    "recrute": "recrutar",
    "recrutei": "recrutar",
    "recruteis": "recrutar",
    "recrutem": "recrutar",
    "recrutemo": "recrutar",
    "recrutemos": "recrutar",
    "recrutes": "recrutar",
    "recruto": "recrutar",
    "recrutou": "recrutar",
    "recrutá": "recrutar",
    "recrutámo": "recrutar",
    "recrutámos": "recrutar",
    "recrutáramo": "recrutar",
    "recrutáramos": "recrutar",
    "recrutárei": "recrutar",
    "recrutáreis": "recrutar",
    "recrutásseis": "recrutar",
    "recrutássemos": "recrutar",
    "recrutávamo": "recrutar",
    "recrutávamos": "recrutar",
    "recrutávei": "recrutar",
    "recrutáveis": "recrutável",
    "recruza": "recruzar",
    "recruzada": "recruzar",
    "recruzadas": "recruzar",
    "recruzado": "recruzar",
    "recruzados": "recruzar",
    "recruzai": "recruzar",
    "recruzais": "recruzar",
    "recruzam": "recruzar",
    "recruzamo": "recruzar",
    "recruzamos": "recruzar",
    "recruzando": "recruzar",
    "recruzara": "recruzar",
    "recruzaram": "recruzar",
    "recruzaras": "recruzar",
    "recruzarde": "recruzar",
    "recruzardes": "recruzar",
    "recruzare": "recruzar",
    "recruzarei": "recruzar",
    "recruzareis": "recruzar",
    "recruzarem": "recruzar",
    "recruzaremos": "recruzar",
    "recruzares": "recruzar",
    "recruzaria": "recruzar",
    "recruzariam": "recruzar",
    "recruzarias": "recruzar",
    "recruzarmo": "recruzar",
    "recruzarmos": "recruzar",
    "recruzará": "recruzar",
    "recruzarás": "recruzar",
    "recruzarão": "recruzar",
    "recruzaríamos": "recruzar",
    "recruzaríeis": "recruzar",
    "recruzas": "recruzar",
    "recruzasse": "recruzar",
    "recruzassem": "recruzar",
    "recruzasses": "recruzar",
    "recruzaste": "recruzar",
    "recruzastes": "recruzar",
    "recruzava": "recruzar",
    "recruzavam": "recruzar",
    "recruzavas": "recruzar",
    "recruze": "recruzar",
    "recruzei": "recruzar",
    "recruzeis": "recruzar",
    "recruzem": "recruzar",
    "recruzemo": "recruzar",
    "recruzemos": "recruzar",
    "recruzes": "recruzar",
    "recruzetada": "recruzetado",
    "recruzetadas": "recruzetado",
    "recruzetados": "recruzetado",
    "recruzo": "recruzar",
    "recruzou": "recruzar",
    "recruzá": "recruzar",
    "recruzámo": "recruzar",
    "recruzámos": "recruzar",
    "recruzáramo": "recruzar",
    "recruzáramos": "recruzar",
    "recruzárei": "recruzar",
    "recruzáreis": "recruzar",
    "recruzásseis": "recruzar",
    "recruzássemos": "recruzar",
    "recruzávamo": "recruzar",
    "recruzávamos": "recruzar",
    "recruzávei": "recruzar",
    "recruzáveis": "recruzar",
    "recréscimos": "recréscimo",
    "recta": "recto",
    "rectaguardas": "rectaguarda",
    "rectais": "rectal",
    "rectalgias": "rectalgia",
    "rectangulares": "rectangular",
    "rectangularidades": "rectangularidade",
    "rectas": "recto",
    "rectazinha": "recto",
    "rectazinhas": "recto",
    "rectazita": "recto",
    "rectazitas": "recto",
    "recticórnea": "recticórneo",
    "recticórneas": "recticórneo",
    "recticórneos": "recticórneo",
    "rectidões": "rectidão",
    "rectifica": "rectificar",
    "rectificada": "rectificar",
    "rectificadas": "rectificar",
    "rectificado": "rectificar",
    "rectificadora": "rectificador",
    "rectificadoras": "rectificadora",
    "rectificadores": "rectificador",
    "rectificados": "rectificar",
    "rectificai": "rectificar",
    "rectificais": "rectificar",
    "rectificam": "rectificar",
    "rectificamo": "rectificar",
    "rectificamos": "rectificar",
    "rectificando": "rectificar",
    "rectificara": "rectificar",
    "rectificaram": "rectificar",
    "rectificaras": "rectificar",
    "rectificarde": "rectificar",
    "rectificardes": "rectificar",
    "rectificare": "rectificar",
    "rectificarei": "rectificar",
    "rectificareis": "rectificar",
    "rectificarem": "rectificar",
    "rectificaremos": "rectificar",
    "rectificares": "rectificar",
    "rectificaria": "rectificar",
    "rectificariam": "rectificar",
    "rectificarias": "rectificar",
    "rectificarmo": "rectificar",
    "rectificarmos": "rectificar",
    "rectificará": "rectificar",
    "rectificarás": "rectificar",
    "rectificarão": "rectificar",
    "rectificaríamos": "rectificar",
    "rectificaríeis": "rectificar",
    "rectificas": "rectificar",
    "rectificasse": "rectificar",
    "rectificassem": "rectificar",
    "rectificasses": "rectificar",
    "rectificaste": "rectificar",
    "rectificastes": "rectificar",
    "rectificativa": "rectificativo",
    "rectificativas": "rectificativo",
    "rectificativos": "rectificativo",
    "rectificava": "rectificar",
    "rectificavam": "rectificar",
    "rectificavas": "rectificar",
    "rectificações": "rectificação",
    "rectifico": "rectificar",
    "rectificou": "rectificar",
    "rectificá": "rectificar",
    "rectificámo": "rectificar",
    "rectificámos": "rectificar",
    "rectificáramo": "rectificar",
    "rectificáramos": "rectificar",
    "rectificárei": "rectificar",
    "rectificáreis": "rectificar",
    "rectificásseis": "rectificar",
    "rectificássemos": "rectificar",
    "rectificávamo": "rectificar",
    "rectificávamos": "rectificar",
    "rectificávei": "rectificar",
    "rectificáveis": "rectificável",
    "rectifique": "rectificar",
    "rectifiquei": "rectificar",
    "rectifiqueis": "rectificar",
    "rectifiquem": "rectificar",
    "rectifiquemo": "rectificar",
    "rectifiquemos": "rectificar",
    "rectifiques": "rectificar",
    "rectiformes": "rectiforme",
    "rectilinearidades": "rectilinearidade",
    "rectilínea": "rectilíneo",
    "rectilíneas": "rectilíneo",
    "rectilíneos": "rectilíneo",
    "rectinha": "recto",
    "rectinhas": "recto",
    "rectinho": "recto",
    "rectinhos": "recto",
    "rectinérvea": "rectinérveo",
    "rectinérveas": "rectinérveo",
    "rectinérveos": "rectinérveo",
    "rectirrostra": "rectirrostro",
    "rectirrostras": "rectirrostro",
    "rectirrostros": "rectirrostro",
    "rectita": "recto",
    "rectitas": "recto",
    "rectites": "rectite",
    "rectito": "recto",
    "rectitos": "recto",
    "rectitudes": "rectitude",
    "rectoceles": "rectocele",
    "rectococcígea": "rectococcígeo",
    "rectococcígeas": "rectococcígeo",
    "rectococcígeos": "rectococcígeo",
    "rectocolites": "rectocolite",
    "rectos": "recto",
    "rectoscopias": "rectoscopia",
    "rectoscópios": "rectoscópio",
    "rectotomias": "rectotomia",
    "rectovaginais": "rectovaginal",
    "rectozinho": "recto",
    "rectozinhos": "recto",
    "rectozito": "recto",
    "rectozitos": "recto",
    "rectriciais": "rectricial",
    "rectrizes": "rectriz",
    "rectroactiva": "rectroactivo",
    "rectroactivas": "rectroactivo",
    "rectroactivos": "rectroactivo",
    "rectálgica": "rectálgico",
    "rectálgicas": "rectálgico",
    "rectálgicos": "rectálgico",
    "rectângulos": "rectângulo",
    "rectígrada": "rectígrado",
    "rectígradas": "rectígrado",
    "rectígrados": "rectígrado",
    "recua": "recuar",
    "recuada": "recuar",
    "recuadas": "recuar",
    "recuadeiras": "recuadeira",
    "recuado": "recuar",
    "recuados": "recuar",
    "recuai": "recuar",
    "recuais": "recuar",
    "recuam": "recuar",
    "recuamentos": "recuamento",
    "recuamo": "recuar",
    "recuamos": "recuar",
    "recuando": "recuar",
    "recuanços": "recuanço",
    "recuara": "recuar",
    "recuaram": "recuar",
    "recuaras": "recuar",
    "recuarde": "recuar",
    "recuardes": "recuar",
    "recuare": "recuar",
    "recuarei": "recuar",
    "recuareis": "recuar",
    "recuarem": "recuar",
    "recuaremos": "recuar",
    "recuares": "recuar",
    "recuaria": "recuar",
    "recuariam": "recuar",
    "recuarias": "recuar",
    "recuarmo": "recuar",
    "recuarmos": "recuar",
    "recuará": "recuar",
    "recuarás": "recuar",
    "recuarão": "recuar",
    "recuaríamos": "recuar",
    "recuaríeis": "recuar",
    "recuas": "recuar",
    "recuasse": "recuar",
    "recuassem": "recuar",
    "recuasses": "recuar",
    "recuaste": "recuar",
    "recuastes": "recuar",
    "recuava": "recuar",
    "recuavam": "recuar",
    "recuavas": "recuar",
    "recubra": "recobrir",
    "recubrais": "recobrir",
    "recubram": "recobrir",
    "recubramo": "recobrir",
    "recubramos": "recobrir",
    "recubras": "recobrir",
    "recubro": "recobrir",
    "recue": "recuar",
    "recuei": "recuar",
    "recueis": "recuar",
    "recuem": "recuar",
    "recuemo": "recuar",
    "recuemos": "recuar",
    "recues": "recuar",
    "recuida": "recuidar",
    "recuidada": "recuidar",
    "recuidadas": "recuidar",
    "recuidado": "recuidar",
    "recuidados": "recuidar",
    "recuidai": "recuidar",
    "recuidais": "recuidar",
    "recuidam": "recuidar",
    "recuidamo": "recuidar",
    "recuidamos": "recuidar",
    "recuidando": "recuidar",
    "recuidara": "recuidar",
    "recuidaram": "recuidar",
    "recuidaras": "recuidar",
    "recuidardes": "recuidar",
    "recuidarei": "recuidar",
    "recuidareis": "recuidar",
    "recuidarem": "recuidar",
    "recuidaremos": "recuidar",
    "recuidares": "recuidar",
    "recuidaria": "recuidar",
    "recuidariam": "recuidar",
    "recuidarias": "recuidar",
    "recuidarmo": "recuidar",
    "recuidarmos": "recuidar",
    "recuidará": "recuidar",
    "recuidarás": "recuidar",
    "recuidarão": "recuidar",
    "recuidaríamos": "recuidar",
    "recuidaríeis": "recuidar",
    "recuidas": "recuidar",
    "recuidasse": "recuidar",
    "recuidassem": "recuidar",
    "recuidasses": "recuidar",
    "recuidaste": "recuidar",
    "recuidastes": "recuidar",
    "recuidava": "recuidar",
    "recuidavam": "recuidar",
    "recuidavas": "recuidar",
    "recuide": "recuidar",
    "recuidei": "recuidar",
    "recuideis": "recuidar",
    "recuidem": "recuidar",
    "recuidemo": "recuidar",
    "recuidemos": "recuidar",
    "recuides": "recuidar",
    "recuido": "recuidar",
    "recuidou": "recuidar",
    "recuidámo": "recuidar",
    "recuidámos": "recuidar",
    "recuidáramo": "recuidar",
    "recuidáramos": "recuidar",
    "recuidáreis": "recuidar",
    "recuidásseis": "recuidar",
    "recuidássemos": "recuidar",
    "recuidávamo": "recuidar",
    "recuidávamos": "recuidar",
    "recuidáveis": "recuidar",
    "recultiva": "recultivar",
    "recultivada": "recultivar",
    "recultivadas": "recultivar",
    "recultivado": "recultivar",
    "recultivados": "recultivar",
    "recultivai": "recultivar",
    "recultivais": "recultivar",
    "recultivam": "recultivar",
    "recultivamo": "recultivar",
    "recultivamos": "recultivar",
    "recultivando": "recultivar",
    "recultivara": "recultivar",
    "recultivaram": "recultivar",
    "recultivaras": "recultivar",
    "recultivarde": "recultivar",
    "recultivardes": "recultivar",
    "recultivare": "recultivar",
    "recultivarei": "recultivar",
    "recultivareis": "recultivar",
    "recultivarem": "recultivar",
    "recultivaremos": "recultivar",
    "recultivares": "recultivar",
    "recultivaria": "recultivar",
    "recultivariam": "recultivar",
    "recultivarias": "recultivar",
    "recultivarmo": "recultivar",
    "recultivarmos": "recultivar",
    "recultivará": "recultivar",
    "recultivarás": "recultivar",
    "recultivarão": "recultivar",
    "recultivaríamos": "recultivar",
    "recultivaríeis": "recultivar",
    "recultivas": "recultivar",
    "recultivasse": "recultivar",
    "recultivassem": "recultivar",
    "recultivasses": "recultivar",
    "recultivaste": "recultivar",
    "recultivastes": "recultivar",
    "recultivava": "recultivar",
    "recultivavam": "recultivar",
    "recultivavas": "recultivar",
    "recultive": "recultivar",
    "recultivei": "recultivar",
    "recultiveis": "recultivar",
    "recultivem": "recultivar",
    "recultivemo": "recultivar",
    "recultivemos": "recultivar",
    "recultives": "recultivar",
    "recultivo": "recultivar",
    "recultivou": "recultivar",
    "recultivá": "recultivar",
    "recultivámo": "recultivar",
    "recultivámos": "recultivar",
    "recultiváramo": "recultivar",
    "recultiváramos": "recultivar",
    "recultivárei": "recultivar",
    "recultiváreis": "recultivar",
    "recultivásseis": "recultivar",
    "recultivássemos": "recultivar",
    "recultivávamo": "recultivar",
    "recultivávamos": "recultivar",
    "recultivávei": "recultivar",
    "recultiváveis": "recultivar",
    "recumba": "recumbir",
    "recumbais": "recumbir",
    "recumbam": "recumbir",
    "recumbamo": "recumbir",
    "recumbamos": "recumbir",
    "recumbas": "recumbir",
    "recumbe": "recumbir",
    "recumbem": "recumbir",
    "recumbentes": "recumbente",
    "recumbes": "recumbir",
    "recumbi": "recumbir",
    "recumbia": "recumbir",
    "recumbiam": "recumbir",
    "recumbias": "recumbir",
    "recumbida": "recumbir",
    "recumbidas": "recumbir",
    "recumbido": "recumbir",
    "recumbidos": "recumbir",
    "recumbimo": "recumbir",
    "recumbimos": "recumbir",
    "recumbindo": "recumbir",
    "recumbira": "recumbir",
    "recumbiram": "recumbir",
    "recumbiras": "recumbir",
    "recumbirdes": "recumbir",
    "recumbirei": "recumbir",
    "recumbireis": "recumbir",
    "recumbirem": "recumbir",
    "recumbiremos": "recumbir",
    "recumbires": "recumbir",
    "recumbiria": "recumbir",
    "recumbiriam": "recumbir",
    "recumbirias": "recumbir",
    "recumbirmo": "recumbir",
    "recumbirmos": "recumbir",
    "recumbirá": "recumbir",
    "recumbirás": "recumbir",
    "recumbirão": "recumbir",
    "recumbiríamos": "recumbir",
    "recumbiríeis": "recumbir",
    "recumbis": "recumbir",
    "recumbisse": "recumbir",
    "recumbissem": "recumbir",
    "recumbisses": "recumbir",
    "recumbiste": "recumbir",
    "recumbistes": "recumbir",
    "recumbiu": "recumbir",
    "recumbo": "recumbir",
    "recumbíamo": "recumbir",
    "recumbíamos": "recumbir",
    "recumbíeis": "recumbir",
    "recumbíramo": "recumbir",
    "recumbíramos": "recumbir",
    "recumbíreis": "recumbir",
    "recumbísseis": "recumbir",
    "recumbíssemos": "recumbir",
    "recunha": "recunhar",
    "recunhada": "recunhar",
    "recunhadas": "recunhar",
    "recunhado": "recunhar",
    "recunhados": "recunhar",
    "recunhai": "recunhar",
    "recunhais": "recunhar",
    "recunham": "recunhar",
    "recunhamo": "recunhar",
    "recunhamos": "recunhar",
    "recunhando": "recunhar",
    "recunhara": "recunhar",
    "recunharam": "recunhar",
    "recunharas": "recunhar",
    "recunharde": "recunhar",
    "recunhardes": "recunhar",
    "recunhare": "recunhar",
    "recunharei": "recunhar",
    "recunhareis": "recunhar",
    "recunharem": "recunhar",
    "recunharemos": "recunhar",
    "recunhares": "recunhar",
    "recunharia": "recunhar",
    "recunhariam": "recunhar",
    "recunharias": "recunhar",
    "recunharmo": "recunhar",
    "recunharmos": "recunhar",
    "recunhará": "recunhar",
    "recunharás": "recunhar",
    "recunharão": "recunhar",
    "recunharíamos": "recunhar",
    "recunharíeis": "recunhar",
    "recunhas": "recunhar",
    "recunhasse": "recunhar",
    "recunhassem": "recunhar",
    "recunhasses": "recunhar",
    "recunhaste": "recunhar",
    "recunhastes": "recunhar",
    "recunhava": "recunhar",
    "recunhavam": "recunhar",
    "recunhavas": "recunhar",
    "recunhe": "recunhar",
    "recunhei": "recunhar",
    "recunheis": "recunhar",
    "recunhem": "recunhar",
    "recunhemo": "recunhar",
    "recunhemos": "recunhar",
    "recunhes": "recunhar",
    "recunho": "recunhar",
    "recunhou": "recunhar",
    "recunhá": "recunhar",
    "recunhámo": "recunhar",
    "recunhámos": "recunhar",
    "recunháramo": "recunhar",
    "recunháramos": "recunhar",
    "recunhárei": "recunhar",
    "recunháreis": "recunhar",
    "recunhásseis": "recunhar",
    "recunhássemos": "recunhar",
    "recunhávamo": "recunhar",
    "recunhávamos": "recunhar",
    "recunhávei": "recunhar",
    "recunháveis": "recunhar",
    "recuo": "recuar",
    "recuos": "recuo",
    "recuou": "recuar",
    "recupera": "recuperar",
    "recuperada": "recuperar",
    "recuperadas": "recuperar",
    "recuperado": "recuperar",
    "recuperadora": "recuperador",
    "recuperadoras": "recuperador",
    "recuperadores": "recuperador",
    "recuperados": "recuperar",
    "recuperai": "recuperar",
    "recuperais": "recuperar",
    "recuperam": "recuperar",
    "recuperamo": "recuperar",
    "recuperamos": "recuperar",
    "recuperando": "recuperar",
    "recuperara": "recuperar",
    "recuperaram": "recuperar",
    "recuperaras": "recuperar",
    "recuperarde": "recuperar",
    "recuperardes": "recuperar",
    "recuperare": "recuperar",
    "recuperarei": "recuperar",
    "recuperareis": "recuperar",
    "recuperarem": "recuperar",
    "recuperaremos": "recuperar",
    "recuperares": "recuperar",
    "recuperaria": "recuperar",
    "recuperariam": "recuperar",
    "recuperarias": "recuperar",
    "recuperarmo": "recuperar",
    "recuperarmos": "recuperar",
    "recuperará": "recuperar",
    "recuperarás": "recuperar",
    "recuperarão": "recuperar",
    "recuperaríamos": "recuperar",
    "recuperaríeis": "recuperar",
    "recuperas": "recuperar",
    "recuperasse": "recuperar",
    "recuperassem": "recuperar",
    "recuperasses": "recuperar",
    "recuperaste": "recuperar",
    "recuperastes": "recuperar",
    "recuperativa": "recuperativo",
    "recuperativas": "recuperativo",
    "recuperativos": "recuperativo",
    "recuperava": "recuperar",
    "recuperavam": "recuperar",
    "recuperavas": "recuperar",
    "recuperações": "recuperação",
    "recupere": "recuperar",
    "recuperei": "recuperar",
    "recupereis": "recuperar",
    "recuperem": "recuperar",
    "recuperemo": "recuperar",
    "recuperemos": "recuperar",
    "recuperes": "recuperar",
    "recupero": "recuperar",
    "recuperou": "recuperar",
    "recuperá": "recuperar",
    "recuperámo": "recuperar",
    "recuperámos": "recuperar",
    "recuperáramo": "recuperar",
    "recuperáramos": "recuperar",
    "recuperárei": "recuperar",
    "recuperáreis": "recuperar",
    "recuperásseis": "recuperar",
    "recuperássemos": "recuperar",
    "recuperávamo": "recuperar",
    "recuperávamos": "recuperar",
    "recuperávei": "recuperar",
    "recuperáveis": "recuperável",
    "recursos": "recurso",
    "recurva": "recurvo",
    "recurvada": "recurvar",
    "recurvadas": "recurvar",
    "recurvado": "recurvar",
    "recurvados": "recurvar",
    "recurvai": "recurvar",
    "recurvais": "recurvar",
    "recurvam": "recurvar",
    "recurvamo": "recurvar",
    "recurvamos": "recurvar",
    "recurvando": "recurvar",
    "recurvara": "recurvar",
    "recurvaram": "recurvar",
    "recurvaras": "recurvar",
    "recurvarde": "recurvar",
    "recurvardes": "recurvar",
    "recurvare": "recurvar",
    "recurvarei": "recurvar",
    "recurvareis": "recurvar",
    "recurvarem": "recurvar",
    "recurvaremos": "recurvar",
    "recurvares": "recurvar",
    "recurvaria": "recurvar",
    "recurvariam": "recurvar",
    "recurvarias": "recurvar",
    "recurvarmo": "recurvar",
    "recurvarmos": "recurvar",
    "recurvará": "recurvar",
    "recurvarás": "recurvar",
    "recurvarão": "recurvar",
    "recurvaríamos": "recurvar",
    "recurvaríeis": "recurvar",
    "recurvas": "recurvo",
    "recurvasse": "recurvar",
    "recurvassem": "recurvar",
    "recurvasses": "recurvar",
    "recurvaste": "recurvar",
    "recurvastes": "recurvar",
    "recurvava": "recurvar",
    "recurvavam": "recurvar",
    "recurvavas": "recurvar",
    "recurve": "recurvar",
    "recurvei": "recurvar",
    "recurveis": "recurvar",
    "recurvem": "recurvar",
    "recurvemo": "recurvar",
    "recurvemos": "recurvar",
    "recurves": "recurvar",
    "recurvo": "recurvar",
    "recurvos": "recurvo",
    "recurvou": "recurvar",
    "recurvá": "recurvar",
    "recurvámo": "recurvar",
    "recurvámos": "recurvar",
    "recurváramo": "recurvar",
    "recurváramos": "recurvar",
    "recurvárei": "recurvar",
    "recurváreis": "recurvar",
    "recurvásseis": "recurvar",
    "recurvássemos": "recurvar",
    "recurvávamo": "recurvar",
    "recurvávamos": "recurvar",
    "recurvávei": "recurvar",
    "recurváveis": "recurvar",
    "recusa": "recusar",
    "recusada": "recusar",
    "recusadas": "recusar",
    "recusado": "recusar",
    "recusadora": "recusador",
    "recusadoras": "recusador",
    "recusadores": "recusador",
    "recusados": "recusar",
    "recusai": "recusar",
    "recusais": "recusar",
    "recusam": "recusar",
    "recusamo": "recusar",
    "recusamos": "recusar",
    "recusando": "recusar",
    "recusantes": "recusante",
    "recusara": "recusar",
    "recusaram": "recusar",
    "recusaras": "recusar",
    "recusarde": "recusar",
    "recusardes": "recusar",
    "recusare": "recusar",
    "recusarei": "recusar",
    "recusareis": "recusar",
    "recusarem": "recusar",
    "recusaremos": "recusar",
    "recusares": "recusar",
    "recusaria": "recusar",
    "recusariam": "recusar",
    "recusarias": "recusar",
    "recusarmo": "recusar",
    "recusarmos": "recusar",
    "recusará": "recusar",
    "recusarás": "recusar",
    "recusarão": "recusar",
    "recusaríamos": "recusar",
    "recusaríeis": "recusar",
    "recusas": "recusar",
    "recusasse": "recusar",
    "recusassem": "recusar",
    "recusasses": "recusar",
    "recusaste": "recusar",
    "recusastes": "recusar",
    "recusativa": "recusativo",
    "recusativas": "recusativo",
    "recusativos": "recusativo",
    "recusava": "recusar",
    "recusavam": "recusar",
    "recusavas": "recusar",
    "recusações": "recusação",
    "recuse": "recusar",
    "recusei": "recusar",
    "recuseis": "recusar",
    "recusem": "recusar",
    "recusemo": "recusar",
    "recusemos": "recusar",
    "recuses": "recusar",
    "recuso": "recusar",
    "recusou": "recusar",
    "recusá": "recusar",
    "recusámo": "recusar",
    "recusámos": "recusar",
    "recusáramo": "recusar",
    "recusáramos": "recusar",
    "recusárei": "recusar",
    "recusáreis": "recusar",
    "recusásseis": "recusar",
    "recusássemos": "recusar",
    "recusávamo": "recusar",
    "recusávamos": "recusar",
    "recusávei": "recusar",
    "recusáveis": "recusável",
    "recuá": "recuar",
    "recuámo": "recuar",
    "recuámos": "recuar",
    "recuáramo": "recuar",
    "recuáramos": "recuar",
    "recuárei": "recuar",
    "recuáreis": "recuar",
    "recuásseis": "recuar",
    "recuássemos": "recuar",
    "recuávamo": "recuar",
    "recuávamos": "recuar",
    "recuávei": "recuar",
    "recuáveis": "recuar",
    "recâmaras": "recâmara",
    "recâmbios": "recâmbio",
    "recíolos": "recíolo",
    "recíproca": "recíproco",
    "recíprocas": "recíproco",
    "recíprocos": "recíproco",
    "recôncavos": "recôncavo",
    "recôndita": "recôndito",
    "recônditas": "recôndito",
    "recônditos": "recôndito",
    "recúbitos": "recúbito",
    "reda": "redar",
    "redactora": "redactor",
    "redactoras": "redactor",
    "redactores": "redactor",
    "redactoriais": "redactorial",
    "redacções": "redacção",
    "redada": "redar",
    "redadas": "redar",
    "redado": "redar",
    "redados": "redar",
    "redai": "redar",
    "redais": "redar",
    "redam": "redar",
    "redamo": "redar",
    "redamos": "redar",
    "redando": "redar",
    "redanhos": "redanho",
    "redara": "redar",
    "redaram": "redar",
    "redaras": "redar",
    "redarde": "redar",
    "redardes": "redar",
    "redare": "redar",
    "redarei": "redar",
    "redareis": "redar",
    "redarem": "redar",
    "redaremos": "redar",
    "redares": "redar",
    "redargua": "redarguir",
    "redarguais": "redarguir",
    "redarguam": "redarguir",
    "redarguamo": "redarguir",
    "redarguamos": "redarguir",
    "redarguas": "redarguir",
    "redarguentes": "redarguente",
    "redargui": "redarguir",
    "redarguia": "redarguir",
    "redarguiam": "redarguir",
    "redarguias": "redarguir",
    "redarguida": "redarguir",
    "redarguidas": "redarguir",
    "redarguido": "redarguir",
    "redarguidora": "redarguidor",
    "redarguidoras": "redarguidor",
    "redarguidores": "redarguidor",
    "redarguidos": "redarguir",
    "redarguimo": "redarguir",
    "redarguimos": "redarguir",
    "redarguindo": "redarguir",
    "redarguira": "redarguir",
    "redarguiram": "redarguir",
    "redarguiras": "redarguir",
    "redarguirde": "redarguir",
    "redarguirdes": "redarguir",
    "redarguire": "redarguir",
    "redarguirei": "redarguir",
    "redarguireis": "redarguir",
    "redarguirem": "redarguir",
    "redarguiremos": "redarguir",
    "redarguires": "redarguir",
    "redarguiria": "redarguir",
    "redarguiriam": "redarguir",
    "redarguirias": "redarguir",
    "redarguirmo": "redarguir",
    "redarguirmos": "redarguir",
    "redarguirá": "redarguir",
    "redarguirás": "redarguir",
    "redarguirão": "redarguir",
    "redarguiríamos": "redarguir",
    "redarguiríeis": "redarguir",
    "redarguis": "redarguir",
    "redarguisse": "redarguir",
    "redarguissem": "redarguir",
    "redarguisses": "redarguir",
    "redarguiste": "redarguir",
    "redarguistes": "redarguir",
    "redarguitiva": "redarguitivo",
    "redarguitivas": "redarguitivo",
    "redarguitivos": "redarguitivo",
    "redarguiu": "redarguir",
    "redarguições": "redarguição",
    "redarguo": "redarguir",
    "redarguíamo": "redarguir",
    "redarguíamos": "redarguir",
    "redarguíei": "redarguir",
    "redarguíeis": "redarguir",
    "redarguíramo": "redarguir",
    "redarguíramos": "redarguir",
    "redarguírei": "redarguir",
    "redarguíreis": "redarguir",
    "redarguísseis": "redarguir",
    "redarguíssemos": "redarguir",
    "redargúem": "redarguir",
    "redargúi": "redarguir",
    "redargúis": "redarguir",
    "redaria": "redar",
    "redariam": "redar",
    "redarias": "redar",
    "redarmo": "redar",
    "redarmos": "redar",
    "redará": "redar",
    "redarás": "redar",
    "redarão": "redar",
    "redaríamos": "redar",
    "redaríeis": "redar",
    "redas": "redar",
    "redasse": "redar",
    "redassem": "redar",
    "redasses": "redar",
    "redaste": "redar",
    "redastes": "redar",
    "redava": "redar",
    "redavam": "redar",
    "redavas": "redar",
    "rede": "redar",
    "redefina": "redefinir",
    "redefinais": "redefinir",
    "redefinam": "redefinir",
    "redefinamo": "redefinir",
    "redefinamos": "redefinir",
    "redefinas": "redefinir",
    "redefine": "redefinir",
    "redefinem": "redefinir",
    "redefines": "redefinir",
    "redefini": "redefinir",
    "redefinia": "redefinir",
    "redefiniam": "redefinir",
    "redefinias": "redefinir",
    "redefinida": "redefinir",
    "redefinidas": "redefinir",
    "redefinido": "redefinir",
    "redefinidos": "redefinir",
    "redefinimo": "redefinir",
    "redefinimos": "redefinir",
    "redefinindo": "redefinir",
    "redefinira": "redefinir",
    "redefiniram": "redefinir",
    "redefiniras": "redefinir",
    "redefinirde": "redefinir",
    "redefinirdes": "redefinir",
    "redefinire": "redefinir",
    "redefinirei": "redefinir",
    "redefinireis": "redefinir",
    "redefinirem": "redefinir",
    "redefiniremos": "redefinir",
    "redefinires": "redefinir",
    "redefiniria": "redefinir",
    "redefiniriam": "redefinir",
    "redefinirias": "redefinir",
    "redefinirmo": "redefinir",
    "redefinirmos": "redefinir",
    "redefinirá": "redefinir",
    "redefinirás": "redefinir",
    "redefinirão": "redefinir",
    "redefiniríamos": "redefinir",
    "redefiniríeis": "redefinir",
    "redefinis": "redefinir",
    "redefinisse": "redefinir",
    "redefinissem": "redefinir",
    "redefinisses": "redefinir",
    "redefiniste": "redefinir",
    "redefinistes": "redefinir",
    "redefiniu": "redefinir",
    "redefinições": "redefinição",
    "redefino": "redefinir",
    "redefiníamo": "redefinir",
    "redefiníamos": "redefinir",
    "redefiníei": "redefinir",
    "redefiníeis": "redefinir",
    "redefiníramo": "redefinir",
    "redefiníramos": "redefinir",
    "redefinírei": "redefinir",
    "redefiníreis": "redefinir",
    "redefinísseis": "redefinir",
    "redefiníssemos": "redefinir",
    "redei": "redar",
    "redeira": "redeiro",
    "redeiras": "redeiro",
    "redeiros": "redeiro",
    "redeis": "redar",
    "redem": "redar",
    "redemo": "redar",
    "redemocratizações": "redemocratização",
    "redemoinha": "redemoinhar",
    "redemoinhada": "redemoinhar",
    "redemoinhadas": "redemoinhar",
    "redemoinhado": "redemoinhar",
    "redemoinhados": "redemoinhar",
    "redemoinhai": "redemoinhar",
    "redemoinhais": "redemoinhar",
    "redemoinham": "redemoinhar",
    "redemoinhamo": "redemoinhar",
    "redemoinhamos": "redemoinhar",
    "redemoinhando": "redemoinhar",
    "redemoinhara": "redemoinhar",
    "redemoinharam": "redemoinhar",
    "redemoinharas": "redemoinhar",
    "redemoinhardes": "redemoinhar",
    "redemoinharei": "redemoinhar",
    "redemoinhareis": "redemoinhar",
    "redemoinharem": "redemoinhar",
    "redemoinharemos": "redemoinhar",
    "redemoinhares": "redemoinhar",
    "redemoinharia": "redemoinhar",
    "redemoinhariam": "redemoinhar",
    "redemoinharias": "redemoinhar",
    "redemoinharmo": "redemoinhar",
    "redemoinharmos": "redemoinhar",
    "redemoinhará": "redemoinhar",
    "redemoinharás": "redemoinhar",
    "redemoinharão": "redemoinhar",
    "redemoinharíamos": "redemoinhar",
    "redemoinharíeis": "redemoinhar",
    "redemoinhas": "redemoinhar",
    "redemoinhasse": "redemoinhar",
    "redemoinhassem": "redemoinhar",
    "redemoinhasses": "redemoinhar",
    "redemoinhaste": "redemoinhar",
    "redemoinhastes": "redemoinhar",
    "redemoinhava": "redemoinhar",
    "redemoinhavam": "redemoinhar",
    "redemoinhavas": "redemoinhar",
    "redemoinhe": "redemoinhar",
    "redemoinhei": "redemoinhar",
    "redemoinheis": "redemoinhar",
    "redemoinhem": "redemoinhar",
    "redemoinhemo": "redemoinhar",
    "redemoinhemos": "redemoinhar",
    "redemoinhes": "redemoinhar",
    "redemoinho": "redemoinhar",
    "redemoinhos": "redemoinho",
    "redemoinhou": "redemoinhar",
    "redemoinhámo": "redemoinhar",
    "redemoinhámos": "redemoinhar",
    "redemoinháramo": "redemoinhar",
    "redemoinháramos": "redemoinhar",
    "redemoinháreis": "redemoinhar",
    "redemoinhásseis": "redemoinhar",
    "redemoinhássemos": "redemoinhar",
    "redemoinhávamo": "redemoinhar",
    "redemoinhávamos": "redemoinhar",
    "redemoinháveis": "redemoinhar",
    "redemos": "redar",
    "redenhos": "redenho",
    "redentora": "redentor",
    "redentoras": "redentor",
    "redentores": "redentor",
    "redentoristas": "redentorista",
    "redenções": "redenção",
    "redes": "rede",
    "redesce": "redescer",
    "redescei": "redescer",
    "redesceis": "redescer",
    "redescem": "redescer",
    "redescemo": "redescer",
    "redescemos": "redescer",
    "redescenda": "redescender",
    "redescendais": "redescender",
    "redescendam": "redescender",
    "redescendamo": "redescender",
    "redescendamos": "redescender",
    "redescendas": "redescender",
    "redescende": "redescender",
    "redescendei": "redescender",
    "redescendeis": "redescender",
    "redescendem": "redescender",
    "redescendemo": "redescender",
    "redescendemos": "redescender",
    "redescendendo": "redescender",
    "redescendera": "redescender",
    "redescenderam": "redescender",
    "redescenderas": "redescender",
    "redescenderdes": "redescender",
    "redescenderei": "redescender",
    "redescendereis": "redescender",
    "redescenderem": "redescender",
    "redescenderemos": "redescender",
    "redescenderes": "redescender",
    "redescenderia": "redescender",
    "redescenderiam": "redescender",
    "redescenderias": "redescender",
    "redescendermo": "redescender",
    "redescendermos": "redescender",
    "redescenderá": "redescender",
    "redescenderás": "redescender",
    "redescenderão": "redescender",
    "redescenderíamos": "redescender",
    "redescenderíeis": "redescender",
    "redescendes": "redescender",
    "redescendesse": "redescender",
    "redescendessem": "redescender",
    "redescendesses": "redescender",
    "redescendeste": "redescender",
    "redescendestes": "redescender",
    "redescendeu": "redescender",
    "redescendi": "redescender",
    "redescendia": "redescender",
    "redescendiam": "redescender",
    "redescendias": "redescender",
    "redescendida": "redescender",
    "redescendidas": "redescender",
    "redescendido": "redescender",
    "redescendidos": "redescender",
    "redescendo": "redescer",
    "redescendêramo": "redescender",
    "redescendêramos": "redescender",
    "redescendêreis": "redescender",
    "redescendêsseis": "redescender",
    "redescendêssemos": "redescender",
    "redescendíamo": "redescender",
    "redescendíamos": "redescender",
    "redescendíeis": "redescender",
    "redescera": "redescer",
    "redesceram": "redescer",
    "redesceras": "redescer",
    "redescerdes": "redescer",
    "redescerei": "redescer",
    "redescereis": "redescer",
    "redescerem": "redescer",
    "redesceremos": "redescer",
    "redesceres": "redescer",
    "redesceria": "redescer",
    "redesceriam": "redescer",
    "redescerias": "redescer",
    "redescermo": "redescer",
    "redescermos": "redescer",
    "redescerá": "redescer",
    "redescerás": "redescer",
    "redescerão": "redescer",
    "redesceríamos": "redescer",
    "redesceríeis": "redescer",
    "redesces": "redescer",
    "redescesse": "redescer",
    "redescessem": "redescer",
    "redescesses": "redescer",
    "redesceste": "redescer",
    "redescestes": "redescer",
    "redesceu": "redescer",
    "redesci": "redescer",
    "redescia": "redescer",
    "redesciam": "redescer",
    "redescias": "redescer",
    "redescida": "redescer",
    "redescidas": "redescer",
    "redescido": "redescer",
    "redescidos": "redescer",
    "redescoberta": "redescoberto",
    "redescobertas": "redescoberto",
    "redescobertos": "redescoberto",
    "redescobra": "redescobrir",
    "redescobrais": "redescobrir",
    "redescobram": "redescobrir",
    "redescobramo": "redescobrir",
    "redescobramos": "redescobrir",
    "redescobras": "redescobrir",
    "redescobre": "redescobrir",
    "redescobrem": "redescobrir",
    "redescobres": "redescobrir",
    "redescobri": "redescobrir",
    "redescobria": "redescobrir",
    "redescobriam": "redescobrir",
    "redescobrias": "redescobrir",
    "redescobrida": "redescobrir",
    "redescobridas": "redescobrir",
    "redescobrido": "redescobrir",
    "redescobridora": "redescobridor",
    "redescobridoras": "redescobridor",
    "redescobridores": "redescobridor",
    "redescobridos": "redescobrir",
    "redescobrimentos": "redescobrimento",
    "redescobrimo": "redescobrir",
    "redescobrimos": "redescobrir",
    "redescobrindo": "redescobrir",
    "redescobrira": "redescobrir",
    "redescobriram": "redescobrir",
    "redescobriras": "redescobrir",
    "redescobrirde": "redescobrir",
    "redescobrirdes": "redescobrir",
    "redescobrire": "redescobrir",
    "redescobrirei": "redescobrir",
    "redescobrireis": "redescobrir",
    "redescobrirem": "redescobrir",
    "redescobriremos": "redescobrir",
    "redescobrires": "redescobrir",
    "redescobriria": "redescobrir",
    "redescobririam": "redescobrir",
    "redescobririas": "redescobrir",
    "redescobrirmo": "redescobrir",
    "redescobrirmos": "redescobrir",
    "redescobrirá": "redescobrir",
    "redescobrirás": "redescobrir",
    "redescobrirão": "redescobrir",
    "redescobriríamos": "redescobrir",
    "redescobriríeis": "redescobrir",
    "redescobris": "redescobrir",
    "redescobrisse": "redescobrir",
    "redescobrissem": "redescobrir",
    "redescobrisses": "redescobrir",
    "redescobriste": "redescobrir",
    "redescobristes": "redescobrir",
    "redescobriu": "redescobrir",
    "redescobro": "redescobrir",
    "redescobríamo": "redescobrir",
    "redescobríamos": "redescobrir",
    "redescobríei": "redescobrir",
    "redescobríeis": "redescobrir",
    "redescobríramo": "redescobrir",
    "redescobríramos": "redescobrir",
    "redescobrírei": "redescobrir",
    "redescobríreis": "redescobrir",
    "redescobrísseis": "redescobrir",
    "redescobríssemos": "redescobrir",
    "redesconta": "redescontar",
    "redescontada": "redescontar",
    "redescontadas": "redescontar",
    "redescontado": "redescontar",
    "redescontados": "redescontar",
    "redescontai": "redescontar",
    "redescontais": "redescontar",
    "redescontam": "redescontar",
    "redescontamo": "redescontar",
    "redescontamos": "redescontar",
    "redescontando": "redescontar",
    "redescontara": "redescontar",
    "redescontaram": "redescontar",
    "redescontaras": "redescontar",
    "redescontarde": "redescontar",
    "redescontardes": "redescontar",
    "redescontare": "redescontar",
    "redescontarei": "redescontar",
    "redescontareis": "redescontar",
    "redescontarem": "redescontar",
    "redescontaremos": "redescontar",
    "redescontares": "redescontar",
    "redescontaria": "redescontar",
    "redescontariam": "redescontar",
    "redescontarias": "redescontar",
    "redescontarmo": "redescontar",
    "redescontarmos": "redescontar",
    "redescontará": "redescontar",
    "redescontarás": "redescontar",
    "redescontarão": "redescontar",
    "redescontaríamos": "redescontar",
    "redescontaríeis": "redescontar",
    "redescontas": "redescontar",
    "redescontasse": "redescontar",
    "redescontassem": "redescontar",
    "redescontasses": "redescontar",
    "redescontaste": "redescontar",
    "redescontastes": "redescontar",
    "redescontava": "redescontar",
    "redescontavam": "redescontar",
    "redescontavas": "redescontar",
    "redesconte": "redescontar",
    "redescontei": "redescontar",
    "redesconteis": "redescontar",
    "redescontem": "redescontar",
    "redescontemo": "redescontar",
    "redescontemos": "redescontar",
    "redescontes": "redescontar",
    "redesconto": "redescontar",
    "redescontos": "redesconto",
    "redescontou": "redescontar",
    "redescontá": "redescontar",
    "redescontámo": "redescontar",
    "redescontámos": "redescontar",
    "redescontáramo": "redescontar",
    "redescontáramos": "redescontar",
    "redescontárei": "redescontar",
    "redescontáreis": "redescontar",
    "redescontásseis": "redescontar",
    "redescontássemos": "redescontar",
    "redescontávamo": "redescontar",
    "redescontávamos": "redescontar",
    "redescontávei": "redescontar",
    "redescontáveis": "redescontar",
    "redescêramo": "redescer",
    "redescêramos": "redescer",
    "redescêreis": "redescer",
    "redescêsseis": "redescer",
    "redescêssemos": "redescer",
    "redescíamo": "redescer",
    "redescíamos": "redescer",
    "redescíeis": "redescer",
    "redesenha": "redesenhar",
    "redesenhada": "redesenhar",
    "redesenhadas": "redesenhar",
    "redesenhado": "redesenhar",
    "redesenhados": "redesenhar",
    "redesenhai": "redesenhar",
    "redesenhais": "redesenhar",
    "redesenham": "redesenhar",
    "redesenhamo": "redesenhar",
    "redesenhamos": "redesenhar",
    "redesenhando": "redesenhar",
    "redesenhara": "redesenhar",
    "redesenharam": "redesenhar",
    "redesenharas": "redesenhar",
    "redesenharde": "redesenhar",
    "redesenhardes": "redesenhar",
    "redesenhare": "redesenhar",
    "redesenharei": "redesenhar",
    "redesenhareis": "redesenhar",
    "redesenharem": "redesenhar",
    "redesenharemos": "redesenhar",
    "redesenhares": "redesenhar",
    "redesenharia": "redesenhar",
    "redesenhariam": "redesenhar",
    "redesenharias": "redesenhar",
    "redesenharmo": "redesenhar",
    "redesenharmos": "redesenhar",
    "redesenhará": "redesenhar",
    "redesenharás": "redesenhar",
    "redesenharão": "redesenhar",
    "redesenharíamos": "redesenhar",
    "redesenharíeis": "redesenhar",
    "redesenhas": "redesenhar",
    "redesenhasse": "redesenhar",
    "redesenhassem": "redesenhar",
    "redesenhasses": "redesenhar",
    "redesenhaste": "redesenhar",
    "redesenhastes": "redesenhar",
    "redesenhava": "redesenhar",
    "redesenhavam": "redesenhar",
    "redesenhavas": "redesenhar",
    "redesenhe": "redesenhar",
    "redesenhei": "redesenhar",
    "redesenheis": "redesenhar",
    "redesenhem": "redesenhar",
    "redesenhemo": "redesenhar",
    "redesenhemos": "redesenhar",
    "redesenhes": "redesenhar",
    "redesenho": "redesenhar",
    "redesenhou": "redesenhar",
    "redesenhá": "redesenhar",
    "redesenhámo": "redesenhar",
    "redesenhámos": "redesenhar",
    "redesenháramo": "redesenhar",
    "redesenháramos": "redesenhar",
    "redesenhárei": "redesenhar",
    "redesenháreis": "redesenhar",
    "redesenhásseis": "redesenhar",
    "redesenhássemos": "redesenhar",
    "redesenhávamo": "redesenhar",
    "redesenhávamos": "redesenhar",
    "redesenhávei": "redesenhar",
    "redesenháveis": "redesenhar",
    "redesperta": "redespertar",
    "redespertada": "redespertar",
    "redespertadas": "redespertar",
    "redespertado": "redespertar",
    "redespertados": "redespertar",
    "redespertai": "redespertar",
    "redespertais": "redespertar",
    "redespertam": "redespertar",
    "redespertamo": "redespertar",
    "redespertamos": "redespertar",
    "redespertando": "redespertar",
    "redespertara": "redespertar",
    "redespertaram": "redespertar",
    "redespertaras": "redespertar",
    "redespertarde": "redespertar",
    "redespertardes": "redespertar",
    "redespertare": "redespertar",
    "redespertarei": "redespertar",
    "redespertareis": "redespertar",
    "redespertarem": "redespertar",
    "redespertaremos": "redespertar",
    "redespertares": "redespertar",
    "redespertaria": "redespertar",
    "redespertariam": "redespertar",
    "redespertarias": "redespertar",
    "redespertarmo": "redespertar",
    "redespertarmos": "redespertar",
    "redespertará": "redespertar",
    "redespertarás": "redespertar",
    "redespertarão": "redespertar",
    "redespertaríamos": "redespertar",
    "redespertaríeis": "redespertar",
    "redespertas": "redespertar",
    "redespertasse": "redespertar",
    "redespertassem": "redespertar",
    "redespertasses": "redespertar",
    "redespertaste": "redespertar",
    "redespertastes": "redespertar",
    "redespertava": "redespertar",
    "redespertavam": "redespertar",
    "redespertavas": "redespertar",
    "redesperte": "redespertar",
    "redespertei": "redespertar",
    "redesperteis": "redespertar",
    "redespertem": "redespertar",
    "redespertemo": "redespertar",
    "redespertemos": "redespertar",
    "redespertes": "redespertar",
    "redesperto": "redespertar",
    "redespertou": "redespertar",
    "redespertá": "redespertar",
    "redespertámo": "redespertar",
    "redespertámos": "redespertar",
    "redespertáramo": "redespertar",
    "redespertáramos": "redespertar",
    "redespertárei": "redespertar",
    "redespertáreis": "redespertar",
    "redespertásseis": "redespertar",
    "redespertássemos": "redespertar",
    "redespertávamo": "redespertar",
    "redespertávamos": "redespertar",
    "redespertávei": "redespertar",
    "redespertáveis": "redespertar",
    "redestila": "redestilar",
    "redestilada": "redestilar",
    "redestiladas": "redestilar",
    "redestilado": "redestilar",
    "redestilados": "redestilar",
    "redestilai": "redestilar",
    "redestilais": "redestilar",
    "redestilam": "redestilar",
    "redestilamo": "redestilar",
    "redestilamos": "redestilar",
    "redestilando": "redestilar",
    "redestilara": "redestilar",
    "redestilaram": "redestilar",
    "redestilaras": "redestilar",
    "redestilarde": "redestilar",
    "redestilardes": "redestilar",
    "redestilare": "redestilar",
    "redestilarei": "redestilar",
    "redestilareis": "redestilar",
    "redestilarem": "redestilar",
    "redestilaremos": "redestilar",
    "redestilares": "redestilar",
    "redestilaria": "redestilar",
    "redestilariam": "redestilar",
    "redestilarias": "redestilar",
    "redestilarmo": "redestilar",
    "redestilarmos": "redestilar",
    "redestilará": "redestilar",
    "redestilarás": "redestilar",
    "redestilarão": "redestilar",
    "redestilaríamos": "redestilar",
    "redestilaríeis": "redestilar",
    "redestilas": "redestilar",
    "redestilasse": "redestilar",
    "redestilassem": "redestilar",
    "redestilasses": "redestilar",
    "redestilaste": "redestilar",
    "redestilastes": "redestilar",
    "redestilava": "redestilar",
    "redestilavam": "redestilar",
    "redestilavas": "redestilar",
    "redestilações": "redestilação",
    "redestile": "redestilar",
    "redestilei": "redestilar",
    "redestileis": "redestilar",
    "redestilem": "redestilar",
    "redestilemo": "redestilar",
    "redestilemos": "redestilar",
    "redestiles": "redestilar",
    "redestilo": "redestilar",
    "redestilou": "redestilar",
    "redestilá": "redestilar",
    "redestilámo": "redestilar",
    "redestilámos": "redestilar",
    "redestiláramo": "redestilar",
    "redestiláramos": "redestilar",
    "redestilárei": "redestilar",
    "redestiláreis": "redestilar",
    "redestilásseis": "redestilar",
    "redestilássemos": "redestilar",
    "redestilávamo": "redestilar",
    "redestilávamos": "redestilar",
    "redestilávei": "redestilar",
    "redestiláveis": "redestilar",
    "redesça": "redescer",
    "redesçais": "redescer",
    "redesçam": "redescer",
    "redesçamo": "redescer",
    "redesçamos": "redescer",
    "redesças": "redescer",
    "redesço": "redescer",
    "rediba": "redibir",
    "redibais": "redibir",
    "redibam": "redibir",
    "redibamo": "redibir",
    "redibamos": "redibir",
    "redibas": "redibir",
    "redibe": "redibir",
    "redibem": "redibir",
    "redibes": "redibir",
    "redibi": "redibir",
    "redibia": "redibir",
    "redibiam": "redibir",
    "redibias": "redibir",
    "redibida": "redibir",
    "redibidas": "redibir",
    "redibido": "redibir",
    "redibidos": "redibir",
    "redibimo": "redibir",
    "redibimos": "redibir",
    "redibindo": "redibir",
    "redibira": "redibir",
    "redibiram": "redibir",
    "redibiras": "redibir",
    "redibirde": "redibir",
    "redibirdes": "redibir",
    "redibire": "redibir",
    "redibirei": "redibir",
    "redibireis": "redibir",
    "redibirem": "redibir",
    "redibiremos": "redibir",
    "redibires": "redibir",
    "redibiria": "redibir",
    "redibiriam": "redibir",
    "redibirias": "redibir",
    "redibirmo": "redibir",
    "redibirmos": "redibir",
    "redibirá": "redibir",
    "redibirás": "redibir",
    "redibirão": "redibir",
    "redibiríamos": "redibir",
    "redibiríeis": "redibir",
    "redibis": "redibir",
    "redibisse": "redibir",
    "redibissem": "redibir",
    "redibisses": "redibir",
    "redibiste": "redibir",
    "redibistes": "redibir",
    "redibitória": "redibitório",
    "redibitórias": "redibitório",
    "redibitórios": "redibitório",
    "redibiu": "redibir",
    "redibições": "redibição",
    "redibo": "redibir",
    "redibíamo": "redibir",
    "redibíamos": "redibir",
    "redibíei": "redibir",
    "redibíeis": "redibir",
    "redibíramo": "redibir",
    "redibíramos": "redibir",
    "redibírei": "redibir",
    "redibíreis": "redibir",
    "redibísseis": "redibir",
    "redibíssemos": "redibir",
    "rediga": "redizer",
    "redigais": "redizer",
    "redigam": "redizer",
    "redigamo": "redizer",
    "redigamos": "redizer",
    "redigas": "redizer",
    "redige": "redigir",
    "redigem": "redigir",
    "rediges": "redigir",
    "redigi": "redigir",
    "redigia": "redigir",
    "redigiam": "redigir",
    "redigias": "redigir",
    "redigida": "redigir",
    "redigidas": "redigir",
    "redigido": "redigir",
    "redigidos": "redigir",
    "redigimo": "redigir",
    "redigimos": "redigir",
    "redigindo": "redigir",
    "redigira": "redigir",
    "redigiram": "redigir",
    "redigiras": "redigir",
    "redigirde": "redigir",
    "redigirdes": "redigir",
    "redigire": "redigir",
    "redigirei": "redigir",
    "redigireis": "redigir",
    "redigirem": "redigir",
    "redigiremos": "redigir",
    "redigires": "redigir",
    "redigiria": "redigir",
    "redigiriam": "redigir",
    "redigirias": "redigir",
    "redigirmo": "redigir",
    "redigirmos": "redigir",
    "redigirá": "redigir",
    "redigirás": "redigir",
    "redigirão": "redigir",
    "redigiríamos": "redigir",
    "redigiríeis": "redigir",
    "redigis": "redigir",
    "redigisse": "redigir",
    "redigissem": "redigir",
    "redigisses": "redigir",
    "redigiste": "redigir",
    "redigistes": "redigir",
    "redigiu": "redigir",
    "redigo": "redizer",
    "redigíamo": "redigir",
    "redigíamos": "redigir",
    "redigíei": "redigir",
    "redigíeis": "redigir",
    "redigíramo": "redigir",
    "redigíramos": "redigir",
    "redigírei": "redigir",
    "redigíreis": "redigir",
    "redigísseis": "redigir",
    "redigíssemos": "redigir",
    "redigíveis": "redigível",
    "redija": "redigir",
    "redijais": "redigir",
    "redijam": "redigir",
    "redijamo": "redigir",
    "redijamos": "redigir",
    "redijas": "redigir",
    "redijo": "redigir",
    "redima": "redimir",
    "redimais": "redimir",
    "redimam": "redimir",
    "redimamo": "redimir",
    "redimamos": "redimir",
    "redimas": "redimir",
    "redime": "redimir",
    "redimem": "redimir",
    "redimensiona": "redimensionar",
    "redimensionada": "redimensionar",
    "redimensionadas": "redimensionar",
    "redimensionado": "redimensionar",
    "redimensionados": "redimensionar",
    "redimensionai": "redimensionar",
    "redimensionais": "redimensionar",
    "redimensionam": "redimensionar",
    "redimensionamentos": "redimensionamento",
    "redimensionamo": "redimensionar",
    "redimensionamos": "redimensionar",
    "redimensionando": "redimensionar",
    "redimensionara": "redimensionar",
    "redimensionaram": "redimensionar",
    "redimensionaras": "redimensionar",
    "redimensionarde": "redimensionar",
    "redimensionardes": "redimensionar",
    "redimensionare": "redimensionar",
    "redimensionarei": "redimensionar",
    "redimensionareis": "redimensionar",
    "redimensionarem": "redimensionar",
    "redimensionaremos": "redimensionar",
    "redimensionares": "redimensionar",
    "redimensionaria": "redimensionar",
    "redimensionariam": "redimensionar",
    "redimensionarias": "redimensionar",
    "redimensionarmo": "redimensionar",
    "redimensionarmos": "redimensionar",
    "redimensionará": "redimensionar",
    "redimensionarás": "redimensionar",
    "redimensionarão": "redimensionar",
    "redimensionaríamos": "redimensionar",
    "redimensionaríeis": "redimensionar",
    "redimensionas": "redimensionar",
    "redimensionasse": "redimensionar",
    "redimensionassem": "redimensionar",
    "redimensionasses": "redimensionar",
    "redimensionaste": "redimensionar",
    "redimensionastes": "redimensionar",
    "redimensionava": "redimensionar",
    "redimensionavam": "redimensionar",
    "redimensionavas": "redimensionar",
    "redimensione": "redimensionar",
    "redimensionei": "redimensionar",
    "redimensioneis": "redimensionar",
    "redimensionem": "redimensionar",
    "redimensionemo": "redimensionar",
    "redimensionemos": "redimensionar",
    "redimensiones": "redimensionar",
    "redimensiono": "redimensionar",
    "redimensionou": "redimensionar",
    "redimensioná": "redimensionar",
    "redimensionámo": "redimensionar",
    "redimensionámos": "redimensionar",
    "redimensionáramo": "redimensionar",
    "redimensionáramos": "redimensionar",
    "redimensionárei": "redimensionar",
    "redimensionáreis": "redimensionar",
    "redimensionásseis": "redimensionar",
    "redimensionássemos": "redimensionar",
    "redimensionávamo": "redimensionar",
    "redimensionávamos": "redimensionar",
    "redimensionávei": "redimensionar",
    "redimensionáveis": "redimensionar",
    "redimes": "redimir",
    "redimi": "redimir",
    "redimia": "redimir",
    "redimiam": "redimir",
    "redimias": "redimir",
    "redimida": "redimir",
    "redimidas": "redimir",
    "redimido": "redimir",
    "redimidos": "redimir",
    "redimimo": "redimir",
    "redimimos": "redimir",
    "redimindo": "redimir",
    "redimira": "redimir",
    "redimiram": "redimir",
    "redimiras": "redimir",
    "redimirde": "redimir",
    "redimirdes": "redimir",
    "redimire": "redimir",
    "redimirei": "redimir",
    "redimireis": "redimir",
    "redimirem": "redimir",
    "redimiremos": "redimir",
    "redimires": "redimir",
    "redimiria": "redimir",
    "redimiriam": "redimir",
    "redimirias": "redimir",
    "redimirmo": "redimir",
    "redimirmos": "redimir",
    "redimirá": "redimir",
    "redimirás": "redimir",
    "redimirão": "redimir",
    "redimiríamos": "redimir",
    "redimiríeis": "redimir",
    "redimis": "redimir",
    "redimisse": "redimir",
    "redimissem": "redimir",
    "redimisses": "redimir",
    "redimiste": "redimir",
    "redimistes": "redimir",
    "redimiu": "redimir",
    "redimo": "redimir",
    "redimíamo": "redimir",
    "redimíamos": "redimir",
    "redimíei": "redimir",
    "redimíeis": "redimir",
    "redimíramo": "redimir",
    "redimíramos": "redimir",
    "redimírei": "redimir",
    "redimíreis": "redimir",
    "redimísseis": "redimir",
    "redimíssemos": "redimir",
    "redimíveis": "redimível",
    "redinamizações": "redinamização",
    "redingotes": "redingote",
    "redinhas": "redinha",
    "redintegra": "redintegrar",
    "redintegrada": "redintegrar",
    "redintegradas": "redintegrar",
    "redintegrado": "redintegrar",
    "redintegrados": "redintegrar",
    "redintegrai": "redintegrar",
    "redintegrais": "redintegrar",
    "redintegram": "redintegrar",
    "redintegramo": "redintegrar",
    "redintegramos": "redintegrar",
    "redintegrando": "redintegrar",
    "redintegrara": "redintegrar",
    "redintegraram": "redintegrar",
    "redintegraras": "redintegrar",
    "redintegrarde": "redintegrar",
    "redintegrardes": "redintegrar",
    "redintegrare": "redintegrar",
    "redintegrarei": "redintegrar",
    "redintegrareis": "redintegrar",
    "redintegrarem": "redintegrar",
    "redintegraremos": "redintegrar",
    "redintegrares": "redintegrar",
    "redintegraria": "redintegrar",
    "redintegrariam": "redintegrar",
    "redintegrarias": "redintegrar",
    "redintegrarmo": "redintegrar",
    "redintegrarmos": "redintegrar",
    "redintegrará": "redintegrar",
    "redintegrarás": "redintegrar",
    "redintegrarão": "redintegrar",
    "redintegraríamos": "redintegrar",
    "redintegraríeis": "redintegrar",
    "redintegras": "redintegrar",
    "redintegrasse": "redintegrar",
    "redintegrassem": "redintegrar",
    "redintegrasses": "redintegrar",
    "redintegraste": "redintegrar",
    "redintegrastes": "redintegrar",
    "redintegrava": "redintegrar",
    "redintegravam": "redintegrar",
    "redintegravas": "redintegrar",
    "redintegre": "redintegrar",
    "redintegrei": "redintegrar",
    "redintegreis": "redintegrar",
    "redintegrem": "redintegrar",
    "redintegremo": "redintegrar",
    "redintegremos": "redintegrar",
    "redintegres": "redintegrar",
    "redintegro": "redintegrar",
    "redintegrou": "redintegrar",
    "redintegrá": "redintegrar",
    "redintegrámo": "redintegrar",
    "redintegrámos": "redintegrar",
    "redintegráramo": "redintegrar",
    "redintegráramos": "redintegrar",
    "redintegrárei": "redintegrar",
    "redintegráreis": "redintegrar",
    "redintegrásseis": "redintegrar",
    "redintegrássemos": "redintegrar",
    "redintegrávamo": "redintegrar",
    "redintegrávamos": "redintegrar",
    "redintegrávei": "redintegrar",
    "redintegráveis": "redintegrar",
    "redirecciona": "redireccionar",
    "redireccionada": "redireccionar",
    "redireccionadas": "redireccionar",
    "redireccionado": "redireccionar",
    "redireccionados": "redireccionar",
    "redireccionai": "redireccionar",
    "redireccionais": "redireccionar",
    "redireccionam": "redireccionar",
    "redireccionamo": "redireccionar",
    "redireccionamos": "redireccionar",
    "redireccionando": "redireccionar",
    "redireccionara": "redireccionar",
    "redireccionaram": "redireccionar",
    "redireccionaras": "redireccionar",
    "redireccionarde": "redireccionar",
    "redireccionardes": "redireccionar",
    "redireccionare": "redireccionar",
    "redireccionarei": "redireccionar",
    "redireccionareis": "redireccionar",
    "redireccionarem": "redireccionar",
    "redireccionaremos": "redireccionar",
    "redireccionares": "redireccionar",
    "redireccionaria": "redireccionar",
    "redireccionariam": "redireccionar",
    "redireccionarias": "redireccionar",
    "redireccionarmo": "redireccionar",
    "redireccionarmos": "redireccionar",
    "redireccionará": "redireccionar",
    "redireccionarás": "redireccionar",
    "redireccionarão": "redireccionar",
    "redireccionaríamos": "redireccionar",
    "redireccionaríeis": "redireccionar",
    "redireccionas": "redireccionar",
    "redireccionasse": "redireccionar",
    "redireccionassem": "redireccionar",
    "redireccionasses": "redireccionar",
    "redireccionaste": "redireccionar",
    "redireccionastes": "redireccionar",
    "redireccionava": "redireccionar",
    "redireccionavam": "redireccionar",
    "redireccionavas": "redireccionar",
    "redireccione": "redireccionar",
    "redireccionei": "redireccionar",
    "redireccioneis": "redireccionar",
    "redireccionem": "redireccionar",
    "redireccionemo": "redireccionar",
    "redireccionemos": "redireccionar",
    "redirecciones": "redireccionar",
    "redirecciono": "redireccionar",
    "redireccionou": "redireccionar",
    "redireccioná": "redireccionar",
    "redireccionámo": "redireccionar",
    "redireccionámos": "redireccionar",
    "redireccionáramo": "redireccionar",
    "redireccionáramos": "redireccionar",
    "redireccionárei": "redireccionar",
    "redireccionáreis": "redireccionar",
    "redireccionásseis": "redireccionar",
    "redireccionássemos": "redireccionar",
    "redireccionávamo": "redireccionar",
    "redireccionávamos": "redireccionar",
    "redireccionávei": "redireccionar",
    "redireccionáveis": "redireccionar",
    "redirei": "redizer",
    "redireis": "redizer",
    "rediremos": "redizer",
    "rediria": "redizer",
    "rediriam": "redizer",
    "redirias": "redizer",
    "redirá": "redizer",
    "redirás": "redizer",
    "redirão": "redizer",
    "rediríamos": "redizer",
    "rediríeis": "redizer",
    "redis": "redil",
    "redisse": "redizer",
    "redissemo": "redizer",
    "redissemos": "redizer",
    "redisser": "redizer",
    "redissera": "redizer",
    "redisseram": "redizer",
    "redisseras": "redizer",
    "redisserdes": "redizer",
    "redisserem": "redizer",
    "redisseres": "redizer",
    "redissermos": "redizer",
    "redissesse": "redizer",
    "redissessem": "redizer",
    "redissesses": "redizer",
    "redisseste": "redizer",
    "redissestes": "redizer",
    "redisséramo": "redizer",
    "redisséramos": "redizer",
    "redissérei": "redizer",
    "redisséreis": "redizer",
    "redissésseis": "redizer",
    "redisséssemos": "redizer",
    "redistribua": "redistribuir",
    "redistribuais": "redistribuir",
    "redistribuam": "redistribuir",
    "redistribuamo": "redistribuir",
    "redistribuamos": "redistribuir",
    "redistribuas": "redistribuir",
    "redistribuem": "redistribuir",
    "redistribui": "redistribuir",
    "redistribuindo": "redistribuir",
    "redistribuirde": "redistribuir",
    "redistribuirdes": "redistribuir",
    "redistribuirei": "redistribuir",
    "redistribuireis": "redistribuir",
    "redistribuiremos": "redistribuir",
    "redistribuiria": "redistribuir",
    "redistribuiriam": "redistribuir",
    "redistribuirias": "redistribuir",
    "redistribuirmo": "redistribuir",
    "redistribuirmos": "redistribuir",
    "redistribuirá": "redistribuir",
    "redistribuirás": "redistribuir",
    "redistribuirão": "redistribuir",
    "redistribuiríamos": "redistribuir",
    "redistribuiríeis": "redistribuir",
    "redistribuis": "redistribuir",
    "redistribuiu": "redistribuir",
    "redistribuições": "redistribuição",
    "redistribuo": "redistribuir",
    "redistributiva": "redistributivo",
    "redistributivas": "redistributivo",
    "redistributivos": "redistributivo",
    "redistribuí": "redistribuir",
    "redistribuía": "redistribuir",
    "redistribuíam": "redistribuir",
    "redistribuíamo": "redistribuir",
    "redistribuíamos": "redistribuir",
    "redistribuías": "redistribuir",
    "redistribuída": "redistribuir",
    "redistribuídas": "redistribuir",
    "redistribuído": "redistribuir",
    "redistribuídos": "redistribuir",
    "redistribuíei": "redistribuir",
    "redistribuíeis": "redistribuir",
    "redistribuímo": "redistribuir",
    "redistribuímos": "redistribuir",
    "redistribuíra": "redistribuir",
    "redistribuíram": "redistribuir",
    "redistribuíramo": "redistribuir",
    "redistribuíramos": "redistribuir",
    "redistribuíras": "redistribuir",
    "redistribuíre": "redistribuir",
    "redistribuírei": "redistribuir",
    "redistribuíreis": "redistribuir",
    "redistribuírem": "redistribuir",
    "redistribuíres": "redistribuir",
    "redistribuís": "redistribuir",
    "redistribuísse": "redistribuir",
    "redistribuísseis": "redistribuir",
    "redistribuíssem": "redistribuir",
    "redistribuíssemos": "redistribuir",
    "redistribuísses": "redistribuir",
    "redistribuíste": "redistribuir",
    "redistribuístes": "redistribuir",
    "redistribuíveis": "redistribuível",
    "redita": "redizer",
    "reditas": "redizer",
    "redito": "redizer",
    "reditos": "redizer",
    "rediviva": "redivivo",
    "redivivas": "redivivo",
    "redivivos": "redivivo",
    "rediz": "redizer",
    "redize": "redizer",
    "redizei": "redizer",
    "redizeis": "redizer",
    "redizem": "redizer",
    "redizemo": "redizer",
    "redizemos": "redizer",
    "redizendo": "redizer",
    "redizerde": "redizer",
    "redizerdes": "redizer",
    "redizere": "redizer",
    "redizerem": "redizer",
    "redizeres": "redizer",
    "redizermo": "redizer",
    "redizermos": "redizer",
    "redizes": "redizer",
    "redizia": "redizer",
    "rediziam": "redizer",
    "redizias": "redizer",
    "redizê": "redizer",
    "redizíamo": "redizer",
    "redizíamos": "redizer",
    "redizíei": "redizer",
    "redizíeis": "redizer",
    "redições": "redição",
    "redo": "redar",
    "redobra": "redobrar",
    "redobrada": "redobrar",
    "redobradas": "redobrar",
    "redobrado": "redobrar",
    "redobrados": "redobrar",
    "redobrai": "redobrar",
    "redobrais": "redobrar",
    "redobram": "redobrar",
    "redobramentos": "redobramento",
    "redobramo": "redobrar",
    "redobramos": "redobrar",
    "redobrando": "redobrar",
    "redobrara": "redobrar",
    "redobraram": "redobrar",
    "redobraras": "redobrar",
    "redobrarde": "redobrar",
    "redobrardes": "redobrar",
    "redobrare": "redobrar",
    "redobrarei": "redobrar",
    "redobrareis": "redobrar",
    "redobrarem": "redobrar",
    "redobraremos": "redobrar",
    "redobrares": "redobrar",
    "redobraria": "redobrar",
    "redobrariam": "redobrar",
    "redobrarias": "redobrar",
    "redobrarmo": "redobrar",
    "redobrarmos": "redobrar",
    "redobrará": "redobrar",
    "redobrarás": "redobrar",
    "redobrarão": "redobrar",
    "redobraríamos": "redobrar",
    "redobraríeis": "redobrar",
    "redobras": "redobrar",
    "redobrasse": "redobrar",
    "redobrassem": "redobrar",
    "redobrasses": "redobrar",
    "redobraste": "redobrar",
    "redobrastes": "redobrar",
    "redobrava": "redobrar",
    "redobravam": "redobrar",
    "redobravas": "redobrar",
    "redobre": "redobrar",
    "redobrei": "redobrar",
    "redobreis": "redobrar",
    "redobrem": "redobrar",
    "redobremo": "redobrar",
    "redobremos": "redobrar",
    "redobres": "redobre",
    "redobro": "redobrar",
    "redobros": "redobro",
    "redobrou": "redobrar",
    "redobrá": "redobrar",
    "redobrámo": "redobrar",
    "redobrámos": "redobrar",
    "redobráramo": "redobrar",
    "redobráramos": "redobrar",
    "redobrárei": "redobrar",
    "redobráreis": "redobrar",
    "redobrásseis": "redobrar",
    "redobrássemos": "redobrar",
    "redobrávamo": "redobrar",
    "redobrávamos": "redobrar",
    "redobrávei": "redobrar",
    "redobráveis": "redobrar",
    "redoice": "redoiçar",
    "redoicei": "redoiçar",
    "redoiceis": "redoiçar",
    "redoicem": "redoiçar",
    "redoicemo": "redoiçar",
    "redoicemos": "redoiçar",
    "redoices": "redoiçar",
    "redoira": "redoirar",
    "redoirada": "redoirar",
    "redoiradas": "redoirar",
    "redoirado": "redoirar",
    "redoirados": "redoirar",
    "redoirai": "redoirar",
    "redoirais": "redoirar",
    "redoiram": "redoirar",
    "redoiramo": "redoirar",
    "redoiramos": "redoirar",
    "redoirando": "redoirar",
    "redoirara": "redoirar",
    "redoiraram": "redoirar",
    "redoiraras": "redoirar",
    "redoirarde": "redoirar",
    "redoirardes": "redoirar",
    "redoirare": "redoirar",
    "redoirarei": "redoirar",
    "redoirareis": "redoirar",
    "redoirarem": "redoirar",
    "redoiraremos": "redoirar",
    "redoirares": "redoirar",
    "redoiraria": "redoirar",
    "redoirariam": "redoirar",
    "redoirarias": "redoirar",
    "redoirarmo": "redoirar",
    "redoirarmos": "redoirar",
    "redoirará": "redoirar",
    "redoirarás": "redoirar",
    "redoirarão": "redoirar",
    "redoiraríamos": "redoirar",
    "redoiraríeis": "redoirar",
    "redoiras": "redoirar",
    "redoirasse": "redoirar",
    "redoirassem": "redoirar",
    "redoirasses": "redoirar",
    "redoiraste": "redoirar",
    "redoirastes": "redoirar",
    "redoirava": "redoirar",
    "redoiravam": "redoirar",
    "redoiravas": "redoirar",
    "redoire": "redoirar",
    "redoirei": "redoirar",
    "redoireis": "redoirar",
    "redoirem": "redoirar",
    "redoiremo": "redoirar",
    "redoiremos": "redoirar",
    "redoires": "redoirar",
    "redoiro": "redoirar",
    "redoirou": "redoirar",
    "redoirá": "redoirar",
    "redoirámo": "redoirar",
    "redoirámos": "redoirar",
    "redoiráramo": "redoirar",
    "redoiráramos": "redoirar",
    "redoirárei": "redoirar",
    "redoiráreis": "redoirar",
    "redoirásseis": "redoirar",
    "redoirássemos": "redoirar",
    "redoirávamo": "redoirar",
    "redoirávamos": "redoirar",
    "redoirávei": "redoirar",
    "redoiráveis": "redoirar",
    "redoiça": "redoiçar",
    "redoiçada": "redoiçar",
    "redoiçadas": "redoiçar",
    "redoiçado": "redoiçar",
    "redoiçados": "redoiçar",
    "redoiçai": "redoiçar",
    "redoiçais": "redoiçar",
    "redoiçam": "redoiçar",
    "redoiçamo": "redoiçar",
    "redoiçamos": "redoiçar",
    "redoiçando": "redoiçar",
    "redoiçara": "redoiçar",
    "redoiçaram": "redoiçar",
    "redoiçaras": "redoiçar",
    "redoiçarde": "redoiçar",
    "redoiçardes": "redoiçar",
    "redoiçare": "redoiçar",
    "redoiçarei": "redoiçar",
    "redoiçareis": "redoiçar",
    "redoiçarem": "redoiçar",
    "redoiçaremos": "redoiçar",
    "redoiçares": "redoiçar",
    "redoiçaria": "redoiçar",
    "redoiçariam": "redoiçar",
    "redoiçarias": "redoiçar",
    "redoiçarmo": "redoiçar",
    "redoiçarmos": "redoiçar",
    "redoiçará": "redoiçar",
    "redoiçarás": "redoiçar",
    "redoiçarão": "redoiçar",
    "redoiçaríamos": "redoiçar",
    "redoiçaríeis": "redoiçar",
    "redoiças": "redoiçar",
    "redoiçasse": "redoiçar",
    "redoiçassem": "redoiçar",
    "redoiçasses": "redoiçar",
    "redoiçaste": "redoiçar",
    "redoiçastes": "redoiçar",
    "redoiçava": "redoiçar",
    "redoiçavam": "redoiçar",
    "redoiçavas": "redoiçar",
    "redoiço": "redoiçar",
    "redoiçou": "redoiçar",
    "redoiçá": "redoiçar",
    "redoiçámo": "redoiçar",
    "redoiçámos": "redoiçar",
    "redoiçáramo": "redoiçar",
    "redoiçáramos": "redoiçar",
    "redoiçárei": "redoiçar",
    "redoiçáreis": "redoiçar",
    "redoiçásseis": "redoiçar",
    "redoiçássemos": "redoiçar",
    "redoiçávamo": "redoiçar",
    "redoiçávamos": "redoiçar",
    "redoiçávei": "redoiçar",
    "redoiçáveis": "redoiçar",
    "redolentes": "redolente",
    "redomas": "redoma",
    "redomoinhos": "redomoinho",
    "redomona": "redomão",
    "redomonas": "redomão",
    "redomões": "redomão",
    "redonda": "redondo",
    "redondais": "redondal",
    "redondas": "redondo",
    "redondazinha": "redondo",
    "redondazinhas": "redondo",
    "redondazita": "redondo",
    "redondazitas": "redondo",
    "redondeada": "redondear",
    "redondeadas": "redondear",
    "redondeado": "redondear",
    "redondeados": "redondear",
    "redondeai": "redondear",
    "redondeais": "redondear",
    "redondeamo": "redondear",
    "redondeamos": "redondear",
    "redondeando": "redondear",
    "redondeara": "redondear",
    "redondearam": "redondear",
    "redondearas": "redondear",
    "redondearde": "redondear",
    "redondeardes": "redondear",
    "redondeare": "redondear",
    "redondearei": "redondear",
    "redondeareis": "redondear",
    "redondearem": "redondear",
    "redondearemos": "redondear",
    "redondeares": "redondear",
    "redondearia": "redondear",
    "redondeariam": "redondear",
    "redondearias": "redondear",
    "redondearmo": "redondear",
    "redondearmos": "redondear",
    "redondeará": "redondear",
    "redondearás": "redondear",
    "redondearão": "redondear",
    "redondearíamos": "redondear",
    "redondearíeis": "redondear",
    "redondeasse": "redondear",
    "redondeassem": "redondear",
    "redondeasses": "redondear",
    "redondeaste": "redondear",
    "redondeastes": "redondear",
    "redondeava": "redondear",
    "redondeavam": "redondear",
    "redondeavas": "redondear",
    "redondeei": "redondear",
    "redondeeis": "redondear",
    "redondeemo": "redondear",
    "redondeemos": "redondear",
    "redondeia": "redondear",
    "redondeiam": "redondear",
    "redondeias": "redondear",
    "redondeie": "redondear",
    "redondeiem": "redondear",
    "redondeies": "redondear",
    "redondeio": "redondear",
    "redondeis": "redondel",
    "redondelas": "redondela",
    "redondeou": "redondear",
    "redondezas": "redondeza",
    "redondezes": "redondez",
    "redondeá": "redondear",
    "redondeámo": "redondear",
    "redondeámos": "redondear",
    "redondeáramo": "redondear",
    "redondeáramos": "redondear",
    "redondeárei": "redondear",
    "redondeáreis": "redondear",
    "redondeásseis": "redondear",
    "redondeássemos": "redondear",
    "redondeávamo": "redondear",
    "redondeávamos": "redondear",
    "redondeávei": "redondear",
    "redondeáveis": "redondear",
    "redondilhas": "redondilha",
    "redondinha": "redondo",
    "redondinhas": "redondo",
    "redondinho": "redondo",
    "redondinhos": "redondo",
    "redondis": "redondil",
    "redondita": "redondo",
    "redonditas": "redondo",
    "redondito": "redondo",
    "redonditos": "redondo",
    "redondos": "redondo",
    "redondozinho": "redondo",
    "redondozinhos": "redondo",
    "redondozito": "redondo",
    "redondozitos": "redondo",
    "redopia": "redopiar",
    "redopiada": "redopiar",
    "redopiadas": "redopiar",
    "redopiado": "redopiar",
    "redopiados": "redopiar",
    "redopiai": "redopiar",
    "redopiais": "redopiar",
    "redopiam": "redopiar",
    "redopiamo": "redopiar",
    "redopiamos": "redopiar",
    "redopiando": "redopiar",
    "redopiara": "redopiar",
    "redopiaram": "redopiar",
    "redopiaras": "redopiar",
    "redopiardes": "redopiar",
    "redopiarei": "redopiar",
    "redopiareis": "redopiar",
    "redopiarem": "redopiar",
    "redopiaremos": "redopiar",
    "redopiares": "redopiar",
    "redopiaria": "redopiar",
    "redopiariam": "redopiar",
    "redopiarias": "redopiar",
    "redopiarmo": "redopiar",
    "redopiarmos": "redopiar",
    "redopiará": "redopiar",
    "redopiarás": "redopiar",
    "redopiarão": "redopiar",
    "redopiaríamos": "redopiar",
    "redopiaríeis": "redopiar",
    "redopias": "redopiar",
    "redopiasse": "redopiar",
    "redopiassem": "redopiar",
    "redopiasses": "redopiar",
    "redopiaste": "redopiar",
    "redopiastes": "redopiar",
    "redopiava": "redopiar",
    "redopiavam": "redopiar",
    "redopiavas": "redopiar",
    "redopie": "redopiar",
    "redopiei": "redopiar",
    "redopieis": "redopiar",
    "redopiem": "redopiar",
    "redopiemo": "redopiar",
    "redopiemos": "redopiar",
    "redopies": "redopiar",
    "redopio": "redopiar",
    "redopios": "redopio",
    "redopiou": "redopiar",
    "redopiámo": "redopiar",
    "redopiámos": "redopiar",
    "redopiáramo": "redopiar",
    "redopiáramos": "redopiar",
    "redopiáreis": "redopiar",
    "redopiásseis": "redopiar",
    "redopiássemos": "redopiar",
    "redopiávamo": "redopiar",
    "redopiávamos": "redopiar",
    "redopiáveis": "redopiar",
    "redores": "redor",
    "redou": "redar",
    "redouce": "redouçar",
    "redoucei": "redouçar",
    "redouceis": "redouçar",
    "redoucem": "redouçar",
    "redoucemo": "redouçar",
    "redoucemos": "redouçar",
    "redouces": "redouçar",
    "redoura": "redourar",
    "redourada": "redourar",
    "redouradas": "redourar",
    "redourado": "redourar",
    "redourados": "redourar",
    "redourai": "redourar",
    "redourais": "redourar",
    "redouram": "redourar",
    "redouramo": "redourar",
    "redouramos": "redourar",
    "redourando": "redourar",
    "redourara": "redourar",
    "redouraram": "redourar",
    "redouraras": "redourar",
    "redourarde": "redourar",
    "redourardes": "redourar",
    "redourare": "redourar",
    "redourarei": "redourar",
    "redourareis": "redourar",
    "redourarem": "redourar",
    "redouraremos": "redourar",
    "redourares": "redourar",
    "redouraria": "redourar",
    "redourariam": "redourar",
    "redourarias": "redourar",
    "redourarmo": "redourar",
    "redourarmos": "redourar",
    "redourará": "redourar",
    "redourarás": "redourar",
    "redourarão": "redourar",
    "redouraríamos": "redourar",
    "redouraríeis": "redourar",
    "redouras": "redourar",
    "redourasse": "redourar",
    "redourassem": "redourar",
    "redourasses": "redourar",
    "redouraste": "redourar",
    "redourastes": "redourar",
    "redourava": "redourar",
    "redouravam": "redourar",
    "redouravas": "redourar",
    "redoure": "redourar",
    "redourei": "redourar",
    "redoureis": "redourar",
    "redourem": "redourar",
    "redouremo": "redourar",
    "redouremos": "redourar",
    "redoures": "redourar",
    "redouro": "redourar",
    "redourou": "redourar",
    "redourá": "redourar",
    "redourámo": "redourar",
    "redourámos": "redourar",
    "redouráramo": "redourar",
    "redouráramos": "redourar",
    "redourárei": "redourar",
    "redouráreis": "redourar",
    "redourásseis": "redourar",
    "redourássemos": "redourar",
    "redourávamo": "redourar",
    "redourávamos": "redourar",
    "redourávei": "redourar",
    "redouráveis": "redourar",
    "redouça": "redouçar",
    "redouçada": "redouçar",
    "redouçadas": "redouçar",
    "redouçado": "redouçar",
    "redouçados": "redouçar",
    "redouçai": "redouçar",
    "redouçais": "redouçar",
    "redouçam": "redouçar",
    "redouçamo": "redouçar",
    "redouçamos": "redouçar",
    "redouçando": "redouçar",
    "redouçara": "redouçar",
    "redouçaram": "redouçar",
    "redouçaras": "redouçar",
    "redouçardes": "redouçar",
    "redouçarei": "redouçar",
    "redouçareis": "redouçar",
    "redouçarem": "redouçar",
    "redouçaremos": "redouçar",
    "redouçares": "redouçar",
    "redouçaria": "redouçar",
    "redouçariam": "redouçar",
    "redouçarias": "redouçar",
    "redouçarmo": "redouçar",
    "redouçarmos": "redouçar",
    "redouçará": "redouçar",
    "redouçarás": "redouçar",
    "redouçarão": "redouçar",
    "redouçaríamos": "redouçar",
    "redouçaríeis": "redouçar",
    "redouças": "redouçar",
    "redouçasse": "redouçar",
    "redouçassem": "redouçar",
    "redouçasses": "redouçar",
    "redouçaste": "redouçar",
    "redouçastes": "redouçar",
    "redouçava": "redouçar",
    "redouçavam": "redouçar",
    "redouçavas": "redouçar",
    "redouço": "redouçar",
    "redouçou": "redouçar",
    "redouçámo": "redouçar",
    "redouçámos": "redouçar",
    "redouçáramo": "redouçar",
    "redouçáramos": "redouçar",
    "redouçáreis": "redouçar",
    "redouçásseis": "redouçar",
    "redouçássemos": "redouçar",
    "redouçávamo": "redouçar",
    "redouçávamos": "redouçar",
    "redouçáveis": "redouçar",
    "redra": "redrar",
    "redrada": "redrar",
    "redradas": "redrar",
    "redrado": "redrar",
    "redrados": "redrar",
    "redrai": "redrar",
    "redrais": "redrar",
    "redram": "redrar",
    "redramo": "redrar",
    "redramos": "redrar",
    "redrando": "redrar",
    "redrara": "redrar",
    "redraram": "redrar",
    "redraras": "redrar",
    "redrardes": "redrar",
    "redrarei": "redrar",
    "redrareis": "redrar",
    "redrarem": "redrar",
    "redraremos": "redrar",
    "redrares": "redrar",
    "redraria": "redrar",
    "redrariam": "redrar",
    "redrarias": "redrar",
    "redrarmo": "redrar",
    "redrarmos": "redrar",
    "redrará": "redrar",
    "redrarás": "redrar",
    "redrarão": "redrar",
    "redraríamos": "redrar",
    "redraríeis": "redrar",
    "redras": "redrar",
    "redrasse": "redrar",
    "redrassem": "redrar",
    "redrasses": "redrar",
    "redraste": "redrar",
    "redrastes": "redrar",
    "redrava": "redrar",
    "redravam": "redrar",
    "redravas": "redrar",
    "redre": "redrar",
    "redrei": "redrar",
    "redreis": "redrar",
    "redrem": "redrar",
    "redremo": "redrar",
    "redremos": "redrar",
    "redres": "redrar",
    "redro": "redrar",
    "redrou": "redrar",
    "redrámo": "redrar",
    "redrámos": "redrar",
    "redráramo": "redrar",
    "redráramos": "redrar",
    "redráreis": "redrar",
    "redrásseis": "redrar",
    "redrássemos": "redrar",
    "redrávamo": "redrar",
    "redrávamos": "redrar",
    "redráveis": "redrar",
    "reducentes": "reducente",
    "reducionistas": "reducionista",
    "redunda": "redundar",
    "redundada": "redundar",
    "redundadas": "redundar",
    "redundado": "redundar",
    "redundados": "redundar",
    "redundai": "redundar",
    "redundais": "redundar",
    "redundam": "redundar",
    "redundamo": "redundar",
    "redundamos": "redundar",
    "redundando": "redundar",
    "redundantes": "redundante",
    "redundara": "redundar",
    "redundaram": "redundar",
    "redundaras": "redundar",
    "redundardes": "redundar",
    "redundarei": "redundar",
    "redundareis": "redundar",
    "redundarem": "redundar",
    "redundaremos": "redundar",
    "redundares": "redundar",
    "redundaria": "redundar",
    "redundariam": "redundar",
    "redundarias": "redundar",
    "redundarmo": "redundar",
    "redundarmos": "redundar",
    "redundará": "redundar",
    "redundarás": "redundar",
    "redundarão": "redundar",
    "redundaríamos": "redundar",
    "redundaríeis": "redundar",
    "redundas": "redundar",
    "redundasse": "redundar",
    "redundassem": "redundar",
    "redundasses": "redundar",
    "redundaste": "redundar",
    "redundastes": "redundar",
    "redundava": "redundar",
    "redundavam": "redundar",
    "redundavas": "redundar",
    "redunde": "redundar",
    "redundei": "redundar",
    "redundeis": "redundar",
    "redundem": "redundar",
    "redundemo": "redundar",
    "redundemos": "redundar",
    "redundes": "redundar",
    "redundo": "redundar",
    "redundou": "redundar",
    "redundámo": "redundar",
    "redundámos": "redundar",
    "redundáramo": "redundar",
    "redundáramos": "redundar",
    "redundáreis": "redundar",
    "redundásseis": "redundar",
    "redundássemos": "redundar",
    "redundávamo": "redundar",
    "redundávamos": "redundar",
    "redundáveis": "redundar",
    "redundâncias": "redundância",
    "reduplica": "reduplicar",
    "reduplicada": "reduplicar",
    "reduplicadas": "reduplicar",
    "reduplicado": "reduplicar",
    "reduplicados": "reduplicar",
    "reduplicai": "reduplicar",
    "reduplicais": "reduplicar",
    "reduplicam": "reduplicar",
    "reduplicamo": "reduplicar",
    "reduplicamos": "reduplicar",
    "reduplicando": "reduplicar",
    "reduplicara": "reduplicar",
    "reduplicaram": "reduplicar",
    "reduplicaras": "reduplicar",
    "reduplicarde": "reduplicar",
    "reduplicardes": "reduplicar",
    "reduplicare": "reduplicar",
    "reduplicarei": "reduplicar",
    "reduplicareis": "reduplicar",
    "reduplicarem": "reduplicar",
    "reduplicaremos": "reduplicar",
    "reduplicares": "reduplicar",
    "reduplicaria": "reduplicar",
    "reduplicariam": "reduplicar",
    "reduplicarias": "reduplicar",
    "reduplicarmo": "reduplicar",
    "reduplicarmos": "reduplicar",
    "reduplicará": "reduplicar",
    "reduplicarás": "reduplicar",
    "reduplicarão": "reduplicar",
    "reduplicaríamos": "reduplicar",
    "reduplicaríeis": "reduplicar",
    "reduplicas": "reduplicar",
    "reduplicasse": "reduplicar",
    "reduplicassem": "reduplicar",
    "reduplicasses": "reduplicar",
    "reduplicaste": "reduplicar",
    "reduplicastes": "reduplicar",
    "reduplicativa": "reduplicativo",
    "reduplicativas": "reduplicativo",
    "reduplicativos": "reduplicativo",
    "reduplicava": "reduplicar",
    "reduplicavam": "reduplicar",
    "reduplicavas": "reduplicar",
    "reduplicações": "reduplicação",
    "reduplico": "reduplicar",
    "reduplicou": "reduplicar",
    "reduplicá": "reduplicar",
    "reduplicámo": "reduplicar",
    "reduplicámos": "reduplicar",
    "reduplicáramo": "reduplicar",
    "reduplicáramos": "reduplicar",
    "reduplicárei": "reduplicar",
    "reduplicáreis": "reduplicar",
    "reduplicásseis": "reduplicar",
    "reduplicássemos": "reduplicar",
    "reduplicávamo": "reduplicar",
    "reduplicávamos": "reduplicar",
    "reduplicávei": "reduplicar",
    "reduplicáveis": "reduplicar",
    "reduplique": "reduplicar",
    "redupliquei": "reduplicar",
    "redupliqueis": "reduplicar",
    "redupliquem": "reduplicar",
    "redupliquemo": "reduplicar",
    "redupliquemos": "reduplicar",
    "redupliques": "reduplicar",
    "reduras": "redura",
    "redutibilidades": "redutibilidade",
    "redutiva": "redutivo",
    "redutivas": "redutivo",
    "redutivos": "redutivo",
    "redutora": "redutor",
    "redutoras": "redutor",
    "redutorazinha": "redutor",
    "redutorazinhas": "redutor",
    "redutorazita": "redutor",
    "redutorazitas": "redutor",
    "redutores": "redutor",
    "redutorzinho": "redutor",
    "redutorzinhos": "redutor",
    "redutorzito": "redutor",
    "redutorzitos": "redutor",
    "redutos": "reduto",
    "redutíveis": "redutível",
    "reduz": "reduzir",
    "reduza": "reduzir",
    "reduzais": "reduzir",
    "reduzam": "reduzir",
    "reduzamo": "reduzir",
    "reduzamos": "reduzir",
    "reduzas": "reduzir",
    "reduze": "reduzir",
    "reduzem": "reduzir",
    "reduzes": "reduzir",
    "reduzi": "reduzir",
    "reduzia": "reduzir",
    "reduziam": "reduzir",
    "reduzias": "reduzir",
    "reduzida": "reduzir",
    "reduzidas": "reduzir",
    "reduzido": "reduzir",
    "reduzidos": "reduzir",
    "reduzidíssima": "reduzido",
    "reduzidíssimas": "reduzido",
    "reduzidíssimo": "reduzido",
    "reduzidíssimos": "reduzido",
    "reduzimo": "reduzir",
    "reduzimos": "reduzir",
    "reduzindo": "reduzir",
    "reduzira": "reduzir",
    "reduziram": "reduzir",
    "reduziras": "reduzir",
    "reduzirde": "reduzir",
    "reduzirdes": "reduzir",
    "reduzire": "reduzir",
    "reduzirei": "reduzir",
    "reduzireis": "reduzir",
    "reduzirem": "reduzir",
    "reduziremos": "reduzir",
    "reduzires": "reduzir",
    "reduziria": "reduzir",
    "reduziriam": "reduzir",
    "reduzirias": "reduzir",
    "reduzirmo": "reduzir",
    "reduzirmos": "reduzir",
    "reduzirá": "reduzir",
    "reduzirás": "reduzir",
    "reduzirão": "reduzir",
    "reduziríamos": "reduzir",
    "reduziríeis": "reduzir",
    "reduzis": "reduzir",
    "reduzisse": "reduzir",
    "reduzissem": "reduzir",
    "reduzisses": "reduzir",
    "reduziste": "reduzir",
    "reduzistes": "reduzir",
    "reduziu": "reduzir",
    "reduzo": "reduzir",
    "reduzíamo": "reduzir",
    "reduzíamos": "reduzir",
    "reduzíei": "reduzir",
    "reduzíeis": "reduzir",
    "reduzíramo": "reduzir",
    "reduzíramos": "reduzir",
    "reduzírei": "reduzir",
    "reduzíreis": "reduzir",
    "reduzísseis": "reduzir",
    "reduzíssemos": "reduzir",
    "reduzíveis": "reduzível",
    "reduções": "redução",
    "redá": "redar",
    "redámo": "redar",
    "redámos": "redar",
    "redáramo": "redar",
    "redáramos": "redar",
    "redárei": "redar",
    "redáreis": "redar",
    "redásseis": "redar",
    "redássemos": "redar",
    "redávamo": "redar",
    "redávamos": "redar",
    "redávei": "redar",
    "redáveis": "redar",
    "redúzios": "redúzio",
    "reedifica": "reedificar",
    "reedificada": "reedificar",
    "reedificadas": "reedificar",
    "reedificado": "reedificar",
    "reedificadora": "reedificador",
    "reedificadoras": "reedificador",
    "reedificadores": "reedificador",
    "reedificados": "reedificar",
    "reedificai": "reedificar",
    "reedificais": "reedificar",
    "reedificam": "reedificar",
    "reedificamo": "reedificar",
    "reedificamos": "reedificar",
    "reedificando": "reedificar",
    "reedificantes": "reedificante",
    "reedificara": "reedificar",
    "reedificaram": "reedificar",
    "reedificaras": "reedificar",
    "reedificarde": "reedificar",
    "reedificardes": "reedificar",
    "reedificare": "reedificar",
    "reedificarei": "reedificar",
    "reedificareis": "reedificar",
    "reedificarem": "reedificar",
    "reedificaremos": "reedificar",
    "reedificares": "reedificar",
    "reedificaria": "reedificar",
    "reedificariam": "reedificar",
    "reedificarias": "reedificar",
    "reedificarmo": "reedificar",
    "reedificarmos": "reedificar",
    "reedificará": "reedificar",
    "reedificarás": "reedificar",
    "reedificarão": "reedificar",
    "reedificaríamos": "reedificar",
    "reedificaríeis": "reedificar",
    "reedificas": "reedificar",
    "reedificasse": "reedificar",
    "reedificassem": "reedificar",
    "reedificasses": "reedificar",
    "reedificaste": "reedificar",
    "reedificastes": "reedificar",
    "reedificava": "reedificar",
    "reedificavam": "reedificar",
    "reedificavas": "reedificar",
    "reedificações": "reedificação",
    "reedifico": "reedificar",
    "reedificou": "reedificar",
    "reedificá": "reedificar",
    "reedificámo": "reedificar",
    "reedificámos": "reedificar",
    "reedificáramo": "reedificar",
    "reedificáramos": "reedificar",
    "reedificárei": "reedificar",
    "reedificáreis": "reedificar",
    "reedificásseis": "reedificar",
    "reedificássemos": "reedificar",
    "reedificávamo": "reedificar",
    "reedificávamos": "reedificar",
    "reedificávei": "reedificar",
    "reedificáveis": "reedificável",
    "reedifique": "reedificar",
    "reedifiquei": "reedificar",
    "reedifiqueis": "reedificar",
    "reedifiquem": "reedificar",
    "reedifiquemo": "reedificar",
    "reedifiquemos": "reedificar",
    "reedifiques": "reedificar",
    "reedita": "reeditar",
    "reeditada": "reeditar",
    "reeditadas": "reeditar",
    "reeditado": "reeditar",
    "reeditados": "reeditar",
    "reeditai": "reeditar",
    "reeditais": "reeditar",
    "reeditam": "reeditar",
    "reeditamo": "reeditar",
    "reeditamos": "reeditar",
    "reeditando": "reeditar",
    "reeditara": "reeditar",
    "reeditaram": "reeditar",
    "reeditaras": "reeditar",
    "reeditarde": "reeditar",
    "reeditardes": "reeditar",
    "reeditare": "reeditar",
    "reeditarei": "reeditar",
    "reeditareis": "reeditar",
    "reeditarem": "reeditar",
    "reeditaremos": "reeditar",
    "reeditares": "reeditar",
    "reeditaria": "reeditar",
    "reeditariam": "reeditar",
    "reeditarias": "reeditar",
    "reeditarmo": "reeditar",
    "reeditarmos": "reeditar",
    "reeditará": "reeditar",
    "reeditarás": "reeditar",
    "reeditarão": "reeditar",
    "reeditaríamos": "reeditar",
    "reeditaríeis": "reeditar",
    "reeditas": "reeditar",
    "reeditasse": "reeditar",
    "reeditassem": "reeditar",
    "reeditasses": "reeditar",
    "reeditaste": "reeditar",
    "reeditastes": "reeditar",
    "reeditava": "reeditar",
    "reeditavam": "reeditar",
    "reeditavas": "reeditar",
    "reedite": "reeditar",
    "reeditei": "reeditar",
    "reediteis": "reeditar",
    "reeditem": "reeditar",
    "reeditemo": "reeditar",
    "reeditemos": "reeditar",
    "reedites": "reeditar",
    "reedito": "reeditar",
    "reeditou": "reeditar",
    "reeditá": "reeditar",
    "reeditámo": "reeditar",
    "reeditámos": "reeditar",
    "reeditáramo": "reeditar",
    "reeditáramos": "reeditar",
    "reeditárei": "reeditar",
    "reeditáreis": "reeditar",
    "reeditásseis": "reeditar",
    "reeditássemos": "reeditar",
    "reeditávamo": "reeditar",
    "reeditávamos": "reeditar",
    "reeditávei": "reeditar",
    "reeditáveis": "reeditável",
    "reedições": "reedição",
    "reeduca": "reeducar",
    "reeducabilidades": "reeducabilidade",
    "reeducada": "reeducar",
    "reeducadas": "reeducar",
    "reeducado": "reeducar",
    "reeducadora": "reeducador",
    "reeducadoras": "reeducador",
    "reeducadores": "reeducador",
    "reeducados": "reeducar",
    "reeducai": "reeducar",
    "reeducais": "reeducar",
    "reeducam": "reeducar",
    "reeducamo": "reeducar",
    "reeducamos": "reeducar",
    "reeducanda": "reeducando",
    "reeducandas": "reeducando",
    "reeducando": "reeducar",
    "reeducandos": "reeducando",
    "reeducara": "reeducar",
    "reeducaram": "reeducar",
    "reeducaras": "reeducar",
    "reeducarde": "reeducar",
    "reeducardes": "reeducar",
    "reeducare": "reeducar",
    "reeducarei": "reeducar",
    "reeducareis": "reeducar",
    "reeducarem": "reeducar",
    "reeducaremos": "reeducar",
    "reeducares": "reeducar",
    "reeducaria": "reeducar",
    "reeducariam": "reeducar",
    "reeducarias": "reeducar",
    "reeducarmo": "reeducar",
    "reeducarmos": "reeducar",
    "reeducará": "reeducar",
    "reeducarás": "reeducar",
    "reeducarão": "reeducar",
    "reeducaríamos": "reeducar",
    "reeducaríeis": "reeducar",
    "reeducas": "reeducar",
    "reeducasse": "reeducar",
    "reeducassem": "reeducar",
    "reeducasses": "reeducar",
    "reeducaste": "reeducar",
    "reeducastes": "reeducar",
    "reeducava": "reeducar",
    "reeducavam": "reeducar",
    "reeducavas": "reeducar",
    "reeducações": "reeducação",
    "reeduco": "reeducar",
    "reeducou": "reeducar",
    "reeducá": "reeducar",
    "reeducámo": "reeducar",
    "reeducámos": "reeducar",
    "reeducáramo": "reeducar",
    "reeducáramos": "reeducar",
    "reeducárei": "reeducar",
    "reeducáreis": "reeducar",
    "reeducásseis": "reeducar",
    "reeducássemos": "reeducar",
    "reeducávamo": "reeducar",
    "reeducávamos": "reeducar",
    "reeducávei": "reeducar",
    "reeducáveis": "reeducável",
    "reeduque": "reeducar",
    "reeduquei": "reeducar",
    "reeduqueis": "reeducar",
    "reeduquem": "reeducar",
    "reeduquemo": "reeducar",
    "reeduquemos": "reeducar",
    "reeduques": "reeducar",
    "reelaborada": "reelaborado",
    "reelaboradas": "reelaborado",
    "reelaborados": "reelaborado",
    "reelege": "reeleger",
    "reelegei": "reeleger",
    "reelegeis": "reeleger",
    "reelegem": "reeleger",
    "reelegemo": "reeleger",
    "reelegemos": "reeleger",
    "reelegendo": "reeleger",
    "reelegera": "reeleger",
    "reelegeram": "reeleger",
    "reelegeras": "reeleger",
    "reelegerde": "reeleger",
    "reelegerdes": "reeleger",
    "reelegere": "reeleger",
    "reelegerei": "reeleger",
    "reelegereis": "reeleger",
    "reelegerem": "reeleger",
    "reelegeremos": "reeleger",
    "reelegeres": "reeleger",
    "reelegeria": "reeleger",
    "reelegeriam": "reeleger",
    "reelegerias": "reeleger",
    "reelegermo": "reeleger",
    "reelegermos": "reeleger",
    "reelegerá": "reeleger",
    "reelegerás": "reeleger",
    "reelegerão": "reeleger",
    "reelegeríamos": "reeleger",
    "reelegeríeis": "reeleger",
    "reeleges": "reeleger",
    "reelegesse": "reeleger",
    "reelegessem": "reeleger",
    "reelegesses": "reeleger",
    "reelegeste": "reeleger",
    "reelegestes": "reeleger",
    "reelegeu": "reeleger",
    "reelegi": "reeleger",
    "reelegia": "reeleger",
    "reelegiam": "reeleger",
    "reelegias": "reeleger",
    "reelegibilidades": "reelegibilidade",
    "reelegida": "reeleger",
    "reelegidas": "reeleger",
    "reelegido": "reeleger",
    "reelegidos": "reeleger",
    "reelegê": "reeleger",
    "reelegêramo": "reeleger",
    "reelegêramos": "reeleger",
    "reelegêrei": "reeleger",
    "reelegêreis": "reeleger",
    "reelegêsseis": "reeleger",
    "reelegêssemos": "reeleger",
    "reelegíamo": "reeleger",
    "reelegíamos": "reeleger",
    "reelegíei": "reeleger",
    "reelegíeis": "reeleger",
    "reelegíveis": "reelegível",
    "reeleita": "reeleito",
    "reeleitas": "reeleito",
    "reeleitos": "reeleito",
    "reeleições": "reeleição",
    "reeleja": "reeleger",
    "reelejais": "reeleger",
    "reelejam": "reeleger",
    "reelejamo": "reeleger",
    "reelejamos": "reeleger",
    "reelejas": "reeleger",
    "reelejo": "reeleger",
    "reembarca": "reembarcar",
    "reembarcada": "reembarcar",
    "reembarcadas": "reembarcar",
    "reembarcado": "reembarcar",
    "reembarcados": "reembarcar",
    "reembarcai": "reembarcar",
    "reembarcais": "reembarcar",
    "reembarcam": "reembarcar",
    "reembarcamo": "reembarcar",
    "reembarcamos": "reembarcar",
    "reembarcando": "reembarcar",
    "reembarcara": "reembarcar",
    "reembarcaram": "reembarcar",
    "reembarcaras": "reembarcar",
    "reembarcarde": "reembarcar",
    "reembarcardes": "reembarcar",
    "reembarcare": "reembarcar",
    "reembarcarei": "reembarcar",
    "reembarcareis": "reembarcar",
    "reembarcarem": "reembarcar",
    "reembarcaremos": "reembarcar",
    "reembarcares": "reembarcar",
    "reembarcaria": "reembarcar",
    "reembarcariam": "reembarcar",
    "reembarcarias": "reembarcar",
    "reembarcarmo": "reembarcar",
    "reembarcarmos": "reembarcar",
    "reembarcará": "reembarcar",
    "reembarcarás": "reembarcar",
    "reembarcarão": "reembarcar",
    "reembarcaríamos": "reembarcar",
    "reembarcaríeis": "reembarcar",
    "reembarcas": "reembarcar",
    "reembarcasse": "reembarcar",
    "reembarcassem": "reembarcar",
    "reembarcasses": "reembarcar",
    "reembarcaste": "reembarcar",
    "reembarcastes": "reembarcar",
    "reembarcava": "reembarcar",
    "reembarcavam": "reembarcar",
    "reembarcavas": "reembarcar",
    "reembarco": "reembarcar",
    "reembarcou": "reembarcar",
    "reembarcá": "reembarcar",
    "reembarcámo": "reembarcar",
    "reembarcámos": "reembarcar",
    "reembarcáramo": "reembarcar",
    "reembarcáramos": "reembarcar",
    "reembarcárei": "reembarcar",
    "reembarcáreis": "reembarcar",
    "reembarcásseis": "reembarcar",
    "reembarcássemos": "reembarcar",
    "reembarcávamo": "reembarcar",
    "reembarcávamos": "reembarcar",
    "reembarcávei": "reembarcar",
    "reembarcáveis": "reembarcar",
    "reembarque": "reembarcar",
    "reembarquei": "reembarcar",
    "reembarqueis": "reembarcar",
    "reembarquem": "reembarcar",
    "reembarquemo": "reembarcar",
    "reembarquemos": "reembarcar",
    "reembarques": "reembarque",
    "reembolsa": "reembolsar",
    "reembolsada": "reembolsar",
    "reembolsadas": "reembolsar",
    "reembolsado": "reembolsar",
    "reembolsados": "reembolsar",
    "reembolsai": "reembolsar",
    "reembolsais": "reembolsar",
    "reembolsam": "reembolsar",
    "reembolsamo": "reembolsar",
    "reembolsamos": "reembolsar",
    "reembolsando": "reembolsar",
    "reembolsara": "reembolsar",
    "reembolsaram": "reembolsar",
    "reembolsaras": "reembolsar",
    "reembolsarde": "reembolsar",
    "reembolsardes": "reembolsar",
    "reembolsare": "reembolsar",
    "reembolsarei": "reembolsar",
    "reembolsareis": "reembolsar",
    "reembolsarem": "reembolsar",
    "reembolsaremos": "reembolsar",
    "reembolsares": "reembolsar",
    "reembolsaria": "reembolsar",
    "reembolsariam": "reembolsar",
    "reembolsarias": "reembolsar",
    "reembolsarmo": "reembolsar",
    "reembolsarmos": "reembolsar",
    "reembolsará": "reembolsar",
    "reembolsarás": "reembolsar",
    "reembolsarão": "reembolsar",
    "reembolsaríamos": "reembolsar",
    "reembolsaríeis": "reembolsar",
    "reembolsas": "reembolsar",
    "reembolsasse": "reembolsar",
    "reembolsassem": "reembolsar",
    "reembolsasses": "reembolsar",
    "reembolsaste": "reembolsar",
    "reembolsastes": "reembolsar",
    "reembolsava": "reembolsar",
    "reembolsavam": "reembolsar",
    "reembolsavas": "reembolsar",
    "reembolse": "reembolsar",
    "reembolsei": "reembolsar",
    "reembolseis": "reembolsar",
    "reembolsem": "reembolsar",
    "reembolsemo": "reembolsar",
    "reembolsemos": "reembolsar",
    "reembolses": "reembolsar",
    "reembolso": "reembolsar",
    "reembolsos": "reembolso",
    "reembolsou": "reembolsar",
    "reembolsá": "reembolsar",
    "reembolsámo": "reembolsar",
    "reembolsámos": "reembolsar",
    "reembolsáramo": "reembolsar",
    "reembolsáramos": "reembolsar",
    "reembolsárei": "reembolsar",
    "reembolsáreis": "reembolsar",
    "reembolsásseis": "reembolsar",
    "reembolsássemos": "reembolsar",
    "reembolsávamo": "reembolsar",
    "reembolsávamos": "reembolsar",
    "reembolsávei": "reembolsar",
    "reembolsáveis": "reembolsável",
    "reemenda": "reemendar",
    "reemendada": "reemendar",
    "reemendadas": "reemendar",
    "reemendado": "reemendar",
    "reemendados": "reemendar",
    "reemendai": "reemendar",
    "reemendais": "reemendar",
    "reemendam": "reemendar",
    "reemendamo": "reemendar",
    "reemendamos": "reemendar",
    "reemendando": "reemendar",
    "reemendara": "reemendar",
    "reemendaram": "reemendar",
    "reemendaras": "reemendar",
    "reemendarde": "reemendar",
    "reemendardes": "reemendar",
    "reemendare": "reemendar",
    "reemendarei": "reemendar",
    "reemendareis": "reemendar",
    "reemendarem": "reemendar",
    "reemendaremos": "reemendar",
    "reemendares": "reemendar",
    "reemendaria": "reemendar",
    "reemendariam": "reemendar",
    "reemendarias": "reemendar",
    "reemendarmo": "reemendar",
    "reemendarmos": "reemendar",
    "reemendará": "reemendar",
    "reemendarás": "reemendar",
    "reemendarão": "reemendar",
    "reemendaríamos": "reemendar",
    "reemendaríeis": "reemendar",
    "reemendas": "reemendar",
    "reemendasse": "reemendar",
    "reemendassem": "reemendar",
    "reemendasses": "reemendar",
    "reemendaste": "reemendar",
    "reemendastes": "reemendar",
    "reemendava": "reemendar",
    "reemendavam": "reemendar",
    "reemendavas": "reemendar",
    "reemende": "reemendar",
    "reemendei": "reemendar",
    "reemendeis": "reemendar",
    "reemendem": "reemendar",
    "reemendemo": "reemendar",
    "reemendemos": "reemendar",
    "reemendes": "reemendar",
    "reemendo": "reemendar",
    "reemendou": "reemendar",
    "reemendá": "reemendar",
    "reemendámo": "reemendar",
    "reemendámos": "reemendar",
    "reemendáramo": "reemendar",
    "reemendáramos": "reemendar",
    "reemendárei": "reemendar",
    "reemendáreis": "reemendar",
    "reemendásseis": "reemendar",
    "reemendássemos": "reemendar",
    "reemendávamo": "reemendar",
    "reemendávamos": "reemendar",
    "reemendávei": "reemendar",
    "reemendáveis": "reemendar",
    "reemerge": "reemergir",
    "reemergem": "reemergir",
    "reemerges": "reemergir",
    "reemergi": "reemergir",
    "reemergia": "reemergir",
    "reemergiam": "reemergir",
    "reemergias": "reemergir",
    "reemergida": "reemergir",
    "reemergidas": "reemergir",
    "reemergido": "reemergir",
    "reemergidos": "reemergir",
    "reemergimo": "reemergir",
    "reemergimos": "reemergir",
    "reemergindo": "reemergir",
    "reemergira": "reemergir",
    "reemergiram": "reemergir",
    "reemergiras": "reemergir",
    "reemergirde": "reemergir",
    "reemergirdes": "reemergir",
    "reemergire": "reemergir",
    "reemergirei": "reemergir",
    "reemergireis": "reemergir",
    "reemergirem": "reemergir",
    "reemergiremos": "reemergir",
    "reemergires": "reemergir",
    "reemergiria": "reemergir",
    "reemergiriam": "reemergir",
    "reemergirias": "reemergir",
    "reemergirmo": "reemergir",
    "reemergirmos": "reemergir",
    "reemergirá": "reemergir",
    "reemergirás": "reemergir",
    "reemergirão": "reemergir",
    "reemergiríamos": "reemergir",
    "reemergiríeis": "reemergir",
    "reemergis": "reemergir",
    "reemergisse": "reemergir",
    "reemergissem": "reemergir",
    "reemergisses": "reemergir",
    "reemergiste": "reemergir",
    "reemergistes": "reemergir",
    "reemergiu": "reemergir",
    "reemergíamo": "reemergir",
    "reemergíamos": "reemergir",
    "reemergíei": "reemergir",
    "reemergíeis": "reemergir",
    "reemergíramo": "reemergir",
    "reemergíramos": "reemergir",
    "reemergírei": "reemergir",
    "reemergíreis": "reemergir",
    "reemergísseis": "reemergir",
    "reemergíssemos": "reemergir",
    "reemigra": "reemigrar",
    "reemigrada": "reemigrar",
    "reemigradas": "reemigrar",
    "reemigrado": "reemigrar",
    "reemigrados": "reemigrar",
    "reemigrai": "reemigrar",
    "reemigrais": "reemigrar",
    "reemigram": "reemigrar",
    "reemigramo": "reemigrar",
    "reemigramos": "reemigrar",
    "reemigrando": "reemigrar",
    "reemigrara": "reemigrar",
    "reemigraram": "reemigrar",
    "reemigraras": "reemigrar",
    "reemigrardes": "reemigrar",
    "reemigrarei": "reemigrar",
    "reemigrareis": "reemigrar",
    "reemigrarem": "reemigrar",
    "reemigraremos": "reemigrar",
    "reemigrares": "reemigrar",
    "reemigraria": "reemigrar",
    "reemigrariam": "reemigrar",
    "reemigrarias": "reemigrar",
    "reemigrarmo": "reemigrar",
    "reemigrarmos": "reemigrar",
    "reemigrará": "reemigrar",
    "reemigrarás": "reemigrar",
    "reemigrarão": "reemigrar",
    "reemigraríamos": "reemigrar",
    "reemigraríeis": "reemigrar",
    "reemigras": "reemigrar",
    "reemigrasse": "reemigrar",
    "reemigrassem": "reemigrar",
    "reemigrasses": "reemigrar",
    "reemigraste": "reemigrar",
    "reemigrastes": "reemigrar",
    "reemigrava": "reemigrar",
    "reemigravam": "reemigrar",
    "reemigravas": "reemigrar",
    "reemigre": "reemigrar",
    "reemigrei": "reemigrar",
    "reemigreis": "reemigrar",
    "reemigrem": "reemigrar",
    "reemigremo": "reemigrar",
    "reemigremos": "reemigrar",
    "reemigres": "reemigrar",
    "reemigro": "reemigrar",
    "reemigrou": "reemigrar",
    "reemigrámo": "reemigrar",
    "reemigrámos": "reemigrar",
    "reemigráramo": "reemigrar",
    "reemigráramos": "reemigrar",
    "reemigráreis": "reemigrar",
    "reemigrásseis": "reemigrar",
    "reemigrássemos": "reemigrar",
    "reemigrávamo": "reemigrar",
    "reemigrávamos": "reemigrar",
    "reemigráveis": "reemigrar",
    "reemirja": "reemergir",
    "reemirjais": "reemergir",
    "reemirjam": "reemergir",
    "reemirjamo": "reemergir",
    "reemirjamos": "reemergir",
    "reemirjas": "reemergir",
    "reemirjo": "reemergir",
    "reempossa": "reempossar",
    "reempossada": "reempossar",
    "reempossadas": "reempossar",
    "reempossado": "reempossar",
    "reempossados": "reempossar",
    "reempossai": "reempossar",
    "reempossais": "reempossar",
    "reempossam": "reempossar",
    "reempossamo": "reempossar",
    "reempossamos": "reempossar",
    "reempossando": "reempossar",
    "reempossara": "reempossar",
    "reempossaram": "reempossar",
    "reempossaras": "reempossar",
    "reempossarde": "reempossar",
    "reempossardes": "reempossar",
    "reempossare": "reempossar",
    "reempossarei": "reempossar",
    "reempossareis": "reempossar",
    "reempossarem": "reempossar",
    "reempossaremos": "reempossar",
    "reempossares": "reempossar",
    "reempossaria": "reempossar",
    "reempossariam": "reempossar",
    "reempossarias": "reempossar",
    "reempossarmo": "reempossar",
    "reempossarmos": "reempossar",
    "reempossará": "reempossar",
    "reempossarás": "reempossar",
    "reempossarão": "reempossar",
    "reempossaríamos": "reempossar",
    "reempossaríeis": "reempossar",
    "reempossas": "reempossar",
    "reempossasse": "reempossar",
    "reempossassem": "reempossar",
    "reempossasses": "reempossar",
    "reempossaste": "reempossar",
    "reempossastes": "reempossar",
    "reempossava": "reempossar",
    "reempossavam": "reempossar",
    "reempossavas": "reempossar",
    "reemposse": "reempossar",
    "reempossei": "reempossar",
    "reemposseis": "reempossar",
    "reempossem": "reempossar",
    "reempossemo": "reempossar",
    "reempossemos": "reempossar",
    "reemposses": "reempossar",
    "reemposso": "reempossar",
    "reempossou": "reempossar",
    "reempossá": "reempossar",
    "reempossámo": "reempossar",
    "reempossámos": "reempossar",
    "reempossáramo": "reempossar",
    "reempossáramos": "reempossar",
    "reempossárei": "reempossar",
    "reempossáreis": "reempossar",
    "reempossásseis": "reempossar",
    "reempossássemos": "reempossar",
    "reempossávamo": "reempossar",
    "reempossávamos": "reempossar",
    "reempossávei": "reempossar",
    "reempossáveis": "reempossar",
    "reemprega": "reempregar",
    "reempregada": "reempregar",
    "reempregadas": "reempregar",
    "reempregado": "reempregar",
    "reempregados": "reempregar",
    "reempregai": "reempregar",
    "reempregais": "reempregar",
    "reempregam": "reempregar",
    "reempregamo": "reempregar",
    "reempregamos": "reempregar",
    "reempregando": "reempregar",
    "reempregara": "reempregar",
    "reempregaram": "reempregar",
    "reempregaras": "reempregar",
    "reempregarde": "reempregar",
    "reempregardes": "reempregar",
    "reempregare": "reempregar",
    "reempregarei": "reempregar",
    "reempregareis": "reempregar",
    "reempregarem": "reempregar",
    "reempregaremos": "reempregar",
    "reempregares": "reempregar",
    "reempregaria": "reempregar",
    "reempregariam": "reempregar",
    "reempregarias": "reempregar",
    "reempregarmo": "reempregar",
    "reempregarmos": "reempregar",
    "reempregará": "reempregar",
    "reempregarás": "reempregar",
    "reempregarão": "reempregar",
    "reempregaríamos": "reempregar",
    "reempregaríeis": "reempregar",
    "reempregas": "reempregar",
    "reempregasse": "reempregar",
    "reempregassem": "reempregar",
    "reempregasses": "reempregar",
    "reempregaste": "reempregar",
    "reempregastes": "reempregar",
    "reempregava": "reempregar",
    "reempregavam": "reempregar",
    "reempregavas": "reempregar",
    "reemprego": "reempregar",
    "reempregou": "reempregar",
    "reempregue": "reempregar",
    "reempreguei": "reempregar",
    "reempregueis": "reempregar",
    "reempreguem": "reempregar",
    "reempreguemo": "reempregar",
    "reempreguemos": "reempregar",
    "reempregues": "reempregar",
    "reempregá": "reempregar",
    "reempregámo": "reempregar",
    "reempregámos": "reempregar",
    "reempregáramo": "reempregar",
    "reempregáramos": "reempregar",
    "reempregárei": "reempregar",
    "reempregáreis": "reempregar",
    "reempregásseis": "reempregar",
    "reempregássemos": "reempregar",
    "reempregávamo": "reempregar",
    "reempregávamos": "reempregar",
    "reempregávei": "reempregar",
    "reempregáveis": "reempregar",
    "reencaixa": "reencaixar",
    "reencaixada": "reencaixar",
    "reencaixadas": "reencaixar",
    "reencaixado": "reencaixar",
    "reencaixados": "reencaixar",
    "reencaixai": "reencaixar",
    "reencaixais": "reencaixar",
    "reencaixam": "reencaixar",
    "reencaixamo": "reencaixar",
    "reencaixamos": "reencaixar",
    "reencaixando": "reencaixar",
    "reencaixara": "reencaixar",
    "reencaixaram": "reencaixar",
    "reencaixaras": "reencaixar",
    "reencaixarde": "reencaixar",
    "reencaixardes": "reencaixar",
    "reencaixare": "reencaixar",
    "reencaixarei": "reencaixar",
    "reencaixareis": "reencaixar",
    "reencaixarem": "reencaixar",
    "reencaixaremos": "reencaixar",
    "reencaixares": "reencaixar",
    "reencaixaria": "reencaixar",
    "reencaixariam": "reencaixar",
    "reencaixarias": "reencaixar",
    "reencaixarmo": "reencaixar",
    "reencaixarmos": "reencaixar",
    "reencaixará": "reencaixar",
    "reencaixarás": "reencaixar",
    "reencaixarão": "reencaixar",
    "reencaixaríamos": "reencaixar",
    "reencaixaríeis": "reencaixar",
    "reencaixas": "reencaixar",
    "reencaixasse": "reencaixar",
    "reencaixassem": "reencaixar",
    "reencaixasses": "reencaixar",
    "reencaixaste": "reencaixar",
    "reencaixastes": "reencaixar",
    "reencaixava": "reencaixar",
    "reencaixavam": "reencaixar",
    "reencaixavas": "reencaixar",
    "reencaixe": "reencaixar",
    "reencaixei": "reencaixar",
    "reencaixeis": "reencaixar",
    "reencaixem": "reencaixar",
    "reencaixemo": "reencaixar",
    "reencaixemos": "reencaixar",
    "reencaixes": "reencaixar",
    "reencaixo": "reencaixar",
    "reencaixou": "reencaixar",
    "reencaixá": "reencaixar",
    "reencaixámo": "reencaixar",
    "reencaixámos": "reencaixar",
    "reencaixáramo": "reencaixar",
    "reencaixáramos": "reencaixar",
    "reencaixárei": "reencaixar",
    "reencaixáreis": "reencaixar",
    "reencaixásseis": "reencaixar",
    "reencaixássemos": "reencaixar",
    "reencaixávamo": "reencaixar",
    "reencaixávamos": "reencaixar",
    "reencaixávei": "reencaixar",
    "reencaixáveis": "reencaixar",
    "reencarcera": "reencarcerar",
    "reencarcerada": "reencarcerar",
    "reencarceradas": "reencarcerar",
    "reencarcerado": "reencarcerar",
    "reencarcerados": "reencarcerar",
    "reencarcerai": "reencarcerar",
    "reencarcerais": "reencarcerar",
    "reencarceram": "reencarcerar",
    "reencarceramo": "reencarcerar",
    "reencarceramos": "reencarcerar",
    "reencarcerando": "reencarcerar",
    "reencarcerara": "reencarcerar",
    "reencarceraram": "reencarcerar",
    "reencarceraras": "reencarcerar",
    "reencarcerarde": "reencarcerar",
    "reencarcerardes": "reencarcerar",
    "reencarcerare": "reencarcerar",
    "reencarcerarei": "reencarcerar",
    "reencarcerareis": "reencarcerar",
    "reencarcerarem": "reencarcerar",
    "reencarceraremos": "reencarcerar",
    "reencarcerares": "reencarcerar",
    "reencarceraria": "reencarcerar",
    "reencarcerariam": "reencarcerar",
    "reencarcerarias": "reencarcerar",
    "reencarcerarmo": "reencarcerar",
    "reencarcerarmos": "reencarcerar",
    "reencarcerará": "reencarcerar",
    "reencarcerarás": "reencarcerar",
    "reencarcerarão": "reencarcerar",
    "reencarceraríamos": "reencarcerar",
    "reencarceraríeis": "reencarcerar",
    "reencarceras": "reencarcerar",
    "reencarcerasse": "reencarcerar",
    "reencarcerassem": "reencarcerar",
    "reencarcerasses": "reencarcerar",
    "reencarceraste": "reencarcerar",
    "reencarcerastes": "reencarcerar",
    "reencarcerava": "reencarcerar",
    "reencarceravam": "reencarcerar",
    "reencarceravas": "reencarcerar",
    "reencarcere": "reencarcerar",
    "reencarcerei": "reencarcerar",
    "reencarcereis": "reencarcerar",
    "reencarcerem": "reencarcerar",
    "reencarceremo": "reencarcerar",
    "reencarceremos": "reencarcerar",
    "reencarceres": "reencarcerar",
    "reencarcero": "reencarcerar",
    "reencarcerou": "reencarcerar",
    "reencarcerá": "reencarcerar",
    "reencarcerámo": "reencarcerar",
    "reencarcerámos": "reencarcerar",
    "reencarceráramo": "reencarcerar",
    "reencarceráramos": "reencarcerar",
    "reencarcerárei": "reencarcerar",
    "reencarceráreis": "reencarcerar",
    "reencarcerásseis": "reencarcerar",
    "reencarcerássemos": "reencarcerar",
    "reencarcerávamo": "reencarcerar",
    "reencarcerávamos": "reencarcerar",
    "reencarcerávei": "reencarcerar",
    "reencarceráveis": "reencarcerar",
    "reencarna": "reencarnar",
    "reencarnacionistas": "reencarnacionista",
    "reencarnada": "reencarnar",
    "reencarnadas": "reencarnar",
    "reencarnado": "reencarnar",
    "reencarnados": "reencarnar",
    "reencarnai": "reencarnar",
    "reencarnais": "reencarnar",
    "reencarnam": "reencarnar",
    "reencarnamo": "reencarnar",
    "reencarnamos": "reencarnar",
    "reencarnando": "reencarnar",
    "reencarnara": "reencarnar",
    "reencarnaram": "reencarnar",
    "reencarnaras": "reencarnar",
    "reencarnardes": "reencarnar",
    "reencarnarei": "reencarnar",
    "reencarnareis": "reencarnar",
    "reencarnarem": "reencarnar",
    "reencarnaremos": "reencarnar",
    "reencarnares": "reencarnar",
    "reencarnaria": "reencarnar",
    "reencarnariam": "reencarnar",
    "reencarnarias": "reencarnar",
    "reencarnarmo": "reencarnar",
    "reencarnarmos": "reencarnar",
    "reencarnará": "reencarnar",
    "reencarnarás": "reencarnar",
    "reencarnarão": "reencarnar",
    "reencarnaríamos": "reencarnar",
    "reencarnaríeis": "reencarnar",
    "reencarnas": "reencarnar",
    "reencarnasse": "reencarnar",
    "reencarnassem": "reencarnar",
    "reencarnasses": "reencarnar",
    "reencarnaste": "reencarnar",
    "reencarnastes": "reencarnar",
    "reencarnava": "reencarnar",
    "reencarnavam": "reencarnar",
    "reencarnavas": "reencarnar",
    "reencarnações": "reencarnação",
    "reencarne": "reencarnar",
    "reencarnei": "reencarnar",
    "reencarneis": "reencarnar",
    "reencarnem": "reencarnar",
    "reencarnemo": "reencarnar",
    "reencarnemos": "reencarnar",
    "reencarnes": "reencarnar",
    "reencarno": "reencarnar",
    "reencarnou": "reencarnar",
    "reencarnámo": "reencarnar",
    "reencarnámos": "reencarnar",
    "reencarnáramo": "reencarnar",
    "reencarnáramos": "reencarnar",
    "reencarnáreis": "reencarnar",
    "reencarnásseis": "reencarnar",
    "reencarnássemos": "reencarnar",
    "reencarnávamo": "reencarnar",
    "reencarnávamos": "reencarnar",
    "reencarnáveis": "reencarnar",
    "reencena": "reencenar",
    "reencenada": "reencenar",
    "reencenadas": "reencenar",
    "reencenado": "reencenar",
    "reencenados": "reencenar",
    "reencenai": "reencenar",
    "reencenais": "reencenar",
    "reencenam": "reencenar",
    "reencenamo": "reencenar",
    "reencenamos": "reencenar",
    "reencenando": "reencenar",
    "reencenara": "reencenar",
    "reencenaram": "reencenar",
    "reencenaras": "reencenar",
    "reencenarde": "reencenar",
    "reencenardes": "reencenar",
    "reencenare": "reencenar",
    "reencenarei": "reencenar",
    "reencenareis": "reencenar",
    "reencenarem": "reencenar",
    "reencenaremos": "reencenar",
    "reencenares": "reencenar",
    "reencenaria": "reencenar",
    "reencenariam": "reencenar",
    "reencenarias": "reencenar",
    "reencenarmo": "reencenar",
    "reencenarmos": "reencenar",
    "reencenará": "reencenar",
    "reencenarás": "reencenar",
    "reencenarão": "reencenar",
    "reencenaríamos": "reencenar",
    "reencenaríeis": "reencenar",
    "reencenas": "reencenar",
    "reencenasse": "reencenar",
    "reencenassem": "reencenar",
    "reencenasses": "reencenar",
    "reencenaste": "reencenar",
    "reencenastes": "reencenar",
    "reencenava": "reencenar",
    "reencenavam": "reencenar",
    "reencenavas": "reencenar",
    "reencene": "reencenar",
    "reencenei": "reencenar",
    "reenceneis": "reencenar",
    "reencenem": "reencenar",
    "reencenemo": "reencenar",
    "reencenemos": "reencenar",
    "reencenes": "reencenar",
    "reenceno": "reencenar",
    "reencenou": "reencenar",
    "reencená": "reencenar",
    "reencenámo": "reencenar",
    "reencenámos": "reencenar",
    "reencenáramo": "reencenar",
    "reencenáramos": "reencenar",
    "reencenárei": "reencenar",
    "reencenáreis": "reencenar",
    "reencenásseis": "reencenar",
    "reencenássemos": "reencenar",
    "reencenávamo": "reencenar",
    "reencenávamos": "reencenar",
    "reencenávei": "reencenar",
    "reencenáveis": "reencenar",
    "reenceta": "reencetar",
    "reencetada": "reencetar",
    "reencetadas": "reencetar",
    "reencetado": "reencetar",
    "reencetados": "reencetar",
    "reencetai": "reencetar",
    "reencetais": "reencetar",
    "reencetam": "reencetar",
    "reencetamo": "reencetar",
    "reencetamos": "reencetar",
    "reencetando": "reencetar",
    "reencetara": "reencetar",
    "reencetaram": "reencetar",
    "reencetaras": "reencetar",
    "reencetarde": "reencetar",
    "reencetardes": "reencetar",
    "reencetare": "reencetar",
    "reencetarei": "reencetar",
    "reencetareis": "reencetar",
    "reencetarem": "reencetar",
    "reencetaremos": "reencetar",
    "reencetares": "reencetar",
    "reencetaria": "reencetar",
    "reencetariam": "reencetar",
    "reencetarias": "reencetar",
    "reencetarmo": "reencetar",
    "reencetarmos": "reencetar",
    "reencetará": "reencetar",
    "reencetarás": "reencetar",
    "reencetarão": "reencetar",
    "reencetaríamos": "reencetar",
    "reencetaríeis": "reencetar",
    "reencetas": "reencetar",
    "reencetasse": "reencetar",
    "reencetassem": "reencetar",
    "reencetasses": "reencetar",
    "reencetaste": "reencetar",
    "reencetastes": "reencetar",
    "reencetava": "reencetar",
    "reencetavam": "reencetar",
    "reencetavas": "reencetar",
    "reencete": "reencetar",
    "reencetei": "reencetar",
    "reenceteis": "reencetar",
    "reencetem": "reencetar",
    "reencetemo": "reencetar",
    "reencetemos": "reencetar",
    "reencetes": "reencetar",
    "reenceto": "reencetar",
    "reencetou": "reencetar",
    "reencetá": "reencetar",
    "reencetámo": "reencetar",
    "reencetámos": "reencetar",
    "reencetáramo": "reencetar",
    "reencetáramos": "reencetar",
    "reencetárei": "reencetar",
    "reencetáreis": "reencetar",
    "reencetásseis": "reencetar",
    "reencetássemos": "reencetar",
    "reencetávamo": "reencetar",
    "reencetávamos": "reencetar",
    "reencetávei": "reencetar",
    "reencetáveis": "reencetar",
    "reencha": "reencher",
    "reenchais": "reencher",
    "reencham": "reencher",
    "reenchamo": "reencher",
    "reenchamos": "reencher",
    "reenchas": "reencher",
    "reenche": "reencher",
    "reenchei": "reencher",
    "reencheis": "reencher",
    "reenchem": "reencher",
    "reenchemo": "reencher",
    "reenchemos": "reencher",
    "reenchendo": "reencher",
    "reenchera": "reencher",
    "reencheram": "reencher",
    "reencheras": "reencher",
    "reencherde": "reencher",
    "reencherdes": "reencher",
    "reenchere": "reencher",
    "reencherei": "reencher",
    "reenchereis": "reencher",
    "reencherem": "reencher",
    "reencheremos": "reencher",
    "reencheres": "reencher",
    "reencheria": "reencher",
    "reencheriam": "reencher",
    "reencherias": "reencher",
    "reenchermo": "reencher",
    "reenchermos": "reencher",
    "reencherá": "reencher",
    "reencherás": "reencher",
    "reencherão": "reencher",
    "reencheríamos": "reencher",
    "reencheríeis": "reencher",
    "reenches": "reencher",
    "reenchesse": "reencher",
    "reenchessem": "reencher",
    "reenchesses": "reencher",
    "reencheste": "reencher",
    "reenchestes": "reencher",
    "reencheu": "reencher",
    "reenchi": "reencher",
    "reenchia": "reencher",
    "reenchiam": "reencher",
    "reenchias": "reencher",
    "reenchida": "reencher",
    "reenchidas": "reencher",
    "reenchido": "reencher",
    "reenchidos": "reencher",
    "reenchimentos": "reenchimento",
    "reencho": "reencher",
    "reenchê": "reencher",
    "reenchêramo": "reencher",
    "reenchêramos": "reencher",
    "reenchêrei": "reencher",
    "reenchêreis": "reencher",
    "reenchêsseis": "reencher",
    "reenchêssemos": "reencher",
    "reenchíamo": "reencher",
    "reenchíamos": "reencher",
    "reenchíei": "reencher",
    "reenchíeis": "reencher",
    "reencontra": "reencontrar",
    "reencontrada": "reencontrar",
    "reencontradas": "reencontrar",
    "reencontrado": "reencontrar",
    "reencontrados": "reencontrar",
    "reencontrai": "reencontrar",
    "reencontrais": "reencontrar",
    "reencontram": "reencontrar",
    "reencontramo": "reencontrar",
    "reencontramos": "reencontrar",
    "reencontrando": "reencontrar",
    "reencontrara": "reencontrar",
    "reencontraram": "reencontrar",
    "reencontraras": "reencontrar",
    "reencontrarde": "reencontrar",
    "reencontrardes": "reencontrar",
    "reencontrare": "reencontrar",
    "reencontrarei": "reencontrar",
    "reencontrareis": "reencontrar",
    "reencontrarem": "reencontrar",
    "reencontraremos": "reencontrar",
    "reencontrares": "reencontrar",
    "reencontraria": "reencontrar",
    "reencontrariam": "reencontrar",
    "reencontrarias": "reencontrar",
    "reencontrarmo": "reencontrar",
    "reencontrarmos": "reencontrar",
    "reencontrará": "reencontrar",
    "reencontrarás": "reencontrar",
    "reencontrarão": "reencontrar",
    "reencontraríamos": "reencontrar",
    "reencontraríeis": "reencontrar",
    "reencontras": "reencontrar",
    "reencontrasse": "reencontrar",
    "reencontrassem": "reencontrar",
    "reencontrasses": "reencontrar",
    "reencontraste": "reencontrar",
    "reencontrastes": "reencontrar",
    "reencontrava": "reencontrar",
    "reencontravam": "reencontrar",
    "reencontravas": "reencontrar",
    "reencontre": "reencontrar",
    "reencontrei": "reencontrar",
    "reencontreis": "reencontrar",
    "reencontrem": "reencontrar",
    "reencontremo": "reencontrar",
    "reencontremos": "reencontrar",
    "reencontres": "reencontrar",
    "reencontro": "reencontrar",
    "reencontros": "reencontro",
    "reencontrou": "reencontrar",
    "reencontrá": "reencontrar",
    "reencontrámo": "reencontrar",
    "reencontrámos": "reencontrar",
    "reencontráramo": "reencontrar",
    "reencontráramos": "reencontrar",
    "reencontrárei": "reencontrar",
    "reencontráreis": "reencontrar",
    "reencontrásseis": "reencontrar",
    "reencontrássemos": "reencontrar",
    "reencontrávamo": "reencontrar",
    "reencontrávamos": "reencontrar",
    "reencontrávei": "reencontrar",
    "reencontráveis": "reencontrar",
    "reendereçamentos": "reendereçamento",
    "reendireita": "reendireitar",
    "reendireitada": "reendireitar",
    "reendireitadas": "reendireitar",
    "reendireitado": "reendireitar",
    "reendireitados": "reendireitar",
    "reendireitai": "reendireitar",
    "reendireitais": "reendireitar",
    "reendireitam": "reendireitar",
    "reendireitamo": "reendireitar",
    "reendireitamos": "reendireitar",
    "reendireitando": "reendireitar",
    "reendireitara": "reendireitar",
    "reendireitaram": "reendireitar",
    "reendireitaras": "reendireitar",
    "reendireitarde": "reendireitar",
    "reendireitardes": "reendireitar",
    "reendireitare": "reendireitar",
    "reendireitarei": "reendireitar",
    "reendireitareis": "reendireitar",
    "reendireitarem": "reendireitar",
    "reendireitaremos": "reendireitar",
    "reendireitares": "reendireitar",
    "reendireitaria": "reendireitar",
    "reendireitariam": "reendireitar",
    "reendireitarias": "reendireitar",
    "reendireitarmo": "reendireitar",
    "reendireitarmos": "reendireitar",
    "reendireitará": "reendireitar",
    "reendireitarás": "reendireitar",
    "reendireitarão": "reendireitar",
    "reendireitaríamos": "reendireitar",
    "reendireitaríeis": "reendireitar",
    "reendireitas": "reendireitar",
    "reendireitasse": "reendireitar",
    "reendireitassem": "reendireitar",
    "reendireitasses": "reendireitar",
    "reendireitaste": "reendireitar",
    "reendireitastes": "reendireitar",
    "reendireitava": "reendireitar",
    "reendireitavam": "reendireitar",
    "reendireitavas": "reendireitar",
    "reendireite": "reendireitar",
    "reendireitei": "reendireitar",
    "reendireiteis": "reendireitar",
    "reendireitem": "reendireitar",
    "reendireitemo": "reendireitar",
    "reendireitemos": "reendireitar",
    "reendireites": "reendireitar",
    "reendireito": "reendireitar",
    "reendireitou": "reendireitar",
    "reendireitá": "reendireitar",
    "reendireitámo": "reendireitar",
    "reendireitámos": "reendireitar",
    "reendireitáramo": "reendireitar",
    "reendireitáramos": "reendireitar",
    "reendireitárei": "reendireitar",
    "reendireitáreis": "reendireitar",
    "reendireitásseis": "reendireitar",
    "reendireitássemos": "reendireitar",
    "reendireitávamo": "reendireitar",
    "reendireitávamos": "reendireitar",
    "reendireitávei": "reendireitar",
    "reendireitáveis": "reendireitar",
    "reendossos": "reendosso",
    "reenfia": "reenfiar",
    "reenfiada": "reenfiar",
    "reenfiadas": "reenfiar",
    "reenfiado": "reenfiar",
    "reenfiados": "reenfiar",
    "reenfiai": "reenfiar",
    "reenfiais": "reenfiar",
    "reenfiam": "reenfiar",
    "reenfiamo": "reenfiar",
    "reenfiamos": "reenfiar",
    "reenfiando": "reenfiar",
    "reenfiara": "reenfiar",
    "reenfiaram": "reenfiar",
    "reenfiaras": "reenfiar",
    "reenfiarde": "reenfiar",
    "reenfiardes": "reenfiar",
    "reenfiare": "reenfiar",
    "reenfiarei": "reenfiar",
    "reenfiareis": "reenfiar",
    "reenfiarem": "reenfiar",
    "reenfiaremos": "reenfiar",
    "reenfiares": "reenfiar",
    "reenfiaria": "reenfiar",
    "reenfiariam": "reenfiar",
    "reenfiarias": "reenfiar",
    "reenfiarmo": "reenfiar",
    "reenfiarmos": "reenfiar",
    "reenfiará": "reenfiar",
    "reenfiarás": "reenfiar",
    "reenfiarão": "reenfiar",
    "reenfiaríamos": "reenfiar",
    "reenfiaríeis": "reenfiar",
    "reenfias": "reenfiar",
    "reenfiasse": "reenfiar",
    "reenfiassem": "reenfiar",
    "reenfiasses": "reenfiar",
    "reenfiaste": "reenfiar",
    "reenfiastes": "reenfiar",
    "reenfiava": "reenfiar",
    "reenfiavam": "reenfiar",
    "reenfiavas": "reenfiar",
    "reenfie": "reenfiar",
    "reenfiei": "reenfiar",
    "reenfieis": "reenfiar",
    "reenfiem": "reenfiar",
    "reenfiemo": "reenfiar",
    "reenfiemos": "reenfiar",
    "reenfies": "reenfiar",
    "reenfio": "reenfiar",
    "reenfiou": "reenfiar",
    "reenfiá": "reenfiar",
    "reenfiámo": "reenfiar",
    "reenfiámos": "reenfiar",
    "reenfiáramo": "reenfiar",
    "reenfiáramos": "reenfiar",
    "reenfiárei": "reenfiar",
    "reenfiáreis": "reenfiar",
    "reenfiásseis": "reenfiar",
    "reenfiássemos": "reenfiar",
    "reenfiávamo": "reenfiar",
    "reenfiávamos": "reenfiar",
    "reenfiávei": "reenfiar",
    "reenfiáveis": "reenfiar",
    "reenlaces": "reenlace",
    "reensina": "reensinar",
    "reensinada": "reensinar",
    "reensinadas": "reensinar",
    "reensinado": "reensinar",
    "reensinados": "reensinar",
    "reensinai": "reensinar",
    "reensinais": "reensinar",
    "reensinam": "reensinar",
    "reensinamo": "reensinar",
    "reensinamos": "reensinar",
    "reensinando": "reensinar",
    "reensinara": "reensinar",
    "reensinaram": "reensinar",
    "reensinaras": "reensinar",
    "reensinarde": "reensinar",
    "reensinardes": "reensinar",
    "reensinare": "reensinar",
    "reensinarei": "reensinar",
    "reensinareis": "reensinar",
    "reensinarem": "reensinar",
    "reensinaremos": "reensinar",
    "reensinares": "reensinar",
    "reensinaria": "reensinar",
    "reensinariam": "reensinar",
    "reensinarias": "reensinar",
    "reensinarmo": "reensinar",
    "reensinarmos": "reensinar",
    "reensinará": "reensinar",
    "reensinarás": "reensinar",
    "reensinarão": "reensinar",
    "reensinaríamos": "reensinar",
    "reensinaríeis": "reensinar",
    "reensinas": "reensinar",
    "reensinasse": "reensinar",
    "reensinassem": "reensinar",
    "reensinasses": "reensinar",
    "reensinaste": "reensinar",
    "reensinastes": "reensinar",
    "reensinava": "reensinar",
    "reensinavam": "reensinar",
    "reensinavas": "reensinar",
    "reensine": "reensinar",
    "reensinei": "reensinar",
    "reensineis": "reensinar",
    "reensinem": "reensinar",
    "reensinemo": "reensinar",
    "reensinemos": "reensinar",
    "reensines": "reensinar",
    "reensino": "reensinar",
    "reensinou": "reensinar",
    "reensiná": "reensinar",
    "reensinámo": "reensinar",
    "reensinámos": "reensinar",
    "reensináramo": "reensinar",
    "reensináramos": "reensinar",
    "reensinárei": "reensinar",
    "reensináreis": "reensinar",
    "reensinásseis": "reensinar",
    "reensinássemos": "reensinar",
    "reensinávamo": "reensinar",
    "reensinávamos": "reensinar",
    "reensinávei": "reensinar",
    "reensináveis": "reensinar",
    "reentra": "reentrar",
    "reentrada": "reentrar",
    "reentradas": "reentrar",
    "reentrado": "reentrar",
    "reentrados": "reentrar",
    "reentrai": "reentrar",
    "reentrais": "reentrar",
    "reentram": "reentrar",
    "reentramo": "reentrar",
    "reentramos": "reentrar",
    "reentrando": "reentrar",
    "reentrantes": "reentrante",
    "reentrara": "reentrar",
    "reentraram": "reentrar",
    "reentraras": "reentrar",
    "reentrardes": "reentrar",
    "reentrarei": "reentrar",
    "reentrareis": "reentrar",
    "reentrarem": "reentrar",
    "reentraremos": "reentrar",
    "reentrares": "reentrar",
    "reentraria": "reentrar",
    "reentrariam": "reentrar",
    "reentrarias": "reentrar",
    "reentrarmo": "reentrar",
    "reentrarmos": "reentrar",
    "reentrará": "reentrar",
    "reentrarás": "reentrar",
    "reentrarão": "reentrar",
    "reentraríamos": "reentrar",
    "reentraríeis": "reentrar",
    "reentras": "reentrar",
    "reentrasse": "reentrar",
    "reentrassem": "reentrar",
    "reentrasses": "reentrar",
    "reentraste": "reentrar",
    "reentrastes": "reentrar",
    "reentrava": "reentrar",
    "reentravam": "reentrar",
    "reentravas": "reentrar",
    "reentre": "reentrar",
    "reentrega": "reentregar",
    "reentregada": "reentregar",
    "reentregadas": "reentregar",
    "reentregado": "reentregar",
    "reentregados": "reentregar",
    "reentregai": "reentregar",
    "reentregais": "reentregar",
    "reentregam": "reentregar",
    "reentregamo": "reentregar",
    "reentregamos": "reentregar",
    "reentregando": "reentregar",
    "reentregara": "reentregar",
    "reentregaram": "reentregar",
    "reentregaras": "reentregar",
    "reentregarde": "reentregar",
    "reentregardes": "reentregar",
    "reentregare": "reentregar",
    "reentregarei": "reentregar",
    "reentregareis": "reentregar",
    "reentregarem": "reentregar",
    "reentregaremos": "reentregar",
    "reentregares": "reentregar",
    "reentregaria": "reentregar",
    "reentregariam": "reentregar",
    "reentregarias": "reentregar",
    "reentregarmo": "reentregar",
    "reentregarmos": "reentregar",
    "reentregará": "reentregar",
    "reentregarás": "reentregar",
    "reentregarão": "reentregar",
    "reentregaríamos": "reentregar",
    "reentregaríeis": "reentregar",
    "reentregas": "reentregar",
    "reentregasse": "reentregar",
    "reentregassem": "reentregar",
    "reentregasses": "reentregar",
    "reentregaste": "reentregar",
    "reentregastes": "reentregar",
    "reentregava": "reentregar",
    "reentregavam": "reentregar",
    "reentregavas": "reentregar",
    "reentrego": "reentregar",
    "reentregou": "reentregar",
    "reentregue": "reentregar",
    "reentreguei": "reentregar",
    "reentregueis": "reentregar",
    "reentreguem": "reentregar",
    "reentreguemo": "reentregar",
    "reentreguemos": "reentregar",
    "reentregues": "reentregar",
    "reentregá": "reentregar",
    "reentregámo": "reentregar",
    "reentregámos": "reentregar",
    "reentregáramo": "reentregar",
    "reentregáramos": "reentregar",
    "reentregárei": "reentregar",
    "reentregáreis": "reentregar",
    "reentregásseis": "reentregar",
    "reentregássemos": "reentregar",
    "reentregávamo": "reentregar",
    "reentregávamos": "reentregar",
    "reentregávei": "reentregar",
    "reentregáveis": "reentregar",
    "reentrei": "reentrar",
    "reentreis": "reentrar",
    "reentrem": "reentrar",
    "reentremo": "reentrar",
    "reentremos": "reentrar",
    "reentres": "reentrar",
    "reentro": "reentrar",
    "reentrou": "reentrar",
    "reentrámo": "reentrar",
    "reentrámos": "reentrar",
    "reentráramo": "reentrar",
    "reentráramos": "reentrar",
    "reentráreis": "reentrar",
    "reentrásseis": "reentrar",
    "reentrássemos": "reentrar",
    "reentrávamo": "reentrar",
    "reentrávamos": "reentrar",
    "reentráveis": "reentrar",
    "reentrâncias": "reentrância",
    "reenvia": "reenviar",
    "reenviada": "reenviar",
    "reenviadas": "reenviar",
    "reenviado": "reenviar",
    "reenviados": "reenviar",
    "reenviai": "reenviar",
    "reenviais": "reenviar",
    "reenviam": "reenviar",
    "reenviamo": "reenviar",
    "reenviamos": "reenviar",
    "reenviando": "reenviar",
    "reenviara": "reenviar",
    "reenviaram": "reenviar",
    "reenviaras": "reenviar",
    "reenviarde": "reenviar",
    "reenviardes": "reenviar",
    "reenviare": "reenviar",
    "reenviarei": "reenviar",
    "reenviareis": "reenviar",
    "reenviarem": "reenviar",
    "reenviaremos": "reenviar",
    "reenviares": "reenviar",
    "reenviaria": "reenviar",
    "reenviariam": "reenviar",
    "reenviarias": "reenviar",
    "reenviarmo": "reenviar",
    "reenviarmos": "reenviar",
    "reenviará": "reenviar",
    "reenviarás": "reenviar",
    "reenviarão": "reenviar",
    "reenviaríamos": "reenviar",
    "reenviaríeis": "reenviar",
    "reenvias": "reenviar",
    "reenviasse": "reenviar",
    "reenviassem": "reenviar",
    "reenviasses": "reenviar",
    "reenviaste": "reenviar",
    "reenviastes": "reenviar",
    "reenviava": "reenviar",
    "reenviavam": "reenviar",
    "reenviavas": "reenviar",
    "reenvida": "reenvidar",
    "reenvidada": "reenvidar",
    "reenvidadas": "reenvidar",
    "reenvidado": "reenvidar",
    "reenvidados": "reenvidar",
    "reenvidai": "reenvidar",
    "reenvidais": "reenvidar",
    "reenvidam": "reenvidar",
    "reenvidamo": "reenvidar",
    "reenvidamos": "reenvidar",
    "reenvidando": "reenvidar",
    "reenvidara": "reenvidar",
    "reenvidaram": "reenvidar",
    "reenvidaras": "reenvidar",
    "reenvidarde": "reenvidar",
    "reenvidardes": "reenvidar",
    "reenvidare": "reenvidar",
    "reenvidarei": "reenvidar",
    "reenvidareis": "reenvidar",
    "reenvidarem": "reenvidar",
    "reenvidaremos": "reenvidar",
    "reenvidares": "reenvidar",
    "reenvidaria": "reenvidar",
    "reenvidariam": "reenvidar",
    "reenvidarias": "reenvidar",
    "reenvidarmo": "reenvidar",
    "reenvidarmos": "reenvidar",
    "reenvidará": "reenvidar",
    "reenvidarás": "reenvidar",
    "reenvidarão": "reenvidar",
    "reenvidaríamos": "reenvidar",
    "reenvidaríeis": "reenvidar",
    "reenvidas": "reenvidar",
    "reenvidasse": "reenvidar",
    "reenvidassem": "reenvidar",
    "reenvidasses": "reenvidar",
    "reenvidaste": "reenvidar",
    "reenvidastes": "reenvidar",
    "reenvidava": "reenvidar",
    "reenvidavam": "reenvidar",
    "reenvidavas": "reenvidar",
    "reenvide": "reenvidar",
    "reenvidei": "reenvidar",
    "reenvideis": "reenvidar",
    "reenvidem": "reenvidar",
    "reenvidemo": "reenvidar",
    "reenvidemos": "reenvidar",
    "reenvides": "reenvidar",
    "reenvido": "reenvidar",
    "reenvidou": "reenvidar",
    "reenvidá": "reenvidar",
    "reenvidámo": "reenvidar",
    "reenvidámos": "reenvidar",
    "reenvidáramo": "reenvidar",
    "reenvidáramos": "reenvidar",
    "reenvidárei": "reenvidar",
    "reenvidáreis": "reenvidar",
    "reenvidásseis": "reenvidar",
    "reenvidássemos": "reenvidar",
    "reenvidávamo": "reenvidar",
    "reenvidávamos": "reenvidar",
    "reenvidávei": "reenvidar",
    "reenvidáveis": "reenvidar",
    "reenvie": "reenviar",
    "reenviei": "reenviar",
    "reenvieis": "reenviar",
    "reenviem": "reenviar",
    "reenviemo": "reenviar",
    "reenviemos": "reenviar",
    "reenvies": "reenviar",
    "reenvio": "reenviar",
    "reenvios": "reenvio",
    "reenviou": "reenviar",
    "reenviá": "reenviar",
    "reenviámo": "reenviar",
    "reenviámos": "reenviar",
    "reenviáramo": "reenviar",
    "reenviáramos": "reenviar",
    "reenviárei": "reenviar",
    "reenviáreis": "reenviar",
    "reenviásseis": "reenviar",
    "reenviássemos": "reenviar",
    "reenviávamo": "reenviar",
    "reenviávamos": "reenviar",
    "reenviávei": "reenviar",
    "reenviáveis": "reenviável",
    "reequaciona": "reequacionar",
    "reequacionada": "reequacionar",
    "reequacionadas": "reequacionar",
    "reequacionado": "reequacionar",
    "reequacionados": "reequacionar",
    "reequacionai": "reequacionar",
    "reequacionais": "reequacionar",
    "reequacionam": "reequacionar",
    "reequacionamentos": "reequacionamento",
    "reequacionamo": "reequacionar",
    "reequacionamos": "reequacionar",
    "reequacionando": "reequacionar",
    "reequacionara": "reequacionar",
    "reequacionaram": "reequacionar",
    "reequacionaras": "reequacionar",
    "reequacionarde": "reequacionar",
    "reequacionardes": "reequacionar",
    "reequacionare": "reequacionar",
    "reequacionarei": "reequacionar",
    "reequacionareis": "reequacionar",
    "reequacionarem": "reequacionar",
    "reequacionaremos": "reequacionar",
    "reequacionares": "reequacionar",
    "reequacionaria": "reequacionar",
    "reequacionariam": "reequacionar",
    "reequacionarias": "reequacionar",
    "reequacionarmo": "reequacionar",
    "reequacionarmos": "reequacionar",
    "reequacionará": "reequacionar",
    "reequacionarás": "reequacionar",
    "reequacionarão": "reequacionar",
    "reequacionaríamos": "reequacionar",
    "reequacionaríeis": "reequacionar",
    "reequacionas": "reequacionar",
    "reequacionasse": "reequacionar",
    "reequacionassem": "reequacionar",
    "reequacionasses": "reequacionar",
    "reequacionaste": "reequacionar",
    "reequacionastes": "reequacionar",
    "reequacionava": "reequacionar",
    "reequacionavam": "reequacionar",
    "reequacionavas": "reequacionar",
    "reequacione": "reequacionar",
    "reequacionei": "reequacionar",
    "reequacioneis": "reequacionar",
    "reequacionem": "reequacionar",
    "reequacionemo": "reequacionar",
    "reequacionemos": "reequacionar",
    "reequaciones": "reequacionar",
    "reequaciono": "reequacionar",
    "reequacionou": "reequacionar",
    "reequacioná": "reequacionar",
    "reequacionámo": "reequacionar",
    "reequacionámos": "reequacionar",
    "reequacionáramo": "reequacionar",
    "reequacionáramos": "reequacionar",
    "reequacionárei": "reequacionar",
    "reequacionáreis": "reequacionar",
    "reequacionásseis": "reequacionar",
    "reequacionássemos": "reequacionar",
    "reequacionávamo": "reequacionar",
    "reequacionávamos": "reequacionar",
    "reequacionávei": "reequacionar",
    "reequacionáveis": "reequacionar",
    "reequilibra": "reequilibrar",
    "reequilibrada": "reequilibrar",
    "reequilibradas": "reequilibrar",
    "reequilibrado": "reequilibrar",
    "reequilibrados": "reequilibrar",
    "reequilibrai": "reequilibrar",
    "reequilibrais": "reequilibrar",
    "reequilibram": "reequilibrar",
    "reequilibramo": "reequilibrar",
    "reequilibramos": "reequilibrar",
    "reequilibrando": "reequilibrar",
    "reequilibrara": "reequilibrar",
    "reequilibraram": "reequilibrar",
    "reequilibraras": "reequilibrar",
    "reequilibrarde": "reequilibrar",
    "reequilibrardes": "reequilibrar",
    "reequilibrare": "reequilibrar",
    "reequilibrarei": "reequilibrar",
    "reequilibrareis": "reequilibrar",
    "reequilibrarem": "reequilibrar",
    "reequilibraremos": "reequilibrar",
    "reequilibrares": "reequilibrar",
    "reequilibraria": "reequilibrar",
    "reequilibrariam": "reequilibrar",
    "reequilibrarias": "reequilibrar",
    "reequilibrarmo": "reequilibrar",
    "reequilibrarmos": "reequilibrar",
    "reequilibrará": "reequilibrar",
    "reequilibrarás": "reequilibrar",
    "reequilibrarão": "reequilibrar",
    "reequilibraríamos": "reequilibrar",
    "reequilibraríeis": "reequilibrar",
    "reequilibras": "reequilibrar",
    "reequilibrasse": "reequilibrar",
    "reequilibrassem": "reequilibrar",
    "reequilibrasses": "reequilibrar",
    "reequilibraste": "reequilibrar",
    "reequilibrastes": "reequilibrar",
    "reequilibrava": "reequilibrar",
    "reequilibravam": "reequilibrar",
    "reequilibravas": "reequilibrar",
    "reequilibre": "reequilibrar",
    "reequilibrei": "reequilibrar",
    "reequilibreis": "reequilibrar",
    "reequilibrem": "reequilibrar",
    "reequilibremo": "reequilibrar",
    "reequilibremos": "reequilibrar",
    "reequilibres": "reequilibrar",
    "reequilibro": "reequilibrar",
    "reequilibrou": "reequilibrar",
    "reequilibrá": "reequilibrar",
    "reequilibrámo": "reequilibrar",
    "reequilibrámos": "reequilibrar",
    "reequilibráramo": "reequilibrar",
    "reequilibráramos": "reequilibrar",
    "reequilibrárei": "reequilibrar",
    "reequilibráreis": "reequilibrar",
    "reequilibrásseis": "reequilibrar",
    "reequilibrássemos": "reequilibrar",
    "reequilibrávamo": "reequilibrar",
    "reequilibrávamos": "reequilibrar",
    "reequilibrávei": "reequilibrar",
    "reequilibráveis": "reequilibrar",
    "reequilíbrios": "reequilíbrio",
    "reequipamentos": "reequipamento",
    "reerga": "reerguer",
    "reergais": "reerguer",
    "reergam": "reerguer",
    "reergamo": "reerguer",
    "reergamos": "reerguer",
    "reergas": "reerguer",
    "reergo": "reerguer",
    "reergue": "reerguer",
    "reerguei": "reerguer",
    "reergueis": "reerguer",
    "reerguem": "reerguer",
    "reerguemo": "reerguer",
    "reerguemos": "reerguer",
    "reerguendo": "reerguer",
    "reerguera": "reerguer",
    "reergueram": "reerguer",
    "reergueras": "reerguer",
    "reerguerde": "reerguer",
    "reerguerdes": "reerguer",
    "reerguere": "reerguer",
    "reerguerei": "reerguer",
    "reerguereis": "reerguer",
    "reerguerem": "reerguer",
    "reergueremos": "reerguer",
    "reergueres": "reerguer",
    "reergueria": "reerguer",
    "reergueriam": "reerguer",
    "reerguerias": "reerguer",
    "reerguermo": "reerguer",
    "reerguermos": "reerguer",
    "reerguerá": "reerguer",
    "reerguerás": "reerguer",
    "reerguerão": "reerguer",
    "reergueríamos": "reerguer",
    "reergueríeis": "reerguer",
    "reergues": "reerguer",
    "reerguesse": "reerguer",
    "reerguessem": "reerguer",
    "reerguesses": "reerguer",
    "reergueste": "reerguer",
    "reerguestes": "reerguer",
    "reergueu": "reerguer",
    "reergui": "reerguer",
    "reerguia": "reerguer",
    "reerguiam": "reerguer",
    "reerguias": "reerguer",
    "reerguida": "reerguer",
    "reerguidas": "reerguer",
    "reerguido": "reerguer",
    "reerguidos": "reerguer",
    "reerguê": "reerguer",
    "reerguêramo": "reerguer",
    "reerguêramos": "reerguer",
    "reerguêrei": "reerguer",
    "reerguêreis": "reerguer",
    "reerguêsseis": "reerguer",
    "reerguêssemos": "reerguer",
    "reerguíamo": "reerguer",
    "reerguíamos": "reerguer",
    "reerguíei": "reerguer",
    "reerguíeis": "reerguer",
    "reescalona": "reescalonar",
    "reescalonada": "reescalonar",
    "reescalonadas": "reescalonar",
    "reescalonado": "reescalonar",
    "reescalonados": "reescalonar",
    "reescalonai": "reescalonar",
    "reescalonais": "reescalonar",
    "reescalonam": "reescalonar",
    "reescalonamentos": "reescalonamento",
    "reescalonamo": "reescalonar",
    "reescalonamos": "reescalonar",
    "reescalonando": "reescalonar",
    "reescalonara": "reescalonar",
    "reescalonaram": "reescalonar",
    "reescalonaras": "reescalonar",
    "reescalonarde": "reescalonar",
    "reescalonardes": "reescalonar",
    "reescalonare": "reescalonar",
    "reescalonarei": "reescalonar",
    "reescalonareis": "reescalonar",
    "reescalonarem": "reescalonar",
    "reescalonaremos": "reescalonar",
    "reescalonares": "reescalonar",
    "reescalonaria": "reescalonar",
    "reescalonariam": "reescalonar",
    "reescalonarias": "reescalonar",
    "reescalonarmo": "reescalonar",
    "reescalonarmos": "reescalonar",
    "reescalonará": "reescalonar",
    "reescalonarás": "reescalonar",
    "reescalonarão": "reescalonar",
    "reescalonaríamos": "reescalonar",
    "reescalonaríeis": "reescalonar",
    "reescalonas": "reescalonar",
    "reescalonasse": "reescalonar",
    "reescalonassem": "reescalonar",
    "reescalonasses": "reescalonar",
    "reescalonaste": "reescalonar",
    "reescalonastes": "reescalonar",
    "reescalonava": "reescalonar",
    "reescalonavam": "reescalonar",
    "reescalonavas": "reescalonar",
    "reescalone": "reescalonar",
    "reescalonei": "reescalonar",
    "reescaloneis": "reescalonar",
    "reescalonem": "reescalonar",
    "reescalonemo": "reescalonar",
    "reescalonemos": "reescalonar",
    "reescalones": "reescalonar",
    "reescalono": "reescalonar",
    "reescalonou": "reescalonar",
    "reescaloná": "reescalonar",
    "reescalonámo": "reescalonar",
    "reescalonámos": "reescalonar",
    "reescalonáramo": "reescalonar",
    "reescalonáramos": "reescalonar",
    "reescalonárei": "reescalonar",
    "reescalonáreis": "reescalonar",
    "reescalonásseis": "reescalonar",
    "reescalonássemos": "reescalonar",
    "reescalonávamo": "reescalonar",
    "reescalonávamos": "reescalonar",
    "reescalonávei": "reescalonar",
    "reescalonáveis": "reescalonar",
    "reescreva": "reescrever",
    "reescrevais": "reescrever",
    "reescrevam": "reescrever",
    "reescrevamo": "reescrever",
    "reescrevamos": "reescrever",
    "reescrevas": "reescrever",
    "reescreve": "reescrever",
    "reescrevei": "reescrever",
    "reescreveis": "reescrever",
    "reescrevem": "reescrever",
    "reescrevemo": "reescrever",
    "reescrevemos": "reescrever",
    "reescrevendo": "reescrever",
    "reescrevera": "reescrever",
    "reescreveram": "reescrever",
    "reescreveras": "reescrever",
    "reescreverde": "reescrever",
    "reescreverdes": "reescrever",
    "reescrevere": "reescrever",
    "reescreverei": "reescrever",
    "reescrevereis": "reescrever",
    "reescreverem": "reescrever",
    "reescreveremos": "reescrever",
    "reescreveres": "reescrever",
    "reescreveria": "reescrever",
    "reescreveriam": "reescrever",
    "reescreverias": "reescrever",
    "reescrevermo": "reescrever",
    "reescrevermos": "reescrever",
    "reescreverá": "reescrever",
    "reescreverás": "reescrever",
    "reescreverão": "reescrever",
    "reescreveríamos": "reescrever",
    "reescreveríeis": "reescrever",
    "reescreves": "reescrever",
    "reescrevesse": "reescrever",
    "reescrevessem": "reescrever",
    "reescrevesses": "reescrever",
    "reescreveste": "reescrever",
    "reescrevestes": "reescrever",
    "reescreveu": "reescrever",
    "reescrevi": "reescrever",
    "reescrevia": "reescrever",
    "reescreviam": "reescrever",
    "reescrevias": "reescrever",
    "reescrevida": "reescrever",
    "reescrevidas": "reescrever",
    "reescrevido": "reescrever",
    "reescrevidos": "reescrever",
    "reescrevo": "reescrever",
    "reescrevê": "reescrever",
    "reescrevêramo": "reescrever",
    "reescrevêramos": "reescrever",
    "reescrevêrei": "reescrever",
    "reescrevêreis": "reescrever",
    "reescrevêsseis": "reescrever",
    "reescrevêssemos": "reescrever",
    "reescrevíamo": "reescrever",
    "reescrevíamos": "reescrever",
    "reescrevíei": "reescrever",
    "reescrevíeis": "reescrever",
    "reescrita": "reescrito",
    "reescritas": "reescrito",
    "reescritos": "reescrito",
    "reespera": "reesperar",
    "reesperada": "reesperar",
    "reesperadas": "reesperar",
    "reesperado": "reesperar",
    "reesperados": "reesperar",
    "reesperai": "reesperar",
    "reesperais": "reesperar",
    "reesperam": "reesperar",
    "reesperamo": "reesperar",
    "reesperamos": "reesperar",
    "reesperando": "reesperar",
    "reesperara": "reesperar",
    "reesperaram": "reesperar",
    "reesperaras": "reesperar",
    "reesperardes": "reesperar",
    "reesperarei": "reesperar",
    "reesperareis": "reesperar",
    "reesperarem": "reesperar",
    "reesperaremos": "reesperar",
    "reesperares": "reesperar",
    "reesperaria": "reesperar",
    "reesperariam": "reesperar",
    "reesperarias": "reesperar",
    "reesperarmo": "reesperar",
    "reesperarmos": "reesperar",
    "reesperará": "reesperar",
    "reesperarás": "reesperar",
    "reesperarão": "reesperar",
    "reesperaríamos": "reesperar",
    "reesperaríeis": "reesperar",
    "reesperas": "reesperar",
    "reesperasse": "reesperar",
    "reesperassem": "reesperar",
    "reesperasses": "reesperar",
    "reesperaste": "reesperar",
    "reesperastes": "reesperar",
    "reesperava": "reesperar",
    "reesperavam": "reesperar",
    "reesperavas": "reesperar",
    "reespere": "reesperar",
    "reesperei": "reesperar",
    "reespereis": "reesperar",
    "reesperem": "reesperar",
    "reesperemo": "reesperar",
    "reesperemos": "reesperar",
    "reesperes": "reesperar",
    "reespero": "reesperar",
    "reesperou": "reesperar",
    "reesperámo": "reesperar",
    "reesperámos": "reesperar",
    "reesperáramo": "reesperar",
    "reesperáramos": "reesperar",
    "reesperáreis": "reesperar",
    "reesperásseis": "reesperar",
    "reesperássemos": "reesperar",
    "reesperávamo": "reesperar",
    "reesperávamos": "reesperar",
    "reesperáveis": "reesperar",
    "reestimações": "reestimação",
    "reestrutura": "reestruturar",
    "reestruturada": "reestruturar",
    "reestruturadas": "reestruturar",
    "reestruturado": "reestruturar",
    "reestruturados": "reestruturar",
    "reestruturai": "reestruturar",
    "reestruturais": "reestruturar",
    "reestruturam": "reestruturar",
    "reestruturamo": "reestruturar",
    "reestruturamos": "reestruturar",
    "reestruturando": "reestruturar",
    "reestruturara": "reestruturar",
    "reestruturaram": "reestruturar",
    "reestruturaras": "reestruturar",
    "reestruturarde": "reestruturar",
    "reestruturardes": "reestruturar",
    "reestruturare": "reestruturar",
    "reestruturarei": "reestruturar",
    "reestruturareis": "reestruturar",
    "reestruturarem": "reestruturar",
    "reestruturaremos": "reestruturar",
    "reestruturares": "reestruturar",
    "reestruturaria": "reestruturar",
    "reestruturariam": "reestruturar",
    "reestruturarias": "reestruturar",
    "reestruturarmo": "reestruturar",
    "reestruturarmos": "reestruturar",
    "reestruturará": "reestruturar",
    "reestruturarás": "reestruturar",
    "reestruturarão": "reestruturar",
    "reestruturaríamos": "reestruturar",
    "reestruturaríeis": "reestruturar",
    "reestruturas": "reestruturar",
    "reestruturasse": "reestruturar",
    "reestruturassem": "reestruturar",
    "reestruturasses": "reestruturar",
    "reestruturaste": "reestruturar",
    "reestruturastes": "reestruturar",
    "reestruturava": "reestruturar",
    "reestruturavam": "reestruturar",
    "reestruturavas": "reestruturar",
    "reestruturações": "reestruturação",
    "reestruture": "reestruturar",
    "reestruturei": "reestruturar",
    "reestrutureis": "reestruturar",
    "reestruturem": "reestruturar",
    "reestruturemo": "reestruturar",
    "reestruturemos": "reestruturar",
    "reestrutures": "reestruturar",
    "reestruturo": "reestruturar",
    "reestruturou": "reestruturar",
    "reestruturá": "reestruturar",
    "reestruturámo": "reestruturar",
    "reestruturámos": "reestruturar",
    "reestruturáramo": "reestruturar",
    "reestruturáramos": "reestruturar",
    "reestruturárei": "reestruturar",
    "reestruturáreis": "reestruturar",
    "reestruturásseis": "reestruturar",
    "reestruturássemos": "reestruturar",
    "reestruturávamo": "reestruturar",
    "reestruturávamos": "reestruturar",
    "reestruturávei": "reestruturar",
    "reestruturáveis": "reestruturar",
    "reestuda": "reestudar",
    "reestudada": "reestudar",
    "reestudadas": "reestudar",
    "reestudado": "reestudar",
    "reestudados": "reestudar",
    "reestudai": "reestudar",
    "reestudais": "reestudar",
    "reestudam": "reestudar",
    "reestudamo": "reestudar",
    "reestudamos": "reestudar",
    "reestudando": "reestudar",
    "reestudara": "reestudar",
    "reestudaram": "reestudar",
    "reestudaras": "reestudar",
    "reestudarde": "reestudar",
    "reestudardes": "reestudar",
    "reestudare": "reestudar",
    "reestudarei": "reestudar",
    "reestudareis": "reestudar",
    "reestudarem": "reestudar",
    "reestudaremos": "reestudar",
    "reestudares": "reestudar",
    "reestudaria": "reestudar",
    "reestudariam": "reestudar",
    "reestudarias": "reestudar",
    "reestudarmo": "reestudar",
    "reestudarmos": "reestudar",
    "reestudará": "reestudar",
    "reestudarás": "reestudar",
    "reestudarão": "reestudar",
    "reestudaríamos": "reestudar",
    "reestudaríeis": "reestudar",
    "reestudas": "reestudar",
    "reestudasse": "reestudar",
    "reestudassem": "reestudar",
    "reestudasses": "reestudar",
    "reestudaste": "reestudar",
    "reestudastes": "reestudar",
    "reestudava": "reestudar",
    "reestudavam": "reestudar",
    "reestudavas": "reestudar",
    "reestude": "reestudar",
    "reestudei": "reestudar",
    "reestudeis": "reestudar",
    "reestudem": "reestudar",
    "reestudemo": "reestudar",
    "reestudemos": "reestudar",
    "reestudes": "reestudar",
    "reestudo": "reestudar",
    "reestudou": "reestudar",
    "reestudá": "reestudar",
    "reestudámo": "reestudar",
    "reestudámos": "reestudar",
    "reestudáramo": "reestudar",
    "reestudáramos": "reestudar",
    "reestudárei": "reestudar",
    "reestudáreis": "reestudar",
    "reestudásseis": "reestudar",
    "reestudássemos": "reestudar",
    "reestudávamo": "reestudar",
    "reestudávamos": "reestudar",
    "reestudávei": "reestudar",
    "reestudáveis": "reestudar",
    "reexames": "reexame",
    "reexamina": "reexaminar",
    "reexaminada": "reexaminar",
    "reexaminadas": "reexaminar",
    "reexaminado": "reexaminar",
    "reexaminados": "reexaminar",
    "reexaminai": "reexaminar",
    "reexaminais": "reexaminar",
    "reexaminam": "reexaminar",
    "reexaminamo": "reexaminar",
    "reexaminamos": "reexaminar",
    "reexaminando": "reexaminar",
    "reexaminara": "reexaminar",
    "reexaminaram": "reexaminar",
    "reexaminaras": "reexaminar",
    "reexaminarde": "reexaminar",
    "reexaminardes": "reexaminar",
    "reexaminare": "reexaminar",
    "reexaminarei": "reexaminar",
    "reexaminareis": "reexaminar",
    "reexaminarem": "reexaminar",
    "reexaminaremos": "reexaminar",
    "reexaminares": "reexaminar",
    "reexaminaria": "reexaminar",
    "reexaminariam": "reexaminar",
    "reexaminarias": "reexaminar",
    "reexaminarmo": "reexaminar",
    "reexaminarmos": "reexaminar",
    "reexaminará": "reexaminar",
    "reexaminarás": "reexaminar",
    "reexaminarão": "reexaminar",
    "reexaminaríamos": "reexaminar",
    "reexaminaríeis": "reexaminar",
    "reexaminas": "reexaminar",
    "reexaminasse": "reexaminar",
    "reexaminassem": "reexaminar",
    "reexaminasses": "reexaminar",
    "reexaminaste": "reexaminar",
    "reexaminastes": "reexaminar",
    "reexaminava": "reexaminar",
    "reexaminavam": "reexaminar",
    "reexaminavas": "reexaminar",
    "reexamine": "reexaminar",
    "reexaminei": "reexaminar",
    "reexamineis": "reexaminar",
    "reexaminem": "reexaminar",
    "reexaminemo": "reexaminar",
    "reexaminemos": "reexaminar",
    "reexamines": "reexaminar",
    "reexamino": "reexaminar",
    "reexaminou": "reexaminar",
    "reexaminá": "reexaminar",
    "reexaminámo": "reexaminar",
    "reexaminámos": "reexaminar",
    "reexamináramo": "reexaminar",
    "reexamináramos": "reexaminar",
    "reexaminárei": "reexaminar",
    "reexamináreis": "reexaminar",
    "reexaminásseis": "reexaminar",
    "reexaminássemos": "reexaminar",
    "reexaminávamo": "reexaminar",
    "reexaminávamos": "reexaminar",
    "reexaminávei": "reexaminar",
    "reexamináveis": "reexaminável",
    "reexista": "reexistir",
    "reexistais": "reexistir",
    "reexistam": "reexistir",
    "reexistamo": "reexistir",
    "reexistamos": "reexistir",
    "reexistas": "reexistir",
    "reexiste": "reexistir",
    "reexistem": "reexistir",
    "reexistes": "reexistir",
    "reexisti": "reexistir",
    "reexistia": "reexistir",
    "reexistiam": "reexistir",
    "reexistias": "reexistir",
    "reexistida": "reexistir",
    "reexistidas": "reexistir",
    "reexistido": "reexistir",
    "reexistidos": "reexistir",
    "reexistimo": "reexistir",
    "reexistimos": "reexistir",
    "reexistindo": "reexistir",
    "reexistira": "reexistir",
    "reexistiram": "reexistir",
    "reexistiras": "reexistir",
    "reexistirde": "reexistir",
    "reexistirdes": "reexistir",
    "reexistire": "reexistir",
    "reexistirei": "reexistir",
    "reexistireis": "reexistir",
    "reexistirem": "reexistir",
    "reexistiremos": "reexistir",
    "reexistires": "reexistir",
    "reexistiria": "reexistir",
    "reexistiriam": "reexistir",
    "reexistirias": "reexistir",
    "reexistirmo": "reexistir",
    "reexistirmos": "reexistir",
    "reexistirá": "reexistir",
    "reexistirás": "reexistir",
    "reexistirão": "reexistir",
    "reexistiríamos": "reexistir",
    "reexistiríeis": "reexistir",
    "reexistis": "reexistir",
    "reexistisse": "reexistir",
    "reexistissem": "reexistir",
    "reexistisses": "reexistir",
    "reexististe": "reexistir",
    "reexististes": "reexistir",
    "reexistiu": "reexistir",
    "reexisto": "reexistir",
    "reexistíamo": "reexistir",
    "reexistíamos": "reexistir",
    "reexistíei": "reexistir",
    "reexistíeis": "reexistir",
    "reexistíramo": "reexistir",
    "reexistíramos": "reexistir",
    "reexistírei": "reexistir",
    "reexistíreis": "reexistir",
    "reexistísseis": "reexistir",
    "reexistíssemos": "reexistir",
    "reexpede": "reexpedir",
    "reexpedem": "reexpedir",
    "reexpedes": "reexpedir",
    "reexpedi": "reexpedir",
    "reexpedia": "reexpedir",
    "reexpediam": "reexpedir",
    "reexpedias": "reexpedir",
    "reexpedida": "reexpedir",
    "reexpedidas": "reexpedir",
    "reexpedido": "reexpedir",
    "reexpedidos": "reexpedir",
    "reexpedimo": "reexpedir",
    "reexpedimos": "reexpedir",
    "reexpedindo": "reexpedir",
    "reexpedira": "reexpedir",
    "reexpediram": "reexpedir",
    "reexpediras": "reexpedir",
    "reexpedirde": "reexpedir",
    "reexpedirdes": "reexpedir",
    "reexpedire": "reexpedir",
    "reexpedirei": "reexpedir",
    "reexpedireis": "reexpedir",
    "reexpedirem": "reexpedir",
    "reexpediremos": "reexpedir",
    "reexpedires": "reexpedir",
    "reexpediria": "reexpedir",
    "reexpediriam": "reexpedir",
    "reexpedirias": "reexpedir",
    "reexpedirmo": "reexpedir",
    "reexpedirmos": "reexpedir",
    "reexpedirá": "reexpedir",
    "reexpedirás": "reexpedir",
    "reexpedirão": "reexpedir",
    "reexpediríamos": "reexpedir",
    "reexpediríeis": "reexpedir",
    "reexpedis": "reexpedir",
    "reexpedisse": "reexpedir",
    "reexpedissem": "reexpedir",
    "reexpedisses": "reexpedir",
    "reexpediste": "reexpedir",
    "reexpedistes": "reexpedir",
    "reexpediu": "reexpedir",
    "reexpedições": "reexpedição",
    "reexpedíamo": "reexpedir",
    "reexpedíamos": "reexpedir",
    "reexpedíei": "reexpedir",
    "reexpedíeis": "reexpedir",
    "reexpedíramo": "reexpedir",
    "reexpedíramos": "reexpedir",
    "reexpedírei": "reexpedir",
    "reexpedíreis": "reexpedir",
    "reexpedísseis": "reexpedir",
    "reexpedíssemos": "reexpedir",
    "reexpeça": "reexpedir",
    "reexpeçais": "reexpedir",
    "reexpeçam": "reexpedir",
    "reexpeçamo": "reexpedir",
    "reexpeçamos": "reexpedir",
    "reexpeças": "reexpedir",
    "reexpeço": "reexpedir",
    "reexplica": "reexplicar",
    "reexplicada": "reexplicar",
    "reexplicadas": "reexplicar",
    "reexplicado": "reexplicar",
    "reexplicados": "reexplicar",
    "reexplicai": "reexplicar",
    "reexplicais": "reexplicar",
    "reexplicam": "reexplicar",
    "reexplicamo": "reexplicar",
    "reexplicamos": "reexplicar",
    "reexplicando": "reexplicar",
    "reexplicara": "reexplicar",
    "reexplicaram": "reexplicar",
    "reexplicaras": "reexplicar",
    "reexplicarde": "reexplicar",
    "reexplicardes": "reexplicar",
    "reexplicare": "reexplicar",
    "reexplicarei": "reexplicar",
    "reexplicareis": "reexplicar",
    "reexplicarem": "reexplicar",
    "reexplicaremos": "reexplicar",
    "reexplicares": "reexplicar",
    "reexplicaria": "reexplicar",
    "reexplicariam": "reexplicar",
    "reexplicarias": "reexplicar",
    "reexplicarmo": "reexplicar",
    "reexplicarmos": "reexplicar",
    "reexplicará": "reexplicar",
    "reexplicarás": "reexplicar",
    "reexplicarão": "reexplicar",
    "reexplicaríamos": "reexplicar",
    "reexplicaríeis": "reexplicar",
    "reexplicas": "reexplicar",
    "reexplicasse": "reexplicar",
    "reexplicassem": "reexplicar",
    "reexplicasses": "reexplicar",
    "reexplicaste": "reexplicar",
    "reexplicastes": "reexplicar",
    "reexplicava": "reexplicar",
    "reexplicavam": "reexplicar",
    "reexplicavas": "reexplicar",
    "reexplico": "reexplicar",
    "reexplicou": "reexplicar",
    "reexplicá": "reexplicar",
    "reexplicámo": "reexplicar",
    "reexplicámos": "reexplicar",
    "reexplicáramo": "reexplicar",
    "reexplicáramos": "reexplicar",
    "reexplicárei": "reexplicar",
    "reexplicáreis": "reexplicar",
    "reexplicásseis": "reexplicar",
    "reexplicássemos": "reexplicar",
    "reexplicávamo": "reexplicar",
    "reexplicávamos": "reexplicar",
    "reexplicávei": "reexplicar",
    "reexplicáveis": "reexplicar",
    "reexplique": "reexplicar",
    "reexpliquei": "reexplicar",
    "reexpliqueis": "reexplicar",
    "reexpliquem": "reexplicar",
    "reexpliquemo": "reexplicar",
    "reexpliquemos": "reexplicar",
    "reexpliques": "reexplicar",
    "reexpomo": "reexpor",
    "reexpomos": "reexpor",
    "reexponde": "reexpor",
    "reexpondes": "reexpor",
    "reexpondo": "reexpor",
    "reexponha": "reexpor",
    "reexponhais": "reexpor",
    "reexponham": "reexpor",
    "reexponhamo": "reexpor",
    "reexponhamos": "reexpor",
    "reexponhas": "reexpor",
    "reexponho": "reexpor",
    "reexporde": "reexpor",
    "reexpordes": "reexpor",
    "reexpore": "reexpor",
    "reexporei": "reexpor",
    "reexporeis": "reexpor",
    "reexporem": "reexpor",
    "reexporemos": "reexpor",
    "reexpores": "reexpor",
    "reexporia": "reexpor",
    "reexporiam": "reexpor",
    "reexporias": "reexpor",
    "reexpormo": "reexpor",
    "reexpormos": "reexpor",
    "reexporta": "reexportar",
    "reexportada": "reexportar",
    "reexportadas": "reexportar",
    "reexportado": "reexportar",
    "reexportadora": "reexportador",
    "reexportadoras": "reexportador",
    "reexportadores": "reexportador",
    "reexportados": "reexportar",
    "reexportai": "reexportar",
    "reexportais": "reexportar",
    "reexportam": "reexportar",
    "reexportamo": "reexportar",
    "reexportamos": "reexportar",
    "reexportando": "reexportar",
    "reexportara": "reexportar",
    "reexportaram": "reexportar",
    "reexportaras": "reexportar",
    "reexportarde": "reexportar",
    "reexportardes": "reexportar",
    "reexportare": "reexportar",
    "reexportarei": "reexportar",
    "reexportareis": "reexportar",
    "reexportarem": "reexportar",
    "reexportaremos": "reexportar",
    "reexportares": "reexportar",
    "reexportaria": "reexportar",
    "reexportariam": "reexportar",
    "reexportarias": "reexportar",
    "reexportarmo": "reexportar",
    "reexportarmos": "reexportar",
    "reexportará": "reexportar",
    "reexportarás": "reexportar",
    "reexportarão": "reexportar",
    "reexportaríamos": "reexportar",
    "reexportaríeis": "reexportar",
    "reexportas": "reexportar",
    "reexportasse": "reexportar",
    "reexportassem": "reexportar",
    "reexportasses": "reexportar",
    "reexportaste": "reexportar",
    "reexportastes": "reexportar",
    "reexportava": "reexportar",
    "reexportavam": "reexportar",
    "reexportavas": "reexportar",
    "reexportações": "reexportação",
    "reexporte": "reexportar",
    "reexportei": "reexportar",
    "reexporteis": "reexportar",
    "reexportem": "reexportar",
    "reexportemo": "reexportar",
    "reexportemos": "reexportar",
    "reexportes": "reexportar",
    "reexporto": "reexportar",
    "reexportou": "reexportar",
    "reexportá": "reexportar",
    "reexportámo": "reexportar",
    "reexportámos": "reexportar",
    "reexportáramo": "reexportar",
    "reexportáramos": "reexportar",
    "reexportárei": "reexportar",
    "reexportáreis": "reexportar",
    "reexportásseis": "reexportar",
    "reexportássemos": "reexportar",
    "reexportávamo": "reexportar",
    "reexportávamos": "reexportar",
    "reexportávei": "reexportar",
    "reexportáveis": "reexportar",
    "reexporá": "reexpor",
    "reexporás": "reexpor",
    "reexporão": "reexpor",
    "reexporíamos": "reexpor",
    "reexporíeis": "reexpor",
    "reexposições": "reexposição",
    "reexposta": "reexpor",
    "reexpostas": "reexpor",
    "reexposto": "reexpor",
    "reexpostos": "reexpor",
    "reexpunha": "reexpor",
    "reexpunham": "reexpor",
    "reexpunhas": "reexpor",
    "reexpus": "reexpor",
    "reexpusemo": "reexpor",
    "reexpusemos": "reexpor",
    "reexpuser": "reexpor",
    "reexpusera": "reexpor",
    "reexpuseram": "reexpor",
    "reexpuseras": "reexpor",
    "reexpuserdes": "reexpor",
    "reexpuserem": "reexpor",
    "reexpuseres": "reexpor",
    "reexpusermos": "reexpor",
    "reexpusesse": "reexpor",
    "reexpusessem": "reexpor",
    "reexpusesses": "reexpor",
    "reexpuseste": "reexpor",
    "reexpusestes": "reexpor",
    "reexpuséramo": "reexpor",
    "reexpuséramos": "reexpor",
    "reexpusérei": "reexpor",
    "reexpuséreis": "reexpor",
    "reexpusésseis": "reexpor",
    "reexpuséssemos": "reexpor",
    "reexpô": "reexpor",
    "reexpôs": "reexpor",
    "reexpõe": "reexpor",
    "reexpõem": "reexpor",
    "reexpões": "reexpor",
    "reexpúnhamo": "reexpor",
    "reexpúnhamos": "reexpor",
    "reexpúnhei": "reexpor",
    "reexpúnheis": "reexpor",
    "refalsa": "refalso",
    "refalsada": "refalsar",
    "refalsadas": "refalsar",
    "refalsado": "refalsar",
    "refalsados": "refalsar",
    "refalsai": "refalsar",
    "refalsais": "refalsar",
    "refalsam": "refalsar",
    "refalsamentos": "refalsamento",
    "refalsamo": "refalsar",
    "refalsamos": "refalsar",
    "refalsando": "refalsar",
    "refalsara": "refalsar",
    "refalsaram": "refalsar",
    "refalsaras": "refalsar",
    "refalsarde": "refalsar",
    "refalsardes": "refalsar",
    "refalsare": "refalsar",
    "refalsarei": "refalsar",
    "refalsareis": "refalsar",
    "refalsarem": "refalsar",
    "refalsaremos": "refalsar",
    "refalsares": "refalsar",
    "refalsaria": "refalsar",
    "refalsariam": "refalsar",
    "refalsarias": "refalsar",
    "refalsarmo": "refalsar",
    "refalsarmos": "refalsar",
    "refalsará": "refalsar",
    "refalsarás": "refalsar",
    "refalsarão": "refalsar",
    "refalsaríamos": "refalsar",
    "refalsaríeis": "refalsar",
    "refalsas": "refalso",
    "refalsasse": "refalsar",
    "refalsassem": "refalsar",
    "refalsasses": "refalsar",
    "refalsaste": "refalsar",
    "refalsastes": "refalsar",
    "refalsava": "refalsar",
    "refalsavam": "refalsar",
    "refalsavas": "refalsar",
    "refalse": "refalsar",
    "refalseada": "refalsear",
    "refalseadas": "refalsear",
    "refalseado": "refalsear",
    "refalseados": "refalsear",
    "refalseai": "refalsear",
    "refalseais": "refalsear",
    "refalseamo": "refalsear",
    "refalseamos": "refalsear",
    "refalseando": "refalsear",
    "refalseara": "refalsear",
    "refalsearam": "refalsear",
    "refalsearas": "refalsear",
    "refalsearde": "refalsear",
    "refalseardes": "refalsear",
    "refalseare": "refalsear",
    "refalsearei": "refalsear",
    "refalseareis": "refalsear",
    "refalsearem": "refalsear",
    "refalsearemos": "refalsear",
    "refalseares": "refalsear",
    "refalsearia": "refalsear",
    "refalseariam": "refalsear",
    "refalsearias": "refalsear",
    "refalsearmo": "refalsear",
    "refalsearmos": "refalsear",
    "refalseará": "refalsear",
    "refalsearás": "refalsear",
    "refalsearão": "refalsear",
    "refalsearíamos": "refalsear",
    "refalsearíeis": "refalsear",
    "refalseasse": "refalsear",
    "refalseassem": "refalsear",
    "refalseasses": "refalsear",
    "refalseaste": "refalsear",
    "refalseastes": "refalsear",
    "refalseava": "refalsear",
    "refalseavam": "refalsear",
    "refalseavas": "refalsear",
    "refalseei": "refalsear",
    "refalseeis": "refalsear",
    "refalseemo": "refalsear",
    "refalseemos": "refalsear",
    "refalsei": "refalsar",
    "refalseia": "refalsear",
    "refalseiam": "refalsear",
    "refalseias": "refalsear",
    "refalseie": "refalsear",
    "refalseiem": "refalsear",
    "refalseies": "refalsear",
    "refalseio": "refalsear",
    "refalseis": "refalsar",
    "refalsem": "refalsar",
    "refalsemo": "refalsar",
    "refalsemos": "refalsar",
    "refalseou": "refalsear",
    "refalses": "refalsar",
    "refalseá": "refalsear",
    "refalseámo": "refalsear",
    "refalseámos": "refalsear",
    "refalseáramo": "refalsear",
    "refalseáramos": "refalsear",
    "refalseárei": "refalsear",
    "refalseáreis": "refalsear",
    "refalseásseis": "refalsear",
    "refalseássemos": "refalsear",
    "refalseávamo": "refalsear",
    "refalseávamos": "refalsear",
    "refalseávei": "refalsear",
    "refalseáveis": "refalsear",
    "refalso": "refalsar",
    "refalsos": "refalso",
    "refalsou": "refalsar",
    "refalsá": "refalsar",
    "refalsámo": "refalsar",
    "refalsámos": "refalsar",
    "refalsáramo": "refalsar",
    "refalsáramos": "refalsar",
    "refalsárei": "refalsar",
    "refalsáreis": "refalsar",
    "refalsásseis": "refalsar",
    "refalsássemos": "refalsar",
    "refalsávamo": "refalsar",
    "refalsávamos": "refalsar",
    "refalsávei": "refalsar",
    "refalsáveis": "refalsar",
    "refarei": "refazer",
    "refareis": "refazer",
    "refaremos": "refazer",
    "refaria": "refazer",
    "refariam": "refazer",
    "refarias": "refazer",
    "refarta": "refartar",
    "refartada": "refartar",
    "refartadas": "refartar",
    "refartado": "refartar",
    "refartados": "refartar",
    "refartai": "refartar",
    "refartais": "refartar",
    "refartam": "refartar",
    "refartamo": "refartar",
    "refartamos": "refartar",
    "refartando": "refartar",
    "refartara": "refartar",
    "refartaram": "refartar",
    "refartaras": "refartar",
    "refartarde": "refartar",
    "refartardes": "refartar",
    "refartare": "refartar",
    "refartarei": "refartar",
    "refartareis": "refartar",
    "refartarem": "refartar",
    "refartaremos": "refartar",
    "refartares": "refartar",
    "refartaria": "refartar",
    "refartariam": "refartar",
    "refartarias": "refartar",
    "refartarmo": "refartar",
    "refartarmos": "refartar",
    "refartará": "refartar",
    "refartarás": "refartar",
    "refartarão": "refartar",
    "refartaríamos": "refartar",
    "refartaríeis": "refartar",
    "refartas": "refartar",
    "refartasse": "refartar",
    "refartassem": "refartar",
    "refartasses": "refartar",
    "refartaste": "refartar",
    "refartastes": "refartar",
    "refartava": "refartar",
    "refartavam": "refartar",
    "refartavas": "refartar",
    "refarte": "refartar",
    "refartei": "refartar",
    "refarteis": "refartar",
    "refartem": "refartar",
    "refartemo": "refartar",
    "refartemos": "refartar",
    "refartes": "refartar",
    "refarto": "refartar",
    "refartou": "refartar",
    "refartá": "refartar",
    "refartámo": "refartar",
    "refartámos": "refartar",
    "refartáramo": "refartar",
    "refartáramos": "refartar",
    "refartárei": "refartar",
    "refartáreis": "refartar",
    "refartásseis": "refartar",
    "refartássemos": "refartar",
    "refartávamo": "refartar",
    "refartávamos": "refartar",
    "refartávei": "refartar",
    "refartáveis": "refartar",
    "refará": "refazer",
    "refarás": "refazer",
    "refarão": "refazer",
    "refaríamos": "refazer",
    "refaríeis": "refazer",
    "refastela": "refastelar",
    "refastelada": "refastelar",
    "refasteladas": "refastelar",
    "refastelado": "refastelar",
    "refastelados": "refastelar",
    "refasteladíssima": "refastelado",
    "refasteladíssimas": "refastelado",
    "refasteladíssimo": "refastelado",
    "refasteladíssimos": "refastelado",
    "refastelai": "refastelar",
    "refastelais": "refastelar",
    "refastelam": "refastelar",
    "refastelamentos": "refastelamento",
    "refastelamo": "refastelar",
    "refastelamos": "refastelar",
    "refastelando": "refastelar",
    "refastelara": "refastelar",
    "refastelaram": "refastelar",
    "refastelaras": "refastelar",
    "refastelarde": "refastelar",
    "refastelardes": "refastelar",
    "refastelare": "refastelar",
    "refastelarei": "refastelar",
    "refastelareis": "refastelar",
    "refastelarem": "refastelar",
    "refastelaremos": "refastelar",
    "refastelares": "refastelar",
    "refastelaria": "refastelar",
    "refastelariam": "refastelar",
    "refastelarias": "refastelar",
    "refastelarmo": "refastelar",
    "refastelarmos": "refastelar",
    "refastelará": "refastelar",
    "refastelarás": "refastelar",
    "refastelarão": "refastelar",
    "refastelaríamos": "refastelar",
    "refastelaríeis": "refastelar",
    "refastelas": "refastelar",
    "refastelasse": "refastelar",
    "refastelassem": "refastelar",
    "refastelasses": "refastelar",
    "refastelaste": "refastelar",
    "refastelastes": "refastelar",
    "refastelava": "refastelar",
    "refastelavam": "refastelar",
    "refastelavas": "refastelar",
    "refastele": "refastelar",
    "refastelei": "refastelar",
    "refasteleis": "refastelar",
    "refastelem": "refastelar",
    "refastelemo": "refastelar",
    "refastelemos": "refastelar",
    "refasteles": "refastelar",
    "refastelo": "refastelar",
    "refastelos": "refastelo",
    "refastelou": "refastelar",
    "refastelá": "refastelar",
    "refastelámo": "refastelar",
    "refastelámos": "refastelar",
    "refasteláramo": "refastelar",
    "refasteláramos": "refastelar",
    "refastelárei": "refastelar",
    "refasteláreis": "refastelar",
    "refastelásseis": "refastelar",
    "refastelássemos": "refastelar",
    "refastelávamo": "refastelar",
    "refastelávamos": "refastelar",
    "refastelávei": "refastelar",
    "refasteláveis": "refastelar",
    "refaz": "refazer",
    "refaze": "refazer",
    "refazedora": "refazedor",
    "refazedoras": "refazedor",
    "refazedores": "refazedor",
    "refazei": "refazer",
    "refazeis": "refazer",
    "refazem": "refazer",
    "refazemo": "refazer",
    "refazemos": "refazer",
    "refazendo": "refazer",
    "refazerde": "refazer",
    "refazerdes": "refazer",
    "refazere": "refazer",
    "refazerem": "refazer",
    "refazeres": "refazer",
    "refazermo": "refazer",
    "refazermos": "refazer",
    "refazes": "refazer",
    "refazia": "refazer",
    "refaziam": "refazer",
    "refazias": "refazer",
    "refazimentos": "refazimento",
    "refazê": "refazer",
    "refazíamo": "refazer",
    "refazíamos": "refazer",
    "refazíei": "refazer",
    "refazíeis": "refazer",
    "refaça": "refazer",
    "refaçais": "refazer",
    "refaçam": "refazer",
    "refaçamo": "refazer",
    "refaçamos": "refazer",
    "refaças": "refazer",
    "refaço": "refazer",
    "refece": "refecer",
    "refecei": "refecer",
    "refeceis": "refecer",
    "refecem": "refecer",
    "refecemo": "refecer",
    "refecemos": "refecer",
    "refecendo": "refecer",
    "refecera": "refecer",
    "refeceram": "refecer",
    "refeceras": "refecer",
    "refecerdes": "refecer",
    "refecerei": "refecer",
    "refecereis": "refecer",
    "refecerem": "refecer",
    "refeceremos": "refecer",
    "refeceres": "refecer",
    "refeceria": "refecer",
    "refeceriam": "refecer",
    "refecerias": "refecer",
    "refecermo": "refecer",
    "refecermos": "refecer",
    "refecerá": "refecer",
    "refecerás": "refecer",
    "refecerão": "refecer",
    "refeceríamos": "refecer",
    "refeceríeis": "refecer",
    "refeces": "refecer",
    "refecesse": "refecer",
    "refecessem": "refecer",
    "refecesses": "refecer",
    "refeceste": "refecer",
    "refecestes": "refecer",
    "refeceu": "refecer",
    "refeci": "refecer",
    "refecia": "refecer",
    "refeciam": "refecer",
    "refecias": "refecer",
    "refecida": "refecer",
    "refecidas": "refecer",
    "refecido": "refecer",
    "refecidos": "refecer",
    "refectiva": "refectivo",
    "refectivas": "refectivo",
    "refectivos": "refectivo",
    "refectória": "refectório",
    "refectórias": "refectório",
    "refectórios": "refectório",
    "refecunda": "refecundar",
    "refecundada": "refecundar",
    "refecundadas": "refecundar",
    "refecundado": "refecundar",
    "refecundados": "refecundar",
    "refecundai": "refecundar",
    "refecundais": "refecundar",
    "refecundam": "refecundar",
    "refecundamo": "refecundar",
    "refecundamos": "refecundar",
    "refecundando": "refecundar",
    "refecundara": "refecundar",
    "refecundaram": "refecundar",
    "refecundaras": "refecundar",
    "refecundarde": "refecundar",
    "refecundardes": "refecundar",
    "refecundare": "refecundar",
    "refecundarei": "refecundar",
    "refecundareis": "refecundar",
    "refecundarem": "refecundar",
    "refecundaremos": "refecundar",
    "refecundares": "refecundar",
    "refecundaria": "refecundar",
    "refecundariam": "refecundar",
    "refecundarias": "refecundar",
    "refecundarmo": "refecundar",
    "refecundarmos": "refecundar",
    "refecundará": "refecundar",
    "refecundarás": "refecundar",
    "refecundarão": "refecundar",
    "refecundaríamos": "refecundar",
    "refecundaríeis": "refecundar",
    "refecundas": "refecundar",
    "refecundasse": "refecundar",
    "refecundassem": "refecundar",
    "refecundasses": "refecundar",
    "refecundaste": "refecundar",
    "refecundastes": "refecundar",
    "refecundava": "refecundar",
    "refecundavam": "refecundar",
    "refecundavas": "refecundar",
    "refecunde": "refecundar",
    "refecundei": "refecundar",
    "refecundeis": "refecundar",
    "refecundem": "refecundar",
    "refecundemo": "refecundar",
    "refecundemos": "refecundar",
    "refecundes": "refecundar",
    "refecundo": "refecundar",
    "refecundou": "refecundar",
    "refecundá": "refecundar",
    "refecundámo": "refecundar",
    "refecundámos": "refecundar",
    "refecundáramo": "refecundar",
    "refecundáramos": "refecundar",
    "refecundárei": "refecundar",
    "refecundáreis": "refecundar",
    "refecundásseis": "refecundar",
    "refecundássemos": "refecundar",
    "refecundávamo": "refecundar",
    "refecundávamos": "refecundar",
    "refecundávei": "refecundar",
    "refecundáveis": "refecundar",
    "refecêramo": "refecer",
    "refecêramos": "refecer",
    "refecêreis": "refecer",
    "refecêsseis": "refecer",
    "refecêssemos": "refecer",
    "refecíamo": "refecer",
    "refecíamos": "refecer",
    "refecíeis": "refecer",
    "refega": "refegar",
    "refegada": "refegar",
    "refegadas": "refegar",
    "refegado": "refegar",
    "refegados": "refegar",
    "refegai": "refegar",
    "refegais": "refegar",
    "refegam": "refegar",
    "refegamo": "refegar",
    "refegamos": "refegar",
    "refegando": "refegar",
    "refegara": "refegar",
    "refegaram": "refegar",
    "refegaras": "refegar",
    "refegarde": "refegar",
    "refegardes": "refegar",
    "refegare": "refegar",
    "refegarei": "refegar",
    "refegareis": "refegar",
    "refegarem": "refegar",
    "refegaremos": "refegar",
    "refegares": "refegar",
    "refegaria": "refegar",
    "refegariam": "refegar",
    "refegarias": "refegar",
    "refegarmo": "refegar",
    "refegarmos": "refegar",
    "refegará": "refegar",
    "refegarás": "refegar",
    "refegarão": "refegar",
    "refegaríamos": "refegar",
    "refegaríeis": "refegar",
    "refegas": "refegar",
    "refegasse": "refegar",
    "refegassem": "refegar",
    "refegasses": "refegar",
    "refegaste": "refegar",
    "refegastes": "refegar",
    "refegava": "refegar",
    "refegavam": "refegar",
    "refegavas": "refegar",
    "refego": "refegar",
    "refegos": "refego",
    "refegou": "refegar",
    "refegue": "refegar",
    "refeguei": "refegar",
    "refegueis": "refegar",
    "refeguem": "refegar",
    "refeguemo": "refegar",
    "refeguemos": "refegar",
    "refegues": "refegar",
    "refegá": "refegar",
    "refegámo": "refegar",
    "refegámos": "refegar",
    "refegáramo": "refegar",
    "refegáramos": "refegar",
    "refegárei": "refegar",
    "refegáreis": "refegar",
    "refegásseis": "refegar",
    "refegássemos": "refegar",
    "refegávamo": "refegar",
    "refegávamos": "refegar",
    "refegávei": "refegar",
    "refegáveis": "refegar",
    "refeita": "refeito",
    "refeitas": "refeito",
    "refeito": "refazer",
    "refeitoreira": "refeitoreiro",
    "refeitoreiras": "refeitoreiro",
    "refeitoreiros": "refeitoreiro",
    "refeitos": "refeito",
    "refeitórios": "refeitório",
    "refeições": "refeição",
    "refenda": "refender",
    "refendais": "refender",
    "refendam": "refender",
    "refendamo": "refender",
    "refendamos": "refender",
    "refendas": "refender",
    "refende": "refender",
    "refendei": "refender",
    "refendeis": "refender",
    "refendem": "refender",
    "refendemo": "refender",
    "refendemos": "refender",
    "refendendo": "refender",
    "refendera": "refender",
    "refenderam": "refender",
    "refenderas": "refender",
    "refenderde": "refender",
    "refenderdes": "refender",
    "refendere": "refender",
    "refenderei": "refender",
    "refendereis": "refender",
    "refenderem": "refender",
    "refenderemos": "refender",
    "refenderes": "refender",
    "refenderia": "refender",
    "refenderiam": "refender",
    "refenderias": "refender",
    "refendermo": "refender",
    "refendermos": "refender",
    "refenderá": "refender",
    "refenderás": "refender",
    "refenderão": "refender",
    "refenderíamos": "refender",
    "refenderíeis": "refender",
    "refendes": "refender",
    "refendesse": "refender",
    "refendessem": "refender",
    "refendesses": "refender",
    "refendeste": "refender",
    "refendestes": "refender",
    "refendeu": "refender",
    "refendi": "refender",
    "refendia": "refender",
    "refendiam": "refender",
    "refendias": "refender",
    "refendida": "refender",
    "refendidas": "refender",
    "refendido": "refender",
    "refendidos": "refender",
    "refendimentos": "refendimento",
    "refendo": "refender",
    "refendê": "refender",
    "refendêramo": "refender",
    "refendêramos": "refender",
    "refendêrei": "refender",
    "refendêreis": "refender",
    "refendêsseis": "refender",
    "refendêssemos": "refender",
    "refendíamo": "refender",
    "refendíamos": "refender",
    "refendíei": "refender",
    "refendíeis": "refender",
    "refenta": "refentar",
    "refentada": "refentar",
    "refentadas": "refentar",
    "refentado": "refentar",
    "refentados": "refentar",
    "refentai": "refentar",
    "refentais": "refentar",
    "refentam": "refentar",
    "refentamo": "refentar",
    "refentamos": "refentar",
    "refentando": "refentar",
    "refentara": "refentar",
    "refentaram": "refentar",
    "refentaras": "refentar",
    "refentarde": "refentar",
    "refentardes": "refentar",
    "refentare": "refentar",
    "refentarei": "refentar",
    "refentareis": "refentar",
    "refentarem": "refentar",
    "refentaremos": "refentar",
    "refentares": "refentar",
    "refentaria": "refentar",
    "refentariam": "refentar",
    "refentarias": "refentar",
    "refentarmo": "refentar",
    "refentarmos": "refentar",
    "refentará": "refentar",
    "refentarás": "refentar",
    "refentarão": "refentar",
    "refentaríamos": "refentar",
    "refentaríeis": "refentar",
    "refentas": "refentar",
    "refentasse": "refentar",
    "refentassem": "refentar",
    "refentasses": "refentar",
    "refentaste": "refentar",
    "refentastes": "refentar",
    "refentava": "refentar",
    "refentavam": "refentar",
    "refentavas": "refentar",
    "refente": "refentar",
    "refentei": "refentar",
    "refenteis": "refentar",
    "refentem": "refentar",
    "refentemo": "refentar",
    "refentemos": "refentar",
    "refentes": "refentar",
    "refento": "refentar",
    "refentou": "refentar",
    "refentá": "refentar",
    "refentámo": "refentar",
    "refentámos": "refentar",
    "refentáramo": "refentar",
    "refentáramos": "refentar",
    "refentárei": "refentar",
    "refentáreis": "refentar",
    "refentásseis": "refentar",
    "refentássemos": "refentar",
    "refentávamo": "refentar",
    "refentávamos": "refentar",
    "refentávei": "refentar",
    "refentáveis": "refentar",
    "refere": "referir",
    "referem": "referir",
    "referencia": "referenciar",
    "referenciada": "referenciar",
    "referenciadas": "referenciar",
    "referenciado": "referenciar",
    "referenciados": "referenciar",
    "referenciai": "referenciar",
    "referenciais": "referenciar",
    "referenciam": "referenciar",
    "referenciamo": "referenciar",
    "referenciamos": "referenciar",
    "referenciando": "referenciar",
    "referenciara": "referenciar",
    "referenciaram": "referenciar",
    "referenciaras": "referenciar",
    "referenciarde": "referenciar",
    "referenciardes": "referenciar",
    "referenciare": "referenciar",
    "referenciarei": "referenciar",
    "referenciareis": "referenciar",
    "referenciarem": "referenciar",
    "referenciaremos": "referenciar",
    "referenciares": "referenciar",
    "referenciaria": "referenciar",
    "referenciariam": "referenciar",
    "referenciarias": "referenciar",
    "referenciarmo": "referenciar",
    "referenciarmos": "referenciar",
    "referenciará": "referenciar",
    "referenciarás": "referenciar",
    "referenciarão": "referenciar",
    "referenciaríamos": "referenciar",
    "referenciaríeis": "referenciar",
    "referencias": "referenciar",
    "referenciasse": "referenciar",
    "referenciassem": "referenciar",
    "referenciasses": "referenciar",
    "referenciaste": "referenciar",
    "referenciastes": "referenciar",
    "referenciava": "referenciar",
    "referenciavam": "referenciar",
    "referenciavas": "referenciar",
    "referencie": "referenciar",
    "referenciei": "referenciar",
    "referencieis": "referenciar",
    "referenciem": "referenciar",
    "referenciemo": "referenciar",
    "referenciemos": "referenciar",
    "referencies": "referenciar",
    "referencio": "referenciar",
    "referenciou": "referenciar",
    "referenciá": "referenciar",
    "referenciámo": "referenciar",
    "referenciámos": "referenciar",
    "referenciáramo": "referenciar",
    "referenciáramos": "referenciar",
    "referenciárei": "referenciar",
    "referenciáreis": "referenciar",
    "referenciásseis": "referenciar",
    "referenciássemos": "referenciar",
    "referenciávamo": "referenciar",
    "referenciávamos": "referenciar",
    "referenciávei": "referenciar",
    "referenciáveis": "referenciável",
    "referenda": "referendar",
    "referendada": "referendar",
    "referendadas": "referendar",
    "referendado": "referendar",
    "referendados": "referendar",
    "referendai": "referendar",
    "referendais": "referendar",
    "referendam": "referendar",
    "referendamo": "referendar",
    "referendamos": "referendar",
    "referendando": "referendar",
    "referendara": "referendar",
    "referendaram": "referendar",
    "referendaras": "referendar",
    "referendarde": "referendar",
    "referendardes": "referendar",
    "referendare": "referendar",
    "referendarei": "referendar",
    "referendareis": "referendar",
    "referendarem": "referendar",
    "referendaremos": "referendar",
    "referendares": "referendar",
    "referendaria": "referendar",
    "referendariam": "referendar",
    "referendarias": "referendar",
    "referendarmo": "referendar",
    "referendarmos": "referendar",
    "referendará": "referendar",
    "referendarás": "referendar",
    "referendarão": "referendar",
    "referendaríamos": "referendar",
    "referendaríeis": "referendar",
    "referendas": "referendar",
    "referendasse": "referendar",
    "referendassem": "referendar",
    "referendasses": "referendar",
    "referendaste": "referendar",
    "referendastes": "referendar",
    "referendava": "referendar",
    "referendavam": "referendar",
    "referendavas": "referendar",
    "referende": "referendar",
    "referendei": "referendar",
    "referendeis": "referendar",
    "referendem": "referendar",
    "referendemo": "referendar",
    "referendemos": "referendar",
    "referendes": "referendar",
    "referendo": "referendar",
    "referendos": "referendo",
    "referendou": "referendar",
    "referendá": "referendar",
    "referendámo": "referendar",
    "referendámos": "referendar",
    "referendáramo": "referendar",
    "referendáramos": "referendar",
    "referendárei": "referendar",
    "referendáreis": "referendar",
    "referendária": "referendário",
    "referendárias": "referendário",
    "referendários": "referendário",
    "referendásseis": "referendar",
    "referendássemos": "referendar",
    "referendávamo": "referendar",
    "referendávamos": "referendar",
    "referendávei": "referendar",
    "referendáveis": "referendável",
    "referentes": "referente",
    "referes": "referir",
    "referi": "referir",
    "referia": "referir",
    "referiam": "referir",
    "referias": "referir",
    "referida": "referir",
    "referidas": "referir",
    "referido": "referir",
    "referidos": "referir",
    "referimentos": "referimento",
    "referimo": "referir",
    "referimos": "referir",
    "referindo": "referir",
    "referira": "referir",
    "referiram": "referir",
    "referiras": "referir",
    "referirde": "referir",
    "referirdes": "referir",
    "referire": "referir",
    "referirei": "referir",
    "referireis": "referir",
    "referirem": "referir",
    "referiremos": "referir",
    "referires": "referir",
    "referiria": "referir",
    "refeririam": "referir",
    "referirias": "referir",
    "referirmo": "referir",
    "referirmos": "referir",
    "referirá": "referir",
    "referirás": "referir",
    "referirão": "referir",
    "referiríamos": "referir",
    "referiríeis": "referir",
    "referis": "referir",
    "referisse": "referir",
    "referissem": "referir",
    "referisses": "referir",
    "referiste": "referir",
    "referistes": "referir",
    "referiu": "referir",
    "refermenta": "refermentar",
    "refermentada": "refermentar",
    "refermentadas": "refermentar",
    "refermentado": "refermentar",
    "refermentados": "refermentar",
    "refermentai": "refermentar",
    "refermentais": "refermentar",
    "refermentam": "refermentar",
    "refermentamo": "refermentar",
    "refermentamos": "refermentar",
    "refermentando": "refermentar",
    "refermentara": "refermentar",
    "refermentaram": "refermentar",
    "refermentaras": "refermentar",
    "refermentardes": "refermentar",
    "refermentarei": "refermentar",
    "refermentareis": "refermentar",
    "refermentarem": "refermentar",
    "refermentaremos": "refermentar",
    "refermentares": "refermentar",
    "refermentaria": "refermentar",
    "refermentariam": "refermentar",
    "refermentarias": "refermentar",
    "refermentarmo": "refermentar",
    "refermentarmos": "refermentar",
    "refermentará": "refermentar",
    "refermentarás": "refermentar",
    "refermentarão": "refermentar",
    "refermentaríamos": "refermentar",
    "refermentaríeis": "refermentar",
    "refermentas": "refermentar",
    "refermentasse": "refermentar",
    "refermentassem": "refermentar",
    "refermentasses": "refermentar",
    "refermentaste": "refermentar",
    "refermentastes": "refermentar",
    "refermentava": "refermentar",
    "refermentavam": "refermentar",
    "refermentavas": "refermentar",
    "refermentações": "refermentação",
    "refermente": "refermentar",
    "refermentei": "refermentar",
    "refermenteis": "refermentar",
    "refermentem": "refermentar",
    "refermentemo": "refermentar",
    "refermentemos": "refermentar",
    "refermentes": "refermentar",
    "refermento": "refermentar",
    "refermentou": "refermentar",
    "refermentámo": "refermentar",
    "refermentámos": "refermentar",
    "refermentáramo": "refermentar",
    "refermentáramos": "refermentar",
    "refermentáreis": "refermentar",
    "refermentásseis": "refermentar",
    "refermentássemos": "refermentar",
    "refermentávamo": "refermentar",
    "refermentávamos": "refermentar",
    "refermentáveis": "refermentar",
    "referta": "referto",
    "refertada": "refertar",
    "refertadas": "refertar",
    "refertado": "refertar",
    "refertados": "refertar",
    "refertai": "refertar",
    "refertais": "refertar",
    "refertam": "refertar",
    "refertamo": "refertar",
    "refertamos": "refertar",
    "refertando": "refertar",
    "refertara": "refertar",
    "refertaram": "refertar",
    "refertaras": "refertar",
    "refertarde": "refertar",
    "refertardes": "refertar",
    "refertare": "refertar",
    "refertarei": "refertar",
    "refertareis": "refertar",
    "refertarem": "refertar",
    "refertaremos": "refertar",
    "refertares": "refertar",
    "refertaria": "refertar",
    "refertariam": "refertar",
    "refertarias": "refertar",
    "refertarmo": "refertar",
    "refertarmos": "refertar",
    "refertará": "refertar",
    "refertarás": "refertar",
    "refertarão": "refertar",
    "refertaríamos": "refertar",
    "refertaríeis": "refertar",
    "refertas": "referto",
    "refertasse": "refertar",
    "refertassem": "refertar",
    "refertasses": "refertar",
    "refertaste": "refertar",
    "refertastes": "refertar",
    "refertava": "refertar",
    "refertavam": "refertar",
    "refertavas": "refertar",
    "referte": "refertar",
    "refertei": "refertar",
    "referteis": "refertar",
    "refertem": "refertar",
    "refertemo": "refertar",
    "refertemos": "refertar",
    "refertes": "refertar",
    "referto": "refertar",
    "refertos": "referto",
    "refertou": "refertar",
    "refertá": "refertar",
    "refertámo": "refertar",
    "refertámos": "refertar",
    "refertáramo": "refertar",
    "refertáramos": "refertar",
    "refertárei": "refertar",
    "refertáreis": "refertar",
    "refertásseis": "refertar",
    "refertássemos": "refertar",
    "refertávamo": "refertar",
    "refertávamos": "refertar",
    "refertávei": "refertar",
    "refertáveis": "refertar",
    "referva": "referver",
    "refervais": "referver",
    "refervam": "referver",
    "refervamo": "referver",
    "refervamos": "referver",
    "refervas": "referver",
    "referve": "referver",
    "refervei": "referver",
    "referveis": "referver",
    "refervem": "referver",
    "refervemo": "referver",
    "refervemos": "referver",
    "refervendo": "referver",
    "referventes": "refervente",
    "refervera": "referver",
    "referveram": "referver",
    "referveras": "referver",
    "referverde": "referver",
    "referverdes": "referver",
    "refervere": "referver",
    "referverei": "referver",
    "refervereis": "referver",
    "referverem": "referver",
    "referveremos": "referver",
    "referveres": "referver",
    "referveria": "referver",
    "referveriam": "referver",
    "referverias": "referver",
    "refervermo": "referver",
    "refervermos": "referver",
    "referverá": "referver",
    "referverás": "referver",
    "referverão": "referver",
    "referveríamos": "referver",
    "referveríeis": "referver",
    "referves": "referver",
    "refervesse": "referver",
    "refervessem": "referver",
    "refervesses": "referver",
    "referveste": "referver",
    "refervestes": "referver",
    "referveu": "referver",
    "refervi": "referver",
    "refervia": "referver",
    "referviam": "referver",
    "refervias": "referver",
    "refervida": "referver",
    "refervidas": "referver",
    "refervido": "referver",
    "refervidos": "referver",
    "refervo": "referver",
    "refervê": "referver",
    "refervêramo": "referver",
    "refervêramos": "referver",
    "refervêrei": "referver",
    "refervêreis": "referver",
    "refervêsseis": "referver",
    "refervêssemos": "referver",
    "refervíamo": "referver",
    "refervíamos": "referver",
    "refervíei": "referver",
    "refervíeis": "referver",
    "referências": "referência",
    "referíamo": "referir",
    "referíamos": "referir",
    "referíei": "referir",
    "referíeis": "referir",
    "referíramo": "referir",
    "referíramos": "referir",
    "referírei": "referir",
    "referíreis": "referir",
    "referísseis": "referir",
    "referíssemos": "referir",
    "refestela": "refestelar",
    "refestelada": "refestelar",
    "refesteladas": "refestelar",
    "refestelado": "refestelar",
    "refestelados": "refestelar",
    "refestelai": "refestelar",
    "refestelais": "refestelar",
    "refestelam": "refestelar",
    "refestelamentos": "refestelamento",
    "refestelamo": "refestelar",
    "refestelamos": "refestelar",
    "refestelando": "refestelar",
    "refestelara": "refestelar",
    "refestelaram": "refestelar",
    "refestelaras": "refestelar",
    "refestelarde": "refestelar",
    "refestelardes": "refestelar",
    "refestelare": "refestelar",
    "refestelarei": "refestelar",
    "refestelareis": "refestelar",
    "refestelarem": "refestelar",
    "refestelaremos": "refestelar",
    "refestelares": "refestelar",
    "refestelaria": "refestelar",
    "refestelariam": "refestelar",
    "refestelarias": "refestelar",
    "refestelarmo": "refestelar",
    "refestelarmos": "refestelar",
    "refestelará": "refestelar",
    "refestelarás": "refestelar",
    "refestelarão": "refestelar",
    "refestelaríamos": "refestelar",
    "refestelaríeis": "refestelar",
    "refestelas": "refestelar",
    "refestelasse": "refestelar",
    "refestelassem": "refestelar",
    "refestelasses": "refestelar",
    "refestelaste": "refestelar",
    "refestelastes": "refestelar",
    "refestelava": "refestelar",
    "refestelavam": "refestelar",
    "refestelavas": "refestelar",
    "refestele": "refestelar",
    "refestelei": "refestelar",
    "refesteleis": "refestelar",
    "refestelem": "refestelar",
    "refestelemo": "refestelar",
    "refestelemos": "refestelar",
    "refesteles": "refestelar",
    "refestelo": "refestelar",
    "refestelos": "refestelo",
    "refestelou": "refestelar",
    "refestelá": "refestelar",
    "refestelámo": "refestelar",
    "refestelámos": "refestelar",
    "refesteláramo": "refestelar",
    "refesteláramos": "refestelar",
    "refestelárei": "refestelar",
    "refesteláreis": "refestelar",
    "refestelásseis": "refestelar",
    "refestelássemos": "refestelar",
    "refestelávamo": "refestelar",
    "refestelávamos": "refestelar",
    "refestelávei": "refestelar",
    "refesteláveis": "refestelar",
    "refestos": "refesto",
    "refez": "refazer",
    "refeça": "refecer",
    "refeçais": "refecer",
    "refeçam": "refecer",
    "refeçamo": "refecer",
    "refeçamos": "refecer",
    "refeças": "refecer",
    "refeço": "refecer",
    "refi": "refazer",
    "refia": "refiar",
    "refiada": "refiar",
    "refiadas": "refiar",
    "refiado": "refiar",
    "refiados": "refiar",
    "refiai": "refiar",
    "refiais": "refiar",
    "refiam": "refiar",
    "refiamo": "refiar",
    "refiamos": "refiar",
    "refiando": "refiar",
    "refiara": "refiar",
    "refiaram": "refiar",
    "refiaras": "refiar",
    "refiarde": "refiar",
    "refiardes": "refiar",
    "refiare": "refiar",
    "refiarei": "refiar",
    "refiareis": "refiar",
    "refiarem": "refiar",
    "refiaremos": "refiar",
    "refiares": "refiar",
    "refiaria": "refiar",
    "refiariam": "refiar",
    "refiarias": "refiar",
    "refiarmo": "refiar",
    "refiarmos": "refiar",
    "refiará": "refiar",
    "refiarás": "refiar",
    "refiarão": "refiar",
    "refiaríamos": "refiar",
    "refiaríeis": "refiar",
    "refias": "refiar",
    "refiasse": "refiar",
    "refiassem": "refiar",
    "refiasses": "refiar",
    "refiaste": "refiar",
    "refiastes": "refiar",
    "refiava": "refiar",
    "refiavam": "refiar",
    "refiavas": "refiar",
    "refie": "refiar",
    "refiei": "refiar",
    "refieis": "refiar",
    "refiem": "refiar",
    "refiemo": "refiar",
    "refiemos": "refiar",
    "refies": "refiar",
    "refila": "refilar",
    "refilada": "refilar",
    "refiladas": "refilar",
    "refilado": "refilar",
    "refiladora": "refilador",
    "refiladoras": "refilador",
    "refiladores": "refilador",
    "refilados": "refilar",
    "refilai": "refilar",
    "refilais": "refilar",
    "refilam": "refilar",
    "refilamo": "refilar",
    "refilamos": "refilar",
    "refilando": "refilar",
    "refilara": "refilar",
    "refilaram": "refilar",
    "refilaras": "refilar",
    "refilardes": "refilar",
    "refilarei": "refilar",
    "refilareis": "refilar",
    "refilarem": "refilar",
    "refilaremos": "refilar",
    "refilares": "refilar",
    "refilaria": "refilar",
    "refilariam": "refilar",
    "refilarias": "refilar",
    "refilarmo": "refilar",
    "refilarmos": "refilar",
    "refilará": "refilar",
    "refilarás": "refilar",
    "refilarão": "refilar",
    "refilaríamos": "refilar",
    "refilaríeis": "refilar",
    "refilas": "refilar",
    "refilasse": "refilar",
    "refilassem": "refilar",
    "refilasses": "refilar",
    "refilaste": "refilar",
    "refilastes": "refilar",
    "refilava": "refilar",
    "refilavam": "refilar",
    "refilavas": "refilar",
    "refile": "refilar",
    "refilei": "refilar",
    "refileis": "refilar",
    "refilem": "refilar",
    "refilemo": "refilar",
    "refilemos": "refilar",
    "refiles": "refilar",
    "refilha": "refilhar",
    "refilhada": "refilhar",
    "refilhadas": "refilhar",
    "refilhado": "refilhar",
    "refilhados": "refilhar",
    "refilhai": "refilhar",
    "refilhais": "refilhar",
    "refilham": "refilhar",
    "refilhamo": "refilhar",
    "refilhamos": "refilhar",
    "refilhando": "refilhar",
    "refilhara": "refilhar",
    "refilharam": "refilhar",
    "refilharas": "refilhar",
    "refilhardes": "refilhar",
    "refilharei": "refilhar",
    "refilhareis": "refilhar",
    "refilharem": "refilhar",
    "refilharemos": "refilhar",
    "refilhares": "refilhar",
    "refilharia": "refilhar",
    "refilhariam": "refilhar",
    "refilharias": "refilhar",
    "refilharmo": "refilhar",
    "refilharmos": "refilhar",
    "refilhará": "refilhar",
    "refilharás": "refilhar",
    "refilharão": "refilhar",
    "refilharíamos": "refilhar",
    "refilharíeis": "refilhar",
    "refilhas": "refilhar",
    "refilhasse": "refilhar",
    "refilhassem": "refilhar",
    "refilhasses": "refilhar",
    "refilhaste": "refilhar",
    "refilhastes": "refilhar",
    "refilhava": "refilhar",
    "refilhavam": "refilhar",
    "refilhavas": "refilhar",
    "refilhe": "refilhar",
    "refilhei": "refilhar",
    "refilheis": "refilhar",
    "refilhem": "refilhar",
    "refilhemo": "refilhar",
    "refilhemos": "refilhar",
    "refilhes": "refilhar",
    "refilho": "refilhar",
    "refilhos": "refilho",
    "refilhou": "refilhar",
    "refilhámo": "refilhar",
    "refilhámos": "refilhar",
    "refilháramo": "refilhar",
    "refilháramos": "refilhar",
    "refilháreis": "refilhar",
    "refilhásseis": "refilhar",
    "refilhássemos": "refilhar",
    "refilhávamo": "refilhar",
    "refilhávamos": "refilhar",
    "refilháveis": "refilhar",
    "refiliada": "refiliado",
    "refiliadas": "refiliado",
    "refiliados": "refiliado",
    "refiliações": "refiliação",
    "refilmagens": "refilmagem",
    "refilo": "refilar",
    "refilona": "refilão",
    "refilonas": "refilão",
    "refilonazinha": "refilão",
    "refilonazinhas": "refilão",
    "refilonazita": "refilão",
    "refilonazitas": "refilão",
    "refilos": "refilo",
    "refilou": "refilar",
    "refiltra": "refiltrar",
    "refiltrada": "refiltrar",
    "refiltradas": "refiltrar",
    "refiltrado": "refiltrar",
    "refiltrados": "refiltrar",
    "refiltrai": "refiltrar",
    "refiltrais": "refiltrar",
    "refiltram": "refiltrar",
    "refiltramo": "refiltrar",
    "refiltramos": "refiltrar",
    "refiltrando": "refiltrar",
    "refiltrara": "refiltrar",
    "refiltraram": "refiltrar",
    "refiltraras": "refiltrar",
    "refiltrardes": "refiltrar",
    "refiltrarei": "refiltrar",
    "refiltrareis": "refiltrar",
    "refiltrarem": "refiltrar",
    "refiltraremos": "refiltrar",
    "refiltrares": "refiltrar",
    "refiltraria": "refiltrar",
    "refiltrariam": "refiltrar",
    "refiltrarias": "refiltrar",
    "refiltrarmo": "refiltrar",
    "refiltrarmos": "refiltrar",
    "refiltrará": "refiltrar",
    "refiltrarás": "refiltrar",
    "refiltrarão": "refiltrar",
    "refiltraríamos": "refiltrar",
    "refiltraríeis": "refiltrar",
    "refiltras": "refiltrar",
    "refiltrasse": "refiltrar",
    "refiltrassem": "refiltrar",
    "refiltrasses": "refiltrar",
    "refiltraste": "refiltrar",
    "refiltrastes": "refiltrar",
    "refiltrava": "refiltrar",
    "refiltravam": "refiltrar",
    "refiltravas": "refiltrar",
    "refiltre": "refiltrar",
    "refiltrei": "refiltrar",
    "refiltreis": "refiltrar",
    "refiltrem": "refiltrar",
    "refiltremo": "refiltrar",
    "refiltremos": "refiltrar",
    "refiltres": "refiltrar",
    "refiltro": "refiltrar",
    "refiltrou": "refiltrar",
    "refiltrámo": "refiltrar",
    "refiltrámos": "refiltrar",
    "refiltráramo": "refiltrar",
    "refiltráramos": "refiltrar",
    "refiltráreis": "refiltrar",
    "refiltrásseis": "refiltrar",
    "refiltrássemos": "refiltrar",
    "refiltrávamo": "refiltrar",
    "refiltrávamos": "refiltrar",
    "refiltráveis": "refiltrar",
    "refilámo": "refilar",
    "refilámos": "refilar",
    "refiláramo": "refilar",
    "refiláramos": "refilar",
    "refiláreis": "refilar",
    "refilásseis": "refilar",
    "refilássemos": "refilar",
    "refilávamo": "refilar",
    "refilávamos": "refilar",
    "refiláveis": "refilar",
    "refilãozinho": "refilão",
    "refilãozito": "refilão",
    "refilões": "refilão",
    "refilõezinhos": "refilão",
    "refilõezitos": "refilão",
    "refina": "refinar",
    "refinada": "refinar",
    "refinadas": "refinar",
    "refinado": "refinar",
    "refinadora": "refinador",
    "refinadoras": "refinador",
    "refinadores": "refinador",
    "refinados": "refinar",
    "refinaduras": "refinadura",
    "refinadíssima": "refinado",
    "refinadíssimas": "refinado",
    "refinadíssimo": "refinado",
    "refinadíssimos": "refinado",
    "refinai": "refinar",
    "refinais": "refinar",
    "refinam": "refinar",
    "refinamentos": "refinamento",
    "refinamo": "refinar",
    "refinamos": "refinar",
    "refinanciamentos": "refinanciamento",
    "refinando": "refinar",
    "refinara": "refinar",
    "refinaram": "refinar",
    "refinaras": "refinar",
    "refinarde": "refinar",
    "refinardes": "refinar",
    "refinare": "refinar",
    "refinarei": "refinar",
    "refinareis": "refinar",
    "refinarem": "refinar",
    "refinaremos": "refinar",
    "refinares": "refinar",
    "refinaria": "refinar",
    "refinariam": "refinar",
    "refinarias": "refinaria",
    "refinarmo": "refinar",
    "refinarmos": "refinar",
    "refinará": "refinar",
    "refinarás": "refinar",
    "refinarão": "refinar",
    "refinaríamos": "refinar",
    "refinaríeis": "refinar",
    "refinas": "refinar",
    "refinasse": "refinar",
    "refinassem": "refinar",
    "refinasses": "refinar",
    "refinaste": "refinar",
    "refinastes": "refinar",
    "refinava": "refinar",
    "refinavam": "refinar",
    "refinavas": "refinar",
    "refinações": "refinação",
    "refinca": "refincar",
    "refincada": "refincar",
    "refincadas": "refincar",
    "refincado": "refincar",
    "refincados": "refincar",
    "refincais": "refincar",
    "refincam": "refincar",
    "refincamo": "refincar",
    "refincamos": "refincar",
    "refincando": "refincar",
    "refincara": "refincar",
    "refincaram": "refincar",
    "refincaras": "refincar",
    "refincardes": "refincar",
    "refincarei": "refincar",
    "refincareis": "refincar",
    "refincarem": "refincar",
    "refincaremos": "refincar",
    "refincares": "refincar",
    "refincaria": "refincar",
    "refincariam": "refincar",
    "refincarias": "refincar",
    "refincarmo": "refincar",
    "refincarmos": "refincar",
    "refincará": "refincar",
    "refincarás": "refincar",
    "refincarão": "refincar",
    "refincaríamos": "refincar",
    "refincaríeis": "refincar",
    "refincas": "refincar",
    "refincasse": "refincar",
    "refincassem": "refincar",
    "refincasses": "refincar",
    "refincaste": "refincar",
    "refincastes": "refincar",
    "refincava": "refincar",
    "refincavam": "refincar",
    "refincavas": "refincar",
    "refinco": "refincar",
    "refincou": "refincar",
    "refincámo": "refincar",
    "refincámos": "refincar",
    "refincáramo": "refincar",
    "refincáramos": "refincar",
    "refincáreis": "refincar",
    "refincásseis": "refincar",
    "refincássemos": "refincar",
    "refincávamo": "refincar",
    "refincávamos": "refincar",
    "refincáveis": "refincar",
    "refine": "refinar",
    "refinei": "refinar",
    "refineis": "refinar",
    "refinem": "refinar",
    "refinemo": "refinar",
    "refinemos": "refinar",
    "refines": "refinar",
    "refino": "refinar",
    "refinou": "refinar",
    "refinque": "refincar",
    "refinquei": "refincar",
    "refinqueis": "refincar",
    "refinquem": "refincar",
    "refinquemos": "refincar",
    "refinques": "refincar",
    "refiná": "refinar",
    "refinámo": "refinar",
    "refinámos": "refinar",
    "refináramo": "refinar",
    "refináramos": "refinar",
    "refinárei": "refinar",
    "refináreis": "refinar",
    "refinásseis": "refinar",
    "refinássemos": "refinar",
    "refinávamo": "refinar",
    "refinávamos": "refinar",
    "refinávei": "refinar",
    "refináveis": "refinável",
    "refio": "refiar",
    "refiou": "refiar",
    "refira": "referir",
    "refirais": "referir",
    "refiram": "referir",
    "refiramo": "referir",
    "refiramos": "referir",
    "refiras": "referir",
    "refirma": "refirmar",
    "refirmada": "refirmar",
    "refirmadas": "refirmar",
    "refirmado": "refirmar",
    "refirmados": "refirmar",
    "refirmai": "refirmar",
    "refirmais": "refirmar",
    "refirmam": "refirmar",
    "refirmamo": "refirmar",
    "refirmamos": "refirmar",
    "refirmando": "refirmar",
    "refirmara": "refirmar",
    "refirmaram": "refirmar",
    "refirmaras": "refirmar",
    "refirmarde": "refirmar",
    "refirmardes": "refirmar",
    "refirmare": "refirmar",
    "refirmarei": "refirmar",
    "refirmareis": "refirmar",
    "refirmarem": "refirmar",
    "refirmaremos": "refirmar",
    "refirmares": "refirmar",
    "refirmaria": "refirmar",
    "refirmariam": "refirmar",
    "refirmarias": "refirmar",
    "refirmarmo": "refirmar",
    "refirmarmos": "refirmar",
    "refirmará": "refirmar",
    "refirmarás": "refirmar",
    "refirmarão": "refirmar",
    "refirmaríamos": "refirmar",
    "refirmaríeis": "refirmar",
    "refirmas": "refirmar",
    "refirmasse": "refirmar",
    "refirmassem": "refirmar",
    "refirmasses": "refirmar",
    "refirmaste": "refirmar",
    "refirmastes": "refirmar",
    "refirmava": "refirmar",
    "refirmavam": "refirmar",
    "refirmavas": "refirmar",
    "refirme": "refirmar",
    "refirmei": "refirmar",
    "refirmeis": "refirmar",
    "refirmem": "refirmar",
    "refirmemo": "refirmar",
    "refirmemos": "refirmar",
    "refirmes": "refirmar",
    "refirmo": "refirmar",
    "refirmou": "refirmar",
    "refirmá": "refirmar",
    "refirmámo": "refirmar",
    "refirmámos": "refirmar",
    "refirmáramo": "refirmar",
    "refirmáramos": "refirmar",
    "refirmárei": "refirmar",
    "refirmáreis": "refirmar",
    "refirmásseis": "refirmar",
    "refirmássemos": "refirmar",
    "refirmávamo": "refirmar",
    "refirmávamos": "refirmar",
    "refirmávei": "refirmar",
    "refirmáveis": "refirmar",
    "refiro": "referir",
    "refiz": "refazer",
    "refizemo": "refazer",
    "refizemos": "refazer",
    "refizer": "refazer",
    "refizera": "refazer",
    "refizeram": "refazer",
    "refizeras": "refazer",
    "refizerdes": "refazer",
    "refizerem": "refazer",
    "refizeres": "refazer",
    "refizermos": "refazer",
    "refizesse": "refazer",
    "refizessem": "refazer",
    "refizesses": "refazer",
    "refizeste": "refazer",
    "refizestes": "refazer",
    "refizéramo": "refazer",
    "refizéramos": "refazer",
    "refizérei": "refazer",
    "refizéreis": "refazer",
    "refizésseis": "refazer",
    "refizéssemos": "refazer",
    "refiá": "refiar",
    "refiámo": "refiar",
    "refiámos": "refiar",
    "refiáramo": "refiar",
    "refiáramos": "refiar",
    "refiárei": "refiar",
    "refiáreis": "refiar",
    "refiásseis": "refiar",
    "refiássemos": "refiar",
    "refiávamo": "refiar",
    "refiávamos": "refiar",
    "refiávei": "refiar",
    "refiáveis": "refiar",
    "refladas": "reflada",
    "reflecte": "reflectir",
    "reflectem": "reflectir",
    "reflectes": "reflectir",
    "reflecti": "reflectir",
    "reflectia": "reflectir",
    "reflectiam": "reflectir",
    "reflectias": "reflectir",
    "reflectida": "reflectir",
    "reflectidas": "reflectir",
    "reflectido": "reflectir",
    "reflectidora": "reflectidor",
    "reflectidoras": "reflectidor",
    "reflectidores": "reflectidor",
    "reflectidos": "reflectir",
    "reflectimo": "reflectir",
    "reflectimos": "reflectir",
    "reflectindo": "reflectir",
    "reflectira": "reflectir",
    "reflectiram": "reflectir",
    "reflectiras": "reflectir",
    "reflectirde": "reflectir",
    "reflectirdes": "reflectir",
    "reflectire": "reflectir",
    "reflectirei": "reflectir",
    "reflectireis": "reflectir",
    "reflectirem": "reflectir",
    "reflectiremos": "reflectir",
    "reflectires": "reflectir",
    "reflectiria": "reflectir",
    "reflectiriam": "reflectir",
    "reflectirias": "reflectir",
    "reflectirmo": "reflectir",
    "reflectirmos": "reflectir",
    "reflectirá": "reflectir",
    "reflectirás": "reflectir",
    "reflectirão": "reflectir",
    "reflectiríamos": "reflectir",
    "reflectiríeis": "reflectir",
    "reflectis": "reflectir",
    "reflectisse": "reflectir",
    "reflectissem": "reflectir",
    "reflectisses": "reflectir",
    "reflectiste": "reflectir",
    "reflectistes": "reflectir",
    "reflectiu": "reflectir",
    "reflectiva": "reflectivo",
    "reflectivas": "reflectivo",
    "reflectividades": "reflectividade",
    "reflectivos": "reflectivo",
    "reflectora": "reflector",
    "reflectoras": "reflector",
    "reflectores": "reflector",
    "reflectânciaa": "reflectância",
    "reflectânciaas": "reflectância",
    "reflectânciaes": "reflectância",
    "reflectíamo": "reflectir",
    "reflectíamos": "reflectir",
    "reflectíei": "reflectir",
    "reflectíeis": "reflectir",
    "reflectíramo": "reflectir",
    "reflectíramos": "reflectir",
    "reflectírei": "reflectir",
    "reflectíreis": "reflectir",
    "reflectísseis": "reflectir",
    "reflectíssemos": "reflectir",
    "refles": "refle",
    "refletografias": "refletografia",
    "reflexa": "reflexo",
    "reflexas": "reflexo",
    "reflexazinha": "reflexo",
    "reflexazinhas": "reflexo",
    "reflexazita": "reflexo",
    "reflexazitas": "reflexo",
    "reflexibilidades": "reflexibilidade",
    "reflexiona": "reflexionar",
    "reflexionada": "reflexionar",
    "reflexionadas": "reflexionar",
    "reflexionado": "reflexionar",
    "reflexionados": "reflexionar",
    "reflexionai": "reflexionar",
    "reflexionais": "reflexionar",
    "reflexionam": "reflexionar",
    "reflexionamo": "reflexionar",
    "reflexionamos": "reflexionar",
    "reflexionando": "reflexionar",
    "reflexionara": "reflexionar",
    "reflexionaram": "reflexionar",
    "reflexionaras": "reflexionar",
    "reflexionardes": "reflexionar",
    "reflexionarei": "reflexionar",
    "reflexionareis": "reflexionar",
    "reflexionarem": "reflexionar",
    "reflexionaremos": "reflexionar",
    "reflexionares": "reflexionar",
    "reflexionaria": "reflexionar",
    "reflexionariam": "reflexionar",
    "reflexionarias": "reflexionar",
    "reflexionarmo": "reflexionar",
    "reflexionarmos": "reflexionar",
    "reflexionará": "reflexionar",
    "reflexionarás": "reflexionar",
    "reflexionarão": "reflexionar",
    "reflexionaríamos": "reflexionar",
    "reflexionaríeis": "reflexionar",
    "reflexionas": "reflexionar",
    "reflexionasse": "reflexionar",
    "reflexionassem": "reflexionar",
    "reflexionasses": "reflexionar",
    "reflexionaste": "reflexionar",
    "reflexionastes": "reflexionar",
    "reflexionava": "reflexionar",
    "reflexionavam": "reflexionar",
    "reflexionavas": "reflexionar",
    "reflexione": "reflexionar",
    "reflexionei": "reflexionar",
    "reflexioneis": "reflexionar",
    "reflexionem": "reflexionar",
    "reflexionemo": "reflexionar",
    "reflexionemos": "reflexionar",
    "reflexiones": "reflexionar",
    "reflexiono": "reflexionar",
    "reflexionou": "reflexionar",
    "reflexionámo": "reflexionar",
    "reflexionámos": "reflexionar",
    "reflexionáramo": "reflexionar",
    "reflexionáramos": "reflexionar",
    "reflexionáreis": "reflexionar",
    "reflexionásseis": "reflexionar",
    "reflexionássemos": "reflexionar",
    "reflexionávamo": "reflexionar",
    "reflexionávamos": "reflexionar",
    "reflexionáveis": "reflexionar",
    "reflexiva": "reflexivo",
    "reflexivas": "reflexivo",
    "reflexividades": "reflexividade",
    "reflexivos": "reflexivo",
    "reflexos": "reflexo",
    "reflexozinho": "reflexo",
    "reflexozinhos": "reflexo",
    "reflexozito": "reflexo",
    "reflexozitos": "reflexo",
    "reflexíveis": "reflexível",
    "reflexões": "reflexão",
    "reflicta": "reflectir",
    "reflictais": "reflectir",
    "reflictam": "reflectir",
    "reflictamo": "reflectir",
    "reflictamos": "reflectir",
    "reflictas": "reflectir",
    "reflicto": "reflectir",
    "reflora": "reflorir",
    "reflorais": "reflorir",
    "refloram": "reflorir",
    "refloramo": "reflorir",
    "refloramos": "reflorir",
    "refloras": "reflorir",
    "reflore": "reflorir",
    "reflorem": "reflorir",
    "reflores": "reflorir",
    "refloresce": "reflorescer",
    "reflorescei": "reflorescer",
    "refloresceis": "reflorescer",
    "reflorescem": "reflorescer",
    "reflorescemo": "reflorescer",
    "reflorescemos": "reflorescer",
    "reflorescendo": "reflorescer",
    "reflorescentes": "reflorescente",
    "reflorescera": "reflorescer",
    "refloresceram": "reflorescer",
    "refloresceras": "reflorescer",
    "reflorescerdes": "reflorescer",
    "reflorescerei": "reflorescer",
    "reflorescereis": "reflorescer",
    "reflorescerem": "reflorescer",
    "refloresceremos": "reflorescer",
    "refloresceres": "reflorescer",
    "refloresceria": "reflorescer",
    "refloresceriam": "reflorescer",
    "reflorescerias": "reflorescer",
    "reflorescermo": "reflorescer",
    "reflorescermos": "reflorescer",
    "reflorescerá": "reflorescer",
    "reflorescerás": "reflorescer",
    "reflorescerão": "reflorescer",
    "refloresceríamos": "reflorescer",
    "refloresceríeis": "reflorescer",
    "refloresces": "reflorescer",
    "reflorescesse": "reflorescer",
    "reflorescessem": "reflorescer",
    "reflorescesses": "reflorescer",
    "refloresceste": "reflorescer",
    "reflorescestes": "reflorescer",
    "refloresceu": "reflorescer",
    "refloresci": "reflorescer",
    "reflorescia": "reflorescer",
    "refloresciam": "reflorescer",
    "reflorescias": "reflorescer",
    "reflorescida": "reflorescer",
    "reflorescidas": "reflorescer",
    "reflorescido": "reflorescer",
    "reflorescidos": "reflorescer",
    "reflorescimentos": "reflorescimento",
    "reflorescências": "reflorescência",
    "reflorescêramo": "reflorescer",
    "reflorescêramos": "reflorescer",
    "reflorescêreis": "reflorescer",
    "reflorescêsseis": "reflorescer",
    "reflorescêssemos": "reflorescer",
    "reflorescíamo": "reflorescer",
    "reflorescíamos": "reflorescer",
    "reflorescíeis": "reflorescer",
    "refloresta": "reflorestar",
    "reflorestada": "reflorestar",
    "reflorestadas": "reflorestar",
    "reflorestado": "reflorestar",
    "reflorestados": "reflorestar",
    "reflorestai": "reflorestar",
    "reflorestais": "reflorestar",
    "reflorestam": "reflorestar",
    "reflorestamentos": "reflorestamento",
    "reflorestamo": "reflorestar",
    "reflorestamos": "reflorestar",
    "reflorestando": "reflorestar",
    "reflorestara": "reflorestar",
    "reflorestaram": "reflorestar",
    "reflorestaras": "reflorestar",
    "reflorestarde": "reflorestar",
    "reflorestardes": "reflorestar",
    "reflorestare": "reflorestar",
    "reflorestarei": "reflorestar",
    "reflorestareis": "reflorestar",
    "reflorestarem": "reflorestar",
    "reflorestaremos": "reflorestar",
    "reflorestares": "reflorestar",
    "reflorestaria": "reflorestar",
    "reflorestariam": "reflorestar",
    "reflorestarias": "reflorestar",
    "reflorestarmo": "reflorestar",
    "reflorestarmos": "reflorestar",
    "reflorestará": "reflorestar",
    "reflorestarás": "reflorestar",
    "reflorestarão": "reflorestar",
    "reflorestaríamos": "reflorestar",
    "reflorestaríeis": "reflorestar",
    "reflorestas": "reflorestar",
    "reflorestasse": "reflorestar",
    "reflorestassem": "reflorestar",
    "reflorestasses": "reflorestar",
    "reflorestaste": "reflorestar",
    "reflorestastes": "reflorestar",
    "reflorestava": "reflorestar",
    "reflorestavam": "reflorestar",
    "reflorestavas": "reflorestar",
    "reflorestações": "reflorestação",
    "refloreste": "reflorestar",
    "reflorestei": "reflorestar",
    "refloresteis": "reflorestar",
    "reflorestem": "reflorestar",
    "reflorestemo": "reflorestar",
    "reflorestemos": "reflorestar",
    "reflorestes": "reflorestar",
    "refloresto": "reflorestar",
    "reflorestou": "reflorestar",
    "reflorestá": "reflorestar",
    "reflorestámo": "reflorestar",
    "reflorestámos": "reflorestar",
    "reflorestáramo": "reflorestar",
    "reflorestáramos": "reflorestar",
    "reflorestárei": "reflorestar",
    "reflorestáreis": "reflorestar",
    "reflorestásseis": "reflorestar",
    "reflorestássemos": "reflorestar",
    "reflorestávamo": "reflorestar",
    "reflorestávamos": "reflorestar",
    "reflorestávei": "reflorestar",
    "reflorestáveis": "reflorestar",
    "refloresça": "reflorescer",
    "refloresçais": "reflorescer",
    "refloresçam": "reflorescer",
    "refloresçamo": "reflorescer",
    "refloresçamos": "reflorescer",
    "refloresças": "reflorescer",
    "refloresço": "reflorescer",
    "reflori": "reflorir",
    "refloria": "reflorir",
    "refloriam": "reflorir",
    "reflorias": "reflorir",
    "reflorida": "reflorir",
    "refloridas": "reflorir",
    "reflorido": "reflorir",
    "refloridos": "reflorir",
    "reflorimo": "reflorir",
    "reflorimos": "reflorir",
    "reflorindo": "reflorir",
    "reflorira": "reflorir",
    "refloriram": "reflorir",
    "refloriras": "reflorir",
    "reflorirde": "reflorir",
    "reflorirdes": "reflorir",
    "reflorire": "reflorir",
    "reflorirei": "reflorir",
    "reflorireis": "reflorir",
    "reflorirem": "reflorir",
    "refloriremos": "reflorir",
    "reflorires": "reflorir",
    "refloriria": "reflorir",
    "refloririam": "reflorir",
    "refloririas": "reflorir",
    "reflorirmo": "reflorir",
    "reflorirmos": "reflorir",
    "reflorirá": "reflorir",
    "reflorirás": "reflorir",
    "reflorirão": "reflorir",
    "refloriríamos": "reflorir",
    "refloriríeis": "reflorir",
    "refloris": "reflorir",
    "reflorisse": "reflorir",
    "reflorissem": "reflorir",
    "reflorisses": "reflorir",
    "refloriste": "reflorir",
    "refloristes": "reflorir",
    "refloriu": "reflorir",
    "refloro": "reflorir",
    "refloríamo": "reflorir",
    "refloríamos": "reflorir",
    "refloríei": "reflorir",
    "refloríeis": "reflorir",
    "refloríramo": "reflorir",
    "refloríramos": "reflorir",
    "reflorírei": "reflorir",
    "refloríreis": "reflorir",
    "reflorísseis": "reflorir",
    "refloríssemos": "reflorir",
    "reflua": "refluir",
    "refluais": "refluir",
    "refluam": "refluir",
    "refluamo": "refluir",
    "refluamos": "refluir",
    "refluas": "refluir",
    "refluem": "refluir",
    "refluentes": "refluente",
    "reflui": "refluir",
    "refluindo": "refluir",
    "refluirdes": "refluir",
    "refluirei": "refluir",
    "refluireis": "refluir",
    "refluiremos": "refluir",
    "refluiria": "refluir",
    "refluiriam": "refluir",
    "refluirias": "refluir",
    "refluirmo": "refluir",
    "refluirmos": "refluir",
    "refluirá": "refluir",
    "refluirás": "refluir",
    "refluirão": "refluir",
    "refluiríamos": "refluir",
    "refluiríeis": "refluir",
    "refluis": "refluir",
    "refluiu": "refluir",
    "refluo": "refluir",
    "reflutua": "reflutuar",
    "reflutuada": "reflutuar",
    "reflutuadas": "reflutuar",
    "reflutuado": "reflutuar",
    "reflutuados": "reflutuar",
    "reflutuai": "reflutuar",
    "reflutuais": "reflutuar",
    "reflutuam": "reflutuar",
    "reflutuamo": "reflutuar",
    "reflutuamos": "reflutuar",
    "reflutuando": "reflutuar",
    "reflutuara": "reflutuar",
    "reflutuaram": "reflutuar",
    "reflutuaras": "reflutuar",
    "reflutuarde": "reflutuar",
    "reflutuardes": "reflutuar",
    "reflutuare": "reflutuar",
    "reflutuarei": "reflutuar",
    "reflutuareis": "reflutuar",
    "reflutuarem": "reflutuar",
    "reflutuaremos": "reflutuar",
    "reflutuares": "reflutuar",
    "reflutuaria": "reflutuar",
    "reflutuariam": "reflutuar",
    "reflutuarias": "reflutuar",
    "reflutuarmo": "reflutuar",
    "reflutuarmos": "reflutuar",
    "reflutuará": "reflutuar",
    "reflutuarás": "reflutuar",
    "reflutuarão": "reflutuar",
    "reflutuaríamos": "reflutuar",
    "reflutuaríeis": "reflutuar",
    "reflutuas": "reflutuar",
    "reflutuasse": "reflutuar",
    "reflutuassem": "reflutuar",
    "reflutuasses": "reflutuar",
    "reflutuaste": "reflutuar",
    "reflutuastes": "reflutuar",
    "reflutuava": "reflutuar",
    "reflutuavam": "reflutuar",
    "reflutuavas": "reflutuar",
    "reflutuações": "reflutuação",
    "reflutue": "reflutuar",
    "reflutuei": "reflutuar",
    "reflutueis": "reflutuar",
    "reflutuem": "reflutuar",
    "reflutuemo": "reflutuar",
    "reflutuemos": "reflutuar",
    "reflutues": "reflutuar",
    "reflutuo": "reflutuar",
    "reflutuou": "reflutuar",
    "reflutuá": "reflutuar",
    "reflutuámo": "reflutuar",
    "reflutuámos": "reflutuar",
    "reflutuáramo": "reflutuar",
    "reflutuáramos": "reflutuar",
    "reflutuárei": "reflutuar",
    "reflutuáreis": "reflutuar",
    "reflutuásseis": "reflutuar",
    "reflutuássemos": "reflutuar",
    "reflutuávamo": "reflutuar",
    "reflutuávamos": "reflutuar",
    "reflutuávei": "reflutuar",
    "reflutuáveis": "reflutuar",
    "refluxos": "refluxo",
    "refluências": "refluência",
    "refluí": "refluir",
    "refluía": "refluir",
    "refluíam": "refluir",
    "refluíamo": "refluir",
    "refluíamos": "refluir",
    "refluías": "refluir",
    "refluída": "refluir",
    "refluídas": "refluir",
    "refluído": "refluir",
    "refluídos": "refluir",
    "refluíeis": "refluir",
    "refluímo": "refluir",
    "refluímos": "refluir",
    "refluíra": "refluir",
    "refluíram": "refluir",
    "refluíramo": "refluir",
    "refluíramos": "refluir",
    "refluíras": "refluir",
    "refluíreis": "refluir",
    "refluírem": "refluir",
    "refluíres": "refluir",
    "refluís": "refluir",
    "refluísse": "refluir",
    "refluísseis": "refluir",
    "refluíssem": "refluir",
    "refluíssemos": "refluir",
    "refluísses": "refluir",
    "refluíste": "refluir",
    "refluístes": "refluir",
    "refocagens": "refocagem",
    "refocila": "refocilar",
    "refocilada": "refocilar",
    "refociladas": "refocilar",
    "refocilado": "refocilar",
    "refocilados": "refocilar",
    "refocilai": "refocilar",
    "refocilais": "refocilar",
    "refocilam": "refocilar",
    "refocilamentos": "refocilamento",
    "refocilamo": "refocilar",
    "refocilamos": "refocilar",
    "refocilando": "refocilar",
    "refocilantes": "refocilante",
    "refocilara": "refocilar",
    "refocilaram": "refocilar",
    "refocilaras": "refocilar",
    "refocilarde": "refocilar",
    "refocilardes": "refocilar",
    "refocilare": "refocilar",
    "refocilarei": "refocilar",
    "refocilareis": "refocilar",
    "refocilarem": "refocilar",
    "refocilaremos": "refocilar",
    "refocilares": "refocilar",
    "refocilaria": "refocilar",
    "refocilariam": "refocilar",
    "refocilarias": "refocilar",
    "refocilarmo": "refocilar",
    "refocilarmos": "refocilar",
    "refocilará": "refocilar",
    "refocilarás": "refocilar",
    "refocilarão": "refocilar",
    "refocilaríamos": "refocilar",
    "refocilaríeis": "refocilar",
    "refocilas": "refocilar",
    "refocilasse": "refocilar",
    "refocilassem": "refocilar",
    "refocilasses": "refocilar",
    "refocilaste": "refocilar",
    "refocilastes": "refocilar",
    "refocilava": "refocilar",
    "refocilavam": "refocilar",
    "refocilavas": "refocilar",
    "refocile": "refocilar",
    "refocilei": "refocilar",
    "refocileis": "refocilar",
    "refocilem": "refocilar",
    "refocilemo": "refocilar",
    "refocilemos": "refocilar",
    "refociles": "refocilar",
    "refocilo": "refocilar",
    "refocilou": "refocilar",
    "refocilá": "refocilar",
    "refocilámo": "refocilar",
    "refocilámos": "refocilar",
    "refociláramo": "refocilar",
    "refociláramos": "refocilar",
    "refocilárei": "refocilar",
    "refociláreis": "refocilar",
    "refocilásseis": "refocilar",
    "refocilássemos": "refocilar",
    "refocilávamo": "refocilar",
    "refocilávamos": "refocilar",
    "refocilávei": "refocilar",
    "refociláveis": "refocilar",
    "refoga": "refogar",
    "refogada": "refogar",
    "refogadas": "refogar",
    "refogadazinha": "refogado",
    "refogadazinhas": "refogado",
    "refogadazita": "refogado",
    "refogadazitas": "refogado",
    "refogadinha": "refogado",
    "refogadinhas": "refogado",
    "refogadinho": "refogado",
    "refogadinhos": "refogado",
    "refogadita": "refogado",
    "refogaditas": "refogado",
    "refogadito": "refogado",
    "refogaditos": "refogado",
    "refogado": "refogar",
    "refogados": "refogar",
    "refogadozinho": "refogado",
    "refogadozinhos": "refogado",
    "refogadozito": "refogado",
    "refogadozitos": "refogado",
    "refogai": "refogar",
    "refogais": "refogar",
    "refogam": "refogar",
    "refogamo": "refogar",
    "refogamos": "refogar",
    "refogando": "refogar",
    "refogara": "refogar",
    "refogaram": "refogar",
    "refogaras": "refogar",
    "refogarde": "refogar",
    "refogardes": "refogar",
    "refogare": "refogar",
    "refogarei": "refogar",
    "refogareis": "refogar",
    "refogarem": "refogar",
    "refogaremos": "refogar",
    "refogares": "refogar",
    "refogaria": "refogar",
    "refogariam": "refogar",
    "refogarias": "refogar",
    "refogarmo": "refogar",
    "refogarmos": "refogar",
    "refogará": "refogar",
    "refogarás": "refogar",
    "refogarão": "refogar",
    "refogaríamos": "refogar",
    "refogaríeis": "refogar",
    "refogas": "refogar",
    "refogasse": "refogar",
    "refogassem": "refogar",
    "refogasses": "refogar",
    "refogaste": "refogar",
    "refogastes": "refogar",
    "refogava": "refogar",
    "refogavam": "refogar",
    "refogavas": "refogar",
    "refoge": "refugir",
    "refogem": "refugir",
    "refoges": "refugir",
    "refogo": "refogar",
    "refogou": "refogar",
    "refogue": "refogar",
    "refoguei": "refogar",
    "refogueis": "refogar",
    "refoguem": "refogar",
    "refoguemo": "refogar",
    "refoguemos": "refogar",
    "refogues": "refogar",
    "refogá": "refogar",
    "refogámo": "refogar",
    "refogámos": "refogar",
    "refogáramo": "refogar",
    "refogáramos": "refogar",
    "refogárei": "refogar",
    "refogáreis": "refogar",
    "refogásseis": "refogar",
    "refogássemos": "refogar",
    "refogávamo": "refogar",
    "refogávamos": "refogar",
    "refogávei": "refogar",
    "refogáveis": "refogar",
    "refojos": "refojo",
    "refolga": "refolgar",
    "refolgada": "refolgar",
    "refolgadas": "refolgar",
    "refolgado": "refolgar",
    "refolgados": "refolgar",
    "refolgai": "refolgar",
    "refolgais": "refolgar",
    "refolgam": "refolgar",
    "refolgamo": "refolgar",
    "refolgamos": "refolgar",
    "refolgando": "refolgar",
    "refolgara": "refolgar",
    "refolgaram": "refolgar",
    "refolgaras": "refolgar",
    "refolgarde": "refolgar",
    "refolgardes": "refolgar",
    "refolgare": "refolgar",
    "refolgarei": "refolgar",
    "refolgareis": "refolgar",
    "refolgarem": "refolgar",
    "refolgaremos": "refolgar",
    "refolgares": "refolgar",
    "refolgaria": "refolgar",
    "refolgariam": "refolgar",
    "refolgarias": "refolgar",
    "refolgarmo": "refolgar",
    "refolgarmos": "refolgar",
    "refolgará": "refolgar",
    "refolgarás": "refolgar",
    "refolgarão": "refolgar",
    "refolgaríamos": "refolgar",
    "refolgaríeis": "refolgar",
    "refolgas": "refolgar",
    "refolgasse": "refolgar",
    "refolgassem": "refolgar",
    "refolgasses": "refolgar",
    "refolgaste": "refolgar",
    "refolgastes": "refolgar",
    "refolgava": "refolgar",
    "refolgavam": "refolgar",
    "refolgavas": "refolgar",
    "refolgo": "refolgar",
    "refolgos": "refolgo",
    "refolgou": "refolgar",
    "refolgue": "refolgar",
    "refolguei": "refolgar",
    "refolgueis": "refolgar",
    "refolguem": "refolgar",
    "refolguemo": "refolgar",
    "refolguemos": "refolgar",
    "refolgues": "refolgar",
    "refolgá": "refolgar",
    "refolgámo": "refolgar",
    "refolgámos": "refolgar",
    "refolgáramo": "refolgar",
    "refolgáramos": "refolgar",
    "refolgárei": "refolgar",
    "refolgáreis": "refolgar",
    "refolgásseis": "refolgar",
    "refolgássemos": "refolgar",
    "refolgávamo": "refolgar",
    "refolgávamos": "refolgar",
    "refolgávei": "refolgar",
    "refolgáveis": "refolgar",
    "refolha": "refolhar",
    "refolhada": "refolhar",
    "refolhadas": "refolhar",
    "refolhado": "refolhar",
    "refolhados": "refolhar",
    "refolhai": "refolhar",
    "refolhais": "refolhar",
    "refolham": "refolhar",
    "refolhamentos": "refolhamento",
    "refolhamo": "refolhar",
    "refolhamos": "refolhar",
    "refolhando": "refolhar",
    "refolhara": "refolhar",
    "refolharam": "refolhar",
    "refolharas": "refolhar",
    "refolharde": "refolhar",
    "refolhardes": "refolhar",
    "refolhare": "refolhar",
    "refolharei": "refolhar",
    "refolhareis": "refolhar",
    "refolharem": "refolhar",
    "refolharemos": "refolhar",
    "refolhares": "refolhar",
    "refolharia": "refolhar",
    "refolhariam": "refolhar",
    "refolharias": "refolhar",
    "refolharmo": "refolhar",
    "refolharmos": "refolhar",
    "refolhará": "refolhar",
    "refolharás": "refolhar",
    "refolharão": "refolhar",
    "refolharíamos": "refolhar",
    "refolharíeis": "refolhar",
    "refolhas": "refolhar",
    "refolhasse": "refolhar",
    "refolhassem": "refolhar",
    "refolhasses": "refolhar",
    "refolhaste": "refolhar",
    "refolhastes": "refolhar",
    "refolhava": "refolhar",
    "refolhavam": "refolhar",
    "refolhavas": "refolhar",
    "refolhe": "refolhar",
    "refolhei": "refolhar",
    "refolheis": "refolhar",
    "refolhem": "refolhar",
    "refolhemo": "refolhar",
    "refolhemos": "refolhar",
    "refolhes": "refolhar",
    "refolho": "refolhar",
    "refolhos": "refolho",
    "refolhou": "refolhar",
    "refolhá": "refolhar",
    "refolhámo": "refolhar",
    "refolhámos": "refolhar",
    "refolháramo": "refolhar",
    "refolháramos": "refolhar",
    "refolhárei": "refolhar",
    "refolháreis": "refolhar",
    "refolhásseis": "refolhar",
    "refolhássemos": "refolhar",
    "refolhávamo": "refolhar",
    "refolhávamos": "refolhar",
    "refolhávei": "refolhar",
    "refolháveis": "refolhar",
    "reforce": "reforçar",
    "reforcei": "reforçar",
    "reforceis": "reforçar",
    "reforcem": "reforçar",
    "reforcemo": "reforçar",
    "reforcemos": "reforçar",
    "reforces": "reforçar",
    "reforja": "reforjar",
    "reforjada": "reforjar",
    "reforjadas": "reforjar",
    "reforjado": "reforjar",
    "reforjados": "reforjar",
    "reforjai": "reforjar",
    "reforjais": "reforjar",
    "reforjam": "reforjar",
    "reforjamo": "reforjar",
    "reforjamos": "reforjar",
    "reforjando": "reforjar",
    "reforjara": "reforjar",
    "reforjaram": "reforjar",
    "reforjaras": "reforjar",
    "reforjarde": "reforjar",
    "reforjardes": "reforjar",
    "reforjare": "reforjar",
    "reforjarei": "reforjar",
    "reforjareis": "reforjar",
    "reforjarem": "reforjar",
    "reforjaremos": "reforjar",
    "reforjares": "reforjar",
    "reforjaria": "reforjar",
    "reforjariam": "reforjar",
    "reforjarias": "reforjar",
    "reforjarmo": "reforjar",
    "reforjarmos": "reforjar",
    "reforjará": "reforjar",
    "reforjarás": "reforjar",
    "reforjarão": "reforjar",
    "reforjaríamos": "reforjar",
    "reforjaríeis": "reforjar",
    "reforjas": "reforjar",
    "reforjasse": "reforjar",
    "reforjassem": "reforjar",
    "reforjasses": "reforjar",
    "reforjaste": "reforjar",
    "reforjastes": "reforjar",
    "reforjava": "reforjar",
    "reforjavam": "reforjar",
    "reforjavas": "reforjar",
    "reforje": "reforjar",
    "reforjei": "reforjar",
    "reforjeis": "reforjar",
    "reforjem": "reforjar",
    "reforjemo": "reforjar",
    "reforjemos": "reforjar",
    "reforjes": "reforjar",
    "reforjo": "reforjar",
    "reforjou": "reforjar",
    "reforjá": "reforjar",
    "reforjámo": "reforjar",
    "reforjámos": "reforjar",
    "reforjáramo": "reforjar",
    "reforjáramos": "reforjar",
    "reforjárei": "reforjar",
    "reforjáreis": "reforjar",
    "reforjásseis": "reforjar",
    "reforjássemos": "reforjar",
    "reforjávamo": "reforjar",
    "reforjávamos": "reforjar",
    "reforjávei": "reforjar",
    "reforjáveis": "reforjar",
    "reforma": "reformar",
    "reformabilidades": "reformabilidade",
    "reformada": "reformar",
    "reformadas": "reformar",
    "reformadazinha": "reformado",
    "reformadazinhas": "reformado",
    "reformadazita": "reformado",
    "reformadazitas": "reformado",
    "reformado": "reformar",
    "reformadora": "reformador",
    "reformadoras": "reformador",
    "reformadorazinha": "reformador",
    "reformadorazinhas": "reformador",
    "reformadorazita": "reformador",
    "reformadorazitas": "reformador",
    "reformadores": "reformador",
    "reformadorzinho": "reformador",
    "reformadorzinhos": "reformador",
    "reformadorzito": "reformador",
    "reformadorzitos": "reformador",
    "reformados": "reformar",
    "reformadozinho": "reformado",
    "reformadozinhos": "reformado",
    "reformadozito": "reformado",
    "reformadozitos": "reformado",
    "reformai": "reformar",
    "reformais": "reformar",
    "reformam": "reformar",
    "reformamo": "reformar",
    "reformamos": "reformar",
    "reformando": "reformar",
    "reformara": "reformar",
    "reformaram": "reformar",
    "reformaras": "reformar",
    "reformarde": "reformar",
    "reformardes": "reformar",
    "reformare": "reformar",
    "reformarei": "reformar",
    "reformareis": "reformar",
    "reformarem": "reformar",
    "reformaremos": "reformar",
    "reformares": "reformar",
    "reformaria": "reformar",
    "reformariam": "reformar",
    "reformarias": "reformar",
    "reformarmo": "reformar",
    "reformarmos": "reformar",
    "reformará": "reformar",
    "reformarás": "reformar",
    "reformarão": "reformar",
    "reformaríamos": "reformar",
    "reformaríeis": "reformar",
    "reformas": "reformar",
    "reformasse": "reformar",
    "reformassem": "reformar",
    "reformasses": "reformar",
    "reformaste": "reformar",
    "reformastes": "reformar",
    "reformativa": "reformativo",
    "reformativas": "reformativo",
    "reformativos": "reformativo",
    "reformatória": "reformatório",
    "reformatórias": "reformatório",
    "reformatórios": "reformatório",
    "reformava": "reformar",
    "reformavam": "reformar",
    "reformavas": "reformar",
    "reformazinha": "reforma",
    "reformazinhas": "reforma",
    "reformazita": "reforma",
    "reformazitas": "reforma",
    "reformações": "reformação",
    "reforme": "reformar",
    "reformei": "reformar",
    "reformeis": "reformar",
    "reformem": "reformar",
    "reformemo": "reformar",
    "reformemos": "reformar",
    "reformes": "reformar",
    "reformismos": "reformismo",
    "reformistas": "reformista",
    "reformistazinha": "reformista",
    "reformistazinhas": "reformista",
    "reformistazinho": "reformista",
    "reformistazinhos": "reformista",
    "reformistazita": "reformista",
    "reformistazitas": "reformista",
    "reformistazito": "reformista",
    "reformistazitos": "reformista",
    "reformo": "reformar",
    "reformou": "reformar",
    "reformula": "reformular",
    "reformulada": "reformular",
    "reformuladas": "reformular",
    "reformulado": "reformular",
    "reformulados": "reformular",
    "reformulai": "reformular",
    "reformulais": "reformular",
    "reformulam": "reformular",
    "reformulamo": "reformular",
    "reformulamos": "reformular",
    "reformulando": "reformular",
    "reformulara": "reformular",
    "reformularam": "reformular",
    "reformularas": "reformular",
    "reformularde": "reformular",
    "reformulardes": "reformular",
    "reformulare": "reformular",
    "reformularei": "reformular",
    "reformulareis": "reformular",
    "reformularem": "reformular",
    "reformularemos": "reformular",
    "reformulares": "reformular",
    "reformularia": "reformular",
    "reformulariam": "reformular",
    "reformularias": "reformular",
    "reformularmo": "reformular",
    "reformularmos": "reformular",
    "reformulará": "reformular",
    "reformularás": "reformular",
    "reformularão": "reformular",
    "reformularíamos": "reformular",
    "reformularíeis": "reformular",
    "reformulas": "reformular",
    "reformulasse": "reformular",
    "reformulassem": "reformular",
    "reformulasses": "reformular",
    "reformulaste": "reformular",
    "reformulastes": "reformular",
    "reformulava": "reformular",
    "reformulavam": "reformular",
    "reformulavas": "reformular",
    "reformulações": "reformulação",
    "reformule": "reformular",
    "reformulei": "reformular",
    "reformuleis": "reformular",
    "reformulem": "reformular",
    "reformulemo": "reformular",
    "reformulemos": "reformular",
    "reformules": "reformular",
    "reformulo": "reformular",
    "reformulou": "reformular",
    "reformulá": "reformular",
    "reformulámo": "reformular",
    "reformulámos": "reformular",
    "reformuláramo": "reformular",
    "reformuláramos": "reformular",
    "reformulárei": "reformular",
    "reformuláreis": "reformular",
    "reformulásseis": "reformular",
    "reformulássemos": "reformular",
    "reformulávamo": "reformular",
    "reformulávamos": "reformular",
    "reformulávei": "reformular",
    "reformuláveis": "reformulável",
    "reformá": "reformar",
    "reformámo": "reformar",
    "reformámos": "reformar",
    "reformáramo": "reformar",
    "reformáramos": "reformar",
    "reformárei": "reformar",
    "reformáreis": "reformar",
    "reformásseis": "reformar",
    "reformássemos": "reformar",
    "reformávamo": "reformar",
    "reformávamos": "reformar",
    "reformávei": "reformar",
    "reformáveis": "reformável",
    "refornece": "refornecer",
    "refornecei": "refornecer",
    "reforneceis": "refornecer",
    "refornecem": "refornecer",
    "refornecemo": "refornecer",
    "refornecemos": "refornecer",
    "refornecendo": "refornecer",
    "refornecera": "refornecer",
    "reforneceram": "refornecer",
    "reforneceras": "refornecer",
    "refornecerde": "refornecer",
    "refornecerdes": "refornecer",
    "refornecere": "refornecer",
    "refornecerei": "refornecer",
    "refornecereis": "refornecer",
    "refornecerem": "refornecer",
    "reforneceremos": "refornecer",
    "reforneceres": "refornecer",
    "reforneceria": "refornecer",
    "reforneceriam": "refornecer",
    "refornecerias": "refornecer",
    "refornecermo": "refornecer",
    "refornecermos": "refornecer",
    "refornecerá": "refornecer",
    "refornecerás": "refornecer",
    "refornecerão": "refornecer",
    "reforneceríamos": "refornecer",
    "reforneceríeis": "refornecer",
    "reforneces": "refornecer",
    "refornecesse": "refornecer",
    "refornecessem": "refornecer",
    "refornecesses": "refornecer",
    "reforneceste": "refornecer",
    "refornecestes": "refornecer",
    "reforneceu": "refornecer",
    "reforneci": "refornecer",
    "refornecia": "refornecer",
    "reforneciam": "refornecer",
    "refornecias": "refornecer",
    "refornecida": "refornecer",
    "refornecidas": "refornecer",
    "refornecido": "refornecer",
    "refornecidos": "refornecer",
    "refornecimentos": "refornecimento",
    "refornecê": "refornecer",
    "refornecêramo": "refornecer",
    "refornecêramos": "refornecer",
    "refornecêrei": "refornecer",
    "refornecêreis": "refornecer",
    "refornecêsseis": "refornecer",
    "refornecêssemos": "refornecer",
    "refornecíamo": "refornecer",
    "refornecíamos": "refornecer",
    "refornecíei": "refornecer",
    "refornecíeis": "refornecer",
    "reforneça": "refornecer",
    "reforneçais": "refornecer",
    "reforneçam": "refornecer",
    "reforneçamo": "refornecer",
    "reforneçamos": "refornecer",
    "reforneças": "refornecer",
    "reforneço": "refornecer",
    "refortalece": "refortalecer",
    "refortalecei": "refortalecer",
    "refortaleceis": "refortalecer",
    "refortalecem": "refortalecer",
    "refortalecemo": "refortalecer",
    "refortalecemos": "refortalecer",
    "refortalecendo": "refortalecer",
    "refortalecera": "refortalecer",
    "refortaleceram": "refortalecer",
    "refortaleceras": "refortalecer",
    "refortalecerde": "refortalecer",
    "refortalecerdes": "refortalecer",
    "refortalecere": "refortalecer",
    "refortalecerei": "refortalecer",
    "refortalecereis": "refortalecer",
    "refortalecerem": "refortalecer",
    "refortaleceremos": "refortalecer",
    "refortaleceres": "refortalecer",
    "refortaleceria": "refortalecer",
    "refortaleceriam": "refortalecer",
    "refortalecerias": "refortalecer",
    "refortalecermo": "refortalecer",
    "refortalecermos": "refortalecer",
    "refortalecerá": "refortalecer",
    "refortalecerás": "refortalecer",
    "refortalecerão": "refortalecer",
    "refortaleceríamos": "refortalecer",
    "refortaleceríeis": "refortalecer",
    "refortaleces": "refortalecer",
    "refortalecesse": "refortalecer",
    "refortalecessem": "refortalecer",
    "refortalecesses": "refortalecer",
    "refortaleceste": "refortalecer",
    "refortalecestes": "refortalecer",
    "refortaleceu": "refortalecer",
    "refortaleci": "refortalecer",
    "refortalecia": "refortalecer",
    "refortaleciam": "refortalecer",
    "refortalecias": "refortalecer",
    "refortalecida": "refortalecer",
    "refortalecidas": "refortalecer",
    "refortalecido": "refortalecer",
    "refortalecidos": "refortalecer",
    "refortalecê": "refortalecer",
    "refortalecêramo": "refortalecer",
    "refortalecêramos": "refortalecer",
    "refortalecêrei": "refortalecer",
    "refortalecêreis": "refortalecer",
    "refortalecêsseis": "refortalecer",
    "refortalecêssemos": "refortalecer",
    "refortalecíamo": "refortalecer",
    "refortalecíamos": "refortalecer",
    "refortalecíei": "refortalecer",
    "refortalecíeis": "refortalecer",
    "refortaleça": "refortalecer",
    "refortaleçais": "refortalecer",
    "refortaleçam": "refortalecer",
    "refortaleçamo": "refortalecer",
    "refortaleçamos": "refortalecer",
    "refortaleças": "refortalecer",
    "refortaleço": "refortalecer",
    "refortifica": "refortificar",
    "refortificada": "refortificar",
    "refortificadas": "refortificar",
    "refortificado": "refortificar",
    "refortificados": "refortificar",
    "refortificai": "refortificar",
    "refortificais": "refortificar",
    "refortificam": "refortificar",
    "refortificamo": "refortificar",
    "refortificamos": "refortificar",
    "refortificando": "refortificar",
    "refortificara": "refortificar",
    "refortificaram": "refortificar",
    "refortificaras": "refortificar",
    "refortificarde": "refortificar",
    "refortificardes": "refortificar",
    "refortificare": "refortificar",
    "refortificarei": "refortificar",
    "refortificareis": "refortificar",
    "refortificarem": "refortificar",
    "refortificaremos": "refortificar",
    "refortificares": "refortificar",
    "refortificaria": "refortificar",
    "refortificariam": "refortificar",
    "refortificarias": "refortificar",
    "refortificarmo": "refortificar",
    "refortificarmos": "refortificar",
    "refortificará": "refortificar",
    "refortificarás": "refortificar",
    "refortificarão": "refortificar",
    "refortificaríamos": "refortificar",
    "refortificaríeis": "refortificar",
    "refortificas": "refortificar",
    "refortificasse": "refortificar",
    "refortificassem": "refortificar",
    "refortificasses": "refortificar",
    "refortificaste": "refortificar",
    "refortificastes": "refortificar",
    "refortificava": "refortificar",
    "refortificavam": "refortificar",
    "refortificavas": "refortificar",
    "refortifico": "refortificar",
    "refortificou": "refortificar",
    "refortificá": "refortificar",
    "refortificámo": "refortificar",
    "refortificámos": "refortificar",
    "refortificáramo": "refortificar",
    "refortificáramos": "refortificar",
    "refortificárei": "refortificar",
    "refortificáreis": "refortificar",
    "refortificásseis": "refortificar",
    "refortificássemos": "refortificar",
    "refortificávamo": "refortificar",
    "refortificávamos": "refortificar",
    "refortificávei": "refortificar",
    "refortificáveis": "refortificar",
    "refortifique": "refortificar",
    "refortifiquei": "refortificar",
    "refortifiqueis": "refortificar",
    "refortifiquem": "refortificar",
    "refortifiquemo": "refortificar",
    "refortifiquemos": "refortificar",
    "refortifiques": "refortificar",
    "reforça": "reforçar",
    "reforçada": "reforçar",
    "reforçadas": "reforçar",
    "reforçado": "reforçar",
    "reforçadora": "reforçador",
    "reforçadoras": "reforçador",
    "reforçadores": "reforçador",
    "reforçados": "reforçar",
    "reforçadíssima": "reforçado",
    "reforçadíssimas": "reforçado",
    "reforçadíssimo": "reforçado",
    "reforçadíssimos": "reforçado",
    "reforçai": "reforçar",
    "reforçais": "reforçar",
    "reforçam": "reforçar",
    "reforçamo": "reforçar",
    "reforçamos": "reforçar",
    "reforçando": "reforçar",
    "reforçara": "reforçar",
    "reforçaram": "reforçar",
    "reforçaras": "reforçar",
    "reforçarde": "reforçar",
    "reforçardes": "reforçar",
    "reforçare": "reforçar",
    "reforçarei": "reforçar",
    "reforçareis": "reforçar",
    "reforçarem": "reforçar",
    "reforçaremos": "reforçar",
    "reforçares": "reforçar",
    "reforçaria": "reforçar",
    "reforçariam": "reforçar",
    "reforçarias": "reforçar",
    "reforçarmo": "reforçar",
    "reforçarmos": "reforçar",
    "reforçará": "reforçar",
    "reforçarás": "reforçar",
    "reforçarão": "reforçar",
    "reforçaríamos": "reforçar",
    "reforçaríeis": "reforçar",
    "reforças": "reforçar",
    "reforçasse": "reforçar",
    "reforçassem": "reforçar",
    "reforçasses": "reforçar",
    "reforçaste": "reforçar",
    "reforçastes": "reforçar",
    "reforçativa": "reforçativo",
    "reforçativas": "reforçativo",
    "reforçativos": "reforçativo",
    "reforçava": "reforçar",
    "reforçavam": "reforçar",
    "reforçavas": "reforçar",
    "reforço": "reforçar",
    "reforços": "reforço",
    "reforçou": "reforçar",
    "reforçá": "reforçar",
    "reforçámo": "reforçar",
    "reforçámos": "reforçar",
    "reforçáramo": "reforçar",
    "reforçáramos": "reforçar",
    "reforçárei": "reforçar",
    "reforçáreis": "reforçar",
    "reforçásseis": "reforçar",
    "reforçássemos": "reforçar",
    "reforçávamo": "reforçar",
    "reforçávamos": "reforçar",
    "reforçávei": "reforçar",
    "reforçáveis": "reforçável",
    "refracta": "refracto",
    "refractada": "refractar",
    "refractadas": "refractar",
    "refractado": "refractar",
    "refractados": "refractar",
    "refractai": "refractar",
    "refractais": "refractar",
    "refractam": "refractar",
    "refractamo": "refractar",
    "refractamos": "refractar",
    "refractando": "refractar",
    "refractara": "refractar",
    "refractaram": "refractar",
    "refractaras": "refractar",
    "refractarde": "refractar",
    "refractardes": "refractar",
    "refractare": "refractar",
    "refractarei": "refractar",
    "refractareis": "refractar",
    "refractarem": "refractar",
    "refractaremos": "refractar",
    "refractares": "refractar",
    "refractaria": "refractar",
    "refractariam": "refractar",
    "refractarias": "refractar",
    "refractarismos": "refractarismo",
    "refractarmo": "refractar",
    "refractarmos": "refractar",
    "refractará": "refractar",
    "refractarás": "refractar",
    "refractarão": "refractar",
    "refractaríamos": "refractar",
    "refractaríeis": "refractar",
    "refractas": "refracto",
    "refractasse": "refractar",
    "refractassem": "refractar",
    "refractasses": "refractar",
    "refractaste": "refractar",
    "refractastes": "refractar",
    "refractava": "refractar",
    "refractavam": "refractar",
    "refractavas": "refractar",
    "refracte": "refractar",
    "refractei": "refractar",
    "refracteis": "refractar",
    "refractem": "refractar",
    "refractemo": "refractar",
    "refractemos": "refractar",
    "refractes": "refractar",
    "refractiva": "refractivo",
    "refractivas": "refractivo",
    "refractividades": "refractividade",
    "refractivos": "refractivo",
    "refracto": "refractar",
    "refractometrias": "refractometria",
    "refractométrica": "refractométrico",
    "refractométricas": "refractométrico",
    "refractométricos": "refractométrico",
    "refractora": "refractor",
    "refractoras": "refractor",
    "refractores": "refractor",
    "refractos": "refracto",
    "refractou": "refractar",
    "refractá": "refractar",
    "refractámo": "refractar",
    "refractámos": "refractar",
    "refractáramo": "refractar",
    "refractáramos": "refractar",
    "refractárei": "refractar",
    "refractáreis": "refractar",
    "refractária": "refractário",
    "refractárias": "refractário",
    "refractários": "refractário",
    "refractásseis": "refractar",
    "refractássemos": "refractar",
    "refractávamo": "refractar",
    "refractávamos": "refractar",
    "refractávei": "refractar",
    "refractáveis": "refractar",
    "refractómetros": "refractómetro",
    "refracções": "refracção",
    "refrange": "refranger",
    "refrangei": "refranger",
    "refrangeis": "refranger",
    "refrangem": "refranger",
    "refrangemo": "refranger",
    "refrangemos": "refranger",
    "refrangendo": "refranger",
    "refrangentes": "refrangente",
    "refrangera": "refranger",
    "refrangeram": "refranger",
    "refrangeras": "refranger",
    "refrangerde": "refranger",
    "refrangerdes": "refranger",
    "refrangere": "refranger",
    "refrangerei": "refranger",
    "refrangereis": "refranger",
    "refrangerem": "refranger",
    "refrangeremos": "refranger",
    "refrangeres": "refranger",
    "refrangeria": "refranger",
    "refrangeriam": "refranger",
    "refrangerias": "refranger",
    "refrangermo": "refranger",
    "refrangermos": "refranger",
    "refrangerá": "refranger",
    "refrangerás": "refranger",
    "refrangerão": "refranger",
    "refrangeríamos": "refranger",
    "refrangeríeis": "refranger",
    "refranges": "refranger",
    "refrangesse": "refranger",
    "refrangessem": "refranger",
    "refrangesses": "refranger",
    "refrangeste": "refranger",
    "refrangestes": "refranger",
    "refrangeu": "refranger",
    "refrangi": "refranger",
    "refrangia": "refranger",
    "refrangiam": "refranger",
    "refrangias": "refranger",
    "refrangibilidades": "refrangibilidade",
    "refrangida": "refranger",
    "refrangidas": "refranger",
    "refrangido": "refranger",
    "refrangidos": "refranger",
    "refrangê": "refranger",
    "refrangências": "refrangência",
    "refrangêramo": "refranger",
    "refrangêramos": "refranger",
    "refrangêrei": "refranger",
    "refrangêreis": "refranger",
    "refrangêsseis": "refranger",
    "refrangêssemos": "refranger",
    "refrangíamo": "refranger",
    "refrangíamos": "refranger",
    "refrangíei": "refranger",
    "refrangíeis": "refranger",
    "refrangíveis": "refrangível",
    "refranja": "refranger",
    "refranjais": "refranger",
    "refranjam": "refranger",
    "refranjamo": "refranger",
    "refranjamos": "refranger",
    "refranjas": "refranger",
    "refranjo": "refranger",
    "refreada": "refrear",
    "refreadas": "refrear",
    "refreado": "refrear",
    "refreadora": "refreador",
    "refreadoras": "refreador",
    "refreadores": "refreador",
    "refreados": "refrear",
    "refreai": "refrear",
    "refreais": "refrear",
    "refreamentos": "refreamento",
    "refreamo": "refrear",
    "refreamos": "refrear",
    "refreando": "refrear",
    "refreara": "refrear",
    "refrearam": "refrear",
    "refrearas": "refrear",
    "refrearde": "refrear",
    "refreardes": "refrear",
    "refreare": "refrear",
    "refrearei": "refrear",
    "refreareis": "refrear",
    "refrearem": "refrear",
    "refrearemos": "refrear",
    "refreares": "refrear",
    "refrearia": "refrear",
    "refreariam": "refrear",
    "refrearias": "refrear",
    "refrearmo": "refrear",
    "refrearmos": "refrear",
    "refreará": "refrear",
    "refrearás": "refrear",
    "refrearão": "refrear",
    "refrearíamos": "refrear",
    "refrearíeis": "refrear",
    "refreasse": "refrear",
    "refreassem": "refrear",
    "refreasses": "refrear",
    "refreaste": "refrear",
    "refreastes": "refrear",
    "refreava": "refrear",
    "refreavam": "refrear",
    "refreavas": "refrear",
    "refreei": "refrear",
    "refreeis": "refrear",
    "refreemo": "refrear",
    "refreemos": "refrear",
    "refrega": "refregar",
    "refregada": "refregar",
    "refregadas": "refregar",
    "refregado": "refregar",
    "refregados": "refregar",
    "refregai": "refregar",
    "refregais": "refregar",
    "refregam": "refregar",
    "refregamo": "refregar",
    "refregamos": "refregar",
    "refregando": "refregar",
    "refregara": "refregar",
    "refregaram": "refregar",
    "refregaras": "refregar",
    "refregardes": "refregar",
    "refregarei": "refregar",
    "refregareis": "refregar",
    "refregarem": "refregar",
    "refregaremos": "refregar",
    "refregares": "refregar",
    "refregaria": "refregar",
    "refregariam": "refregar",
    "refregarias": "refregar",
    "refregarmo": "refregar",
    "refregarmos": "refregar",
    "refregará": "refregar",
    "refregarás": "refregar",
    "refregarão": "refregar",
    "refregaríamos": "refregar",
    "refregaríeis": "refregar",
    "refregas": "refregar",
    "refregasse": "refregar",
    "refregassem": "refregar",
    "refregasses": "refregar",
    "refregaste": "refregar",
    "refregastes": "refregar",
    "refregava": "refregar",
    "refregavam": "refregar",
    "refregavas": "refregar",
    "refrego": "refregar",
    "refregou": "refregar",
    "refregue": "refregar",
    "refreguei": "refregar",
    "refregueis": "refregar",
    "refreguem": "refregar",
    "refreguemo": "refregar",
    "refreguemos": "refregar",
    "refregues": "refregar",
    "refregámo": "refregar",
    "refregámos": "refregar",
    "refregáramo": "refregar",
    "refregáramos": "refregar",
    "refregáreis": "refregar",
    "refregásseis": "refregar",
    "refregássemos": "refregar",
    "refregávamo": "refregar",
    "refregávamos": "refregar",
    "refregáveis": "refregar",
    "refreia": "refrear",
    "refreiam": "refrear",
    "refreias": "refrear",
    "refreie": "refrear",
    "refreiem": "refrear",
    "refreies": "refrear",
    "refreio": "refrear",
    "refreios": "refreio",
    "refreou": "refrear",
    "refresca": "refrescar",
    "refrescada": "refrescar",
    "refrescadas": "refrescar",
    "refrescadelas": "refrescadela",
    "refrescado": "refrescar",
    "refrescados": "refrescar",
    "refrescai": "refrescar",
    "refrescais": "refrescar",
    "refrescam": "refrescar",
    "refrescamentos": "refrescamento",
    "refrescamo": "refrescar",
    "refrescamos": "refrescar",
    "refrescando": "refrescar",
    "refrescantes": "refrescante",
    "refrescara": "refrescar",
    "refrescaram": "refrescar",
    "refrescaras": "refrescar",
    "refrescarde": "refrescar",
    "refrescardes": "refrescar",
    "refrescare": "refrescar",
    "refrescarei": "refrescar",
    "refrescareis": "refrescar",
    "refrescarem": "refrescar",
    "refrescaremos": "refrescar",
    "refrescares": "refrescar",
    "refrescaria": "refrescar",
    "refrescariam": "refrescar",
    "refrescarias": "refrescar",
    "refrescarmo": "refrescar",
    "refrescarmos": "refrescar",
    "refrescará": "refrescar",
    "refrescarás": "refrescar",
    "refrescarão": "refrescar",
    "refrescaríamos": "refrescar",
    "refrescaríeis": "refrescar",
    "refrescas": "refrescar",
    "refrescasse": "refrescar",
    "refrescassem": "refrescar",
    "refrescasses": "refrescar",
    "refrescaste": "refrescar",
    "refrescastes": "refrescar",
    "refrescativa": "refrescativo",
    "refrescativas": "refrescativo",
    "refrescativos": "refrescativo",
    "refrescava": "refrescar",
    "refrescavam": "refrescar",
    "refrescavas": "refrescar",
    "refresco": "refrescar",
    "refrescos": "refresco",
    "refrescou": "refrescar",
    "refrescá": "refrescar",
    "refrescámo": "refrescar",
    "refrescámos": "refrescar",
    "refrescáramo": "refrescar",
    "refrescáramos": "refrescar",
    "refrescárei": "refrescar",
    "refrescáreis": "refrescar",
    "refrescásseis": "refrescar",
    "refrescássemos": "refrescar",
    "refrescávamo": "refrescar",
    "refrescávamos": "refrescar",
    "refrescávei": "refrescar",
    "refrescáveis": "refrescar",
    "refresque": "refrescar",
    "refresquei": "refrescar",
    "refresqueis": "refrescar",
    "refresquem": "refrescar",
    "refresquemo": "refrescar",
    "refresquemos": "refrescar",
    "refresques": "refrescar",
    "refreá": "refrear",
    "refreámo": "refrear",
    "refreámos": "refrear",
    "refreáramo": "refrear",
    "refreáramos": "refrear",
    "refreárei": "refrear",
    "refreáreis": "refrear",
    "refreásseis": "refrear",
    "refreássemos": "refrear",
    "refreávamo": "refrear",
    "refreávamos": "refrear",
    "refreávei": "refrear",
    "refreáveis": "refreável",
    "refrigentes": "refrigente",
    "refrigera": "refrigerar",
    "refrigerada": "refrigerar",
    "refrigeradas": "refrigerar",
    "refrigerado": "refrigerar",
    "refrigeradores": "refrigerador",
    "refrigerados": "refrigerar",
    "refrigerai": "refrigerar",
    "refrigerais": "refrigerar",
    "refrigeram": "refrigerar",
    "refrigeramo": "refrigerar",
    "refrigeramos": "refrigerar",
    "refrigerando": "refrigerar",
    "refrigerantes": "refrigerante",
    "refrigerantezinha": "refrigerante",
    "refrigerantezinhas": "refrigerante",
    "refrigerantezinho": "refrigerante",
    "refrigerantezinhos": "refrigerante",
    "refrigerantezita": "refrigerante",
    "refrigerantezitas": "refrigerante",
    "refrigerantezito": "refrigerante",
    "refrigerantezitos": "refrigerante",
    "refrigerara": "refrigerar",
    "refrigeraram": "refrigerar",
    "refrigeraras": "refrigerar",
    "refrigerarde": "refrigerar",
    "refrigerardes": "refrigerar",
    "refrigerare": "refrigerar",
    "refrigerarei": "refrigerar",
    "refrigerareis": "refrigerar",
    "refrigerarem": "refrigerar",
    "refrigeraremos": "refrigerar",
    "refrigerares": "refrigerar",
    "refrigeraria": "refrigerar",
    "refrigerariam": "refrigerar",
    "refrigerarias": "refrigerar",
    "refrigerarmo": "refrigerar",
    "refrigerarmos": "refrigerar",
    "refrigerará": "refrigerar",
    "refrigerarás": "refrigerar",
    "refrigerarão": "refrigerar",
    "refrigeraríamos": "refrigerar",
    "refrigeraríeis": "refrigerar",
    "refrigeras": "refrigerar",
    "refrigerasse": "refrigerar",
    "refrigerassem": "refrigerar",
    "refrigerasses": "refrigerar",
    "refrigeraste": "refrigerar",
    "refrigerastes": "refrigerar",
    "refrigerativa": "refrigerativo",
    "refrigerativas": "refrigerativo",
    "refrigerativos": "refrigerativo",
    "refrigeratórios": "refrigeratório",
    "refrigerava": "refrigerar",
    "refrigeravam": "refrigerar",
    "refrigeravas": "refrigerar",
    "refrigerações": "refrigeração",
    "refrigere": "refrigerar",
    "refrigerei": "refrigerar",
    "refrigereis": "refrigerar",
    "refrigerem": "refrigerar",
    "refrigeremo": "refrigerar",
    "refrigeremos": "refrigerar",
    "refrigeres": "refrigerar",
    "refrigero": "refrigerar",
    "refrigerou": "refrigerar",
    "refrigerá": "refrigerar",
    "refrigerámo": "refrigerar",
    "refrigerámos": "refrigerar",
    "refrigeráramo": "refrigerar",
    "refrigeráramos": "refrigerar",
    "refrigerárei": "refrigerar",
    "refrigeráreis": "refrigerar",
    "refrigerásseis": "refrigerar",
    "refrigerássemos": "refrigerar",
    "refrigerávamo": "refrigerar",
    "refrigerávamos": "refrigerar",
    "refrigerávei": "refrigerar",
    "refrigeráveis": "refrigerar",
    "refrigérios": "refrigério",
    "refringibilidades": "refringibilidade",
    "refringências": "refringência",
    "refrondesce": "refrondescer",
    "refrondescei": "refrondescer",
    "refrondesceis": "refrondescer",
    "refrondescem": "refrondescer",
    "refrondescemo": "refrondescer",
    "refrondescemos": "refrondescer",
    "refrondescendo": "refrondescer",
    "refrondescera": "refrondescer",
    "refrondesceram": "refrondescer",
    "refrondesceras": "refrondescer",
    "refrondescerdes": "refrondescer",
    "refrondescerei": "refrondescer",
    "refrondescereis": "refrondescer",
    "refrondescerem": "refrondescer",
    "refrondesceremos": "refrondescer",
    "refrondesceres": "refrondescer",
    "refrondesceria": "refrondescer",
    "refrondesceriam": "refrondescer",
    "refrondescerias": "refrondescer",
    "refrondescermo": "refrondescer",
    "refrondescermos": "refrondescer",
    "refrondescerá": "refrondescer",
    "refrondescerás": "refrondescer",
    "refrondescerão": "refrondescer",
    "refrondesceríamos": "refrondescer",
    "refrondesceríeis": "refrondescer",
    "refrondesces": "refrondescer",
    "refrondescesse": "refrondescer",
    "refrondescessem": "refrondescer",
    "refrondescesses": "refrondescer",
    "refrondesceste": "refrondescer",
    "refrondescestes": "refrondescer",
    "refrondesceu": "refrondescer",
    "refrondesci": "refrondescer",
    "refrondescia": "refrondescer",
    "refrondesciam": "refrondescer",
    "refrondescias": "refrondescer",
    "refrondescida": "refrondescer",
    "refrondescidas": "refrondescer",
    "refrondescido": "refrondescer",
    "refrondescidos": "refrondescer",
    "refrondescêramo": "refrondescer",
    "refrondescêramos": "refrondescer",
    "refrondescêreis": "refrondescer",
    "refrondescêsseis": "refrondescer",
    "refrondescêssemos": "refrondescer",
    "refrondescíamo": "refrondescer",
    "refrondescíamos": "refrondescer",
    "refrondescíeis": "refrondescer",
    "refrondesça": "refrondescer",
    "refrondesçais": "refrondescer",
    "refrondesçam": "refrondescer",
    "refrondesçamo": "refrondescer",
    "refrondesçamos": "refrondescer",
    "refrondesças": "refrondescer",
    "refrondesço": "refrondescer",
    "refrulha": "refrulhar",
    "refrulhada": "refrulhar",
    "refrulhadas": "refrulhar",
    "refrulhado": "refrulhar",
    "refrulhados": "refrulhar",
    "refrulhai": "refrulhar",
    "refrulhais": "refrulhar",
    "refrulham": "refrulhar",
    "refrulhamo": "refrulhar",
    "refrulhamos": "refrulhar",
    "refrulhando": "refrulhar",
    "refrulhara": "refrulhar",
    "refrulharam": "refrulhar",
    "refrulharas": "refrulhar",
    "refrulhardes": "refrulhar",
    "refrulharei": "refrulhar",
    "refrulhareis": "refrulhar",
    "refrulharem": "refrulhar",
    "refrulharemos": "refrulhar",
    "refrulhares": "refrulhar",
    "refrulharia": "refrulhar",
    "refrulhariam": "refrulhar",
    "refrulharias": "refrulhar",
    "refrulharmo": "refrulhar",
    "refrulharmos": "refrulhar",
    "refrulhará": "refrulhar",
    "refrulharás": "refrulhar",
    "refrulharão": "refrulhar",
    "refrulharíamos": "refrulhar",
    "refrulharíeis": "refrulhar",
    "refrulhas": "refrulhar",
    "refrulhasse": "refrulhar",
    "refrulhassem": "refrulhar",
    "refrulhasses": "refrulhar",
    "refrulhaste": "refrulhar",
    "refrulhastes": "refrulhar",
    "refrulhava": "refrulhar",
    "refrulhavam": "refrulhar",
    "refrulhavas": "refrulhar",
    "refrulhe": "refrulhar",
    "refrulhei": "refrulhar",
    "refrulheis": "refrulhar",
    "refrulhem": "refrulhar",
    "refrulhemo": "refrulhar",
    "refrulhemos": "refrulhar",
    "refrulhes": "refrulhar",
    "refrulho": "refrulhar",
    "refrulhos": "refrulho",
    "refrulhou": "refrulhar",
    "refrulhámo": "refrulhar",
    "refrulhámos": "refrulhar",
    "refrulháramo": "refrulhar",
    "refrulháramos": "refrulhar",
    "refrulháreis": "refrulhar",
    "refrulhásseis": "refrulhar",
    "refrulhássemos": "refrulhar",
    "refrulhávamo": "refrulhar",
    "refrulhávamos": "refrulhar",
    "refrulháveis": "refrulhar",
    "refréns": "refrém",
    "refrões": "refrão",
    "refuga": "refugar",
    "refugada": "refugar",
    "refugadas": "refugar",
    "refugadazinha": "refugado",
    "refugadazinhas": "refugado",
    "refugadazita": "refugado",
    "refugadazitas": "refugado",
    "refugado": "refugar",
    "refugadora": "refugador",
    "refugadoras": "refugador",
    "refugadores": "refugador",
    "refugados": "refugar",
    "refugadozinho": "refugado",
    "refugadozinhos": "refugado",
    "refugadozito": "refugado",
    "refugadozitos": "refugado",
    "refugai": "refugar",
    "refugais": "refugar",
    "refugam": "refugar",
    "refugamo": "refugar",
    "refugamos": "refugar",
    "refugando": "refugar",
    "refugara": "refugar",
    "refugaram": "refugar",
    "refugaras": "refugar",
    "refugarde": "refugar",
    "refugardes": "refugar",
    "refugare": "refugar",
    "refugarei": "refugar",
    "refugareis": "refugar",
    "refugarem": "refugar",
    "refugaremos": "refugar",
    "refugares": "refugar",
    "refugaria": "refugar",
    "refugariam": "refugar",
    "refugarias": "refugar",
    "refugarmo": "refugar",
    "refugarmos": "refugar",
    "refugará": "refugar",
    "refugarás": "refugar",
    "refugarão": "refugar",
    "refugaríamos": "refugar",
    "refugaríeis": "refugar",
    "refugas": "refugar",
    "refugasse": "refugar",
    "refugassem": "refugar",
    "refugasses": "refugar",
    "refugaste": "refugar",
    "refugastes": "refugar",
    "refugava": "refugar",
    "refugavam": "refugar",
    "refugavas": "refugar",
    "refugi": "refugir",
    "refugia": "refugir",
    "refugiada": "refugiar",
    "refugiadas": "refugiar",
    "refugiadazinha": "refugiado",
    "refugiadazinhas": "refugiado",
    "refugiadazita": "refugiado",
    "refugiadazitas": "refugiado",
    "refugiadinha": "refugiado",
    "refugiadinhas": "refugiado",
    "refugiadinho": "refugiado",
    "refugiadinhos": "refugiado",
    "refugiadita": "refugiado",
    "refugiaditas": "refugiado",
    "refugiadito": "refugiado",
    "refugiaditos": "refugiado",
    "refugiado": "refugiar",
    "refugiados": "refugiar",
    "refugiadozinho": "refugiado",
    "refugiadozinhos": "refugiado",
    "refugiadozito": "refugiado",
    "refugiadozitos": "refugiado",
    "refugiai": "refugiar",
    "refugiais": "refugiar",
    "refugiam": "refugir",
    "refugiamo": "refugiar",
    "refugiamos": "refugiar",
    "refugiando": "refugiar",
    "refugiara": "refugiar",
    "refugiaram": "refugiar",
    "refugiaras": "refugiar",
    "refugiarde": "refugiar",
    "refugiardes": "refugiar",
    "refugiare": "refugiar",
    "refugiarei": "refugiar",
    "refugiareis": "refugiar",
    "refugiarem": "refugiar",
    "refugiaremos": "refugiar",
    "refugiares": "refugiar",
    "refugiaria": "refugiar",
    "refugiariam": "refugiar",
    "refugiarias": "refugiar",
    "refugiarmo": "refugiar",
    "refugiarmos": "refugiar",
    "refugiará": "refugiar",
    "refugiarás": "refugiar",
    "refugiarão": "refugiar",
    "refugiaríamos": "refugiar",
    "refugiaríeis": "refugiar",
    "refugias": "refugir",
    "refugiasse": "refugiar",
    "refugiassem": "refugiar",
    "refugiasses": "refugiar",
    "refugiaste": "refugiar",
    "refugiastes": "refugiar",
    "refugiava": "refugiar",
    "refugiavam": "refugiar",
    "refugiavas": "refugiar",
    "refugida": "refugir",
    "refugidas": "refugir",
    "refugido": "refugir",
    "refugidos": "refugir",
    "refugie": "refugiar",
    "refugiei": "refugiar",
    "refugieis": "refugiar",
    "refugiem": "refugiar",
    "refugiemo": "refugiar",
    "refugiemos": "refugiar",
    "refugies": "refugiar",
    "refugimo": "refugir",
    "refugimos": "refugir",
    "refugindo": "refugir",
    "refugio": "refugiar",
    "refugiou": "refugiar",
    "refugira": "refugir",
    "refugiram": "refugir",
    "refugiras": "refugir",
    "refugirdes": "refugir",
    "refugirei": "refugir",
    "refugireis": "refugir",
    "refugirem": "refugir",
    "refugiremos": "refugir",
    "refugires": "refugir",
    "refugiria": "refugir",
    "refugiriam": "refugir",
    "refugirias": "refugir",
    "refugirmo": "refugir",
    "refugirmos": "refugir",
    "refugirá": "refugir",
    "refugirás": "refugir",
    "refugirão": "refugir",
    "refugiríamos": "refugir",
    "refugiríeis": "refugir",
    "refugis": "refugir",
    "refugisse": "refugir",
    "refugissem": "refugir",
    "refugisses": "refugir",
    "refugiste": "refugir",
    "refugistes": "refugir",
    "refugiu": "refugir",
    "refugiá": "refugiar",
    "refugiámo": "refugiar",
    "refugiámos": "refugiar",
    "refugiáramo": "refugiar",
    "refugiáramos": "refugiar",
    "refugiárei": "refugiar",
    "refugiáreis": "refugiar",
    "refugiásseis": "refugiar",
    "refugiássemos": "refugiar",
    "refugiávamo": "refugiar",
    "refugiávamos": "refugiar",
    "refugiávei": "refugiar",
    "refugiáveis": "refugiar",
    "refugo": "refugar",
    "refugos": "refugo",
    "refugou": "refugar",
    "refugue": "refugar",
    "refuguei": "refugar",
    "refugueis": "refugar",
    "refuguem": "refugar",
    "refuguemo": "refugar",
    "refuguemos": "refugar",
    "refugues": "refugar",
    "refugá": "refugar",
    "refugámo": "refugar",
    "refugámos": "refugar",
    "refugáramo": "refugar",
    "refugáramos": "refugar",
    "refugárei": "refugar",
    "refugáreis": "refugar",
    "refugásseis": "refugar",
    "refugássemos": "refugar",
    "refugávamo": "refugar",
    "refugávamos": "refugar",
    "refugávei": "refugar",
    "refugáveis": "refugar",
    "refugíamo": "refugir",
    "refugíamos": "refugir",
    "refugíeis": "refugir",
    "refugíramo": "refugir",
    "refugíramos": "refugir",
    "refugíreis": "refugir",
    "refugísseis": "refugir",
    "refugíssemos": "refugir",
    "refuja": "refugir",
    "refujais": "refugir",
    "refujam": "refugir",
    "refujamo": "refugir",
    "refujamos": "refugir",
    "refujas": "refugir",
    "refujo": "refugir",
    "refulge": "refulgir",
    "refulgem": "refulgir",
    "refulgentes": "refulgente",
    "refulges": "refulgir",
    "refulgi": "refulgir",
    "refulgia": "refulgir",
    "refulgiam": "refulgir",
    "refulgias": "refulgir",
    "refulgida": "refulgir",
    "refulgidas": "refulgir",
    "refulgido": "refulgir",
    "refulgidos": "refulgir",
    "refulgimo": "refulgir",
    "refulgimos": "refulgir",
    "refulgindo": "refulgir",
    "refulgira": "refulgir",
    "refulgiram": "refulgir",
    "refulgiras": "refulgir",
    "refulgirdes": "refulgir",
    "refulgirei": "refulgir",
    "refulgireis": "refulgir",
    "refulgirem": "refulgir",
    "refulgiremos": "refulgir",
    "refulgires": "refulgir",
    "refulgiria": "refulgir",
    "refulgiriam": "refulgir",
    "refulgirias": "refulgir",
    "refulgirmo": "refulgir",
    "refulgirmos": "refulgir",
    "refulgirá": "refulgir",
    "refulgirás": "refulgir",
    "refulgirão": "refulgir",
    "refulgiríamos": "refulgir",
    "refulgiríeis": "refulgir",
    "refulgis": "refulgir",
    "refulgisse": "refulgir",
    "refulgissem": "refulgir",
    "refulgisses": "refulgir",
    "refulgiste": "refulgir",
    "refulgistes": "refulgir",
    "refulgiu": "refulgir",
    "refulgências": "refulgência",
    "refulgíamo": "refulgir",
    "refulgíamos": "refulgir",
    "refulgíeis": "refulgir",
    "refulgíramo": "refulgir",
    "refulgíramos": "refulgir",
    "refulgíreis": "refulgir",
    "refulgísseis": "refulgir",
    "refulgíssemos": "refulgir",
    "refulja": "refulgir",
    "refuljais": "refulgir",
    "refuljam": "refulgir",
    "refuljamo": "refulgir",
    "refuljamos": "refulgir",
    "refuljas": "refulgir",
    "refuljo": "refulgir",
    "refunda": "refundir",
    "refundada": "refundar",
    "refundadas": "refundar",
    "refundado": "refundar",
    "refundadora": "refundador",
    "refundadoras": "refundador",
    "refundadores": "refundador",
    "refundados": "refundar",
    "refundai": "refundar",
    "refundais": "refundir",
    "refundam": "refundir",
    "refundamo": "refundir",
    "refundamos": "refundir",
    "refundando": "refundar",
    "refundara": "refundar",
    "refundaram": "refundar",
    "refundaras": "refundar",
    "refundarde": "refundar",
    "refundardes": "refundar",
    "refundare": "refundar",
    "refundarei": "refundar",
    "refundareis": "refundar",
    "refundarem": "refundar",
    "refundaremos": "refundar",
    "refundares": "refundar",
    "refundaria": "refundar",
    "refundariam": "refundar",
    "refundarias": "refundar",
    "refundarmo": "refundar",
    "refundarmos": "refundar",
    "refundará": "refundar",
    "refundarás": "refundar",
    "refundarão": "refundar",
    "refundaríamos": "refundar",
    "refundaríeis": "refundar",
    "refundas": "refundir",
    "refundasse": "refundar",
    "refundassem": "refundar",
    "refundasses": "refundar",
    "refundaste": "refundar",
    "refundastes": "refundar",
    "refundava": "refundar",
    "refundavam": "refundar",
    "refundavas": "refundar",
    "refundações": "refundação",
    "refunde": "refundir",
    "refundei": "refundar",
    "refundeis": "refundar",
    "refundem": "refundir",
    "refundemo": "refundar",
    "refundemos": "refundar",
    "refundes": "refundir",
    "refundi": "refundir",
    "refundia": "refundir",
    "refundiam": "refundir",
    "refundias": "refundir",
    "refundida": "refundir",
    "refundidas": "refundir",
    "refundido": "refundir",
    "refundidora": "refundidor",
    "refundidoras": "refundidor",
    "refundidores": "refundidor",
    "refundidos": "refundir",
    "refundimo": "refundir",
    "refundimos": "refundir",
    "refundindo": "refundir",
    "refundira": "refundir",
    "refundiram": "refundir",
    "refundiras": "refundir",
    "refundirde": "refundir",
    "refundirdes": "refundir",
    "refundire": "refundir",
    "refundirei": "refundir",
    "refundireis": "refundir",
    "refundirem": "refundir",
    "refundiremos": "refundir",
    "refundires": "refundir",
    "refundiria": "refundir",
    "refundiriam": "refundir",
    "refundirias": "refundir",
    "refundirmo": "refundir",
    "refundirmos": "refundir",
    "refundirá": "refundir",
    "refundirás": "refundir",
    "refundirão": "refundir",
    "refundiríamos": "refundir",
    "refundiríeis": "refundir",
    "refundis": "refundir",
    "refundisse": "refundir",
    "refundissem": "refundir",
    "refundisses": "refundir",
    "refundiste": "refundir",
    "refundistes": "refundir",
    "refundiu": "refundir",
    "refundições": "refundição",
    "refundo": "refundir",
    "refundou": "refundar",
    "refundá": "refundar",
    "refundámo": "refundar",
    "refundámos": "refundar",
    "refundáramo": "refundar",
    "refundáramos": "refundar",
    "refundárei": "refundar",
    "refundáreis": "refundar",
    "refundásseis": "refundar",
    "refundássemos": "refundar",
    "refundávamo": "refundar",
    "refundávamos": "refundar",
    "refundávei": "refundar",
    "refundáveis": "refundar",
    "refundíamo": "refundir",
    "refundíamos": "refundir",
    "refundíei": "refundir",
    "refundíeis": "refundir",
    "refundíramo": "refundir",
    "refundíramos": "refundir",
    "refundírei": "refundir",
    "refundíreis": "refundir",
    "refundísseis": "refundir",
    "refundíssemos": "refundir",
    "refundíveis": "refundível",
    "refusa": "refusar",
    "refusada": "refusar",
    "refusadas": "refusar",
    "refusado": "refusar",
    "refusados": "refusar",
    "refusai": "refusar",
    "refusais": "refusar",
    "refusam": "refusar",
    "refusamo": "refusar",
    "refusamos": "refusar",
    "refusando": "refusar",
    "refusara": "refusar",
    "refusaram": "refusar",
    "refusaras": "refusar",
    "refusarde": "refusar",
    "refusardes": "refusar",
    "refusare": "refusar",
    "refusarei": "refusar",
    "refusareis": "refusar",
    "refusarem": "refusar",
    "refusaremos": "refusar",
    "refusares": "refusar",
    "refusaria": "refusar",
    "refusariam": "refusar",
    "refusarias": "refusar",
    "refusarmo": "refusar",
    "refusarmos": "refusar",
    "refusará": "refusar",
    "refusarás": "refusar",
    "refusarão": "refusar",
    "refusaríamos": "refusar",
    "refusaríeis": "refusar",
    "refusas": "refusar",
    "refusasse": "refusar",
    "refusassem": "refusar",
    "refusasses": "refusar",
    "refusaste": "refusar",
    "refusastes": "refusar",
    "refusava": "refusar",
    "refusavam": "refusar",
    "refusavas": "refusar",
    "refuse": "refusar",
    "refusei": "refusar",
    "refuseis": "refusar",
    "refusem": "refusar",
    "refusemo": "refusar",
    "refusemos": "refusar",
    "refuses": "refusar",
    "refuso": "refusar",
    "refusou": "refusar",
    "refusta": "refustar",
    "refustada": "refustar",
    "refustadas": "refustar",
    "refustado": "refustar",
    "refustados": "refustar",
    "refustai": "refustar",
    "refustais": "refustar",
    "refustam": "refustar",
    "refustamo": "refustar",
    "refustamos": "refustar",
    "refustando": "refustar",
    "refustara": "refustar",
    "refustaram": "refustar",
    "refustaras": "refustar",
    "refustardes": "refustar",
    "refustarei": "refustar",
    "refustareis": "refustar",
    "refustarem": "refustar",
    "refustaremos": "refustar",
    "refustares": "refustar",
    "refustaria": "refustar",
    "refustariam": "refustar",
    "refustarias": "refustar",
    "refustarmo": "refustar",
    "refustarmos": "refustar",
    "refustará": "refustar",
    "refustarás": "refustar",
    "refustarão": "refustar",
    "refustaríamos": "refustar",
    "refustaríeis": "refustar",
    "refustas": "refustar",
    "refustasse": "refustar",
    "refustassem": "refustar",
    "refustasses": "refustar",
    "refustaste": "refustar",
    "refustastes": "refustar",
    "refustava": "refustar",
    "refustavam": "refustar",
    "refustavas": "refustar",
    "refuste": "refustar",
    "refustei": "refustar",
    "refusteis": "refustar",
    "refustem": "refustar",
    "refustemo": "refustar",
    "refustemos": "refustar",
    "refustes": "refuste",
    "refusto": "refuste",
    "refustos": "refusto",
    "refustou": "refustar",
    "refustámo": "refustar",
    "refustámos": "refustar",
    "refustáramo": "refustar",
    "refustáramos": "refustar",
    "refustáreis": "refustar",
    "refustásseis": "refustar",
    "refustássemos": "refustar",
    "refustávamo": "refustar",
    "refustávamos": "refustar",
    "refustáveis": "refustar",
    "refusá": "refusar",
    "refusámo": "refusar",
    "refusámos": "refusar",
    "refusáramo": "refusar",
    "refusáramos": "refusar",
    "refusárei": "refusar",
    "refusáreis": "refusar",
    "refusásseis": "refusar",
    "refusássemos": "refusar",
    "refusávamo": "refusar",
    "refusávamos": "refusar",
    "refusávei": "refusar",
    "refusáveis": "refusar",
    "refuta": "refutar",
    "refutada": "refutar",
    "refutadas": "refutar",
    "refutado": "refutar",
    "refutadora": "refutador",
    "refutadoras": "refutador",
    "refutadores": "refutador",
    "refutados": "refutar",
    "refutai": "refutar",
    "refutais": "refutar",
    "refutam": "refutar",
    "refutamo": "refutar",
    "refutamos": "refutar",
    "refutando": "refutar",
    "refutara": "refutar",
    "refutaram": "refutar",
    "refutaras": "refutar",
    "refutarde": "refutar",
    "refutardes": "refutar",
    "refutare": "refutar",
    "refutarei": "refutar",
    "refutareis": "refutar",
    "refutarem": "refutar",
    "refutaremos": "refutar",
    "refutares": "refutar",
    "refutaria": "refutar",
    "refutariam": "refutar",
    "refutarias": "refutar",
    "refutarmo": "refutar",
    "refutarmos": "refutar",
    "refutará": "refutar",
    "refutarás": "refutar",
    "refutarão": "refutar",
    "refutaríamos": "refutar",
    "refutaríeis": "refutar",
    "refutas": "refutar",
    "refutasse": "refutar",
    "refutassem": "refutar",
    "refutasses": "refutar",
    "refutaste": "refutar",
    "refutastes": "refutar",
    "refutativa": "refutativo",
    "refutativas": "refutativo",
    "refutativos": "refutativo",
    "refutatória": "refutatório",
    "refutatórias": "refutatório",
    "refutatórios": "refutatório",
    "refutava": "refutar",
    "refutavam": "refutar",
    "refutavas": "refutar",
    "refutações": "refutação",
    "refute": "refutar",
    "refutei": "refutar",
    "refuteis": "refutar",
    "refutem": "refutar",
    "refutemo": "refutar",
    "refutemos": "refutar",
    "refutes": "refutar",
    "refuto": "refutar",
    "refutou": "refutar",
    "refutá": "refutar",
    "refutámo": "refutar",
    "refutámos": "refutar",
    "refutáramo": "refutar",
    "refutáramos": "refutar",
    "refutárei": "refutar",
    "refutáreis": "refutar",
    "refutásseis": "refutar",
    "refutássemos": "refutar",
    "refutávamo": "refutar",
    "refutávamos": "refutar",
    "refutávei": "refutar",
    "refutáveis": "refutável",
    "refá": "refazer",
    "reféns": "refém",
    "refê": "refazer",
    "refúgios": "refúgio",
    "refúlgida": "refúlgido",
    "refúlgidas": "refúlgido",
    "refúlgidos": "refúlgido",
    "rega": "regar",
    "regabofes": "regabofe",
    "regabofistas": "regabofista",
    "regace": "regaçar",
    "regacei": "regaçar",
    "regaceis": "regaçar",
    "regacem": "regaçar",
    "regacemo": "regaçar",
    "regacemos": "regaçar",
    "regaces": "regaçar",
    "regada": "regar",
    "regadas": "regar",
    "regadia": "regadio",
    "regadias": "regadio",
    "regadios": "regadio",
    "regado": "regar",
    "regadora": "regador",
    "regadoras": "regador",
    "regadorazinha": "regador",
    "regadorazinhas": "regador",
    "regadorazita": "regador",
    "regadorazitas": "regador",
    "regadores": "regador",
    "regadorzinho": "regador",
    "regadorzinhos": "regador",
    "regadorzito": "regador",
    "regadorzitos": "regador",
    "regados": "regar",
    "regaduras": "regadura",
    "regai": "regar",
    "regais": "regar",
    "regala": "regalar",
    "regalada": "regalar",
    "regaladas": "regalar",
    "regalado": "regalar",
    "regaladora": "regalador",
    "regaladoras": "regalador",
    "regaladores": "regalador",
    "regalados": "regalar",
    "regalai": "regalar",
    "regalais": "regalar",
    "regalam": "regalar",
    "regalamo": "regalar",
    "regalamos": "regalar",
    "regalando": "regalar",
    "regalara": "regalar",
    "regalaram": "regalar",
    "regalaras": "regalar",
    "regalarde": "regalar",
    "regalardes": "regalar",
    "regalardoa": "regalardoar",
    "regalardoada": "regalardoar",
    "regalardoadas": "regalardoar",
    "regalardoado": "regalardoar",
    "regalardoados": "regalardoar",
    "regalardoai": "regalardoar",
    "regalardoais": "regalardoar",
    "regalardoam": "regalardoar",
    "regalardoamo": "regalardoar",
    "regalardoamos": "regalardoar",
    "regalardoando": "regalardoar",
    "regalardoara": "regalardoar",
    "regalardoaram": "regalardoar",
    "regalardoaras": "regalardoar",
    "regalardoarde": "regalardoar",
    "regalardoardes": "regalardoar",
    "regalardoare": "regalardoar",
    "regalardoarei": "regalardoar",
    "regalardoareis": "regalardoar",
    "regalardoarem": "regalardoar",
    "regalardoaremos": "regalardoar",
    "regalardoares": "regalardoar",
    "regalardoaria": "regalardoar",
    "regalardoariam": "regalardoar",
    "regalardoarias": "regalardoar",
    "regalardoarmo": "regalardoar",
    "regalardoarmos": "regalardoar",
    "regalardoará": "regalardoar",
    "regalardoarás": "regalardoar",
    "regalardoarão": "regalardoar",
    "regalardoaríamos": "regalardoar",
    "regalardoaríeis": "regalardoar",
    "regalardoas": "regalardoar",
    "regalardoasse": "regalardoar",
    "regalardoassem": "regalardoar",
    "regalardoasses": "regalardoar",
    "regalardoaste": "regalardoar",
    "regalardoastes": "regalardoar",
    "regalardoava": "regalardoar",
    "regalardoavam": "regalardoar",
    "regalardoavas": "regalardoar",
    "regalardoe": "regalardoar",
    "regalardoei": "regalardoar",
    "regalardoeis": "regalardoar",
    "regalardoem": "regalardoar",
    "regalardoemo": "regalardoar",
    "regalardoemos": "regalardoar",
    "regalardoes": "regalardoar",
    "regalardoo": "regalardoar",
    "regalardoou": "regalardoar",
    "regalardoá": "regalardoar",
    "regalardoámo": "regalardoar",
    "regalardoámos": "regalardoar",
    "regalardoáramo": "regalardoar",
    "regalardoáramos": "regalardoar",
    "regalardoárei": "regalardoar",
    "regalardoáreis": "regalardoar",
    "regalardoásseis": "regalardoar",
    "regalardoássemos": "regalardoar",
    "regalardoávamo": "regalardoar",
    "regalardoávamos": "regalardoar",
    "regalardoávei": "regalardoar",
    "regalardoáveis": "regalardoar",
    "regalare": "regalar",
    "regalarei": "regalar",
    "regalareis": "regalar",
    "regalarem": "regalar",
    "regalaremos": "regalar",
    "regalares": "regalar",
    "regalaria": "regalar",
    "regalariam": "regalar",
    "regalarias": "regalar",
    "regalarmo": "regalar",
    "regalarmos": "regalar",
    "regalará": "regalar",
    "regalarás": "regalar",
    "regalarão": "regalar",
    "regalaríamos": "regalar",
    "regalaríeis": "regalar",
    "regalas": "regalar",
    "regalasse": "regalar",
    "regalassem": "regalar",
    "regalasses": "regalar",
    "regalaste": "regalar",
    "regalastes": "regalar",
    "regalava": "regalar",
    "regalavam": "regalar",
    "regalavas": "regalar",
    "regale": "regalar",
    "regalei": "regalar",
    "regaleiras": "regaleira",
    "regaleis": "regalar",
    "regalem": "regalar",
    "regalemo": "regalar",
    "regalemos": "regalar",
    "regalenga": "regalengo",
    "regalengas": "regalengo",
    "regalengos": "regalengo",
    "regales": "regalar",
    "regalias": "regalia",
    "regalismos": "regalismo",
    "regalistas": "regalista",
    "regalizas": "regaliza",
    "regalizes": "regaliz",
    "regalo": "regalar",
    "regalona": "regalão",
    "regalonas": "regalona",
    "regalos": "regalo",
    "regalou": "regalar",
    "regalvaniza": "regalvanizar",
    "regalvanizada": "regalvanizar",
    "regalvanizadas": "regalvanizar",
    "regalvanizado": "regalvanizar",
    "regalvanizados": "regalvanizar",
    "regalvanizai": "regalvanizar",
    "regalvanizais": "regalvanizar",
    "regalvanizam": "regalvanizar",
    "regalvanizamo": "regalvanizar",
    "regalvanizamos": "regalvanizar",
    "regalvanizando": "regalvanizar",
    "regalvanizara": "regalvanizar",
    "regalvanizaram": "regalvanizar",
    "regalvanizaras": "regalvanizar",
    "regalvanizarde": "regalvanizar",
    "regalvanizardes": "regalvanizar",
    "regalvanizare": "regalvanizar",
    "regalvanizarei": "regalvanizar",
    "regalvanizareis": "regalvanizar",
    "regalvanizarem": "regalvanizar",
    "regalvanizaremos": "regalvanizar",
    "regalvanizares": "regalvanizar",
    "regalvanizaria": "regalvanizar",
    "regalvanizariam": "regalvanizar",
    "regalvanizarias": "regalvanizar",
    "regalvanizarmo": "regalvanizar",
    "regalvanizarmos": "regalvanizar",
    "regalvanizará": "regalvanizar",
    "regalvanizarás": "regalvanizar",
    "regalvanizarão": "regalvanizar",
    "regalvanizaríamos": "regalvanizar",
    "regalvanizaríeis": "regalvanizar",
    "regalvanizas": "regalvanizar",
    "regalvanizasse": "regalvanizar",
    "regalvanizassem": "regalvanizar",
    "regalvanizasses": "regalvanizar",
    "regalvanizaste": "regalvanizar",
    "regalvanizastes": "regalvanizar",
    "regalvanizava": "regalvanizar",
    "regalvanizavam": "regalvanizar",
    "regalvanizavas": "regalvanizar",
    "regalvanizações": "regalvanização",
    "regalvanize": "regalvanizar",
    "regalvanizei": "regalvanizar",
    "regalvanizeis": "regalvanizar",
    "regalvanizem": "regalvanizar",
    "regalvanizemo": "regalvanizar",
    "regalvanizemos": "regalvanizar",
    "regalvanizes": "regalvanizar",
    "regalvanizo": "regalvanizar",
    "regalvanizou": "regalvanizar",
    "regalvanizá": "regalvanizar",
    "regalvanizámo": "regalvanizar",
    "regalvanizámos": "regalvanizar",
    "regalvanizáramo": "regalvanizar",
    "regalvanizáramos": "regalvanizar",
    "regalvanizárei": "regalvanizar",
    "regalvanizáreis": "regalvanizar",
    "regalvanizásseis": "regalvanizar",
    "regalvanizássemos": "regalvanizar",
    "regalvanizávamo": "regalvanizar",
    "regalvanizávamos": "regalvanizar",
    "regalvanizávei": "regalvanizar",
    "regalvanizáveis": "regalvanizar",
    "regalá": "regalar",
    "regalámo": "regalar",
    "regalámos": "regalar",
    "regaláramo": "regalar",
    "regaláramos": "regalar",
    "regalárei": "regalar",
    "regaláreis": "regalar",
    "regalásseis": "regalar",
    "regalássemos": "regalar",
    "regalávamo": "regalar",
    "regalávamos": "regalar",
    "regalávei": "regalar",
    "regaláveis": "regalar",
    "regalórios": "regalório",
    "regalões": "regalão",
    "regam": "regar",
    "regamboleada": "regambolear",
    "regamboleadas": "regambolear",
    "regamboleado": "regambolear",
    "regamboleados": "regambolear",
    "regamboleai": "regambolear",
    "regamboleais": "regambolear",
    "regamboleamo": "regambolear",
    "regamboleamos": "regambolear",
    "regamboleando": "regambolear",
    "regamboleara": "regambolear",
    "regambolearam": "regambolear",
    "regambolearas": "regambolear",
    "regamboleardes": "regambolear",
    "regambolearei": "regambolear",
    "regamboleareis": "regambolear",
    "regambolearem": "regambolear",
    "regambolearemos": "regambolear",
    "regamboleares": "regambolear",
    "regambolearia": "regambolear",
    "regamboleariam": "regambolear",
    "regambolearias": "regambolear",
    "regambolearmo": "regambolear",
    "regambolearmos": "regambolear",
    "regamboleará": "regambolear",
    "regambolearás": "regambolear",
    "regambolearão": "regambolear",
    "regambolearíamos": "regambolear",
    "regambolearíeis": "regambolear",
    "regamboleasse": "regambolear",
    "regamboleassem": "regambolear",
    "regamboleasses": "regambolear",
    "regamboleaste": "regambolear",
    "regamboleastes": "regambolear",
    "regamboleava": "regambolear",
    "regamboleavam": "regambolear",
    "regamboleavas": "regambolear",
    "regamboleei": "regambolear",
    "regamboleeis": "regambolear",
    "regamboleemo": "regambolear",
    "regamboleemos": "regambolear",
    "regamboleia": "regambolear",
    "regamboleiam": "regambolear",
    "regamboleias": "regambolear",
    "regamboleie": "regambolear",
    "regamboleiem": "regambolear",
    "regamboleies": "regambolear",
    "regamboleio": "regambolear",
    "regamboleios": "regamboleio",
    "regamboleou": "regambolear",
    "regamboleámo": "regambolear",
    "regamboleámos": "regambolear",
    "regamboleáramo": "regambolear",
    "regamboleáramos": "regambolear",
    "regamboleáreis": "regambolear",
    "regamboleásseis": "regambolear",
    "regamboleássemos": "regambolear",
    "regamboleávamo": "regambolear",
    "regamboleávamos": "regambolear",
    "regamboleáveis": "regambolear",
    "regamo": "regar",
    "regamos": "regar",
    "regando": "regar",
    "reganha": "reganhar",
    "reganhada": "reganhar",
    "reganhadas": "reganhar",
    "reganhado": "reganhar",
    "reganhados": "reganhar",
    "reganhai": "reganhar",
    "reganhais": "reganhar",
    "reganham": "reganhar",
    "reganhamo": "reganhar",
    "reganhamos": "reganhar",
    "reganhando": "reganhar",
    "reganhara": "reganhar",
    "reganharam": "reganhar",
    "reganharas": "reganhar",
    "reganharde": "reganhar",
    "reganhardes": "reganhar",
    "reganhare": "reganhar",
    "reganharei": "reganhar",
    "reganhareis": "reganhar",
    "reganharem": "reganhar",
    "reganharemos": "reganhar",
    "reganhares": "reganhar",
    "reganharia": "reganhar",
    "reganhariam": "reganhar",
    "reganharias": "reganhar",
    "reganharmo": "reganhar",
    "reganharmos": "reganhar",
    "reganhará": "reganhar",
    "reganharás": "reganhar",
    "reganharão": "reganhar",
    "reganharíamos": "reganhar",
    "reganharíeis": "reganhar",
    "reganhas": "reganhar",
    "reganhasse": "reganhar",
    "reganhassem": "reganhar",
    "reganhasses": "reganhar",
    "reganhaste": "reganhar",
    "reganhastes": "reganhar",
    "reganhava": "reganhar",
    "reganhavam": "reganhar",
    "reganhavas": "reganhar",
    "reganhe": "reganhar",
    "reganhei": "reganhar",
    "reganheis": "reganhar",
    "reganhem": "reganhar",
    "reganhemo": "reganhar",
    "reganhemos": "reganhar",
    "reganhes": "reganhar",
    "reganho": "reganhar",
    "reganhou": "reganhar",
    "reganhá": "reganhar",
    "reganhámo": "reganhar",
    "reganhámos": "reganhar",
    "reganháramo": "reganhar",
    "reganháramos": "reganhar",
    "reganhárei": "reganhar",
    "reganháreis": "reganhar",
    "reganhásseis": "reganhar",
    "reganhássemos": "reganhar",
    "reganhávamo": "reganhar",
    "reganhávamos": "reganhar",
    "reganhávei": "reganhar",
    "reganháveis": "reganhar",
    "regantes": "regante",
    "regara": "regar",
    "regaram": "regar",
    "regaras": "regar",
    "regarde": "regar",
    "regardes": "regar",
    "regare": "regar",
    "regarei": "regar",
    "regareis": "regar",
    "regarem": "regar",
    "regaremos": "regar",
    "regares": "regar",
    "regaria": "regar",
    "regariam": "regar",
    "regarias": "regar",
    "regarmo": "regar",
    "regarmos": "regar",
    "regará": "regar",
    "regarás": "regar",
    "regarão": "regar",
    "regaríamos": "regar",
    "regaríeis": "regar",
    "regas": "regar",
    "regasse": "regar",
    "regassem": "regar",
    "regasses": "regar",
    "regaste": "regar",
    "regastes": "regar",
    "regata": "regatar",
    "regatada": "regatar",
    "regatadas": "regatar",
    "regatado": "regatar",
    "regatados": "regatar",
    "regatagens": "regatagem",
    "regatai": "regatar",
    "regatais": "regatar",
    "regatam": "regatar",
    "regatamo": "regatar",
    "regatamos": "regatar",
    "regatando": "regatar",
    "regatara": "regatar",
    "regataram": "regatar",
    "regataras": "regatar",
    "regatarde": "regatar",
    "regatardes": "regatar",
    "regatare": "regatar",
    "regatarei": "regatar",
    "regatareis": "regatar",
    "regatarem": "regatar",
    "regataremos": "regatar",
    "regatares": "regatar",
    "regataria": "regatar",
    "regatariam": "regatar",
    "regatarias": "regatar",
    "regatarmo": "regatar",
    "regatarmos": "regatar",
    "regatará": "regatar",
    "regatarás": "regatar",
    "regatarão": "regatar",
    "regataríamos": "regatar",
    "regataríeis": "regatar",
    "regatas": "regatar",
    "regatasse": "regatar",
    "regatassem": "regatar",
    "regatasses": "regatar",
    "regataste": "regatar",
    "regatastes": "regatar",
    "regatava": "regatar",
    "regatavam": "regatar",
    "regatavas": "regatar",
    "regate": "regatar",
    "regateada": "regatear",
    "regateadas": "regatear",
    "regateado": "regatear",
    "regateadora": "regateador",
    "regateadoras": "regateador",
    "regateadores": "regateador",
    "regateados": "regatear",
    "regateai": "regatear",
    "regateais": "regatear",
    "regateamo": "regatear",
    "regateamos": "regatear",
    "regateando": "regatear",
    "regateara": "regatear",
    "regatearam": "regatear",
    "regatearas": "regatear",
    "regatearde": "regatear",
    "regateardes": "regatear",
    "regateare": "regatear",
    "regatearei": "regatear",
    "regateareis": "regatear",
    "regatearem": "regatear",
    "regatearemos": "regatear",
    "regateares": "regatear",
    "regatearia": "regatear",
    "regateariam": "regatear",
    "regatearias": "regatear",
    "regatearmo": "regatear",
    "regatearmos": "regatear",
    "regateará": "regatear",
    "regatearás": "regatear",
    "regatearão": "regatear",
    "regatearíamos": "regatear",
    "regatearíeis": "regatear",
    "regateasse": "regatear",
    "regateassem": "regatear",
    "regateasses": "regatear",
    "regateaste": "regatear",
    "regateastes": "regatear",
    "regateava": "regatear",
    "regateavam": "regatear",
    "regateavas": "regatear",
    "regateei": "regatear",
    "regateeis": "regatear",
    "regateemo": "regatear",
    "regateemos": "regatear",
    "regatei": "regatar",
    "regateia": "regatear",
    "regateiam": "regatear",
    "regateias": "regatear",
    "regateie": "regatear",
    "regateiem": "regatear",
    "regateies": "regatear",
    "regateio": "regatear",
    "regateios": "regateio",
    "regateira": "regateiro",
    "regateirais": "regateiral",
    "regateiras": "regateiro",
    "regateirazinha": "regateiro",
    "regateirazinhas": "regateiro",
    "regateirazita": "regateiro",
    "regateirazitas": "regateiro",
    "regateirices": "regateirice",
    "regateirinha": "regateiro",
    "regateirinhas": "regateiro",
    "regateirinho": "regateiro",
    "regateirinhos": "regateiro",
    "regateirita": "regateiro",
    "regateiritas": "regateiro",
    "regateirito": "regateiro",
    "regateiritos": "regateiro",
    "regateirona": "regateiro",
    "regateironas": "regateiro",
    "regateiros": "regateiro",
    "regateirozinho": "regateiro",
    "regateirozinhos": "regateiro",
    "regateirozito": "regateiro",
    "regateirozitos": "regateiro",
    "regateirão": "regateiro",
    "regateirões": "regateiro",
    "regateis": "regatar",
    "regatem": "regatar",
    "regatemo": "regatar",
    "regatemos": "regatar",
    "regateou": "regatear",
    "regates": "regatar",
    "regateá": "regatear",
    "regateámo": "regatear",
    "regateámos": "regatear",
    "regateáramo": "regatear",
    "regateáramos": "regatear",
    "regateárei": "regatear",
    "regateáreis": "regatear",
    "regateásseis": "regatear",
    "regateássemos": "regatear",
    "regateávamo": "regatear",
    "regateávamos": "regatear",
    "regateávei": "regatear",
    "regateáveis": "regatear",
    "regatias": "regatia",
    "regatinha": "regatinhar",
    "regatinhada": "regatinhar",
    "regatinhadas": "regatinhar",
    "regatinhado": "regatinhar",
    "regatinhados": "regatinhar",
    "regatinhai": "regatinhar",
    "regatinhais": "regatinhar",
    "regatinham": "regatinhar",
    "regatinhamo": "regatinhar",
    "regatinhamos": "regatinhar",
    "regatinhando": "regatinhar",
    "regatinhara": "regatinhar",
    "regatinharam": "regatinhar",
    "regatinharas": "regatinhar",
    "regatinharde": "regatinhar",
    "regatinhardes": "regatinhar",
    "regatinhare": "regatinhar",
    "regatinharei": "regatinhar",
    "regatinhareis": "regatinhar",
    "regatinharem": "regatinhar",
    "regatinharemos": "regatinhar",
    "regatinhares": "regatinhar",
    "regatinharia": "regatinhar",
    "regatinhariam": "regatinhar",
    "regatinharias": "regatinhar",
    "regatinharmo": "regatinhar",
    "regatinharmos": "regatinhar",
    "regatinhará": "regatinhar",
    "regatinharás": "regatinhar",
    "regatinharão": "regatinhar",
    "regatinharíamos": "regatinhar",
    "regatinharíeis": "regatinhar",
    "regatinhas": "regatinhar",
    "regatinhasse": "regatinhar",
    "regatinhassem": "regatinhar",
    "regatinhasses": "regatinhar",
    "regatinhaste": "regatinhar",
    "regatinhastes": "regatinhar",
    "regatinhava": "regatinhar",
    "regatinhavam": "regatinhar",
    "regatinhavas": "regatinhar",
    "regatinhe": "regatinhar",
    "regatinhei": "regatinhar",
    "regatinheis": "regatinhar",
    "regatinhem": "regatinhar",
    "regatinhemo": "regatinhar",
    "regatinhemos": "regatinhar",
    "regatinhes": "regatinhar",
    "regatinho": "regatinhar",
    "regatinhou": "regatinhar",
    "regatinhá": "regatinhar",
    "regatinhámo": "regatinhar",
    "regatinhámos": "regatinhar",
    "regatinháramo": "regatinhar",
    "regatinháramos": "regatinhar",
    "regatinhárei": "regatinhar",
    "regatinháreis": "regatinhar",
    "regatinhásseis": "regatinhar",
    "regatinhássemos": "regatinhar",
    "regatinhávamo": "regatinhar",
    "regatinhávamos": "regatinhar",
    "regatinhávei": "regatinhar",
    "regatinháveis": "regatinhar",
    "regatistas": "regatista",
    "regato": "regatar",
    "regatoa": "regatão",
    "regatoas": "regatão",
    "regatona": "regatão",
    "regatonas": "regatão",
    "regatos": "regato",
    "regatou": "regatar",
    "regatá": "regatar",
    "regatámo": "regatar",
    "regatámos": "regatar",
    "regatáramo": "regatar",
    "regatáramos": "regatar",
    "regatárei": "regatar",
    "regatáreis": "regatar",
    "regatásseis": "regatar",
    "regatássemos": "regatar",
    "regatávamo": "regatar",
    "regatávamos": "regatar",
    "regatávei": "regatar",
    "regatáveis": "regatar",
    "regatões": "regatão",
    "regava": "regar",
    "regavam": "regar",
    "regavas": "regar",
    "regaça": "regaçar",
    "regaçada": "regaçar",
    "regaçadas": "regaçar",
    "regaçado": "regaçar",
    "regaçados": "regaçar",
    "regaçai": "regaçar",
    "regaçais": "regaçar",
    "regaçam": "regaçar",
    "regaçamo": "regaçar",
    "regaçamos": "regaçar",
    "regaçando": "regaçar",
    "regaçara": "regaçar",
    "regaçaram": "regaçar",
    "regaçaras": "regaçar",
    "regaçarde": "regaçar",
    "regaçardes": "regaçar",
    "regaçare": "regaçar",
    "regaçarei": "regaçar",
    "regaçareis": "regaçar",
    "regaçarem": "regaçar",
    "regaçaremos": "regaçar",
    "regaçares": "regaçar",
    "regaçaria": "regaçar",
    "regaçariam": "regaçar",
    "regaçarias": "regaçar",
    "regaçarmo": "regaçar",
    "regaçarmos": "regaçar",
    "regaçará": "regaçar",
    "regaçarás": "regaçar",
    "regaçarão": "regaçar",
    "regaçaríamos": "regaçar",
    "regaçaríeis": "regaçar",
    "regaças": "regaçar",
    "regaçasse": "regaçar",
    "regaçassem": "regaçar",
    "regaçasses": "regaçar",
    "regaçaste": "regaçar",
    "regaçastes": "regaçar",
    "regaçava": "regaçar",
    "regaçavam": "regaçar",
    "regaçavas": "regaçar",
    "regaço": "regaçar",
    "regaços": "regaço",
    "regaçou": "regaçar",
    "regaçá": "regaçar",
    "regaçámo": "regaçar",
    "regaçámos": "regaçar",
    "regaçáramo": "regaçar",
    "regaçáramos": "regaçar",
    "regaçárei": "regaçar",
    "regaçáreis": "regaçar",
    "regaçásseis": "regaçar",
    "regaçássemos": "regaçar",
    "regaçávamo": "regaçar",
    "regaçávamos": "regaçar",
    "regaçávei": "regaçar",
    "regaçáveis": "regaçar",
    "rege": "reger",
    "regedora": "regedor",
    "regedorais": "regedoral",
    "regedoras": "regedor",
    "regedores": "regedor",
    "regedorias": "regedoria",
    "regei": "reger",
    "regeis": "reger",
    "regela": "regelar",
    "regelada": "regelar",
    "regeladas": "regelar",
    "regelado": "regelar",
    "regeladora": "regelador",
    "regeladoras": "regelador",
    "regeladores": "regelador",
    "regelados": "regelar",
    "regelai": "regelar",
    "regelais": "regelar",
    "regelam": "regelar",
    "regelamo": "regelar",
    "regelamos": "regelar",
    "regelando": "regelar",
    "regelantes": "regelante",
    "regelara": "regelar",
    "regelaram": "regelar",
    "regelaras": "regelar",
    "regelarde": "regelar",
    "regelardes": "regelar",
    "regelare": "regelar",
    "regelarei": "regelar",
    "regelareis": "regelar",
    "regelarem": "regelar",
    "regelaremos": "regelar",
    "regelares": "regelar",
    "regelaria": "regelar",
    "regelariam": "regelar",
    "regelarias": "regelar",
    "regelarmo": "regelar",
    "regelarmos": "regelar",
    "regelará": "regelar",
    "regelarás": "regelar",
    "regelarão": "regelar",
    "regelaríamos": "regelar",
    "regelaríeis": "regelar",
    "regelas": "regelar",
    "regelasse": "regelar",
    "regelassem": "regelar",
    "regelasses": "regelar",
    "regelaste": "regelar",
    "regelastes": "regelar",
    "regelava": "regelar",
    "regelavam": "regelar",
    "regelavas": "regelar",
    "regelações": "regelação",
    "regele": "regelar",
    "regelei": "regelar",
    "regeleis": "regelar",
    "regelem": "regelar",
    "regelemo": "regelar",
    "regelemos": "regelar",
    "regeles": "regelar",
    "regelo": "regelar",
    "regelos": "regelo",
    "regelou": "regelar",
    "regelá": "regelar",
    "regelámo": "regelar",
    "regelámos": "regelar",
    "regeláramo": "regelar",
    "regeláramos": "regelar",
    "regelárei": "regelar",
    "regeláreis": "regelar",
    "regelásseis": "regelar",
    "regelássemos": "regelar",
    "regelávamo": "regelar",
    "regelávamos": "regelar",
    "regelávei": "regelar",
    "regeláveis": "regelar",
    "regem": "reger",
    "regemo": "reger",
    "regemos": "reger",
    "regenciais": "regencial",
    "regendo": "reger",
    "regenera": "regenerar",
    "regenerabilidades": "regenerabilidade",
    "regenerada": "regenerar",
    "regeneradas": "regenerar",
    "regenerado": "regenerar",
    "regeneradora": "regenerador",
    "regeneradoras": "regenerador",
    "regeneradores": "regenerador",
    "regenerados": "regenerar",
    "regenerai": "regenerar",
    "regenerais": "regenerar",
    "regeneram": "regenerar",
    "regeneramo": "regenerar",
    "regeneramos": "regenerar",
    "regeneranda": "regenerando",
    "regenerandas": "regenerando",
    "regenerando": "regenerar",
    "regenerandos": "regenerando",
    "regenerantes": "regenerante",
    "regenerara": "regenerar",
    "regeneraram": "regenerar",
    "regeneraras": "regenerar",
    "regenerarde": "regenerar",
    "regenerardes": "regenerar",
    "regenerare": "regenerar",
    "regenerarei": "regenerar",
    "regenerareis": "regenerar",
    "regenerarem": "regenerar",
    "regeneraremos": "regenerar",
    "regenerares": "regenerar",
    "regeneraria": "regenerar",
    "regenerariam": "regenerar",
    "regenerarias": "regenerar",
    "regenerarmo": "regenerar",
    "regenerarmos": "regenerar",
    "regenerará": "regenerar",
    "regenerarás": "regenerar",
    "regenerarão": "regenerar",
    "regeneraríamos": "regenerar",
    "regeneraríeis": "regenerar",
    "regeneras": "regenerar",
    "regenerasse": "regenerar",
    "regenerassem": "regenerar",
    "regenerasses": "regenerar",
    "regeneraste": "regenerar",
    "regenerastes": "regenerar",
    "regenerativa": "regenerativo",
    "regenerativas": "regenerativo",
    "regenerativos": "regenerativo",
    "regenerava": "regenerar",
    "regeneravam": "regenerar",
    "regeneravas": "regenerar",
    "regenerações": "regeneração",
    "regenere": "regenerar",
    "regenerei": "regenerar",
    "regenereis": "regenerar",
    "regenerem": "regenerar",
    "regeneremo": "regenerar",
    "regeneremos": "regenerar",
    "regeneres": "regenerar",
    "regenerescências": "regenerescência",
    "regenero": "regenerar",
    "regenerou": "regenerar",
    "regenerá": "regenerar",
    "regenerámo": "regenerar",
    "regenerámos": "regenerar",
    "regeneráramo": "regenerar",
    "regeneráramos": "regenerar",
    "regenerárei": "regenerar",
    "regeneráreis": "regenerar",
    "regenerásseis": "regenerar",
    "regenerássemos": "regenerar",
    "regenerávamo": "regenerar",
    "regenerávamos": "regenerar",
    "regenerávei": "regenerar",
    "regeneráveis": "regenerável",
    "regentes": "regente",
    "regera": "regerar",
    "regerada": "regerar",
    "regeradas": "regerar",
    "regerado": "regerar",
    "regerados": "regerar",
    "regerai": "regerar",
    "regerais": "regerar",
    "regeram": "regerar",
    "regeramo": "regerar",
    "regeramos": "regerar",
    "regerando": "regerar",
    "regerara": "regerar",
    "regeraram": "regerar",
    "regeraras": "regerar",
    "regerarde": "regerar",
    "regerardes": "regerar",
    "regerare": "regerar",
    "regerarei": "regerar",
    "regerareis": "regerar",
    "regerarem": "regerar",
    "regeraremos": "regerar",
    "regerares": "regerar",
    "regeraria": "regerar",
    "regerariam": "regerar",
    "regerarias": "regerar",
    "regerarmo": "regerar",
    "regerarmos": "regerar",
    "regerará": "regerar",
    "regerarás": "regerar",
    "regerarão": "regerar",
    "regeraríamos": "regerar",
    "regeraríeis": "regerar",
    "regeras": "regerar",
    "regerasse": "regerar",
    "regerassem": "regerar",
    "regerasses": "regerar",
    "regeraste": "regerar",
    "regerastes": "regerar",
    "regerava": "regerar",
    "regeravam": "regerar",
    "regeravas": "regerar",
    "regerde": "reger",
    "regerdes": "reger",
    "regere": "regerar",
    "regerei": "regerar",
    "regereis": "regerar",
    "regerem": "regerar",
    "regeremo": "regerar",
    "regeremos": "regerar",
    "regeres": "regerar",
    "regeria": "reger",
    "regeriam": "reger",
    "regerias": "reger",
    "regermo": "reger",
    "regermos": "reger",
    "regero": "regerar",
    "regerou": "regerar",
    "regerá": "regerar",
    "regerámo": "regerar",
    "regerámos": "regerar",
    "regeráramo": "regerar",
    "regeráramos": "regerar",
    "regerárei": "regerar",
    "regeráreis": "regerar",
    "regerás": "reger",
    "regerásseis": "regerar",
    "regerássemos": "regerar",
    "regerávamo": "regerar",
    "regerávamos": "regerar",
    "regerávei": "regerar",
    "regeráveis": "regerar",
    "regerão": "reger",
    "regeríamos": "reger",
    "regeríeis": "reger",
    "reges": "reger",
    "regesse": "reger",
    "regessem": "reger",
    "regesses": "reger",
    "regeste": "reger",
    "regestes": "reger",
    "regeu": "reger",
    "reggies": "reggie",
    "regi": "reger",
    "regia": "reger",
    "regiam": "reger",
    "regias": "reger",
    "regicidas": "regicida",
    "regicídios": "regicídio",
    "regida": "regido",
    "regidas": "regido",
    "regido": "reger",
    "regidos": "regido",
    "regimenta": "regimentar",
    "regimentada": "regimentar",
    "regimentadas": "regimentar",
    "regimentado": "regimentar",
    "regimentados": "regimentar",
    "regimentai": "regimentar",
    "regimentais": "regimentar",
    "regimentam": "regimentar",
    "regimentamo": "regimentar",
    "regimentamos": "regimentar",
    "regimentando": "regimentar",
    "regimentara": "regimentar",
    "regimentaram": "regimentar",
    "regimentaras": "regimentar",
    "regimentarde": "regimentar",
    "regimentardes": "regimentar",
    "regimentare": "regimentar",
    "regimentarei": "regimentar",
    "regimentareis": "regimentar",
    "regimentarem": "regimentar",
    "regimentaremos": "regimentar",
    "regimentares": "regimentar",
    "regimentaria": "regimentar",
    "regimentariam": "regimentar",
    "regimentarias": "regimentar",
    "regimentarmo": "regimentar",
    "regimentarmos": "regimentar",
    "regimentará": "regimentar",
    "regimentarás": "regimentar",
    "regimentarão": "regimentar",
    "regimentaríamos": "regimentar",
    "regimentaríeis": "regimentar",
    "regimentas": "regimentar",
    "regimentasse": "regimentar",
    "regimentassem": "regimentar",
    "regimentasses": "regimentar",
    "regimentaste": "regimentar",
    "regimentastes": "regimentar",
    "regimentava": "regimentar",
    "regimentavam": "regimentar",
    "regimentavas": "regimentar",
    "regimente": "regimentar",
    "regimentei": "regimentar",
    "regimenteis": "regimentar",
    "regimentem": "regimentar",
    "regimentemo": "regimentar",
    "regimentemos": "regimentar",
    "regimentes": "regimentar",
    "regimento": "regimentar",
    "regimentos": "regimento",
    "regimentou": "regimentar",
    "regimentá": "regimentar",
    "regimentámo": "regimentar",
    "regimentámos": "regimentar",
    "regimentáramo": "regimentar",
    "regimentáramos": "regimentar",
    "regimentárei": "regimentar",
    "regimentáreis": "regimentar",
    "regimentásseis": "regimentar",
    "regimentássemos": "regimentar",
    "regimentávamo": "regimentar",
    "regimentávamos": "regimentar",
    "regimentávei": "regimentar",
    "regimentáveis": "regimentar",
    "regimes": "regime",
    "reginas": "regina",
    "regionais": "regional",
    "regionalismos": "regionalismo",
    "regionalistas": "regionalista",
    "regionaliza": "regionalizar",
    "regionalizada": "regionalizar",
    "regionalizadas": "regionalizar",
    "regionalizado": "regionalizar",
    "regionalizadora": "regionalizador",
    "regionalizadoras": "regionalizador",
    "regionalizadores": "regionalizador",
    "regionalizados": "regionalizar",
    "regionalizai": "regionalizar",
    "regionalizais": "regionalizar",
    "regionalizam": "regionalizar",
    "regionalizamo": "regionalizar",
    "regionalizamos": "regionalizar",
    "regionalizando": "regionalizar",
    "regionalizara": "regionalizar",
    "regionalizaram": "regionalizar",
    "regionalizaras": "regionalizar",
    "regionalizarde": "regionalizar",
    "regionalizardes": "regionalizar",
    "regionalizare": "regionalizar",
    "regionalizarei": "regionalizar",
    "regionalizareis": "regionalizar",
    "regionalizarem": "regionalizar",
    "regionalizaremos": "regionalizar",
    "regionalizares": "regionalizar",
    "regionalizaria": "regionalizar",
    "regionalizariam": "regionalizar",
    "regionalizarias": "regionalizar",
    "regionalizarmo": "regionalizar",
    "regionalizarmos": "regionalizar",
    "regionalizará": "regionalizar",
    "regionalizarás": "regionalizar",
    "regionalizarão": "regionalizar",
    "regionalizaríamos": "regionalizar",
    "regionalizaríeis": "regionalizar",
    "regionalizas": "regionalizar",
    "regionalizasse": "regionalizar",
    "regionalizassem": "regionalizar",
    "regionalizasses": "regionalizar",
    "regionalizaste": "regionalizar",
    "regionalizastes": "regionalizar",
    "regionalizava": "regionalizar",
    "regionalizavam": "regionalizar",
    "regionalizavas": "regionalizar",
    "regionalizações": "regionalização",
    "regionalize": "regionalizar",
    "regionalizei": "regionalizar",
    "regionalizeis": "regionalizar",
    "regionalizem": "regionalizar",
    "regionalizemo": "regionalizar",
    "regionalizemos": "regionalizar",
    "regionalizes": "regionalizar",
    "regionalizo": "regionalizar",
    "regionalizou": "regionalizar",
    "regionalizá": "regionalizar",
    "regionalizámo": "regionalizar",
    "regionalizámos": "regionalizar",
    "regionalizáramo": "regionalizar",
    "regionalizáramos": "regionalizar",
    "regionalizárei": "regionalizar",
    "regionalizáreis": "regionalizar",
    "regionalizásseis": "regionalizar",
    "regionalizássemos": "regionalizar",
    "regionalizávamo": "regionalizar",
    "regionalizávamos": "regionalizar",
    "regionalizávei": "regionalizar",
    "regionalizáveis": "regionalizar",
    "regira": "regirar",
    "regirada": "regirar",
    "regiradas": "regirar",
    "regirado": "regirar",
    "regirados": "regirar",
    "regirai": "regirar",
    "regirais": "regirar",
    "regiram": "regirar",
    "regiramo": "regirar",
    "regiramos": "regirar",
    "regirando": "regirar",
    "regirara": "regirar",
    "regiraram": "regirar",
    "regiraras": "regirar",
    "regirarde": "regirar",
    "regirardes": "regirar",
    "regirare": "regirar",
    "regirarei": "regirar",
    "regirareis": "regirar",
    "regirarem": "regirar",
    "regiraremos": "regirar",
    "regirares": "regirar",
    "regiraria": "regirar",
    "regirariam": "regirar",
    "regirarias": "regirar",
    "regirarmo": "regirar",
    "regirarmos": "regirar",
    "regirará": "regirar",
    "regirarás": "regirar",
    "regirarão": "regirar",
    "regiraríamos": "regirar",
    "regiraríeis": "regirar",
    "regiras": "regirar",
    "regirasse": "regirar",
    "regirassem": "regirar",
    "regirasses": "regirar",
    "regiraste": "regirar",
    "regirastes": "regirar",
    "regirava": "regirar",
    "regiravam": "regirar",
    "regiravas": "regirar",
    "regire": "regirar",
    "regirei": "regirar",
    "regireis": "regirar",
    "regirem": "regirar",
    "regiremo": "regirar",
    "regiremos": "regirar",
    "regires": "regirar",
    "regiro": "regirar",
    "regiros": "regiro",
    "regirou": "regirar",
    "regirá": "regirar",
    "regirámo": "regirar",
    "regirámos": "regirar",
    "regiráramo": "regirar",
    "regiráramos": "regirar",
    "regirárei": "regirar",
    "regiráreis": "regirar",
    "regirásseis": "regirar",
    "regirássemos": "regirar",
    "regirávamo": "regirar",
    "regirávamos": "regirar",
    "regirávei": "regirar",
    "regiráveis": "regirar",
    "regista": "registar",
    "registada": "registar",
    "registadas": "registar",
    "registado": "registar",
    "registadora": "registador",
    "registadoras": "registadora",
    "registadores": "registador",
    "registados": "registar",
    "registai": "registar",
    "registais": "registar",
    "registam": "registar",
    "registamo": "registar",
    "registamos": "registar",
    "registando": "registar",
    "registara": "registar",
    "registaram": "registar",
    "registaras": "registar",
    "registarde": "registar",
    "registardes": "registar",
    "registare": "registar",
    "registarei": "registar",
    "registareis": "registar",
    "registarem": "registar",
    "registaremos": "registar",
    "registares": "registar",
    "registaria": "registar",
    "registariam": "registar",
    "registarias": "registar",
    "registarmo": "registar",
    "registarmos": "registar",
    "registará": "registar",
    "registarás": "registar",
    "registarão": "registar",
    "registaríamos": "registar",
    "registaríeis": "registar",
    "registas": "registar",
    "registasse": "registar",
    "registassem": "registar",
    "registasses": "registar",
    "registaste": "registar",
    "registastes": "registar",
    "registava": "registar",
    "registavam": "registar",
    "registavas": "registar",
    "registações": "registação",
    "registe": "registar",
    "registei": "registar",
    "registeis": "registar",
    "registem": "registar",
    "registemo": "registar",
    "registemos": "registar",
    "registes": "registar",
    "registo": "registar",
    "registos": "registo",
    "registou": "registar",
    "registra": "registrar",
    "registrada": "registrar",
    "registradas": "registrar",
    "registrado": "registrar",
    "registradora": "registrador",
    "registradoras": "registradora",
    "registradores": "registrador",
    "registrados": "registrar",
    "registrai": "registrar",
    "registrais": "registrar",
    "registram": "registrar",
    "registramo": "registrar",
    "registramos": "registrar",
    "registrando": "registrar",
    "registrara": "registrar",
    "registraram": "registrar",
    "registraras": "registrar",
    "registrarde": "registrar",
    "registrardes": "registrar",
    "registrare": "registrar",
    "registrarei": "registrar",
    "registrareis": "registrar",
    "registrarem": "registrar",
    "registraremos": "registrar",
    "registrares": "registrar",
    "registraria": "registrar",
    "registrariam": "registrar",
    "registrarias": "registrar",
    "registrarmo": "registrar",
    "registrarmos": "registrar",
    "registrará": "registrar",
    "registrarás": "registrar",
    "registrarão": "registrar",
    "registraríamos": "registrar",
    "registraríeis": "registrar",
    "registras": "registrar",
    "registrasse": "registrar",
    "registrassem": "registrar",
    "registrasses": "registrar",
    "registraste": "registrar",
    "registrastes": "registrar",
    "registrava": "registrar",
    "registravam": "registrar",
    "registravas": "registrar",
    "registrações": "registração",
    "registre": "registrar",
    "registrei": "registrar",
    "registreis": "registrar",
    "registrem": "registrar",
    "registremo": "registrar",
    "registremos": "registrar",
    "registres": "registrar",
    "registro": "registrar",
    "registros": "registro",
    "registrou": "registrar",
    "registrá": "registrar",
    "registrámo": "registrar",
    "registrámos": "registrar",
    "registráramo": "registrar",
    "registráramos": "registrar",
    "registrárei": "registrar",
    "registráreis": "registrar",
    "registrásseis": "registrar",
    "registrássemos": "registrar",
    "registrávamo": "registrar",
    "registrávamos": "registrar",
    "registrávei": "registrar",
    "registráveis": "registrável",
    "registá": "registar",
    "registámo": "registar",
    "registámos": "registar",
    "registáramo": "registar",
    "registáramos": "registar",
    "registárei": "registar",
    "registáreis": "registar",
    "registásseis": "registar",
    "registássemos": "registar",
    "registávamo": "registar",
    "registávamos": "registar",
    "registávei": "registar",
    "registáveis": "registável",
    "regiões": "região",
    "regnicídios": "regnicídio",
    "rego": "regar",
    "regoa": "regoar",
    "regoada": "regoar",
    "regoadas": "regoar",
    "regoado": "regoar",
    "regoados": "regoar",
    "regoai": "regoar",
    "regoais": "regoar",
    "regoam": "regoar",
    "regoamo": "regoar",
    "regoamos": "regoar",
    "regoando": "regoar",
    "regoara": "regoar",
    "regoaram": "regoar",
    "regoaras": "regoar",
    "regoarde": "regoar",
    "regoardes": "regoar",
    "regoare": "regoar",
    "regoarei": "regoar",
    "regoareis": "regoar",
    "regoarem": "regoar",
    "regoaremos": "regoar",
    "regoares": "regoar",
    "regoaria": "regoar",
    "regoariam": "regoar",
    "regoarias": "regoar",
    "regoarmo": "regoar",
    "regoarmos": "regoar",
    "regoará": "regoar",
    "regoarás": "regoar",
    "regoarão": "regoar",
    "regoaríamos": "regoar",
    "regoaríeis": "regoar",
    "regoas": "regoar",
    "regoasse": "regoar",
    "regoassem": "regoar",
    "regoasses": "regoar",
    "regoaste": "regoar",
    "regoastes": "regoar",
    "regoava": "regoar",
    "regoavam": "regoar",
    "regoavas": "regoar",
    "regoe": "regoar",
    "regoei": "regoar",
    "regoeis": "regoar",
    "regoem": "regoar",
    "regoemo": "regoar",
    "regoemos": "regoar",
    "regoes": "regoar",
    "regolas": "regola",
    "regolfos": "regolfo",
    "regolizes": "regoliz",
    "regoo": "regoar",
    "regoou": "regoar",
    "regorjeada": "regorjear",
    "regorjeadas": "regorjear",
    "regorjeado": "regorjear",
    "regorjeados": "regorjear",
    "regorjeai": "regorjear",
    "regorjeais": "regorjear",
    "regorjeamo": "regorjear",
    "regorjeamos": "regorjear",
    "regorjeando": "regorjear",
    "regorjeara": "regorjear",
    "regorjearam": "regorjear",
    "regorjearas": "regorjear",
    "regorjeardes": "regorjear",
    "regorjearei": "regorjear",
    "regorjeareis": "regorjear",
    "regorjearem": "regorjear",
    "regorjearemos": "regorjear",
    "regorjeares": "regorjear",
    "regorjearia": "regorjear",
    "regorjeariam": "regorjear",
    "regorjearias": "regorjear",
    "regorjearmo": "regorjear",
    "regorjearmos": "regorjear",
    "regorjeará": "regorjear",
    "regorjearás": "regorjear",
    "regorjearão": "regorjear",
    "regorjearíamos": "regorjear",
    "regorjearíeis": "regorjear",
    "regorjeasse": "regorjear",
    "regorjeassem": "regorjear",
    "regorjeasses": "regorjear",
    "regorjeaste": "regorjear",
    "regorjeastes": "regorjear",
    "regorjeava": "regorjear",
    "regorjeavam": "regorjear",
    "regorjeavas": "regorjear",
    "regorjeei": "regorjear",
    "regorjeeis": "regorjear",
    "regorjeemo": "regorjear",
    "regorjeemos": "regorjear",
    "regorjeia": "regorjear",
    "regorjeiam": "regorjear",
    "regorjeias": "regorjear",
    "regorjeie": "regorjear",
    "regorjeiem": "regorjear",
    "regorjeies": "regorjear",
    "regorjeio": "regorjear",
    "regorjeios": "regorjeio",
    "regorjeou": "regorjear",
    "regorjeámo": "regorjear",
    "regorjeámos": "regorjear",
    "regorjeáramo": "regorjear",
    "regorjeáramos": "regorjear",
    "regorjeáreis": "regorjear",
    "regorjeásseis": "regorjear",
    "regorjeássemos": "regorjear",
    "regorjeávamo": "regorjear",
    "regorjeávamos": "regorjear",
    "regorjeáveis": "regorjear",
    "regos": "rego",
    "regou": "regar",
    "regouga": "regougar",
    "regougada": "regougar",
    "regougadas": "regougar",
    "regougado": "regougar",
    "regougados": "regougar",
    "regougai": "regougar",
    "regougais": "regougar",
    "regougam": "regougar",
    "regougamo": "regougar",
    "regougamos": "regougar",
    "regougando": "regougar",
    "regougara": "regougar",
    "regougaram": "regougar",
    "regougaras": "regougar",
    "regougardes": "regougar",
    "regougarei": "regougar",
    "regougareis": "regougar",
    "regougarem": "regougar",
    "regougaremos": "regougar",
    "regougares": "regougar",
    "regougaria": "regougar",
    "regougariam": "regougar",
    "regougarias": "regougar",
    "regougarmo": "regougar",
    "regougarmos": "regougar",
    "regougará": "regougar",
    "regougarás": "regougar",
    "regougarão": "regougar",
    "regougaríamos": "regougar",
    "regougaríeis": "regougar",
    "regougas": "regougar",
    "regougasse": "regougar",
    "regougassem": "regougar",
    "regougasses": "regougar",
    "regougaste": "regougar",
    "regougastes": "regougar",
    "regougava": "regougar",
    "regougavam": "regougar",
    "regougavas": "regougar",
    "regougo": "regougar",
    "regougos": "regougo",
    "regougou": "regougar",
    "regougue": "regougar",
    "regouguei": "regougar",
    "regougueis": "regougar",
    "regouguem": "regougar",
    "regouguemo": "regougar",
    "regouguemos": "regougar",
    "regougues": "regougar",
    "regougámo": "regougar",
    "regougámos": "regougar",
    "regougáramo": "regougar",
    "regougáramos": "regougar",
    "regougáreis": "regougar",
    "regougásseis": "regougar",
    "regougássemos": "regougar",
    "regougávamo": "regougar",
    "regougávamos": "regougar",
    "regougáveis": "regougar",
    "regozija": "regozijar",
    "regozijada": "regozijar",
    "regozijadas": "regozijar",
    "regozijado": "regozijar",
    "regozijadora": "regozijador",
    "regozijadoras": "regozijador",
    "regozijadores": "regozijador",
    "regozijados": "regozijar",
    "regozijai": "regozijar",
    "regozijais": "regozijar",
    "regozijam": "regozijar",
    "regozijamo": "regozijar",
    "regozijamos": "regozijar",
    "regozijando": "regozijar",
    "regozijara": "regozijar",
    "regozijaram": "regozijar",
    "regozijaras": "regozijar",
    "regozijarde": "regozijar",
    "regozijardes": "regozijar",
    "regozijare": "regozijar",
    "regozijarei": "regozijar",
    "regozijareis": "regozijar",
    "regozijarem": "regozijar",
    "regozijaremos": "regozijar",
    "regozijares": "regozijar",
    "regozijaria": "regozijar",
    "regozijariam": "regozijar",
    "regozijarias": "regozijar",
    "regozijarmo": "regozijar",
    "regozijarmos": "regozijar",
    "regozijará": "regozijar",
    "regozijarás": "regozijar",
    "regozijarão": "regozijar",
    "regozijaríamos": "regozijar",
    "regozijaríeis": "regozijar",
    "regozijas": "regozijar",
    "regozijasse": "regozijar",
    "regozijassem": "regozijar",
    "regozijasses": "regozijar",
    "regozijaste": "regozijar",
    "regozijastes": "regozijar",
    "regozijava": "regozijar",
    "regozijavam": "regozijar",
    "regozijavas": "regozijar",
    "regozije": "regozijar",
    "regozijei": "regozijar",
    "regozijeis": "regozijar",
    "regozijem": "regozijar",
    "regozijemo": "regozijar",
    "regozijemos": "regozijar",
    "regozijes": "regozijar",
    "regozijo": "regozijar",
    "regozijos": "regozijo",
    "regozijou": "regozijar",
    "regozijá": "regozijar",
    "regozijámo": "regozijar",
    "regozijámos": "regozijar",
    "regozijáramo": "regozijar",
    "regozijáramos": "regozijar",
    "regozijárei": "regozijar",
    "regozijáreis": "regozijar",
    "regozijásseis": "regozijar",
    "regozijássemos": "regozijar",
    "regozijávamo": "regozijar",
    "regozijávamos": "regozijar",
    "regozijávei": "regozijar",
    "regozijáveis": "regozijar",
    "regoá": "regoar",
    "regoámo": "regoar",
    "regoámos": "regoar",
    "regoáramo": "regoar",
    "regoáramos": "regoar",
    "regoárei": "regoar",
    "regoáreis": "regoar",
    "regoásseis": "regoar",
    "regoássemos": "regoar",
    "regoávamo": "regoar",
    "regoávamos": "regoar",
    "regoávei": "regoar",
    "regoáveis": "regoar",
    "regra": "regrar",
    "regrada": "regrar",
    "regradas": "regrar",
    "regradazinha": "regrado",
    "regradazinhas": "regrado",
    "regradazita": "regrado",
    "regradazitas": "regrado",
    "regradeiras": "regradeira",
    "regradinha": "regrado",
    "regradinhas": "regrado",
    "regradinho": "regrado",
    "regradinhos": "regrado",
    "regradita": "regrado",
    "regraditas": "regrado",
    "regradito": "regrado",
    "regraditos": "regrado",
    "regrado": "regrar",
    "regradors": "regrador",
    "regrados": "regrar",
    "regradozinho": "regrado",
    "regradozinhos": "regrado",
    "regradozito": "regrado",
    "regradozitos": "regrado",
    "regradíssima": "regrado",
    "regradíssimas": "regrado",
    "regradíssimo": "regrado",
    "regradíssimos": "regrado",
    "regrai": "regrar",
    "regrais": "regrar",
    "regram": "regrar",
    "regramo": "regrar",
    "regramos": "regrar",
    "regrando": "regrar",
    "regrantes": "regrante",
    "regrara": "regrar",
    "regraram": "regrar",
    "regraras": "regrar",
    "regrarde": "regrar",
    "regrardes": "regrar",
    "regrare": "regrar",
    "regrarei": "regrar",
    "regrareis": "regrar",
    "regrarem": "regrar",
    "regraremos": "regrar",
    "regrares": "regrar",
    "regraria": "regrar",
    "regrariam": "regrar",
    "regrarias": "regrar",
    "regrarmo": "regrar",
    "regrarmos": "regrar",
    "regrará": "regrar",
    "regrarás": "regrar",
    "regrarão": "regrar",
    "regraríamos": "regrar",
    "regraríeis": "regrar",
    "regras": "regrar",
    "regrasse": "regrar",
    "regrassem": "regrar",
    "regrasses": "regrar",
    "regraste": "regrar",
    "regrastes": "regrar",
    "regrava": "regravar",
    "regravada": "regravar",
    "regravadas": "regravar",
    "regravado": "regravar",
    "regravados": "regravar",
    "regravai": "regravar",
    "regravais": "regravar",
    "regravam": "regravar",
    "regravamo": "regravar",
    "regravamos": "regravar",
    "regravando": "regravar",
    "regravara": "regravar",
    "regravaram": "regravar",
    "regravaras": "regravar",
    "regravarde": "regravar",
    "regravardes": "regravar",
    "regravare": "regravar",
    "regravarei": "regravar",
    "regravareis": "regravar",
    "regravarem": "regravar",
    "regravaremos": "regravar",
    "regravares": "regravar",
    "regravaria": "regravar",
    "regravariam": "regravar",
    "regravarias": "regravar",
    "regravarmo": "regravar",
    "regravarmos": "regravar",
    "regravará": "regravar",
    "regravarás": "regravar",
    "regravarão": "regravar",
    "regravaríamos": "regravar",
    "regravaríeis": "regravar",
    "regravas": "regravar",
    "regravasse": "regravar",
    "regravassem": "regravar",
    "regravasses": "regravar",
    "regravaste": "regravar",
    "regravastes": "regravar",
    "regravava": "regravar",
    "regravavam": "regravar",
    "regravavas": "regravar",
    "regrave": "regravar",
    "regravei": "regravar",
    "regraveis": "regravar",
    "regravem": "regravar",
    "regravemo": "regravar",
    "regravemos": "regravar",
    "regraves": "regravar",
    "regravo": "regravar",
    "regravou": "regravar",
    "regravá": "regravar",
    "regravámo": "regravar",
    "regravámos": "regravar",
    "regraváramo": "regravar",
    "regraváramos": "regravar",
    "regravárei": "regravar",
    "regraváreis": "regravar",
    "regravásseis": "regravar",
    "regravássemos": "regravar",
    "regravávamo": "regravar",
    "regravávamos": "regravar",
    "regravávei": "regravar",
    "regraváveis": "regravar",
    "regraxa": "regraxar",
    "regraxada": "regraxar",
    "regraxadas": "regraxar",
    "regraxado": "regraxar",
    "regraxados": "regraxar",
    "regraxai": "regraxar",
    "regraxais": "regraxar",
    "regraxam": "regraxar",
    "regraxamo": "regraxar",
    "regraxamos": "regraxar",
    "regraxando": "regraxar",
    "regraxara": "regraxar",
    "regraxaram": "regraxar",
    "regraxaras": "regraxar",
    "regraxarde": "regraxar",
    "regraxardes": "regraxar",
    "regraxare": "regraxar",
    "regraxarei": "regraxar",
    "regraxareis": "regraxar",
    "regraxarem": "regraxar",
    "regraxaremos": "regraxar",
    "regraxares": "regraxar",
    "regraxaria": "regraxar",
    "regraxariam": "regraxar",
    "regraxarias": "regraxar",
    "regraxarmo": "regraxar",
    "regraxarmos": "regraxar",
    "regraxará": "regraxar",
    "regraxarás": "regraxar",
    "regraxarão": "regraxar",
    "regraxaríamos": "regraxar",
    "regraxaríeis": "regraxar",
    "regraxas": "regraxar",
    "regraxasse": "regraxar",
    "regraxassem": "regraxar",
    "regraxasses": "regraxar",
    "regraxaste": "regraxar",
    "regraxastes": "regraxar",
    "regraxava": "regraxar",
    "regraxavam": "regraxar",
    "regraxavas": "regraxar",
    "regraxe": "regraxar",
    "regraxei": "regraxar",
    "regraxeis": "regraxar",
    "regraxem": "regraxar",
    "regraxemo": "regraxar",
    "regraxemos": "regraxar",
    "regraxes": "regraxar",
    "regraxo": "regraxar",
    "regraxos": "regraxo",
    "regraxou": "regraxar",
    "regraxá": "regraxar",
    "regraxámo": "regraxar",
    "regraxámos": "regraxar",
    "regraxáramo": "regraxar",
    "regraxáramos": "regraxar",
    "regraxárei": "regraxar",
    "regraxáreis": "regraxar",
    "regraxásseis": "regraxar",
    "regraxássemos": "regraxar",
    "regraxávamo": "regraxar",
    "regraxávamos": "regraxar",
    "regraxávei": "regraxar",
    "regraxáveis": "regraxar",
    "regre": "regrar",
    "regredi": "regredir",
    "regredia": "regredir",
    "regrediam": "regredir",
    "regredias": "regredir",
    "regredida": "regredir",
    "regredidas": "regredir",
    "regredido": "regredir",
    "regredidos": "regredir",
    "regredimo": "regredir",
    "regredimos": "regredir",
    "regredindo": "regredir",
    "regredira": "regredir",
    "regrediram": "regredir",
    "regrediras": "regredir",
    "regredirdes": "regredir",
    "regredirei": "regredir",
    "regredireis": "regredir",
    "regredirem": "regredir",
    "regrediremos": "regredir",
    "regredires": "regredir",
    "regrediria": "regredir",
    "regrediriam": "regredir",
    "regredirias": "regredir",
    "regredirmo": "regredir",
    "regredirmos": "regredir",
    "regredirá": "regredir",
    "regredirás": "regredir",
    "regredirão": "regredir",
    "regrediríamos": "regredir",
    "regrediríeis": "regredir",
    "regredis": "regredir",
    "regredisse": "regredir",
    "regredissem": "regredir",
    "regredisses": "regredir",
    "regrediste": "regredir",
    "regredistes": "regredir",
    "regrediu": "regredir",
    "regredíamo": "regredir",
    "regredíamos": "regredir",
    "regredíeis": "regredir",
    "regredíramo": "regredir",
    "regredíramos": "regredir",
    "regredíreis": "regredir",
    "regredísseis": "regredir",
    "regredíssemos": "regredir",
    "regrei": "regrar",
    "regreis": "regrar",
    "regrem": "regrar",
    "regremo": "regrar",
    "regremos": "regrar",
    "regres": "regrar",
    "regressa": "regressar",
    "regressada": "regressar",
    "regressadas": "regressar",
    "regressado": "regressar",
    "regressados": "regressar",
    "regressai": "regressar",
    "regressais": "regressar",
    "regressam": "regressar",
    "regressamo": "regressar",
    "regressamos": "regressar",
    "regressando": "regressar",
    "regressara": "regressar",
    "regressaram": "regressar",
    "regressaras": "regressar",
    "regressardes": "regressar",
    "regressarei": "regressar",
    "regressareis": "regressar",
    "regressarem": "regressar",
    "regressaremos": "regressar",
    "regressares": "regressar",
    "regressaria": "regressar",
    "regressariam": "regressar",
    "regressarias": "regressar",
    "regressarmo": "regressar",
    "regressarmos": "regressar",
    "regressará": "regressar",
    "regressarás": "regressar",
    "regressarão": "regressar",
    "regressaríamos": "regressar",
    "regressaríeis": "regressar",
    "regressas": "regressar",
    "regressasse": "regressar",
    "regressassem": "regressar",
    "regressasses": "regressar",
    "regressaste": "regressar",
    "regressastes": "regressar",
    "regressava": "regressar",
    "regressavam": "regressar",
    "regressavas": "regressar",
    "regresse": "regressar",
    "regressei": "regressar",
    "regresseis": "regressar",
    "regressem": "regressar",
    "regressemo": "regressar",
    "regressemos": "regressar",
    "regresses": "regressar",
    "regressistas": "regressista",
    "regressiva": "regressivo",
    "regressivas": "regressivo",
    "regressividades": "regressividade",
    "regressivos": "regressivo",
    "regresso": "regressar",
    "regressos": "regresso",
    "regressou": "regressar",
    "regressámo": "regressar",
    "regressámos": "regressar",
    "regressáramo": "regressar",
    "regressáramos": "regressar",
    "regressáreis": "regressar",
    "regressásseis": "regressar",
    "regressássemos": "regressar",
    "regressávamo": "regressar",
    "regressávamos": "regressar",
    "regressáveis": "regressar",
    "regressões": "regressão",
    "regretas": "regreta",
    "regrida": "regredir",
    "regridais": "regredir",
    "regridam": "regredir",
    "regridamo": "regredir",
    "regridamos": "regredir",
    "regridas": "regredir",
    "regride": "regredir",
    "regridem": "regredir",
    "regrides": "regredir",
    "regrido": "regredir",
    "regristas": "regrista",
    "regro": "regrar",
    "regrou": "regrar",
    "regrá": "regrar",
    "regrámo": "regrar",
    "regrámos": "regrar",
    "regráramo": "regrar",
    "regráramos": "regrar",
    "regrárei": "regrar",
    "regráreis": "regrar",
    "regrásseis": "regrar",
    "regrássemos": "regrar",
    "regrávamo": "regrar",
    "regrávamos": "regrar",
    "regrávei": "regrar",
    "regráveis": "regrar",
    "regrões": "regrão",
    "reguadas": "reguada",
    "regue": "regar",
    "reguei": "regar",
    "regueifas": "regueifa",
    "regueifeira": "regueifeiro",
    "regueifeiras": "regueifeiro",
    "regueifeiros": "regueifeiro",
    "regueiras": "regueira",
    "regueiros": "regueiro",
    "regueirões": "regueirão",
    "regueis": "regar",
    "reguem": "regar",
    "reguemo": "regar",
    "reguemos": "regar",
    "reguengos": "reguengo",
    "reguengozinho": "reguengo",
    "reguengozinhos": "reguengo",
    "reguengozito": "reguengo",
    "reguengozitos": "reguengo",
    "reguengueira": "reguengueiro",
    "reguengueiras": "reguengueiro",
    "reguengueiros": "reguengueiro",
    "reguenguenses": "reguenguense",
    "reguenses": "reguense",
    "regues": "regar",
    "reguinga": "reguingar",
    "reguingada": "reguingar",
    "reguingadas": "reguingar",
    "reguingado": "reguingar",
    "reguingados": "reguingar",
    "reguingai": "reguingar",
    "reguingais": "reguingar",
    "reguingam": "reguingar",
    "reguingamo": "reguingar",
    "reguingamos": "reguingar",
    "reguingando": "reguingar",
    "reguingara": "reguingar",
    "reguingaram": "reguingar",
    "reguingaras": "reguingar",
    "reguingardes": "reguingar",
    "reguingarei": "reguingar",
    "reguingareis": "reguingar",
    "reguingarem": "reguingar",
    "reguingaremos": "reguingar",
    "reguingares": "reguingar",
    "reguingaria": "reguingar",
    "reguingariam": "reguingar",
    "reguingarias": "reguingar",
    "reguingarmo": "reguingar",
    "reguingarmos": "reguingar",
    "reguingará": "reguingar",
    "reguingarás": "reguingar",
    "reguingarão": "reguingar",
    "reguingaríamos": "reguingar",
    "reguingaríeis": "reguingar",
    "reguingas": "reguingar",
    "reguingasse": "reguingar",
    "reguingassem": "reguingar",
    "reguingasses": "reguingar",
    "reguingaste": "reguingar",
    "reguingastes": "reguingar",
    "reguingava": "reguingar",
    "reguingavam": "reguingar",
    "reguingavas": "reguingar",
    "reguingo": "reguingar",
    "reguingotes": "reguingote",
    "reguingou": "reguingar",
    "reguingue": "reguingar",
    "reguinguei": "reguingar",
    "reguingueis": "reguingar",
    "reguinguem": "reguingar",
    "reguinguemo": "reguingar",
    "reguinguemos": "reguingar",
    "reguingues": "reguingar",
    "reguingámo": "reguingar",
    "reguingámos": "reguingar",
    "reguingáramo": "reguingar",
    "reguingáramos": "reguingar",
    "reguingáreis": "reguingar",
    "reguingásseis": "reguingar",
    "reguingássemos": "reguingar",
    "reguingávamo": "reguingar",
    "reguingávamos": "reguingar",
    "reguingáveis": "reguingar",
    "reguinho": "rego",
    "reguinhos": "rego",
    "reguito": "rego",
    "reguitos": "rego",
    "regula": "regular",
    "regulada": "regular",
    "reguladas": "regular",
    "reguladazinha": "regulado",
    "reguladazinhas": "regulado",
    "reguladazita": "regulado",
    "reguladazitas": "regulado",
    "reguladinha": "regulado",
    "reguladinhas": "regulado",
    "reguladinho": "regulado",
    "reguladinhos": "regulado",
    "reguladita": "regulado",
    "reguladitas": "regulado",
    "reguladito": "regulado",
    "reguladitos": "regulado",
    "regulado": "regular",
    "reguladora": "regulador",
    "reguladoras": "regulador",
    "reguladores": "regulador",
    "regulados": "regular",
    "reguladozinho": "regulado",
    "reguladozinhos": "regulado",
    "reguladozito": "regulado",
    "reguladozitos": "regulado",
    "reguladíssima": "regulado",
    "reguladíssimas": "regulado",
    "reguladíssimo": "regulado",
    "reguladíssimos": "regulado",
    "regulai": "regular",
    "regulais": "regular",
    "regulam": "regular",
    "regulamenta": "regulamentar",
    "regulamentada": "regulamentar",
    "regulamentadas": "regulamentar",
    "regulamentado": "regulamentar",
    "regulamentadora": "regulamentador",
    "regulamentadoras": "regulamentador",
    "regulamentadores": "regulamentador",
    "regulamentados": "regulamentar",
    "regulamentai": "regulamentar",
    "regulamentais": "regulamentar",
    "regulamentam": "regulamentar",
    "regulamentamo": "regulamentar",
    "regulamentamos": "regulamentar",
    "regulamentando": "regulamentar",
    "regulamentara": "regulamentar",
    "regulamentaram": "regulamentar",
    "regulamentaras": "regulamentar",
    "regulamentarde": "regulamentar",
    "regulamentardes": "regulamentar",
    "regulamentare": "regulamentar",
    "regulamentarei": "regulamentar",
    "regulamentareis": "regulamentar",
    "regulamentarem": "regulamentar",
    "regulamentaremos": "regulamentar",
    "regulamentares": "regulamentar",
    "regulamentaria": "regulamentar",
    "regulamentariam": "regulamentar",
    "regulamentarias": "regulamentar",
    "regulamentarmo": "regulamentar",
    "regulamentarmos": "regulamentar",
    "regulamentará": "regulamentar",
    "regulamentarás": "regulamentar",
    "regulamentarão": "regulamentar",
    "regulamentaríamos": "regulamentar",
    "regulamentaríeis": "regulamentar",
    "regulamentas": "regulamentar",
    "regulamentasse": "regulamentar",
    "regulamentassem": "regulamentar",
    "regulamentasses": "regulamentar",
    "regulamentaste": "regulamentar",
    "regulamentastes": "regulamentar",
    "regulamentava": "regulamentar",
    "regulamentavam": "regulamentar",
    "regulamentavas": "regulamentar",
    "regulamentações": "regulamentação",
    "regulamente": "regulamentar",
    "regulamentei": "regulamentar",
    "regulamenteis": "regulamentar",
    "regulamentem": "regulamentar",
    "regulamentemo": "regulamentar",
    "regulamentemos": "regulamentar",
    "regulamentes": "regulamentar",
    "regulamento": "regulamentar",
    "regulamentos": "regulamento",
    "regulamentou": "regulamentar",
    "regulamentá": "regulamentar",
    "regulamentámo": "regulamentar",
    "regulamentámos": "regulamentar",
    "regulamentáramo": "regulamentar",
    "regulamentáramos": "regulamentar",
    "regulamentárei": "regulamentar",
    "regulamentáreis": "regulamentar",
    "regulamentária": "regulamentário",
    "regulamentárias": "regulamentário",
    "regulamentários": "regulamentário",
    "regulamentásseis": "regulamentar",
    "regulamentássemos": "regulamentar",
    "regulamentávamo": "regulamentar",
    "regulamentávamos": "regulamentar",
    "regulamentávei": "regulamentar",
    "regulamentáveis": "regulamentável",
    "regulamo": "regular",
    "regulamos": "regular",
    "regulando": "regular",
    "regulara": "regular",
    "regularam": "regular",
    "regularas": "regular",
    "regularde": "regular",
    "regulardes": "regular",
    "regulare": "regular",
    "regularei": "regular",
    "regulareis": "regular",
    "regularem": "regular",
    "regularemos": "regular",
    "regulares": "regular",
    "regularia": "regular",
    "regulariam": "regular",
    "regularias": "regular",
    "regularidades": "regularidade",
    "regulariza": "regularizar",
    "regularizada": "regularizar",
    "regularizadas": "regularizar",
    "regularizado": "regularizar",
    "regularizadora": "regularizador",
    "regularizadoras": "regularizador",
    "regularizadores": "regularizador",
    "regularizados": "regularizar",
    "regularizai": "regularizar",
    "regularizais": "regularizar",
    "regularizam": "regularizar",
    "regularizamo": "regularizar",
    "regularizamos": "regularizar",
    "regularizando": "regularizar",
    "regularizara": "regularizar",
    "regularizaram": "regularizar",
    "regularizaras": "regularizar",
    "regularizarde": "regularizar",
    "regularizardes": "regularizar",
    "regularizare": "regularizar",
    "regularizarei": "regularizar",
    "regularizareis": "regularizar",
    "regularizarem": "regularizar",
    "regularizaremos": "regularizar",
    "regularizares": "regularizar",
    "regularizaria": "regularizar",
    "regularizariam": "regularizar",
    "regularizarias": "regularizar",
    "regularizarmo": "regularizar",
    "regularizarmos": "regularizar",
    "regularizará": "regularizar",
    "regularizarás": "regularizar",
    "regularizarão": "regularizar",
    "regularizaríamos": "regularizar",
    "regularizaríeis": "regularizar",
    "regularizas": "regularizar",
    "regularizasse": "regularizar",
    "regularizassem": "regularizar",
    "regularizasses": "regularizar",
    "regularizaste": "regularizar",
    "regularizastes": "regularizar",
    "regularizava": "regularizar",
    "regularizavam": "regularizar",
    "regularizavas": "regularizar",
    "regularizações": "regularização",
    "regularize": "regularizar",
    "regularizei": "regularizar",
    "regularizeis": "regularizar",
    "regularizem": "regularizar",
    "regularizemo": "regularizar",
    "regularizemos": "regularizar",
    "regularizes": "regularizar",
    "regularizo": "regularizar",
    "regularizou": "regularizar",
    "regularizá": "regularizar",
    "regularizámo": "regularizar",
    "regularizámos": "regularizar",
    "regularizáramo": "regularizar",
    "regularizáramos": "regularizar",
    "regularizárei": "regularizar",
    "regularizáreis": "regularizar",
    "regularizásseis": "regularizar",
    "regularizássemos": "regularizar",
    "regularizávamo": "regularizar",
    "regularizávamos": "regularizar",
    "regularizávei": "regularizar",
    "regularizáveis": "regularizável",
    "regularmo": "regular",
    "regularmos": "regular",
    "regularzinha": "regular",
    "regularzinhas": "regular",
    "regularzinho": "regular",
    "regularzinhos": "regular",
    "regularzita": "regular",
    "regularzitas": "regular",
    "regularzito": "regular",
    "regularzitos": "regular",
    "regulará": "regular",
    "regularás": "regular",
    "regularão": "regular",
    "regularíamos": "regular",
    "regularíeis": "regular",
    "regularíssima": "regular",
    "regularíssimas": "regular",
    "regularíssimo": "regular",
    "regularíssimos": "regular",
    "regulas": "regular",
    "regulasse": "regular",
    "regulassem": "regular",
    "regulasses": "regular",
    "regulaste": "regular",
    "regulastes": "regular",
    "regulava": "regular",
    "regulavam": "regular",
    "regulavas": "regular",
    "regulações": "regulação",
    "regule": "regular",
    "regulei": "regular",
    "reguleis": "regular",
    "regulem": "regular",
    "regulemo": "regular",
    "regulemos": "regular",
    "regules": "regular",
    "reguletes": "regulete",
    "regulo": "regular",
    "regulou": "regular",
    "regulá": "regular",
    "regulámo": "regular",
    "regulámos": "regular",
    "reguláramo": "regular",
    "reguláramos": "regular",
    "regulárei": "regular",
    "reguláreis": "regular",
    "regulásseis": "regular",
    "regulássemos": "regular",
    "regulávamo": "regular",
    "regulávamos": "regular",
    "regulávei": "regular",
    "reguláveis": "regulável",
    "regulídeos": "regulídeo",
    "regurgita": "regurgitar",
    "regurgitada": "regurgitar",
    "regurgitadas": "regurgitar",
    "regurgitado": "regurgitar",
    "regurgitados": "regurgitar",
    "regurgitai": "regurgitar",
    "regurgitais": "regurgitar",
    "regurgitam": "regurgitar",
    "regurgitamentos": "regurgitamento",
    "regurgitamo": "regurgitar",
    "regurgitamos": "regurgitar",
    "regurgitando": "regurgitar",
    "regurgitara": "regurgitar",
    "regurgitaram": "regurgitar",
    "regurgitaras": "regurgitar",
    "regurgitardes": "regurgitar",
    "regurgitarei": "regurgitar",
    "regurgitareis": "regurgitar",
    "regurgitarem": "regurgitar",
    "regurgitaremos": "regurgitar",
    "regurgitares": "regurgitar",
    "regurgitaria": "regurgitar",
    "regurgitariam": "regurgitar",
    "regurgitarias": "regurgitar",
    "regurgitarmo": "regurgitar",
    "regurgitarmos": "regurgitar",
    "regurgitará": "regurgitar",
    "regurgitarás": "regurgitar",
    "regurgitarão": "regurgitar",
    "regurgitaríamos": "regurgitar",
    "regurgitaríeis": "regurgitar",
    "regurgitas": "regurgitar",
    "regurgitasse": "regurgitar",
    "regurgitassem": "regurgitar",
    "regurgitasses": "regurgitar",
    "regurgitaste": "regurgitar",
    "regurgitastes": "regurgitar",
    "regurgitava": "regurgitar",
    "regurgitavam": "regurgitar",
    "regurgitavas": "regurgitar",
    "regurgitações": "regurgitação",
    "regurgite": "regurgitar",
    "regurgitei": "regurgitar",
    "regurgiteis": "regurgitar",
    "regurgitem": "regurgitar",
    "regurgitemo": "regurgitar",
    "regurgitemos": "regurgitar",
    "regurgites": "regurgitar",
    "regurgito": "regurgitar",
    "regurgitou": "regurgitar",
    "regurgitámo": "regurgitar",
    "regurgitámos": "regurgitar",
    "regurgitáramo": "regurgitar",
    "regurgitáramos": "regurgitar",
    "regurgitáreis": "regurgitar",
    "regurgitásseis": "regurgitar",
    "regurgitássemos": "regurgitar",
    "regurgitávamo": "regurgitar",
    "regurgitávamos": "regurgitar",
    "regurgitáveis": "regurgitar",
    "regá": "regar",
    "regámo": "regar",
    "regámos": "regar",
    "regáramo": "regar",
    "regáramos": "regar",
    "regárei": "regar",
    "regáreis": "regar",
    "regásseis": "regar",
    "regássemos": "regar",
    "regávamo": "regar",
    "regávamos": "regar",
    "regávei": "regar",
    "regáveis": "regar",
    "regélida": "regélido",
    "regélidas": "regélido",
    "regélidos": "regélido",
    "regê": "reger",
    "regências": "regência",
    "regêramo": "reger",
    "regêramos": "reger",
    "regêrei": "reger",
    "regêreis": "reger",
    "regêsseis": "reger",
    "regêssemos": "reger",
    "regíamo": "reger",
    "regíamos": "reger",
    "regíei": "reger",
    "regíeis": "reger",
    "regímen": "regime",
    "regímenes": "regime",
    "regímens": "regime",
    "regínea": "regíneo",
    "regíneas": "regíneo",
    "regíneos": "regíneo",
    "regúlidas": "regúlida",
    "reidratações": "reidratação",
    "reifica": "reificar",
    "reificada": "reificar",
    "reificadas": "reificar",
    "reificado": "reificar",
    "reificados": "reificar",
    "reificai": "reificar",
    "reificais": "reificar",
    "reificam": "reificar",
    "reificamo": "reificar",
    "reificamos": "reificar",
    "reificando": "reificar",
    "reificara": "reificar",
    "reificaram": "reificar",
    "reificaras": "reificar",
    "reificarde": "reificar",
    "reificardes": "reificar",
    "reificare": "reificar",
    "reificarei": "reificar",
    "reificareis": "reificar",
    "reificarem": "reificar",
    "reificaremos": "reificar",
    "reificares": "reificar",
    "reificaria": "reificar",
    "reificariam": "reificar",
    "reificarias": "reificar",
    "reificarmo": "reificar",
    "reificarmos": "reificar",
    "reificará": "reificar",
    "reificarás": "reificar",
    "reificarão": "reificar",
    "reificaríamos": "reificar",
    "reificaríeis": "reificar",
    "reificas": "reificar",
    "reificasse": "reificar",
    "reificassem": "reificar",
    "reificasses": "reificar",
    "reificaste": "reificar",
    "reificastes": "reificar",
    "reificava": "reificar",
    "reificavam": "reificar",
    "reificavas": "reificar",
    "reificações": "reificação",
    "reifico": "reificar",
    "reificou": "reificar",
    "reificá": "reificar",
    "reificámo": "reificar",
    "reificámos": "reificar",
    "reificáramo": "reificar",
    "reificáramos": "reificar",
    "reificárei": "reificar",
    "reificáreis": "reificar",
    "reificásseis": "reificar",
    "reificássemos": "reificar",
    "reificávamo": "reificar",
    "reificávamos": "reificar",
    "reificávei": "reificar",
    "reificáveis": "reificar",
    "reifique": "reificar",
    "reifiquei": "reificar",
    "reifiqueis": "reificar",
    "reifiquem": "reificar",
    "reifiquemo": "reificar",
    "reifiquemos": "reificar",
    "reifiques": "reificar",
    "reigadas": "reigada",
    "reimas": "reima",
    "reimosa": "reimoso",
    "reimosas": "reimoso",
    "reimosos": "reimoso",
    "reimplanta": "reimplantar",
    "reimplantada": "reimplantar",
    "reimplantadas": "reimplantar",
    "reimplantado": "reimplantar",
    "reimplantados": "reimplantar",
    "reimplantai": "reimplantar",
    "reimplantais": "reimplantar",
    "reimplantam": "reimplantar",
    "reimplantamo": "reimplantar",
    "reimplantamos": "reimplantar",
    "reimplantando": "reimplantar",
    "reimplantara": "reimplantar",
    "reimplantaram": "reimplantar",
    "reimplantaras": "reimplantar",
    "reimplantarde": "reimplantar",
    "reimplantardes": "reimplantar",
    "reimplantare": "reimplantar",
    "reimplantarei": "reimplantar",
    "reimplantareis": "reimplantar",
    "reimplantarem": "reimplantar",
    "reimplantaremos": "reimplantar",
    "reimplantares": "reimplantar",
    "reimplantaria": "reimplantar",
    "reimplantariam": "reimplantar",
    "reimplantarias": "reimplantar",
    "reimplantarmo": "reimplantar",
    "reimplantarmos": "reimplantar",
    "reimplantará": "reimplantar",
    "reimplantarás": "reimplantar",
    "reimplantarão": "reimplantar",
    "reimplantaríamos": "reimplantar",
    "reimplantaríeis": "reimplantar",
    "reimplantas": "reimplantar",
    "reimplantasse": "reimplantar",
    "reimplantassem": "reimplantar",
    "reimplantasses": "reimplantar",
    "reimplantaste": "reimplantar",
    "reimplantastes": "reimplantar",
    "reimplantava": "reimplantar",
    "reimplantavam": "reimplantar",
    "reimplantavas": "reimplantar",
    "reimplantações": "reimplantação",
    "reimplante": "reimplantar",
    "reimplantei": "reimplantar",
    "reimplanteis": "reimplantar",
    "reimplantem": "reimplantar",
    "reimplantemo": "reimplantar",
    "reimplantemos": "reimplantar",
    "reimplantes": "reimplantar",
    "reimplanto": "reimplantar",
    "reimplantou": "reimplantar",
    "reimplantá": "reimplantar",
    "reimplantámo": "reimplantar",
    "reimplantámos": "reimplantar",
    "reimplantáramo": "reimplantar",
    "reimplantáramos": "reimplantar",
    "reimplantárei": "reimplantar",
    "reimplantáreis": "reimplantar",
    "reimplantásseis": "reimplantar",
    "reimplantássemos": "reimplantar",
    "reimplantávamo": "reimplantar",
    "reimplantávamos": "reimplantar",
    "reimplantávei": "reimplantar",
    "reimplantáveis": "reimplantável",
    "reimpomo": "reimpor",
    "reimpomos": "reimpor",
    "reimponde": "reimpor",
    "reimpondes": "reimpor",
    "reimpondo": "reimpor",
    "reimponha": "reimpor",
    "reimponhais": "reimpor",
    "reimponham": "reimpor",
    "reimponhamo": "reimpor",
    "reimponhamos": "reimpor",
    "reimponhas": "reimpor",
    "reimponho": "reimpor",
    "reimporde": "reimpor",
    "reimpordes": "reimpor",
    "reimpore": "reimpor",
    "reimporei": "reimpor",
    "reimporeis": "reimpor",
    "reimporem": "reimpor",
    "reimporemos": "reimpor",
    "reimpores": "reimpor",
    "reimporia": "reimpor",
    "reimporiam": "reimpor",
    "reimporias": "reimpor",
    "reimpormo": "reimpor",
    "reimpormos": "reimpor",
    "reimporta": "reimportar",
    "reimportada": "reimportar",
    "reimportadas": "reimportar",
    "reimportado": "reimportar",
    "reimportados": "reimportar",
    "reimportai": "reimportar",
    "reimportais": "reimportar",
    "reimportam": "reimportar",
    "reimportamo": "reimportar",
    "reimportamos": "reimportar",
    "reimportando": "reimportar",
    "reimportara": "reimportar",
    "reimportaram": "reimportar",
    "reimportaras": "reimportar",
    "reimportarde": "reimportar",
    "reimportardes": "reimportar",
    "reimportare": "reimportar",
    "reimportarei": "reimportar",
    "reimportareis": "reimportar",
    "reimportarem": "reimportar",
    "reimportaremos": "reimportar",
    "reimportares": "reimportar",
    "reimportaria": "reimportar",
    "reimportariam": "reimportar",
    "reimportarias": "reimportar",
    "reimportarmo": "reimportar",
    "reimportarmos": "reimportar",
    "reimportará": "reimportar",
    "reimportarás": "reimportar",
    "reimportarão": "reimportar",
    "reimportaríamos": "reimportar",
    "reimportaríeis": "reimportar",
    "reimportas": "reimportar",
    "reimportasse": "reimportar",
    "reimportassem": "reimportar",
    "reimportasses": "reimportar",
    "reimportaste": "reimportar",
    "reimportastes": "reimportar",
    "reimportava": "reimportar",
    "reimportavam": "reimportar",
    "reimportavas": "reimportar",
    "reimportações": "reimportação",
    "reimporte": "reimportar",
    "reimportei": "reimportar",
    "reimporteis": "reimportar",
    "reimportem": "reimportar",
    "reimportemo": "reimportar",
    "reimportemos": "reimportar",
    "reimportes": "reimportar",
    "reimporto": "reimportar",
    "reimportou": "reimportar",
    "reimportá": "reimportar",
    "reimportámo": "reimportar",
    "reimportámos": "reimportar",
    "reimportáramo": "reimportar",
    "reimportáramos": "reimportar",
    "reimportárei": "reimportar",
    "reimportáreis": "reimportar",
    "reimportásseis": "reimportar",
    "reimportássemos": "reimportar",
    "reimportávamo": "reimportar",
    "reimportávamos": "reimportar",
    "reimportávei": "reimportar",
    "reimportáveis": "reimportável",
    "reimporá": "reimpor",
    "reimporás": "reimpor",
    "reimporão": "reimpor",
    "reimporíamos": "reimpor",
    "reimporíeis": "reimpor",
    "reimposições": "reimposição",
    "reimposta": "reimposto",
    "reimpostas": "reimposto",
    "reimposto": "reimpor",
    "reimpostos": "reimposto",
    "reimpressa": "reimpresso",
    "reimpressas": "reimpresso",
    "reimpressos": "reimpresso",
    "reimpressões": "reimpressão",
    "reimprima": "reimprimir",
    "reimprimais": "reimprimir",
    "reimprimam": "reimprimir",
    "reimprimamo": "reimprimir",
    "reimprimamos": "reimprimir",
    "reimprimas": "reimprimir",
    "reimprime": "reimprimir",
    "reimprimem": "reimprimir",
    "reimprimes": "reimprimir",
    "reimprimi": "reimprimir",
    "reimprimia": "reimprimir",
    "reimprimiam": "reimprimir",
    "reimprimias": "reimprimir",
    "reimprimida": "reimprimir",
    "reimprimidas": "reimprimir",
    "reimprimido": "reimprimir",
    "reimprimidos": "reimprimir",
    "reimprimimo": "reimprimir",
    "reimprimimos": "reimprimir",
    "reimprimindo": "reimprimir",
    "reimprimira": "reimprimir",
    "reimprimiram": "reimprimir",
    "reimprimiras": "reimprimir",
    "reimprimirde": "reimprimir",
    "reimprimirdes": "reimprimir",
    "reimprimire": "reimprimir",
    "reimprimirei": "reimprimir",
    "reimprimireis": "reimprimir",
    "reimprimirem": "reimprimir",
    "reimprimiremos": "reimprimir",
    "reimprimires": "reimprimir",
    "reimprimiria": "reimprimir",
    "reimprimiriam": "reimprimir",
    "reimprimirias": "reimprimir",
    "reimprimirmo": "reimprimir",
    "reimprimirmos": "reimprimir",
    "reimprimirá": "reimprimir",
    "reimprimirás": "reimprimir",
    "reimprimirão": "reimprimir",
    "reimprimiríamos": "reimprimir",
    "reimprimiríeis": "reimprimir",
    "reimprimis": "reimprimir",
    "reimprimisse": "reimprimir",
    "reimprimissem": "reimprimir",
    "reimprimisses": "reimprimir",
    "reimprimiste": "reimprimir",
    "reimprimistes": "reimprimir",
    "reimprimiu": "reimprimir",
    "reimprimo": "reimprimir",
    "reimprimíamo": "reimprimir",
    "reimprimíamos": "reimprimir",
    "reimprimíei": "reimprimir",
    "reimprimíeis": "reimprimir",
    "reimprimíramo": "reimprimir",
    "reimprimíramos": "reimprimir",
    "reimprimírei": "reimprimir",
    "reimprimíreis": "reimprimir",
    "reimprimísseis": "reimprimir",
    "reimprimíssemos": "reimprimir",
    "reimpulsos": "reimpulso",
    "reimpunha": "reimpor",
    "reimpunham": "reimpor",
    "reimpunhas": "reimpor",
    "reimpus": "reimpor",
    "reimpusemo": "reimpor",
    "reimpusemos": "reimpor",
    "reimpuser": "reimpor",
    "reimpusera": "reimpor",
    "reimpuseram": "reimpor",
    "reimpuseras": "reimpor",
    "reimpuserdes": "reimpor",
    "reimpuserem": "reimpor",
    "reimpuseres": "reimpor",
    "reimpusermos": "reimpor",
    "reimpusesse": "reimpor",
    "reimpusessem": "reimpor",
    "reimpusesses": "reimpor",
    "reimpuseste": "reimpor",
    "reimpusestes": "reimpor",
    "reimpuséramo": "reimpor",
    "reimpuséramos": "reimpor",
    "reimpusérei": "reimpor",
    "reimpuséreis": "reimpor",
    "reimpusésseis": "reimpor",
    "reimpuséssemos": "reimpor",
    "reimpô": "reimpor",
    "reimpôs": "reimpor",
    "reimpõe": "reimpor",
    "reimpõem": "reimpor",
    "reimpões": "reimpor",
    "reimpúnhamo": "reimpor",
    "reimpúnhamos": "reimpor",
    "reimpúnhei": "reimpor",
    "reimpúnheis": "reimpor",
    "reina": "reinar",
    "reinada": "reinar",
    "reinadas": "reinar",
    "reinadia": "reinadio",
    "reinadias": "reinadio",
    "reinadiazinha": "reinadio",
    "reinadiazinhas": "reinadio",
    "reinadiazita": "reinadio",
    "reinadiazitas": "reinadio",
    "reinadios": "reinadio",
    "reinadiozinho": "reinadio",
    "reinadiozinhos": "reinadio",
    "reinadiozito": "reinadio",
    "reinadiozitos": "reinadio",
    "reinado": "reinar",
    "reinados": "reinar",
    "reinai": "reinar",
    "reinais": "reinar",
    "reinam": "reinar",
    "reinamo": "reinar",
    "reinamos": "reinar",
    "reinando": "reinar",
    "reinantes": "reinante",
    "reinara": "reinar",
    "reinaram": "reinar",
    "reinaras": "reinar",
    "reinardes": "reinar",
    "reinarei": "reinar",
    "reinareis": "reinar",
    "reinarem": "reinar",
    "reinaremos": "reinar",
    "reinares": "reinar",
    "reinaria": "reinar",
    "reinariam": "reinar",
    "reinarias": "reinar",
    "reinarmo": "reinar",
    "reinarmos": "reinar",
    "reinará": "reinar",
    "reinarás": "reinar",
    "reinarão": "reinar",
    "reinaríamos": "reinar",
    "reinaríeis": "reinar",
    "reinas": "reinar",
    "reinasse": "reinar",
    "reinassem": "reinar",
    "reinasses": "reinar",
    "reinaste": "reinar",
    "reinastes": "reinar",
    "reinatas": "reinata",
    "reinaugura": "reinaugurar",
    "reinaugurada": "reinaugurar",
    "reinauguradas": "reinaugurar",
    "reinaugurado": "reinaugurar",
    "reinaugurados": "reinaugurar",
    "reinaugurai": "reinaugurar",
    "reinaugurais": "reinaugurar",
    "reinauguram": "reinaugurar",
    "reinauguramo": "reinaugurar",
    "reinauguramos": "reinaugurar",
    "reinaugurando": "reinaugurar",
    "reinaugurara": "reinaugurar",
    "reinauguraram": "reinaugurar",
    "reinauguraras": "reinaugurar",
    "reinaugurarde": "reinaugurar",
    "reinaugurardes": "reinaugurar",
    "reinaugurare": "reinaugurar",
    "reinaugurarei": "reinaugurar",
    "reinaugurareis": "reinaugurar",
    "reinaugurarem": "reinaugurar",
    "reinauguraremos": "reinaugurar",
    "reinaugurares": "reinaugurar",
    "reinauguraria": "reinaugurar",
    "reinaugurariam": "reinaugurar",
    "reinaugurarias": "reinaugurar",
    "reinaugurarmo": "reinaugurar",
    "reinaugurarmos": "reinaugurar",
    "reinaugurará": "reinaugurar",
    "reinaugurarás": "reinaugurar",
    "reinaugurarão": "reinaugurar",
    "reinauguraríamos": "reinaugurar",
    "reinauguraríeis": "reinaugurar",
    "reinauguras": "reinaugurar",
    "reinaugurasse": "reinaugurar",
    "reinaugurassem": "reinaugurar",
    "reinaugurasses": "reinaugurar",
    "reinauguraste": "reinaugurar",
    "reinaugurastes": "reinaugurar",
    "reinaugurava": "reinaugurar",
    "reinauguravam": "reinaugurar",
    "reinauguravas": "reinaugurar",
    "reinaugurações": "reinauguração",
    "reinaugure": "reinaugurar",
    "reinaugurei": "reinaugurar",
    "reinaugureis": "reinaugurar",
    "reinaugurem": "reinaugurar",
    "reinauguremo": "reinaugurar",
    "reinauguremos": "reinaugurar",
    "reinaugures": "reinaugurar",
    "reinauguro": "reinaugurar",
    "reinaugurou": "reinaugurar",
    "reinaugurá": "reinaugurar",
    "reinaugurámo": "reinaugurar",
    "reinaugurámos": "reinaugurar",
    "reinauguráramo": "reinaugurar",
    "reinauguráramos": "reinaugurar",
    "reinaugurárei": "reinaugurar",
    "reinauguráreis": "reinaugurar",
    "reinaugurásseis": "reinaugurar",
    "reinaugurássemos": "reinaugurar",
    "reinaugurávamo": "reinaugurar",
    "reinaugurávamos": "reinaugurar",
    "reinaugurávei": "reinaugurar",
    "reinauguráveis": "reinaugurar",
    "reinava": "reinar",
    "reinavam": "reinar",
    "reinavas": "reinar",
    "reinações": "reinação",
    "reincarnada": "reincarnado",
    "reincarnadas": "reincarnado",
    "reincarnados": "reincarnado",
    "reincida": "reincidir",
    "reincidais": "reincidir",
    "reincidam": "reincidir",
    "reincidamo": "reincidir",
    "reincidamos": "reincidir",
    "reincidas": "reincidir",
    "reincide": "reincidir",
    "reincidem": "reincidir",
    "reincidentes": "reincidente",
    "reincides": "reincidir",
    "reincidi": "reincidir",
    "reincidia": "reincidir",
    "reincidiam": "reincidir",
    "reincidias": "reincidir",
    "reincidida": "reincidir",
    "reincididas": "reincidir",
    "reincidido": "reincidir",
    "reincididos": "reincidir",
    "reincidimo": "reincidir",
    "reincidimos": "reincidir",
    "reincidindo": "reincidir",
    "reincidira": "reincidir",
    "reincidiram": "reincidir",
    "reincidiras": "reincidir",
    "reincidirdes": "reincidir",
    "reincidirei": "reincidir",
    "reincidireis": "reincidir",
    "reincidirem": "reincidir",
    "reincidiremos": "reincidir",
    "reincidires": "reincidir",
    "reincidiria": "reincidir",
    "reincidiriam": "reincidir",
    "reincidirias": "reincidir",
    "reincidirmo": "reincidir",
    "reincidirmos": "reincidir",
    "reincidirá": "reincidir",
    "reincidirás": "reincidir",
    "reincidirão": "reincidir",
    "reincidiríamos": "reincidir",
    "reincidiríeis": "reincidir",
    "reincidis": "reincidir",
    "reincidisse": "reincidir",
    "reincidissem": "reincidir",
    "reincidisses": "reincidir",
    "reincidiste": "reincidir",
    "reincidistes": "reincidir",
    "reincidiu": "reincidir",
    "reincido": "reincidir",
    "reincidências": "reincidência",
    "reincidíamo": "reincidir",
    "reincidíamos": "reincidir",
    "reincidíeis": "reincidir",
    "reincidíramo": "reincidir",
    "reincidíramos": "reincidir",
    "reincidíreis": "reincidir",
    "reincidísseis": "reincidir",
    "reincidíssemos": "reincidir",
    "reincita": "reincitar",
    "reincitada": "reincitar",
    "reincitadas": "reincitar",
    "reincitado": "reincitar",
    "reincitados": "reincitar",
    "reincitai": "reincitar",
    "reincitais": "reincitar",
    "reincitam": "reincitar",
    "reincitamentos": "reincitamento",
    "reincitamo": "reincitar",
    "reincitamos": "reincitar",
    "reincitando": "reincitar",
    "reincitara": "reincitar",
    "reincitaram": "reincitar",
    "reincitaras": "reincitar",
    "reincitarde": "reincitar",
    "reincitardes": "reincitar",
    "reincitare": "reincitar",
    "reincitarei": "reincitar",
    "reincitareis": "reincitar",
    "reincitarem": "reincitar",
    "reincitaremos": "reincitar",
    "reincitares": "reincitar",
    "reincitaria": "reincitar",
    "reincitariam": "reincitar",
    "reincitarias": "reincitar",
    "reincitarmo": "reincitar",
    "reincitarmos": "reincitar",
    "reincitará": "reincitar",
    "reincitarás": "reincitar",
    "reincitarão": "reincitar",
    "reincitaríamos": "reincitar",
    "reincitaríeis": "reincitar",
    "reincitas": "reincitar",
    "reincitasse": "reincitar",
    "reincitassem": "reincitar",
    "reincitasses": "reincitar",
    "reincitaste": "reincitar",
    "reincitastes": "reincitar",
    "reincitava": "reincitar",
    "reincitavam": "reincitar",
    "reincitavas": "reincitar",
    "reincite": "reincitar",
    "reincitei": "reincitar",
    "reinciteis": "reincitar",
    "reincitem": "reincitar",
    "reincitemo": "reincitar",
    "reincitemos": "reincitar",
    "reincites": "reincitar",
    "reincito": "reincitar",
    "reincitou": "reincitar",
    "reincitá": "reincitar",
    "reincitámo": "reincitar",
    "reincitámos": "reincitar",
    "reincitáramo": "reincitar",
    "reincitáramos": "reincitar",
    "reincitárei": "reincitar",
    "reincitáreis": "reincitar",
    "reincitásseis": "reincitar",
    "reincitássemos": "reincitar",
    "reincitávamo": "reincitar",
    "reincitávamos": "reincitar",
    "reincitávei": "reincitar",
    "reincitáveis": "reincitar",
    "reincorpora": "reincorporar",
    "reincorporada": "reincorporar",
    "reincorporadas": "reincorporar",
    "reincorporado": "reincorporar",
    "reincorporados": "reincorporar",
    "reincorporai": "reincorporar",
    "reincorporais": "reincorporar",
    "reincorporam": "reincorporar",
    "reincorporamo": "reincorporar",
    "reincorporamos": "reincorporar",
    "reincorporando": "reincorporar",
    "reincorporara": "reincorporar",
    "reincorporaram": "reincorporar",
    "reincorporaras": "reincorporar",
    "reincorporarde": "reincorporar",
    "reincorporardes": "reincorporar",
    "reincorporare": "reincorporar",
    "reincorporarei": "reincorporar",
    "reincorporareis": "reincorporar",
    "reincorporarem": "reincorporar",
    "reincorporaremos": "reincorporar",
    "reincorporares": "reincorporar",
    "reincorporaria": "reincorporar",
    "reincorporariam": "reincorporar",
    "reincorporarias": "reincorporar",
    "reincorporarmo": "reincorporar",
    "reincorporarmos": "reincorporar",
    "reincorporará": "reincorporar",
    "reincorporarás": "reincorporar",
    "reincorporarão": "reincorporar",
    "reincorporaríamos": "reincorporar",
    "reincorporaríeis": "reincorporar",
    "reincorporas": "reincorporar",
    "reincorporasse": "reincorporar",
    "reincorporassem": "reincorporar",
    "reincorporasses": "reincorporar",
    "reincorporaste": "reincorporar",
    "reincorporastes": "reincorporar",
    "reincorporava": "reincorporar",
    "reincorporavam": "reincorporar",
    "reincorporavas": "reincorporar",
    "reincorporações": "reincorporação",
    "reincorpore": "reincorporar",
    "reincorporei": "reincorporar",
    "reincorporeis": "reincorporar",
    "reincorporem": "reincorporar",
    "reincorporemo": "reincorporar",
    "reincorporemos": "reincorporar",
    "reincorpores": "reincorporar",
    "reincorporo": "reincorporar",
    "reincorporou": "reincorporar",
    "reincorporá": "reincorporar",
    "reincorporámo": "reincorporar",
    "reincorporámos": "reincorporar",
    "reincorporáramo": "reincorporar",
    "reincorporáramos": "reincorporar",
    "reincorporárei": "reincorporar",
    "reincorporáreis": "reincorporar",
    "reincorporásseis": "reincorporar",
    "reincorporássemos": "reincorporar",
    "reincorporávamo": "reincorporar",
    "reincorporávamos": "reincorporar",
    "reincorporávei": "reincorporar",
    "reincorporáveis": "reincorporar",
    "reindustrializações": "reindustrialização",
    "reine": "reinar",
    "reinei": "reinar",
    "reineis": "reinar",
    "reinem": "reinar",
    "reinemo": "reinar",
    "reinemos": "reinar",
    "reines": "reinar",
    "reinetas": "reineta",
    "reinfecciona": "reinfeccionar",
    "reinfeccionada": "reinfeccionar",
    "reinfeccionadas": "reinfeccionar",
    "reinfeccionado": "reinfeccionar",
    "reinfeccionados": "reinfeccionar",
    "reinfeccionai": "reinfeccionar",
    "reinfeccionais": "reinfeccionar",
    "reinfeccionam": "reinfeccionar",
    "reinfeccionamo": "reinfeccionar",
    "reinfeccionamos": "reinfeccionar",
    "reinfeccionando": "reinfeccionar",
    "reinfeccionara": "reinfeccionar",
    "reinfeccionaram": "reinfeccionar",
    "reinfeccionaras": "reinfeccionar",
    "reinfeccionarde": "reinfeccionar",
    "reinfeccionardes": "reinfeccionar",
    "reinfeccionare": "reinfeccionar",
    "reinfeccionarei": "reinfeccionar",
    "reinfeccionareis": "reinfeccionar",
    "reinfeccionarem": "reinfeccionar",
    "reinfeccionaremos": "reinfeccionar",
    "reinfeccionares": "reinfeccionar",
    "reinfeccionaria": "reinfeccionar",
    "reinfeccionariam": "reinfeccionar",
    "reinfeccionarias": "reinfeccionar",
    "reinfeccionarmo": "reinfeccionar",
    "reinfeccionarmos": "reinfeccionar",
    "reinfeccionará": "reinfeccionar",
    "reinfeccionarás": "reinfeccionar",
    "reinfeccionarão": "reinfeccionar",
    "reinfeccionaríamos": "reinfeccionar",
    "reinfeccionaríeis": "reinfeccionar",
    "reinfeccionas": "reinfeccionar",
    "reinfeccionasse": "reinfeccionar",
    "reinfeccionassem": "reinfeccionar",
    "reinfeccionasses": "reinfeccionar",
    "reinfeccionaste": "reinfeccionar",
    "reinfeccionastes": "reinfeccionar",
    "reinfeccionava": "reinfeccionar",
    "reinfeccionavam": "reinfeccionar",
    "reinfeccionavas": "reinfeccionar",
    "reinfeccione": "reinfeccionar",
    "reinfeccionei": "reinfeccionar",
    "reinfeccioneis": "reinfeccionar",
    "reinfeccionem": "reinfeccionar",
    "reinfeccionemo": "reinfeccionar",
    "reinfeccionemos": "reinfeccionar",
    "reinfecciones": "reinfeccionar",
    "reinfecciono": "reinfeccionar",
    "reinfeccionou": "reinfeccionar",
    "reinfeccioná": "reinfeccionar",
    "reinfeccionámo": "reinfeccionar",
    "reinfeccionámos": "reinfeccionar",
    "reinfeccionáramo": "reinfeccionar",
    "reinfeccionáramos": "reinfeccionar",
    "reinfeccionárei": "reinfeccionar",
    "reinfeccionáreis": "reinfeccionar",
    "reinfeccionásseis": "reinfeccionar",
    "reinfeccionássemos": "reinfeccionar",
    "reinfeccionávamo": "reinfeccionar",
    "reinfeccionávamos": "reinfeccionar",
    "reinfeccionávei": "reinfeccionar",
    "reinfeccionáveis": "reinfeccionar",
    "reinfecções": "reinfecção",
    "reinfunda": "reinfundir",
    "reinfundais": "reinfundir",
    "reinfundam": "reinfundir",
    "reinfundamo": "reinfundir",
    "reinfundamos": "reinfundir",
    "reinfundas": "reinfundir",
    "reinfunde": "reinfundir",
    "reinfundem": "reinfundir",
    "reinfundes": "reinfundir",
    "reinfundi": "reinfundir",
    "reinfundia": "reinfundir",
    "reinfundiam": "reinfundir",
    "reinfundias": "reinfundir",
    "reinfundida": "reinfundir",
    "reinfundidas": "reinfundir",
    "reinfundido": "reinfundir",
    "reinfundidos": "reinfundir",
    "reinfundimo": "reinfundir",
    "reinfundimos": "reinfundir",
    "reinfundindo": "reinfundir",
    "reinfundira": "reinfundir",
    "reinfundiram": "reinfundir",
    "reinfundiras": "reinfundir",
    "reinfundirde": "reinfundir",
    "reinfundirdes": "reinfundir",
    "reinfundire": "reinfundir",
    "reinfundirei": "reinfundir",
    "reinfundireis": "reinfundir",
    "reinfundirem": "reinfundir",
    "reinfundiremos": "reinfundir",
    "reinfundires": "reinfundir",
    "reinfundiria": "reinfundir",
    "reinfundiriam": "reinfundir",
    "reinfundirias": "reinfundir",
    "reinfundirmo": "reinfundir",
    "reinfundirmos": "reinfundir",
    "reinfundirá": "reinfundir",
    "reinfundirás": "reinfundir",
    "reinfundirão": "reinfundir",
    "reinfundiríamos": "reinfundir",
    "reinfundiríeis": "reinfundir",
    "reinfundis": "reinfundir",
    "reinfundisse": "reinfundir",
    "reinfundissem": "reinfundir",
    "reinfundisses": "reinfundir",
    "reinfundiste": "reinfundir",
    "reinfundistes": "reinfundir",
    "reinfundiu": "reinfundir",
    "reinfundo": "reinfundir",
    "reinfundíamo": "reinfundir",
    "reinfundíamos": "reinfundir",
    "reinfundíei": "reinfundir",
    "reinfundíeis": "reinfundir",
    "reinfundíramo": "reinfundir",
    "reinfundíramos": "reinfundir",
    "reinfundírei": "reinfundir",
    "reinfundíreis": "reinfundir",
    "reinfundísseis": "reinfundir",
    "reinfundíssemos": "reinfundir",
    "reingressada": "reingressado",
    "reingressadas": "reingressado",
    "reingressados": "reingressado",
    "reingressos": "reingresso",
    "reinicia": "reiniciar",
    "reiniciada": "reiniciar",
    "reiniciadas": "reiniciar",
    "reiniciado": "reiniciar",
    "reiniciados": "reiniciar",
    "reiniciai": "reiniciar",
    "reiniciais": "reiniciar",
    "reiniciam": "reiniciar",
    "reiniciamo": "reiniciar",
    "reiniciamos": "reiniciar",
    "reiniciando": "reiniciar",
    "reiniciara": "reiniciar",
    "reiniciaram": "reiniciar",
    "reiniciaras": "reiniciar",
    "reiniciarde": "reiniciar",
    "reiniciardes": "reiniciar",
    "reiniciare": "reiniciar",
    "reiniciarei": "reiniciar",
    "reiniciareis": "reiniciar",
    "reiniciarem": "reiniciar",
    "reiniciaremos": "reiniciar",
    "reiniciares": "reiniciar",
    "reiniciaria": "reiniciar",
    "reiniciariam": "reiniciar",
    "reiniciarias": "reiniciar",
    "reiniciarmo": "reiniciar",
    "reiniciarmos": "reiniciar",
    "reiniciará": "reiniciar",
    "reiniciarás": "reiniciar",
    "reiniciarão": "reiniciar",
    "reiniciaríamos": "reiniciar",
    "reiniciaríeis": "reiniciar",
    "reinicias": "reiniciar",
    "reiniciasse": "reiniciar",
    "reiniciassem": "reiniciar",
    "reiniciasses": "reiniciar",
    "reiniciaste": "reiniciar",
    "reiniciastes": "reiniciar",
    "reiniciava": "reiniciar",
    "reiniciavam": "reiniciar",
    "reiniciavas": "reiniciar",
    "reinicie": "reiniciar",
    "reiniciei": "reiniciar",
    "reinicieis": "reiniciar",
    "reiniciem": "reiniciar",
    "reiniciemo": "reiniciar",
    "reiniciemos": "reiniciar",
    "reinicies": "reiniciar",
    "reinicio": "reiniciar",
    "reiniciou": "reiniciar",
    "reiniciá": "reiniciar",
    "reiniciámo": "reiniciar",
    "reiniciámos": "reiniciar",
    "reiniciáramo": "reiniciar",
    "reiniciáramos": "reiniciar",
    "reiniciárei": "reiniciar",
    "reiniciáreis": "reiniciar",
    "reiniciásseis": "reiniciar",
    "reiniciássemos": "reiniciar",
    "reiniciávamo": "reiniciar",
    "reiniciávamos": "reiniciar",
    "reiniciávei": "reiniciar",
    "reiniciáveis": "reiniciar",
    "reino": "reinar",
    "reinolas": "reinola",
    "reinos": "reino",
    "reinou": "reinar",
    "reinquira": "reinquirir",
    "reinquirais": "reinquirir",
    "reinquiram": "reinquirir",
    "reinquiramo": "reinquirir",
    "reinquiramos": "reinquirir",
    "reinquiras": "reinquirir",
    "reinquire": "reinquirir",
    "reinquirem": "reinquirir",
    "reinquires": "reinquirir",
    "reinquiri": "reinquirir",
    "reinquiria": "reinquirir",
    "reinquiriam": "reinquirir",
    "reinquirias": "reinquirir",
    "reinquirida": "reinquirir",
    "reinquiridas": "reinquirir",
    "reinquirido": "reinquirir",
    "reinquiridos": "reinquirir",
    "reinquirimo": "reinquirir",
    "reinquirimos": "reinquirir",
    "reinquirindo": "reinquirir",
    "reinquirira": "reinquirir",
    "reinquiriram": "reinquirir",
    "reinquiriras": "reinquirir",
    "reinquirirde": "reinquirir",
    "reinquirirdes": "reinquirir",
    "reinquirire": "reinquirir",
    "reinquirirei": "reinquirir",
    "reinquirireis": "reinquirir",
    "reinquirirem": "reinquirir",
    "reinquiriremos": "reinquirir",
    "reinquirires": "reinquirir",
    "reinquiriria": "reinquirir",
    "reinquiririam": "reinquirir",
    "reinquiririas": "reinquirir",
    "reinquirirmo": "reinquirir",
    "reinquirirmos": "reinquirir",
    "reinquirirá": "reinquirir",
    "reinquirirás": "reinquirir",
    "reinquirirão": "reinquirir",
    "reinquiriríamos": "reinquirir",
    "reinquiriríeis": "reinquirir",
    "reinquiris": "reinquirir",
    "reinquirisse": "reinquirir",
    "reinquirissem": "reinquirir",
    "reinquirisses": "reinquirir",
    "reinquiriste": "reinquirir",
    "reinquiristes": "reinquirir",
    "reinquiriu": "reinquirir",
    "reinquirições": "reinquirição",
    "reinquiro": "reinquirir",
    "reinquiríamo": "reinquirir",
    "reinquiríamos": "reinquirir",
    "reinquiríei": "reinquirir",
    "reinquiríeis": "reinquirir",
    "reinquiríramo": "reinquirir",
    "reinquiríramos": "reinquirir",
    "reinquirírei": "reinquirir",
    "reinquiríreis": "reinquirir",
    "reinquirísseis": "reinquirir",
    "reinquiríssemos": "reinquirir",
    "reinscreva": "reinscrever",
    "reinscrevais": "reinscrever",
    "reinscrevam": "reinscrever",
    "reinscrevamo": "reinscrever",
    "reinscrevamos": "reinscrever",
    "reinscrevas": "reinscrever",
    "reinscreve": "reinscrever",
    "reinscrevei": "reinscrever",
    "reinscreveis": "reinscrever",
    "reinscrevem": "reinscrever",
    "reinscrevemo": "reinscrever",
    "reinscrevemos": "reinscrever",
    "reinscrevendo": "reinscrever",
    "reinscrevera": "reinscrever",
    "reinscreveram": "reinscrever",
    "reinscreveras": "reinscrever",
    "reinscreverde": "reinscrever",
    "reinscreverdes": "reinscrever",
    "reinscrevere": "reinscrever",
    "reinscreverei": "reinscrever",
    "reinscrevereis": "reinscrever",
    "reinscreverem": "reinscrever",
    "reinscreveremos": "reinscrever",
    "reinscreveres": "reinscrever",
    "reinscreveria": "reinscrever",
    "reinscreveriam": "reinscrever",
    "reinscreverias": "reinscrever",
    "reinscrevermo": "reinscrever",
    "reinscrevermos": "reinscrever",
    "reinscreverá": "reinscrever",
    "reinscreverás": "reinscrever",
    "reinscreverão": "reinscrever",
    "reinscreveríamos": "reinscrever",
    "reinscreveríeis": "reinscrever",
    "reinscreves": "reinscrever",
    "reinscrevesse": "reinscrever",
    "reinscrevessem": "reinscrever",
    "reinscrevesses": "reinscrever",
    "reinscreveste": "reinscrever",
    "reinscrevestes": "reinscrever",
    "reinscreveu": "reinscrever",
    "reinscrevi": "reinscrever",
    "reinscrevia": "reinscrever",
    "reinscreviam": "reinscrever",
    "reinscrevias": "reinscrever",
    "reinscrevida": "reinscrever",
    "reinscrevidas": "reinscrever",
    "reinscrevido": "reinscrever",
    "reinscrevidos": "reinscrever",
    "reinscrevo": "reinscrever",
    "reinscrevê": "reinscrever",
    "reinscrevêramo": "reinscrever",
    "reinscrevêramos": "reinscrever",
    "reinscrevêrei": "reinscrever",
    "reinscrevêreis": "reinscrever",
    "reinscrevêsseis": "reinscrever",
    "reinscrevêssemos": "reinscrever",
    "reinscrevíamo": "reinscrever",
    "reinscrevíamos": "reinscrever",
    "reinscrevíei": "reinscrever",
    "reinscrevíeis": "reinscrever",
    "reinscrições": "reinscrição",
    "reinsere": "reinserir",
    "reinserem": "reinserir",
    "reinseres": "reinserir",
    "reinseri": "reinserir",
    "reinseria": "reinserir",
    "reinseriam": "reinserir",
    "reinserias": "reinserir",
    "reinserida": "reinserir",
    "reinseridas": "reinserir",
    "reinserido": "reinserir",
    "reinseridos": "reinserir",
    "reinserimo": "reinserir",
    "reinserimos": "reinserir",
    "reinserindo": "reinserir",
    "reinserira": "reinserir",
    "reinseriram": "reinserir",
    "reinseriras": "reinserir",
    "reinserirde": "reinserir",
    "reinserirdes": "reinserir",
    "reinserire": "reinserir",
    "reinserirei": "reinserir",
    "reinserireis": "reinserir",
    "reinserirem": "reinserir",
    "reinseriremos": "reinserir",
    "reinserires": "reinserir",
    "reinseriria": "reinserir",
    "reinseririam": "reinserir",
    "reinseririas": "reinserir",
    "reinserirmo": "reinserir",
    "reinserirmos": "reinserir",
    "reinserirá": "reinserir",
    "reinserirás": "reinserir",
    "reinserirão": "reinserir",
    "reinseriríamos": "reinserir",
    "reinseriríeis": "reinserir",
    "reinseris": "reinserir",
    "reinserisse": "reinserir",
    "reinserissem": "reinserir",
    "reinserisses": "reinserir",
    "reinseriste": "reinserir",
    "reinseristes": "reinserir",
    "reinseriu": "reinserir",
    "reinserções": "reinserção",
    "reinseríamo": "reinserir",
    "reinseríamos": "reinserir",
    "reinseríei": "reinserir",
    "reinseríeis": "reinserir",
    "reinseríramo": "reinserir",
    "reinseríramos": "reinserir",
    "reinserírei": "reinserir",
    "reinseríreis": "reinserir",
    "reinserísseis": "reinserir",
    "reinseríssemos": "reinserir",
    "reinsira": "reinserir",
    "reinsirais": "reinserir",
    "reinsiram": "reinserir",
    "reinsiramo": "reinserir",
    "reinsiramos": "reinserir",
    "reinsiras": "reinserir",
    "reinsiro": "reinserir",
    "reinsista": "reinsistir",
    "reinsistais": "reinsistir",
    "reinsistam": "reinsistir",
    "reinsistamo": "reinsistir",
    "reinsistamos": "reinsistir",
    "reinsistas": "reinsistir",
    "reinsiste": "reinsistir",
    "reinsistem": "reinsistir",
    "reinsistes": "reinsistir",
    "reinsisti": "reinsistir",
    "reinsistia": "reinsistir",
    "reinsistiam": "reinsistir",
    "reinsistias": "reinsistir",
    "reinsistida": "reinsistir",
    "reinsistidas": "reinsistir",
    "reinsistido": "reinsistir",
    "reinsistidos": "reinsistir",
    "reinsistimo": "reinsistir",
    "reinsistimos": "reinsistir",
    "reinsistindo": "reinsistir",
    "reinsistira": "reinsistir",
    "reinsistiram": "reinsistir",
    "reinsistiras": "reinsistir",
    "reinsistirde": "reinsistir",
    "reinsistirdes": "reinsistir",
    "reinsistire": "reinsistir",
    "reinsistirei": "reinsistir",
    "reinsistireis": "reinsistir",
    "reinsistirem": "reinsistir",
    "reinsistiremos": "reinsistir",
    "reinsistires": "reinsistir",
    "reinsistiria": "reinsistir",
    "reinsistiriam": "reinsistir",
    "reinsistirias": "reinsistir",
    "reinsistirmo": "reinsistir",
    "reinsistirmos": "reinsistir",
    "reinsistirá": "reinsistir",
    "reinsistirás": "reinsistir",
    "reinsistirão": "reinsistir",
    "reinsistiríamos": "reinsistir",
    "reinsistiríeis": "reinsistir",
    "reinsistis": "reinsistir",
    "reinsistisse": "reinsistir",
    "reinsistissem": "reinsistir",
    "reinsistisses": "reinsistir",
    "reinsististe": "reinsistir",
    "reinsististes": "reinsistir",
    "reinsistiu": "reinsistir",
    "reinsisto": "reinsistir",
    "reinsistências": "reinsistência",
    "reinsistíamo": "reinsistir",
    "reinsistíamos": "reinsistir",
    "reinsistíei": "reinsistir",
    "reinsistíeis": "reinsistir",
    "reinsistíramo": "reinsistir",
    "reinsistíramos": "reinsistir",
    "reinsistírei": "reinsistir",
    "reinsistíreis": "reinsistir",
    "reinsistísseis": "reinsistir",
    "reinsistíssemos": "reinsistir",
    "reinspecções": "reinspecção",
    "reinstala": "reinstalar",
    "reinstalada": "reinstalar",
    "reinstaladas": "reinstalar",
    "reinstalado": "reinstalar",
    "reinstalados": "reinstalar",
    "reinstalai": "reinstalar",
    "reinstalais": "reinstalar",
    "reinstalam": "reinstalar",
    "reinstalamo": "reinstalar",
    "reinstalamos": "reinstalar",
    "reinstalando": "reinstalar",
    "reinstalara": "reinstalar",
    "reinstalaram": "reinstalar",
    "reinstalaras": "reinstalar",
    "reinstalarde": "reinstalar",
    "reinstalardes": "reinstalar",
    "reinstalare": "reinstalar",
    "reinstalarei": "reinstalar",
    "reinstalareis": "reinstalar",
    "reinstalarem": "reinstalar",
    "reinstalaremos": "reinstalar",
    "reinstalares": "reinstalar",
    "reinstalaria": "reinstalar",
    "reinstalariam": "reinstalar",
    "reinstalarias": "reinstalar",
    "reinstalarmo": "reinstalar",
    "reinstalarmos": "reinstalar",
    "reinstalará": "reinstalar",
    "reinstalarás": "reinstalar",
    "reinstalarão": "reinstalar",
    "reinstalaríamos": "reinstalar",
    "reinstalaríeis": "reinstalar",
    "reinstalas": "reinstalar",
    "reinstalasse": "reinstalar",
    "reinstalassem": "reinstalar",
    "reinstalasses": "reinstalar",
    "reinstalaste": "reinstalar",
    "reinstalastes": "reinstalar",
    "reinstalava": "reinstalar",
    "reinstalavam": "reinstalar",
    "reinstalavas": "reinstalar",
    "reinstalações": "reinstalação",
    "reinstale": "reinstalar",
    "reinstalei": "reinstalar",
    "reinstaleis": "reinstalar",
    "reinstalem": "reinstalar",
    "reinstalemo": "reinstalar",
    "reinstalemos": "reinstalar",
    "reinstales": "reinstalar",
    "reinstalo": "reinstalar",
    "reinstalou": "reinstalar",
    "reinstalá": "reinstalar",
    "reinstalámo": "reinstalar",
    "reinstalámos": "reinstalar",
    "reinstaláramo": "reinstalar",
    "reinstaláramos": "reinstalar",
    "reinstalárei": "reinstalar",
    "reinstaláreis": "reinstalar",
    "reinstalásseis": "reinstalar",
    "reinstalássemos": "reinstalar",
    "reinstalávamo": "reinstalar",
    "reinstalávamos": "reinstalar",
    "reinstalávei": "reinstalar",
    "reinstaláveis": "reinstalar",
    "reinstitua": "reinstituir",
    "reinstituais": "reinstituir",
    "reinstituam": "reinstituir",
    "reinstituamo": "reinstituir",
    "reinstituamos": "reinstituir",
    "reinstituas": "reinstituir",
    "reinstituem": "reinstituir",
    "reinstitui": "reinstituir",
    "reinstituindo": "reinstituir",
    "reinstituirde": "reinstituir",
    "reinstituirdes": "reinstituir",
    "reinstituirei": "reinstituir",
    "reinstituireis": "reinstituir",
    "reinstituiremos": "reinstituir",
    "reinstituiria": "reinstituir",
    "reinstituiriam": "reinstituir",
    "reinstituirias": "reinstituir",
    "reinstituirmo": "reinstituir",
    "reinstituirmos": "reinstituir",
    "reinstituirá": "reinstituir",
    "reinstituirás": "reinstituir",
    "reinstituirão": "reinstituir",
    "reinstituiríamos": "reinstituir",
    "reinstituiríeis": "reinstituir",
    "reinstituis": "reinstituir",
    "reinstituiu": "reinstituir",
    "reinstituições": "reinstituição",
    "reinstituo": "reinstituir",
    "reinstituí": "reinstituir",
    "reinstituía": "reinstituir",
    "reinstituíam": "reinstituir",
    "reinstituíamo": "reinstituir",
    "reinstituíamos": "reinstituir",
    "reinstituías": "reinstituir",
    "reinstituída": "reinstituir",
    "reinstituídas": "reinstituir",
    "reinstituído": "reinstituir",
    "reinstituídos": "reinstituir",
    "reinstituíei": "reinstituir",
    "reinstituíeis": "reinstituir",
    "reinstituímo": "reinstituir",
    "reinstituímos": "reinstituir",
    "reinstituíra": "reinstituir",
    "reinstituíram": "reinstituir",
    "reinstituíramo": "reinstituir",
    "reinstituíramos": "reinstituir",
    "reinstituíras": "reinstituir",
    "reinstituíre": "reinstituir",
    "reinstituírei": "reinstituir",
    "reinstituíreis": "reinstituir",
    "reinstituírem": "reinstituir",
    "reinstituíres": "reinstituir",
    "reinstituís": "reinstituir",
    "reinstituísse": "reinstituir",
    "reinstituísseis": "reinstituir",
    "reinstituíssem": "reinstituir",
    "reinstituíssemos": "reinstituir",
    "reinstituísses": "reinstituir",
    "reinstituíste": "reinstituir",
    "reinstituístes": "reinstituir",
    "reinstrumentações": "reinstrumentação",
    "reinsurge": "reinsurgir",
    "reinsurgem": "reinsurgir",
    "reinsurges": "reinsurgir",
    "reinsurgi": "reinsurgir",
    "reinsurgia": "reinsurgir",
    "reinsurgiam": "reinsurgir",
    "reinsurgias": "reinsurgir",
    "reinsurgida": "reinsurgir",
    "reinsurgidas": "reinsurgir",
    "reinsurgido": "reinsurgir",
    "reinsurgidos": "reinsurgir",
    "reinsurgimo": "reinsurgir",
    "reinsurgimos": "reinsurgir",
    "reinsurgindo": "reinsurgir",
    "reinsurgira": "reinsurgir",
    "reinsurgiram": "reinsurgir",
    "reinsurgiras": "reinsurgir",
    "reinsurgirde": "reinsurgir",
    "reinsurgirdes": "reinsurgir",
    "reinsurgire": "reinsurgir",
    "reinsurgirei": "reinsurgir",
    "reinsurgireis": "reinsurgir",
    "reinsurgirem": "reinsurgir",
    "reinsurgiremos": "reinsurgir",
    "reinsurgires": "reinsurgir",
    "reinsurgiria": "reinsurgir",
    "reinsurgiriam": "reinsurgir",
    "reinsurgirias": "reinsurgir",
    "reinsurgirmo": "reinsurgir",
    "reinsurgirmos": "reinsurgir",
    "reinsurgirá": "reinsurgir",
    "reinsurgirás": "reinsurgir",
    "reinsurgirão": "reinsurgir",
    "reinsurgiríamos": "reinsurgir",
    "reinsurgiríeis": "reinsurgir",
    "reinsurgis": "reinsurgir",
    "reinsurgisse": "reinsurgir",
    "reinsurgissem": "reinsurgir",
    "reinsurgisses": "reinsurgir",
    "reinsurgiste": "reinsurgir",
    "reinsurgistes": "reinsurgir",
    "reinsurgiu": "reinsurgir",
    "reinsurgíamo": "reinsurgir",
    "reinsurgíamos": "reinsurgir",
    "reinsurgíei": "reinsurgir",
    "reinsurgíeis": "reinsurgir",
    "reinsurgíramo": "reinsurgir",
    "reinsurgíramos": "reinsurgir",
    "reinsurgírei": "reinsurgir",
    "reinsurgíreis": "reinsurgir",
    "reinsurgísseis": "reinsurgir",
    "reinsurgíssemos": "reinsurgir",
    "reinsurja": "reinsurgir",
    "reinsurjais": "reinsurgir",
    "reinsurjam": "reinsurgir",
    "reinsurjamo": "reinsurgir",
    "reinsurjamos": "reinsurgir",
    "reinsurjas": "reinsurgir",
    "reinsurjo": "reinsurgir",
    "reintegra": "reintegrar",
    "reintegrada": "reintegrar",
    "reintegradas": "reintegrar",
    "reintegrado": "reintegrar",
    "reintegrados": "reintegrar",
    "reintegrai": "reintegrar",
    "reintegrais": "reintegrar",
    "reintegram": "reintegrar",
    "reintegramo": "reintegrar",
    "reintegramos": "reintegrar",
    "reintegrando": "reintegrar",
    "reintegrara": "reintegrar",
    "reintegraram": "reintegrar",
    "reintegraras": "reintegrar",
    "reintegrarde": "reintegrar",
    "reintegrardes": "reintegrar",
    "reintegrare": "reintegrar",
    "reintegrarei": "reintegrar",
    "reintegrareis": "reintegrar",
    "reintegrarem": "reintegrar",
    "reintegraremos": "reintegrar",
    "reintegrares": "reintegrar",
    "reintegraria": "reintegrar",
    "reintegrariam": "reintegrar",
    "reintegrarias": "reintegrar",
    "reintegrarmo": "reintegrar",
    "reintegrarmos": "reintegrar",
    "reintegrará": "reintegrar",
    "reintegrarás": "reintegrar",
    "reintegrarão": "reintegrar",
    "reintegraríamos": "reintegrar",
    "reintegraríeis": "reintegrar",
    "reintegras": "reintegrar",
    "reintegrasse": "reintegrar",
    "reintegrassem": "reintegrar",
    "reintegrasses": "reintegrar",
    "reintegraste": "reintegrar",
    "reintegrastes": "reintegrar",
    "reintegrava": "reintegrar",
    "reintegravam": "reintegrar",
    "reintegravas": "reintegrar",
    "reintegrações": "reintegração",
    "reintegre": "reintegrar",
    "reintegrei": "reintegrar",
    "reintegreis": "reintegrar",
    "reintegrem": "reintegrar",
    "reintegremo": "reintegrar",
    "reintegremos": "reintegrar",
    "reintegres": "reintegrar",
    "reintegro": "reintegrar",
    "reintegros": "reintegro",
    "reintegrou": "reintegrar",
    "reintegrá": "reintegrar",
    "reintegrámo": "reintegrar",
    "reintegrámos": "reintegrar",
    "reintegráramo": "reintegrar",
    "reintegráramos": "reintegrar",
    "reintegrárei": "reintegrar",
    "reintegráreis": "reintegrar",
    "reintegrásseis": "reintegrar",
    "reintegrássemos": "reintegrar",
    "reintegrávamo": "reintegrar",
    "reintegrávamos": "reintegrar",
    "reintegrávei": "reintegrar",
    "reintegráveis": "reintegrável",
    "reinterpreta": "reinterpretar",
    "reinterpretada": "reinterpretar",
    "reinterpretadas": "reinterpretar",
    "reinterpretado": "reinterpretar",
    "reinterpretados": "reinterpretar",
    "reinterpretai": "reinterpretar",
    "reinterpretais": "reinterpretar",
    "reinterpretam": "reinterpretar",
    "reinterpretamo": "reinterpretar",
    "reinterpretamos": "reinterpretar",
    "reinterpretando": "reinterpretar",
    "reinterpretara": "reinterpretar",
    "reinterpretaram": "reinterpretar",
    "reinterpretaras": "reinterpretar",
    "reinterpretarde": "reinterpretar",
    "reinterpretardes": "reinterpretar",
    "reinterpretare": "reinterpretar",
    "reinterpretarei": "reinterpretar",
    "reinterpretareis": "reinterpretar",
    "reinterpretarem": "reinterpretar",
    "reinterpretaremos": "reinterpretar",
    "reinterpretares": "reinterpretar",
    "reinterpretaria": "reinterpretar",
    "reinterpretariam": "reinterpretar",
    "reinterpretarias": "reinterpretar",
    "reinterpretarmo": "reinterpretar",
    "reinterpretarmos": "reinterpretar",
    "reinterpretará": "reinterpretar",
    "reinterpretarás": "reinterpretar",
    "reinterpretarão": "reinterpretar",
    "reinterpretaríamos": "reinterpretar",
    "reinterpretaríeis": "reinterpretar",
    "reinterpretas": "reinterpretar",
    "reinterpretasse": "reinterpretar",
    "reinterpretassem": "reinterpretar",
    "reinterpretasses": "reinterpretar",
    "reinterpretaste": "reinterpretar",
    "reinterpretastes": "reinterpretar",
    "reinterpretava": "reinterpretar",
    "reinterpretavam": "reinterpretar",
    "reinterpretavas": "reinterpretar",
    "reinterprete": "reinterpretar",
    "reinterpretei": "reinterpretar",
    "reinterpreteis": "reinterpretar",
    "reinterpretem": "reinterpretar",
    "reinterpretemo": "reinterpretar",
    "reinterpretemos": "reinterpretar",
    "reinterpretes": "reinterpretar",
    "reinterpreto": "reinterpretar",
    "reinterpretou": "reinterpretar",
    "reinterpretá": "reinterpretar",
    "reinterpretámo": "reinterpretar",
    "reinterpretámos": "reinterpretar",
    "reinterpretáramo": "reinterpretar",
    "reinterpretáramos": "reinterpretar",
    "reinterpretárei": "reinterpretar",
    "reinterpretáreis": "reinterpretar",
    "reinterpretásseis": "reinterpretar",
    "reinterpretássemos": "reinterpretar",
    "reinterpretávamo": "reinterpretar",
    "reinterpretávamos": "reinterpretar",
    "reinterpretávei": "reinterpretar",
    "reinterpretáveis": "reinterpretável",
    "reintroduz": "reintroduzir",
    "reintroduza": "reintroduzir",
    "reintroduzais": "reintroduzir",
    "reintroduzam": "reintroduzir",
    "reintroduzamo": "reintroduzir",
    "reintroduzamos": "reintroduzir",
    "reintroduzas": "reintroduzir",
    "reintroduze": "reintroduzir",
    "reintroduzem": "reintroduzir",
    "reintroduzes": "reintroduzir",
    "reintroduzi": "reintroduzir",
    "reintroduzia": "reintroduzir",
    "reintroduziam": "reintroduzir",
    "reintroduzias": "reintroduzir",
    "reintroduzida": "reintroduzir",
    "reintroduzidas": "reintroduzir",
    "reintroduzido": "reintroduzir",
    "reintroduzidos": "reintroduzir",
    "reintroduzimo": "reintroduzir",
    "reintroduzimos": "reintroduzir",
    "reintroduzindo": "reintroduzir",
    "reintroduzira": "reintroduzir",
    "reintroduziram": "reintroduzir",
    "reintroduziras": "reintroduzir",
    "reintroduzirde": "reintroduzir",
    "reintroduzirdes": "reintroduzir",
    "reintroduzire": "reintroduzir",
    "reintroduzirei": "reintroduzir",
    "reintroduzireis": "reintroduzir",
    "reintroduzirem": "reintroduzir",
    "reintroduziremos": "reintroduzir",
    "reintroduzires": "reintroduzir",
    "reintroduziria": "reintroduzir",
    "reintroduziriam": "reintroduzir",
    "reintroduzirias": "reintroduzir",
    "reintroduzirmo": "reintroduzir",
    "reintroduzirmos": "reintroduzir",
    "reintroduzirá": "reintroduzir",
    "reintroduzirás": "reintroduzir",
    "reintroduzirão": "reintroduzir",
    "reintroduziríamos": "reintroduzir",
    "reintroduziríeis": "reintroduzir",
    "reintroduzis": "reintroduzir",
    "reintroduzisse": "reintroduzir",
    "reintroduzissem": "reintroduzir",
    "reintroduzisses": "reintroduzir",
    "reintroduziste": "reintroduzir",
    "reintroduzistes": "reintroduzir",
    "reintroduziu": "reintroduzir",
    "reintroduzo": "reintroduzir",
    "reintroduzíamo": "reintroduzir",
    "reintroduzíamos": "reintroduzir",
    "reintroduzíei": "reintroduzir",
    "reintroduzíeis": "reintroduzir",
    "reintroduzíramo": "reintroduzir",
    "reintroduzíramos": "reintroduzir",
    "reintroduzírei": "reintroduzir",
    "reintroduzíreis": "reintroduzir",
    "reintroduzísseis": "reintroduzir",
    "reintroduzíssemos": "reintroduzir",
    "reintroduções": "reintrodução",
    "reinventa": "reinventar",
    "reinventada": "reinventar",
    "reinventadas": "reinventar",
    "reinventado": "reinventar",
    "reinventados": "reinventar",
    "reinventai": "reinventar",
    "reinventais": "reinventar",
    "reinventam": "reinventar",
    "reinventamo": "reinventar",
    "reinventamos": "reinventar",
    "reinventando": "reinventar",
    "reinventara": "reinventar",
    "reinventaram": "reinventar",
    "reinventaras": "reinventar",
    "reinventarde": "reinventar",
    "reinventardes": "reinventar",
    "reinventare": "reinventar",
    "reinventarei": "reinventar",
    "reinventareis": "reinventar",
    "reinventarem": "reinventar",
    "reinventaremos": "reinventar",
    "reinventares": "reinventar",
    "reinventaria": "reinventar",
    "reinventariam": "reinventar",
    "reinventarias": "reinventar",
    "reinventarmo": "reinventar",
    "reinventarmos": "reinventar",
    "reinventará": "reinventar",
    "reinventarás": "reinventar",
    "reinventarão": "reinventar",
    "reinventaríamos": "reinventar",
    "reinventaríeis": "reinventar",
    "reinventas": "reinventar",
    "reinventasse": "reinventar",
    "reinventassem": "reinventar",
    "reinventasses": "reinventar",
    "reinventaste": "reinventar",
    "reinventastes": "reinventar",
    "reinventava": "reinventar",
    "reinventavam": "reinventar",
    "reinventavas": "reinventar",
    "reinvente": "reinventar",
    "reinventei": "reinventar",
    "reinventeis": "reinventar",
    "reinventem": "reinventar",
    "reinventemo": "reinventar",
    "reinventemos": "reinventar",
    "reinventes": "reinventar",
    "reinvento": "reinventar",
    "reinventou": "reinventar",
    "reinventá": "reinventar",
    "reinventámo": "reinventar",
    "reinventámos": "reinventar",
    "reinventáramo": "reinventar",
    "reinventáramos": "reinventar",
    "reinventárei": "reinventar",
    "reinventáreis": "reinventar",
    "reinventásseis": "reinventar",
    "reinventássemos": "reinventar",
    "reinventávamo": "reinventar",
    "reinventávamos": "reinventar",
    "reinventávei": "reinventar",
    "reinventáveis": "reinventar",
    "reinvenções": "reinvenção",
    "reinveste": "reinvestir",
    "reinvestem": "reinvestir",
    "reinvestes": "reinvestir",
    "reinvesti": "reinvestir",
    "reinvestia": "reinvestir",
    "reinvestiam": "reinvestir",
    "reinvestias": "reinvestir",
    "reinvestida": "reinvestir",
    "reinvestidas": "reinvestir",
    "reinvestido": "reinvestir",
    "reinvestidos": "reinvestir",
    "reinvestimentos": "reinvestimento",
    "reinvestimo": "reinvestir",
    "reinvestimos": "reinvestir",
    "reinvestindo": "reinvestir",
    "reinvestira": "reinvestir",
    "reinvestiram": "reinvestir",
    "reinvestiras": "reinvestir",
    "reinvestirde": "reinvestir",
    "reinvestirdes": "reinvestir",
    "reinvestire": "reinvestir",
    "reinvestirei": "reinvestir",
    "reinvestireis": "reinvestir",
    "reinvestirem": "reinvestir",
    "reinvestiremos": "reinvestir",
    "reinvestires": "reinvestir",
    "reinvestiria": "reinvestir",
    "reinvestiriam": "reinvestir",
    "reinvestirias": "reinvestir",
    "reinvestirmo": "reinvestir",
    "reinvestirmos": "reinvestir",
    "reinvestirá": "reinvestir",
    "reinvestirás": "reinvestir",
    "reinvestirão": "reinvestir",
    "reinvestiríamos": "reinvestir",
    "reinvestiríeis": "reinvestir",
    "reinvestis": "reinvestir",
    "reinvestisse": "reinvestir",
    "reinvestissem": "reinvestir",
    "reinvestisses": "reinvestir",
    "reinvestiste": "reinvestir",
    "reinvestistes": "reinvestir",
    "reinvestiu": "reinvestir",
    "reinvestíamo": "reinvestir",
    "reinvestíamos": "reinvestir",
    "reinvestíei": "reinvestir",
    "reinvestíeis": "reinvestir",
    "reinvestíramo": "reinvestir",
    "reinvestíramos": "reinvestir",
    "reinvestírei": "reinvestir",
    "reinvestíreis": "reinvestir",
    "reinvestísseis": "reinvestir",
    "reinvestíssemos": "reinvestir",
    "reinvista": "reinvestir",
    "reinvistais": "reinvestir",
    "reinvistam": "reinvestir",
    "reinvistamo": "reinvestir",
    "reinvistamos": "reinvestir",
    "reinvistas": "reinvestir",
    "reinvisto": "reinvestir",
    "reinvocações": "reinvocação",
    "reinámo": "reinar",
    "reinámos": "reinar",
    "reináramo": "reinar",
    "reináramos": "reinar",
    "reináreis": "reinar",
    "reinásseis": "reinar",
    "reinássemos": "reinar",
    "reinávamo": "reinar",
    "reinávamos": "reinar",
    "reináveis": "reinar",
    "reinícios": "reinício",
    "reinícolas": "reinícola",
    "reinóis": "reinol",
    "reiras": "reira",
    "reis": "rei",
    "reisadas": "reisada",
    "reiseira": "reiseiro",
    "reiseiras": "reiseiro",
    "reiseiros": "reiseiro",
    "reitera": "reiterar",
    "reiterada": "reiterar",
    "reiteradas": "reiterar",
    "reiterado": "reiterar",
    "reiterados": "reiterar",
    "reiterai": "reiterar",
    "reiterais": "reiterar",
    "reiteram": "reiterar",
    "reiteramo": "reiterar",
    "reiteramos": "reiterar",
    "reiterando": "reiterar",
    "reiterara": "reiterar",
    "reiteraram": "reiterar",
    "reiteraras": "reiterar",
    "reiterarde": "reiterar",
    "reiterardes": "reiterar",
    "reiterare": "reiterar",
    "reiterarei": "reiterar",
    "reiterareis": "reiterar",
    "reiterarem": "reiterar",
    "reiteraremos": "reiterar",
    "reiterares": "reiterar",
    "reiteraria": "reiterar",
    "reiterariam": "reiterar",
    "reiterarias": "reiterar",
    "reiterarmo": "reiterar",
    "reiterarmos": "reiterar",
    "reiterará": "reiterar",
    "reiterarás": "reiterar",
    "reiterarão": "reiterar",
    "reiteraríamos": "reiterar",
    "reiteraríeis": "reiterar",
    "reiteras": "reiterar",
    "reiterasse": "reiterar",
    "reiterassem": "reiterar",
    "reiterasses": "reiterar",
    "reiteraste": "reiterar",
    "reiterastes": "reiterar",
    "reiterativa": "reiterativo",
    "reiterativas": "reiterativo",
    "reiterativos": "reiterativo",
    "reiterava": "reiterar",
    "reiteravam": "reiterar",
    "reiteravas": "reiterar",
    "reiterações": "reiteração",
    "reitere": "reiterar",
    "reiterei": "reiterar",
    "reitereis": "reiterar",
    "reiterem": "reiterar",
    "reiteremo": "reiterar",
    "reiteremos": "reiterar",
    "reiteres": "reiterar",
    "reitero": "reiterar",
    "reiterou": "reiterar",
    "reiterá": "reiterar",
    "reiterámo": "reiterar",
    "reiterámos": "reiterar",
    "reiteráramo": "reiterar",
    "reiteráramos": "reiterar",
    "reiterárei": "reiterar",
    "reiteráreis": "reiterar",
    "reiterásseis": "reiterar",
    "reiterássemos": "reiterar",
    "reiterávamo": "reiterar",
    "reiterávamos": "reiterar",
    "reiterávei": "reiterar",
    "reiteráveis": "reiterável",
    "reitora": "reitor",
    "reitorados": "reitorado",
    "reitorais": "reitoral",
    "reitoras": "reitor",
    "reitores": "reitor",
    "reitorias": "reitoria",
    "reiuna": "reiuno",
    "reiunas": "reiuno",
    "reiunos": "reiuno",
    "reivindica": "reivindicar",
    "reivindicabilidades": "reivindicabilidade",
    "reivindicada": "reivindicar",
    "reivindicadas": "reivindicar",
    "reivindicado": "reivindicar",
    "reivindicadora": "reivindicador",
    "reivindicadoras": "reivindicador",
    "reivindicadores": "reivindicador",
    "reivindicados": "reivindicar",
    "reivindicai": "reivindicar",
    "reivindicais": "reivindicar",
    "reivindicam": "reivindicar",
    "reivindicamo": "reivindicar",
    "reivindicamos": "reivindicar",
    "reivindicando": "reivindicar",
    "reivindicara": "reivindicar",
    "reivindicaram": "reivindicar",
    "reivindicaras": "reivindicar",
    "reivindicarde": "reivindicar",
    "reivindicardes": "reivindicar",
    "reivindicare": "reivindicar",
    "reivindicarei": "reivindicar",
    "reivindicareis": "reivindicar",
    "reivindicarem": "reivindicar",
    "reivindicaremos": "reivindicar",
    "reivindicares": "reivindicar",
    "reivindicaria": "reivindicar",
    "reivindicariam": "reivindicar",
    "reivindicarias": "reivindicar",
    "reivindicarmo": "reivindicar",
    "reivindicarmos": "reivindicar",
    "reivindicará": "reivindicar",
    "reivindicarás": "reivindicar",
    "reivindicarão": "reivindicar",
    "reivindicaríamos": "reivindicar",
    "reivindicaríeis": "reivindicar",
    "reivindicas": "reivindicar",
    "reivindicasse": "reivindicar",
    "reivindicassem": "reivindicar",
    "reivindicasses": "reivindicar",
    "reivindicaste": "reivindicar",
    "reivindicastes": "reivindicar",
    "reivindicativa": "reivindicativo",
    "reivindicativas": "reivindicativo",
    "reivindicativos": "reivindicativo",
    "reivindicatória": "reivindicatório",
    "reivindicatórias": "reivindicatório",
    "reivindicatórios": "reivindicatório",
    "reivindicava": "reivindicar",
    "reivindicavam": "reivindicar",
    "reivindicavas": "reivindicar",
    "reivindicações": "reivindicação",
    "reivindico": "reivindicar",
    "reivindicou": "reivindicar",
    "reivindicá": "reivindicar",
    "reivindicámo": "reivindicar",
    "reivindicámos": "reivindicar",
    "reivindicáramo": "reivindicar",
    "reivindicáramos": "reivindicar",
    "reivindicárei": "reivindicar",
    "reivindicáreis": "reivindicar",
    "reivindicásseis": "reivindicar",
    "reivindicássemos": "reivindicar",
    "reivindicávamo": "reivindicar",
    "reivindicávamos": "reivindicar",
    "reivindicávei": "reivindicar",
    "reivindicáveis": "reivindicar",
    "reivindique": "reivindicar",
    "reivindiquei": "reivindicar",
    "reivindiqueis": "reivindicar",
    "reivindiquem": "reivindicar",
    "reivindiquemo": "reivindicar",
    "reivindiquemos": "reivindicar",
    "reivindiques": "reivindicar",
    "reivós": "reivó",
    "reixas": "reixa",
    "reixelos": "reixelo",
    "reizetes": "reizete",
    "reiúnas": "reiúna",
    "reja": "reger",
    "rejais": "reger",
    "rejam": "reger",
    "rejamo": "reger",
    "rejamos": "reger",
    "rejas": "reger",
    "rejeita": "rejeitar",
    "rejeitada": "rejeitar",
    "rejeitadas": "rejeitar",
    "rejeitado": "rejeitar",
    "rejeitados": "rejeitar",
    "rejeitai": "rejeitar",
    "rejeitais": "rejeitar",
    "rejeitam": "rejeitar",
    "rejeitamo": "rejeitar",
    "rejeitamos": "rejeitar",
    "rejeitando": "rejeitar",
    "rejeitara": "rejeitar",
    "rejeitaram": "rejeitar",
    "rejeitaras": "rejeitar",
    "rejeitarde": "rejeitar",
    "rejeitardes": "rejeitar",
    "rejeitare": "rejeitar",
    "rejeitarei": "rejeitar",
    "rejeitareis": "rejeitar",
    "rejeitarem": "rejeitar",
    "rejeitaremos": "rejeitar",
    "rejeitares": "rejeitar",
    "rejeitaria": "rejeitar",
    "rejeitariam": "rejeitar",
    "rejeitarias": "rejeitar",
    "rejeitarmo": "rejeitar",
    "rejeitarmos": "rejeitar",
    "rejeitará": "rejeitar",
    "rejeitarás": "rejeitar",
    "rejeitarão": "rejeitar",
    "rejeitaríamos": "rejeitar",
    "rejeitaríeis": "rejeitar",
    "rejeitas": "rejeitar",
    "rejeitasse": "rejeitar",
    "rejeitassem": "rejeitar",
    "rejeitasses": "rejeitar",
    "rejeitaste": "rejeitar",
    "rejeitastes": "rejeitar",
    "rejeitava": "rejeitar",
    "rejeitavam": "rejeitar",
    "rejeitavas": "rejeitar",
    "rejeite": "rejeitar",
    "rejeitei": "rejeitar",
    "rejeiteis": "rejeitar",
    "rejeitem": "rejeitar",
    "rejeitemo": "rejeitar",
    "rejeitemos": "rejeitar",
    "rejeites": "rejeitar",
    "rejeito": "rejeitar",
    "rejeitos": "rejeito",
    "rejeitou": "rejeitar",
    "rejeitá": "rejeitar",
    "rejeitámo": "rejeitar",
    "rejeitámos": "rejeitar",
    "rejeitáramo": "rejeitar",
    "rejeitáramos": "rejeitar",
    "rejeitárei": "rejeitar",
    "rejeitáreis": "rejeitar",
    "rejeitásseis": "rejeitar",
    "rejeitássemos": "rejeitar",
    "rejeitávamo": "rejeitar",
    "rejeitávamos": "rejeitar",
    "rejeitávei": "rejeitar",
    "rejeitáveis": "rejeitável",
    "rejeições": "rejeição",
    "rejo": "reger",
    "rejubila": "rejubilar",
    "rejubilada": "rejubilar",
    "rejubiladas": "rejubilar",
    "rejubilado": "rejubilar",
    "rejubilados": "rejubilar",
    "rejubilai": "rejubilar",
    "rejubilais": "rejubilar",
    "rejubilam": "rejubilar",
    "rejubilamo": "rejubilar",
    "rejubilamos": "rejubilar",
    "rejubilando": "rejubilar",
    "rejubilara": "rejubilar",
    "rejubilaram": "rejubilar",
    "rejubilaras": "rejubilar",
    "rejubilardes": "rejubilar",
    "rejubilarei": "rejubilar",
    "rejubilareis": "rejubilar",
    "rejubilarem": "rejubilar",
    "rejubilaremos": "rejubilar",
    "rejubilares": "rejubilar",
    "rejubilaria": "rejubilar",
    "rejubilariam": "rejubilar",
    "rejubilarias": "rejubilar",
    "rejubilarmo": "rejubilar",
    "rejubilarmos": "rejubilar",
    "rejubilará": "rejubilar",
    "rejubilarás": "rejubilar",
    "rejubilarão": "rejubilar",
    "rejubilaríamos": "rejubilar",
    "rejubilaríeis": "rejubilar",
    "rejubilas": "rejubilar",
    "rejubilasse": "rejubilar",
    "rejubilassem": "rejubilar",
    "rejubilasses": "rejubilar",
    "rejubilaste": "rejubilar",
    "rejubilastes": "rejubilar",
    "rejubilava": "rejubilar",
    "rejubilavam": "rejubilar",
    "rejubilavas": "rejubilar",
    "rejubilações": "rejubilação",
    "rejubile": "rejubilar",
    "rejubilei": "rejubilar",
    "rejubileis": "rejubilar",
    "rejubilem": "rejubilar",
    "rejubilemo": "rejubilar",
    "rejubilemos": "rejubilar",
    "rejubiles": "rejubilar",
    "rejubilo": "rejubilar",
    "rejubilou": "rejubilar",
    "rejubilámo": "rejubilar",
    "rejubilámos": "rejubilar",
    "rejubiláramo": "rejubilar",
    "rejubiláramos": "rejubilar",
    "rejubiláreis": "rejubilar",
    "rejubilásseis": "rejubilar",
    "rejubilássemos": "rejubilar",
    "rejubilávamo": "rejubilar",
    "rejubilávamos": "rejubilar",
    "rejubiláveis": "rejubilar",
    "rejura": "rejurar",
    "rejurada": "rejurar",
    "rejuradas": "rejurar",
    "rejurado": "rejurar",
    "rejurados": "rejurar",
    "rejurai": "rejurar",
    "rejurais": "rejurar",
    "rejuram": "rejurar",
    "rejuramo": "rejurar",
    "rejuramos": "rejurar",
    "rejurando": "rejurar",
    "rejurara": "rejurar",
    "rejuraram": "rejurar",
    "rejuraras": "rejurar",
    "rejurarde": "rejurar",
    "rejurardes": "rejurar",
    "rejurare": "rejurar",
    "rejurarei": "rejurar",
    "rejurareis": "rejurar",
    "rejurarem": "rejurar",
    "rejuraremos": "rejurar",
    "rejurares": "rejurar",
    "rejuraria": "rejurar",
    "rejurariam": "rejurar",
    "rejurarias": "rejurar",
    "rejurarmo": "rejurar",
    "rejurarmos": "rejurar",
    "rejurará": "rejurar",
    "rejurarás": "rejurar",
    "rejurarão": "rejurar",
    "rejuraríamos": "rejurar",
    "rejuraríeis": "rejurar",
    "rejuras": "rejurar",
    "rejurasse": "rejurar",
    "rejurassem": "rejurar",
    "rejurasses": "rejurar",
    "rejuraste": "rejurar",
    "rejurastes": "rejurar",
    "rejurava": "rejurar",
    "rejuravam": "rejurar",
    "rejuravas": "rejurar",
    "rejure": "rejurar",
    "rejurei": "rejurar",
    "rejureis": "rejurar",
    "rejurem": "rejurar",
    "rejuremo": "rejurar",
    "rejuremos": "rejurar",
    "rejures": "rejurar",
    "rejuro": "rejurar",
    "rejurou": "rejurar",
    "rejurá": "rejurar",
    "rejurámo": "rejurar",
    "rejurámos": "rejurar",
    "rejuráramo": "rejurar",
    "rejuráramos": "rejurar",
    "rejurárei": "rejurar",
    "rejuráreis": "rejurar",
    "rejurásseis": "rejurar",
    "rejurássemos": "rejurar",
    "rejurávamo": "rejurar",
    "rejurávamos": "rejurar",
    "rejurávei": "rejurar",
    "rejuráveis": "rejurar",
    "rejuvenecedores": "rejuvenecedor",
    "rejuvenesce": "rejuvenescer",
    "rejuvenescedora": "rejuvenescedor",
    "rejuvenescedoras": "rejuvenescedor",
    "rejuvenescedores": "rejuvenescedor",
    "rejuvenescei": "rejuvenescer",
    "rejuvenesceis": "rejuvenescer",
    "rejuvenescem": "rejuvenescer",
    "rejuvenescemo": "rejuvenescer",
    "rejuvenescemos": "rejuvenescer",
    "rejuvenescendo": "rejuvenescer",
    "rejuvenescentes": "rejuvenescente",
    "rejuvenescera": "rejuvenescer",
    "rejuvenesceram": "rejuvenescer",
    "rejuvenesceras": "rejuvenescer",
    "rejuvenescerde": "rejuvenescer",
    "rejuvenescerdes": "rejuvenescer",
    "rejuvenescere": "rejuvenescer",
    "rejuvenescerei": "rejuvenescer",
    "rejuvenescereis": "rejuvenescer",
    "rejuvenescerem": "rejuvenescer",
    "rejuvenesceremos": "rejuvenescer",
    "rejuvenesceres": "rejuvenescer",
    "rejuvenesceria": "rejuvenescer",
    "rejuvenesceriam": "rejuvenescer",
    "rejuvenescerias": "rejuvenescer",
    "rejuvenescermo": "rejuvenescer",
    "rejuvenescermos": "rejuvenescer",
    "rejuvenescerá": "rejuvenescer",
    "rejuvenescerás": "rejuvenescer",
    "rejuvenescerão": "rejuvenescer",
    "rejuvenesceríamos": "rejuvenescer",
    "rejuvenesceríeis": "rejuvenescer",
    "rejuvenesces": "rejuvenescer",
    "rejuvenescesse": "rejuvenescer",
    "rejuvenescessem": "rejuvenescer",
    "rejuvenescesses": "rejuvenescer",
    "rejuvenesceste": "rejuvenescer",
    "rejuvenescestes": "rejuvenescer",
    "rejuvenesceu": "rejuvenescer",
    "rejuvenesci": "rejuvenescer",
    "rejuvenescia": "rejuvenescer",
    "rejuvenesciam": "rejuvenescer",
    "rejuvenescias": "rejuvenescer",
    "rejuvenescida": "rejuvenescido",
    "rejuvenescidas": "rejuvenescido",
    "rejuvenescido": "rejuvenescer",
    "rejuvenescidos": "rejuvenescido",
    "rejuvenescimentos": "rejuvenescimento",
    "rejuvenescê": "rejuvenescer",
    "rejuvenescências": "rejuvenescência",
    "rejuvenescêramo": "rejuvenescer",
    "rejuvenescêramos": "rejuvenescer",
    "rejuvenescêrei": "rejuvenescer",
    "rejuvenescêreis": "rejuvenescer",
    "rejuvenescêsseis": "rejuvenescer",
    "rejuvenescêssemos": "rejuvenescer",
    "rejuvenescíamo": "rejuvenescer",
    "rejuvenescíamos": "rejuvenescer",
    "rejuvenescíei": "rejuvenescer",
    "rejuvenescíeis": "rejuvenescer",
    "rejuvenesça": "rejuvenescer",
    "rejuvenesçais": "rejuvenescer",
    "rejuvenesçam": "rejuvenescer",
    "rejuvenesçamo": "rejuvenescer",
    "rejuvenesçamos": "rejuvenescer",
    "rejuvenesças": "rejuvenescer",
    "rejuvenesço": "rejuvenescer",
    "rejúbilos": "rejúbilo",
    "rela": "relar",
    "relaciona": "relacionar",
    "relacionada": "relacionar",
    "relacionadas": "relacionar",
    "relacionado": "relacionar",
    "relacionados": "relacionar",
    "relacionai": "relacionar",
    "relacionais": "relacionar",
    "relacionam": "relacionar",
    "relacionamentos": "relacionamento",
    "relacionamo": "relacionar",
    "relacionamos": "relacionar",
    "relacionando": "relacionar",
    "relacionara": "relacionar",
    "relacionaram": "relacionar",
    "relacionaras": "relacionar",
    "relacionarde": "relacionar",
    "relacionardes": "relacionar",
    "relacionare": "relacionar",
    "relacionarei": "relacionar",
    "relacionareis": "relacionar",
    "relacionarem": "relacionar",
    "relacionaremos": "relacionar",
    "relacionares": "relacionar",
    "relacionaria": "relacionar",
    "relacionariam": "relacionar",
    "relacionarias": "relacionar",
    "relacionarmo": "relacionar",
    "relacionarmos": "relacionar",
    "relacionará": "relacionar",
    "relacionarás": "relacionar",
    "relacionarão": "relacionar",
    "relacionaríamos": "relacionar",
    "relacionaríeis": "relacionar",
    "relacionas": "relacionar",
    "relacionasse": "relacionar",
    "relacionassem": "relacionar",
    "relacionasses": "relacionar",
    "relacionaste": "relacionar",
    "relacionastes": "relacionar",
    "relacionava": "relacionar",
    "relacionavam": "relacionar",
    "relacionavas": "relacionar",
    "relacionações": "relacionação",
    "relacione": "relacionar",
    "relacionei": "relacionar",
    "relacioneis": "relacionar",
    "relacionem": "relacionar",
    "relacionemo": "relacionar",
    "relacionemos": "relacionar",
    "relaciones": "relacionar",
    "relaciono": "relacionar",
    "relacionou": "relacionar",
    "relacioná": "relacionar",
    "relacionámo": "relacionar",
    "relacionámos": "relacionar",
    "relacionáramo": "relacionar",
    "relacionáramos": "relacionar",
    "relacionárei": "relacionar",
    "relacionáreis": "relacionar",
    "relacionásseis": "relacionar",
    "relacionássemos": "relacionar",
    "relacionávamo": "relacionar",
    "relacionávamos": "relacionar",
    "relacionávei": "relacionar",
    "relacionáveis": "relacionável",
    "relacra": "relacrar",
    "relacrada": "relacrar",
    "relacradas": "relacrar",
    "relacrado": "relacrar",
    "relacrados": "relacrar",
    "relacrai": "relacrar",
    "relacrais": "relacrar",
    "relacram": "relacrar",
    "relacramo": "relacrar",
    "relacramos": "relacrar",
    "relacrando": "relacrar",
    "relacrara": "relacrar",
    "relacraram": "relacrar",
    "relacraras": "relacrar",
    "relacrarde": "relacrar",
    "relacrardes": "relacrar",
    "relacrare": "relacrar",
    "relacrarei": "relacrar",
    "relacrareis": "relacrar",
    "relacrarem": "relacrar",
    "relacraremos": "relacrar",
    "relacrares": "relacrar",
    "relacraria": "relacrar",
    "relacrariam": "relacrar",
    "relacrarias": "relacrar",
    "relacrarmo": "relacrar",
    "relacrarmos": "relacrar",
    "relacrará": "relacrar",
    "relacrarás": "relacrar",
    "relacrarão": "relacrar",
    "relacraríamos": "relacrar",
    "relacraríeis": "relacrar",
    "relacras": "relacrar",
    "relacrasse": "relacrar",
    "relacrassem": "relacrar",
    "relacrasses": "relacrar",
    "relacraste": "relacrar",
    "relacrastes": "relacrar",
    "relacrava": "relacrar",
    "relacravam": "relacrar",
    "relacravas": "relacrar",
    "relacre": "relacrar",
    "relacrei": "relacrar",
    "relacreis": "relacrar",
    "relacrem": "relacrar",
    "relacremo": "relacrar",
    "relacremos": "relacrar",
    "relacres": "relacrar",
    "relacro": "relacrar",
    "relacrou": "relacrar",
    "relacrá": "relacrar",
    "relacrámo": "relacrar",
    "relacrámos": "relacrar",
    "relacráramo": "relacrar",
    "relacráramos": "relacrar",
    "relacrárei": "relacrar",
    "relacráreis": "relacrar",
    "relacrásseis": "relacrar",
    "relacrássemos": "relacrar",
    "relacrávamo": "relacrar",
    "relacrávamos": "relacrar",
    "relacrávei": "relacrar",
    "relacráveis": "relacrar",
    "relada": "relar",
    "reladas": "relar",
    "relado": "relar",
    "relados": "relar",
    "relai": "relar",
    "relais": "relar",
    "relam": "relar",
    "relamba": "relamber",
    "relambais": "relamber",
    "relambam": "relamber",
    "relambamo": "relamber",
    "relambamos": "relamber",
    "relambas": "relamber",
    "relambe": "relamber",
    "relambei": "relamber",
    "relambeis": "relamber",
    "relambem": "relamber",
    "relambemo": "relamber",
    "relambemos": "relamber",
    "relambendo": "relamber",
    "relambera": "relamber",
    "relamberam": "relamber",
    "relamberas": "relamber",
    "relamberde": "relamber",
    "relamberdes": "relamber",
    "relambere": "relamber",
    "relamberei": "relamber",
    "relambereis": "relamber",
    "relamberem": "relamber",
    "relamberemos": "relamber",
    "relamberes": "relamber",
    "relamberia": "relamber",
    "relamberiam": "relamber",
    "relamberias": "relamber",
    "relambermo": "relamber",
    "relambermos": "relamber",
    "relamberá": "relamber",
    "relamberás": "relamber",
    "relamberão": "relamber",
    "relamberíamos": "relamber",
    "relamberíeis": "relamber",
    "relambes": "relamber",
    "relambesse": "relamber",
    "relambessem": "relamber",
    "relambesses": "relamber",
    "relambeste": "relamber",
    "relambestes": "relamber",
    "relambeu": "relamber",
    "relambi": "relamber",
    "relambia": "relamber",
    "relambiam": "relamber",
    "relambias": "relamber",
    "relambida": "relambido",
    "relambidas": "relambido",
    "relambido": "relamber",
    "relambidos": "relambido",
    "relambo": "relamber",
    "relambê": "relamber",
    "relambêramo": "relamber",
    "relambêramos": "relamber",
    "relambêrei": "relamber",
    "relambêreis": "relamber",
    "relambêsseis": "relamber",
    "relambêssemos": "relamber",
    "relambíamo": "relamber",
    "relambíamos": "relamber",
    "relambíei": "relamber",
    "relambíeis": "relamber",
    "relambória": "relambório",
    "relambórias": "relambório",
    "relambórios": "relambório",
    "relamo": "relar",
    "relamos": "relar",
    "relampa": "relampar",
    "relampada": "relampar",
    "relampadas": "relampar",
    "relampadeja": "relampadejar",
    "relampadejada": "relampadejar",
    "relampadejadas": "relampadejar",
    "relampadejado": "relampadejar",
    "relampadejados": "relampadejar",
    "relampadejai": "relampadejar",
    "relampadejais": "relampadejar",
    "relampadejam": "relampadejar",
    "relampadejamo": "relampadejar",
    "relampadejamos": "relampadejar",
    "relampadejando": "relampadejar",
    "relampadejara": "relampadejar",
    "relampadejaram": "relampadejar",
    "relampadejaras": "relampadejar",
    "relampadejardes": "relampadejar",
    "relampadejarei": "relampadejar",
    "relampadejareis": "relampadejar",
    "relampadejarem": "relampadejar",
    "relampadejaremos": "relampadejar",
    "relampadejares": "relampadejar",
    "relampadejaria": "relampadejar",
    "relampadejariam": "relampadejar",
    "relampadejarias": "relampadejar",
    "relampadejarmo": "relampadejar",
    "relampadejarmos": "relampadejar",
    "relampadejará": "relampadejar",
    "relampadejarás": "relampadejar",
    "relampadejarão": "relampadejar",
    "relampadejaríamos": "relampadejar",
    "relampadejaríeis": "relampadejar",
    "relampadejas": "relampadejar",
    "relampadejasse": "relampadejar",
    "relampadejassem": "relampadejar",
    "relampadejasses": "relampadejar",
    "relampadejaste": "relampadejar",
    "relampadejastes": "relampadejar",
    "relampadejava": "relampadejar",
    "relampadejavam": "relampadejar",
    "relampadejavas": "relampadejar",
    "relampadeje": "relampadejar",
    "relampadejei": "relampadejar",
    "relampadejeis": "relampadejar",
    "relampadejem": "relampadejar",
    "relampadejemo": "relampadejar",
    "relampadejemos": "relampadejar",
    "relampadejes": "relampadejar",
    "relampadejo": "relampadejar",
    "relampadejou": "relampadejar",
    "relampadejámo": "relampadejar",
    "relampadejámos": "relampadejar",
    "relampadejáramo": "relampadejar",
    "relampadejáramos": "relampadejar",
    "relampadejáreis": "relampadejar",
    "relampadejásseis": "relampadejar",
    "relampadejássemos": "relampadejar",
    "relampadejávamo": "relampadejar",
    "relampadejávamos": "relampadejar",
    "relampadejáveis": "relampadejar",
    "relampado": "relampar",
    "relampados": "relampar",
    "relampagueada": "relampaguear",
    "relampagueadas": "relampaguear",
    "relampagueado": "relampaguear",
    "relampagueados": "relampaguear",
    "relampagueai": "relampaguear",
    "relampagueais": "relampaguear",
    "relampagueamentos": "relampagueamento",
    "relampagueamo": "relampaguear",
    "relampagueamos": "relampaguear",
    "relampagueando": "relampaguear",
    "relampagueantes": "relampagueante",
    "relampagueara": "relampaguear",
    "relampaguearam": "relampaguear",
    "relampaguearas": "relampaguear",
    "relampagueardes": "relampaguear",
    "relampaguearei": "relampaguear",
    "relampagueareis": "relampaguear",
    "relampaguearem": "relampaguear",
    "relampaguearemos": "relampaguear",
    "relampagueares": "relampaguear",
    "relampaguearia": "relampaguear",
    "relampagueariam": "relampaguear",
    "relampaguearias": "relampaguear",
    "relampaguearmo": "relampaguear",
    "relampaguearmos": "relampaguear",
    "relampagueará": "relampaguear",
    "relampaguearás": "relampaguear",
    "relampaguearão": "relampaguear",
    "relampaguearíamos": "relampaguear",
    "relampaguearíeis": "relampaguear",
    "relampagueasse": "relampaguear",
    "relampagueassem": "relampaguear",
    "relampagueasses": "relampaguear",
    "relampagueaste": "relampaguear",
    "relampagueastes": "relampaguear",
    "relampagueava": "relampaguear",
    "relampagueavam": "relampaguear",
    "relampagueavas": "relampaguear",
    "relampagueei": "relampaguear",
    "relampagueeis": "relampaguear",
    "relampagueemo": "relampaguear",
    "relampagueemos": "relampaguear",
    "relampagueia": "relampaguear",
    "relampagueiam": "relampaguear",
    "relampagueias": "relampaguear",
    "relampagueie": "relampaguear",
    "relampagueiem": "relampaguear",
    "relampagueies": "relampaguear",
    "relampagueio": "relampaguear",
    "relampagueou": "relampaguear",
    "relampagueámo": "relampaguear",
    "relampagueámos": "relampaguear",
    "relampagueáramo": "relampaguear",
    "relampagueáramos": "relampaguear",
    "relampagueáreis": "relampaguear",
    "relampagueásseis": "relampaguear",
    "relampagueássemos": "relampaguear",
    "relampagueávamo": "relampaguear",
    "relampagueávamos": "relampaguear",
    "relampagueáveis": "relampaguear",
    "relampai": "relampar",
    "relampais": "relampar",
    "relampam": "relampar",
    "relampamo": "relampar",
    "relampamos": "relampar",
    "relampando": "relampar",
    "relampara": "relampar",
    "relamparam": "relampar",
    "relamparas": "relampar",
    "relampardes": "relampar",
    "relamparei": "relampar",
    "relampareis": "relampar",
    "relamparem": "relampar",
    "relamparemos": "relampar",
    "relampares": "relampar",
    "relamparia": "relampar",
    "relampariam": "relampar",
    "relamparias": "relampar",
    "relamparmo": "relampar",
    "relamparmos": "relampar",
    "relampará": "relampar",
    "relamparás": "relampar",
    "relamparão": "relampar",
    "relamparíamos": "relampar",
    "relamparíeis": "relampar",
    "relampas": "relampar",
    "relampasse": "relampar",
    "relampassem": "relampar",
    "relampasses": "relampar",
    "relampaste": "relampar",
    "relampastes": "relampar",
    "relampava": "relampar",
    "relampavam": "relampar",
    "relampavas": "relampar",
    "relampe": "relampar",
    "relampeada": "relampear",
    "relampeadas": "relampear",
    "relampeado": "relampear",
    "relampeados": "relampear",
    "relampeai": "relampear",
    "relampeais": "relampear",
    "relampeamo": "relampear",
    "relampeamos": "relampear",
    "relampeando": "relampear",
    "relampeara": "relampear",
    "relampearam": "relampear",
    "relampearas": "relampear",
    "relampeardes": "relampear",
    "relampearei": "relampear",
    "relampeareis": "relampear",
    "relampearem": "relampear",
    "relampearemos": "relampear",
    "relampeares": "relampear",
    "relampearia": "relampear",
    "relampeariam": "relampear",
    "relampearias": "relampear",
    "relampearmo": "relampear",
    "relampearmos": "relampear",
    "relampeará": "relampear",
    "relampearás": "relampear",
    "relampearão": "relampear",
    "relampearíamos": "relampear",
    "relampearíeis": "relampear",
    "relampeasse": "relampear",
    "relampeassem": "relampear",
    "relampeasses": "relampear",
    "relampeaste": "relampear",
    "relampeastes": "relampear",
    "relampeava": "relampear",
    "relampeavam": "relampear",
    "relampeavas": "relampear",
    "relampeei": "relampear",
    "relampeeis": "relampear",
    "relampeemo": "relampear",
    "relampeemos": "relampear",
    "relampei": "relampar",
    "relampeia": "relampear",
    "relampeiam": "relampear",
    "relampeias": "relampear",
    "relampeie": "relampear",
    "relampeiem": "relampear",
    "relampeies": "relampear",
    "relampeio": "relampear",
    "relampeis": "relampar",
    "relampeja": "relampejar",
    "relampejada": "relampejar",
    "relampejadas": "relampejar",
    "relampejado": "relampejar",
    "relampejados": "relampejar",
    "relampejai": "relampejar",
    "relampejais": "relampejar",
    "relampejam": "relampejar",
    "relampejamo": "relampejar",
    "relampejamos": "relampejar",
    "relampejando": "relampejar",
    "relampejantes": "relampejante",
    "relampejara": "relampejar",
    "relampejaram": "relampejar",
    "relampejaras": "relampejar",
    "relampejardes": "relampejar",
    "relampejarei": "relampejar",
    "relampejareis": "relampejar",
    "relampejarem": "relampejar",
    "relampejaremos": "relampejar",
    "relampejares": "relampejar",
    "relampejaria": "relampejar",
    "relampejariam": "relampejar",
    "relampejarias": "relampejar",
    "relampejarmo": "relampejar",
    "relampejarmos": "relampejar",
    "relampejará": "relampejar",
    "relampejarás": "relampejar",
    "relampejarão": "relampejar",
    "relampejaríamos": "relampejar",
    "relampejaríeis": "relampejar",
    "relampejas": "relampejar",
    "relampejasse": "relampejar",
    "relampejassem": "relampejar",
    "relampejasses": "relampejar",
    "relampejaste": "relampejar",
    "relampejastes": "relampejar",
    "relampejava": "relampejar",
    "relampejavam": "relampejar",
    "relampejavas": "relampejar",
    "relampeje": "relampejar",
    "relampejei": "relampejar",
    "relampejeis": "relampejar",
    "relampejem": "relampejar",
    "relampejemo": "relampejar",
    "relampejemos": "relampejar",
    "relampejes": "relampejar",
    "relampejo": "relampejar",
    "relampejos": "relampejo",
    "relampejou": "relampejar",
    "relampejámo": "relampejar",
    "relampejámos": "relampejar",
    "relampejáramo": "relampejar",
    "relampejáramos": "relampejar",
    "relampejáreis": "relampejar",
    "relampejásseis": "relampejar",
    "relampejássemos": "relampejar",
    "relampejávamo": "relampejar",
    "relampejávamos": "relampejar",
    "relampejáveis": "relampejar",
    "relampem": "relampar",
    "relampemo": "relampar",
    "relampemos": "relampar",
    "relampeou": "relampear",
    "relampes": "relampar",
    "relampeámo": "relampear",
    "relampeámos": "relampear",
    "relampeáramo": "relampear",
    "relampeáramos": "relampear",
    "relampeáreis": "relampear",
    "relampeásseis": "relampear",
    "relampeássemos": "relampear",
    "relampeávamo": "relampear",
    "relampeávamos": "relampear",
    "relampeáveis": "relampear",
    "relampo": "relampar",
    "relampos": "relampo",
    "relampou": "relampar",
    "relampámo": "relampar",
    "relampámos": "relampar",
    "relampáramo": "relampar",
    "relampáramos": "relampar",
    "relampáreis": "relampar",
    "relampásseis": "relampar",
    "relampássemos": "relampar",
    "relampávamo": "relampar",
    "relampávamos": "relampar",
    "relampáveis": "relampar",
    "relance": "relançar",
    "relanceada": "relancear",
    "relanceadas": "relancear",
    "relanceado": "relancear",
    "relanceados": "relancear",
    "relanceai": "relancear",
    "relanceais": "relancear",
    "relanceamo": "relancear",
    "relanceamos": "relancear",
    "relanceando": "relancear",
    "relanceara": "relancear",
    "relancearam": "relancear",
    "relancearas": "relancear",
    "relancearde": "relancear",
    "relanceardes": "relancear",
    "relanceare": "relancear",
    "relancearei": "relancear",
    "relanceareis": "relancear",
    "relancearem": "relancear",
    "relancearemos": "relancear",
    "relanceares": "relancear",
    "relancearia": "relancear",
    "relanceariam": "relancear",
    "relancearias": "relancear",
    "relancearmo": "relancear",
    "relancearmos": "relancear",
    "relanceará": "relancear",
    "relancearás": "relancear",
    "relancearão": "relancear",
    "relancearíamos": "relancear",
    "relancearíeis": "relancear",
    "relanceasse": "relancear",
    "relanceassem": "relancear",
    "relanceasses": "relancear",
    "relanceaste": "relancear",
    "relanceastes": "relancear",
    "relanceava": "relancear",
    "relanceavam": "relancear",
    "relanceavas": "relancear",
    "relanceei": "relancear",
    "relanceeis": "relancear",
    "relanceemo": "relancear",
    "relanceemos": "relancear",
    "relancei": "relançar",
    "relanceia": "relancear",
    "relanceiam": "relancear",
    "relanceias": "relancear",
    "relanceie": "relancear",
    "relanceiem": "relancear",
    "relanceies": "relancear",
    "relanceio": "relancear",
    "relanceis": "relançar",
    "relancem": "relançar",
    "relancemo": "relançar",
    "relancemos": "relançar",
    "relanceou": "relancear",
    "relances": "relance",
    "relanceá": "relancear",
    "relanceámo": "relancear",
    "relanceámos": "relancear",
    "relanceáramo": "relancear",
    "relanceáramos": "relancear",
    "relanceárei": "relancear",
    "relanceáreis": "relancear",
    "relanceásseis": "relancear",
    "relanceássemos": "relancear",
    "relanceávamo": "relancear",
    "relanceávamos": "relancear",
    "relanceávei": "relancear",
    "relanceáveis": "relancear",
    "relando": "relar",
    "relança": "relançar",
    "relançada": "relançar",
    "relançadas": "relançar",
    "relançado": "relançar",
    "relançados": "relançar",
    "relançai": "relançar",
    "relançais": "relançar",
    "relançam": "relançar",
    "relançamentos": "relançamento",
    "relançamo": "relançar",
    "relançamos": "relançar",
    "relançando": "relançar",
    "relançara": "relançar",
    "relançaram": "relançar",
    "relançaras": "relançar",
    "relançarde": "relançar",
    "relançardes": "relançar",
    "relançare": "relançar",
    "relançarei": "relançar",
    "relançareis": "relançar",
    "relançarem": "relançar",
    "relançaremos": "relançar",
    "relançares": "relançar",
    "relançaria": "relançar",
    "relançariam": "relançar",
    "relançarias": "relançar",
    "relançarmo": "relançar",
    "relançarmos": "relançar",
    "relançará": "relançar",
    "relançarás": "relançar",
    "relançarão": "relançar",
    "relançaríamos": "relançar",
    "relançaríeis": "relançar",
    "relanças": "relançar",
    "relançasse": "relançar",
    "relançassem": "relançar",
    "relançasses": "relançar",
    "relançaste": "relançar",
    "relançastes": "relançar",
    "relançava": "relançar",
    "relançavam": "relançar",
    "relançavas": "relançar",
    "relanço": "relançar",
    "relançou": "relançar",
    "relançá": "relançar",
    "relançámo": "relançar",
    "relançámos": "relançar",
    "relançáramo": "relançar",
    "relançáramos": "relançar",
    "relançárei": "relançar",
    "relançáreis": "relançar",
    "relançásseis": "relançar",
    "relançássemos": "relançar",
    "relançávamo": "relançar",
    "relançávamos": "relançar",
    "relançávei": "relançar",
    "relançáveis": "relançável",
    "relapsa": "relapso",
    "relapsas": "relapso",
    "relapsias": "relapsia",
    "relapsos": "relapso",
    "relapsões": "relapsão",
    "relara": "relar",
    "relaram": "relar",
    "relaras": "relar",
    "relarde": "relar",
    "relardes": "relar",
    "relare": "relar",
    "relarei": "relar",
    "relareis": "relar",
    "relarem": "relar",
    "relaremos": "relar",
    "relares": "relar",
    "relaria": "relar",
    "relariam": "relar",
    "relarias": "relar",
    "relarmo": "relar",
    "relarmos": "relar",
    "relará": "relar",
    "relarás": "relar",
    "relarão": "relar",
    "relaríamos": "relar",
    "relaríeis": "relar",
    "relas": "relar",
    "relasse": "relar",
    "relassem": "relar",
    "relasses": "relar",
    "relaste": "relar",
    "relastes": "relar",
    "relata": "relatar",
    "relatada": "relatar",
    "relatadas": "relatar",
    "relatado": "relatar",
    "relatadora": "relatador",
    "relatadoras": "relatador",
    "relatadores": "relatador",
    "relatados": "relatar",
    "relatai": "relatar",
    "relatais": "relatar",
    "relatam": "relatar",
    "relatamo": "relatar",
    "relatamos": "relatar",
    "relatando": "relatar",
    "relatara": "relatar",
    "relataram": "relatar",
    "relataras": "relatar",
    "relatarde": "relatar",
    "relatardes": "relatar",
    "relatare": "relatar",
    "relatarei": "relatar",
    "relatareis": "relatar",
    "relatarem": "relatar",
    "relataremos": "relatar",
    "relatares": "relatar",
    "relataria": "relatar",
    "relatariam": "relatar",
    "relatarias": "relatar",
    "relatarmo": "relatar",
    "relatarmos": "relatar",
    "relatará": "relatar",
    "relatarás": "relatar",
    "relatarão": "relatar",
    "relataríamos": "relatar",
    "relataríeis": "relatar",
    "relatas": "relatar",
    "relatasse": "relatar",
    "relatassem": "relatar",
    "relatasses": "relatar",
    "relataste": "relatar",
    "relatastes": "relatar",
    "relatava": "relatar",
    "relatavam": "relatar",
    "relatavas": "relatar",
    "relate": "relatar",
    "relatei": "relatar",
    "relateis": "relatar",
    "relatem": "relatar",
    "relatemo": "relatar",
    "relatemos": "relatar",
    "relates": "relatar",
    "relativa": "relativo",
    "relativas": "relativo",
    "relatividades": "relatividade",
    "relativismos": "relativismo",
    "relativistas": "relativista",
    "relativiza": "relativizar",
    "relativizada": "relativizar",
    "relativizadas": "relativizar",
    "relativizado": "relativizar",
    "relativizados": "relativizar",
    "relativizai": "relativizar",
    "relativizais": "relativizar",
    "relativizam": "relativizar",
    "relativizamo": "relativizar",
    "relativizamos": "relativizar",
    "relativizando": "relativizar",
    "relativizara": "relativizar",
    "relativizaram": "relativizar",
    "relativizaras": "relativizar",
    "relativizarde": "relativizar",
    "relativizardes": "relativizar",
    "relativizare": "relativizar",
    "relativizarei": "relativizar",
    "relativizareis": "relativizar",
    "relativizarem": "relativizar",
    "relativizaremos": "relativizar",
    "relativizares": "relativizar",
    "relativizaria": "relativizar",
    "relativizariam": "relativizar",
    "relativizarias": "relativizar",
    "relativizarmo": "relativizar",
    "relativizarmos": "relativizar",
    "relativizará": "relativizar",
    "relativizarás": "relativizar",
    "relativizarão": "relativizar",
    "relativizaríamos": "relativizar",
    "relativizaríeis": "relativizar",
    "relativizas": "relativizar",
    "relativizasse": "relativizar",
    "relativizassem": "relativizar",
    "relativizasses": "relativizar",
    "relativizaste": "relativizar",
    "relativizastes": "relativizar",
    "relativizava": "relativizar",
    "relativizavam": "relativizar",
    "relativizavas": "relativizar",
    "relativizações": "relativização",
    "relativize": "relativizar",
    "relativizei": "relativizar",
    "relativizeis": "relativizar",
    "relativizem": "relativizar",
    "relativizemo": "relativizar",
    "relativizemos": "relativizar",
    "relativizes": "relativizar",
    "relativizo": "relativizar",
    "relativizou": "relativizar",
    "relativizá": "relativizar",
    "relativizámo": "relativizar",
    "relativizámos": "relativizar",
    "relativizáramo": "relativizar",
    "relativizáramos": "relativizar",
    "relativizárei": "relativizar",
    "relativizáreis": "relativizar",
    "relativizásseis": "relativizar",
    "relativizássemos": "relativizar",
    "relativizávamo": "relativizar",
    "relativizávamos": "relativizar",
    "relativizávei": "relativizar",
    "relativizáveis": "relativizar",
    "relativos": "relativo",
    "relato": "relatar",
    "relatora": "relator",
    "relatoras": "relator",
    "relatorazinha": "relator",
    "relatorazinhas": "relator",
    "relatorazita": "relator",
    "relatorazitas": "relator",
    "relatores": "relator",
    "relatorzinho": "relator",
    "relatorzinhos": "relator",
    "relatorzito": "relator",
    "relatorzitos": "relator",
    "relatos": "relato",
    "relatou": "relatar",
    "relatá": "relatar",
    "relatámo": "relatar",
    "relatámos": "relatar",
    "relatáramo": "relatar",
    "relatáramos": "relatar",
    "relatárei": "relatar",
    "relatáreis": "relatar",
    "relatásseis": "relatar",
    "relatássemos": "relatar",
    "relatávamo": "relatar",
    "relatávamos": "relatar",
    "relatávei": "relatar",
    "relatáveis": "relatar",
    "relatórios": "relatório",
    "relava": "relar",
    "relavam": "relar",
    "relavas": "relar",
    "relaxa": "relaxar",
    "relaxada": "relaxar",
    "relaxadas": "relaxar",
    "relaxadazinha": "relaxado",
    "relaxadazinhas": "relaxado",
    "relaxadazita": "relaxado",
    "relaxadazitas": "relaxado",
    "relaxadinha": "relaxado",
    "relaxadinhas": "relaxado",
    "relaxadinho": "relaxado",
    "relaxadinhos": "relaxado",
    "relaxadita": "relaxado",
    "relaxaditas": "relaxado",
    "relaxadito": "relaxado",
    "relaxaditos": "relaxado",
    "relaxado": "relaxar",
    "relaxadora": "relaxador",
    "relaxadoras": "relaxador",
    "relaxadores": "relaxador",
    "relaxados": "relaxar",
    "relaxadozinho": "relaxado",
    "relaxadozinhos": "relaxado",
    "relaxadozito": "relaxado",
    "relaxadozitos": "relaxado",
    "relaxadíssima": "relaxado",
    "relaxadíssimas": "relaxado",
    "relaxadíssimo": "relaxado",
    "relaxadíssimos": "relaxado",
    "relaxai": "relaxar",
    "relaxais": "relaxar",
    "relaxam": "relaxar",
    "relaxamentos": "relaxamento",
    "relaxamo": "relaxar",
    "relaxamos": "relaxar",
    "relaxando": "relaxar",
    "relaxantes": "relaxante",
    "relaxara": "relaxar",
    "relaxaram": "relaxar",
    "relaxaras": "relaxar",
    "relaxarde": "relaxar",
    "relaxardes": "relaxar",
    "relaxare": "relaxar",
    "relaxarei": "relaxar",
    "relaxareis": "relaxar",
    "relaxarem": "relaxar",
    "relaxaremos": "relaxar",
    "relaxares": "relaxar",
    "relaxaria": "relaxar",
    "relaxariam": "relaxar",
    "relaxarias": "relaxar",
    "relaxarmo": "relaxar",
    "relaxarmos": "relaxar",
    "relaxará": "relaxar",
    "relaxarás": "relaxar",
    "relaxarão": "relaxar",
    "relaxaríamos": "relaxar",
    "relaxaríeis": "relaxar",
    "relaxas": "relaxar",
    "relaxasse": "relaxar",
    "relaxassem": "relaxar",
    "relaxasses": "relaxar",
    "relaxaste": "relaxar",
    "relaxastes": "relaxar",
    "relaxativa": "relaxativo",
    "relaxativas": "relaxativo",
    "relaxativos": "relaxativo",
    "relaxava": "relaxar",
    "relaxavam": "relaxar",
    "relaxavas": "relaxar",
    "relaxações": "relaxação",
    "relaxe": "relaxar",
    "relaxei": "relaxar",
    "relaxeis": "relaxar",
    "relaxem": "relaxar",
    "relaxemo": "relaxar",
    "relaxemos": "relaxar",
    "relaxes": "relaxe",
    "relaxidões": "relaxidão",
    "relaxismos": "relaxismo",
    "relaxistas": "relaxista",
    "relaxo": "relaxar",
    "relaxou": "relaxar",
    "relaxá": "relaxar",
    "relaxámo": "relaxar",
    "relaxámos": "relaxar",
    "relaxáramo": "relaxar",
    "relaxáramos": "relaxar",
    "relaxárei": "relaxar",
    "relaxáreis": "relaxar",
    "relaxásseis": "relaxar",
    "relaxássemos": "relaxar",
    "relaxávamo": "relaxar",
    "relaxávamos": "relaxar",
    "relaxávei": "relaxar",
    "relaxáveis": "relaxar",
    "relações": "relação",
    "rele": "relar",
    "releases": "release",
    "relede": "reler",
    "reledes": "reler",
    "relega": "relegar",
    "relegada": "relegar",
    "relegadas": "relegar",
    "relegado": "relegar",
    "relegados": "relegar",
    "relegai": "relegar",
    "relegais": "relegar",
    "relegam": "relegar",
    "relegamo": "relegar",
    "relegamos": "relegar",
    "relegando": "relegar",
    "relegara": "relegar",
    "relegaram": "relegar",
    "relegaras": "relegar",
    "relegarde": "relegar",
    "relegardes": "relegar",
    "relegare": "relegar",
    "relegarei": "relegar",
    "relegareis": "relegar",
    "relegarem": "relegar",
    "relegaremos": "relegar",
    "relegares": "relegar",
    "relegaria": "relegar",
    "relegariam": "relegar",
    "relegarias": "relegar",
    "relegarmo": "relegar",
    "relegarmos": "relegar",
    "relegará": "relegar",
    "relegarás": "relegar",
    "relegarão": "relegar",
    "relegaríamos": "relegar",
    "relegaríeis": "relegar",
    "relegas": "relegar",
    "relegasse": "relegar",
    "relegassem": "relegar",
    "relegasses": "relegar",
    "relegaste": "relegar",
    "relegastes": "relegar",
    "relegava": "relegar",
    "relegavam": "relegar",
    "relegavas": "relegar",
    "relegações": "relegação",
    "relegitimações": "relegitimação",
    "relego": "relegar",
    "relegos": "relego",
    "relegou": "relegar",
    "relegue": "relegar",
    "releguei": "relegar",
    "relegueis": "relegar",
    "releguem": "relegar",
    "releguemo": "relegar",
    "releguemos": "relegar",
    "relegues": "relegar",
    "relegá": "relegar",
    "relegámo": "relegar",
    "relegámos": "relegar",
    "relegáramo": "relegar",
    "relegáramos": "relegar",
    "relegárei": "relegar",
    "relegáreis": "relegar",
    "relegásseis": "relegar",
    "relegássemos": "relegar",
    "relegávamo": "relegar",
    "relegávamos": "relegar",
    "relegávei": "relegar",
    "relegáveis": "relegável",
    "relei": "relar",
    "releia": "reler",
    "releiais": "reler",
    "releiam": "reler",
    "releiamo": "reler",
    "releiamos": "reler",
    "releias": "reler",
    "releio": "reler",
    "releiros": "releiro",
    "releis": "relar",
    "releituras": "releitura",
    "releixa": "releixar",
    "releixada": "releixar",
    "releixadas": "releixar",
    "releixado": "releixar",
    "releixados": "releixar",
    "releixai": "releixar",
    "releixais": "releixar",
    "releixam": "releixar",
    "releixamo": "releixar",
    "releixamos": "releixar",
    "releixando": "releixar",
    "releixara": "releixar",
    "releixaram": "releixar",
    "releixaras": "releixar",
    "releixarde": "releixar",
    "releixardes": "releixar",
    "releixare": "releixar",
    "releixarei": "releixar",
    "releixareis": "releixar",
    "releixarem": "releixar",
    "releixaremos": "releixar",
    "releixares": "releixar",
    "releixaria": "releixar",
    "releixariam": "releixar",
    "releixarias": "releixar",
    "releixarmo": "releixar",
    "releixarmos": "releixar",
    "releixará": "releixar",
    "releixarás": "releixar",
    "releixarão": "releixar",
    "releixaríamos": "releixar",
    "releixaríeis": "releixar",
    "releixas": "releixar",
    "releixasse": "releixar",
    "releixassem": "releixar",
    "releixasses": "releixar",
    "releixaste": "releixar",
    "releixastes": "releixar",
    "releixava": "releixar",
    "releixavam": "releixar",
    "releixavas": "releixar",
    "releixe": "releixar",
    "releixei": "releixar",
    "releixeis": "releixar",
    "releixem": "releixar",
    "releixemo": "releixar",
    "releixemos": "releixar",
    "releixes": "releixar",
    "releixo": "releixar",
    "releixos": "releixo",
    "releixou": "releixar",
    "releixá": "releixar",
    "releixámo": "releixar",
    "releixámos": "releixar",
    "releixáramo": "releixar",
    "releixáramos": "releixar",
    "releixárei": "releixar",
    "releixáreis": "releixar",
    "releixásseis": "releixar",
    "releixássemos": "releixar",
    "releixávamo": "releixar",
    "releixávamos": "releixar",
    "releixávei": "releixar",
    "releixáveis": "releixar",
    "relem": "relar",
    "relembra": "relembrar",
    "relembrada": "relembrar",
    "relembradas": "relembrar",
    "relembrado": "relembrar",
    "relembrados": "relembrar",
    "relembrai": "relembrar",
    "relembrais": "relembrar",
    "relembram": "relembrar",
    "relembramo": "relembrar",
    "relembramos": "relembrar",
    "relembrando": "relembrar",
    "relembranças": "relembrança",
    "relembrara": "relembrar",
    "relembraram": "relembrar",
    "relembraras": "relembrar",
    "relembrarde": "relembrar",
    "relembrardes": "relembrar",
    "relembrare": "relembrar",
    "relembrarei": "relembrar",
    "relembrareis": "relembrar",
    "relembrarem": "relembrar",
    "relembraremos": "relembrar",
    "relembrares": "relembrar",
    "relembraria": "relembrar",
    "relembrariam": "relembrar",
    "relembrarias": "relembrar",
    "relembrarmo": "relembrar",
    "relembrarmos": "relembrar",
    "relembrará": "relembrar",
    "relembrarás": "relembrar",
    "relembrarão": "relembrar",
    "relembraríamos": "relembrar",
    "relembraríeis": "relembrar",
    "relembras": "relembrar",
    "relembrasse": "relembrar",
    "relembrassem": "relembrar",
    "relembrasses": "relembrar",
    "relembraste": "relembrar",
    "relembrastes": "relembrar",
    "relembrativa": "relembrativo",
    "relembrativas": "relembrativo",
    "relembrativos": "relembrativo",
    "relembrava": "relembrar",
    "relembravam": "relembrar",
    "relembravas": "relembrar",
    "relembre": "relembrar",
    "relembrei": "relembrar",
    "relembreis": "relembrar",
    "relembrem": "relembrar",
    "relembremo": "relembrar",
    "relembremos": "relembrar",
    "relembres": "relembrar",
    "relembro": "relembrar",
    "relembrou": "relembrar",
    "relembrá": "relembrar",
    "relembrámo": "relembrar",
    "relembrámos": "relembrar",
    "relembráramo": "relembrar",
    "relembráramos": "relembrar",
    "relembrárei": "relembrar",
    "relembráreis": "relembrar",
    "relembrásseis": "relembrar",
    "relembrássemos": "relembrar",
    "relembrávamo": "relembrar",
    "relembrávamos": "relembrar",
    "relembrávei": "relembrar",
    "relembráveis": "relembrável",
    "relemo": "reler",
    "relemos": "reler",
    "relendo": "reler",
    "relengos": "relengo",
    "relenta": "relentar",
    "relentada": "relentar",
    "relentadas": "relentar",
    "relentado": "relentar",
    "relentados": "relentar",
    "relentai": "relentar",
    "relentais": "relentar",
    "relentam": "relentar",
    "relentamo": "relentar",
    "relentamos": "relentar",
    "relentando": "relentar",
    "relentara": "relentar",
    "relentaram": "relentar",
    "relentaras": "relentar",
    "relentardes": "relentar",
    "relentarei": "relentar",
    "relentareis": "relentar",
    "relentarem": "relentar",
    "relentaremos": "relentar",
    "relentares": "relentar",
    "relentaria": "relentar",
    "relentariam": "relentar",
    "relentarias": "relentar",
    "relentarmo": "relentar",
    "relentarmos": "relentar",
    "relentará": "relentar",
    "relentarás": "relentar",
    "relentarão": "relentar",
    "relentaríamos": "relentar",
    "relentaríeis": "relentar",
    "relentas": "relentar",
    "relentasse": "relentar",
    "relentassem": "relentar",
    "relentasses": "relentar",
    "relentaste": "relentar",
    "relentastes": "relentar",
    "relentava": "relentar",
    "relentavam": "relentar",
    "relentavas": "relentar",
    "relente": "relentar",
    "relentei": "relentar",
    "relenteis": "relentar",
    "relentem": "relentar",
    "relentemo": "relentar",
    "relentemos": "relentar",
    "relentes": "relentar",
    "relento": "relentar",
    "relentos": "relento",
    "relentou": "relentar",
    "relentámo": "relentar",
    "relentámos": "relentar",
    "relentáramo": "relentar",
    "relentáramos": "relentar",
    "relentáreis": "relentar",
    "relentásseis": "relentar",
    "relentássemos": "relentar",
    "relentávamo": "relentar",
    "relentávamos": "relentar",
    "relentáveis": "relentar",
    "relera": "reler",
    "releram": "reler",
    "releras": "reler",
    "relerde": "reler",
    "relerdes": "reler",
    "relere": "reler",
    "relerei": "reler",
    "relereis": "reler",
    "relerem": "reler",
    "releremos": "reler",
    "releres": "reler",
    "releria": "reler",
    "releriam": "reler",
    "relerias": "reler",
    "relermo": "reler",
    "relermos": "reler",
    "relerá": "reler",
    "relerás": "reler",
    "relerão": "reler",
    "releríamos": "reler",
    "releríeis": "reler",
    "reles": "relar",
    "relesse": "reler",
    "relessem": "reler",
    "relesses": "reler",
    "releste": "reler",
    "relestes": "reler",
    "releu": "reler",
    "releva": "relevar",
    "relevada": "relevar",
    "relevadas": "relevar",
    "relevado": "relevar",
    "relevadora": "relevador",
    "relevadoras": "relevador",
    "relevadores": "relevador",
    "relevados": "relevar",
    "relevai": "relevar",
    "relevais": "relevar",
    "relevam": "relevar",
    "relevamentos": "relevamento",
    "relevamo": "relevar",
    "relevamos": "relevar",
    "relevando": "relevar",
    "relevantes": "relevante",
    "relevantíssima": "relevante",
    "relevantíssimas": "relevante",
    "relevantíssimo": "relevante",
    "relevantíssimos": "relevante",
    "relevara": "relevar",
    "relevaram": "relevar",
    "relevaras": "relevar",
    "relevarde": "relevar",
    "relevardes": "relevar",
    "relevare": "relevar",
    "relevarei": "relevar",
    "relevareis": "relevar",
    "relevarem": "relevar",
    "relevaremos": "relevar",
    "relevares": "relevar",
    "relevaria": "relevar",
    "relevariam": "relevar",
    "relevarias": "relevar",
    "relevarmo": "relevar",
    "relevarmos": "relevar",
    "relevará": "relevar",
    "relevarás": "relevar",
    "relevarão": "relevar",
    "relevaríamos": "relevar",
    "relevaríeis": "relevar",
    "relevas": "relevar",
    "relevasse": "relevar",
    "relevassem": "relevar",
    "relevasses": "relevar",
    "relevaste": "relevar",
    "relevastes": "relevar",
    "relevava": "relevar",
    "relevavam": "relevar",
    "relevavas": "relevar",
    "relevações": "relevação",
    "releve": "relevar",
    "relevei": "relevar",
    "releveis": "relevar",
    "relevem": "relevar",
    "relevemo": "relevar",
    "relevemos": "relevar",
    "releves": "relevar",
    "relevo": "relevar",
    "relevos": "relevo",
    "relevou": "relevar",
    "relevá": "relevar",
    "relevámo": "relevar",
    "relevámos": "relevar",
    "releváramo": "relevar",
    "releváramos": "relevar",
    "relevárei": "relevar",
    "releváreis": "relevar",
    "relevásseis": "relevar",
    "relevássemos": "relevar",
    "relevávamo": "relevar",
    "relevávamos": "relevar",
    "relevávei": "relevar",
    "releváveis": "relevável",
    "relevâncias": "relevância",
    "relha": "relho",
    "relhada": "relhar",
    "relhadas": "relhar",
    "relhado": "relhar",
    "relhados": "relhar",
    "relhai": "relhar",
    "relhais": "relhar",
    "relham": "relhar",
    "relhamo": "relhar",
    "relhamos": "relhar",
    "relhando": "relhar",
    "relhara": "relhar",
    "relharam": "relhar",
    "relharas": "relhar",
    "relharde": "relhar",
    "relhardes": "relhar",
    "relhare": "relhar",
    "relharei": "relhar",
    "relhareis": "relhar",
    "relharem": "relhar",
    "relharemos": "relhar",
    "relhares": "relhar",
    "relharia": "relhar",
    "relhariam": "relhar",
    "relharias": "relhar",
    "relharmo": "relhar",
    "relharmos": "relhar",
    "relhará": "relhar",
    "relharás": "relhar",
    "relharão": "relhar",
    "relharíamos": "relhar",
    "relharíeis": "relhar",
    "relhas": "relho",
    "relhasse": "relhar",
    "relhassem": "relhar",
    "relhasses": "relhar",
    "relhaste": "relhar",
    "relhastes": "relhar",
    "relhava": "relhar",
    "relhavam": "relhar",
    "relhavas": "relhar",
    "relhe": "relhar",
    "relhei": "relhar",
    "relheiras": "relheira",
    "relheiros": "relheiro",
    "relheis": "relhar",
    "relhem": "relhar",
    "relhemo": "relhar",
    "relhemos": "relhar",
    "relhes": "relhar",
    "relho": "relhar",
    "relhos": "relho",
    "relhotas": "relhota",
    "relhotes": "relhote",
    "relhou": "relhar",
    "relhá": "relhar",
    "relhámo": "relhar",
    "relhámos": "relhar",
    "relháramo": "relhar",
    "relháramos": "relhar",
    "relhárei": "relhar",
    "relháreis": "relhar",
    "relhásseis": "relhar",
    "relhássemos": "relhar",
    "relhávamo": "relhar",
    "relhávamos": "relhar",
    "relhávei": "relhar",
    "relháveis": "relhar",
    "reli": "reler",
    "relia": "reler",
    "reliam": "reler",
    "relias": "reler",
    "relices": "relice",
    "relicita": "relicitar",
    "relicitada": "relicitar",
    "relicitadas": "relicitar",
    "relicitado": "relicitar",
    "relicitados": "relicitar",
    "relicitai": "relicitar",
    "relicitais": "relicitar",
    "relicitam": "relicitar",
    "relicitamo": "relicitar",
    "relicitamos": "relicitar",
    "relicitando": "relicitar",
    "relicitara": "relicitar",
    "relicitaram": "relicitar",
    "relicitaras": "relicitar",
    "relicitarde": "relicitar",
    "relicitardes": "relicitar",
    "relicitare": "relicitar",
    "relicitarei": "relicitar",
    "relicitareis": "relicitar",
    "relicitarem": "relicitar",
    "relicitaremos": "relicitar",
    "relicitares": "relicitar",
    "relicitaria": "relicitar",
    "relicitariam": "relicitar",
    "relicitarias": "relicitar",
    "relicitarmo": "relicitar",
    "relicitarmos": "relicitar",
    "relicitará": "relicitar",
    "relicitarás": "relicitar",
    "relicitarão": "relicitar",
    "relicitaríamos": "relicitar",
    "relicitaríeis": "relicitar",
    "relicitas": "relicitar",
    "relicitasse": "relicitar",
    "relicitassem": "relicitar",
    "relicitasses": "relicitar",
    "relicitaste": "relicitar",
    "relicitastes": "relicitar",
    "relicitava": "relicitar",
    "relicitavam": "relicitar",
    "relicitavas": "relicitar",
    "relicitações": "relicitação",
    "relicite": "relicitar",
    "relicitei": "relicitar",
    "reliciteis": "relicitar",
    "relicitem": "relicitar",
    "relicitemo": "relicitar",
    "relicitemos": "relicitar",
    "relicites": "relicitar",
    "relicito": "relicitar",
    "relicitou": "relicitar",
    "relicitá": "relicitar",
    "relicitámo": "relicitar",
    "relicitámos": "relicitar",
    "relicitáramo": "relicitar",
    "relicitáramos": "relicitar",
    "relicitárei": "relicitar",
    "relicitáreis": "relicitar",
    "relicitásseis": "relicitar",
    "relicitássemos": "relicitar",
    "relicitávamo": "relicitar",
    "relicitávamos": "relicitar",
    "relicitávei": "relicitar",
    "relicitáveis": "relicitar",
    "relicários": "relicário",
    "relida": "relido",
    "relidas": "relido",
    "relido": "reler",
    "relidos": "relido",
    "religa": "religar",
    "religada": "religar",
    "religadas": "religar",
    "religado": "religar",
    "religados": "religar",
    "religai": "religar",
    "religais": "religar",
    "religam": "religar",
    "religamo": "religar",
    "religamos": "religar",
    "religando": "religar",
    "religara": "religar",
    "religaram": "religar",
    "religaras": "religar",
    "religarde": "religar",
    "religardes": "religar",
    "religare": "religar",
    "religarei": "religar",
    "religareis": "religar",
    "religarem": "religar",
    "religaremos": "religar",
    "religares": "religar",
    "religaria": "religar",
    "religariam": "religar",
    "religarias": "religar",
    "religarmo": "religar",
    "religarmos": "religar",
    "religará": "religar",
    "religarás": "religar",
    "religarão": "religar",
    "religaríamos": "religar",
    "religaríeis": "religar",
    "religas": "religar",
    "religasse": "religar",
    "religassem": "religar",
    "religasses": "religar",
    "religaste": "religar",
    "religastes": "religar",
    "religava": "religar",
    "religavam": "religar",
    "religavas": "religar",
    "religiomanias": "religiomania",
    "religiomaníaca": "religiomaníaco",
    "religiomaníacas": "religiomaníaco",
    "religiomaníacos": "religiomaníaco",
    "religionária": "religionário",
    "religionárias": "religionário",
    "religionários": "religionário",
    "religiosa": "religioso",
    "religiosas": "religioso",
    "religiosazinha": "religioso",
    "religiosazinhas": "religioso",
    "religiosazita": "religioso",
    "religiosazitas": "religioso",
    "religiosidades": "religiosidade",
    "religiosos": "religioso",
    "religiosozinho": "religioso",
    "religiosozinhos": "religioso",
    "religiosozito": "religioso",
    "religiosozitos": "religioso",
    "religiosíssima": "religioso",
    "religiosíssimas": "religioso",
    "religiosíssimo": "religioso",
    "religiosíssimos": "religioso",
    "religiões": "religião",
    "religo": "religar",
    "religou": "religar",
    "religue": "religar",
    "religuei": "religar",
    "religueis": "religar",
    "religuem": "religar",
    "religuemo": "religar",
    "religuemos": "religar",
    "religues": "religar",
    "religá": "religar",
    "religámo": "religar",
    "religámos": "religar",
    "religáramo": "religar",
    "religáramos": "religar",
    "religárei": "religar",
    "religáreis": "religar",
    "religásseis": "religar",
    "religássemos": "religar",
    "religávamo": "religar",
    "religávamos": "religar",
    "religávei": "religar",
    "religáveis": "religar",
    "relima": "relimar",
    "relimada": "relimar",
    "relimadas": "relimar",
    "relimado": "relimar",
    "relimados": "relimar",
    "relimai": "relimar",
    "relimais": "relimar",
    "relimam": "relimar",
    "relimamo": "relimar",
    "relimamos": "relimar",
    "relimando": "relimar",
    "relimara": "relimar",
    "relimaram": "relimar",
    "relimaras": "relimar",
    "relimarde": "relimar",
    "relimardes": "relimar",
    "relimare": "relimar",
    "relimarei": "relimar",
    "relimareis": "relimar",
    "relimarem": "relimar",
    "relimaremos": "relimar",
    "relimares": "relimar",
    "relimaria": "relimar",
    "relimariam": "relimar",
    "relimarias": "relimar",
    "relimarmo": "relimar",
    "relimarmos": "relimar",
    "relimará": "relimar",
    "relimarás": "relimar",
    "relimarão": "relimar",
    "relimaríamos": "relimar",
    "relimaríeis": "relimar",
    "relimas": "relimar",
    "relimasse": "relimar",
    "relimassem": "relimar",
    "relimasses": "relimar",
    "relimaste": "relimar",
    "relimastes": "relimar",
    "relimava": "relimar",
    "relimavam": "relimar",
    "relimavas": "relimar",
    "relime": "relimar",
    "relimei": "relimar",
    "relimeis": "relimar",
    "relimem": "relimar",
    "relimemo": "relimar",
    "relimemos": "relimar",
    "relimes": "relimar",
    "relimo": "relimar",
    "relimou": "relimar",
    "relimá": "relimar",
    "relimámo": "relimar",
    "relimámos": "relimar",
    "relimáramo": "relimar",
    "relimáramos": "relimar",
    "relimárei": "relimar",
    "relimáreis": "relimar",
    "relimásseis": "relimar",
    "relimássemos": "relimar",
    "relimávamo": "relimar",
    "relimávamos": "relimar",
    "relimávei": "relimar",
    "relimáveis": "relimar",
    "relincha": "relinchar",
    "relinchada": "relinchar",
    "relinchadas": "relinchar",
    "relinchado": "relinchar",
    "relinchados": "relinchar",
    "relinchai": "relinchar",
    "relinchais": "relinchar",
    "relincham": "relinchar",
    "relinchamo": "relinchar",
    "relinchamos": "relinchar",
    "relinchando": "relinchar",
    "relinchara": "relinchar",
    "relincharam": "relinchar",
    "relincharas": "relinchar",
    "relinchardes": "relinchar",
    "relincharei": "relinchar",
    "relinchareis": "relinchar",
    "relincharem": "relinchar",
    "relincharemos": "relinchar",
    "relinchares": "relinchar",
    "relincharia": "relinchar",
    "relinchariam": "relinchar",
    "relincharias": "relinchar",
    "relincharmo": "relinchar",
    "relincharmos": "relinchar",
    "relinchará": "relinchar",
    "relincharás": "relinchar",
    "relincharão": "relinchar",
    "relincharíamos": "relinchar",
    "relincharíeis": "relinchar",
    "relinchas": "relinchar",
    "relinchasse": "relinchar",
    "relinchassem": "relinchar",
    "relinchasses": "relinchar",
    "relinchaste": "relinchar",
    "relinchastes": "relinchar",
    "relinchava": "relinchar",
    "relinchavam": "relinchar",
    "relinchavas": "relinchar",
    "relinche": "relinchar",
    "relinchei": "relinchar",
    "relincheis": "relinchar",
    "relinchem": "relinchar",
    "relinchemo": "relinchar",
    "relinchemos": "relinchar",
    "relinches": "relinchar",
    "relincho": "relinchar",
    "relinchona": "relinchão",
    "relinchonas": "relinchão",
    "relinchos": "relincho",
    "relinchou": "relinchar",
    "relinchámo": "relinchar",
    "relinchámos": "relinchar",
    "relincháramo": "relinchar",
    "relincháramos": "relinchar",
    "relincháreis": "relinchar",
    "relinchásseis": "relinchar",
    "relinchássemos": "relinchar",
    "relinchávamo": "relinchar",
    "relinchávamos": "relinchar",
    "relincháveis": "relinchar",
    "relinchões": "relinchão",
    "relinga": "relingar",
    "relingada": "relingar",
    "relingadas": "relingar",
    "relingado": "relingar",
    "relingados": "relingar",
    "relingai": "relingar",
    "relingais": "relingar",
    "relingam": "relingar",
    "relingamo": "relingar",
    "relingamos": "relingar",
    "relingando": "relingar",
    "relingara": "relingar",
    "relingaram": "relingar",
    "relingaras": "relingar",
    "relingarde": "relingar",
    "relingardes": "relingar",
    "relingare": "relingar",
    "relingarei": "relingar",
    "relingareis": "relingar",
    "relingarem": "relingar",
    "relingaremos": "relingar",
    "relingares": "relingar",
    "relingaria": "relingar",
    "relingariam": "relingar",
    "relingarias": "relingar",
    "relingarmo": "relingar",
    "relingarmos": "relingar",
    "relingará": "relingar",
    "relingarás": "relingar",
    "relingarão": "relingar",
    "relingaríamos": "relingar",
    "relingaríeis": "relingar",
    "relingas": "relingar",
    "relingasse": "relingar",
    "relingassem": "relingar",
    "relingasses": "relingar",
    "relingaste": "relingar",
    "relingastes": "relingar",
    "relingava": "relingar",
    "relingavam": "relingar",
    "relingavas": "relingar",
    "relingo": "relingar",
    "relingou": "relingar",
    "relingue": "relingar",
    "relinguei": "relingar",
    "relingueis": "relingar",
    "relinguem": "relingar",
    "relinguemo": "relingar",
    "relinguemos": "relingar",
    "relingues": "relingar",
    "relingá": "relingar",
    "relingámo": "relingar",
    "relingámos": "relingar",
    "relingáramo": "relingar",
    "relingáramos": "relingar",
    "relingárei": "relingar",
    "relingáreis": "relingar",
    "relingásseis": "relingar",
    "relingássemos": "relingar",
    "relingávamo": "relingar",
    "relingávamos": "relingar",
    "relingávei": "relingar",
    "relingáveis": "relingar",
    "relo": "relar",
    "relojeira": "relojeiro",
    "relojeiras": "relojeiro",
    "relojeiros": "relojeiro",
    "relojoarias": "relojoaria",
    "relojoeira": "relojoeiro",
    "relojoeiras": "relojoeiro",
    "relojoeiros": "relojoeiro",
    "reloteamentos": "reloteamento",
    "relou": "relar",
    "relouca": "reloucar",
    "reloucada": "reloucar",
    "reloucadas": "reloucar",
    "reloucado": "reloucar",
    "reloucados": "reloucar",
    "reloucais": "reloucar",
    "reloucam": "reloucar",
    "reloucamo": "reloucar",
    "reloucamos": "reloucar",
    "reloucando": "reloucar",
    "reloucara": "reloucar",
    "reloucaram": "reloucar",
    "reloucaras": "reloucar",
    "reloucardes": "reloucar",
    "reloucarei": "reloucar",
    "reloucareis": "reloucar",
    "reloucarem": "reloucar",
    "reloucaremos": "reloucar",
    "reloucares": "reloucar",
    "reloucaria": "reloucar",
    "reloucariam": "reloucar",
    "reloucarias": "reloucar",
    "reloucarmo": "reloucar",
    "reloucarmos": "reloucar",
    "reloucará": "reloucar",
    "reloucarás": "reloucar",
    "reloucarão": "reloucar",
    "reloucaríamos": "reloucar",
    "reloucaríeis": "reloucar",
    "reloucas": "reloucar",
    "reloucasse": "reloucar",
    "reloucassem": "reloucar",
    "reloucasses": "reloucar",
    "reloucaste": "reloucar",
    "reloucastes": "reloucar",
    "reloucava": "reloucar",
    "reloucavam": "reloucar",
    "reloucavas": "reloucar",
    "relouco": "reloucar",
    "reloucou": "reloucar",
    "reloucámo": "reloucar",
    "reloucámos": "reloucar",
    "reloucáramo": "reloucar",
    "reloucáramos": "reloucar",
    "reloucáreis": "reloucar",
    "reloucásseis": "reloucar",
    "reloucássemos": "reloucar",
    "reloucávamo": "reloucar",
    "reloucávamos": "reloucar",
    "reloucáveis": "reloucar",
    "relouque": "reloucar",
    "relouqueada": "relouquear",
    "relouqueadas": "relouquear",
    "relouqueado": "relouquear",
    "relouqueados": "relouquear",
    "relouqueai": "relouquear",
    "relouqueais": "relouquear",
    "relouqueamo": "relouquear",
    "relouqueamos": "relouquear",
    "relouqueando": "relouquear",
    "relouqueara": "relouquear",
    "relouquearam": "relouquear",
    "relouquearas": "relouquear",
    "relouqueardes": "relouquear",
    "relouquearei": "relouquear",
    "relouqueareis": "relouquear",
    "relouquearem": "relouquear",
    "relouquearemos": "relouquear",
    "relouqueares": "relouquear",
    "relouquearia": "relouquear",
    "relouqueariam": "relouquear",
    "relouquearias": "relouquear",
    "relouquearmo": "relouquear",
    "relouquearmos": "relouquear",
    "relouqueará": "relouquear",
    "relouquearás": "relouquear",
    "relouquearão": "relouquear",
    "relouquearíamos": "relouquear",
    "relouquearíeis": "relouquear",
    "relouqueasse": "relouquear",
    "relouqueassem": "relouquear",
    "relouqueasses": "relouquear",
    "relouqueaste": "relouquear",
    "relouqueastes": "relouquear",
    "relouqueava": "relouquear",
    "relouqueavam": "relouquear",
    "relouqueavas": "relouquear",
    "relouqueei": "relouquear",
    "relouqueeis": "relouquear",
    "relouqueemo": "relouquear",
    "relouqueemos": "relouquear",
    "relouquei": "reloucar",
    "relouqueia": "relouquear",
    "relouqueiam": "relouquear",
    "relouqueias": "relouquear",
    "relouqueie": "relouquear",
    "relouqueiem": "relouquear",
    "relouqueies": "relouquear",
    "relouqueio": "relouquear",
    "relouqueis": "reloucar",
    "relouquem": "reloucar",
    "relouquemos": "reloucar",
    "relouqueou": "relouquear",
    "relouques": "reloucar",
    "relouqueámo": "relouquear",
    "relouqueámos": "relouquear",
    "relouqueáramo": "relouquear",
    "relouqueáramos": "relouquear",
    "relouqueáreis": "relouquear",
    "relouqueásseis": "relouquear",
    "relouqueássemos": "relouquear",
    "relouqueávamo": "relouquear",
    "relouqueávamos": "relouquear",
    "relouqueáveis": "relouquear",
    "relumbra": "relumbrar",
    "relumbrada": "relumbrar",
    "relumbradas": "relumbrar",
    "relumbrado": "relumbrar",
    "relumbrados": "relumbrar",
    "relumbrai": "relumbrar",
    "relumbrais": "relumbrar",
    "relumbram": "relumbrar",
    "relumbramo": "relumbrar",
    "relumbramos": "relumbrar",
    "relumbrando": "relumbrar",
    "relumbrantes": "relumbrante",
    "relumbrara": "relumbrar",
    "relumbraram": "relumbrar",
    "relumbraras": "relumbrar",
    "relumbrardes": "relumbrar",
    "relumbrarei": "relumbrar",
    "relumbrareis": "relumbrar",
    "relumbrarem": "relumbrar",
    "relumbraremos": "relumbrar",
    "relumbrares": "relumbrar",
    "relumbraria": "relumbrar",
    "relumbrariam": "relumbrar",
    "relumbrarias": "relumbrar",
    "relumbrarmo": "relumbrar",
    "relumbrarmos": "relumbrar",
    "relumbrará": "relumbrar",
    "relumbrarás": "relumbrar",
    "relumbrarão": "relumbrar",
    "relumbraríamos": "relumbrar",
    "relumbraríeis": "relumbrar",
    "relumbras": "relumbrar",
    "relumbrasse": "relumbrar",
    "relumbrassem": "relumbrar",
    "relumbrasses": "relumbrar",
    "relumbraste": "relumbrar",
    "relumbrastes": "relumbrar",
    "relumbrava": "relumbrar",
    "relumbravam": "relumbrar",
    "relumbravas": "relumbrar",
    "relumbre": "relumbrar",
    "relumbrei": "relumbrar",
    "relumbreis": "relumbrar",
    "relumbrem": "relumbrar",
    "relumbremo": "relumbrar",
    "relumbremos": "relumbrar",
    "relumbres": "relumbrar",
    "relumbro": "relumbrar",
    "relumbrou": "relumbrar",
    "relumbrámo": "relumbrar",
    "relumbrámos": "relumbrar",
    "relumbráramo": "relumbrar",
    "relumbráramos": "relumbrar",
    "relumbráreis": "relumbrar",
    "relumbrásseis": "relumbrar",
    "relumbrássemos": "relumbrar",
    "relumbrávamo": "relumbrar",
    "relumbrávamos": "relumbrar",
    "relumbráveis": "relumbrar",
    "relumes": "relume",
    "reluta": "relutar",
    "relutada": "relutar",
    "relutadas": "relutar",
    "relutado": "relutar",
    "relutados": "relutar",
    "relutai": "relutar",
    "relutais": "relutar",
    "relutam": "relutar",
    "relutamo": "relutar",
    "relutamos": "relutar",
    "relutando": "relutar",
    "relutantes": "relutante",
    "relutara": "relutar",
    "relutaram": "relutar",
    "relutaras": "relutar",
    "relutardes": "relutar",
    "relutarei": "relutar",
    "relutareis": "relutar",
    "relutarem": "relutar",
    "relutaremos": "relutar",
    "relutares": "relutar",
    "relutaria": "relutar",
    "relutariam": "relutar",
    "relutarias": "relutar",
    "relutarmo": "relutar",
    "relutarmos": "relutar",
    "relutará": "relutar",
    "relutarás": "relutar",
    "relutarão": "relutar",
    "relutaríamos": "relutar",
    "relutaríeis": "relutar",
    "relutas": "relutar",
    "relutasse": "relutar",
    "relutassem": "relutar",
    "relutasses": "relutar",
    "relutaste": "relutar",
    "relutastes": "relutar",
    "relutava": "relutar",
    "relutavam": "relutar",
    "relutavas": "relutar",
    "relutações": "relutação",
    "relute": "relutar",
    "relutei": "relutar",
    "reluteis": "relutar",
    "relutem": "relutar",
    "relutemo": "relutar",
    "relutemos": "relutar",
    "relutes": "relutar",
    "relutividades": "relutividade",
    "reluto": "relutar",
    "relutou": "relutar",
    "relutámo": "relutar",
    "relutámos": "relutar",
    "relutáramo": "relutar",
    "relutáramos": "relutar",
    "relutáreis": "relutar",
    "relutásseis": "relutar",
    "relutássemos": "relutar",
    "relutávamo": "relutar",
    "relutávamos": "relutar",
    "relutáveis": "relutar",
    "relutâncias": "relutância",
    "reluz": "reluzir",
    "reluza": "reluzir",
    "reluzais": "reluzir",
    "reluzam": "reluzir",
    "reluzamo": "reluzir",
    "reluzamos": "reluzir",
    "reluzas": "reluzir",
    "reluze": "reluzir",
    "reluzem": "reluzir",
    "reluzentes": "reluzente",
    "reluzes": "reluzir",
    "reluzi": "reluzir",
    "reluzia": "reluzir",
    "reluziam": "reluzir",
    "reluzias": "reluzir",
    "reluzida": "reluzir",
    "reluzidas": "reluzir",
    "reluzido": "reluzir",
    "reluzidos": "reluzir",
    "reluzimo": "reluzir",
    "reluzimos": "reluzir",
    "reluzindo": "reluzir",
    "reluzira": "reluzir",
    "reluziram": "reluzir",
    "reluziras": "reluzir",
    "reluzirdes": "reluzir",
    "reluzirei": "reluzir",
    "reluzireis": "reluzir",
    "reluzirem": "reluzir",
    "reluziremos": "reluzir",
    "reluzires": "reluzir",
    "reluziria": "reluzir",
    "reluziriam": "reluzir",
    "reluzirias": "reluzir",
    "reluzirmo": "reluzir",
    "reluzirmos": "reluzir",
    "reluzirá": "reluzir",
    "reluzirás": "reluzir",
    "reluzirão": "reluzir",
    "reluziríamos": "reluzir",
    "reluziríeis": "reluzir",
    "reluzis": "reluzir",
    "reluzisse": "reluzir",
    "reluzissem": "reluzir",
    "reluzisses": "reluzir",
    "reluziste": "reluzir",
    "reluzistes": "reluzir",
    "reluziu": "reluzir",
    "reluzo": "reluzir",
    "reluzíamo": "reluzir",
    "reluzíamos": "reluzir",
    "reluzíeis": "reluzir",
    "reluzíramo": "reluzir",
    "reluzíramos": "reluzir",
    "reluzíreis": "reluzir",
    "reluzísseis": "reluzir",
    "reluzíssemos": "reluzir",
    "relva": "relvar",
    "relvada": "relvar",
    "relvadas": "relvar",
    "relvado": "relvar",
    "relvados": "relvar",
    "relvagens": "relvagem",
    "relvai": "relvar",
    "relvais": "relvar",
    "relvam": "relvar",
    "relvamo": "relvar",
    "relvamos": "relvar",
    "relvando": "relvar",
    "relvara": "relvar",
    "relvaram": "relvar",
    "relvaras": "relvar",
    "relvarde": "relvar",
    "relvardes": "relvar",
    "relvare": "relvar",
    "relvarei": "relvar",
    "relvareis": "relvar",
    "relvarem": "relvar",
    "relvaremos": "relvar",
    "relvares": "relvar",
    "relvaria": "relvar",
    "relvariam": "relvar",
    "relvarias": "relvar",
    "relvarmo": "relvar",
    "relvarmos": "relvar",
    "relvará": "relvar",
    "relvarás": "relvar",
    "relvarão": "relvar",
    "relvaríamos": "relvar",
    "relvaríeis": "relvar",
    "relvas": "relvar",
    "relvasse": "relvar",
    "relvassem": "relvar",
    "relvasses": "relvar",
    "relvaste": "relvar",
    "relvastes": "relvar",
    "relvava": "relvar",
    "relvavam": "relvar",
    "relvavas": "relvar",
    "relve": "relvar",
    "relvedos": "relvedo",
    "relvei": "relvar",
    "relveis": "relvar",
    "relveja": "relvejar",
    "relvejada": "relvejar",
    "relvejadas": "relvejar",
    "relvejado": "relvejar",
    "relvejados": "relvejar",
    "relvejai": "relvejar",
    "relvejais": "relvejar",
    "relvejam": "relvejar",
    "relvejamo": "relvejar",
    "relvejamos": "relvejar",
    "relvejando": "relvejar",
    "relvejara": "relvejar",
    "relvejaram": "relvejar",
    "relvejaras": "relvejar",
    "relvejardes": "relvejar",
    "relvejarei": "relvejar",
    "relvejareis": "relvejar",
    "relvejarem": "relvejar",
    "relvejaremos": "relvejar",
    "relvejares": "relvejar",
    "relvejaria": "relvejar",
    "relvejariam": "relvejar",
    "relvejarias": "relvejar",
    "relvejarmo": "relvejar",
    "relvejarmos": "relvejar",
    "relvejará": "relvejar",
    "relvejarás": "relvejar",
    "relvejarão": "relvejar",
    "relvejaríamos": "relvejar",
    "relvejaríeis": "relvejar",
    "relvejas": "relvejar",
    "relvejasse": "relvejar",
    "relvejassem": "relvejar",
    "relvejasses": "relvejar",
    "relvejaste": "relvejar",
    "relvejastes": "relvejar",
    "relvejava": "relvejar",
    "relvejavam": "relvejar",
    "relvejavas": "relvejar",
    "relveje": "relvejar",
    "relvejei": "relvejar",
    "relvejeis": "relvejar",
    "relvejem": "relvejar",
    "relvejemo": "relvejar",
    "relvejemos": "relvejar",
    "relvejes": "relvejar",
    "relvejo": "relvejar",
    "relvejou": "relvejar",
    "relvejámo": "relvejar",
    "relvejámos": "relvejar",
    "relvejáramo": "relvejar",
    "relvejáramos": "relvejar",
    "relvejáreis": "relvejar",
    "relvejásseis": "relvejar",
    "relvejássemos": "relvejar",
    "relvejávamo": "relvejar",
    "relvejávamos": "relvejar",
    "relvejáveis": "relvejar",
    "relvem": "relvar",
    "relvemo": "relvar",
    "relvemos": "relvar",
    "relves": "relvar",
    "relvinha": "relva",
    "relvinhas": "relva",
    "relvita": "relva",
    "relvitas": "relva",
    "relvo": "relvar",
    "relvosa": "relvoso",
    "relvosas": "relvoso",
    "relvosos": "relvoso",
    "relvou": "relvar",
    "relvá": "relvar",
    "relvámo": "relvar",
    "relvámos": "relvar",
    "relváramo": "relvar",
    "relváramos": "relvar",
    "relvárei": "relvar",
    "relváreis": "relvar",
    "relvásseis": "relvar",
    "relvássemos": "relvar",
    "relvávamo": "relvar",
    "relvávamos": "relvar",
    "relvávei": "relvar",
    "relváveis": "relvar",
    "relá": "relar",
    "relámo": "relar",
    "relámos": "relar",
    "reláramo": "relar",
    "reláramos": "relar",
    "relárei": "relar",
    "reláreis": "relar",
    "relásseis": "relar",
    "relássemos": "relar",
    "relávamo": "relar",
    "relávamos": "relar",
    "relávei": "relar",
    "reláveis": "relar",
    "relâmpados": "relâmpado",
    "relâmpagos": "relâmpago",
    "relés": "relé",
    "relê": "reler",
    "relêem": "reler",
    "relêramo": "reler",
    "relêramos": "reler",
    "relêrei": "reler",
    "relêreis": "reler",
    "relês": "reler",
    "relêsseis": "reler",
    "relêssemos": "reler",
    "relíamo": "reler",
    "relíamos": "reler",
    "relíei": "reler",
    "relíeis": "reler",
    "relíquias": "relíquia",
    "relógios": "relógio",
    "rema": "remir",
    "remada": "remar",
    "remadas": "remar",
    "remadelas": "remadela",
    "remado": "remar",
    "remadora": "remador",
    "remadoras": "remador",
    "remadorazinha": "remador",
    "remadorazinhas": "remador",
    "remadorazita": "remador",
    "remadorazitas": "remador",
    "remadores": "remador",
    "remadorzinho": "remador",
    "remadorzinhos": "remador",
    "remadorzito": "remador",
    "remadorzitos": "remador",
    "remados": "remar",
    "remaduras": "remadura",
    "remagnetiza": "remagnetizar",
    "remagnetizada": "remagnetizar",
    "remagnetizadas": "remagnetizar",
    "remagnetizado": "remagnetizar",
    "remagnetizados": "remagnetizar",
    "remagnetizai": "remagnetizar",
    "remagnetizais": "remagnetizar",
    "remagnetizam": "remagnetizar",
    "remagnetizamo": "remagnetizar",
    "remagnetizamos": "remagnetizar",
    "remagnetizando": "remagnetizar",
    "remagnetizara": "remagnetizar",
    "remagnetizaram": "remagnetizar",
    "remagnetizaras": "remagnetizar",
    "remagnetizarde": "remagnetizar",
    "remagnetizardes": "remagnetizar",
    "remagnetizare": "remagnetizar",
    "remagnetizarei": "remagnetizar",
    "remagnetizareis": "remagnetizar",
    "remagnetizarem": "remagnetizar",
    "remagnetizaremos": "remagnetizar",
    "remagnetizares": "remagnetizar",
    "remagnetizaria": "remagnetizar",
    "remagnetizariam": "remagnetizar",
    "remagnetizarias": "remagnetizar",
    "remagnetizarmo": "remagnetizar",
    "remagnetizarmos": "remagnetizar",
    "remagnetizará": "remagnetizar",
    "remagnetizarás": "remagnetizar",
    "remagnetizarão": "remagnetizar",
    "remagnetizaríamos": "remagnetizar",
    "remagnetizaríeis": "remagnetizar",
    "remagnetizas": "remagnetizar",
    "remagnetizasse": "remagnetizar",
    "remagnetizassem": "remagnetizar",
    "remagnetizasses": "remagnetizar",
    "remagnetizaste": "remagnetizar",
    "remagnetizastes": "remagnetizar",
    "remagnetizava": "remagnetizar",
    "remagnetizavam": "remagnetizar",
    "remagnetizavas": "remagnetizar",
    "remagnetize": "remagnetizar",
    "remagnetizei": "remagnetizar",
    "remagnetizeis": "remagnetizar",
    "remagnetizem": "remagnetizar",
    "remagnetizemo": "remagnetizar",
    "remagnetizemos": "remagnetizar",
    "remagnetizes": "remagnetizar",
    "remagnetizo": "remagnetizar",
    "remagnetizou": "remagnetizar",
    "remagnetizá": "remagnetizar",
    "remagnetizámo": "remagnetizar",
    "remagnetizámos": "remagnetizar",
    "remagnetizáramo": "remagnetizar",
    "remagnetizáramos": "remagnetizar",
    "remagnetizárei": "remagnetizar",
    "remagnetizáreis": "remagnetizar",
    "remagnetizásseis": "remagnetizar",
    "remagnetizássemos": "remagnetizar",
    "remagnetizávamo": "remagnetizar",
    "remagnetizávamos": "remagnetizar",
    "remagnetizávei": "remagnetizar",
    "remagnetizáveis": "remagnetizar",
    "remai": "remar",
    "remais": "remir",
    "remam": "remir",
    "remamo": "remir",
    "remamos": "remir",
    "remancha": "remanchar",
    "remanchada": "remanchar",
    "remanchadas": "remanchar",
    "remanchado": "remanchar",
    "remanchados": "remanchar",
    "remanchai": "remanchar",
    "remanchais": "remanchar",
    "remancham": "remanchar",
    "remanchamo": "remanchar",
    "remanchamos": "remanchar",
    "remanchando": "remanchar",
    "remanchara": "remanchar",
    "remancharam": "remanchar",
    "remancharas": "remanchar",
    "remanchardes": "remanchar",
    "remancharei": "remanchar",
    "remanchareis": "remanchar",
    "remancharem": "remanchar",
    "remancharemos": "remanchar",
    "remanchares": "remanchar",
    "remancharia": "remanchar",
    "remanchariam": "remanchar",
    "remancharias": "remanchar",
    "remancharmo": "remanchar",
    "remancharmos": "remanchar",
    "remanchará": "remanchar",
    "remancharás": "remanchar",
    "remancharão": "remanchar",
    "remancharíamos": "remanchar",
    "remancharíeis": "remanchar",
    "remanchas": "remanchar",
    "remanchasse": "remanchar",
    "remanchassem": "remanchar",
    "remanchasses": "remanchar",
    "remanchaste": "remanchar",
    "remanchastes": "remanchar",
    "remanchava": "remanchar",
    "remanchavam": "remanchar",
    "remanchavas": "remanchar",
    "remanche": "remanchar",
    "remanchei": "remanchar",
    "remancheis": "remanchar",
    "remanchem": "remanchar",
    "remanchemo": "remanchar",
    "remanchemos": "remanchar",
    "remanches": "remanchar",
    "remancho": "remanchar",
    "remanchona": "remanchão",
    "remanchonas": "remanchão",
    "remanchou": "remanchar",
    "remanchámo": "remanchar",
    "remanchámos": "remanchar",
    "remancháramo": "remanchar",
    "remancháramos": "remanchar",
    "remancháreis": "remanchar",
    "remanchásseis": "remanchar",
    "remanchássemos": "remanchar",
    "remanchávamo": "remanchar",
    "remanchávamos": "remanchar",
    "remancháveis": "remanchar",
    "remanchões": "remanchão",
    "remanda": "remandar",
    "remandada": "remandar",
    "remandadas": "remandar",
    "remandado": "remandar",
    "remandados": "remandar",
    "remandai": "remandar",
    "remandais": "remandar",
    "remandam": "remandar",
    "remandamo": "remandar",
    "remandamos": "remandar",
    "remandando": "remandar",
    "remandara": "remandar",
    "remandaram": "remandar",
    "remandaras": "remandar",
    "remandarde": "remandar",
    "remandardes": "remandar",
    "remandare": "remandar",
    "remandarei": "remandar",
    "remandareis": "remandar",
    "remandarem": "remandar",
    "remandaremos": "remandar",
    "remandares": "remandar",
    "remandaria": "remandar",
    "remandariam": "remandar",
    "remandarias": "remandar",
    "remandarmo": "remandar",
    "remandarmos": "remandar",
    "remandará": "remandar",
    "remandarás": "remandar",
    "remandarão": "remandar",
    "remandaríamos": "remandar",
    "remandaríeis": "remandar",
    "remandas": "remandar",
    "remandasse": "remandar",
    "remandassem": "remandar",
    "remandasses": "remandar",
    "remandaste": "remandar",
    "remandastes": "remandar",
    "remandava": "remandar",
    "remandavam": "remandar",
    "remandavas": "remandar",
    "remande": "remandar",
    "remandei": "remandar",
    "remandeis": "remandar",
    "remandem": "remandar",
    "remandemo": "remandar",
    "remandemos": "remandar",
    "remandes": "remandar",
    "remando": "remar",
    "remandou": "remandar",
    "remandá": "remandar",
    "remandámo": "remandar",
    "remandámos": "remandar",
    "remandáramo": "remandar",
    "remandáramos": "remandar",
    "remandárei": "remandar",
    "remandáreis": "remandar",
    "remandásseis": "remandar",
    "remandássemos": "remandar",
    "remandávamo": "remandar",
    "remandávamos": "remandar",
    "remandávei": "remandar",
    "remandáveis": "remandar",
    "remanentes": "remanente",
    "remanesce": "remanescer",
    "remanescei": "remanescer",
    "remanesceis": "remanescer",
    "remanescem": "remanescer",
    "remanescemo": "remanescer",
    "remanescemos": "remanescer",
    "remanescendo": "remanescer",
    "remanescentes": "remanescente",
    "remanescera": "remanescer",
    "remanesceram": "remanescer",
    "remanesceras": "remanescer",
    "remanescerdes": "remanescer",
    "remanescerei": "remanescer",
    "remanescereis": "remanescer",
    "remanescerem": "remanescer",
    "remanesceremos": "remanescer",
    "remanesceres": "remanescer",
    "remanesceria": "remanescer",
    "remanesceriam": "remanescer",
    "remanescerias": "remanescer",
    "remanescermo": "remanescer",
    "remanescermos": "remanescer",
    "remanescerá": "remanescer",
    "remanescerás": "remanescer",
    "remanescerão": "remanescer",
    "remanesceríamos": "remanescer",
    "remanesceríeis": "remanescer",
    "remanesces": "remanescer",
    "remanescesse": "remanescer",
    "remanescessem": "remanescer",
    "remanescesses": "remanescer",
    "remanesceste": "remanescer",
    "remanescestes": "remanescer",
    "remanesceu": "remanescer",
    "remanesci": "remanescer",
    "remanescia": "remanescer",
    "remanesciam": "remanescer",
    "remanescias": "remanescer",
    "remanescida": "remanescer",
    "remanescidas": "remanescer",
    "remanescido": "remanescer",
    "remanescidos": "remanescer",
    "remanescêramo": "remanescer",
    "remanescêramos": "remanescer",
    "remanescêreis": "remanescer",
    "remanescêsseis": "remanescer",
    "remanescêssemos": "remanescer",
    "remanescíamo": "remanescer",
    "remanescíamos": "remanescer",
    "remanescíeis": "remanescer",
    "remanesça": "remanescer",
    "remanesçais": "remanescer",
    "remanesçam": "remanescer",
    "remanesçamo": "remanescer",
    "remanesçamos": "remanescer",
    "remanesças": "remanescer",
    "remanesço": "remanescer",
    "remanga": "remangar",
    "remangada": "remangar",
    "remangadas": "remangar",
    "remangado": "remangar",
    "remangados": "remangar",
    "remangai": "remangar",
    "remangais": "remangar",
    "remangam": "remangar",
    "remangamo": "remangar",
    "remangamos": "remangar",
    "remangando": "remangar",
    "remangara": "remangar",
    "remangaram": "remangar",
    "remangaras": "remangar",
    "remangardes": "remangar",
    "remangarei": "remangar",
    "remangareis": "remangar",
    "remangarem": "remangar",
    "remangaremos": "remangar",
    "remangares": "remangar",
    "remangaria": "remangar",
    "remangariam": "remangar",
    "remangarias": "remangar",
    "remangarmo": "remangar",
    "remangarmos": "remangar",
    "remangará": "remangar",
    "remangarás": "remangar",
    "remangarão": "remangar",
    "remangaríamos": "remangar",
    "remangaríeis": "remangar",
    "remangas": "remangar",
    "remangasse": "remangar",
    "remangassem": "remangar",
    "remangasses": "remangar",
    "remangaste": "remangar",
    "remangastes": "remangar",
    "remangava": "remangar",
    "remangavam": "remangar",
    "remangavas": "remangar",
    "remango": "remangar",
    "remangou": "remangar",
    "remangue": "remangar",
    "remanguei": "remangar",
    "remangueis": "remangar",
    "remanguem": "remangar",
    "remanguemo": "remangar",
    "remanguemos": "remangar",
    "remangues": "remangar",
    "remangámo": "remangar",
    "remangámos": "remangar",
    "remangáramo": "remangar",
    "remangáramos": "remangar",
    "remangáreis": "remangar",
    "remangásseis": "remangar",
    "remangássemos": "remangar",
    "remangávamo": "remangar",
    "remangávamos": "remangar",
    "remangáveis": "remangar",
    "remansa": "remansar",
    "remansada": "remansar",
    "remansadas": "remansar",
    "remansado": "remansar",
    "remansados": "remansar",
    "remansai": "remansar",
    "remansais": "remansar",
    "remansam": "remansar",
    "remansamo": "remansar",
    "remansamos": "remansar",
    "remansando": "remansar",
    "remansara": "remansar",
    "remansaram": "remansar",
    "remansaras": "remansar",
    "remansarde": "remansar",
    "remansardes": "remansar",
    "remansare": "remansar",
    "remansarei": "remansar",
    "remansareis": "remansar",
    "remansarem": "remansar",
    "remansaremos": "remansar",
    "remansares": "remansar",
    "remansaria": "remansar",
    "remansariam": "remansar",
    "remansarias": "remansar",
    "remansarmo": "remansar",
    "remansarmos": "remansar",
    "remansará": "remansar",
    "remansarás": "remansar",
    "remansarão": "remansar",
    "remansaríamos": "remansar",
    "remansaríeis": "remansar",
    "remansas": "remansar",
    "remansasse": "remansar",
    "remansassem": "remansar",
    "remansasses": "remansar",
    "remansaste": "remansar",
    "remansastes": "remansar",
    "remansava": "remansar",
    "remansavam": "remansar",
    "remansavas": "remansar",
    "remanse": "remansar",
    "remanseada": "remansear",
    "remanseadas": "remansear",
    "remanseado": "remansear",
    "remanseados": "remansear",
    "remanseai": "remansear",
    "remanseais": "remansear",
    "remanseamo": "remansear",
    "remanseamos": "remansear",
    "remanseando": "remansear",
    "remanseara": "remansear",
    "remansearam": "remansear",
    "remansearas": "remansear",
    "remanseardes": "remansear",
    "remansearei": "remansear",
    "remanseareis": "remansear",
    "remansearem": "remansear",
    "remansearemos": "remansear",
    "remanseares": "remansear",
    "remansearia": "remansear",
    "remanseariam": "remansear",
    "remansearias": "remansear",
    "remansearmo": "remansear",
    "remansearmos": "remansear",
    "remanseará": "remansear",
    "remansearás": "remansear",
    "remansearão": "remansear",
    "remansearíamos": "remansear",
    "remansearíeis": "remansear",
    "remanseasse": "remansear",
    "remanseassem": "remansear",
    "remanseasses": "remansear",
    "remanseaste": "remansear",
    "remanseastes": "remansear",
    "remanseava": "remansear",
    "remanseavam": "remansear",
    "remanseavas": "remansear",
    "remanseei": "remansear",
    "remanseeis": "remansear",
    "remanseemo": "remansear",
    "remanseemos": "remansear",
    "remansei": "remansar",
    "remanseia": "remansear",
    "remanseiam": "remansear",
    "remanseias": "remansear",
    "remanseie": "remansear",
    "remanseiem": "remansear",
    "remanseies": "remansear",
    "remanseio": "remansear",
    "remanseis": "remansar",
    "remansem": "remansar",
    "remansemo": "remansar",
    "remansemos": "remansar",
    "remanseou": "remansear",
    "remanses": "remansar",
    "remanseámo": "remansear",
    "remanseámos": "remansear",
    "remanseáramo": "remansear",
    "remanseáramos": "remansear",
    "remanseáreis": "remansear",
    "remanseásseis": "remansear",
    "remanseássemos": "remansear",
    "remanseávamo": "remansear",
    "remanseávamos": "remansear",
    "remanseáveis": "remansear",
    "remanso": "remansar",
    "remansos": "remanso",
    "remansosa": "remansoso",
    "remansosas": "remansoso",
    "remansosos": "remansoso",
    "remansou": "remansar",
    "remansá": "remansar",
    "remansámo": "remansar",
    "remansámos": "remansar",
    "remansáramo": "remansar",
    "remansáramos": "remansar",
    "remansárei": "remansar",
    "remansáreis": "remansar",
    "remansásseis": "remansar",
    "remansássemos": "remansar",
    "remansávamo": "remansar",
    "remansávamos": "remansar",
    "remansávei": "remansar",
    "remansáveis": "remansar",
    "remanências": "remanência",
    "remara": "remar",
    "remaram": "remar",
    "remaras": "remar",
    "remarca": "remarcar",
    "remarcada": "remarcar",
    "remarcadas": "remarcar",
    "remarcado": "remarcar",
    "remarcados": "remarcar",
    "remarcai": "remarcar",
    "remarcais": "remarcar",
    "remarcam": "remarcar",
    "remarcamo": "remarcar",
    "remarcamos": "remarcar",
    "remarcando": "remarcar",
    "remarcara": "remarcar",
    "remarcaram": "remarcar",
    "remarcaras": "remarcar",
    "remarcarde": "remarcar",
    "remarcardes": "remarcar",
    "remarcare": "remarcar",
    "remarcarei": "remarcar",
    "remarcareis": "remarcar",
    "remarcarem": "remarcar",
    "remarcaremos": "remarcar",
    "remarcares": "remarcar",
    "remarcaria": "remarcar",
    "remarcariam": "remarcar",
    "remarcarias": "remarcar",
    "remarcarmo": "remarcar",
    "remarcarmos": "remarcar",
    "remarcará": "remarcar",
    "remarcarás": "remarcar",
    "remarcarão": "remarcar",
    "remarcaríamos": "remarcar",
    "remarcaríeis": "remarcar",
    "remarcas": "remarcar",
    "remarcasse": "remarcar",
    "remarcassem": "remarcar",
    "remarcasses": "remarcar",
    "remarcaste": "remarcar",
    "remarcastes": "remarcar",
    "remarcava": "remarcar",
    "remarcavam": "remarcar",
    "remarcavas": "remarcar",
    "remarcações": "remarcação",
    "remarco": "remarcar",
    "remarcou": "remarcar",
    "remarcá": "remarcar",
    "remarcámo": "remarcar",
    "remarcámos": "remarcar",
    "remarcáramo": "remarcar",
    "remarcáramos": "remarcar",
    "remarcárei": "remarcar",
    "remarcáreis": "remarcar",
    "remarcásseis": "remarcar",
    "remarcássemos": "remarcar",
    "remarcávamo": "remarcar",
    "remarcávamos": "remarcar",
    "remarcávei": "remarcar",
    "remarcáveis": "remarcar",
    "remardes": "remar",
    "remarei": "remar",
    "remareis": "remar",
    "remarem": "remar",
    "remaremos": "remar",
    "remares": "remar",
    "remaria": "remar",
    "remariam": "remar",
    "remarias": "remar",
    "remarida": "remaridar",
    "remaridada": "remaridar",
    "remaridadas": "remaridar",
    "remaridado": "remaridar",
    "remaridados": "remaridar",
    "remaridai": "remaridar",
    "remaridais": "remaridar",
    "remaridam": "remaridar",
    "remaridamo": "remaridar",
    "remaridamos": "remaridar",
    "remaridando": "remaridar",
    "remaridara": "remaridar",
    "remaridaram": "remaridar",
    "remaridaras": "remaridar",
    "remaridarde": "remaridar",
    "remaridardes": "remaridar",
    "remaridare": "remaridar",
    "remaridarei": "remaridar",
    "remaridareis": "remaridar",
    "remaridarem": "remaridar",
    "remaridaremos": "remaridar",
    "remaridares": "remaridar",
    "remaridaria": "remaridar",
    "remaridariam": "remaridar",
    "remaridarias": "remaridar",
    "remaridarmo": "remaridar",
    "remaridarmos": "remaridar",
    "remaridará": "remaridar",
    "remaridarás": "remaridar",
    "remaridarão": "remaridar",
    "remaridaríamos": "remaridar",
    "remaridaríeis": "remaridar",
    "remaridas": "remaridar",
    "remaridasse": "remaridar",
    "remaridassem": "remaridar",
    "remaridasses": "remaridar",
    "remaridaste": "remaridar",
    "remaridastes": "remaridar",
    "remaridava": "remaridar",
    "remaridavam": "remaridar",
    "remaridavas": "remaridar",
    "remaride": "remaridar",
    "remaridei": "remaridar",
    "remarideis": "remaridar",
    "remaridem": "remaridar",
    "remaridemo": "remaridar",
    "remaridemos": "remaridar",
    "remarides": "remaridar",
    "remarido": "remaridar",
    "remaridou": "remaridar",
    "remaridá": "remaridar",
    "remaridámo": "remaridar",
    "remaridámos": "remaridar",
    "remaridáramo": "remaridar",
    "remaridáramos": "remaridar",
    "remaridárei": "remaridar",
    "remaridáreis": "remaridar",
    "remaridásseis": "remaridar",
    "remaridássemos": "remaridar",
    "remaridávamo": "remaridar",
    "remaridávamos": "remaridar",
    "remaridávei": "remaridar",
    "remaridáveis": "remaridar",
    "remarmo": "remar",
    "remarmos": "remar",
    "remarque": "remarcar",
    "remarquei": "remarcar",
    "remarqueis": "remarcar",
    "remarquem": "remarcar",
    "remarquemo": "remarcar",
    "remarquemos": "remarcar",
    "remarques": "remarcar",
    "remará": "remar",
    "remarás": "remar",
    "remarão": "remar",
    "remaríamos": "remar",
    "remaríeis": "remar",
    "remas": "remir",
    "remasca": "remascar",
    "remascada": "remascar",
    "remascadas": "remascar",
    "remascado": "remascar",
    "remascados": "remascar",
    "remascai": "remascar",
    "remascais": "remascar",
    "remascam": "remascar",
    "remascamo": "remascar",
    "remascamos": "remascar",
    "remascando": "remascar",
    "remascara": "remascar",
    "remascaram": "remascar",
    "remascaras": "remascar",
    "remascarde": "remascar",
    "remascardes": "remascar",
    "remascare": "remascar",
    "remascarei": "remascar",
    "remascareis": "remascar",
    "remascarem": "remascar",
    "remascaremos": "remascar",
    "remascares": "remascar",
    "remascaria": "remascar",
    "remascariam": "remascar",
    "remascarias": "remascar",
    "remascarmo": "remascar",
    "remascarmos": "remascar",
    "remascará": "remascar",
    "remascarás": "remascar",
    "remascarão": "remascar",
    "remascaríamos": "remascar",
    "remascaríeis": "remascar",
    "remascas": "remascar",
    "remascasse": "remascar",
    "remascassem": "remascar",
    "remascasses": "remascar",
    "remascaste": "remascar",
    "remascastes": "remascar",
    "remascava": "remascar",
    "remascavam": "remascar",
    "remascavas": "remascar",
    "remasco": "remascar",
    "remascou": "remascar",
    "remascá": "remascar",
    "remascámo": "remascar",
    "remascámos": "remascar",
    "remascáramo": "remascar",
    "remascáramos": "remascar",
    "remascárei": "remascar",
    "remascáreis": "remascar",
    "remascásseis": "remascar",
    "remascássemos": "remascar",
    "remascávamo": "remascar",
    "remascávamos": "remascar",
    "remascávei": "remascar",
    "remascáveis": "remascar",
    "remasque": "remascar",
    "remasquei": "remascar",
    "remasqueis": "remascar",
    "remasquem": "remascar",
    "remasquemo": "remascar",
    "remasquemos": "remascar",
    "remasques": "remascar",
    "remasse": "remar",
    "remassem": "remar",
    "remasses": "remasse",
    "remaste": "remar",
    "remastes": "remar",
    "remastiga": "remastigar",
    "remastigada": "remastigar",
    "remastigadas": "remastigar",
    "remastigado": "remastigar",
    "remastigados": "remastigar",
    "remastigai": "remastigar",
    "remastigais": "remastigar",
    "remastigam": "remastigar",
    "remastigamo": "remastigar",
    "remastigamos": "remastigar",
    "remastigando": "remastigar",
    "remastigara": "remastigar",
    "remastigaram": "remastigar",
    "remastigaras": "remastigar",
    "remastigarde": "remastigar",
    "remastigardes": "remastigar",
    "remastigare": "remastigar",
    "remastigarei": "remastigar",
    "remastigareis": "remastigar",
    "remastigarem": "remastigar",
    "remastigaremos": "remastigar",
    "remastigares": "remastigar",
    "remastigaria": "remastigar",
    "remastigariam": "remastigar",
    "remastigarias": "remastigar",
    "remastigarmo": "remastigar",
    "remastigarmos": "remastigar",
    "remastigará": "remastigar",
    "remastigarás": "remastigar",
    "remastigarão": "remastigar",
    "remastigaríamos": "remastigar",
    "remastigaríeis": "remastigar",
    "remastigas": "remastigar",
    "remastigasse": "remastigar",
    "remastigassem": "remastigar",
    "remastigasses": "remastigar",
    "remastigaste": "remastigar",
    "remastigastes": "remastigar",
    "remastigava": "remastigar",
    "remastigavam": "remastigar",
    "remastigavas": "remastigar",
    "remastigações": "remastigação",
    "remastigo": "remastigar",
    "remastigou": "remastigar",
    "remastigue": "remastigar",
    "remastiguei": "remastigar",
    "remastigueis": "remastigar",
    "remastiguem": "remastigar",
    "remastiguemo": "remastigar",
    "remastiguemos": "remastigar",
    "remastigues": "remastigar",
    "remastigá": "remastigar",
    "remastigámo": "remastigar",
    "remastigámos": "remastigar",
    "remastigáramo": "remastigar",
    "remastigáramos": "remastigar",
    "remastigárei": "remastigar",
    "remastigáreis": "remastigar",
    "remastigásseis": "remastigar",
    "remastigássemos": "remastigar",
    "remastigávamo": "remastigar",
    "remastigávamos": "remastigar",
    "remastigávei": "remastigar",
    "remastigáveis": "remastigar",
    "remata": "rematar",
    "rematada": "rematar",
    "rematadas": "rematar",
    "rematado": "rematar",
    "rematadora": "rematador",
    "rematadoras": "rematador",
    "rematadores": "rematador",
    "rematados": "rematar",
    "rematai": "rematar",
    "rematais": "rematar",
    "rematam": "rematar",
    "rematamo": "rematar",
    "rematamos": "rematar",
    "rematando": "rematar",
    "rematara": "rematar",
    "remataram": "rematar",
    "remataras": "rematar",
    "rematarde": "rematar",
    "rematardes": "rematar",
    "rematare": "rematar",
    "rematarei": "rematar",
    "rematareis": "rematar",
    "rematarem": "rematar",
    "remataremos": "rematar",
    "rematares": "rematar",
    "remataria": "rematar",
    "rematariam": "rematar",
    "rematarias": "rematar",
    "rematarmo": "rematar",
    "rematarmos": "rematar",
    "rematará": "rematar",
    "rematarás": "rematar",
    "rematarão": "rematar",
    "remataríamos": "rematar",
    "remataríeis": "rematar",
    "rematas": "rematar",
    "rematasse": "rematar",
    "rematassem": "rematar",
    "rematasses": "rematar",
    "remataste": "rematar",
    "rematastes": "rematar",
    "rematava": "rematar",
    "rematavam": "rematar",
    "rematavas": "rematar",
    "rematações": "rematação",
    "remate": "rematar",
    "rematei": "rematar",
    "remateis": "rematar",
    "rematem": "rematar",
    "rematemo": "rematar",
    "rematemos": "rematar",
    "remates": "remate",
    "remato": "rematar",
    "rematou": "rematar",
    "rematá": "rematar",
    "rematámo": "rematar",
    "rematámos": "rematar",
    "rematáramo": "rematar",
    "rematáramos": "rematar",
    "rematárei": "rematar",
    "rematáreis": "rematar",
    "rematásseis": "rematar",
    "rematássemos": "rematar",
    "rematávamo": "rematar",
    "rematávamos": "rematar",
    "rematávei": "rematar",
    "rematáveis": "rematar",
    "remava": "remar",
    "remavam": "remar",
    "remavas": "remar",
    "rembrandtesca": "rembrandtesco",
    "rembrandtescas": "rembrandtesco",
    "rembrandtescos": "rembrandtesco",
    "reme": "remir",
    "remeda": "remedar",
    "remedada": "remedar",
    "remedadas": "remedar",
    "remedado": "remedar",
    "remedados": "remedar",
    "remedai": "remedar",
    "remedais": "remedar",
    "remedam": "remedar",
    "remedamo": "remedar",
    "remedamos": "remedar",
    "remedando": "remedar",
    "remedara": "remedar",
    "remedaram": "remedar",
    "remedaras": "remedar",
    "remedarde": "remedar",
    "remedardes": "remedar",
    "remedare": "remedar",
    "remedarei": "remedar",
    "remedareis": "remedar",
    "remedarem": "remedar",
    "remedaremos": "remedar",
    "remedares": "remedar",
    "remedaria": "remedar",
    "remedariam": "remedar",
    "remedarias": "remedar",
    "remedarmo": "remedar",
    "remedarmos": "remedar",
    "remedará": "remedar",
    "remedarás": "remedar",
    "remedarão": "remedar",
    "remedaríamos": "remedar",
    "remedaríeis": "remedar",
    "remedas": "remedar",
    "remedasse": "remedar",
    "remedassem": "remedar",
    "remedasses": "remedar",
    "remedaste": "remedar",
    "remedastes": "remedar",
    "remedava": "remedar",
    "remedavam": "remedar",
    "remedavas": "remedar",
    "remede": "remedir",
    "remedei": "remedar",
    "remedeia": "remediar",
    "remedeiam": "remediar",
    "remedeias": "remediar",
    "remedeie": "remediar",
    "remedeiem": "remediar",
    "remedeies": "remediar",
    "remedeio": "remediar",
    "remedeios": "remedeio",
    "remedeis": "remedar",
    "remedem": "remedir",
    "remedemo": "remedar",
    "remedemos": "remedar",
    "remedes": "remedir",
    "remedi": "remedir",
    "remedia": "remedir",
    "remediada": "remediar",
    "remediadas": "remediar",
    "remediado": "remediar",
    "remediadora": "remediador",
    "remediadoras": "remediador",
    "remediadores": "remediador",
    "remediados": "remediar",
    "remediai": "remediar",
    "remediais": "remediar",
    "remediam": "remedir",
    "remediamo": "remediar",
    "remediamos": "remediar",
    "remediando": "remediar",
    "remediara": "remediar",
    "remediaram": "remediar",
    "remediaras": "remediar",
    "remediarde": "remediar",
    "remediardes": "remediar",
    "remediare": "remediar",
    "remediarei": "remediar",
    "remediareis": "remediar",
    "remediarem": "remediar",
    "remediaremos": "remediar",
    "remediares": "remediar",
    "remediaria": "remediar",
    "remediariam": "remediar",
    "remediarias": "remediar",
    "remediarmo": "remediar",
    "remediarmos": "remediar",
    "remediará": "remediar",
    "remediarás": "remediar",
    "remediarão": "remediar",
    "remediaríamos": "remediar",
    "remediaríeis": "remediar",
    "remedias": "remedir",
    "remediasse": "remediar",
    "remediassem": "remediar",
    "remediasses": "remediar",
    "remediaste": "remediar",
    "remediastes": "remediar",
    "remediava": "remediar",
    "remediavam": "remediar",
    "remediavas": "remediar",
    "remedida": "remedir",
    "remedidas": "remedir",
    "remedido": "remedir",
    "remedidos": "remedir",
    "remediei": "remediar",
    "remedieis": "remediar",
    "remediemo": "remediar",
    "remediemos": "remediar",
    "remedimo": "remedir",
    "remedimos": "remedir",
    "remedindo": "remedir",
    "remediou": "remediar",
    "remedira": "remedir",
    "remediram": "remedir",
    "remediras": "remedir",
    "remedirde": "remedir",
    "remedirdes": "remedir",
    "remedire": "remedir",
    "remedirei": "remedir",
    "remedireis": "remedir",
    "remedirem": "remedir",
    "remediremos": "remedir",
    "remedires": "remedir",
    "remediria": "remedir",
    "remediriam": "remedir",
    "remedirias": "remedir",
    "remedirmo": "remedir",
    "remedirmos": "remedir",
    "remedirá": "remedir",
    "remedirás": "remedir",
    "remedirão": "remedir",
    "remediríamos": "remedir",
    "remediríeis": "remedir",
    "remedis": "remedir",
    "remedisse": "remedir",
    "remedissem": "remedir",
    "remedisses": "remedir",
    "remediste": "remedir",
    "remedistes": "remedir",
    "remediu": "remedir",
    "remediá": "remediar",
    "remediámo": "remediar",
    "remediámos": "remediar",
    "remediáramo": "remediar",
    "remediáramos": "remediar",
    "remediárei": "remediar",
    "remediáreis": "remediar",
    "remediásseis": "remediar",
    "remediássemos": "remediar",
    "remediávamo": "remediar",
    "remediávamos": "remediar",
    "remediávei": "remediar",
    "remediáveis": "remediável",
    "remedições": "remedição",
    "remedo": "remedar",
    "remedos": "remedo",
    "remedou": "remedar",
    "remedá": "remedar",
    "remedámo": "remedar",
    "remedámos": "remedar",
    "remedáramo": "remedar",
    "remedáramos": "remedar",
    "remedárei": "remedar",
    "remedáreis": "remedar",
    "remedásseis": "remedar",
    "remedássemos": "remedar",
    "remedávamo": "remedar",
    "remedávamos": "remedar",
    "remedávei": "remedar",
    "remedáveis": "remedar",
    "remedíamo": "remedir",
    "remedíamos": "remedir",
    "remedíei": "remedir",
    "remedíeis": "remedir",
    "remedíramo": "remedir",
    "remedíramos": "remedir",
    "remedírei": "remedir",
    "remedíreis": "remedir",
    "remedísseis": "remedir",
    "remedíssemos": "remedir",
    "remei": "remar",
    "remeias": "remeia",
    "remeira": "remeiro",
    "remeiras": "remeiro",
    "remeiros": "remeiro",
    "remeis": "remel",
    "remela": "remelar",
    "remelada": "remelar",
    "remeladas": "remelar",
    "remelado": "remelar",
    "remelados": "remelar",
    "remelai": "remelar",
    "remelais": "remelar",
    "remelam": "remelar",
    "remelamo": "remelar",
    "remelamos": "remelar",
    "remelando": "remelar",
    "remelara": "remelar",
    "remelaram": "remelar",
    "remelaras": "remelar",
    "remelardes": "remelar",
    "remelarei": "remelar",
    "remelareis": "remelar",
    "remelarem": "remelar",
    "remelaremos": "remelar",
    "remelares": "remelar",
    "remelaria": "remelar",
    "remelariam": "remelar",
    "remelarias": "remelar",
    "remelarmo": "remelar",
    "remelarmos": "remelar",
    "remelará": "remelar",
    "remelarás": "remelar",
    "remelarão": "remelar",
    "remelaríamos": "remelar",
    "remelaríeis": "remelar",
    "remelas": "remelar",
    "remelasse": "remelar",
    "remelassem": "remelar",
    "remelasses": "remelar",
    "remelaste": "remelar",
    "remelastes": "remelar",
    "remelava": "remelar",
    "remelavam": "remelar",
    "remelavas": "remelar",
    "remele": "remelar",
    "remelei": "remelar",
    "remeleira": "remeleiro",
    "remeleiras": "remeleiro",
    "remeleiros": "remeleiro",
    "remeleis": "remelar",
    "remeleixa": "remeleixo",
    "remeleixas": "remeleixo",
    "remeleixos": "remeleixo",
    "remelem": "remelar",
    "remelemo": "remelar",
    "remelemos": "remelar",
    "remelenta": "remelento",
    "remelentas": "remelento",
    "remelentos": "remelento",
    "remeles": "remelar",
    "remelgada": "remelgado",
    "remelgadas": "remelgado",
    "remelgados": "remelgado",
    "remelgas": "remelga",
    "remelgueira": "remelgueiro",
    "remelgueiras": "remelgueiro",
    "remelgueiros": "remelgueiro",
    "remelhores": "remelhor",
    "remelo": "remelar",
    "remelona": "remelão",
    "remelonas": "remelão",
    "remelosa": "remeloso",
    "remelosas": "remeloso",
    "remelosos": "remeloso",
    "remelou": "remelar",
    "remelámo": "remelar",
    "remelámos": "remelar",
    "remeláramo": "remelar",
    "remeláramos": "remelar",
    "remeláreis": "remelar",
    "remelásseis": "remelar",
    "remelássemos": "remelar",
    "remelávamo": "remelar",
    "remelávamos": "remelar",
    "remeláveis": "remelar",
    "remelões": "remelão",
    "remem": "remir",
    "remembramentos": "remembramento",
    "remembranças": "remembrança",
    "rememo": "remar",
    "rememora": "rememorar",
    "rememorada": "rememorar",
    "rememoradas": "rememorar",
    "rememorado": "rememorar",
    "rememoradora": "rememorador",
    "rememoradoras": "rememorador",
    "rememoradores": "rememorador",
    "rememorados": "rememorar",
    "rememorai": "rememorar",
    "rememorais": "rememorar",
    "rememoram": "rememorar",
    "rememoramo": "rememorar",
    "rememoramos": "rememorar",
    "rememorando": "rememorar",
    "rememorara": "rememorar",
    "rememoraram": "rememorar",
    "rememoraras": "rememorar",
    "rememorarde": "rememorar",
    "rememorardes": "rememorar",
    "rememorare": "rememorar",
    "rememorarei": "rememorar",
    "rememorareis": "rememorar",
    "rememorarem": "rememorar",
    "rememoraremos": "rememorar",
    "rememorares": "rememorar",
    "rememoraria": "rememorar",
    "rememorariam": "rememorar",
    "rememorarias": "rememorar",
    "rememorarmo": "rememorar",
    "rememorarmos": "rememorar",
    "rememorará": "rememorar",
    "rememorarás": "rememorar",
    "rememorarão": "rememorar",
    "rememoraríamos": "rememorar",
    "rememoraríeis": "rememorar",
    "rememoras": "rememorar",
    "rememorasse": "rememorar",
    "rememorassem": "rememorar",
    "rememorasses": "rememorar",
    "rememoraste": "rememorar",
    "rememorastes": "rememorar",
    "rememorativa": "rememorativo",
    "rememorativas": "rememorativo",
    "rememorativos": "rememorativo",
    "rememorava": "rememorar",
    "rememoravam": "rememorar",
    "rememoravas": "rememorar",
    "rememorações": "rememoração",
    "rememore": "rememorar",
    "rememorei": "rememorar",
    "rememoreis": "rememorar",
    "rememorem": "rememorar",
    "rememoremo": "rememorar",
    "rememoremos": "rememorar",
    "rememores": "rememorar",
    "rememorizações": "rememorização",
    "rememoro": "rememorar",
    "rememorou": "rememorar",
    "rememorá": "rememorar",
    "rememorámo": "rememorar",
    "rememorámos": "rememorar",
    "rememoráramo": "rememorar",
    "rememoráramos": "rememorar",
    "rememorárei": "rememorar",
    "rememoráreis": "rememorar",
    "rememorásseis": "rememorar",
    "rememorássemos": "rememorar",
    "rememorávamo": "rememorar",
    "rememorávamos": "rememorar",
    "rememorávei": "rememorar",
    "rememoráveis": "rememorável",
    "rememos": "remar",
    "remenda": "remendar",
    "remendada": "remendar",
    "remendadas": "remendar",
    "remendadazinha": "remendado",
    "remendadazinhas": "remendado",
    "remendadazita": "remendado",
    "remendadazitas": "remendado",
    "remendadinha": "remendado",
    "remendadinhas": "remendado",
    "remendadinho": "remendado",
    "remendadinhos": "remendado",
    "remendadita": "remendado",
    "remendaditas": "remendado",
    "remendadito": "remendado",
    "remendaditos": "remendado",
    "remendado": "remendar",
    "remendados": "remendar",
    "remendadozinho": "remendado",
    "remendadozinhos": "remendado",
    "remendadozito": "remendado",
    "remendadozitos": "remendado",
    "remendadíssima": "remendado",
    "remendadíssimas": "remendado",
    "remendadíssimo": "remendado",
    "remendadíssimos": "remendado",
    "remendagens": "remendagem",
    "remendai": "remendar",
    "remendais": "remendar",
    "remendam": "remendar",
    "remendamo": "remendar",
    "remendamos": "remendar",
    "remendando": "remendar",
    "remendara": "remendar",
    "remendaram": "remendar",
    "remendaras": "remendar",
    "remendarde": "remendar",
    "remendardes": "remendar",
    "remendare": "remendar",
    "remendarei": "remendar",
    "remendareis": "remendar",
    "remendarem": "remendar",
    "remendaremos": "remendar",
    "remendares": "remendar",
    "remendaria": "remendar",
    "remendariam": "remendar",
    "remendarias": "remendar",
    "remendarmo": "remendar",
    "remendarmos": "remendar",
    "remendará": "remendar",
    "remendarás": "remendar",
    "remendarão": "remendar",
    "remendaríamos": "remendar",
    "remendaríeis": "remendar",
    "remendas": "remendar",
    "remendasse": "remendar",
    "remendassem": "remendar",
    "remendasses": "remendar",
    "remendaste": "remendar",
    "remendastes": "remendar",
    "remendava": "remendar",
    "remendavam": "remendar",
    "remendavas": "remendar",
    "remende": "remendar",
    "remendei": "remendar",
    "remendeira": "remendeiro",
    "remendeiras": "remendeiro",
    "remendeiros": "remendeiro",
    "remendeis": "remendar",
    "remendem": "remendar",
    "remendemo": "remendar",
    "remendemos": "remendar",
    "remendes": "remendar",
    "remendo": "remendar",
    "remendona": "remendão",
    "remendonas": "remendão",
    "remendos": "remendo",
    "remendou": "remendar",
    "remendá": "remendar",
    "remendámo": "remendar",
    "remendámos": "remendar",
    "remendáramo": "remendar",
    "remendáramos": "remendar",
    "remendárei": "remendar",
    "remendáreis": "remendar",
    "remendásseis": "remendar",
    "remendássemos": "remendar",
    "remendávamo": "remendar",
    "remendávamos": "remendar",
    "remendávei": "remendar",
    "remendáveis": "remendar",
    "remendões": "remendão",
    "remeneios": "remeneio",
    "remenica": "remenicar",
    "remenicada": "remenicar",
    "remenicadas": "remenicar",
    "remenicado": "remenicar",
    "remenicados": "remenicar",
    "remenicais": "remenicar",
    "remenicam": "remenicar",
    "remenicamo": "remenicar",
    "remenicamos": "remenicar",
    "remenicando": "remenicar",
    "remenicara": "remenicar",
    "remenicaram": "remenicar",
    "remenicaras": "remenicar",
    "remenicardes": "remenicar",
    "remenicarei": "remenicar",
    "remenicareis": "remenicar",
    "remenicarem": "remenicar",
    "remenicaremos": "remenicar",
    "remenicares": "remenicar",
    "remenicaria": "remenicar",
    "remenicariam": "remenicar",
    "remenicarias": "remenicar",
    "remenicarmo": "remenicar",
    "remenicarmos": "remenicar",
    "remenicará": "remenicar",
    "remenicarás": "remenicar",
    "remenicarão": "remenicar",
    "remenicaríamos": "remenicar",
    "remenicaríeis": "remenicar",
    "remenicas": "remenicar",
    "remenicasse": "remenicar",
    "remenicassem": "remenicar",
    "remenicasses": "remenicar",
    "remenicaste": "remenicar",
    "remenicastes": "remenicar",
    "remenicava": "remenicar",
    "remenicavam": "remenicar",
    "remenicavas": "remenicar",
    "remenico": "remenicar",
    "remenicou": "remenicar",
    "remenicámo": "remenicar",
    "remenicámos": "remenicar",
    "remenicáramo": "remenicar",
    "remenicáramos": "remenicar",
    "remenicáreis": "remenicar",
    "remenicásseis": "remenicar",
    "remenicássemos": "remenicar",
    "remenicávamo": "remenicar",
    "remenicávamos": "remenicar",
    "remenicáveis": "remenicar",
    "remenique": "remenicar",
    "remeniquei": "remenicar",
    "remeniqueis": "remenicar",
    "remeniquem": "remenicar",
    "remeniquemos": "remenicar",
    "remeniques": "remenicar",
    "remerece": "remerecer",
    "remerecedora": "remerecedor",
    "remerecedoras": "remerecedor",
    "remerecedores": "remerecedor",
    "remerecei": "remerecer",
    "remereceis": "remerecer",
    "remerecem": "remerecer",
    "remerecemo": "remerecer",
    "remerecemos": "remerecer",
    "remerecendo": "remerecer",
    "remerecera": "remerecer",
    "remereceram": "remerecer",
    "remereceras": "remerecer",
    "remerecerde": "remerecer",
    "remerecerdes": "remerecer",
    "remerecere": "remerecer",
    "remerecerei": "remerecer",
    "remerecereis": "remerecer",
    "remerecerem": "remerecer",
    "remereceremos": "remerecer",
    "remereceres": "remerecer",
    "remereceria": "remerecer",
    "remereceriam": "remerecer",
    "remerecerias": "remerecer",
    "remerecermo": "remerecer",
    "remerecermos": "remerecer",
    "remerecerá": "remerecer",
    "remerecerás": "remerecer",
    "remerecerão": "remerecer",
    "remereceríamos": "remerecer",
    "remereceríeis": "remerecer",
    "remereces": "remerecer",
    "remerecesse": "remerecer",
    "remerecessem": "remerecer",
    "remerecesses": "remerecer",
    "remereceste": "remerecer",
    "remerecestes": "remerecer",
    "remereceu": "remerecer",
    "remereci": "remerecer",
    "remerecia": "remerecer",
    "remereciam": "remerecer",
    "remerecias": "remerecer",
    "remerecida": "remerecer",
    "remerecidas": "remerecer",
    "remerecido": "remerecer",
    "remerecidos": "remerecer",
    "remerecê": "remerecer",
    "remerecêramo": "remerecer",
    "remerecêramos": "remerecer",
    "remerecêrei": "remerecer",
    "remerecêreis": "remerecer",
    "remerecêsseis": "remerecer",
    "remerecêssemos": "remerecer",
    "remerecíamo": "remerecer",
    "remerecíamos": "remerecer",
    "remerecíei": "remerecer",
    "remerecíeis": "remerecer",
    "remereça": "remerecer",
    "remereçais": "remerecer",
    "remereçam": "remerecer",
    "remereçamo": "remerecer",
    "remereçamos": "remerecer",
    "remereças": "remerecer",
    "remereço": "remerecer",
    "remergulha": "remergulhar",
    "remergulhada": "remergulhar",
    "remergulhadas": "remergulhar",
    "remergulhado": "remergulhar",
    "remergulhados": "remergulhar",
    "remergulhai": "remergulhar",
    "remergulhais": "remergulhar",
    "remergulham": "remergulhar",
    "remergulhamo": "remergulhar",
    "remergulhamos": "remergulhar",
    "remergulhando": "remergulhar",
    "remergulhara": "remergulhar",
    "remergulharam": "remergulhar",
    "remergulharas": "remergulhar",
    "remergulharde": "remergulhar",
    "remergulhardes": "remergulhar",
    "remergulhare": "remergulhar",
    "remergulharei": "remergulhar",
    "remergulhareis": "remergulhar",
    "remergulharem": "remergulhar",
    "remergulharemos": "remergulhar",
    "remergulhares": "remergulhar",
    "remergulharia": "remergulhar",
    "remergulhariam": "remergulhar",
    "remergulharias": "remergulhar",
    "remergulharmo": "remergulhar",
    "remergulharmos": "remergulhar",
    "remergulhará": "remergulhar",
    "remergulharás": "remergulhar",
    "remergulharão": "remergulhar",
    "remergulharíamos": "remergulhar",
    "remergulharíeis": "remergulhar",
    "remergulhas": "remergulhar",
    "remergulhasse": "remergulhar",
    "remergulhassem": "remergulhar",
    "remergulhasses": "remergulhar",
    "remergulhaste": "remergulhar",
    "remergulhastes": "remergulhar",
    "remergulhava": "remergulhar",
    "remergulhavam": "remergulhar",
    "remergulhavas": "remergulhar",
    "remergulhe": "remergulhar",
    "remergulhei": "remergulhar",
    "remergulheis": "remergulhar",
    "remergulhem": "remergulhar",
    "remergulhemo": "remergulhar",
    "remergulhemos": "remergulhar",
    "remergulhes": "remergulhar",
    "remergulho": "remergulhar",
    "remergulhou": "remergulhar",
    "remergulhá": "remergulhar",
    "remergulhámo": "remergulhar",
    "remergulhámos": "remergulhar",
    "remergulháramo": "remergulhar",
    "remergulháramos": "remergulhar",
    "remergulhárei": "remergulhar",
    "remergulháreis": "remergulhar",
    "remergulhásseis": "remergulhar",
    "remergulhássemos": "remergulhar",
    "remergulhávamo": "remergulhar",
    "remergulhávamos": "remergulhar",
    "remergulhávei": "remergulhar",
    "remergulháveis": "remergulhar",
    "remes": "remir",
    "remessa": "remessar",
    "remessada": "remessar",
    "remessadas": "remessar",
    "remessado": "remessar",
    "remessados": "remessar",
    "remessai": "remessar",
    "remessais": "remessar",
    "remessam": "remessar",
    "remessamo": "remessar",
    "remessamos": "remessar",
    "remessando": "remessar",
    "remessara": "remessar",
    "remessaram": "remessar",
    "remessaras": "remessar",
    "remessarde": "remessar",
    "remessardes": "remessar",
    "remessare": "remessar",
    "remessarei": "remessar",
    "remessareis": "remessar",
    "remessarem": "remessar",
    "remessaremos": "remessar",
    "remessares": "remessar",
    "remessaria": "remessar",
    "remessariam": "remessar",
    "remessarias": "remessar",
    "remessarmo": "remessar",
    "remessarmos": "remessar",
    "remessará": "remessar",
    "remessarás": "remessar",
    "remessarão": "remessar",
    "remessaríamos": "remessar",
    "remessaríeis": "remessar",
    "remessas": "remessar",
    "remessasse": "remessar",
    "remessassem": "remessar",
    "remessasses": "remessar",
    "remessaste": "remessar",
    "remessastes": "remessar",
    "remessava": "remessar",
    "remessavam": "remessar",
    "remessavas": "remessar",
    "remesse": "remessar",
    "remessei": "remessar",
    "remesseis": "remessar",
    "remessem": "remessar",
    "remessemo": "remessar",
    "remessemos": "remessar",
    "remesses": "remessar",
    "remesso": "remessar",
    "remessos": "remesso",
    "remessou": "remessar",
    "remessá": "remessar",
    "remessámo": "remessar",
    "remessámos": "remessar",
    "remessáramo": "remessar",
    "remessáramos": "remessar",
    "remessárei": "remessar",
    "remessáreis": "remessar",
    "remessásseis": "remessar",
    "remessássemos": "remessar",
    "remessávamo": "remessar",
    "remessávamos": "remessar",
    "remessávei": "remessar",
    "remessáveis": "remessar",
    "remessões": "remessão",
    "remeta": "remeter",
    "remetais": "remeter",
    "remetam": "remeter",
    "remetamo": "remeter",
    "remetamos": "remeter",
    "remetas": "remeter",
    "remete": "remeter",
    "remeteduras": "remetedura",
    "remetei": "remeter",
    "remeteis": "remeter",
    "remetem": "remeter",
    "remetemo": "remeter",
    "remetemos": "remeter",
    "remetendo": "remeter",
    "remetentes": "remetente",
    "remetera": "remeter",
    "remeteram": "remeter",
    "remeteras": "remeter",
    "remeterde": "remeter",
    "remeterdes": "remeter",
    "remetere": "remeter",
    "remeterei": "remeter",
    "remetereis": "remeter",
    "remeterem": "remeter",
    "remeteremos": "remeter",
    "remeteres": "remeter",
    "remeteria": "remeter",
    "remeteriam": "remeter",
    "remeterias": "remeter",
    "remetermo": "remeter",
    "remetermos": "remeter",
    "remeterá": "remeter",
    "remeterás": "remeter",
    "remeterão": "remeter",
    "remeteríamos": "remeter",
    "remeteríeis": "remeter",
    "remetes": "remeter",
    "remetesse": "remeter",
    "remetessem": "remeter",
    "remetesses": "remeter",
    "remeteste": "remeter",
    "remetestes": "remeter",
    "remeteu": "remeter",
    "remeti": "remeter",
    "remetia": "remeter",
    "remetiam": "remeter",
    "remetias": "remeter",
    "remetida": "remetido",
    "remetidas": "remetido",
    "remetido": "remeter",
    "remetidos": "remetido",
    "remetimentos": "remetimento",
    "remeto": "remeter",
    "remetê": "remeter",
    "remetêramo": "remeter",
    "remetêramos": "remeter",
    "remetêrei": "remeter",
    "remetêreis": "remeter",
    "remetêsseis": "remeter",
    "remetêssemos": "remeter",
    "remetíamo": "remeter",
    "remetíamos": "remeter",
    "remetíei": "remeter",
    "remetíeis": "remeter",
    "remexa": "remexer",
    "remexais": "remexer",
    "remexam": "remexer",
    "remexamo": "remexer",
    "remexamos": "remexer",
    "remexas": "remexer",
    "remexe": "remexer",
    "remexei": "remexer",
    "remexeis": "remexer",
    "remexem": "remexer",
    "remexemo": "remexer",
    "remexemos": "remexer",
    "remexendo": "remexer",
    "remexera": "remexer",
    "remexeram": "remexer",
    "remexeras": "remexer",
    "remexerde": "remexer",
    "remexerdes": "remexer",
    "remexere": "remexer",
    "remexerei": "remexer",
    "remexereis": "remexer",
    "remexerem": "remexer",
    "remexeremos": "remexer",
    "remexeres": "remexer",
    "remexeria": "remexer",
    "remexeriam": "remexer",
    "remexerias": "remexer",
    "remexermo": "remexer",
    "remexermos": "remexer",
    "remexerá": "remexer",
    "remexerás": "remexer",
    "remexerão": "remexer",
    "remexeríamos": "remexer",
    "remexeríeis": "remexer",
    "remexes": "remexer",
    "remexesse": "remexer",
    "remexessem": "remexer",
    "remexesses": "remexer",
    "remexeste": "remexer",
    "remexestes": "remexer",
    "remexeu": "remexer",
    "remexi": "remexer",
    "remexia": "remexer",
    "remexiam": "remexer",
    "remexias": "remexer",
    "remexida": "remexido",
    "remexidas": "remexido",
    "remexidazinha": "remexido",
    "remexidazinhas": "remexido",
    "remexidazita": "remexido",
    "remexidazitas": "remexido",
    "remexidinha": "remexido",
    "remexidinhas": "remexido",
    "remexidinho": "remexido",
    "remexidinhos": "remexido",
    "remexidita": "remexido",
    "remexiditas": "remexido",
    "remexidito": "remexido",
    "remexiditos": "remexido",
    "remexido": "remexer",
    "remexidos": "remexido",
    "remexidozinho": "remexido",
    "remexidozinhos": "remexido",
    "remexidozito": "remexido",
    "remexidozitos": "remexido",
    "remexidíssima": "remexido",
    "remexidíssimas": "remexido",
    "remexidíssimo": "remexido",
    "remexidíssimos": "remexido",
    "remeximentos": "remeximento",
    "remexo": "remexer",
    "remexona": "remexão",
    "remexonas": "remexão",
    "remexê": "remexer",
    "remexêramo": "remexer",
    "remexêramos": "remexer",
    "remexêrei": "remexer",
    "remexêreis": "remexer",
    "remexêsseis": "remexer",
    "remexêssemos": "remexer",
    "remexíamo": "remexer",
    "remexíamos": "remexer",
    "remexíei": "remexer",
    "remexíeis": "remexer",
    "remexões": "remexão",
    "remeça": "remedir",
    "remeçais": "remedir",
    "remeçam": "remedir",
    "remeçamo": "remedir",
    "remeçamos": "remedir",
    "remeças": "remedir",
    "remeço": "remedir",
    "remeções": "remeção",
    "remi": "remir",
    "remia": "remir",
    "remiam": "remir",
    "remias": "remir",
    "remida": "remir",
    "remidas": "remir",
    "remido": "remir",
    "remidora": "remidor",
    "remidoras": "remidor",
    "remidores": "remidor",
    "remidos": "remir",
    "remiformes": "remiforme",
    "remigra": "remigrar",
    "remigrada": "remigrar",
    "remigradas": "remigrar",
    "remigrado": "remigrar",
    "remigrados": "remigrar",
    "remigrai": "remigrar",
    "remigrais": "remigrar",
    "remigram": "remigrar",
    "remigramo": "remigrar",
    "remigramos": "remigrar",
    "remigrando": "remigrar",
    "remigrara": "remigrar",
    "remigraram": "remigrar",
    "remigraras": "remigrar",
    "remigrarde": "remigrar",
    "remigrardes": "remigrar",
    "remigrare": "remigrar",
    "remigrarei": "remigrar",
    "remigrareis": "remigrar",
    "remigrarem": "remigrar",
    "remigraremos": "remigrar",
    "remigrares": "remigrar",
    "remigraria": "remigrar",
    "remigrariam": "remigrar",
    "remigrarias": "remigrar",
    "remigrarmo": "remigrar",
    "remigrarmos": "remigrar",
    "remigrará": "remigrar",
    "remigrarás": "remigrar",
    "remigrarão": "remigrar",
    "remigraríamos": "remigrar",
    "remigraríeis": "remigrar",
    "remigras": "remigrar",
    "remigrasse": "remigrar",
    "remigrassem": "remigrar",
    "remigrasses": "remigrar",
    "remigraste": "remigrar",
    "remigrastes": "remigrar",
    "remigrava": "remigrar",
    "remigravam": "remigrar",
    "remigravas": "remigrar",
    "remigrações": "remigração",
    "remigre": "remigrar",
    "remigrei": "remigrar",
    "remigreis": "remigrar",
    "remigrem": "remigrar",
    "remigremo": "remigrar",
    "remigremos": "remigrar",
    "remigres": "remigrar",
    "remigro": "remigrar",
    "remigrou": "remigrar",
    "remigrá": "remigrar",
    "remigrámo": "remigrar",
    "remigrámos": "remigrar",
    "remigráramo": "remigrar",
    "remigráramos": "remigrar",
    "remigrárei": "remigrar",
    "remigráreis": "remigrar",
    "remigrásseis": "remigrar",
    "remigrássemos": "remigrar",
    "remigrávamo": "remigrar",
    "remigrávamos": "remigrar",
    "remigrávei": "remigrar",
    "remigráveis": "remigrar",
    "remimo": "remir",
    "remimos": "remir",
    "remina": "reminar",
    "reminada": "reminar",
    "reminadas": "reminar",
    "reminado": "reminar",
    "reminados": "reminar",
    "reminai": "reminar",
    "reminais": "reminar",
    "reminam": "reminar",
    "reminamo": "reminar",
    "reminamos": "reminar",
    "reminando": "reminar",
    "reminara": "reminar",
    "reminaram": "reminar",
    "reminaras": "reminar",
    "reminarde": "reminar",
    "reminardes": "reminar",
    "reminare": "reminar",
    "reminarei": "reminar",
    "reminareis": "reminar",
    "reminarem": "reminar",
    "reminaremos": "reminar",
    "reminares": "reminar",
    "reminaria": "reminar",
    "reminariam": "reminar",
    "reminarias": "reminar",
    "reminarmo": "reminar",
    "reminarmos": "reminar",
    "reminará": "reminar",
    "reminarás": "reminar",
    "reminarão": "reminar",
    "reminaríamos": "reminar",
    "reminaríeis": "reminar",
    "reminas": "reminar",
    "reminasse": "reminar",
    "reminassem": "reminar",
    "reminasses": "reminar",
    "reminaste": "reminar",
    "reminastes": "reminar",
    "reminava": "reminar",
    "reminavam": "reminar",
    "reminavas": "reminar",
    "remindo": "remir",
    "remine": "reminar",
    "reminei": "reminar",
    "remineis": "reminar",
    "reminem": "reminar",
    "reminemo": "reminar",
    "reminemos": "reminar",
    "remineraliza": "remineralizar",
    "remineralizada": "remineralizar",
    "remineralizadas": "remineralizar",
    "remineralizado": "remineralizar",
    "remineralizados": "remineralizar",
    "remineralizai": "remineralizar",
    "remineralizais": "remineralizar",
    "remineralizam": "remineralizar",
    "remineralizamo": "remineralizar",
    "remineralizamos": "remineralizar",
    "remineralizando": "remineralizar",
    "remineralizara": "remineralizar",
    "remineralizaram": "remineralizar",
    "remineralizaras": "remineralizar",
    "remineralizarde": "remineralizar",
    "remineralizardes": "remineralizar",
    "remineralizare": "remineralizar",
    "remineralizarei": "remineralizar",
    "remineralizareis": "remineralizar",
    "remineralizarem": "remineralizar",
    "remineralizaremos": "remineralizar",
    "remineralizares": "remineralizar",
    "remineralizaria": "remineralizar",
    "remineralizariam": "remineralizar",
    "remineralizarias": "remineralizar",
    "remineralizarmo": "remineralizar",
    "remineralizarmos": "remineralizar",
    "remineralizará": "remineralizar",
    "remineralizarás": "remineralizar",
    "remineralizarão": "remineralizar",
    "remineralizaríamos": "remineralizar",
    "remineralizaríeis": "remineralizar",
    "remineralizas": "remineralizar",
    "remineralizasse": "remineralizar",
    "remineralizassem": "remineralizar",
    "remineralizasses": "remineralizar",
    "remineralizaste": "remineralizar",
    "remineralizastes": "remineralizar",
    "remineralizava": "remineralizar",
    "remineralizavam": "remineralizar",
    "remineralizavas": "remineralizar",
    "remineralizações": "remineralização",
    "remineralize": "remineralizar",
    "remineralizei": "remineralizar",
    "remineralizeis": "remineralizar",
    "remineralizem": "remineralizar",
    "remineralizemo": "remineralizar",
    "remineralizemos": "remineralizar",
    "remineralizes": "remineralizar",
    "remineralizo": "remineralizar",
    "remineralizou": "remineralizar",
    "remineralizá": "remineralizar",
    "remineralizámo": "remineralizar",
    "remineralizámos": "remineralizar",
    "remineralizáramo": "remineralizar",
    "remineralizáramos": "remineralizar",
    "remineralizárei": "remineralizar",
    "remineralizáreis": "remineralizar",
    "remineralizásseis": "remineralizar",
    "remineralizássemos": "remineralizar",
    "remineralizávamo": "remineralizar",
    "remineralizávamos": "remineralizar",
    "remineralizávei": "remineralizar",
    "remineralizáveis": "remineralizar",
    "remines": "reminar",
    "reminiscentes": "reminiscente",
    "reminiscências": "reminiscência",
    "remino": "reminar",
    "reminou": "reminar",
    "reminá": "reminar",
    "reminámo": "reminar",
    "reminámos": "reminar",
    "remináramo": "reminar",
    "remináramos": "reminar",
    "reminárei": "reminar",
    "remináreis": "reminar",
    "reminásseis": "reminar",
    "reminássemos": "reminar",
    "reminávamo": "reminar",
    "reminávamos": "reminar",
    "reminávei": "reminar",
    "remináveis": "reminar",
    "remira": "remirar",
    "remirada": "remirar",
    "remiradas": "remirar",
    "remirado": "remirar",
    "remirados": "remirar",
    "remirai": "remirar",
    "remirais": "remirar",
    "remiram": "remirar",
    "remiramo": "remirar",
    "remiramos": "remirar",
    "remirando": "remirar",
    "remirara": "remirar",
    "remiraram": "remirar",
    "remiraras": "remirar",
    "remirarde": "remirar",
    "remirardes": "remirar",
    "remirare": "remirar",
    "remirarei": "remirar",
    "remirareis": "remirar",
    "remirarem": "remirar",
    "remiraremos": "remirar",
    "remirares": "remirar",
    "remiraria": "remirar",
    "remirariam": "remirar",
    "remirarias": "remirar",
    "remirarmo": "remirar",
    "remirarmos": "remirar",
    "remirará": "remirar",
    "remirarás": "remirar",
    "remirarão": "remirar",
    "remiraríamos": "remirar",
    "remiraríeis": "remirar",
    "remiras": "remirar",
    "remirasse": "remirar",
    "remirassem": "remirar",
    "remirasses": "remirar",
    "remiraste": "remirar",
    "remirastes": "remirar",
    "remirava": "remirar",
    "remiravam": "remirar",
    "remiravas": "remirar",
    "remirde": "remir",
    "remirdes": "remir",
    "remire": "remirar",
    "remirei": "remirar",
    "remireis": "remirar",
    "remirem": "remirar",
    "remiremo": "remirar",
    "remiremos": "remirar",
    "remires": "remirar",
    "remiria": "remir",
    "remiriam": "remir",
    "remirias": "remir",
    "remirmo": "remir",
    "remirmos": "remir",
    "remiro": "remirar",
    "remirou": "remirar",
    "remirá": "remirar",
    "remirámo": "remirar",
    "remirámos": "remirar",
    "remiráramo": "remirar",
    "remiráramos": "remirar",
    "remirárei": "remirar",
    "remiráreis": "remirar",
    "remirás": "remir",
    "remirásseis": "remirar",
    "remirássemos": "remirar",
    "remirávamo": "remirar",
    "remirávamos": "remirar",
    "remirávei": "remirar",
    "remiráveis": "remirar",
    "remirão": "remir",
    "remiríamos": "remir",
    "remiríeis": "remir",
    "remis": "remir",
    "remissa": "remisso",
    "remissas": "remisso",
    "remisse": "remir",
    "remissem": "remir",
    "remisses": "remir",
    "remissibilidades": "remissibilidade",
    "remissiva": "remissivo",
    "remissivas": "remissivo",
    "remissivos": "remissivo",
    "remissos": "remisso",
    "remissíveis": "remissível",
    "remissória": "remissório",
    "remissórias": "remissório",
    "remissórios": "remissório",
    "remissões": "remissão",
    "remiste": "remir",
    "remistes": "remir",
    "remisturada": "remisturado",
    "remisturadas": "remisturado",
    "remisturados": "remisturado",
    "remita": "remitir",
    "remitais": "remitir",
    "remitam": "remitir",
    "remitamo": "remitir",
    "remitamos": "remitir",
    "remitarsa": "remitarso",
    "remitarsas": "remitarso",
    "remitarsos": "remitarso",
    "remitas": "remitir",
    "remite": "remitir",
    "remitem": "remitir",
    "remitentes": "remitente",
    "remites": "remitir",
    "remiti": "remitir",
    "remitia": "remitir",
    "remitiam": "remitir",
    "remitias": "remitir",
    "remitida": "remitir",
    "remitidas": "remitir",
    "remitido": "remitir",
    "remitidos": "remitir",
    "remitimo": "remitir",
    "remitimos": "remitir",
    "remitindo": "remitir",
    "remitira": "remitir",
    "remitiram": "remitir",
    "remitiras": "remitir",
    "remitirde": "remitir",
    "remitirdes": "remitir",
    "remitire": "remitir",
    "remitirei": "remitir",
    "remitireis": "remitir",
    "remitirem": "remitir",
    "remitiremos": "remitir",
    "remitires": "remitir",
    "remitiria": "remitir",
    "remitiriam": "remitir",
    "remitirias": "remitir",
    "remitirmo": "remitir",
    "remitirmos": "remitir",
    "remitirá": "remitir",
    "remitirás": "remitir",
    "remitirão": "remitir",
    "remitiríamos": "remitir",
    "remitiríeis": "remitir",
    "remitis": "remitir",
    "remitisse": "remitir",
    "remitissem": "remitir",
    "remitisses": "remitir",
    "remitiste": "remitir",
    "remitistes": "remitir",
    "remitiu": "remitir",
    "remito": "remitir",
    "remitências": "remitência",
    "remitíamo": "remitir",
    "remitíamos": "remitir",
    "remitíei": "remitir",
    "remitíeis": "remitir",
    "remitíramo": "remitir",
    "remitíramos": "remitir",
    "remitírei": "remitir",
    "remitíreis": "remitir",
    "remitísseis": "remitir",
    "remitíssemos": "remitir",
    "remiu": "remir",
    "remições": "remição",
    "remo": "remir",
    "remoa": "remoer",
    "remoagens": "remoagem",
    "remoais": "remoer",
    "remoalhos": "remoalho",
    "remoam": "remoer",
    "remoamo": "remoer",
    "remoamos": "remoer",
    "remoas": "remoer",
    "remobila": "remobilar",
    "remobilada": "remobilar",
    "remobiladas": "remobilar",
    "remobilado": "remobilar",
    "remobilados": "remobilar",
    "remobilai": "remobilar",
    "remobilais": "remobilar",
    "remobilam": "remobilar",
    "remobilamo": "remobilar",
    "remobilamos": "remobilar",
    "remobilando": "remobilar",
    "remobilara": "remobilar",
    "remobilaram": "remobilar",
    "remobilaras": "remobilar",
    "remobilarde": "remobilar",
    "remobilardes": "remobilar",
    "remobilare": "remobilar",
    "remobilarei": "remobilar",
    "remobilareis": "remobilar",
    "remobilarem": "remobilar",
    "remobilaremos": "remobilar",
    "remobilares": "remobilar",
    "remobilaria": "remobilar",
    "remobilariam": "remobilar",
    "remobilarias": "remobilar",
    "remobilarmo": "remobilar",
    "remobilarmos": "remobilar",
    "remobilará": "remobilar",
    "remobilarás": "remobilar",
    "remobilarão": "remobilar",
    "remobilaríamos": "remobilar",
    "remobilaríeis": "remobilar",
    "remobilas": "remobilar",
    "remobilasse": "remobilar",
    "remobilassem": "remobilar",
    "remobilasses": "remobilar",
    "remobilaste": "remobilar",
    "remobilastes": "remobilar",
    "remobilava": "remobilar",
    "remobilavam": "remobilar",
    "remobilavas": "remobilar",
    "remobile": "remobilar",
    "remobilei": "remobilar",
    "remobileis": "remobilar",
    "remobilem": "remobilar",
    "remobilemo": "remobilar",
    "remobilemos": "remobilar",
    "remobiles": "remobilar",
    "remobilizações": "remobilização",
    "remobilo": "remobilar",
    "remobilou": "remobilar",
    "remobilá": "remobilar",
    "remobilámo": "remobilar",
    "remobilámos": "remobilar",
    "remobiláramo": "remobilar",
    "remobiláramos": "remobilar",
    "remobilárei": "remobilar",
    "remobiláreis": "remobilar",
    "remobilásseis": "remobilar",
    "remobilássemos": "remobilar",
    "remobilávamo": "remobilar",
    "remobilávamos": "remobilar",
    "remobilávei": "remobilar",
    "remobiláveis": "remobilar",
    "remoca": "remocar",
    "remocada": "remocar",
    "remocadas": "remocar",
    "remocado": "remocar",
    "remocados": "remocar",
    "remocai": "remocar",
    "remocais": "remocar",
    "remocam": "remocar",
    "remocamo": "remocar",
    "remocamos": "remocar",
    "remocando": "remocar",
    "remocara": "remocar",
    "remocaram": "remocar",
    "remocaras": "remocar",
    "remocarde": "remocar",
    "remocardes": "remocar",
    "remocare": "remocar",
    "remocarei": "remocar",
    "remocareis": "remocar",
    "remocarem": "remocar",
    "remocaremos": "remocar",
    "remocares": "remocar",
    "remocaria": "remocar",
    "remocariam": "remocar",
    "remocarias": "remocar",
    "remocarmo": "remocar",
    "remocarmos": "remocar",
    "remocará": "remocar",
    "remocarás": "remocar",
    "remocarão": "remocar",
    "remocaríamos": "remocar",
    "remocaríeis": "remocar",
    "remocas": "remocar",
    "remocasse": "remocar",
    "remocassem": "remocar",
    "remocasses": "remocar",
    "remocaste": "remocar",
    "remocastes": "remocar",
    "remocava": "remocar",
    "remocavam": "remocar",
    "remocavas": "remocar",
    "remoce": "remoçar",
    "remocei": "remoçar",
    "remoceis": "remoçar",
    "remocem": "remoçar",
    "remocemo": "remoçar",
    "remocemos": "remoçar",
    "remoces": "remoçar",
    "remoco": "remocar",
    "remocou": "remocar",
    "remocá": "remocar",
    "remocámo": "remocar",
    "remocámos": "remocar",
    "remocáramo": "remocar",
    "remocáramos": "remocar",
    "remocárei": "remocar",
    "remocáreis": "remocar",
    "remocásseis": "remocar",
    "remocássemos": "remocar",
    "remocávamo": "remocar",
    "remocávamos": "remocar",
    "remocávei": "remocar",
    "remocáveis": "remocar",
    "remodela": "remodelar",
    "remodelada": "remodelar",
    "remodeladas": "remodelar",
    "remodelado": "remodelar",
    "remodelados": "remodelar",
    "remodelagens": "remodelagem",
    "remodelai": "remodelar",
    "remodelais": "remodelar",
    "remodelam": "remodelar",
    "remodelamentos": "remodelamento",
    "remodelamo": "remodelar",
    "remodelamos": "remodelar",
    "remodelando": "remodelar",
    "remodelara": "remodelar",
    "remodelaram": "remodelar",
    "remodelaras": "remodelar",
    "remodelarde": "remodelar",
    "remodelardes": "remodelar",
    "remodelare": "remodelar",
    "remodelarei": "remodelar",
    "remodelareis": "remodelar",
    "remodelarem": "remodelar",
    "remodelaremos": "remodelar",
    "remodelares": "remodelar",
    "remodelaria": "remodelar",
    "remodelariam": "remodelar",
    "remodelarias": "remodelar",
    "remodelarmo": "remodelar",
    "remodelarmos": "remodelar",
    "remodelará": "remodelar",
    "remodelarás": "remodelar",
    "remodelarão": "remodelar",
    "remodelaríamos": "remodelar",
    "remodelaríeis": "remodelar",
    "remodelas": "remodelar",
    "remodelasse": "remodelar",
    "remodelassem": "remodelar",
    "remodelasses": "remodelar",
    "remodelaste": "remodelar",
    "remodelastes": "remodelar",
    "remodelava": "remodelar",
    "remodelavam": "remodelar",
    "remodelavas": "remodelar",
    "remodelações": "remodelação",
    "remodele": "remodelar",
    "remodelei": "remodelar",
    "remodeleis": "remodelar",
    "remodelem": "remodelar",
    "remodelemo": "remodelar",
    "remodelemos": "remodelar",
    "remodeles": "remodelar",
    "remodelo": "remodelar",
    "remodelou": "remodelar",
    "remodelá": "remodelar",
    "remodelámo": "remodelar",
    "remodelámos": "remodelar",
    "remodeláramo": "remodelar",
    "remodeláramos": "remodelar",
    "remodelárei": "remodelar",
    "remodeláreis": "remodelar",
    "remodelásseis": "remodelar",
    "remodelássemos": "remodelar",
    "remodelávamo": "remodelar",
    "remodelávamos": "remodelar",
    "remodelávei": "remodelar",
    "remodeláveis": "remodelável",
    "remoeduras": "remoedura",
    "remoei": "remoer",
    "remoeis": "remoer",
    "remoem": "remoer",
    "remoemo": "remoer",
    "remoemos": "remoer",
    "remoendo": "remoer",
    "remoera": "remoer",
    "remoeram": "remoer",
    "remoeras": "remoer",
    "remoerde": "remoer",
    "remoerdes": "remoer",
    "remoere": "remoer",
    "remoerei": "remoer",
    "remoereis": "remoer",
    "remoerem": "remoer",
    "remoeremos": "remoer",
    "remoeres": "remoer",
    "remoeria": "remoer",
    "remoeriam": "remoer",
    "remoerias": "remoer",
    "remoermo": "remoer",
    "remoermos": "remoer",
    "remoerá": "remoer",
    "remoerás": "remoer",
    "remoerão": "remoer",
    "remoeríamos": "remoer",
    "remoeríeis": "remoer",
    "remoesse": "remoer",
    "remoessem": "remoer",
    "remoesses": "remoer",
    "remoeste": "remoer",
    "remoestes": "remoer",
    "remoeu": "remoer",
    "remoinha": "remoinhar",
    "remoinhada": "remoinhar",
    "remoinhadas": "remoinhar",
    "remoinhado": "remoinhar",
    "remoinhados": "remoinhar",
    "remoinhai": "remoinhar",
    "remoinhais": "remoinhar",
    "remoinham": "remoinhar",
    "remoinhamo": "remoinhar",
    "remoinhamos": "remoinhar",
    "remoinhando": "remoinhar",
    "remoinhara": "remoinhar",
    "remoinharam": "remoinhar",
    "remoinharas": "remoinhar",
    "remoinhardes": "remoinhar",
    "remoinharei": "remoinhar",
    "remoinhareis": "remoinhar",
    "remoinharem": "remoinhar",
    "remoinharemos": "remoinhar",
    "remoinhares": "remoinhar",
    "remoinharia": "remoinhar",
    "remoinhariam": "remoinhar",
    "remoinharias": "remoinhar",
    "remoinharmo": "remoinhar",
    "remoinharmos": "remoinhar",
    "remoinhará": "remoinhar",
    "remoinharás": "remoinhar",
    "remoinharão": "remoinhar",
    "remoinharíamos": "remoinhar",
    "remoinharíeis": "remoinhar",
    "remoinhas": "remoinhar",
    "remoinhasse": "remoinhar",
    "remoinhassem": "remoinhar",
    "remoinhasses": "remoinhar",
    "remoinhaste": "remoinhar",
    "remoinhastes": "remoinhar",
    "remoinhava": "remoinhar",
    "remoinhavam": "remoinhar",
    "remoinhavas": "remoinhar",
    "remoinhe": "remoinhar",
    "remoinhei": "remoinhar",
    "remoinheis": "remoinhar",
    "remoinhem": "remoinhar",
    "remoinhemo": "remoinhar",
    "remoinhemos": "remoinhar",
    "remoinhes": "remoinhar",
    "remoinho": "remoinhar",
    "remoinhos": "remoinho",
    "remoinhosa": "remoinhoso",
    "remoinhosas": "remoinhoso",
    "remoinhosos": "remoinhoso",
    "remoinhou": "remoinhar",
    "remoinhámo": "remoinhar",
    "remoinhámos": "remoinhar",
    "remoinháramo": "remoinhar",
    "remoinháramos": "remoinhar",
    "remoinháreis": "remoinhar",
    "remoinhásseis": "remoinhar",
    "remoinhássemos": "remoinhar",
    "remoinhávamo": "remoinhar",
    "remoinhávamos": "remoinhar",
    "remoinháveis": "remoinhar",
    "remolha": "remolhar",
    "remolhada": "remolhar",
    "remolhadas": "remolhar",
    "remolhado": "remolhar",
    "remolhados": "remolhar",
    "remolhai": "remolhar",
    "remolhais": "remolhar",
    "remolham": "remolhar",
    "remolhamo": "remolhar",
    "remolhamos": "remolhar",
    "remolhando": "remolhar",
    "remolhara": "remolhar",
    "remolharam": "remolhar",
    "remolharas": "remolhar",
    "remolharde": "remolhar",
    "remolhardes": "remolhar",
    "remolhare": "remolhar",
    "remolharei": "remolhar",
    "remolhareis": "remolhar",
    "remolharem": "remolhar",
    "remolharemos": "remolhar",
    "remolhares": "remolhar",
    "remolharia": "remolhar",
    "remolhariam": "remolhar",
    "remolharias": "remolhar",
    "remolharmo": "remolhar",
    "remolharmos": "remolhar",
    "remolhará": "remolhar",
    "remolharás": "remolhar",
    "remolharão": "remolhar",
    "remolharíamos": "remolhar",
    "remolharíeis": "remolhar",
    "remolhas": "remolhar",
    "remolhasse": "remolhar",
    "remolhassem": "remolhar",
    "remolhasses": "remolhar",
    "remolhaste": "remolhar",
    "remolhastes": "remolhar",
    "remolhava": "remolhar",
    "remolhavam": "remolhar",
    "remolhavas": "remolhar",
    "remolhe": "remolhar",
    "remolhei": "remolhar",
    "remolheis": "remolhar",
    "remolhem": "remolhar",
    "remolhemo": "remolhar",
    "remolhemos": "remolhar",
    "remolhes": "remolhar",
    "remolho": "remolhar",
    "remolhos": "remolho",
    "remolhou": "remolhar",
    "remolhá": "remolhar",
    "remolhámo": "remolhar",
    "remolhámos": "remolhar",
    "remolháramo": "remolhar",
    "remolháramos": "remolhar",
    "remolhárei": "remolhar",
    "remolháreis": "remolhar",
    "remolhásseis": "remolhar",
    "remolhássemos": "remolhar",
    "remolhávamo": "remolhar",
    "remolhávamos": "remolhar",
    "remolhávei": "remolhar",
    "remolháveis": "remolhar",
    "remonda": "remondar",
    "remondada": "remondar",
    "remondadas": "remondar",
    "remondado": "remondar",
    "remondados": "remondar",
    "remondagens": "remondagem",
    "remondai": "remondar",
    "remondais": "remondar",
    "remondam": "remondar",
    "remondamo": "remondar",
    "remondamos": "remondar",
    "remondando": "remondar",
    "remondara": "remondar",
    "remondaram": "remondar",
    "remondaras": "remondar",
    "remondarde": "remondar",
    "remondardes": "remondar",
    "remondare": "remondar",
    "remondarei": "remondar",
    "remondareis": "remondar",
    "remondarem": "remondar",
    "remondaremos": "remondar",
    "remondares": "remondar",
    "remondaria": "remondar",
    "remondariam": "remondar",
    "remondarias": "remondar",
    "remondarmo": "remondar",
    "remondarmos": "remondar",
    "remondará": "remondar",
    "remondarás": "remondar",
    "remondarão": "remondar",
    "remondaríamos": "remondar",
    "remondaríeis": "remondar",
    "remondas": "remondar",
    "remondasse": "remondar",
    "remondassem": "remondar",
    "remondasses": "remondar",
    "remondaste": "remondar",
    "remondastes": "remondar",
    "remondava": "remondar",
    "remondavam": "remondar",
    "remondavas": "remondar",
    "remonde": "remondar",
    "remondei": "remondar",
    "remondeis": "remondar",
    "remondem": "remondar",
    "remondemo": "remondar",
    "remondemos": "remondar",
    "remondes": "remondar",
    "remondo": "remondar",
    "remondou": "remondar",
    "remondá": "remondar",
    "remondámo": "remondar",
    "remondámos": "remondar",
    "remondáramo": "remondar",
    "remondáramos": "remondar",
    "remondárei": "remondar",
    "remondáreis": "remondar",
    "remondásseis": "remondar",
    "remondássemos": "remondar",
    "remondávamo": "remondar",
    "remondávamos": "remondar",
    "remondávei": "remondar",
    "remondáveis": "remondar",
    "remonta": "remontar",
    "remontada": "remontar",
    "remontadas": "remontar",
    "remontado": "remontar",
    "remontados": "remontar",
    "remontagens": "remontagem",
    "remontai": "remontar",
    "remontais": "remontar",
    "remontam": "remontar",
    "remontamo": "remontar",
    "remontamos": "remontar",
    "remontando": "remontar",
    "remontantes": "remontante",
    "remontara": "remontar",
    "remontaram": "remontar",
    "remontaras": "remontar",
    "remontarde": "remontar",
    "remontardes": "remontar",
    "remontare": "remontar",
    "remontarei": "remontar",
    "remontareis": "remontar",
    "remontarem": "remontar",
    "remontaremos": "remontar",
    "remontares": "remontar",
    "remontaria": "remontar",
    "remontariam": "remontar",
    "remontarias": "remontar",
    "remontarmo": "remontar",
    "remontarmos": "remontar",
    "remontará": "remontar",
    "remontarás": "remontar",
    "remontarão": "remontar",
    "remontaríamos": "remontar",
    "remontaríeis": "remontar",
    "remontas": "remontar",
    "remontasse": "remontar",
    "remontassem": "remontar",
    "remontasses": "remontar",
    "remontaste": "remontar",
    "remontastes": "remontar",
    "remontava": "remontar",
    "remontavam": "remontar",
    "remontavas": "remontar",
    "remonte": "remontar",
    "remontei": "remontar",
    "remonteis": "remontar",
    "remontem": "remontar",
    "remontemo": "remontar",
    "remontemos": "remontar",
    "remontes": "remonte",
    "remontistas": "remontista",
    "remonto": "remontar",
    "remontou": "remontar",
    "remontá": "remontar",
    "remontámo": "remontar",
    "remontámos": "remontar",
    "remontáramo": "remontar",
    "remontáramos": "remontar",
    "remontárei": "remontar",
    "remontáreis": "remontar",
    "remontásseis": "remontar",
    "remontássemos": "remontar",
    "remontávamo": "remontar",
    "remontávamos": "remontar",
    "remontávei": "remontar",
    "remontáveis": "remontar",
    "remoo": "remoer",
    "remoque": "remocar",
    "remoqueada": "remoquear",
    "remoqueadas": "remoquear",
    "remoqueado": "remoquear",
    "remoqueadora": "remoqueador",
    "remoqueadoras": "remoqueador",
    "remoqueadores": "remoqueador",
    "remoqueados": "remoquear",
    "remoqueai": "remoquear",
    "remoqueais": "remoquear",
    "remoqueamo": "remoquear",
    "remoqueamos": "remoquear",
    "remoqueando": "remoquear",
    "remoqueara": "remoquear",
    "remoquearam": "remoquear",
    "remoquearas": "remoquear",
    "remoquearde": "remoquear",
    "remoqueardes": "remoquear",
    "remoqueare": "remoquear",
    "remoquearei": "remoquear",
    "remoqueareis": "remoquear",
    "remoquearem": "remoquear",
    "remoquearemos": "remoquear",
    "remoqueares": "remoquear",
    "remoquearia": "remoquear",
    "remoqueariam": "remoquear",
    "remoquearias": "remoquear",
    "remoquearmo": "remoquear",
    "remoquearmos": "remoquear",
    "remoqueará": "remoquear",
    "remoquearás": "remoquear",
    "remoquearão": "remoquear",
    "remoquearíamos": "remoquear",
    "remoquearíeis": "remoquear",
    "remoqueasse": "remoquear",
    "remoqueassem": "remoquear",
    "remoqueasses": "remoquear",
    "remoqueaste": "remoquear",
    "remoqueastes": "remoquear",
    "remoqueava": "remoquear",
    "remoqueavam": "remoquear",
    "remoqueavas": "remoquear",
    "remoqueei": "remoquear",
    "remoqueeis": "remoquear",
    "remoqueemo": "remoquear",
    "remoqueemos": "remoquear",
    "remoquei": "remocar",
    "remoqueia": "remoquear",
    "remoqueiam": "remoquear",
    "remoqueias": "remoquear",
    "remoqueie": "remoquear",
    "remoqueiem": "remoquear",
    "remoqueies": "remoquear",
    "remoqueio": "remoquear",
    "remoqueis": "remocar",
    "remoquem": "remocar",
    "remoquemo": "remocar",
    "remoquemos": "remocar",
    "remoqueou": "remoquear",
    "remoques": "remoque",
    "remoqueá": "remoquear",
    "remoqueámo": "remoquear",
    "remoqueámos": "remoquear",
    "remoqueáramo": "remoquear",
    "remoqueáramos": "remoquear",
    "remoqueárei": "remoquear",
    "remoqueáreis": "remoquear",
    "remoqueásseis": "remoquear",
    "remoqueássemos": "remoquear",
    "remoqueávamo": "remoquear",
    "remoqueávamos": "remoquear",
    "remoqueávei": "remoquear",
    "remoqueáveis": "remoquear",
    "remora": "remorar",
    "remorada": "remorar",
    "remoradas": "remorar",
    "remorado": "remorar",
    "remorados": "remorar",
    "remorai": "remorar",
    "remorais": "remorar",
    "remoram": "remorar",
    "remoramo": "remorar",
    "remoramos": "remorar",
    "remorando": "remorar",
    "remorara": "remorar",
    "remoraram": "remorar",
    "remoraras": "remorar",
    "remorarde": "remorar",
    "remorardes": "remorar",
    "remorare": "remorar",
    "remorarei": "remorar",
    "remorareis": "remorar",
    "remorarem": "remorar",
    "remoraremos": "remorar",
    "remorares": "remorar",
    "remoraria": "remorar",
    "remorariam": "remorar",
    "remorarias": "remorar",
    "remorarmo": "remorar",
    "remorarmos": "remorar",
    "remorará": "remorar",
    "remorarás": "remorar",
    "remorarão": "remorar",
    "remoraríamos": "remorar",
    "remoraríeis": "remorar",
    "remoras": "remorar",
    "remorasse": "remorar",
    "remorassem": "remorar",
    "remorasses": "remorar",
    "remoraste": "remorar",
    "remorastes": "remorar",
    "remorava": "remorar",
    "remoravam": "remorar",
    "remoravas": "remorar",
    "remorda": "remorder",
    "remordais": "remorder",
    "remordam": "remorder",
    "remordamo": "remorder",
    "remordamos": "remorder",
    "remordas": "remorder",
    "remordazes": "remordaz",
    "remorde": "remorder",
    "remordedora": "remordedor",
    "remordedoras": "remordedor",
    "remordedores": "remordedor",
    "remordei": "remorder",
    "remordeis": "remorder",
    "remordem": "remorder",
    "remordemo": "remorder",
    "remordemos": "remorder",
    "remordendo": "remorder",
    "remordentes": "remordente",
    "remordera": "remorder",
    "remorderam": "remorder",
    "remorderas": "remorder",
    "remorderde": "remorder",
    "remorderdes": "remorder",
    "remordere": "remorder",
    "remorderei": "remorder",
    "remordereis": "remorder",
    "remorderem": "remorder",
    "remorderemos": "remorder",
    "remorderes": "remorder",
    "remorderia": "remorder",
    "remorderiam": "remorder",
    "remorderias": "remorder",
    "remordermo": "remorder",
    "remordermos": "remorder",
    "remorderá": "remorder",
    "remorderás": "remorder",
    "remorderão": "remorder",
    "remorderíamos": "remorder",
    "remorderíeis": "remorder",
    "remordes": "remorder",
    "remordesse": "remorder",
    "remordessem": "remorder",
    "remordesses": "remorder",
    "remordeste": "remorder",
    "remordestes": "remorder",
    "remordeu": "remorder",
    "remordi": "remorder",
    "remordia": "remorder",
    "remordiam": "remorder",
    "remordias": "remorder",
    "remordida": "remorder",
    "remordidas": "remorder",
    "remordido": "remorder",
    "remordidos": "remorder",
    "remordimentos": "remordimento",
    "remordo": "remorder",
    "remordê": "remorder",
    "remordêramo": "remorder",
    "remordêramos": "remorder",
    "remordêrei": "remorder",
    "remordêreis": "remorder",
    "remordêsseis": "remorder",
    "remordêssemos": "remorder",
    "remordíamo": "remorder",
    "remordíamos": "remorder",
    "remordíei": "remorder",
    "remordíeis": "remorder",
    "remore": "remorar",
    "remorei": "remorar",
    "remoreis": "remorar",
    "remorem": "remorar",
    "remoremo": "remorar",
    "remoremos": "remorar",
    "remores": "remorar",
    "remoro": "remorar",
    "remorosa": "remoroso",
    "remorosas": "remoroso",
    "remorosos": "remoroso",
    "remorou": "remorar",
    "remorsos": "remorso",
    "remorta": "remorto",
    "remortas": "remorto",
    "remortos": "remorto",
    "remorá": "remorar",
    "remorámo": "remorar",
    "remorámos": "remorar",
    "remoráramo": "remorar",
    "remoráramos": "remorar",
    "remorárei": "remorar",
    "remoráreis": "remorar",
    "remorásseis": "remorar",
    "remorássemos": "remorar",
    "remorávamo": "remorar",
    "remorávamos": "remorar",
    "remorávei": "remorar",
    "remoráveis": "remorar",
    "remos": "remo",
    "remota": "remoto",
    "remotas": "remoto",
    "remotos": "remoto",
    "remotíssima": "remoto",
    "remotíssimas": "remoto",
    "remotíssimo": "remoto",
    "remotíssimos": "remoto",
    "remou": "remar",
    "remova": "remover",
    "removais": "remover",
    "removam": "remover",
    "removamo": "remover",
    "removamos": "remover",
    "removas": "remover",
    "remove": "remover",
    "removei": "remover",
    "removeis": "remover",
    "removem": "remover",
    "removemo": "remover",
    "removemos": "remover",
    "removendo": "remover",
    "removera": "remover",
    "removeram": "remover",
    "removeras": "remover",
    "removerde": "remover",
    "removerdes": "remover",
    "removere": "remover",
    "removerei": "remover",
    "removereis": "remover",
    "removerem": "remover",
    "removeremos": "remover",
    "removeres": "remover",
    "removeria": "remover",
    "removeriam": "remover",
    "removerias": "remover",
    "removermo": "remover",
    "removermos": "remover",
    "removerá": "remover",
    "removerás": "remover",
    "removerão": "remover",
    "removeríamos": "remover",
    "removeríeis": "remover",
    "removes": "remover",
    "removesse": "remover",
    "removessem": "remover",
    "removesses": "remover",
    "removeste": "remover",
    "removestes": "remover",
    "removeu": "remover",
    "removi": "remover",
    "removia": "remover",
    "removiam": "remover",
    "removias": "remover",
    "removida": "removido",
    "removidas": "removido",
    "removido": "remover",
    "removidos": "removido",
    "removimentos": "removimento",
    "removo": "remover",
    "removê": "remover",
    "removêramo": "remover",
    "removêramos": "remover",
    "removêrei": "remover",
    "removêreis": "remover",
    "removêsseis": "remover",
    "removêssemos": "remover",
    "removíamo": "remover",
    "removíamos": "remover",
    "removíei": "remover",
    "removíeis": "remover",
    "removíveis": "removível",
    "remoça": "remoçar",
    "remoçada": "remoçar",
    "remoçadas": "remoçar",
    "remoçado": "remoçar",
    "remoçadora": "remoçador",
    "remoçadoras": "remoçador",
    "remoçadores": "remoçador",
    "remoçados": "remoçar",
    "remoçai": "remoçar",
    "remoçais": "remoçar",
    "remoçam": "remoçar",
    "remoçamo": "remoçar",
    "remoçamos": "remoçar",
    "remoçando": "remoçar",
    "remoçara": "remoçar",
    "remoçaram": "remoçar",
    "remoçaras": "remoçar",
    "remoçardes": "remoçar",
    "remoçarei": "remoçar",
    "remoçareis": "remoçar",
    "remoçarem": "remoçar",
    "remoçaremos": "remoçar",
    "remoçares": "remoçar",
    "remoçaria": "remoçar",
    "remoçariam": "remoçar",
    "remoçarias": "remoçar",
    "remoçarmo": "remoçar",
    "remoçarmos": "remoçar",
    "remoçará": "remoçar",
    "remoçarás": "remoçar",
    "remoçarão": "remoçar",
    "remoçaríamos": "remoçar",
    "remoçaríeis": "remoçar",
    "remoças": "remoçar",
    "remoçasse": "remoçar",
    "remoçassem": "remoçar",
    "remoçasses": "remoçar",
    "remoçaste": "remoçar",
    "remoçastes": "remoçar",
    "remoçativa": "remoçativo",
    "remoçativas": "remoçativo",
    "remoçativos": "remoçativo",
    "remoçava": "remoçar",
    "remoçavam": "remoçar",
    "remoçavas": "remoçar",
    "remoço": "remoçar",
    "remoçou": "remoçar",
    "remoçámo": "remoçar",
    "remoçámos": "remoçar",
    "remoçáramo": "remoçar",
    "remoçáramos": "remoçar",
    "remoçáreis": "remoçar",
    "remoçásseis": "remoçar",
    "remoçássemos": "remoçar",
    "remoçávamo": "remoçar",
    "remoçávamos": "remoçar",
    "remoçáveis": "remoçar",
    "remoções": "remoção",
    "remoê": "remoer",
    "remoêramo": "remoer",
    "remoêramos": "remoer",
    "remoêrei": "remoer",
    "remoêreis": "remoer",
    "remoêsseis": "remoer",
    "remoêssemos": "remoer",
    "remoí": "remoer",
    "remoía": "remoer",
    "remoíam": "remoer",
    "remoíamo": "remoer",
    "remoíamos": "remoer",
    "remoías": "remoer",
    "remoída": "remoído",
    "remoídas": "remoído",
    "remoído": "remoer",
    "remoídos": "remoído",
    "remoíei": "remoer",
    "remoíeis": "remoer",
    "remualhos": "remualho",
    "remuda": "remudar",
    "remudada": "remudar",
    "remudadas": "remudar",
    "remudado": "remudar",
    "remudados": "remudar",
    "remudai": "remudar",
    "remudais": "remudar",
    "remudam": "remudar",
    "remudamo": "remudar",
    "remudamos": "remudar",
    "remudando": "remudar",
    "remudara": "remudar",
    "remudaram": "remudar",
    "remudaras": "remudar",
    "remudarde": "remudar",
    "remudardes": "remudar",
    "remudare": "remudar",
    "remudarei": "remudar",
    "remudareis": "remudar",
    "remudarem": "remudar",
    "remudaremos": "remudar",
    "remudares": "remudar",
    "remudaria": "remudar",
    "remudariam": "remudar",
    "remudarias": "remudar",
    "remudarmo": "remudar",
    "remudarmos": "remudar",
    "remudará": "remudar",
    "remudarás": "remudar",
    "remudarão": "remudar",
    "remudaríamos": "remudar",
    "remudaríeis": "remudar",
    "remudas": "remudar",
    "remudasse": "remudar",
    "remudassem": "remudar",
    "remudasses": "remudar",
    "remudaste": "remudar",
    "remudastes": "remudar",
    "remudava": "remudar",
    "remudavam": "remudar",
    "remudavas": "remudar",
    "remude": "remudar",
    "remudei": "remudar",
    "remudeis": "remudar",
    "remudem": "remudar",
    "remudemo": "remudar",
    "remudemos": "remudar",
    "remudes": "remudar",
    "remudo": "remudar",
    "remudou": "remudar",
    "remudá": "remudar",
    "remudámo": "remudar",
    "remudámos": "remudar",
    "remudáramo": "remudar",
    "remudáramos": "remudar",
    "remudárei": "remudar",
    "remudáreis": "remudar",
    "remudásseis": "remudar",
    "remudássemos": "remudar",
    "remudávamo": "remudar",
    "remudávamos": "remudar",
    "remudávei": "remudar",
    "remudáveis": "remudar",
    "remuge": "remugir",
    "remugem": "remugir",
    "remuges": "remugir",
    "remugi": "remugir",
    "remugia": "remugir",
    "remugiam": "remugir",
    "remugias": "remugir",
    "remugida": "remugir",
    "remugidas": "remugir",
    "remugido": "remugir",
    "remugidos": "remugir",
    "remugimo": "remugir",
    "remugimos": "remugir",
    "remugindo": "remugir",
    "remugira": "remugir",
    "remugiram": "remugir",
    "remugiras": "remugir",
    "remugirdes": "remugir",
    "remugirei": "remugir",
    "remugireis": "remugir",
    "remugirem": "remugir",
    "remugiremos": "remugir",
    "remugires": "remugir",
    "remugiria": "remugir",
    "remugiriam": "remugir",
    "remugirias": "remugir",
    "remugirmo": "remugir",
    "remugirmos": "remugir",
    "remugirá": "remugir",
    "remugirás": "remugir",
    "remugirão": "remugir",
    "remugiríamos": "remugir",
    "remugiríeis": "remugir",
    "remugis": "remugir",
    "remugisse": "remugir",
    "remugissem": "remugir",
    "remugisses": "remugir",
    "remugiste": "remugir",
    "remugistes": "remugir",
    "remugiu": "remugir",
    "remugíamo": "remugir",
    "remugíamos": "remugir",
    "remugíeis": "remugir",
    "remugíramo": "remugir",
    "remugíramos": "remugir",
    "remugíreis": "remugir",
    "remugísseis": "remugir",
    "remugíssemos": "remugir",
    "remuja": "remugir",
    "remujais": "remugir",
    "remujam": "remugir",
    "remujamo": "remugir",
    "remujamos": "remugir",
    "remujas": "remugir",
    "remujo": "remugir",
    "remunera": "remunerar",
    "remunerada": "remunerar",
    "remuneradas": "remunerar",
    "remunerado": "remunerar",
    "remuneradora": "remunerador",
    "remuneradoras": "remunerador",
    "remuneradores": "remunerador",
    "remunerados": "remunerar",
    "remunerai": "remunerar",
    "remunerais": "remunerar",
    "remuneram": "remunerar",
    "remuneramo": "remunerar",
    "remuneramos": "remunerar",
    "remunerando": "remunerar",
    "remunerara": "remunerar",
    "remuneraram": "remunerar",
    "remuneraras": "remunerar",
    "remunerarde": "remunerar",
    "remunerardes": "remunerar",
    "remunerare": "remunerar",
    "remunerarei": "remunerar",
    "remunerareis": "remunerar",
    "remunerarem": "remunerar",
    "remuneraremos": "remunerar",
    "remunerares": "remunerar",
    "remuneraria": "remunerar",
    "remunerariam": "remunerar",
    "remunerarias": "remunerar",
    "remunerarmo": "remunerar",
    "remunerarmos": "remunerar",
    "remunerará": "remunerar",
    "remunerarás": "remunerar",
    "remunerarão": "remunerar",
    "remuneraríamos": "remunerar",
    "remuneraríeis": "remunerar",
    "remuneras": "remunerar",
    "remunerasse": "remunerar",
    "remunerassem": "remunerar",
    "remunerasses": "remunerar",
    "remuneraste": "remunerar",
    "remunerastes": "remunerar",
    "remunerativa": "remunerativo",
    "remunerativas": "remunerativo",
    "remunerativos": "remunerativo",
    "remuneratória": "remuneratório",
    "remuneratórias": "remuneratório",
    "remuneratórios": "remuneratório",
    "remunerava": "remunerar",
    "remuneravam": "remunerar",
    "remuneravas": "remunerar",
    "remunerações": "remuneração",
    "remunere": "remunerar",
    "remunerei": "remunerar",
    "remunereis": "remunerar",
    "remunerem": "remunerar",
    "remuneremo": "remunerar",
    "remuneremos": "remunerar",
    "remuneres": "remunerar",
    "remunero": "remunerar",
    "remunerosa": "remuneroso",
    "remunerosas": "remuneroso",
    "remunerosos": "remuneroso",
    "remunerou": "remunerar",
    "remunerá": "remunerar",
    "remunerámo": "remunerar",
    "remunerámos": "remunerar",
    "remuneráramo": "remunerar",
    "remuneráramos": "remunerar",
    "remunerárei": "remunerar",
    "remuneráreis": "remunerar",
    "remunerásseis": "remunerar",
    "remunerássemos": "remunerar",
    "remunerávamo": "remunerar",
    "remunerávamos": "remunerar",
    "remunerávei": "remunerar",
    "remuneráveis": "remunerável",
    "remurmura": "remurmurar",
    "remurmurada": "remurmurar",
    "remurmuradas": "remurmurar",
    "remurmurado": "remurmurar",
    "remurmurados": "remurmurar",
    "remurmurai": "remurmurar",
    "remurmurais": "remurmurar",
    "remurmuram": "remurmurar",
    "remurmuramo": "remurmurar",
    "remurmuramos": "remurmurar",
    "remurmurando": "remurmurar",
    "remurmurara": "remurmurar",
    "remurmuraram": "remurmurar",
    "remurmuraras": "remurmurar",
    "remurmurardes": "remurmurar",
    "remurmurarei": "remurmurar",
    "remurmurareis": "remurmurar",
    "remurmurarem": "remurmurar",
    "remurmuraremos": "remurmurar",
    "remurmurares": "remurmurar",
    "remurmuraria": "remurmurar",
    "remurmurariam": "remurmurar",
    "remurmurarias": "remurmurar",
    "remurmurarmo": "remurmurar",
    "remurmurarmos": "remurmurar",
    "remurmurará": "remurmurar",
    "remurmurarás": "remurmurar",
    "remurmurarão": "remurmurar",
    "remurmuraríamos": "remurmurar",
    "remurmuraríeis": "remurmurar",
    "remurmuras": "remurmurar",
    "remurmurasse": "remurmurar",
    "remurmurassem": "remurmurar",
    "remurmurasses": "remurmurar",
    "remurmuraste": "remurmurar",
    "remurmurastes": "remurmurar",
    "remurmurava": "remurmurar",
    "remurmuravam": "remurmurar",
    "remurmuravas": "remurmurar",
    "remurmure": "remurmurar",
    "remurmurei": "remurmurar",
    "remurmureis": "remurmurar",
    "remurmureja": "remurmurejar",
    "remurmurejada": "remurmurejar",
    "remurmurejadas": "remurmurejar",
    "remurmurejado": "remurmurejar",
    "remurmurejados": "remurmurejar",
    "remurmurejai": "remurmurejar",
    "remurmurejais": "remurmurejar",
    "remurmurejam": "remurmurejar",
    "remurmurejamo": "remurmurejar",
    "remurmurejamos": "remurmurejar",
    "remurmurejando": "remurmurejar",
    "remurmurejara": "remurmurejar",
    "remurmurejaram": "remurmurejar",
    "remurmurejaras": "remurmurejar",
    "remurmurejardes": "remurmurejar",
    "remurmurejarei": "remurmurejar",
    "remurmurejareis": "remurmurejar",
    "remurmurejarem": "remurmurejar",
    "remurmurejaremos": "remurmurejar",
    "remurmurejares": "remurmurejar",
    "remurmurejaria": "remurmurejar",
    "remurmurejariam": "remurmurejar",
    "remurmurejarias": "remurmurejar",
    "remurmurejarmo": "remurmurejar",
    "remurmurejarmos": "remurmurejar",
    "remurmurejará": "remurmurejar",
    "remurmurejarás": "remurmurejar",
    "remurmurejarão": "remurmurejar",
    "remurmurejaríamos": "remurmurejar",
    "remurmurejaríeis": "remurmurejar",
    "remurmurejas": "remurmurejar",
    "remurmurejasse": "remurmurejar",
    "remurmurejassem": "remurmurejar",
    "remurmurejasses": "remurmurejar",
    "remurmurejaste": "remurmurejar",
    "remurmurejastes": "remurmurejar",
    "remurmurejava": "remurmurejar",
    "remurmurejavam": "remurmurejar",
    "remurmurejavas": "remurmurejar",
    "remurmureje": "remurmurejar",
    "remurmurejei": "remurmurejar",
    "remurmurejeis": "remurmurejar",
    "remurmurejem": "remurmurejar",
    "remurmurejemo": "remurmurejar",
    "remurmurejemos": "remurmurejar",
    "remurmurejes": "remurmurejar",
    "remurmurejo": "remurmurejar",
    "remurmurejou": "remurmurejar",
    "remurmurejámo": "remurmurejar",
    "remurmurejámos": "remurmurejar",
    "remurmurejáramo": "remurmurejar",
    "remurmurejáramos": "remurmurejar",
    "remurmurejáreis": "remurmurejar",
    "remurmurejásseis": "remurmurejar",
    "remurmurejássemos": "remurmurejar",
    "remurmurejávamo": "remurmurejar",
    "remurmurejávamos": "remurmurejar",
    "remurmurejáveis": "remurmurejar",
    "remurmurem": "remurmurar",
    "remurmuremo": "remurmurar",
    "remurmuremos": "remurmurar",
    "remurmures": "remurmurar",
    "remurmuro": "remurmurar",
    "remurmurou": "remurmurar",
    "remurmurámo": "remurmurar",
    "remurmurámos": "remurmurar",
    "remurmuráramo": "remurmurar",
    "remurmuráramos": "remurmurar",
    "remurmuráreis": "remurmurar",
    "remurmurásseis": "remurmurar",
    "remurmurássemos": "remurmurar",
    "remurmurávamo": "remurmurar",
    "remurmurávamos": "remurmurar",
    "remurmuráveis": "remurmurar",
    "remurmúrios": "remurmúrio",
    "remámo": "remar",
    "remámos": "remar",
    "remáramo": "remar",
    "remáramos": "remar",
    "remáreis": "remar",
    "remásseis": "remar",
    "remássemos": "remar",
    "remávamo": "remar",
    "remávamos": "remar",
    "remáveis": "remar",
    "remédios": "remédio",
    "remémora": "remémoro",
    "remémoras": "remémoro",
    "remémoros": "remémoro",
    "remíamo": "remir",
    "remíamos": "remir",
    "remíei": "remir",
    "remíeis": "remir",
    "remígera": "remígero",
    "remígeras": "remígero",
    "remígeros": "remígero",
    "remígies": "remígie",
    "remígios": "remígio",
    "remípedes": "remípede",
    "remíramo": "remir",
    "remíramos": "remir",
    "remírei": "remir",
    "remíreis": "remir",
    "remísseis": "remir",
    "remíssemos": "remir",
    "remíveis": "remível",
    "remói": "remoer",
    "remóis": "remoer",
    "renacionalizações": "renacionalização",
    "renais": "renal",
    "renana": "renano",
    "renanas": "renano",
    "renanazinha": "renano",
    "renanazinhas": "renano",
    "renanazita": "renano",
    "renanazitas": "renano",
    "renanos": "renano",
    "renanozinho": "renano",
    "renanozinhos": "renano",
    "renanozito": "renano",
    "renanozitos": "renano",
    "renas": "rena",
    "renasce": "renascer",
    "renascei": "renascer",
    "renasceis": "renascer",
    "renascem": "renascer",
    "renascemo": "renascer",
    "renascemos": "renascer",
    "renascendo": "renascer",
    "renascentes": "renascente",
    "renascentismos": "renascentismo",
    "renascentistas": "renascentista",
    "renascenças": "renascença",
    "renascera": "renascer",
    "renasceram": "renascer",
    "renasceras": "renascer",
    "renascerdes": "renascer",
    "renascerei": "renascer",
    "renascereis": "renascer",
    "renascerem": "renascer",
    "renasceremos": "renascer",
    "renasceres": "renascer",
    "renasceria": "renascer",
    "renasceriam": "renascer",
    "renascerias": "renascer",
    "renascermo": "renascer",
    "renascermos": "renascer",
    "renascerá": "renascer",
    "renascerás": "renascer",
    "renascerão": "renascer",
    "renasceríamos": "renascer",
    "renasceríeis": "renascer",
    "renasces": "renascer",
    "renascesse": "renascer",
    "renascessem": "renascer",
    "renascesses": "renascer",
    "renasceste": "renascer",
    "renascestes": "renascer",
    "renasceu": "renascer",
    "renasci": "renascer",
    "renascia": "renascer",
    "renasciam": "renascer",
    "renascias": "renascer",
    "renascida": "renascido",
    "renascidas": "renascido",
    "renascido": "renascer",
    "renascidos": "renascido",
    "renascimentos": "renascimento",
    "renascêramo": "renascer",
    "renascêramos": "renascer",
    "renascêreis": "renascer",
    "renascêsseis": "renascer",
    "renascêssemos": "renascer",
    "renascíamo": "renascer",
    "renascíamos": "renascer",
    "renascíeis": "renascer",
    "renasça": "renascer",
    "renasçais": "renascer",
    "renasçam": "renascer",
    "renasçamo": "renascer",
    "renasçamos": "renascer",
    "renasças": "renascer",
    "renasço": "renascer",
    "renavega": "renavegar",
    "renavegada": "renavegar",
    "renavegadas": "renavegar",
    "renavegado": "renavegar",
    "renavegados": "renavegar",
    "renavegai": "renavegar",
    "renavegais": "renavegar",
    "renavegam": "renavegar",
    "renavegamo": "renavegar",
    "renavegamos": "renavegar",
    "renavegando": "renavegar",
    "renavegara": "renavegar",
    "renavegaram": "renavegar",
    "renavegaras": "renavegar",
    "renavegardes": "renavegar",
    "renavegarei": "renavegar",
    "renavegareis": "renavegar",
    "renavegarem": "renavegar",
    "renavegaremos": "renavegar",
    "renavegares": "renavegar",
    "renavegaria": "renavegar",
    "renavegariam": "renavegar",
    "renavegarias": "renavegar",
    "renavegarmo": "renavegar",
    "renavegarmos": "renavegar",
    "renavegará": "renavegar",
    "renavegarás": "renavegar",
    "renavegarão": "renavegar",
    "renavegaríamos": "renavegar",
    "renavegaríeis": "renavegar",
    "renavegas": "renavegar",
    "renavegasse": "renavegar",
    "renavegassem": "renavegar",
    "renavegasses": "renavegar",
    "renavegaste": "renavegar",
    "renavegastes": "renavegar",
    "renavegava": "renavegar",
    "renavegavam": "renavegar",
    "renavegavas": "renavegar",
    "renavego": "renavegar",
    "renavegou": "renavegar",
    "renavegue": "renavegar",
    "renaveguei": "renavegar",
    "renavegueis": "renavegar",
    "renaveguem": "renavegar",
    "renaveguemo": "renavegar",
    "renaveguemos": "renavegar",
    "renavegues": "renavegar",
    "renavegámo": "renavegar",
    "renavegámos": "renavegar",
    "renavegáramo": "renavegar",
    "renavegáramos": "renavegar",
    "renavegáreis": "renavegar",
    "renavegásseis": "renavegar",
    "renavegássemos": "renavegar",
    "renavegávamo": "renavegar",
    "renavegávamos": "renavegar",
    "renavegáveis": "renavegar",
    "renda": "render",
    "rendada": "rendar",
    "rendadas": "rendar",
    "rendadazinha": "rendado",
    "rendadazinhas": "rendado",
    "rendadazita": "rendado",
    "rendadazitas": "rendado",
    "rendado": "rendar",
    "rendados": "rendar",
    "rendadozinho": "rendado",
    "rendadozinhos": "rendado",
    "rendadozito": "rendado",
    "rendadozitos": "rendado",
    "rendai": "rendar",
    "rendais": "render",
    "rendam": "render",
    "rendamo": "render",
    "rendamos": "render",
    "rendando": "rendar",
    "rendara": "rendar",
    "rendaram": "rendar",
    "rendaras": "rendar",
    "rendarde": "rendar",
    "rendardes": "rendar",
    "rendare": "rendar",
    "rendarei": "rendar",
    "rendareis": "rendar",
    "rendarem": "rendar",
    "rendaremos": "rendar",
    "rendares": "rendar",
    "rendaria": "rendar",
    "rendariam": "rendar",
    "rendarias": "rendaria",
    "rendarmo": "rendar",
    "rendarmos": "rendar",
    "rendará": "rendar",
    "rendarás": "rendar",
    "rendarão": "rendar",
    "rendaríamos": "rendar",
    "rendaríeis": "rendar",
    "rendas": "render",
    "rendasse": "rendar",
    "rendassem": "rendar",
    "rendasses": "rendar",
    "rendaste": "rendar",
    "rendastes": "rendar",
    "rendava": "rendar",
    "rendavam": "rendar",
    "rendavas": "rendar",
    "rende": "render",
    "rendedoira": "rendedoiro",
    "rendedoiras": "rendedoiro",
    "rendedoiros": "rendedoiro",
    "rendedoura": "rendedouro",
    "rendedouras": "rendedouro",
    "rendedouros": "rendedouro",
    "rendei": "render",
    "rendeira": "rendeiro",
    "rendeiras": "rendeiro",
    "rendeiros": "rendeiro",
    "rendeis": "render",
    "rendem": "render",
    "rendemo": "render",
    "rendemos": "render",
    "rendendo": "render",
    "rendera": "render",
    "renderam": "render",
    "renderas": "render",
    "renderde": "render",
    "renderdes": "render",
    "rendere": "render",
    "renderei": "render",
    "rendereis": "render",
    "renderem": "render",
    "renderemos": "render",
    "renderes": "render",
    "renderia": "render",
    "renderiam": "render",
    "renderias": "render",
    "rendermo": "render",
    "rendermos": "render",
    "renderá": "render",
    "renderás": "render",
    "renderão": "render",
    "renderíamos": "render",
    "renderíeis": "render",
    "rendes": "render",
    "rendesse": "render",
    "rendessem": "render",
    "rendesses": "render",
    "rendeste": "render",
    "rendestes": "render",
    "rendeu": "render",
    "rendi": "render",
    "rendia": "render",
    "rendiam": "render",
    "rendias": "render",
    "rendibilidades": "rendibilidade",
    "rendibiliza": "rendibilizar",
    "rendibilizada": "rendibilizar",
    "rendibilizadas": "rendibilizar",
    "rendibilizado": "rendibilizar",
    "rendibilizados": "rendibilizar",
    "rendibilizai": "rendibilizar",
    "rendibilizais": "rendibilizar",
    "rendibilizam": "rendibilizar",
    "rendibilizamo": "rendibilizar",
    "rendibilizamos": "rendibilizar",
    "rendibilizando": "rendibilizar",
    "rendibilizara": "rendibilizar",
    "rendibilizaram": "rendibilizar",
    "rendibilizaras": "rendibilizar",
    "rendibilizarde": "rendibilizar",
    "rendibilizardes": "rendibilizar",
    "rendibilizare": "rendibilizar",
    "rendibilizarei": "rendibilizar",
    "rendibilizareis": "rendibilizar",
    "rendibilizarem": "rendibilizar",
    "rendibilizaremos": "rendibilizar",
    "rendibilizares": "rendibilizar",
    "rendibilizaria": "rendibilizar",
    "rendibilizariam": "rendibilizar",
    "rendibilizarias": "rendibilizar",
    "rendibilizarmo": "rendibilizar",
    "rendibilizarmos": "rendibilizar",
    "rendibilizará": "rendibilizar",
    "rendibilizarás": "rendibilizar",
    "rendibilizarão": "rendibilizar",
    "rendibilizaríamos": "rendibilizar",
    "rendibilizaríeis": "rendibilizar",
    "rendibilizas": "rendibilizar",
    "rendibilizasse": "rendibilizar",
    "rendibilizassem": "rendibilizar",
    "rendibilizasses": "rendibilizar",
    "rendibilizaste": "rendibilizar",
    "rendibilizastes": "rendibilizar",
    "rendibilizava": "rendibilizar",
    "rendibilizavam": "rendibilizar",
    "rendibilizavas": "rendibilizar",
    "rendibilizações": "rendibilização",
    "rendibilize": "rendibilizar",
    "rendibilizei": "rendibilizar",
    "rendibilizeis": "rendibilizar",
    "rendibilizem": "rendibilizar",
    "rendibilizemo": "rendibilizar",
    "rendibilizemos": "rendibilizar",
    "rendibilizes": "rendibilizar",
    "rendibilizo": "rendibilizar",
    "rendibilizou": "rendibilizar",
    "rendibilizá": "rendibilizar",
    "rendibilizámo": "rendibilizar",
    "rendibilizámos": "rendibilizar",
    "rendibilizáramo": "rendibilizar",
    "rendibilizáramos": "rendibilizar",
    "rendibilizárei": "rendibilizar",
    "rendibilizáreis": "rendibilizar",
    "rendibilizásseis": "rendibilizar",
    "rendibilizássemos": "rendibilizar",
    "rendibilizávamo": "rendibilizar",
    "rendibilizávamos": "rendibilizar",
    "rendibilizávei": "rendibilizar",
    "rendibilizáveis": "rendibilizar",
    "rendida": "rendido",
    "rendidas": "rendido",
    "rendido": "render",
    "rendidos": "rendido",
    "rendilha": "rendilhar",
    "rendilhada": "rendilhar",
    "rendilhadas": "rendilhar",
    "rendilhado": "rendilhar",
    "rendilhados": "rendilhar",
    "rendilhai": "rendilhar",
    "rendilhais": "rendilhar",
    "rendilham": "rendilhar",
    "rendilhamentos": "rendilhamento",
    "rendilhamo": "rendilhar",
    "rendilhamos": "rendilhar",
    "rendilhando": "rendilhar",
    "rendilhara": "rendilhar",
    "rendilharam": "rendilhar",
    "rendilharas": "rendilhar",
    "rendilharde": "rendilhar",
    "rendilhardes": "rendilhar",
    "rendilhare": "rendilhar",
    "rendilharei": "rendilhar",
    "rendilhareis": "rendilhar",
    "rendilharem": "rendilhar",
    "rendilharemos": "rendilhar",
    "rendilhares": "rendilhar",
    "rendilharia": "rendilhar",
    "rendilhariam": "rendilhar",
    "rendilharias": "rendilhar",
    "rendilharmo": "rendilhar",
    "rendilharmos": "rendilhar",
    "rendilhará": "rendilhar",
    "rendilharás": "rendilhar",
    "rendilharão": "rendilhar",
    "rendilharíamos": "rendilhar",
    "rendilharíeis": "rendilhar",
    "rendilhas": "rendilhar",
    "rendilhasse": "rendilhar",
    "rendilhassem": "rendilhar",
    "rendilhasses": "rendilhar",
    "rendilhaste": "rendilhar",
    "rendilhastes": "rendilhar",
    "rendilhava": "rendilhar",
    "rendilhavam": "rendilhar",
    "rendilhavas": "rendilhar",
    "rendilhe": "rendilhar",
    "rendilhei": "rendilhar",
    "rendilheira": "rendilheiro",
    "rendilheiras": "rendilheiro",
    "rendilheiros": "rendilheiro",
    "rendilheis": "rendilhar",
    "rendilhem": "rendilhar",
    "rendilhemo": "rendilhar",
    "rendilhemos": "rendilhar",
    "rendilhes": "rendilhar",
    "rendilho": "rendilhar",
    "rendilhou": "rendilhar",
    "rendilhá": "rendilhar",
    "rendilhámo": "rendilhar",
    "rendilhámos": "rendilhar",
    "rendilháramo": "rendilhar",
    "rendilháramos": "rendilhar",
    "rendilhárei": "rendilhar",
    "rendilháreis": "rendilhar",
    "rendilhásseis": "rendilhar",
    "rendilhássemos": "rendilhar",
    "rendilhávamo": "rendilhar",
    "rendilhávamos": "rendilhar",
    "rendilhávei": "rendilhar",
    "rendilháveis": "rendilhar",
    "rendimentos": "rendimento",
    "rendinha": "renda",
    "rendinhas": "renda",
    "rendita": "renda",
    "renditas": "renda",
    "rendições": "rendição",
    "rendo": "render",
    "rendores": "rendor",
    "rendosa": "rendoso",
    "rendosas": "rendoso",
    "rendosos": "rendoso",
    "rendou": "rendar",
    "rendá": "rendar",
    "rendámo": "rendar",
    "rendámos": "rendar",
    "rendáramo": "rendar",
    "rendáramos": "rendar",
    "rendárei": "rendar",
    "rendáreis": "rendar",
    "rendásseis": "rendar",
    "rendássemos": "rendar",
    "rendávamo": "rendar",
    "rendávamos": "rendar",
    "rendávei": "rendar",
    "rendáveis": "rendar",
    "rendê": "render",
    "rendêramo": "render",
    "rendêramos": "render",
    "rendêrei": "render",
    "rendêreis": "render",
    "rendêsseis": "render",
    "rendêssemos": "render",
    "rendíamo": "render",
    "rendíamos": "render",
    "rendíei": "render",
    "rendíeis": "render",
    "rendíveis": "rendível",
    "renega": "renegar",
    "renegada": "renegar",
    "renegadas": "renegar",
    "renegadazinha": "renegado",
    "renegadazinhas": "renegado",
    "renegadazita": "renegado",
    "renegadazitas": "renegado",
    "renegado": "renegar",
    "renegadora": "renegador",
    "renegadoras": "renegador",
    "renegadores": "renegador",
    "renegados": "renegar",
    "renegadozinho": "renegado",
    "renegadozinhos": "renegado",
    "renegadozito": "renegado",
    "renegadozitos": "renegado",
    "renegai": "renegar",
    "renegais": "renegar",
    "renegam": "renegar",
    "renegamo": "renegar",
    "renegamos": "renegar",
    "renegando": "renegar",
    "renegara": "renegar",
    "renegaram": "renegar",
    "renegaras": "renegar",
    "renegarde": "renegar",
    "renegardes": "renegar",
    "renegare": "renegar",
    "renegarei": "renegar",
    "renegareis": "renegar",
    "renegarem": "renegar",
    "renegaremos": "renegar",
    "renegares": "renegar",
    "renegaria": "renegar",
    "renegariam": "renegar",
    "renegarias": "renegar",
    "renegarmo": "renegar",
    "renegarmos": "renegar",
    "renegará": "renegar",
    "renegarás": "renegar",
    "renegarão": "renegar",
    "renegaríamos": "renegar",
    "renegaríeis": "renegar",
    "renegas": "renegar",
    "renegasse": "renegar",
    "renegassem": "renegar",
    "renegasses": "renegar",
    "renegaste": "renegar",
    "renegastes": "renegar",
    "renegava": "renegar",
    "renegavam": "renegar",
    "renegavas": "renegar",
    "renegações": "renegação",
    "renego": "renegar",
    "renegoceia": "renegociar",
    "renegoceiam": "renegociar",
    "renegoceias": "renegociar",
    "renegoceie": "renegociar",
    "renegoceiem": "renegociar",
    "renegoceies": "renegociar",
    "renegoceio": "renegociar",
    "renegocia": "renegociar",
    "renegociada": "renegociar",
    "renegociadas": "renegociar",
    "renegociado": "renegociar",
    "renegociados": "renegociar",
    "renegociai": "renegociar",
    "renegociais": "renegociar",
    "renegociam": "renegociar",
    "renegociamo": "renegociar",
    "renegociamos": "renegociar",
    "renegociando": "renegociar",
    "renegociara": "renegociar",
    "renegociaram": "renegociar",
    "renegociaras": "renegociar",
    "renegociarde": "renegociar",
    "renegociardes": "renegociar",
    "renegociare": "renegociar",
    "renegociarei": "renegociar",
    "renegociareis": "renegociar",
    "renegociarem": "renegociar",
    "renegociaremos": "renegociar",
    "renegociares": "renegociar",
    "renegociaria": "renegociar",
    "renegociariam": "renegociar",
    "renegociarias": "renegociar",
    "renegociarmo": "renegociar",
    "renegociarmos": "renegociar",
    "renegociará": "renegociar",
    "renegociarás": "renegociar",
    "renegociarão": "renegociar",
    "renegociaríamos": "renegociar",
    "renegociaríeis": "renegociar",
    "renegocias": "renegociar",
    "renegociasse": "renegociar",
    "renegociassem": "renegociar",
    "renegociasses": "renegociar",
    "renegociaste": "renegociar",
    "renegociastes": "renegociar",
    "renegociava": "renegociar",
    "renegociavam": "renegociar",
    "renegociavas": "renegociar",
    "renegociações": "renegociação",
    "renegocie": "renegociar",
    "renegociei": "renegociar",
    "renegocieis": "renegociar",
    "renegociem": "renegociar",
    "renegociemo": "renegociar",
    "renegociemos": "renegociar",
    "renegocies": "renegociar",
    "renegocio": "renegociar",
    "renegociou": "renegociar",
    "renegociá": "renegociar",
    "renegociámo": "renegociar",
    "renegociámos": "renegociar",
    "renegociáramo": "renegociar",
    "renegociáramos": "renegociar",
    "renegociárei": "renegociar",
    "renegociáreis": "renegociar",
    "renegociásseis": "renegociar",
    "renegociássemos": "renegociar",
    "renegociávamo": "renegociar",
    "renegociávamos": "renegociar",
    "renegociávei": "renegociar",
    "renegociáveis": "renegociar",
    "renegou": "renegar",
    "renegue": "renegar",
    "reneguei": "renegar",
    "renegueis": "renegar",
    "reneguem": "renegar",
    "reneguemo": "renegar",
    "reneguemos": "renegar",
    "renegues": "renegar",
    "renegá": "renegar",
    "renegámo": "renegar",
    "renegámos": "renegar",
    "renegáramo": "renegar",
    "renegáramos": "renegar",
    "renegárei": "renegar",
    "renegáreis": "renegar",
    "renegásseis": "renegar",
    "renegássemos": "renegar",
    "renegávamo": "renegar",
    "renegávamos": "renegar",
    "renegávei": "renegar",
    "renegáveis": "renegável",
    "reneta": "renetar",
    "renetada": "renetar",
    "renetadas": "renetar",
    "renetado": "renetar",
    "renetados": "renetar",
    "renetai": "renetar",
    "renetais": "renetar",
    "renetam": "renetar",
    "renetamo": "renetar",
    "renetamos": "renetar",
    "renetando": "renetar",
    "renetara": "renetar",
    "renetaram": "renetar",
    "renetaras": "renetar",
    "renetarde": "renetar",
    "renetardes": "renetar",
    "renetare": "renetar",
    "renetarei": "renetar",
    "renetareis": "renetar",
    "renetarem": "renetar",
    "renetaremos": "renetar",
    "renetares": "renetar",
    "renetaria": "renetar",
    "renetariam": "renetar",
    "renetarias": "renetar",
    "renetarmo": "renetar",
    "renetarmos": "renetar",
    "renetará": "renetar",
    "renetarás": "renetar",
    "renetarão": "renetar",
    "renetaríamos": "renetar",
    "renetaríeis": "renetar",
    "renetas": "renetar",
    "renetasse": "renetar",
    "renetassem": "renetar",
    "renetasses": "renetar",
    "renetaste": "renetar",
    "renetastes": "renetar",
    "renetava": "renetar",
    "renetavam": "renetar",
    "renetavas": "renetar",
    "renete": "renetar",
    "renetei": "renetar",
    "reneteis": "renetar",
    "renetem": "renetar",
    "renetemo": "renetar",
    "renetemos": "renetar",
    "renetes": "renete",
    "reneto": "renetar",
    "renetou": "renetar",
    "renetá": "renetar",
    "renetámo": "renetar",
    "renetámos": "renetar",
    "renetáramo": "renetar",
    "renetáramos": "renetar",
    "renetárei": "renetar",
    "renetáreis": "renetar",
    "renetásseis": "renetar",
    "renetássemos": "renetar",
    "renetávamo": "renetar",
    "renetávamos": "renetar",
    "renetávei": "renetar",
    "renetáveis": "renetar",
    "renga": "rengo",
    "rengalhos": "rengalho",
    "rengas": "rengo",
    "rengos": "rengo",
    "renha": "renhir",
    "renhais": "renhir",
    "renham": "renhir",
    "renhamo": "renhir",
    "renhamos": "renhir",
    "renhas": "renhir",
    "renhe": "renhir",
    "renhem": "renhir",
    "renhes": "renhir",
    "renhi": "renhir",
    "renhia": "renhir",
    "renhiam": "renhir",
    "renhias": "renhir",
    "renhida": "renhir",
    "renhidas": "renhir",
    "renhidazinha": "renhido",
    "renhidazinhas": "renhido",
    "renhidazita": "renhido",
    "renhidazitas": "renhido",
    "renhidinha": "renhido",
    "renhidinhas": "renhido",
    "renhidinho": "renhido",
    "renhidinhos": "renhido",
    "renhidita": "renhido",
    "renhiditas": "renhido",
    "renhidito": "renhido",
    "renhiditos": "renhido",
    "renhido": "renhir",
    "renhidos": "renhir",
    "renhidozinho": "renhido",
    "renhidozinhos": "renhido",
    "renhidozito": "renhido",
    "renhidozitos": "renhido",
    "renhidíssima": "renhido",
    "renhidíssimas": "renhido",
    "renhidíssimo": "renhido",
    "renhidíssimos": "renhido",
    "renhimentos": "renhimento",
    "renhimo": "renhir",
    "renhimos": "renhir",
    "renhindo": "renhir",
    "renhira": "renhir",
    "renhiram": "renhir",
    "renhiras": "renhir",
    "renhirde": "renhir",
    "renhirdes": "renhir",
    "renhire": "renhir",
    "renhirei": "renhir",
    "renhireis": "renhir",
    "renhirem": "renhir",
    "renhiremos": "renhir",
    "renhires": "renhir",
    "renhiria": "renhir",
    "renhiriam": "renhir",
    "renhirias": "renhir",
    "renhirmo": "renhir",
    "renhirmos": "renhir",
    "renhirá": "renhir",
    "renhirás": "renhir",
    "renhirão": "renhir",
    "renhiríamos": "renhir",
    "renhiríeis": "renhir",
    "renhis": "renhir",
    "renhisse": "renhir",
    "renhissem": "renhir",
    "renhisses": "renhir",
    "renhiste": "renhir",
    "renhistes": "renhir",
    "renhiu": "renhir",
    "renho": "renhir",
    "renhíamo": "renhir",
    "renhíamos": "renhir",
    "renhíei": "renhir",
    "renhíeis": "renhir",
    "renhíramo": "renhir",
    "renhíramos": "renhir",
    "renhírei": "renhir",
    "renhíreis": "renhir",
    "renhísseis": "renhir",
    "renhíssemos": "renhir",
    "renidentes": "renidente",
    "reniformes": "reniforme",
    "reninas": "renina",
    "renita": "renitir",
    "renitais": "renitir",
    "renitam": "renitir",
    "renitamo": "renitir",
    "renitamos": "renitir",
    "renitas": "renitir",
    "renite": "renitir",
    "renitem": "renitir",
    "renitentes": "renitente",
    "renites": "renitir",
    "reniti": "renitir",
    "renitia": "renitir",
    "renitiam": "renitir",
    "renitias": "renitir",
    "renitida": "renitir",
    "renitidas": "renitir",
    "renitido": "renitir",
    "renitidos": "renitir",
    "renitimo": "renitir",
    "renitimos": "renitir",
    "renitindo": "renitir",
    "renitira": "renitir",
    "renitiram": "renitir",
    "renitiras": "renitir",
    "renitirdes": "renitir",
    "renitirei": "renitir",
    "renitireis": "renitir",
    "renitirem": "renitir",
    "renitiremos": "renitir",
    "renitires": "renitir",
    "renitiria": "renitir",
    "renitiriam": "renitir",
    "renitirias": "renitir",
    "renitirmo": "renitir",
    "renitirmos": "renitir",
    "renitirá": "renitir",
    "renitirás": "renitir",
    "renitirão": "renitir",
    "renitiríamos": "renitir",
    "renitiríeis": "renitir",
    "renitis": "renitir",
    "renitisse": "renitir",
    "renitissem": "renitir",
    "renitisses": "renitir",
    "renitiste": "renitir",
    "renitistes": "renitir",
    "renitiu": "renitir",
    "renito": "renitir",
    "renitências": "renitência",
    "renitíamo": "renitir",
    "renitíamos": "renitir",
    "renitíeis": "renitir",
    "renitíramo": "renitir",
    "renitíramos": "renitir",
    "renitíreis": "renitir",
    "renitísseis": "renitir",
    "renitíssemos": "renitir",
    "renomeada": "renomear",
    "renomeadas": "renomear",
    "renomeado": "renomear",
    "renomeados": "renomear",
    "renomeai": "renomear",
    "renomeais": "renomear",
    "renomeamo": "renomear",
    "renomeamos": "renomear",
    "renomeando": "renomear",
    "renomeara": "renomear",
    "renomearam": "renomear",
    "renomearas": "renomear",
    "renomearde": "renomear",
    "renomeardes": "renomear",
    "renomeare": "renomear",
    "renomearei": "renomear",
    "renomeareis": "renomear",
    "renomearem": "renomear",
    "renomearemos": "renomear",
    "renomeares": "renomear",
    "renomearia": "renomear",
    "renomeariam": "renomear",
    "renomearias": "renomear",
    "renomearmo": "renomear",
    "renomearmos": "renomear",
    "renomeará": "renomear",
    "renomearás": "renomear",
    "renomearão": "renomear",
    "renomearíamos": "renomear",
    "renomearíeis": "renomear",
    "renomeasse": "renomear",
    "renomeassem": "renomear",
    "renomeasses": "renomear",
    "renomeaste": "renomear",
    "renomeastes": "renomear",
    "renomeava": "renomear",
    "renomeavam": "renomear",
    "renomeavas": "renomear",
    "renomeei": "renomear",
    "renomeeis": "renomear",
    "renomeemo": "renomear",
    "renomeemos": "renomear",
    "renomeia": "renomear",
    "renomeiam": "renomear",
    "renomeias": "renomear",
    "renomeie": "renomear",
    "renomeiem": "renomear",
    "renomeies": "renomear",
    "renomeio": "renomear",
    "renomeou": "renomear",
    "renomes": "renome",
    "renomeá": "renomear",
    "renomeámo": "renomear",
    "renomeámos": "renomear",
    "renomeáramo": "renomear",
    "renomeáramos": "renomear",
    "renomeárei": "renomear",
    "renomeáreis": "renomear",
    "renomeásseis": "renomear",
    "renomeássemos": "renomear",
    "renomeávamo": "renomear",
    "renomeávamos": "renomear",
    "renomeávei": "renomear",
    "renomeáveis": "renomear",
    "renova": "renovar",
    "renovada": "renovar",
    "renovadas": "renovar",
    "renovado": "renovar",
    "renovadora": "renovador",
    "renovadoras": "renovador",
    "renovadores": "renovador",
    "renovados": "renovar",
    "renovai": "renovar",
    "renovais": "renovar",
    "renovam": "renovar",
    "renovamentos": "renovamento",
    "renovamo": "renovar",
    "renovamos": "renovar",
    "renovando": "renovar",
    "renovara": "renovar",
    "renovaram": "renovar",
    "renovaras": "renovar",
    "renovarde": "renovar",
    "renovardes": "renovar",
    "renovare": "renovar",
    "renovarei": "renovar",
    "renovareis": "renovar",
    "renovarem": "renovar",
    "renovaremos": "renovar",
    "renovares": "renovar",
    "renovaria": "renovar",
    "renovariam": "renovar",
    "renovarias": "renovar",
    "renovarmo": "renovar",
    "renovarmos": "renovar",
    "renovará": "renovar",
    "renovarás": "renovar",
    "renovarão": "renovar",
    "renovaríamos": "renovar",
    "renovaríeis": "renovar",
    "renovas": "renovar",
    "renovasse": "renovar",
    "renovassem": "renovar",
    "renovasses": "renovar",
    "renovaste": "renovar",
    "renovastes": "renovar",
    "renovava": "renovar",
    "renovavam": "renovar",
    "renovavas": "renovar",
    "renovações": "renovação",
    "renove": "renovar",
    "renovei": "renovar",
    "renoveis": "renovar",
    "renovem": "renovar",
    "renovemo": "renovar",
    "renovemos": "renovar",
    "renoves": "renovar",
    "renovo": "renovar",
    "renovos": "renovo",
    "renovou": "renovar",
    "renová": "renovar",
    "renovámo": "renovar",
    "renovámos": "renovar",
    "renováramo": "renovar",
    "renováramos": "renovar",
    "renovárei": "renovar",
    "renováreis": "renovar",
    "renovásseis": "renovar",
    "renovássemos": "renovar",
    "renovávamo": "renovar",
    "renovávamos": "renovar",
    "renovávei": "renovar",
    "renováveis": "renovável",
    "renques": "renque",
    "renta": "rentar",
    "rentabilidades": "rentabilidade",
    "rentabiliza": "rentabilizar",
    "rentabilizada": "rentabilizar",
    "rentabilizadas": "rentabilizar",
    "rentabilizado": "rentabilizar",
    "rentabilizados": "rentabilizar",
    "rentabilizai": "rentabilizar",
    "rentabilizais": "rentabilizar",
    "rentabilizam": "rentabilizar",
    "rentabilizamo": "rentabilizar",
    "rentabilizamos": "rentabilizar",
    "rentabilizando": "rentabilizar",
    "rentabilizara": "rentabilizar",
    "rentabilizaram": "rentabilizar",
    "rentabilizaras": "rentabilizar",
    "rentabilizarde": "rentabilizar",
    "rentabilizardes": "rentabilizar",
    "rentabilizare": "rentabilizar",
    "rentabilizarei": "rentabilizar",
    "rentabilizareis": "rentabilizar",
    "rentabilizarem": "rentabilizar",
    "rentabilizaremos": "rentabilizar",
    "rentabilizares": "rentabilizar",
    "rentabilizaria": "rentabilizar",
    "rentabilizariam": "rentabilizar",
    "rentabilizarias": "rentabilizar",
    "rentabilizarmo": "rentabilizar",
    "rentabilizarmos": "rentabilizar",
    "rentabilizará": "rentabilizar",
    "rentabilizarás": "rentabilizar",
    "rentabilizarão": "rentabilizar",
    "rentabilizaríamos": "rentabilizar",
    "rentabilizaríeis": "rentabilizar",
    "rentabilizas": "rentabilizar",
    "rentabilizasse": "rentabilizar",
    "rentabilizassem": "rentabilizar",
    "rentabilizasses": "rentabilizar",
    "rentabilizaste": "rentabilizar",
    "rentabilizastes": "rentabilizar",
    "rentabilizava": "rentabilizar",
    "rentabilizavam": "rentabilizar",
    "rentabilizavas": "rentabilizar",
    "rentabilizações": "rentabilização",
    "rentabilize": "rentabilizar",
    "rentabilizei": "rentabilizar",
    "rentabilizeis": "rentabilizar",
    "rentabilizem": "rentabilizar",
    "rentabilizemo": "rentabilizar",
    "rentabilizemos": "rentabilizar",
    "rentabilizes": "rentabilizar",
    "rentabilizo": "rentabilizar",
    "rentabilizou": "rentabilizar",
    "rentabilizá": "rentabilizar",
    "rentabilizámo": "rentabilizar",
    "rentabilizámos": "rentabilizar",
    "rentabilizáramo": "rentabilizar",
    "rentabilizáramos": "rentabilizar",
    "rentabilizárei": "rentabilizar",
    "rentabilizáreis": "rentabilizar",
    "rentabilizásseis": "rentabilizar",
    "rentabilizássemos": "rentabilizar",
    "rentabilizávamo": "rentabilizar",
    "rentabilizávamos": "rentabilizar",
    "rentabilizávei": "rentabilizar",
    "rentabilizáveis": "rentabilizar",
    "rentabilíssima": "rentável",
    "rentabilíssimas": "rentável",
    "rentabilíssimo": "rentável",
    "rentabilíssimos": "rentável",
    "rentada": "rentar",
    "rentadas": "rentar",
    "rentado": "rentar",
    "rentados": "rentar",
    "rentai": "rentar",
    "rentais": "rentar",
    "rentam": "rentar",
    "rentamo": "rentar",
    "rentamos": "rentar",
    "rentando": "rentar",
    "rentara": "rentar",
    "rentaram": "rentar",
    "rentaras": "rentar",
    "rentardes": "rentar",
    "rentarei": "rentar",
    "rentareis": "rentar",
    "rentarem": "rentar",
    "rentaremos": "rentar",
    "rentares": "rentar",
    "rentaria": "rentar",
    "rentariam": "rentar",
    "rentarias": "rentar",
    "rentarmo": "rentar",
    "rentarmos": "rentar",
    "rentará": "rentar",
    "rentarás": "rentar",
    "rentarão": "rentar",
    "rentaríamos": "rentar",
    "rentaríeis": "rentar",
    "rentas": "rentar",
    "rentasse": "rentar",
    "rentassem": "rentar",
    "rentasses": "rentar",
    "rentaste": "rentar",
    "rentastes": "rentar",
    "rentava": "rentar",
    "rentavam": "rentar",
    "rentavas": "rentar",
    "rente": "rentar",
    "renteada": "rentear",
    "renteadas": "rentear",
    "renteado": "rentear",
    "renteadora": "renteador",
    "renteadoras": "renteador",
    "renteadores": "renteador",
    "renteados": "rentear",
    "renteai": "rentear",
    "renteais": "rentear",
    "renteamo": "rentear",
    "renteamos": "rentear",
    "renteando": "rentear",
    "renteara": "rentear",
    "rentearam": "rentear",
    "rentearas": "rentear",
    "rentearde": "rentear",
    "renteardes": "rentear",
    "renteare": "rentear",
    "rentearei": "rentear",
    "renteareis": "rentear",
    "rentearem": "rentear",
    "rentearemos": "rentear",
    "renteares": "rentear",
    "rentearia": "rentear",
    "renteariam": "rentear",
    "rentearias": "rentear",
    "rentearmo": "rentear",
    "rentearmos": "rentear",
    "renteará": "rentear",
    "rentearás": "rentear",
    "rentearão": "rentear",
    "rentearíamos": "rentear",
    "rentearíeis": "rentear",
    "renteasse": "rentear",
    "renteassem": "rentear",
    "renteasses": "rentear",
    "renteaste": "rentear",
    "renteastes": "rentear",
    "renteava": "rentear",
    "renteavam": "rentear",
    "renteavas": "rentear",
    "renteei": "rentear",
    "renteeis": "rentear",
    "renteemo": "rentear",
    "renteemos": "rentear",
    "rentei": "rentar",
    "renteia": "rentear",
    "renteiam": "rentear",
    "renteias": "rentear",
    "renteie": "rentear",
    "renteiem": "rentear",
    "renteies": "rentear",
    "renteio": "rentear",
    "renteis": "rentar",
    "rentem": "rentar",
    "rentemo": "rentar",
    "rentemos": "rentar",
    "renteou": "rentear",
    "rentes": "rente",
    "renteá": "rentear",
    "renteámo": "rentear",
    "renteámos": "rentear",
    "renteáramo": "rentear",
    "renteáramos": "rentear",
    "renteárei": "rentear",
    "renteáreis": "rentear",
    "renteásseis": "rentear",
    "renteássemos": "rentear",
    "renteávamo": "rentear",
    "renteávamos": "rentear",
    "renteávei": "rentear",
    "renteáveis": "rentear",
    "rentinha": "rentinho",
    "rentinhas": "rentinho",
    "rentinhos": "rentinho",
    "rento": "rentar",
    "rentona": "rentão",
    "rentonas": "rentão",
    "rentou": "rentar",
    "rentrées": "rentrée",
    "rentámo": "rentar",
    "rentámos": "rentar",
    "rentáramo": "rentar",
    "rentáramos": "rentar",
    "rentáreis": "rentar",
    "rentásseis": "rentar",
    "rentássemos": "rentar",
    "rentávamo": "rentar",
    "rentávamos": "rentar",
    "rentáveis": "rentável",
    "rentões": "rentão",
    "renua": "renuir",
    "renuais": "renuir",
    "renuam": "renuir",
    "renuamo": "renuir",
    "renuamos": "renuir",
    "renuas": "renuir",
    "renuem": "renuir",
    "renuentes": "renuente",
    "renui": "renuir",
    "renuindo": "renuir",
    "renuirde": "renuir",
    "renuirdes": "renuir",
    "renuirei": "renuir",
    "renuireis": "renuir",
    "renuiremos": "renuir",
    "renuiria": "renuir",
    "renuiriam": "renuir",
    "renuirias": "renuir",
    "renuirmo": "renuir",
    "renuirmos": "renuir",
    "renuirá": "renuir",
    "renuirás": "renuir",
    "renuirão": "renuir",
    "renuiríamos": "renuir",
    "renuiríeis": "renuir",
    "renuis": "renuir",
    "renuiu": "renuir",
    "renuncia": "renunciar",
    "renunciada": "renunciar",
    "renunciadas": "renunciar",
    "renunciado": "renunciar",
    "renunciadora": "renunciador",
    "renunciadoras": "renunciador",
    "renunciadores": "renunciador",
    "renunciados": "renunciar",
    "renunciai": "renunciar",
    "renunciais": "renunciar",
    "renunciam": "renunciar",
    "renunciamo": "renunciar",
    "renunciamos": "renunciar",
    "renunciando": "renunciar",
    "renunciantes": "renunciante",
    "renunciara": "renunciar",
    "renunciaram": "renunciar",
    "renunciaras": "renunciar",
    "renunciarde": "renunciar",
    "renunciardes": "renunciar",
    "renunciare": "renunciar",
    "renunciarei": "renunciar",
    "renunciareis": "renunciar",
    "renunciarem": "renunciar",
    "renunciaremos": "renunciar",
    "renunciares": "renunciar",
    "renunciaria": "renunciar",
    "renunciariam": "renunciar",
    "renunciarias": "renunciar",
    "renunciarmo": "renunciar",
    "renunciarmos": "renunciar",
    "renunciará": "renunciar",
    "renunciarás": "renunciar",
    "renunciarão": "renunciar",
    "renunciaríamos": "renunciar",
    "renunciaríeis": "renunciar",
    "renuncias": "renunciar",
    "renunciasse": "renunciar",
    "renunciassem": "renunciar",
    "renunciasses": "renunciar",
    "renunciaste": "renunciar",
    "renunciastes": "renunciar",
    "renunciatória": "renunciatório",
    "renunciatórias": "renunciatório",
    "renunciatórios": "renunciatório",
    "renunciava": "renunciar",
    "renunciavam": "renunciar",
    "renunciavas": "renunciar",
    "renunciações": "renunciação",
    "renuncie": "renunciar",
    "renunciei": "renunciar",
    "renuncieis": "renunciar",
    "renunciem": "renunciar",
    "renunciemo": "renunciar",
    "renunciemos": "renunciar",
    "renuncies": "renunciar",
    "renuncio": "renunciar",
    "renunciou": "renunciar",
    "renunciá": "renunciar",
    "renunciámo": "renunciar",
    "renunciámos": "renunciar",
    "renunciáramo": "renunciar",
    "renunciáramos": "renunciar",
    "renunciárei": "renunciar",
    "renunciáreis": "renunciar",
    "renunciásseis": "renunciar",
    "renunciássemos": "renunciar",
    "renunciávamo": "renunciar",
    "renunciávamos": "renunciar",
    "renunciávei": "renunciar",
    "renunciáveis": "renunciável",
    "renuo": "renuir",
    "renutações": "renutação",
    "renuí": "renuir",
    "renuía": "renuir",
    "renuíam": "renuir",
    "renuíamo": "renuir",
    "renuíamos": "renuir",
    "renuías": "renuir",
    "renuída": "renuir",
    "renuídas": "renuir",
    "renuído": "renuir",
    "renuídos": "renuir",
    "renuíei": "renuir",
    "renuíeis": "renuir",
    "renuímo": "renuir",
    "renuímos": "renuir",
    "renuíra": "renuir",
    "renuíram": "renuir",
    "renuíramo": "renuir",
    "renuíramos": "renuir",
    "renuíras": "renuir",
    "renuíre": "renuir",
    "renuírei": "renuir",
    "renuíreis": "renuir",
    "renuírem": "renuir",
    "renuíres": "renuir",
    "renuís": "renuir",
    "renuísse": "renuir",
    "renuísseis": "renuir",
    "renuíssem": "renuir",
    "renuíssemos": "renuir",
    "renuísses": "renuir",
    "renuíste": "renuir",
    "renuístes": "renuir",
    "renzilha": "renzilhar",
    "renzilhada": "renzilhar",
    "renzilhadas": "renzilhar",
    "renzilhado": "renzilhar",
    "renzilhados": "renzilhar",
    "renzilhai": "renzilhar",
    "renzilhais": "renzilhar",
    "renzilham": "renzilhar",
    "renzilhamo": "renzilhar",
    "renzilhamos": "renzilhar",
    "renzilhando": "renzilhar",
    "renzilhara": "renzilhar",
    "renzilharam": "renzilhar",
    "renzilharas": "renzilhar",
    "renzilhardes": "renzilhar",
    "renzilharei": "renzilhar",
    "renzilhareis": "renzilhar",
    "renzilharem": "renzilhar",
    "renzilharemos": "renzilhar",
    "renzilhares": "renzilhar",
    "renzilharia": "renzilhar",
    "renzilhariam": "renzilhar",
    "renzilharias": "renzilhar",
    "renzilharmo": "renzilhar",
    "renzilharmos": "renzilhar",
    "renzilhará": "renzilhar",
    "renzilharás": "renzilhar",
    "renzilharão": "renzilhar",
    "renzilharíamos": "renzilhar",
    "renzilharíeis": "renzilhar",
    "renzilhas": "renzilhar",
    "renzilhasse": "renzilhar",
    "renzilhassem": "renzilhar",
    "renzilhasses": "renzilhar",
    "renzilhaste": "renzilhar",
    "renzilhastes": "renzilhar",
    "renzilhava": "renzilhar",
    "renzilhavam": "renzilhar",
    "renzilhavas": "renzilhar",
    "renzilhe": "renzilhar",
    "renzilhei": "renzilhar",
    "renzilheis": "renzilhar",
    "renzilhem": "renzilhar",
    "renzilhemo": "renzilhar",
    "renzilhemos": "renzilhar",
    "renzilhes": "renzilhar",
    "renzilho": "renzilhar",
    "renzilhou": "renzilhar",
    "renzilhámo": "renzilhar",
    "renzilhámos": "renzilhar",
    "renzilháramo": "renzilhar",
    "renzilháramos": "renzilhar",
    "renzilháreis": "renzilhar",
    "renzilhásseis": "renzilhar",
    "renzilhássemos": "renzilhar",
    "renzilhávamo": "renzilhar",
    "renzilhávamos": "renzilhar",
    "renzilháveis": "renzilhar",
    "renículos": "renículo",
    "renúncias": "renúncia",
    "reocupa": "reocupar",
    "reocupada": "reocupar",
    "reocupadas": "reocupar",
    "reocupado": "reocupar",
    "reocupados": "reocupar",
    "reocupai": "reocupar",
    "reocupais": "reocupar",
    "reocupam": "reocupar",
    "reocupamo": "reocupar",
    "reocupamos": "reocupar",
    "reocupando": "reocupar",
    "reocupara": "reocupar",
    "reocuparam": "reocupar",
    "reocuparas": "reocupar",
    "reocuparde": "reocupar",
    "reocupardes": "reocupar",
    "reocupare": "reocupar",
    "reocuparei": "reocupar",
    "reocupareis": "reocupar",
    "reocuparem": "reocupar",
    "reocuparemos": "reocupar",
    "reocupares": "reocupar",
    "reocuparia": "reocupar",
    "reocupariam": "reocupar",
    "reocuparias": "reocupar",
    "reocuparmo": "reocupar",
    "reocuparmos": "reocupar",
    "reocupará": "reocupar",
    "reocuparás": "reocupar",
    "reocuparão": "reocupar",
    "reocuparíamos": "reocupar",
    "reocuparíeis": "reocupar",
    "reocupas": "reocupar",
    "reocupasse": "reocupar",
    "reocupassem": "reocupar",
    "reocupasses": "reocupar",
    "reocupaste": "reocupar",
    "reocupastes": "reocupar",
    "reocupava": "reocupar",
    "reocupavam": "reocupar",
    "reocupavas": "reocupar",
    "reocupações": "reocupação",
    "reocupe": "reocupar",
    "reocupei": "reocupar",
    "reocupeis": "reocupar",
    "reocupem": "reocupar",
    "reocupemo": "reocupar",
    "reocupemos": "reocupar",
    "reocupes": "reocupar",
    "reocupo": "reocupar",
    "reocupou": "reocupar",
    "reocupá": "reocupar",
    "reocupámo": "reocupar",
    "reocupámos": "reocupar",
    "reocupáramo": "reocupar",
    "reocupáramos": "reocupar",
    "reocupárei": "reocupar",
    "reocupáreis": "reocupar",
    "reocupásseis": "reocupar",
    "reocupássemos": "reocupar",
    "reocupávamo": "reocupar",
    "reocupávamos": "reocupar",
    "reocupávei": "reocupar",
    "reocupáveis": "reocupar",
    "reocórdios": "reocórdio",
    "reogramas": "reograma",
    "reologias": "reologia",
    "reordena": "reordenar",
    "reordenada": "reordenar",
    "reordenadas": "reordenar",
    "reordenado": "reordenar",
    "reordenados": "reordenar",
    "reordenai": "reordenar",
    "reordenais": "reordenar",
    "reordenam": "reordenar",
    "reordenamentos": "reordenamento",
    "reordenamo": "reordenar",
    "reordenamos": "reordenar",
    "reordenando": "reordenar",
    "reordenara": "reordenar",
    "reordenaram": "reordenar",
    "reordenaras": "reordenar",
    "reordenarde": "reordenar",
    "reordenardes": "reordenar",
    "reordenare": "reordenar",
    "reordenarei": "reordenar",
    "reordenareis": "reordenar",
    "reordenarem": "reordenar",
    "reordenaremos": "reordenar",
    "reordenares": "reordenar",
    "reordenaria": "reordenar",
    "reordenariam": "reordenar",
    "reordenarias": "reordenar",
    "reordenarmo": "reordenar",
    "reordenarmos": "reordenar",
    "reordenará": "reordenar",
    "reordenarás": "reordenar",
    "reordenarão": "reordenar",
    "reordenaríamos": "reordenar",
    "reordenaríeis": "reordenar",
    "reordenas": "reordenar",
    "reordenasse": "reordenar",
    "reordenassem": "reordenar",
    "reordenasses": "reordenar",
    "reordenaste": "reordenar",
    "reordenastes": "reordenar",
    "reordenava": "reordenar",
    "reordenavam": "reordenar",
    "reordenavas": "reordenar",
    "reordenações": "reordenação",
    "reordene": "reordenar",
    "reordenei": "reordenar",
    "reordeneis": "reordenar",
    "reordenem": "reordenar",
    "reordenemo": "reordenar",
    "reordenemos": "reordenar",
    "reordenes": "reordenar",
    "reordeno": "reordenar",
    "reordenou": "reordenar",
    "reordená": "reordenar",
    "reordenámo": "reordenar",
    "reordenámos": "reordenar",
    "reordenáramo": "reordenar",
    "reordenáramos": "reordenar",
    "reordenárei": "reordenar",
    "reordenáreis": "reordenar",
    "reordenásseis": "reordenar",
    "reordenássemos": "reordenar",
    "reordenávamo": "reordenar",
    "reordenávamos": "reordenar",
    "reordenávei": "reordenar",
    "reordenáveis": "reordenável",
    "reorganiza": "reorganizar",
    "reorganizada": "reorganizar",
    "reorganizadas": "reorganizar",
    "reorganizado": "reorganizar",
    "reorganizadora": "reorganizador",
    "reorganizadoras": "reorganizador",
    "reorganizadores": "reorganizador",
    "reorganizados": "reorganizar",
    "reorganizai": "reorganizar",
    "reorganizais": "reorganizar",
    "reorganizam": "reorganizar",
    "reorganizamo": "reorganizar",
    "reorganizamos": "reorganizar",
    "reorganizando": "reorganizar",
    "reorganizara": "reorganizar",
    "reorganizaram": "reorganizar",
    "reorganizaras": "reorganizar",
    "reorganizarde": "reorganizar",
    "reorganizardes": "reorganizar",
    "reorganizare": "reorganizar",
    "reorganizarei": "reorganizar",
    "reorganizareis": "reorganizar",
    "reorganizarem": "reorganizar",
    "reorganizaremos": "reorganizar",
    "reorganizares": "reorganizar",
    "reorganizaria": "reorganizar",
    "reorganizariam": "reorganizar",
    "reorganizarias": "reorganizar",
    "reorganizarmo": "reorganizar",
    "reorganizarmos": "reorganizar",
    "reorganizará": "reorganizar",
    "reorganizarás": "reorganizar",
    "reorganizarão": "reorganizar",
    "reorganizaríamos": "reorganizar",
    "reorganizaríeis": "reorganizar",
    "reorganizas": "reorganizar",
    "reorganizasse": "reorganizar",
    "reorganizassem": "reorganizar",
    "reorganizasses": "reorganizar",
    "reorganizaste": "reorganizar",
    "reorganizastes": "reorganizar",
    "reorganizava": "reorganizar",
    "reorganizavam": "reorganizar",
    "reorganizavas": "reorganizar",
    "reorganizações": "reorganização",
    "reorganize": "reorganizar",
    "reorganizei": "reorganizar",
    "reorganizeis": "reorganizar",
    "reorganizem": "reorganizar",
    "reorganizemo": "reorganizar",
    "reorganizemos": "reorganizar",
    "reorganizes": "reorganizar",
    "reorganizo": "reorganizar",
    "reorganizou": "reorganizar",
    "reorganizá": "reorganizar",
    "reorganizámo": "reorganizar",
    "reorganizámos": "reorganizar",
    "reorganizáramo": "reorganizar",
    "reorganizáramos": "reorganizar",
    "reorganizárei": "reorganizar",
    "reorganizáreis": "reorganizar",
    "reorganizásseis": "reorganizar",
    "reorganizássemos": "reorganizar",
    "reorganizávamo": "reorganizar",
    "reorganizávamos": "reorganizar",
    "reorganizávei": "reorganizar",
    "reorganizáveis": "reorganizável",
    "reorienta": "reorientar",
    "reorientada": "reorientar",
    "reorientadas": "reorientar",
    "reorientado": "reorientar",
    "reorientados": "reorientar",
    "reorientai": "reorientar",
    "reorientais": "reorientar",
    "reorientam": "reorientar",
    "reorientamo": "reorientar",
    "reorientamos": "reorientar",
    "reorientando": "reorientar",
    "reorientara": "reorientar",
    "reorientaram": "reorientar",
    "reorientaras": "reorientar",
    "reorientarde": "reorientar",
    "reorientardes": "reorientar",
    "reorientare": "reorientar",
    "reorientarei": "reorientar",
    "reorientareis": "reorientar",
    "reorientarem": "reorientar",
    "reorientaremos": "reorientar",
    "reorientares": "reorientar",
    "reorientaria": "reorientar",
    "reorientariam": "reorientar",
    "reorientarias": "reorientar",
    "reorientarmo": "reorientar",
    "reorientarmos": "reorientar",
    "reorientará": "reorientar",
    "reorientarás": "reorientar",
    "reorientarão": "reorientar",
    "reorientaríamos": "reorientar",
    "reorientaríeis": "reorientar",
    "reorientas": "reorientar",
    "reorientasse": "reorientar",
    "reorientassem": "reorientar",
    "reorientasses": "reorientar",
    "reorientaste": "reorientar",
    "reorientastes": "reorientar",
    "reorientava": "reorientar",
    "reorientavam": "reorientar",
    "reorientavas": "reorientar",
    "reorientações": "reorientação",
    "reoriente": "reorientar",
    "reorientei": "reorientar",
    "reorienteis": "reorientar",
    "reorientem": "reorientar",
    "reorientemo": "reorientar",
    "reorientemos": "reorientar",
    "reorientes": "reorientar",
    "reoriento": "reorientar",
    "reorientou": "reorientar",
    "reorientá": "reorientar",
    "reorientámo": "reorientar",
    "reorientámos": "reorientar",
    "reorientáramo": "reorientar",
    "reorientáramos": "reorientar",
    "reorientárei": "reorientar",
    "reorientáreis": "reorientar",
    "reorientásseis": "reorientar",
    "reorientássemos": "reorientar",
    "reorientávamo": "reorientar",
    "reorientávamos": "reorientar",
    "reorientávei": "reorientar",
    "reorientáveis": "reorientar",
    "reostática": "reostático",
    "reostáticas": "reostático",
    "reostáticos": "reostático",
    "reotropismos": "reotropismo",
    "reouve": "reaver",
    "reouvemo": "reaver",
    "reouvemos": "reaver",
    "reouver": "reaver",
    "reouvera": "reaver",
    "reouveram": "reaver",
    "reouveras": "reaver",
    "reouverdes": "reaver",
    "reouverem": "reaver",
    "reouveres": "reaver",
    "reouvermos": "reaver",
    "reouvesse": "reaver",
    "reouvessem": "reaver",
    "reouvesses": "reaver",
    "reouveste": "reaver",
    "reouvestes": "reaver",
    "reouvéramo": "reaver",
    "reouvéramos": "reaver",
    "reouvérei": "reaver",
    "reouvéreis": "reaver",
    "reouvésseis": "reaver",
    "reouvéssemos": "reaver",
    "repaga": "repago",
    "repagada": "repagar",
    "repagadas": "repagar",
    "repagado": "repagar",
    "repagados": "repagar",
    "repagai": "repagar",
    "repagais": "repagar",
    "repagam": "repagar",
    "repagamo": "repagar",
    "repagamos": "repagar",
    "repagando": "repagar",
    "repagara": "repagar",
    "repagaram": "repagar",
    "repagaras": "repagar",
    "repagarde": "repagar",
    "repagardes": "repagar",
    "repagare": "repagar",
    "repagarei": "repagar",
    "repagareis": "repagar",
    "repagarem": "repagar",
    "repagaremos": "repagar",
    "repagares": "repagar",
    "repagaria": "repagar",
    "repagariam": "repagar",
    "repagarias": "repagar",
    "repagarmo": "repagar",
    "repagarmos": "repagar",
    "repagará": "repagar",
    "repagarás": "repagar",
    "repagarão": "repagar",
    "repagaríamos": "repagar",
    "repagaríeis": "repagar",
    "repagas": "repago",
    "repagasse": "repagar",
    "repagassem": "repagar",
    "repagasses": "repagar",
    "repagaste": "repagar",
    "repagastes": "repagar",
    "repagava": "repagar",
    "repagavam": "repagar",
    "repagavas": "repagar",
    "repagina": "repaginar",
    "repaginada": "repaginar",
    "repaginadas": "repaginar",
    "repaginado": "repaginar",
    "repaginados": "repaginar",
    "repaginai": "repaginar",
    "repaginais": "repaginar",
    "repaginam": "repaginar",
    "repaginamentos": "repaginamento",
    "repaginamo": "repaginar",
    "repaginamos": "repaginar",
    "repaginando": "repaginar",
    "repaginara": "repaginar",
    "repaginaram": "repaginar",
    "repaginaras": "repaginar",
    "repaginarde": "repaginar",
    "repaginardes": "repaginar",
    "repaginare": "repaginar",
    "repaginarei": "repaginar",
    "repaginareis": "repaginar",
    "repaginarem": "repaginar",
    "repaginaremos": "repaginar",
    "repaginares": "repaginar",
    "repaginaria": "repaginar",
    "repaginariam": "repaginar",
    "repaginarias": "repaginar",
    "repaginarmo": "repaginar",
    "repaginarmos": "repaginar",
    "repaginará": "repaginar",
    "repaginarás": "repaginar",
    "repaginarão": "repaginar",
    "repaginaríamos": "repaginar",
    "repaginaríeis": "repaginar",
    "repaginas": "repaginar",
    "repaginasse": "repaginar",
    "repaginassem": "repaginar",
    "repaginasses": "repaginar",
    "repaginaste": "repaginar",
    "repaginastes": "repaginar",
    "repaginava": "repaginar",
    "repaginavam": "repaginar",
    "repaginavas": "repaginar",
    "repaginações": "repaginação",
    "repagine": "repaginar",
    "repaginei": "repaginar",
    "repagineis": "repaginar",
    "repaginem": "repaginar",
    "repaginemo": "repaginar",
    "repaginemos": "repaginar",
    "repagines": "repaginar",
    "repagino": "repaginar",
    "repaginou": "repaginar",
    "repaginá": "repaginar",
    "repaginámo": "repaginar",
    "repaginámos": "repaginar",
    "repagináramo": "repaginar",
    "repagináramos": "repaginar",
    "repaginárei": "repaginar",
    "repagináreis": "repaginar",
    "repaginásseis": "repaginar",
    "repaginássemos": "repaginar",
    "repaginávamo": "repaginar",
    "repaginávamos": "repaginar",
    "repaginávei": "repaginar",
    "repagináveis": "repaginável",
    "repago": "repagar",
    "repagos": "repago",
    "repagou": "repagar",
    "repague": "repagar",
    "repaguei": "repagar",
    "repagueis": "repagar",
    "repaguem": "repagar",
    "repaguemo": "repagar",
    "repaguemos": "repagar",
    "repagues": "repagar",
    "repagá": "repagar",
    "repagámo": "repagar",
    "repagámos": "repagar",
    "repagáramo": "repagar",
    "repagáramos": "repagar",
    "repagárei": "repagar",
    "repagáreis": "repagar",
    "repagásseis": "repagar",
    "repagássemos": "repagar",
    "repagávamo": "repagar",
    "repagávamos": "repagar",
    "repagávei": "repagar",
    "repagáveis": "repagar",
    "repara": "reparar",
    "reparabilidades": "reparabilidade",
    "reparada": "reparar",
    "reparadas": "reparar",
    "reparadeira": "reparador",
    "reparadeiras": "reparador",
    "reparado": "reparar",
    "reparadora": "reparador",
    "reparadoras": "reparador",
    "reparadores": "reparador",
    "reparados": "reparar",
    "reparai": "reparar",
    "reparais": "reparar",
    "reparam": "reparar",
    "reparamo": "reparar",
    "reparamos": "reparar",
    "reparando": "reparar",
    "reparara": "reparar",
    "repararam": "reparar",
    "repararas": "reparar",
    "repararde": "reparar",
    "reparardes": "reparar",
    "reparare": "reparar",
    "repararei": "reparar",
    "reparareis": "reparar",
    "repararem": "reparar",
    "repararemos": "reparar",
    "reparares": "reparar",
    "repararia": "reparar",
    "reparariam": "reparar",
    "repararias": "reparar",
    "repararmo": "reparar",
    "repararmos": "reparar",
    "reparará": "reparar",
    "repararás": "reparar",
    "repararão": "reparar",
    "repararíamos": "reparar",
    "repararíeis": "reparar",
    "reparas": "reparar",
    "reparasse": "reparar",
    "reparassem": "reparar",
    "reparasses": "reparar",
    "reparaste": "reparar",
    "reparastes": "reparar",
    "reparatória": "reparatório",
    "reparatórias": "reparatório",
    "reparatórios": "reparatório",
    "reparava": "reparar",
    "reparavam": "reparar",
    "reparavas": "reparar",
    "reparações": "reparação",
    "repare": "reparar",
    "reparei": "reparar",
    "repareis": "reparar",
    "reparem": "reparar",
    "reparemo": "reparar",
    "reparemos": "reparar",
    "repares": "reparar",
    "reparo": "reparar",
    "reparos": "reparo",
    "reparou": "reparar",
    "reparta": "repartir",
    "repartais": "repartir",
    "repartam": "repartir",
    "repartamo": "repartir",
    "repartamos": "repartir",
    "repartas": "repartir",
    "reparte": "repartir",
    "repartem": "repartir",
    "repartes": "repartir",
    "reparti": "repartir",
    "repartia": "repartir",
    "repartiam": "repartir",
    "repartias": "repartir",
    "repartida": "repartir",
    "repartidas": "repartir",
    "repartideira": "repartidor",
    "repartideiras": "repartidor",
    "repartido": "repartir",
    "repartidores": "repartidor",
    "repartidos": "repartir",
    "repartimentos": "repartimento",
    "repartimo": "repartir",
    "repartimos": "repartir",
    "repartindo": "repartir",
    "repartira": "repartir",
    "repartiram": "repartir",
    "repartiras": "repartir",
    "repartirde": "repartir",
    "repartirdes": "repartir",
    "repartire": "repartir",
    "repartirei": "repartir",
    "repartireis": "repartir",
    "repartirem": "repartir",
    "repartiremos": "repartir",
    "repartires": "repartir",
    "repartiria": "repartir",
    "repartiriam": "repartir",
    "repartirias": "repartir",
    "repartirmo": "repartir",
    "repartirmos": "repartir",
    "repartirá": "repartir",
    "repartirás": "repartir",
    "repartirão": "repartir",
    "repartiríamos": "repartir",
    "repartiríeis": "repartir",
    "repartis": "repartir",
    "repartisse": "repartir",
    "repartissem": "repartir",
    "repartisses": "repartir",
    "repartiste": "repartir",
    "repartistes": "repartir",
    "repartitiva": "repartitivo",
    "repartitivas": "repartitivo",
    "repartitivos": "repartitivo",
    "repartiu": "repartir",
    "repartições": "repartição",
    "reparto": "repartir",
    "repartíamo": "repartir",
    "repartíamos": "repartir",
    "repartíei": "repartir",
    "repartíeis": "repartir",
    "repartíramo": "repartir",
    "repartíramos": "repartir",
    "repartírei": "repartir",
    "repartíreis": "repartir",
    "repartísseis": "repartir",
    "repartíssemos": "repartir",
    "repartíveis": "repartível",
    "repará": "reparar",
    "reparámo": "reparar",
    "reparámos": "reparar",
    "reparáramo": "reparar",
    "reparáramos": "reparar",
    "reparárei": "reparar",
    "reparáreis": "reparar",
    "reparásseis": "reparar",
    "reparássemos": "reparar",
    "reparávamo": "reparar",
    "reparávamos": "reparar",
    "reparávei": "reparar",
    "reparáveis": "reparável",
    "repas": "repa",
    "repassa": "repassar",
    "repassada": "repassar",
    "repassadas": "repassar",
    "repassadeiras": "repassadeira",
    "repassado": "repassar",
    "repassados": "repassar",
    "repassai": "repassar",
    "repassais": "repassar",
    "repassam": "repassar",
    "repassamo": "repassar",
    "repassamos": "repassar",
    "repassando": "repassar",
    "repassara": "repassar",
    "repassaram": "repassar",
    "repassaras": "repassar",
    "repassarde": "repassar",
    "repassardes": "repassar",
    "repassare": "repassar",
    "repassarei": "repassar",
    "repassareis": "repassar",
    "repassarem": "repassar",
    "repassaremos": "repassar",
    "repassares": "repassar",
    "repassaria": "repassar",
    "repassariam": "repassar",
    "repassarias": "repassar",
    "repassarmo": "repassar",
    "repassarmos": "repassar",
    "repassará": "repassar",
    "repassarás": "repassar",
    "repassarão": "repassar",
    "repassaríamos": "repassar",
    "repassaríeis": "repassar",
    "repassas": "repassar",
    "repassasse": "repassar",
    "repassassem": "repassar",
    "repassasses": "repassar",
    "repassaste": "repassar",
    "repassastes": "repassar",
    "repassava": "repassar",
    "repassavam": "repassar",
    "repassavas": "repassar",
    "repasse": "repassar",
    "repassei": "repassar",
    "repasseis": "repassar",
    "repassem": "repassar",
    "repassemo": "repassar",
    "repassemos": "repassar",
    "repasses": "repasse",
    "repasso": "repasse",
    "repassos": "repasso",
    "repassou": "repassar",
    "repassá": "repassar",
    "repassámo": "repassar",
    "repassámos": "repassar",
    "repassáramo": "repassar",
    "repassáramos": "repassar",
    "repassárei": "repassar",
    "repassáreis": "repassar",
    "repassásseis": "repassar",
    "repassássemos": "repassar",
    "repassávamo": "repassar",
    "repassávamos": "repassar",
    "repassávei": "repassar",
    "repassáveis": "repassar",
    "repasta": "repastar",
    "repastada": "repastar",
    "repastadas": "repastar",
    "repastado": "repastar",
    "repastados": "repastar",
    "repastai": "repastar",
    "repastais": "repastar",
    "repastam": "repastar",
    "repastamo": "repastar",
    "repastamos": "repastar",
    "repastando": "repastar",
    "repastara": "repastar",
    "repastaram": "repastar",
    "repastaras": "repastar",
    "repastarde": "repastar",
    "repastardes": "repastar",
    "repastare": "repastar",
    "repastarei": "repastar",
    "repastareis": "repastar",
    "repastarem": "repastar",
    "repastaremos": "repastar",
    "repastares": "repastar",
    "repastaria": "repastar",
    "repastariam": "repastar",
    "repastarias": "repastar",
    "repastarmo": "repastar",
    "repastarmos": "repastar",
    "repastará": "repastar",
    "repastarás": "repastar",
    "repastarão": "repastar",
    "repastaríamos": "repastar",
    "repastaríeis": "repastar",
    "repastas": "repastar",
    "repastasse": "repastar",
    "repastassem": "repastar",
    "repastasses": "repastar",
    "repastaste": "repastar",
    "repastastes": "repastar",
    "repastava": "repastar",
    "repastavam": "repastar",
    "repastavas": "repastar",
    "repaste": "repastar",
    "repastei": "repastar",
    "repasteis": "repastar",
    "repastem": "repastar",
    "repastemo": "repastar",
    "repastemos": "repastar",
    "repastes": "repastar",
    "repasto": "repastar",
    "repastos": "repasto",
    "repastou": "repastar",
    "repastá": "repastar",
    "repastámo": "repastar",
    "repastámos": "repastar",
    "repastáramo": "repastar",
    "repastáramos": "repastar",
    "repastárei": "repastar",
    "repastáreis": "repastar",
    "repastásseis": "repastar",
    "repastássemos": "repastar",
    "repastávamo": "repastar",
    "repastávamos": "repastar",
    "repastávei": "repastar",
    "repastáveis": "repastar",
    "repatana": "repatanar",
    "repatanada": "repatanar",
    "repatanadas": "repatanar",
    "repatanado": "repatanar",
    "repatanados": "repatanar",
    "repatanai": "repatanar",
    "repatanais": "repatanar",
    "repatanam": "repatanar",
    "repatanamo": "repatanar",
    "repatanamos": "repatanar",
    "repatanando": "repatanar",
    "repatanara": "repatanar",
    "repatanaram": "repatanar",
    "repatanaras": "repatanar",
    "repatanarde": "repatanar",
    "repatanardes": "repatanar",
    "repatanare": "repatanar",
    "repatanarei": "repatanar",
    "repatanareis": "repatanar",
    "repatanarem": "repatanar",
    "repatanaremos": "repatanar",
    "repatanares": "repatanar",
    "repatanaria": "repatanar",
    "repatanariam": "repatanar",
    "repatanarias": "repatanar",
    "repatanarmo": "repatanar",
    "repatanarmos": "repatanar",
    "repatanará": "repatanar",
    "repatanarás": "repatanar",
    "repatanarão": "repatanar",
    "repatanaríamos": "repatanar",
    "repatanaríeis": "repatanar",
    "repatanas": "repatanar",
    "repatanasse": "repatanar",
    "repatanassem": "repatanar",
    "repatanasses": "repatanar",
    "repatanaste": "repatanar",
    "repatanastes": "repatanar",
    "repatanava": "repatanar",
    "repatanavam": "repatanar",
    "repatanavas": "repatanar",
    "repatane": "repatanar",
    "repatanei": "repatanar",
    "repataneis": "repatanar",
    "repatanem": "repatanar",
    "repatanemo": "repatanar",
    "repatanemos": "repatanar",
    "repatanes": "repatanar",
    "repatano": "repatanar",
    "repatanou": "repatanar",
    "repataná": "repatanar",
    "repatanámo": "repatanar",
    "repatanámos": "repatanar",
    "repatanáramo": "repatanar",
    "repatanáramos": "repatanar",
    "repatanárei": "repatanar",
    "repatanáreis": "repatanar",
    "repatanásseis": "repatanar",
    "repatanássemos": "repatanar",
    "repatanávamo": "repatanar",
    "repatanávamos": "repatanar",
    "repatanávei": "repatanar",
    "repatanáveis": "repatanar",
    "repatria": "repatriar",
    "repatriada": "repatriar",
    "repatriadas": "repatriar",
    "repatriado": "repatriar",
    "repatriadora": "repatriador",
    "repatriadoras": "repatriador",
    "repatriadores": "repatriador",
    "repatriados": "repatriar",
    "repatriai": "repatriar",
    "repatriais": "repatriar",
    "repatriam": "repatriar",
    "repatriamentos": "repatriamento",
    "repatriamo": "repatriar",
    "repatriamos": "repatriar",
    "repatriando": "repatriar",
    "repatriara": "repatriar",
    "repatriaram": "repatriar",
    "repatriaras": "repatriar",
    "repatriarde": "repatriar",
    "repatriardes": "repatriar",
    "repatriare": "repatriar",
    "repatriarei": "repatriar",
    "repatriareis": "repatriar",
    "repatriarem": "repatriar",
    "repatriaremos": "repatriar",
    "repatriares": "repatriar",
    "repatriaria": "repatriar",
    "repatriariam": "repatriar",
    "repatriarias": "repatriar",
    "repatriarmo": "repatriar",
    "repatriarmos": "repatriar",
    "repatriará": "repatriar",
    "repatriarás": "repatriar",
    "repatriarão": "repatriar",
    "repatriaríamos": "repatriar",
    "repatriaríeis": "repatriar",
    "repatrias": "repatriar",
    "repatriasse": "repatriar",
    "repatriassem": "repatriar",
    "repatriasses": "repatriar",
    "repatriaste": "repatriar",
    "repatriastes": "repatriar",
    "repatriava": "repatriar",
    "repatriavam": "repatriar",
    "repatriavas": "repatriar",
    "repatriações": "repatriação",
    "repatrie": "repatriar",
    "repatriei": "repatriar",
    "repatrieis": "repatriar",
    "repatriem": "repatriar",
    "repatriemo": "repatriar",
    "repatriemos": "repatriar",
    "repatries": "repatriar",
    "repatrio": "repatriar",
    "repatriou": "repatriar",
    "repatriá": "repatriar",
    "repatriámo": "repatriar",
    "repatriámos": "repatriar",
    "repatriáramo": "repatriar",
    "repatriáramos": "repatriar",
    "repatriárei": "repatriar",
    "repatriáreis": "repatriar",
    "repatriásseis": "repatriar",
    "repatriássemos": "repatriar",
    "repatriávamo": "repatriar",
    "repatriávamos": "repatriar",
    "repatriávei": "repatriar",
    "repatriáveis": "repatriável",
    "repavimentações": "repavimentação",
    "repega": "repegar",
    "repegada": "repegar",
    "repegadas": "repegar",
    "repegado": "repegar",
    "repegados": "repegar",
    "repegai": "repegar",
    "repegais": "repegar",
    "repegam": "repegar",
    "repegamo": "repegar",
    "repegamos": "repegar",
    "repegando": "repegar",
    "repegara": "repegar",
    "repegaram": "repegar",
    "repegaras": "repegar",
    "repegarde": "repegar",
    "repegardes": "repegar",
    "repegare": "repegar",
    "repegarei": "repegar",
    "repegareis": "repegar",
    "repegarem": "repegar",
    "repegaremos": "repegar",
    "repegares": "repegar",
    "repegaria": "repegar",
    "repegariam": "repegar",
    "repegarias": "repegar",
    "repegarmo": "repegar",
    "repegarmos": "repegar",
    "repegará": "repegar",
    "repegarás": "repegar",
    "repegarão": "repegar",
    "repegaríamos": "repegar",
    "repegaríeis": "repegar",
    "repegas": "repegar",
    "repegasse": "repegar",
    "repegassem": "repegar",
    "repegasses": "repegar",
    "repegaste": "repegar",
    "repegastes": "repegar",
    "repegava": "repegar",
    "repegavam": "repegar",
    "repegavas": "repegar",
    "repego": "repegar",
    "repegou": "repegar",
    "repegue": "repegar",
    "repeguei": "repegar",
    "repegueis": "repegar",
    "repeguem": "repegar",
    "repeguemo": "repegar",
    "repeguemos": "repegar",
    "repegues": "repegar",
    "repegá": "repegar",
    "repegámo": "repegar",
    "repegámos": "repegar",
    "repegáramo": "repegar",
    "repegáramos": "repegar",
    "repegárei": "repegar",
    "repegáreis": "repegar",
    "repegásseis": "repegar",
    "repegássemos": "repegar",
    "repegávamo": "repegar",
    "repegávamos": "repegar",
    "repegávei": "repegar",
    "repegáveis": "repegar",
    "repela": "repelar",
    "repelada": "repelar",
    "repeladas": "repelar",
    "repelado": "repelar",
    "repelados": "repelar",
    "repelai": "repelar",
    "repelais": "repelar",
    "repelam": "repelar",
    "repelamo": "repelar",
    "repelamos": "repelar",
    "repelando": "repelar",
    "repelara": "repelar",
    "repelaram": "repelar",
    "repelaras": "repelar",
    "repelarde": "repelar",
    "repelardes": "repelar",
    "repelare": "repelar",
    "repelarei": "repelar",
    "repelareis": "repelar",
    "repelarem": "repelar",
    "repelaremos": "repelar",
    "repelares": "repelar",
    "repelaria": "repelar",
    "repelariam": "repelar",
    "repelarias": "repelar",
    "repelarmo": "repelar",
    "repelarmos": "repelar",
    "repelará": "repelar",
    "repelarás": "repelar",
    "repelarão": "repelar",
    "repelaríamos": "repelar",
    "repelaríeis": "repelar",
    "repelas": "repelar",
    "repelasse": "repelar",
    "repelassem": "repelar",
    "repelasses": "repelar",
    "repelaste": "repelar",
    "repelastes": "repelar",
    "repelava": "repelar",
    "repelavam": "repelar",
    "repelavas": "repelar",
    "repele": "repelir",
    "repelei": "repelar",
    "repeleis": "repelar",
    "repelem": "repelir",
    "repelemo": "repelar",
    "repelemos": "repelar",
    "repelentes": "repelente",
    "repeles": "repelir",
    "repeli": "repelir",
    "repelia": "repelir",
    "repeliam": "repelir",
    "repelias": "repelir",
    "repelida": "repelir",
    "repelidas": "repelir",
    "repelido": "repelir",
    "repelidos": "repelir",
    "repelimo": "repelir",
    "repelimos": "repelir",
    "repelindo": "repelir",
    "repelira": "repelir",
    "repeliram": "repelir",
    "repeliras": "repelir",
    "repelirde": "repelir",
    "repelirdes": "repelir",
    "repelire": "repelir",
    "repelirei": "repelir",
    "repelireis": "repelir",
    "repelirem": "repelir",
    "repeliremos": "repelir",
    "repelires": "repelir",
    "repeliria": "repelir",
    "repeliriam": "repelir",
    "repelirias": "repelir",
    "repelirmo": "repelir",
    "repelirmos": "repelir",
    "repelirá": "repelir",
    "repelirás": "repelir",
    "repelirão": "repelir",
    "repeliríamos": "repelir",
    "repeliríeis": "repelir",
    "repelis": "repelir",
    "repelisse": "repelir",
    "repelissem": "repelir",
    "repelisses": "repelir",
    "repeliste": "repelir",
    "repelistes": "repelir",
    "repeliu": "repelir",
    "repelo": "repelar",
    "repelos": "repelo",
    "repelou": "repelar",
    "repelá": "repelar",
    "repelámo": "repelar",
    "repelámos": "repelar",
    "repeláramo": "repelar",
    "repeláramos": "repelar",
    "repelárei": "repelar",
    "repeláreis": "repelar",
    "repelásseis": "repelar",
    "repelássemos": "repelar",
    "repelávamo": "repelar",
    "repelávamos": "repelar",
    "repelávei": "repelar",
    "repeláveis": "repelar",
    "repelências": "repelência",
    "repelíamo": "repelir",
    "repelíamos": "repelir",
    "repelíei": "repelir",
    "repelíeis": "repelir",
    "repelíramo": "repelir",
    "repelíramos": "repelir",
    "repelírei": "repelir",
    "repelíreis": "repelir",
    "repelísseis": "repelir",
    "repelíssemos": "repelir",
    "repelões": "repelão",
    "repenalizações": "repenalização",
    "repenica": "repenicar",
    "repenicada": "repenicar",
    "repenicadas": "repenicar",
    "repenicado": "repenicar",
    "repenicados": "repenicar",
    "repenicai": "repenicar",
    "repenicais": "repenicar",
    "repenicam": "repenicar",
    "repenicamo": "repenicar",
    "repenicamos": "repenicar",
    "repenicando": "repenicar",
    "repenicara": "repenicar",
    "repenicaram": "repenicar",
    "repenicaras": "repenicar",
    "repenicarde": "repenicar",
    "repenicardes": "repenicar",
    "repenicare": "repenicar",
    "repenicarei": "repenicar",
    "repenicareis": "repenicar",
    "repenicarem": "repenicar",
    "repenicaremos": "repenicar",
    "repenicares": "repenicar",
    "repenicaria": "repenicar",
    "repenicariam": "repenicar",
    "repenicarias": "repenicar",
    "repenicarmo": "repenicar",
    "repenicarmos": "repenicar",
    "repenicará": "repenicar",
    "repenicarás": "repenicar",
    "repenicarão": "repenicar",
    "repenicaríamos": "repenicar",
    "repenicaríeis": "repenicar",
    "repenicas": "repenicar",
    "repenicasse": "repenicar",
    "repenicassem": "repenicar",
    "repenicasses": "repenicar",
    "repenicaste": "repenicar",
    "repenicastes": "repenicar",
    "repenicava": "repenicar",
    "repenicavam": "repenicar",
    "repenicavas": "repenicar",
    "repenico": "repenicar",
    "repenicou": "repenicar",
    "repenicá": "repenicar",
    "repenicámo": "repenicar",
    "repenicámos": "repenicar",
    "repenicáramo": "repenicar",
    "repenicáramos": "repenicar",
    "repenicárei": "repenicar",
    "repenicáreis": "repenicar",
    "repenicásseis": "repenicar",
    "repenicássemos": "repenicar",
    "repenicávamo": "repenicar",
    "repenicávamos": "repenicar",
    "repenicávei": "repenicar",
    "repenicáveis": "repenicar",
    "repenique": "repenicar",
    "repeniquei": "repenicar",
    "repeniqueis": "repenicar",
    "repeniquem": "repenicar",
    "repeniquemo": "repenicar",
    "repeniquemos": "repenicar",
    "repeniques": "repenique",
    "repensa": "repensar",
    "repensada": "repensar",
    "repensadas": "repensar",
    "repensado": "repensar",
    "repensados": "repensar",
    "repensai": "repensar",
    "repensais": "repensar",
    "repensam": "repensar",
    "repensamo": "repensar",
    "repensamos": "repensar",
    "repensando": "repensar",
    "repensara": "repensar",
    "repensaram": "repensar",
    "repensaras": "repensar",
    "repensarde": "repensar",
    "repensardes": "repensar",
    "repensare": "repensar",
    "repensarei": "repensar",
    "repensareis": "repensar",
    "repensarem": "repensar",
    "repensaremos": "repensar",
    "repensares": "repensar",
    "repensaria": "repensar",
    "repensariam": "repensar",
    "repensarias": "repensar",
    "repensarmo": "repensar",
    "repensarmos": "repensar",
    "repensará": "repensar",
    "repensarás": "repensar",
    "repensarão": "repensar",
    "repensaríamos": "repensar",
    "repensaríeis": "repensar",
    "repensas": "repensar",
    "repensasse": "repensar",
    "repensassem": "repensar",
    "repensasses": "repensar",
    "repensaste": "repensar",
    "repensastes": "repensar",
    "repensava": "repensar",
    "repensavam": "repensar",
    "repensavas": "repensar",
    "repense": "repensar",
    "repensei": "repensar",
    "repenseis": "repensar",
    "repensem": "repensar",
    "repensemo": "repensar",
    "repensemos": "repensar",
    "repenses": "repensar",
    "repenso": "repensar",
    "repensou": "repensar",
    "repensá": "repensar",
    "repensámo": "repensar",
    "repensámos": "repensar",
    "repensáramo": "repensar",
    "repensáramos": "repensar",
    "repensárei": "repensar",
    "repensáreis": "repensar",
    "repensásseis": "repensar",
    "repensássemos": "repensar",
    "repensávamo": "repensar",
    "repensávamos": "repensar",
    "repensávei": "repensar",
    "repensáveis": "repensável",
    "repentes": "repente",
    "repentezinho": "repente",
    "repentezinhos": "repente",
    "repentezito": "repente",
    "repentezitos": "repente",
    "repentina": "repentino",
    "repentinas": "repentino",
    "repentinos": "repentino",
    "repentinosa": "repentinoso",
    "repentinosas": "repentinoso",
    "repentinosos": "repentinoso",
    "repentismos": "repentismo",
    "repentistas": "repentista",
    "repercorra": "repercorrer",
    "repercorrais": "repercorrer",
    "repercorram": "repercorrer",
    "repercorramo": "repercorrer",
    "repercorramos": "repercorrer",
    "repercorras": "repercorrer",
    "repercorre": "repercorrer",
    "repercorrei": "repercorrer",
    "repercorreis": "repercorrer",
    "repercorrem": "repercorrer",
    "repercorremo": "repercorrer",
    "repercorremos": "repercorrer",
    "repercorrendo": "repercorrer",
    "repercorrera": "repercorrer",
    "repercorreram": "repercorrer",
    "repercorreras": "repercorrer",
    "repercorrerde": "repercorrer",
    "repercorrerdes": "repercorrer",
    "repercorrere": "repercorrer",
    "repercorrerei": "repercorrer",
    "repercorrereis": "repercorrer",
    "repercorrerem": "repercorrer",
    "repercorreremos": "repercorrer",
    "repercorreres": "repercorrer",
    "repercorreria": "repercorrer",
    "repercorreriam": "repercorrer",
    "repercorrerias": "repercorrer",
    "repercorrermo": "repercorrer",
    "repercorrermos": "repercorrer",
    "repercorrerá": "repercorrer",
    "repercorrerás": "repercorrer",
    "repercorrerão": "repercorrer",
    "repercorreríamos": "repercorrer",
    "repercorreríeis": "repercorrer",
    "repercorres": "repercorrer",
    "repercorresse": "repercorrer",
    "repercorressem": "repercorrer",
    "repercorresses": "repercorrer",
    "repercorreste": "repercorrer",
    "repercorrestes": "repercorrer",
    "repercorreu": "repercorrer",
    "repercorri": "repercorrer",
    "repercorria": "repercorrer",
    "repercorriam": "repercorrer",
    "repercorrias": "repercorrer",
    "repercorrida": "repercorrer",
    "repercorridas": "repercorrer",
    "repercorrido": "repercorrer",
    "repercorridos": "repercorrer",
    "repercorro": "repercorrer",
    "repercorrê": "repercorrer",
    "repercorrêramo": "repercorrer",
    "repercorrêramos": "repercorrer",
    "repercorrêrei": "repercorrer",
    "repercorrêreis": "repercorrer",
    "repercorrêsseis": "repercorrer",
    "repercorrêssemos": "repercorrer",
    "repercorríamo": "repercorrer",
    "repercorríamos": "repercorrer",
    "repercorríei": "repercorrer",
    "repercorríeis": "repercorrer",
    "repercussiva": "repercussivo",
    "repercussivas": "repercussivo",
    "repercussivos": "repercussivo",
    "repercussos": "repercusso",
    "repercussões": "repercussão",
    "repercuta": "repercutir",
    "repercutais": "repercutir",
    "repercutam": "repercutir",
    "repercutamo": "repercutir",
    "repercutamos": "repercutir",
    "repercutas": "repercutir",
    "repercute": "repercutir",
    "repercutem": "repercutir",
    "repercutentes": "repercutente",
    "repercutes": "repercutir",
    "repercuti": "repercutir",
    "repercutia": "repercutir",
    "repercutiam": "repercutir",
    "repercutias": "repercutir",
    "repercutida": "repercutir",
    "repercutidas": "repercutir",
    "repercutido": "repercutir",
    "repercutidos": "repercutir",
    "repercutimo": "repercutir",
    "repercutimos": "repercutir",
    "repercutindo": "repercutir",
    "repercutira": "repercutir",
    "repercutiram": "repercutir",
    "repercutiras": "repercutir",
    "repercutirde": "repercutir",
    "repercutirdes": "repercutir",
    "repercutire": "repercutir",
    "repercutirei": "repercutir",
    "repercutireis": "repercutir",
    "repercutirem": "repercutir",
    "repercutiremos": "repercutir",
    "repercutires": "repercutir",
    "repercutiria": "repercutir",
    "repercutiriam": "repercutir",
    "repercutirias": "repercutir",
    "repercutirmo": "repercutir",
    "repercutirmos": "repercutir",
    "repercutirá": "repercutir",
    "repercutirás": "repercutir",
    "repercutirão": "repercutir",
    "repercutiríamos": "repercutir",
    "repercutiríeis": "repercutir",
    "repercutis": "repercutir",
    "repercutisse": "repercutir",
    "repercutissem": "repercutir",
    "repercutisses": "repercutir",
    "repercutiste": "repercutir",
    "repercutistes": "repercutir",
    "repercutiu": "repercutir",
    "repercuto": "repercutir",
    "repercutíamo": "repercutir",
    "repercutíamos": "repercutir",
    "repercutíei": "repercutir",
    "repercutíeis": "repercutir",
    "repercutíramo": "repercutir",
    "repercutíramos": "repercutir",
    "repercutírei": "repercutir",
    "repercutíreis": "repercutir",
    "repercutísseis": "repercutir",
    "repercutíssemos": "repercutir",
    "repergunta": "reperguntar",
    "reperguntada": "reperguntar",
    "reperguntadas": "reperguntar",
    "reperguntado": "reperguntar",
    "reperguntados": "reperguntar",
    "reperguntai": "reperguntar",
    "reperguntais": "reperguntar",
    "reperguntam": "reperguntar",
    "reperguntamo": "reperguntar",
    "reperguntamos": "reperguntar",
    "reperguntando": "reperguntar",
    "reperguntara": "reperguntar",
    "reperguntaram": "reperguntar",
    "reperguntaras": "reperguntar",
    "reperguntarde": "reperguntar",
    "reperguntardes": "reperguntar",
    "reperguntare": "reperguntar",
    "reperguntarei": "reperguntar",
    "reperguntareis": "reperguntar",
    "reperguntarem": "reperguntar",
    "reperguntaremos": "reperguntar",
    "reperguntares": "reperguntar",
    "reperguntaria": "reperguntar",
    "reperguntariam": "reperguntar",
    "reperguntarias": "reperguntar",
    "reperguntarmo": "reperguntar",
    "reperguntarmos": "reperguntar",
    "reperguntará": "reperguntar",
    "reperguntarás": "reperguntar",
    "reperguntarão": "reperguntar",
    "reperguntaríamos": "reperguntar",
    "reperguntaríeis": "reperguntar",
    "reperguntas": "reperguntar",
    "reperguntasse": "reperguntar",
    "reperguntassem": "reperguntar",
    "reperguntasses": "reperguntar",
    "reperguntaste": "reperguntar",
    "reperguntastes": "reperguntar",
    "reperguntava": "reperguntar",
    "reperguntavam": "reperguntar",
    "reperguntavas": "reperguntar",
    "repergunte": "reperguntar",
    "reperguntei": "reperguntar",
    "repergunteis": "reperguntar",
    "reperguntem": "reperguntar",
    "reperguntemo": "reperguntar",
    "reperguntemos": "reperguntar",
    "reperguntes": "reperguntar",
    "repergunto": "reperguntar",
    "reperguntou": "reperguntar",
    "reperguntá": "reperguntar",
    "reperguntámo": "reperguntar",
    "reperguntámos": "reperguntar",
    "reperguntáramo": "reperguntar",
    "reperguntáramos": "reperguntar",
    "reperguntárei": "reperguntar",
    "reperguntáreis": "reperguntar",
    "reperguntásseis": "reperguntar",
    "reperguntássemos": "reperguntar",
    "reperguntávamo": "reperguntar",
    "reperguntávamos": "reperguntar",
    "reperguntávei": "reperguntar",
    "reperguntáveis": "reperguntar",
    "repertórios": "repertório",
    "repesa": "repeso",
    "repesada": "repesar",
    "repesadas": "repesar",
    "repesado": "repesar",
    "repesadora": "repesador",
    "repesadoras": "repesador",
    "repesadores": "repesador",
    "repesados": "repesar",
    "repesai": "repesar",
    "repesais": "repesar",
    "repesam": "repesar",
    "repesamo": "repesar",
    "repesamos": "repesar",
    "repesando": "repesar",
    "repesara": "repesar",
    "repesaram": "repesar",
    "repesaras": "repesar",
    "repesarde": "repesar",
    "repesardes": "repesar",
    "repesare": "repesar",
    "repesarei": "repesar",
    "repesareis": "repesar",
    "repesarem": "repesar",
    "repesaremos": "repesar",
    "repesares": "repesar",
    "repesaria": "repesar",
    "repesariam": "repesar",
    "repesarias": "repesar",
    "repesarmo": "repesar",
    "repesarmos": "repesar",
    "repesará": "repesar",
    "repesarás": "repesar",
    "repesarão": "repesar",
    "repesaríamos": "repesar",
    "repesaríeis": "repesar",
    "repesas": "repeso",
    "repesasse": "repesar",
    "repesassem": "repesar",
    "repesasses": "repesar",
    "repesaste": "repesar",
    "repesastes": "repesar",
    "repesava": "repesar",
    "repesavam": "repesar",
    "repesavas": "repesar",
    "repesca": "repescar",
    "repescada": "repescar",
    "repescadas": "repescar",
    "repescado": "repescar",
    "repescados": "repescar",
    "repescagens": "repescagem",
    "repescai": "repescar",
    "repescais": "repescar",
    "repescam": "repescar",
    "repescamo": "repescar",
    "repescamos": "repescar",
    "repescando": "repescar",
    "repescara": "repescar",
    "repescaram": "repescar",
    "repescaras": "repescar",
    "repescarde": "repescar",
    "repescardes": "repescar",
    "repescare": "repescar",
    "repescarei": "repescar",
    "repescareis": "repescar",
    "repescarem": "repescar",
    "repescaremos": "repescar",
    "repescares": "repescar",
    "repescaria": "repescar",
    "repescariam": "repescar",
    "repescarias": "repescar",
    "repescarmo": "repescar",
    "repescarmos": "repescar",
    "repescará": "repescar",
    "repescarás": "repescar",
    "repescarão": "repescar",
    "repescaríamos": "repescar",
    "repescaríeis": "repescar",
    "repescas": "repescar",
    "repescasse": "repescar",
    "repescassem": "repescar",
    "repescasses": "repescar",
    "repescaste": "repescar",
    "repescastes": "repescar",
    "repescava": "repescar",
    "repescavam": "repescar",
    "repescavas": "repescar",
    "repesco": "repescar",
    "repescou": "repescar",
    "repescá": "repescar",
    "repescámo": "repescar",
    "repescámos": "repescar",
    "repescáramo": "repescar",
    "repescáramos": "repescar",
    "repescárei": "repescar",
    "repescáreis": "repescar",
    "repescásseis": "repescar",
    "repescássemos": "repescar",
    "repescávamo": "repescar",
    "repescávamos": "repescar",
    "repescávei": "repescar",
    "repescáveis": "repescar",
    "repese": "repesar",
    "repesei": "repesar",
    "repeseis": "repesar",
    "repesem": "repesar",
    "repesemo": "repesar",
    "repesemos": "repesar",
    "repeses": "repesar",
    "repeso": "repesar",
    "repesos": "repeso",
    "repesou": "repesar",
    "repesque": "repescar",
    "repesquei": "repescar",
    "repesqueis": "repescar",
    "repesquem": "repescar",
    "repesquemo": "repescar",
    "repesquemos": "repescar",
    "repesques": "repescar",
    "repesá": "repesar",
    "repesámo": "repesar",
    "repesámos": "repesar",
    "repesáramo": "repesar",
    "repesáramos": "repesar",
    "repesárei": "repesar",
    "repesáreis": "repesar",
    "repesásseis": "repesar",
    "repesássemos": "repesar",
    "repesávamo": "repesar",
    "repesávamos": "repesar",
    "repesávei": "repesar",
    "repesáveis": "repesar",
    "repete": "repetir",
    "repetem": "repetir",
    "repetena": "repetenar",
    "repetenada": "repetenar",
    "repetenadas": "repetenar",
    "repetenado": "repetenar",
    "repetenados": "repetenar",
    "repetenai": "repetenar",
    "repetenais": "repetenar",
    "repetenam": "repetenar",
    "repetenamo": "repetenar",
    "repetenamos": "repetenar",
    "repetenando": "repetenar",
    "repetenara": "repetenar",
    "repetenaram": "repetenar",
    "repetenaras": "repetenar",
    "repetenarde": "repetenar",
    "repetenardes": "repetenar",
    "repetenare": "repetenar",
    "repetenarei": "repetenar",
    "repetenareis": "repetenar",
    "repetenarem": "repetenar",
    "repetenaremos": "repetenar",
    "repetenares": "repetenar",
    "repetenaria": "repetenar",
    "repetenariam": "repetenar",
    "repetenarias": "repetenar",
    "repetenarmo": "repetenar",
    "repetenarmos": "repetenar",
    "repetenará": "repetenar",
    "repetenarás": "repetenar",
    "repetenarão": "repetenar",
    "repetenaríamos": "repetenar",
    "repetenaríeis": "repetenar",
    "repetenas": "repetenar",
    "repetenasse": "repetenar",
    "repetenassem": "repetenar",
    "repetenasses": "repetenar",
    "repetenaste": "repetenar",
    "repetenastes": "repetenar",
    "repetenava": "repetenar",
    "repetenavam": "repetenar",
    "repetenavas": "repetenar",
    "repetene": "repetenar",
    "repetenei": "repetenar",
    "repeteneis": "repetenar",
    "repetenem": "repetenar",
    "repetenemo": "repetenar",
    "repetenemos": "repetenar",
    "repetenes": "repetenar",
    "repeteno": "repetenar",
    "repetenou": "repetenar",
    "repetentes": "repetente",
    "repetentezinha": "repetente",
    "repetentezinhas": "repetente",
    "repetentezinho": "repetente",
    "repetentezinhos": "repetente",
    "repetentezita": "repetente",
    "repetentezitas": "repetente",
    "repetentezito": "repetente",
    "repetentezitos": "repetente",
    "repetená": "repetenar",
    "repetenámo": "repetenar",
    "repetenámos": "repetenar",
    "repetenáramo": "repetenar",
    "repetenáramos": "repetenar",
    "repetenárei": "repetenar",
    "repetenáreis": "repetenar",
    "repetenásseis": "repetenar",
    "repetenássemos": "repetenar",
    "repetenávamo": "repetenar",
    "repetenávamos": "repetenar",
    "repetenávei": "repetenar",
    "repetenáveis": "repetenar",
    "repetes": "repetir",
    "repeti": "repetir",
    "repetia": "repetir",
    "repetiam": "repetir",
    "repetias": "repetir",
    "repetibilidades": "repetibilidade",
    "repetida": "repetir",
    "repetidas": "repetir",
    "repetido": "repetir",
    "repetidora": "repetidor",
    "repetidoras": "repetidor",
    "repetidores": "repetidor",
    "repetidos": "repetir",
    "repetimo": "repetir",
    "repetimos": "repetir",
    "repetindo": "repetir",
    "repetira": "repetir",
    "repetiram": "repetir",
    "repetiras": "repetir",
    "repetirde": "repetir",
    "repetirdes": "repetir",
    "repetire": "repetir",
    "repetirei": "repetir",
    "repetireis": "repetir",
    "repetirem": "repetir",
    "repetiremos": "repetir",
    "repetires": "repetir",
    "repetiria": "repetir",
    "repetiriam": "repetir",
    "repetirias": "repetir",
    "repetirmo": "repetir",
    "repetirmos": "repetir",
    "repetirá": "repetir",
    "repetirás": "repetir",
    "repetirão": "repetir",
    "repetiríamos": "repetir",
    "repetiríeis": "repetir",
    "repetis": "repetir",
    "repetisse": "repetir",
    "repetissem": "repetir",
    "repetisses": "repetir",
    "repetiste": "repetir",
    "repetistes": "repetir",
    "repetitiva": "repetitivo",
    "repetitivas": "repetitivo",
    "repetitivos": "repetitivo",
    "repetitória": "repetitório",
    "repetitórias": "repetitório",
    "repetitórios": "repetitório",
    "repetiu": "repetir",
    "repetições": "repetição",
    "repetências": "repetência",
    "repetíamo": "repetir",
    "repetíamos": "repetir",
    "repetíei": "repetir",
    "repetíeis": "repetir",
    "repetíramo": "repetir",
    "repetíramos": "repetir",
    "repetírei": "repetir",
    "repetíreis": "repetir",
    "repetísseis": "repetir",
    "repetíssemos": "repetir",
    "repetíveis": "repetível",
    "repica": "repicar",
    "repicada": "repicar",
    "repicadas": "repicar",
    "repicado": "repicar",
    "repicadora": "repicador",
    "repicadoras": "repicador",
    "repicadores": "repicador",
    "repicados": "repicar",
    "repicagens": "repicagem",
    "repicai": "repicar",
    "repicais": "repicar",
    "repicam": "repicar",
    "repicamo": "repicar",
    "repicamos": "repicar",
    "repicando": "repicar",
    "repicara": "repicar",
    "repicaram": "repicar",
    "repicaras": "repicar",
    "repicarde": "repicar",
    "repicardes": "repicar",
    "repicare": "repicar",
    "repicarei": "repicar",
    "repicareis": "repicar",
    "repicarem": "repicar",
    "repicaremos": "repicar",
    "repicares": "repicar",
    "repicaria": "repicar",
    "repicariam": "repicar",
    "repicarias": "repicar",
    "repicarmo": "repicar",
    "repicarmos": "repicar",
    "repicará": "repicar",
    "repicarás": "repicar",
    "repicarão": "repicar",
    "repicaríamos": "repicar",
    "repicaríeis": "repicar",
    "repicas": "repicar",
    "repicasse": "repicar",
    "repicassem": "repicar",
    "repicasses": "repicar",
    "repicaste": "repicar",
    "repicastes": "repicar",
    "repicava": "repicar",
    "repicavam": "repicar",
    "repicavas": "repicar",
    "repico": "repicar",
    "repicou": "repicar",
    "repicá": "repicar",
    "repicámo": "repicar",
    "repicámos": "repicar",
    "repicáramo": "repicar",
    "repicáramos": "repicar",
    "repicárei": "repicar",
    "repicáreis": "repicar",
    "repicásseis": "repicar",
    "repicássemos": "repicar",
    "repicávamo": "repicar",
    "repicávamos": "repicar",
    "repicávei": "repicar",
    "repicáveis": "repicar",
    "repila": "repelir",
    "repilais": "repelir",
    "repilam": "repelir",
    "repilamo": "repelir",
    "repilamos": "repelir",
    "repilas": "repelir",
    "repilo": "repelir",
    "repimpa": "repimpar",
    "repimpada": "repimpar",
    "repimpadas": "repimpar",
    "repimpado": "repimpar",
    "repimpados": "repimpar",
    "repimpadíssima": "repimpado",
    "repimpadíssimas": "repimpado",
    "repimpadíssimo": "repimpado",
    "repimpadíssimos": "repimpado",
    "repimpai": "repimpar",
    "repimpais": "repimpar",
    "repimpam": "repimpar",
    "repimpamo": "repimpar",
    "repimpamos": "repimpar",
    "repimpando": "repimpar",
    "repimpara": "repimpar",
    "repimparam": "repimpar",
    "repimparas": "repimpar",
    "repimparde": "repimpar",
    "repimpardes": "repimpar",
    "repimpare": "repimpar",
    "repimparei": "repimpar",
    "repimpareis": "repimpar",
    "repimparem": "repimpar",
    "repimparemos": "repimpar",
    "repimpares": "repimpar",
    "repimparia": "repimpar",
    "repimpariam": "repimpar",
    "repimparias": "repimpar",
    "repimparmo": "repimpar",
    "repimparmos": "repimpar",
    "repimpará": "repimpar",
    "repimparás": "repimpar",
    "repimparão": "repimpar",
    "repimparíamos": "repimpar",
    "repimparíeis": "repimpar",
    "repimpas": "repimpar",
    "repimpasse": "repimpar",
    "repimpassem": "repimpar",
    "repimpasses": "repimpar",
    "repimpaste": "repimpar",
    "repimpastes": "repimpar",
    "repimpava": "repimpar",
    "repimpavam": "repimpar",
    "repimpavas": "repimpar",
    "repimpe": "repimpar",
    "repimpei": "repimpar",
    "repimpeis": "repimpar",
    "repimpem": "repimpar",
    "repimpemo": "repimpar",
    "repimpemos": "repimpar",
    "repimpes": "repimpar",
    "repimpins": "repimpim",
    "repimpo": "repimpar",
    "repimpou": "repimpar",
    "repimpá": "repimpar",
    "repimpámo": "repimpar",
    "repimpámos": "repimpar",
    "repimpáramo": "repimpar",
    "repimpáramos": "repimpar",
    "repimpárei": "repimpar",
    "repimpáreis": "repimpar",
    "repimpásseis": "repimpar",
    "repimpássemos": "repimpar",
    "repimpávamo": "repimpar",
    "repimpávamos": "repimpar",
    "repimpávei": "repimpar",
    "repimpáveis": "repimpar",
    "repincha": "repinchar",
    "repinchada": "repinchar",
    "repinchadas": "repinchar",
    "repinchado": "repinchar",
    "repinchados": "repinchar",
    "repinchai": "repinchar",
    "repinchais": "repinchar",
    "repincham": "repinchar",
    "repinchamo": "repinchar",
    "repinchamos": "repinchar",
    "repinchando": "repinchar",
    "repinchara": "repinchar",
    "repincharam": "repinchar",
    "repincharas": "repinchar",
    "repinchardes": "repinchar",
    "repincharei": "repinchar",
    "repinchareis": "repinchar",
    "repincharem": "repinchar",
    "repincharemos": "repinchar",
    "repinchares": "repinchar",
    "repincharia": "repinchar",
    "repinchariam": "repinchar",
    "repincharias": "repinchar",
    "repincharmo": "repinchar",
    "repincharmos": "repinchar",
    "repinchará": "repinchar",
    "repincharás": "repinchar",
    "repincharão": "repinchar",
    "repincharíamos": "repinchar",
    "repincharíeis": "repinchar",
    "repinchas": "repinchar",
    "repinchasse": "repinchar",
    "repinchassem": "repinchar",
    "repinchasses": "repinchar",
    "repinchaste": "repinchar",
    "repinchastes": "repinchar",
    "repinchava": "repinchar",
    "repinchavam": "repinchar",
    "repinchavas": "repinchar",
    "repinche": "repinchar",
    "repinchei": "repinchar",
    "repincheis": "repinchar",
    "repinchem": "repinchar",
    "repinchemo": "repinchar",
    "repinchemos": "repinchar",
    "repinches": "repinchar",
    "repincho": "repinchar",
    "repinchou": "repinchar",
    "repinchámo": "repinchar",
    "repinchámos": "repinchar",
    "repincháramo": "repinchar",
    "repincháramos": "repinchar",
    "repincháreis": "repinchar",
    "repinchásseis": "repinchar",
    "repinchássemos": "repinchar",
    "repinchávamo": "repinchar",
    "repinchávamos": "repinchar",
    "repincháveis": "repinchar",
    "repinta": "repintar",
    "repintada": "repintar",
    "repintadas": "repintar",
    "repintado": "repintar",
    "repintados": "repintar",
    "repintai": "repintar",
    "repintais": "repintar",
    "repintalgada": "repintalgado",
    "repintalgadas": "repintalgado",
    "repintalgados": "repintalgado",
    "repintam": "repintar",
    "repintamo": "repintar",
    "repintamos": "repintar",
    "repintando": "repintar",
    "repintara": "repintar",
    "repintaram": "repintar",
    "repintaras": "repintar",
    "repintarde": "repintar",
    "repintardes": "repintar",
    "repintare": "repintar",
    "repintarei": "repintar",
    "repintareis": "repintar",
    "repintarem": "repintar",
    "repintaremos": "repintar",
    "repintares": "repintar",
    "repintaria": "repintar",
    "repintariam": "repintar",
    "repintarias": "repintar",
    "repintarmo": "repintar",
    "repintarmos": "repintar",
    "repintará": "repintar",
    "repintarás": "repintar",
    "repintarão": "repintar",
    "repintaríamos": "repintar",
    "repintaríeis": "repintar",
    "repintas": "repintar",
    "repintasse": "repintar",
    "repintassem": "repintar",
    "repintasses": "repintar",
    "repintaste": "repintar",
    "repintastes": "repintar",
    "repintava": "repintar",
    "repintavam": "repintar",
    "repintavas": "repintar",
    "repinte": "repintar",
    "repintei": "repintar",
    "repinteis": "repintar",
    "repintem": "repintar",
    "repintemo": "repintar",
    "repintemos": "repintar",
    "repintes": "repintar",
    "repinto": "repintar",
    "repintou": "repintar",
    "repintá": "repintar",
    "repintámo": "repintar",
    "repintámos": "repintar",
    "repintáramo": "repintar",
    "repintáramos": "repintar",
    "repintárei": "repintar",
    "repintáreis": "repintar",
    "repintásseis": "repintar",
    "repintássemos": "repintar",
    "repintávamo": "repintar",
    "repintávamos": "repintar",
    "repintávei": "repintar",
    "repintáveis": "repintar",
    "repique": "repicar",
    "repiquei": "repicar",
    "repiqueis": "repicar",
    "repiquem": "repicar",
    "repiquemo": "repicar",
    "repiquemos": "repicar",
    "repiques": "repique",
    "repiqueta": "repiquetar",
    "repiquetada": "repiquetar",
    "repiquetadas": "repiquetar",
    "repiquetado": "repiquetar",
    "repiquetados": "repiquetar",
    "repiquetai": "repiquetar",
    "repiquetais": "repiquetar",
    "repiquetam": "repiquetar",
    "repiquetamo": "repiquetar",
    "repiquetamos": "repiquetar",
    "repiquetando": "repiquetar",
    "repiquetara": "repiquetar",
    "repiquetaram": "repiquetar",
    "repiquetaras": "repiquetar",
    "repiquetarde": "repiquetar",
    "repiquetardes": "repiquetar",
    "repiquetare": "repiquetar",
    "repiquetarei": "repiquetar",
    "repiquetareis": "repiquetar",
    "repiquetarem": "repiquetar",
    "repiquetaremos": "repiquetar",
    "repiquetares": "repiquetar",
    "repiquetaria": "repiquetar",
    "repiquetariam": "repiquetar",
    "repiquetarias": "repiquetar",
    "repiquetarmo": "repiquetar",
    "repiquetarmos": "repiquetar",
    "repiquetará": "repiquetar",
    "repiquetarás": "repiquetar",
    "repiquetarão": "repiquetar",
    "repiquetaríamos": "repiquetar",
    "repiquetaríeis": "repiquetar",
    "repiquetas": "repiquetar",
    "repiquetasse": "repiquetar",
    "repiquetassem": "repiquetar",
    "repiquetasses": "repiquetar",
    "repiquetaste": "repiquetar",
    "repiquetastes": "repiquetar",
    "repiquetava": "repiquetar",
    "repiquetavam": "repiquetar",
    "repiquetavas": "repiquetar",
    "repiquete": "repiquetar",
    "repiquetei": "repiquetar",
    "repiqueteis": "repiquetar",
    "repiquetem": "repiquetar",
    "repiquetemo": "repiquetar",
    "repiquetemos": "repiquetar",
    "repiquetes": "repiquete",
    "repiqueto": "repiquetar",
    "repiquetou": "repiquetar",
    "repiquetá": "repiquetar",
    "repiquetámo": "repiquetar",
    "repiquetámos": "repiquetar",
    "repiquetáramo": "repiquetar",
    "repiquetáramos": "repiquetar",
    "repiquetárei": "repiquetar",
    "repiquetáreis": "repiquetar",
    "repiquetásseis": "repiquetar",
    "repiquetássemos": "repiquetar",
    "repiquetávamo": "repiquetar",
    "repiquetávamos": "repiquetar",
    "repiquetávei": "repiquetar",
    "repiquetáveis": "repiquetar",
    "repisa": "repisar",
    "repisada": "repisar",
    "repisadas": "repisar",
    "repisado": "repisar",
    "repisados": "repisar",
    "repisai": "repisar",
    "repisais": "repisar",
    "repisam": "repisar",
    "repisamentos": "repisamento",
    "repisamo": "repisar",
    "repisamos": "repisar",
    "repisando": "repisar",
    "repisara": "repisar",
    "repisaram": "repisar",
    "repisaras": "repisar",
    "repisarde": "repisar",
    "repisardes": "repisar",
    "repisare": "repisar",
    "repisarei": "repisar",
    "repisareis": "repisar",
    "repisarem": "repisar",
    "repisaremos": "repisar",
    "repisares": "repisar",
    "repisaria": "repisar",
    "repisariam": "repisar",
    "repisarias": "repisar",
    "repisarmo": "repisar",
    "repisarmos": "repisar",
    "repisará": "repisar",
    "repisarás": "repisar",
    "repisarão": "repisar",
    "repisaríamos": "repisar",
    "repisaríeis": "repisar",
    "repisas": "repisar",
    "repisasse": "repisar",
    "repisassem": "repisar",
    "repisasses": "repisar",
    "repisaste": "repisar",
    "repisastes": "repisar",
    "repisava": "repisar",
    "repisavam": "repisar",
    "repisavas": "repisar",
    "repise": "repisar",
    "repisei": "repisar",
    "repiseis": "repisar",
    "repisem": "repisar",
    "repisemo": "repisar",
    "repisemos": "repisar",
    "repises": "repisar",
    "repiso": "repisar",
    "repisou": "repisar",
    "repisá": "repisar",
    "repisámo": "repisar",
    "repisámos": "repisar",
    "repisáramo": "repisar",
    "repisáramos": "repisar",
    "repisárei": "repisar",
    "repisáreis": "repisar",
    "repisásseis": "repisar",
    "repisássemos": "repisar",
    "repisávamo": "repisar",
    "repisávamos": "repisar",
    "repisávei": "repisar",
    "repisáveis": "repisar",
    "repita": "repetir",
    "repitais": "repetir",
    "repitam": "repetir",
    "repitamo": "repetir",
    "repitamos": "repetir",
    "repitas": "repetir",
    "repito": "repetir",
    "replaina": "replainar",
    "replainada": "replainar",
    "replainadas": "replainar",
    "replainado": "replainar",
    "replainados": "replainar",
    "replainai": "replainar",
    "replainais": "replainar",
    "replainam": "replainar",
    "replainamo": "replainar",
    "replainamos": "replainar",
    "replainando": "replainar",
    "replainara": "replainar",
    "replainaram": "replainar",
    "replainaras": "replainar",
    "replainarde": "replainar",
    "replainardes": "replainar",
    "replainare": "replainar",
    "replainarei": "replainar",
    "replainareis": "replainar",
    "replainarem": "replainar",
    "replainaremos": "replainar",
    "replainares": "replainar",
    "replainaria": "replainar",
    "replainariam": "replainar",
    "replainarias": "replainar",
    "replainarmo": "replainar",
    "replainarmos": "replainar",
    "replainará": "replainar",
    "replainarás": "replainar",
    "replainarão": "replainar",
    "replainaríamos": "replainar",
    "replainaríeis": "replainar",
    "replainas": "replainar",
    "replainasse": "replainar",
    "replainassem": "replainar",
    "replainasses": "replainar",
    "replainaste": "replainar",
    "replainastes": "replainar",
    "replainava": "replainar",
    "replainavam": "replainar",
    "replainavas": "replainar",
    "replaine": "replainar",
    "replainei": "replainar",
    "replaineis": "replainar",
    "replainem": "replainar",
    "replainemo": "replainar",
    "replainemos": "replainar",
    "replaines": "replainar",
    "replaino": "replainar",
    "replainos": "replaino",
    "replainou": "replainar",
    "replainá": "replainar",
    "replainámo": "replainar",
    "replainámos": "replainar",
    "replaináramo": "replainar",
    "replaináramos": "replainar",
    "replainárei": "replainar",
    "replaináreis": "replainar",
    "replainásseis": "replainar",
    "replainássemos": "replainar",
    "replainávamo": "replainar",
    "replainávamos": "replainar",
    "replainávei": "replainar",
    "replaináveis": "replainar",
    "replanada": "replanado",
    "replanadas": "replanado",
    "replanados": "replanado",
    "replanta": "replantar",
    "replantada": "replantar",
    "replantadas": "replantar",
    "replantado": "replantar",
    "replantados": "replantar",
    "replantai": "replantar",
    "replantais": "replantar",
    "replantam": "replantar",
    "replantamo": "replantar",
    "replantamos": "replantar",
    "replantando": "replantar",
    "replantara": "replantar",
    "replantaram": "replantar",
    "replantaras": "replantar",
    "replantarde": "replantar",
    "replantardes": "replantar",
    "replantare": "replantar",
    "replantarei": "replantar",
    "replantareis": "replantar",
    "replantarem": "replantar",
    "replantaremos": "replantar",
    "replantares": "replantar",
    "replantaria": "replantar",
    "replantariam": "replantar",
    "replantarias": "replantar",
    "replantarmo": "replantar",
    "replantarmos": "replantar",
    "replantará": "replantar",
    "replantarás": "replantar",
    "replantarão": "replantar",
    "replantaríamos": "replantar",
    "replantaríeis": "replantar",
    "replantas": "replantar",
    "replantasse": "replantar",
    "replantassem": "replantar",
    "replantasses": "replantar",
    "replantaste": "replantar",
    "replantastes": "replantar",
    "replantava": "replantar",
    "replantavam": "replantar",
    "replantavas": "replantar",
    "replantações": "replantação",
    "replante": "replantar",
    "replantei": "replantar",
    "replanteis": "replantar",
    "replantem": "replantar",
    "replantemo": "replantar",
    "replantemos": "replantar",
    "replantes": "replantar",
    "replantios": "replantio",
    "replanto": "replantar",
    "replantou": "replantar",
    "replantá": "replantar",
    "replantámo": "replantar",
    "replantámos": "replantar",
    "replantáramo": "replantar",
    "replantáramos": "replantar",
    "replantárei": "replantar",
    "replantáreis": "replantar",
    "replantásseis": "replantar",
    "replantássemos": "replantar",
    "replantávamo": "replantar",
    "replantávamos": "replantar",
    "replantávei": "replantar",
    "replantáveis": "replantar",
    "replena": "repleno",
    "replenas": "repleno",
    "replenos": "repleno",
    "repleta": "repleto",
    "repletada": "repletar",
    "repletadas": "repletar",
    "repletado": "repletar",
    "repletados": "repletar",
    "repletai": "repletar",
    "repletais": "repletar",
    "repletam": "repletar",
    "repletamo": "repletar",
    "repletamos": "repletar",
    "repletando": "repletar",
    "repletara": "repletar",
    "repletaram": "repletar",
    "repletaras": "repletar",
    "repletarde": "repletar",
    "repletardes": "repletar",
    "repletare": "repletar",
    "repletarei": "repletar",
    "repletareis": "repletar",
    "repletarem": "repletar",
    "repletaremos": "repletar",
    "repletares": "repletar",
    "repletaria": "repletar",
    "repletariam": "repletar",
    "repletarias": "repletar",
    "repletarmo": "repletar",
    "repletarmos": "repletar",
    "repletará": "repletar",
    "repletarás": "repletar",
    "repletarão": "repletar",
    "repletaríamos": "repletar",
    "repletaríeis": "repletar",
    "repletas": "repleto",
    "repletasse": "repletar",
    "repletassem": "repletar",
    "repletasses": "repletar",
    "repletaste": "repletar",
    "repletastes": "repletar",
    "repletava": "repletar",
    "repletavam": "repletar",
    "repletavas": "repletar",
    "replete": "repletar",
    "repletei": "repletar",
    "repleteis": "repletar",
    "repletem": "repletar",
    "repletemo": "repletar",
    "repletemos": "repletar",
    "repletes": "repletar",
    "repleto": "repletar",
    "repletos": "repleto",
    "repletou": "repletar",
    "repletá": "repletar",
    "repletámo": "repletar",
    "repletámos": "repletar",
    "repletáramo": "repletar",
    "repletáramos": "repletar",
    "repletárei": "repletar",
    "repletáreis": "repletar",
    "repletásseis": "repletar",
    "repletássemos": "repletar",
    "repletávamo": "repletar",
    "repletávamos": "repletar",
    "repletávei": "repletar",
    "repletáveis": "repletar",
    "repleções": "repleção",
    "replica": "replicar",
    "replicada": "replicar",
    "replicadas": "replicar",
    "replicado": "replicar",
    "replicadora": "replicador",
    "replicadoras": "replicador",
    "replicadorazinha": "replicador",
    "replicadorazinhas": "replicador",
    "replicadorazita": "replicador",
    "replicadorazitas": "replicador",
    "replicadores": "replicador",
    "replicadorzinho": "replicador",
    "replicadorzinhos": "replicador",
    "replicadorzito": "replicador",
    "replicadorzitos": "replicador",
    "replicados": "replicar",
    "replicai": "replicar",
    "replicais": "replicar",
    "replicam": "replicar",
    "replicamo": "replicar",
    "replicamos": "replicar",
    "replicando": "replicar",
    "replicara": "replicar",
    "replicaram": "replicar",
    "replicaras": "replicar",
    "replicarde": "replicar",
    "replicardes": "replicar",
    "replicare": "replicar",
    "replicarei": "replicar",
    "replicareis": "replicar",
    "replicarem": "replicar",
    "replicaremos": "replicar",
    "replicares": "replicar",
    "replicaria": "replicar",
    "replicariam": "replicar",
    "replicarias": "replicar",
    "replicarmo": "replicar",
    "replicarmos": "replicar",
    "replicará": "replicar",
    "replicarás": "replicar",
    "replicarão": "replicar",
    "replicaríamos": "replicar",
    "replicaríeis": "replicar",
    "replicas": "replicar",
    "replicasse": "replicar",
    "replicassem": "replicar",
    "replicasses": "replicar",
    "replicaste": "replicar",
    "replicastes": "replicar",
    "replicava": "replicar",
    "replicavam": "replicar",
    "replicavas": "replicar",
    "replicações": "replicação",
    "replico": "replicar",
    "replicou": "replicar",
    "replicá": "replicar",
    "replicámo": "replicar",
    "replicámos": "replicar",
    "replicáramo": "replicar",
    "replicáramos": "replicar",
    "replicárei": "replicar",
    "replicáreis": "replicar",
    "replicásseis": "replicar",
    "replicássemos": "replicar",
    "replicávamo": "replicar",
    "replicávamos": "replicar",
    "replicávei": "replicar",
    "replicáveis": "replicar",
    "replique": "replicar",
    "repliquei": "replicar",
    "repliqueis": "replicar",
    "repliquem": "replicar",
    "repliquemo": "replicar",
    "repliquemos": "replicar",
    "repliques": "replicar",
    "repoisa": "repoisar",
    "repoisada": "repoisar",
    "repoisadas": "repoisar",
    "repoisado": "repoisar",
    "repoisados": "repoisar",
    "repoisai": "repoisar",
    "repoisais": "repoisar",
    "repoisam": "repoisar",
    "repoisamo": "repoisar",
    "repoisamos": "repoisar",
    "repoisando": "repoisar",
    "repoisara": "repoisar",
    "repoisaram": "repoisar",
    "repoisaras": "repoisar",
    "repoisarde": "repoisar",
    "repoisardes": "repoisar",
    "repoisare": "repoisar",
    "repoisarei": "repoisar",
    "repoisareis": "repoisar",
    "repoisarem": "repoisar",
    "repoisaremos": "repoisar",
    "repoisares": "repoisar",
    "repoisaria": "repoisar",
    "repoisariam": "repoisar",
    "repoisarias": "repoisar",
    "repoisarmo": "repoisar",
    "repoisarmos": "repoisar",
    "repoisará": "repoisar",
    "repoisarás": "repoisar",
    "repoisarão": "repoisar",
    "repoisaríamos": "repoisar",
    "repoisaríeis": "repoisar",
    "repoisas": "repoisar",
    "repoisasse": "repoisar",
    "repoisassem": "repoisar",
    "repoisasses": "repoisar",
    "repoisaste": "repoisar",
    "repoisastes": "repoisar",
    "repoisava": "repoisar",
    "repoisavam": "repoisar",
    "repoisavas": "repoisar",
    "repoise": "repoisar",
    "repoisei": "repoisar",
    "repoiseis": "repoisar",
    "repoisem": "repoisar",
    "repoisemo": "repoisar",
    "repoisemos": "repoisar",
    "repoises": "repoisar",
    "repoiso": "repoisar",
    "repoisos": "repoiso",
    "repoisou": "repoisar",
    "repoisá": "repoisar",
    "repoisámo": "repoisar",
    "repoisámos": "repoisar",
    "repoisáramo": "repoisar",
    "repoisáramos": "repoisar",
    "repoisárei": "repoisar",
    "repoisáreis": "repoisar",
    "repoisásseis": "repoisar",
    "repoisássemos": "repoisar",
    "repoisávamo": "repoisar",
    "repoisávamos": "repoisar",
    "repoisávei": "repoisar",
    "repoisáveis": "repoisar",
    "repolega": "repolegar",
    "repolegada": "repolegar",
    "repolegadas": "repolegar",
    "repolegado": "repolegar",
    "repolegados": "repolegar",
    "repolegai": "repolegar",
    "repolegais": "repolegar",
    "repolegam": "repolegar",
    "repolegamo": "repolegar",
    "repolegamos": "repolegar",
    "repolegando": "repolegar",
    "repolegara": "repolegar",
    "repolegaram": "repolegar",
    "repolegaras": "repolegar",
    "repolegarde": "repolegar",
    "repolegardes": "repolegar",
    "repolegare": "repolegar",
    "repolegarei": "repolegar",
    "repolegareis": "repolegar",
    "repolegarem": "repolegar",
    "repolegaremos": "repolegar",
    "repolegares": "repolegar",
    "repolegaria": "repolegar",
    "repolegariam": "repolegar",
    "repolegarias": "repolegar",
    "repolegarmo": "repolegar",
    "repolegarmos": "repolegar",
    "repolegará": "repolegar",
    "repolegarás": "repolegar",
    "repolegarão": "repolegar",
    "repolegaríamos": "repolegar",
    "repolegaríeis": "repolegar",
    "repolegas": "repolegar",
    "repolegasse": "repolegar",
    "repolegassem": "repolegar",
    "repolegasses": "repolegar",
    "repolegaste": "repolegar",
    "repolegastes": "repolegar",
    "repolegava": "repolegar",
    "repolegavam": "repolegar",
    "repolegavas": "repolegar",
    "repolego": "repolegar",
    "repolegos": "repolego",
    "repolegou": "repolegar",
    "repolegue": "repolegar",
    "repoleguei": "repolegar",
    "repolegueis": "repolegar",
    "repoleguem": "repolegar",
    "repoleguemo": "repolegar",
    "repoleguemos": "repolegar",
    "repolegues": "repolegar",
    "repolegá": "repolegar",
    "repolegámo": "repolegar",
    "repolegámos": "repolegar",
    "repolegáramo": "repolegar",
    "repolegáramos": "repolegar",
    "repolegárei": "repolegar",
    "repolegáreis": "repolegar",
    "repolegásseis": "repolegar",
    "repolegássemos": "repolegar",
    "repolegávamo": "repolegar",
    "repolegávamos": "repolegar",
    "repolegávei": "repolegar",
    "repolegáveis": "repolegar",
    "repolha": "repolhar",
    "repolhada": "repolhar",
    "repolhadas": "repolhar",
    "repolhado": "repolhar",
    "repolhados": "repolhar",
    "repolhai": "repolhar",
    "repolhais": "repolhar",
    "repolham": "repolhar",
    "repolhamo": "repolhar",
    "repolhamos": "repolhar",
    "repolhando": "repolhar",
    "repolhara": "repolhar",
    "repolharam": "repolhar",
    "repolharas": "repolhar",
    "repolhardes": "repolhar",
    "repolharei": "repolhar",
    "repolhareis": "repolhar",
    "repolharem": "repolhar",
    "repolharemos": "repolhar",
    "repolhares": "repolhar",
    "repolharia": "repolhar",
    "repolhariam": "repolhar",
    "repolharias": "repolhar",
    "repolharmo": "repolhar",
    "repolharmos": "repolhar",
    "repolhará": "repolhar",
    "repolharás": "repolhar",
    "repolharão": "repolhar",
    "repolharíamos": "repolhar",
    "repolharíeis": "repolhar",
    "repolhas": "repolhar",
    "repolhasse": "repolhar",
    "repolhassem": "repolhar",
    "repolhasses": "repolhar",
    "repolhaste": "repolhar",
    "repolhastes": "repolhar",
    "repolhava": "repolhar",
    "repolhavam": "repolhar",
    "repolhavas": "repolhar",
    "repolhaça": "repolhaço",
    "repolhaças": "repolhaço",
    "repolhaços": "repolhaço",
    "repolhe": "repolhar",
    "repolhei": "repolhar",
    "repolheis": "repolhar",
    "repolhem": "repolhar",
    "repolhemo": "repolhar",
    "repolhemos": "repolhar",
    "repolhes": "repolhar",
    "repolho": "repolhar",
    "repolhos": "repolho",
    "repolhou": "repolhar",
    "repolhuda": "repolhudo",
    "repolhudas": "repolhudo",
    "repolhudazinha": "repolhudo",
    "repolhudazinhas": "repolhudo",
    "repolhudazita": "repolhudo",
    "repolhudazitas": "repolhudo",
    "repolhudinha": "repolhudo",
    "repolhudinhas": "repolhudo",
    "repolhudinho": "repolhudo",
    "repolhudinhos": "repolhudo",
    "repolhudita": "repolhudo",
    "repolhuditas": "repolhudo",
    "repolhudito": "repolhudo",
    "repolhuditos": "repolhudo",
    "repolhudos": "repolhudo",
    "repolhudozinho": "repolhudo",
    "repolhudozinhos": "repolhudo",
    "repolhudozito": "repolhudo",
    "repolhudozitos": "repolhudo",
    "repolhudíssima": "repolhudo",
    "repolhudíssimas": "repolhudo",
    "repolhudíssimo": "repolhudo",
    "repolhudíssimos": "repolhudo",
    "repolhámo": "repolhar",
    "repolhámos": "repolhar",
    "repolháramo": "repolhar",
    "repolháramos": "repolhar",
    "repolháreis": "repolhar",
    "repolhásseis": "repolhar",
    "repolhássemos": "repolhar",
    "repolhávamo": "repolhar",
    "repolhávamos": "repolhar",
    "repolháveis": "repolhar",
    "repoltreada": "repoltrear",
    "repoltreadas": "repoltrear",
    "repoltreado": "repoltrear",
    "repoltreados": "repoltrear",
    "repoltreai": "repoltrear",
    "repoltreais": "repoltrear",
    "repoltreamo": "repoltrear",
    "repoltreamos": "repoltrear",
    "repoltreando": "repoltrear",
    "repoltreara": "repoltrear",
    "repoltrearam": "repoltrear",
    "repoltrearas": "repoltrear",
    "repoltrearde": "repoltrear",
    "repoltreardes": "repoltrear",
    "repoltreare": "repoltrear",
    "repoltrearei": "repoltrear",
    "repoltreareis": "repoltrear",
    "repoltrearem": "repoltrear",
    "repoltrearemos": "repoltrear",
    "repoltreares": "repoltrear",
    "repoltrearia": "repoltrear",
    "repoltreariam": "repoltrear",
    "repoltrearias": "repoltrear",
    "repoltrearmo": "repoltrear",
    "repoltrearmos": "repoltrear",
    "repoltreará": "repoltrear",
    "repoltrearás": "repoltrear",
    "repoltrearão": "repoltrear",
    "repoltrearíamos": "repoltrear",
    "repoltrearíeis": "repoltrear",
    "repoltreasse": "repoltrear",
    "repoltreassem": "repoltrear",
    "repoltreasses": "repoltrear",
    "repoltreaste": "repoltrear",
    "repoltreastes": "repoltrear",
    "repoltreava": "repoltrear",
    "repoltreavam": "repoltrear",
    "repoltreavas": "repoltrear",
    "repoltreei": "repoltrear",
    "repoltreeis": "repoltrear",
    "repoltreemo": "repoltrear",
    "repoltreemos": "repoltrear",
    "repoltreia": "repoltrear",
    "repoltreiam": "repoltrear",
    "repoltreias": "repoltrear",
    "repoltreie": "repoltrear",
    "repoltreiem": "repoltrear",
    "repoltreies": "repoltrear",
    "repoltreio": "repoltrear",
    "repoltreou": "repoltrear",
    "repoltreá": "repoltrear",
    "repoltreámo": "repoltrear",
    "repoltreámos": "repoltrear",
    "repoltreáramo": "repoltrear",
    "repoltreáramos": "repoltrear",
    "repoltreárei": "repoltrear",
    "repoltreáreis": "repoltrear",
    "repoltreásseis": "repoltrear",
    "repoltreássemos": "repoltrear",
    "repoltreávamo": "repoltrear",
    "repoltreávamos": "repoltrear",
    "repoltreávei": "repoltrear",
    "repoltreáveis": "repoltrear",
    "repomo": "repor",
    "repomos": "repor",
    "reponde": "repor",
    "repondera": "reponderar",
    "reponderada": "reponderar",
    "reponderadas": "reponderar",
    "reponderado": "reponderar",
    "reponderados": "reponderar",
    "reponderai": "reponderar",
    "reponderais": "reponderar",
    "reponderam": "reponderar",
    "reponderamo": "reponderar",
    "reponderamos": "reponderar",
    "reponderando": "reponderar",
    "reponderara": "reponderar",
    "reponderaram": "reponderar",
    "reponderaras": "reponderar",
    "reponderarde": "reponderar",
    "reponderardes": "reponderar",
    "reponderare": "reponderar",
    "reponderarei": "reponderar",
    "reponderareis": "reponderar",
    "reponderarem": "reponderar",
    "reponderaremos": "reponderar",
    "reponderares": "reponderar",
    "reponderaria": "reponderar",
    "reponderariam": "reponderar",
    "reponderarias": "reponderar",
    "reponderarmo": "reponderar",
    "reponderarmos": "reponderar",
    "reponderará": "reponderar",
    "reponderarás": "reponderar",
    "reponderarão": "reponderar",
    "reponderaríamos": "reponderar",
    "reponderaríeis": "reponderar",
    "reponderas": "reponderar",
    "reponderasse": "reponderar",
    "reponderassem": "reponderar",
    "reponderasses": "reponderar",
    "reponderaste": "reponderar",
    "reponderastes": "reponderar",
    "reponderava": "reponderar",
    "reponderavam": "reponderar",
    "reponderavas": "reponderar",
    "repondere": "reponderar",
    "reponderei": "reponderar",
    "repondereis": "reponderar",
    "reponderem": "reponderar",
    "reponderemo": "reponderar",
    "reponderemos": "reponderar",
    "reponderes": "reponderar",
    "repondero": "reponderar",
    "reponderou": "reponderar",
    "reponderá": "reponderar",
    "reponderámo": "reponderar",
    "reponderámos": "reponderar",
    "reponderáramo": "reponderar",
    "reponderáramos": "reponderar",
    "reponderárei": "reponderar",
    "reponderáreis": "reponderar",
    "reponderásseis": "reponderar",
    "reponderássemos": "reponderar",
    "reponderávamo": "reponderar",
    "reponderávamos": "reponderar",
    "reponderávei": "reponderar",
    "reponderáveis": "reponderar",
    "repondes": "repor",
    "repondo": "repor",
    "reponha": "repor",
    "reponhais": "repor",
    "reponham": "repor",
    "reponhamo": "repor",
    "reponhamos": "repor",
    "reponhas": "repor",
    "reponho": "repor",
    "reponta": "repontar",
    "repontada": "repontar",
    "repontadas": "repontar",
    "repontado": "repontar",
    "repontados": "repontar",
    "repontai": "repontar",
    "repontais": "repontar",
    "repontam": "repontar",
    "repontamo": "repontar",
    "repontamos": "repontar",
    "repontando": "repontar",
    "repontara": "repontar",
    "repontaram": "repontar",
    "repontaras": "repontar",
    "repontarde": "repontar",
    "repontardes": "repontar",
    "repontare": "repontar",
    "repontarei": "repontar",
    "repontareis": "repontar",
    "repontarem": "repontar",
    "repontaremos": "repontar",
    "repontares": "repontar",
    "repontaria": "repontar",
    "repontariam": "repontar",
    "repontarias": "repontar",
    "repontarmo": "repontar",
    "repontarmos": "repontar",
    "repontará": "repontar",
    "repontarás": "repontar",
    "repontarão": "repontar",
    "repontaríamos": "repontar",
    "repontaríeis": "repontar",
    "repontas": "repontar",
    "repontasse": "repontar",
    "repontassem": "repontar",
    "repontasses": "repontar",
    "repontaste": "repontar",
    "repontastes": "repontar",
    "repontava": "repontar",
    "repontavam": "repontar",
    "repontavas": "repontar",
    "reponte": "repontar",
    "repontei": "repontar",
    "reponteis": "repontar",
    "repontem": "repontar",
    "repontemo": "repontar",
    "repontemos": "repontar",
    "repontes": "repontar",
    "repontices": "repontice",
    "reponto": "repontar",
    "repontona": "repontão",
    "repontonas": "repontão",
    "repontou": "repontar",
    "repontá": "repontar",
    "repontámo": "repontar",
    "repontámos": "repontar",
    "repontáramo": "repontar",
    "repontáramos": "repontar",
    "repontárei": "repontar",
    "repontáreis": "repontar",
    "repontásseis": "repontar",
    "repontássemos": "repontar",
    "repontávamo": "repontar",
    "repontávamos": "repontar",
    "repontávei": "repontar",
    "repontáveis": "repontar",
    "repontões": "repontão",
    "reponíveis": "reponível",
    "reporde": "repor",
    "repordes": "repor",
    "repore": "repor",
    "reporei": "repor",
    "reporeis": "repor",
    "reporem": "repor",
    "reporemos": "repor",
    "repores": "repor",
    "reporia": "repor",
    "reporiam": "repor",
    "reporias": "repor",
    "repormo": "repor",
    "repormos": "repor",
    "reporta": "reportar",
    "reportada": "reportar",
    "reportadas": "reportar",
    "reportado": "reportar",
    "reportados": "reportar",
    "reportagens": "reportagem",
    "reportai": "reportar",
    "reportais": "reportar",
    "reportam": "reportar",
    "reportamentos": "reportamento",
    "reportamo": "reportar",
    "reportamos": "reportar",
    "reportando": "reportar",
    "reportara": "reportar",
    "reportaram": "reportar",
    "reportaras": "reportar",
    "reportarde": "reportar",
    "reportardes": "reportar",
    "reportare": "reportar",
    "reportarei": "reportar",
    "reportareis": "reportar",
    "reportarem": "reportar",
    "reportaremos": "reportar",
    "reportares": "reportar",
    "reportaria": "reportar",
    "reportariam": "reportar",
    "reportarias": "reportar",
    "reportarmo": "reportar",
    "reportarmos": "reportar",
    "reportará": "reportar",
    "reportarás": "reportar",
    "reportarão": "reportar",
    "reportaríamos": "reportar",
    "reportaríeis": "reportar",
    "reportas": "reportar",
    "reportasse": "reportar",
    "reportassem": "reportar",
    "reportasses": "reportar",
    "reportaste": "reportar",
    "reportastes": "reportar",
    "reportava": "reportar",
    "reportavam": "reportar",
    "reportavas": "reportar",
    "reportações": "reportação",
    "reporte": "reportar",
    "reportei": "reportar",
    "reporteis": "reportar",
    "reportem": "reportar",
    "reportemo": "reportar",
    "reportemos": "reportar",
    "reportes": "reportar",
    "reporto": "reportar",
    "reportou": "reportar",
    "reportá": "reportar",
    "reportámo": "reportar",
    "reportámos": "reportar",
    "reportáramo": "reportar",
    "reportáramos": "reportar",
    "reportárei": "reportar",
    "reportáreis": "reportar",
    "reportásseis": "reportar",
    "reportássemos": "reportar",
    "reportávamo": "reportar",
    "reportávamos": "reportar",
    "reportávei": "reportar",
    "reportáveis": "reportar",
    "reportórios": "reportório",
    "reporá": "repor",
    "reporás": "repor",
    "reporão": "repor",
    "reporíamos": "repor",
    "reporíeis": "repor",
    "reposiciona": "reposicionar",
    "reposicionada": "reposicionar",
    "reposicionadas": "reposicionar",
    "reposicionado": "reposicionar",
    "reposicionados": "reposicionar",
    "reposicionai": "reposicionar",
    "reposicionais": "reposicionar",
    "reposicionam": "reposicionar",
    "reposicionamentos": "reposicionamento",
    "reposicionamo": "reposicionar",
    "reposicionamos": "reposicionar",
    "reposicionando": "reposicionar",
    "reposicionara": "reposicionar",
    "reposicionaram": "reposicionar",
    "reposicionaras": "reposicionar",
    "reposicionarde": "reposicionar",
    "reposicionardes": "reposicionar",
    "reposicionare": "reposicionar",
    "reposicionarei": "reposicionar",
    "reposicionareis": "reposicionar",
    "reposicionarem": "reposicionar",
    "reposicionaremos": "reposicionar",
    "reposicionares": "reposicionar",
    "reposicionaria": "reposicionar",
    "reposicionariam": "reposicionar",
    "reposicionarias": "reposicionar",
    "reposicionarmo": "reposicionar",
    "reposicionarmos": "reposicionar",
    "reposicionará": "reposicionar",
    "reposicionarás": "reposicionar",
    "reposicionarão": "reposicionar",
    "reposicionaríamos": "reposicionar",
    "reposicionaríeis": "reposicionar",
    "reposicionas": "reposicionar",
    "reposicionasse": "reposicionar",
    "reposicionassem": "reposicionar",
    "reposicionasses": "reposicionar",
    "reposicionaste": "reposicionar",
    "reposicionastes": "reposicionar",
    "reposicionava": "reposicionar",
    "reposicionavam": "reposicionar",
    "reposicionavas": "reposicionar",
    "reposicione": "reposicionar",
    "reposicionei": "reposicionar",
    "reposicioneis": "reposicionar",
    "reposicionem": "reposicionar",
    "reposicionemo": "reposicionar",
    "reposicionemos": "reposicionar",
    "reposiciones": "reposicionar",
    "reposiciono": "reposicionar",
    "reposicionou": "reposicionar",
    "reposicioná": "reposicionar",
    "reposicionámo": "reposicionar",
    "reposicionámos": "reposicionar",
    "reposicionáramo": "reposicionar",
    "reposicionáramos": "reposicionar",
    "reposicionárei": "reposicionar",
    "reposicionáreis": "reposicionar",
    "reposicionásseis": "reposicionar",
    "reposicionássemos": "reposicionar",
    "reposicionávamo": "reposicionar",
    "reposicionávamos": "reposicionar",
    "reposicionávei": "reposicionar",
    "reposicionáveis": "reposicionar",
    "repositora": "repositor",
    "repositoras": "repositor",
    "repositores": "repositor",
    "repositória": "repositório",
    "repositórias": "repositório",
    "repositórios": "repositório",
    "reposições": "reposição",
    "repossua": "repossuir",
    "repossuais": "repossuir",
    "repossuam": "repossuir",
    "repossuamo": "repossuir",
    "repossuamos": "repossuir",
    "repossuas": "repossuir",
    "repossuem": "repossuir",
    "repossui": "repossuir",
    "repossuindo": "repossuir",
    "repossuirde": "repossuir",
    "repossuirdes": "repossuir",
    "repossuirei": "repossuir",
    "repossuireis": "repossuir",
    "repossuiremos": "repossuir",
    "repossuiria": "repossuir",
    "repossuiriam": "repossuir",
    "repossuirias": "repossuir",
    "repossuirmo": "repossuir",
    "repossuirmos": "repossuir",
    "repossuirá": "repossuir",
    "repossuirás": "repossuir",
    "repossuirão": "repossuir",
    "repossuiríamos": "repossuir",
    "repossuiríeis": "repossuir",
    "repossuis": "repossuir",
    "repossuiu": "repossuir",
    "repossuo": "repossuir",
    "repossuí": "repossuir",
    "repossuía": "repossuir",
    "repossuíam": "repossuir",
    "repossuíamo": "repossuir",
    "repossuíamos": "repossuir",
    "repossuías": "repossuir",
    "repossuída": "repossuir",
    "repossuídas": "repossuir",
    "repossuído": "repossuir",
    "repossuídos": "repossuir",
    "repossuíei": "repossuir",
    "repossuíeis": "repossuir",
    "repossuímo": "repossuir",
    "repossuímos": "repossuir",
    "repossuíra": "repossuir",
    "repossuíram": "repossuir",
    "repossuíramo": "repossuir",
    "repossuíramos": "repossuir",
    "repossuíras": "repossuir",
    "repossuíre": "repossuir",
    "repossuírei": "repossuir",
    "repossuíreis": "repossuir",
    "repossuírem": "repossuir",
    "repossuíres": "repossuir",
    "repossuís": "repossuir",
    "repossuísse": "repossuir",
    "repossuísseis": "repossuir",
    "repossuíssem": "repossuir",
    "repossuíssemos": "repossuir",
    "repossuísses": "repossuir",
    "repossuíste": "repossuir",
    "repossuístes": "repossuir",
    "reposta": "reposto",
    "repostada": "repostar",
    "repostadas": "repostar",
    "repostado": "repostar",
    "repostados": "repostar",
    "repostai": "repostar",
    "repostais": "repostar",
    "repostam": "repostar",
    "repostamo": "repostar",
    "repostamos": "repostar",
    "repostando": "repostar",
    "repostara": "repostar",
    "repostaram": "repostar",
    "repostaras": "repostar",
    "repostardes": "repostar",
    "repostarei": "repostar",
    "repostareis": "repostar",
    "repostarem": "repostar",
    "repostaremos": "repostar",
    "repostares": "repostar",
    "repostaria": "repostar",
    "repostariam": "repostar",
    "repostarias": "repostar",
    "repostarmo": "repostar",
    "repostarmos": "repostar",
    "repostará": "repostar",
    "repostarás": "repostar",
    "repostarão": "repostar",
    "repostaríamos": "repostar",
    "repostaríeis": "repostar",
    "repostas": "reposto",
    "repostasse": "repostar",
    "repostassem": "repostar",
    "repostasses": "repostar",
    "repostaste": "repostar",
    "repostastes": "repostar",
    "repostava": "repostar",
    "repostavam": "repostar",
    "repostavas": "repostar",
    "reposte": "repostar",
    "repostei": "repostar",
    "reposteiros": "reposteiro",
    "reposteis": "repostar",
    "repostem": "repostar",
    "repostemo": "repostar",
    "repostemos": "repostar",
    "repostes": "reposte",
    "reposto": "repostar",
    "repostos": "reposto",
    "repostou": "repostar",
    "repostámo": "repostar",
    "repostámos": "repostar",
    "repostáramo": "repostar",
    "repostáramos": "repostar",
    "repostáreis": "repostar",
    "repostásseis": "repostar",
    "repostássemos": "repostar",
    "repostávamo": "repostar",
    "repostávamos": "repostar",
    "repostáveis": "repostar",
    "repotreada": "repotrear",
    "repotreadas": "repotrear",
    "repotreado": "repotrear",
    "repotreados": "repotrear",
    "repotreai": "repotrear",
    "repotreais": "repotrear",
    "repotreamo": "repotrear",
    "repotreamos": "repotrear",
    "repotreando": "repotrear",
    "repotreara": "repotrear",
    "repotrearam": "repotrear",
    "repotrearas": "repotrear",
    "repotrearde": "repotrear",
    "repotreardes": "repotrear",
    "repotreare": "repotrear",
    "repotrearei": "repotrear",
    "repotreareis": "repotrear",
    "repotrearem": "repotrear",
    "repotrearemos": "repotrear",
    "repotreares": "repotrear",
    "repotrearia": "repotrear",
    "repotreariam": "repotrear",
    "repotrearias": "repotrear",
    "repotrearmo": "repotrear",
    "repotrearmos": "repotrear",
    "repotreará": "repotrear",
    "repotrearás": "repotrear",
    "repotrearão": "repotrear",
    "repotrearíamos": "repotrear",
    "repotrearíeis": "repotrear",
    "repotreasse": "repotrear",
    "repotreassem": "repotrear",
    "repotreasses": "repotrear",
    "repotreaste": "repotrear",
    "repotreastes": "repotrear",
    "repotreava": "repotrear",
    "repotreavam": "repotrear",
    "repotreavas": "repotrear",
    "repotreei": "repotrear",
    "repotreeis": "repotrear",
    "repotreemo": "repotrear",
    "repotreemos": "repotrear",
    "repotreia": "repotrear",
    "repotreiam": "repotrear",
    "repotreias": "repotrear",
    "repotreie": "repotrear",
    "repotreiem": "repotrear",
    "repotreies": "repotrear",
    "repotreio": "repotrear",
    "repotreou": "repotrear",
    "repotreá": "repotrear",
    "repotreámo": "repotrear",
    "repotreámos": "repotrear",
    "repotreáramo": "repotrear",
    "repotreáramos": "repotrear",
    "repotreárei": "repotrear",
    "repotreáreis": "repotrear",
    "repotreásseis": "repotrear",
    "repotreássemos": "repotrear",
    "repotreávamo": "repotrear",
    "repotreávamos": "repotrear",
    "repotreávei": "repotrear",
    "repotreáveis": "repotrear",
    "repotrona": "repotronar",
    "repotronada": "repotronar",
    "repotronadas": "repotronar",
    "repotronado": "repotronar",
    "repotronados": "repotronar",
    "repotronai": "repotronar",
    "repotronais": "repotronar",
    "repotronam": "repotronar",
    "repotronamo": "repotronar",
    "repotronamos": "repotronar",
    "repotronando": "repotronar",
    "repotronara": "repotronar",
    "repotronaram": "repotronar",
    "repotronaras": "repotronar",
    "repotronarde": "repotronar",
    "repotronardes": "repotronar",
    "repotronare": "repotronar",
    "repotronarei": "repotronar",
    "repotronareis": "repotronar",
    "repotronarem": "repotronar",
    "repotronaremos": "repotronar",
    "repotronares": "repotronar",
    "repotronaria": "repotronar",
    "repotronariam": "repotronar",
    "repotronarias": "repotronar",
    "repotronarmo": "repotronar",
    "repotronarmos": "repotronar",
    "repotronará": "repotronar",
    "repotronarás": "repotronar",
    "repotronarão": "repotronar",
    "repotronaríamos": "repotronar",
    "repotronaríeis": "repotronar",
    "repotronas": "repotronar",
    "repotronasse": "repotronar",
    "repotronassem": "repotronar",
    "repotronasses": "repotronar",
    "repotronaste": "repotronar",
    "repotronastes": "repotronar",
    "repotronava": "repotronar",
    "repotronavam": "repotronar",
    "repotronavas": "repotronar",
    "repotrone": "repotronar",
    "repotronei": "repotronar",
    "repotroneis": "repotronar",
    "repotronem": "repotronar",
    "repotronemo": "repotronar",
    "repotronemos": "repotronar",
    "repotrones": "repotronar",
    "repotrono": "repotronar",
    "repotronou": "repotronar",
    "repotroná": "repotronar",
    "repotronámo": "repotronar",
    "repotronámos": "repotronar",
    "repotronáramo": "repotronar",
    "repotronáramos": "repotronar",
    "repotronárei": "repotronar",
    "repotronáreis": "repotronar",
    "repotronásseis": "repotronar",
    "repotronássemos": "repotronar",
    "repotronávamo": "repotronar",
    "repotronávamos": "repotronar",
    "repotronávei": "repotronar",
    "repotronáveis": "repotronar",
    "repousa": "repousar",
    "repousada": "repousar",
    "repousadas": "repousar",
    "repousado": "repousar",
    "repousados": "repousar",
    "repousai": "repousar",
    "repousais": "repousar",
    "repousam": "repousar",
    "repousamo": "repousar",
    "repousamos": "repousar",
    "repousando": "repousar",
    "repousantes": "repousante",
    "repousara": "repousar",
    "repousaram": "repousar",
    "repousaras": "repousar",
    "repousarde": "repousar",
    "repousardes": "repousar",
    "repousare": "repousar",
    "repousarei": "repousar",
    "repousareis": "repousar",
    "repousarem": "repousar",
    "repousaremos": "repousar",
    "repousares": "repousar",
    "repousaria": "repousar",
    "repousariam": "repousar",
    "repousarias": "repousar",
    "repousarmo": "repousar",
    "repousarmos": "repousar",
    "repousará": "repousar",
    "repousarás": "repousar",
    "repousarão": "repousar",
    "repousaríamos": "repousar",
    "repousaríeis": "repousar",
    "repousas": "repousar",
    "repousasse": "repousar",
    "repousassem": "repousar",
    "repousasses": "repousar",
    "repousaste": "repousar",
    "repousastes": "repousar",
    "repousava": "repousar",
    "repousavam": "repousar",
    "repousavas": "repousar",
    "repouse": "repousar",
    "repousei": "repousar",
    "repouseis": "repousar",
    "repousem": "repousar",
    "repousemo": "repousar",
    "repousemos": "repousar",
    "repouses": "repousar",
    "repouso": "repousar",
    "repousos": "repouso",
    "repousou": "repousar",
    "repousá": "repousar",
    "repousámo": "repousar",
    "repousámos": "repousar",
    "repousáramo": "repousar",
    "repousáramos": "repousar",
    "repousárei": "repousar",
    "repousáreis": "repousar",
    "repousásseis": "repousar",
    "repousássemos": "repousar",
    "repousávamo": "repousar",
    "repousávamos": "repousar",
    "repousávei": "repousar",
    "repousáveis": "repousar",
    "repovoa": "repovoar",
    "repovoada": "repovoar",
    "repovoadas": "repovoar",
    "repovoado": "repovoar",
    "repovoados": "repovoar",
    "repovoai": "repovoar",
    "repovoais": "repovoar",
    "repovoam": "repovoar",
    "repovoamentos": "repovoamento",
    "repovoamo": "repovoar",
    "repovoamos": "repovoar",
    "repovoando": "repovoar",
    "repovoara": "repovoar",
    "repovoaram": "repovoar",
    "repovoaras": "repovoar",
    "repovoarde": "repovoar",
    "repovoardes": "repovoar",
    "repovoare": "repovoar",
    "repovoarei": "repovoar",
    "repovoareis": "repovoar",
    "repovoarem": "repovoar",
    "repovoaremos": "repovoar",
    "repovoares": "repovoar",
    "repovoaria": "repovoar",
    "repovoariam": "repovoar",
    "repovoarias": "repovoar",
    "repovoarmo": "repovoar",
    "repovoarmos": "repovoar",
    "repovoará": "repovoar",
    "repovoarás": "repovoar",
    "repovoarão": "repovoar",
    "repovoaríamos": "repovoar",
    "repovoaríeis": "repovoar",
    "repovoas": "repovoar",
    "repovoasse": "repovoar",
    "repovoassem": "repovoar",
    "repovoasses": "repovoar",
    "repovoaste": "repovoar",
    "repovoastes": "repovoar",
    "repovoava": "repovoar",
    "repovoavam": "repovoar",
    "repovoavas": "repovoar",
    "repovoações": "repovoação",
    "repovoe": "repovoar",
    "repovoei": "repovoar",
    "repovoeis": "repovoar",
    "repovoem": "repovoar",
    "repovoemo": "repovoar",
    "repovoemos": "repovoar",
    "repovoes": "repovoar",
    "repovoo": "repovoar",
    "repovoou": "repovoar",
    "repovoá": "repovoar",
    "repovoámo": "repovoar",
    "repovoámos": "repovoar",
    "repovoáramo": "repovoar",
    "repovoáramos": "repovoar",
    "repovoárei": "repovoar",
    "repovoáreis": "repovoar",
    "repovoásseis": "repovoar",
    "repovoássemos": "repovoar",
    "repovoávamo": "repovoar",
    "repovoávamos": "repovoar",
    "repovoávei": "repovoar",
    "repovoáveis": "repovoável",
    "repreenda": "repreender",
    "repreendais": "repreender",
    "repreendam": "repreender",
    "repreendamo": "repreender",
    "repreendamos": "repreender",
    "repreendas": "repreender",
    "repreende": "repreender",
    "repreendedora": "repreendedor",
    "repreendedoras": "repreendedor",
    "repreendedores": "repreendedor",
    "repreendei": "repreender",
    "repreendeis": "repreender",
    "repreendem": "repreender",
    "repreendemo": "repreender",
    "repreendemos": "repreender",
    "repreendendo": "repreender",
    "repreendera": "repreender",
    "repreenderam": "repreender",
    "repreenderas": "repreender",
    "repreenderde": "repreender",
    "repreenderdes": "repreender",
    "repreendere": "repreender",
    "repreenderei": "repreender",
    "repreendereis": "repreender",
    "repreenderem": "repreender",
    "repreenderemos": "repreender",
    "repreenderes": "repreender",
    "repreenderia": "repreender",
    "repreenderiam": "repreender",
    "repreenderias": "repreender",
    "repreendermo": "repreender",
    "repreendermos": "repreender",
    "repreenderá": "repreender",
    "repreenderás": "repreender",
    "repreenderão": "repreender",
    "repreenderíamos": "repreender",
    "repreenderíeis": "repreender",
    "repreendes": "repreender",
    "repreendesse": "repreender",
    "repreendessem": "repreender",
    "repreendesses": "repreender",
    "repreendeste": "repreender",
    "repreendestes": "repreender",
    "repreendeu": "repreender",
    "repreendi": "repreender",
    "repreendia": "repreender",
    "repreendiam": "repreender",
    "repreendias": "repreender",
    "repreendida": "repreendido",
    "repreendidas": "repreendido",
    "repreendido": "repreender",
    "repreendidos": "repreendido",
    "repreendo": "repreender",
    "repreendê": "repreender",
    "repreendêramo": "repreender",
    "repreendêramos": "repreender",
    "repreendêrei": "repreender",
    "repreendêreis": "repreender",
    "repreendêsseis": "repreender",
    "repreendêssemos": "repreender",
    "repreendíamo": "repreender",
    "repreendíamos": "repreender",
    "repreendíei": "repreender",
    "repreendíeis": "repreender",
    "repreensiva": "repreensivo",
    "repreensivas": "repreensivo",
    "repreensivos": "repreensivo",
    "repreensora": "repreensor",
    "repreensoras": "repreensor",
    "repreensores": "repreensor",
    "repreensíveis": "repreensível",
    "repreensões": "repreensão",
    "reprega": "repregar",
    "repregada": "repregar",
    "repregadas": "repregar",
    "repregado": "repregar",
    "repregados": "repregar",
    "repregai": "repregar",
    "repregais": "repregar",
    "repregam": "repregar",
    "repregamo": "repregar",
    "repregamos": "repregar",
    "repregando": "repregar",
    "repregara": "repregar",
    "repregaram": "repregar",
    "repregaras": "repregar",
    "repregarde": "repregar",
    "repregardes": "repregar",
    "repregare": "repregar",
    "repregarei": "repregar",
    "repregareis": "repregar",
    "repregarem": "repregar",
    "repregaremos": "repregar",
    "repregares": "repregar",
    "repregaria": "repregar",
    "repregariam": "repregar",
    "repregarias": "repregar",
    "repregarmo": "repregar",
    "repregarmos": "repregar",
    "repregará": "repregar",
    "repregarás": "repregar",
    "repregarão": "repregar",
    "repregaríamos": "repregar",
    "repregaríeis": "repregar",
    "repregas": "repregar",
    "repregasse": "repregar",
    "repregassem": "repregar",
    "repregasses": "repregar",
    "repregaste": "repregar",
    "repregastes": "repregar",
    "repregava": "repregar",
    "repregavam": "repregar",
    "repregavas": "repregar",
    "reprego": "repregar",
    "repregos": "reprego",
    "repregou": "repregar",
    "repregue": "repregar",
    "repreguei": "repregar",
    "repregueis": "repregar",
    "repreguem": "repregar",
    "repreguemo": "repregar",
    "repreguemos": "repregar",
    "repregues": "repregar",
    "repregá": "repregar",
    "repregámo": "repregar",
    "repregámos": "repregar",
    "repregáramo": "repregar",
    "repregáramos": "repregar",
    "repregárei": "repregar",
    "repregáreis": "repregar",
    "repregásseis": "repregar",
    "repregássemos": "repregar",
    "repregávamo": "repregar",
    "repregávamos": "repregar",
    "repregávei": "repregar",
    "repregáveis": "repregar",
    "represa": "represo",
    "represada": "represar",
    "represadas": "represar",
    "represado": "represar",
    "represadora": "represador",
    "represadoras": "represador",
    "represadores": "represador",
    "represados": "represar",
    "represaduras": "represadura",
    "represai": "represar",
    "represais": "represar",
    "represam": "represar",
    "represamo": "represar",
    "represamos": "represar",
    "represando": "represar",
    "represara": "represar",
    "represaram": "represar",
    "represaras": "represar",
    "represarde": "represar",
    "represardes": "represar",
    "represare": "represar",
    "represarei": "represar",
    "represareis": "represar",
    "represarem": "represar",
    "represaremos": "represar",
    "represares": "represar",
    "represaria": "represar",
    "represariam": "represar",
    "represarias": "represar",
    "represarmo": "represar",
    "represarmos": "represar",
    "represará": "represar",
    "represarás": "represar",
    "represarão": "represar",
    "represaríamos": "represar",
    "represaríeis": "represar",
    "represas": "represo",
    "represasse": "represar",
    "represassem": "represar",
    "represasses": "represar",
    "represaste": "represar",
    "represastes": "represar",
    "represava": "represar",
    "represavam": "represar",
    "represavas": "represar",
    "represe": "represar",
    "represei": "represar",
    "represeis": "represar",
    "represem": "represar",
    "represemo": "represar",
    "represemos": "represar",
    "representa": "representar",
    "representada": "representar",
    "representadas": "representar",
    "representado": "representar",
    "representadora": "representador",
    "representadoras": "representador",
    "representadores": "representador",
    "representados": "representar",
    "representai": "representar",
    "representais": "representar",
    "representam": "representar",
    "representamo": "representar",
    "representamos": "representar",
    "representando": "representar",
    "representantes": "representante",
    "representantezinha": "representante",
    "representantezinhas": "representante",
    "representantezinho": "representante",
    "representantezinhos": "representante",
    "representantezita": "representante",
    "representantezitas": "representante",
    "representantezito": "representante",
    "representantezitos": "representante",
    "representara": "representar",
    "representaram": "representar",
    "representaras": "representar",
    "representarde": "representar",
    "representardes": "representar",
    "representare": "representar",
    "representarei": "representar",
    "representareis": "representar",
    "representarem": "representar",
    "representaremos": "representar",
    "representares": "representar",
    "representaria": "representar",
    "representariam": "representar",
    "representarias": "representar",
    "representarmo": "representar",
    "representarmos": "representar",
    "representará": "representar",
    "representarás": "representar",
    "representarão": "representar",
    "representaríamos": "representar",
    "representaríeis": "representar",
    "representas": "representar",
    "representasse": "representar",
    "representassem": "representar",
    "representasses": "representar",
    "representaste": "representar",
    "representastes": "representar",
    "representativa": "representativo",
    "representativas": "representativo",
    "representatividades": "representatividade",
    "representativos": "representativo",
    "representava": "representar",
    "representavam": "representar",
    "representavas": "representar",
    "representações": "representação",
    "represente": "representar",
    "representeada": "representear",
    "representeadas": "representear",
    "representeado": "representear",
    "representeados": "representear",
    "representeai": "representear",
    "representeais": "representear",
    "representeamo": "representear",
    "representeamos": "representear",
    "representeando": "representear",
    "representeara": "representear",
    "representearam": "representear",
    "representearas": "representear",
    "representearde": "representear",
    "representeardes": "representear",
    "representeare": "representear",
    "representearei": "representear",
    "representeareis": "representear",
    "representearem": "representear",
    "representearemos": "representear",
    "representeares": "representear",
    "representearia": "representear",
    "representeariam": "representear",
    "representearias": "representear",
    "representearmo": "representear",
    "representearmos": "representear",
    "representeará": "representear",
    "representearás": "representear",
    "representearão": "representear",
    "representearíamos": "representear",
    "representearíeis": "representear",
    "representeasse": "representear",
    "representeassem": "representear",
    "representeasses": "representear",
    "representeaste": "representear",
    "representeastes": "representear",
    "representeava": "representear",
    "representeavam": "representear",
    "representeavas": "representear",
    "representeei": "representear",
    "representeeis": "representear",
    "representeemo": "representear",
    "representeemos": "representear",
    "representei": "representar",
    "representeia": "representear",
    "representeiam": "representear",
    "representeias": "representear",
    "representeie": "representear",
    "representeiem": "representear",
    "representeies": "representear",
    "representeio": "representear",
    "representeis": "representar",
    "representem": "representar",
    "representemo": "representar",
    "representemos": "representar",
    "representeou": "representear",
    "representes": "representar",
    "representeá": "representear",
    "representeámo": "representear",
    "representeámos": "representear",
    "representeáramo": "representear",
    "representeáramos": "representear",
    "representeárei": "representear",
    "representeáreis": "representear",
    "representeásseis": "representear",
    "representeássemos": "representear",
    "representeávamo": "representear",
    "representeávamos": "representear",
    "representeávei": "representear",
    "representeáveis": "representear",
    "represento": "representar",
    "representou": "representar",
    "representá": "representar",
    "representámo": "representar",
    "representámos": "representar",
    "representáramo": "representar",
    "representáramos": "representar",
    "representárei": "representar",
    "representáreis": "representar",
    "representásseis": "representar",
    "representássemos": "representar",
    "representávamo": "representar",
    "representávamos": "representar",
    "representávei": "representar",
    "representáveis": "representável",
    "represes": "represar",
    "represo": "represar",
    "represos": "represo",
    "represou": "represar",
    "repressiva": "repressivo",
    "repressivas": "repressivo",
    "repressivos": "repressivo",
    "repressora": "repressor",
    "repressoras": "repressor",
    "repressorazinha": "repressor",
    "repressorazinhas": "repressor",
    "repressorazita": "repressor",
    "repressorazitas": "repressor",
    "repressores": "repressor",
    "repressorzinho": "repressor",
    "repressorzinhos": "repressor",
    "repressorzito": "repressor",
    "repressorzitos": "repressor",
    "repressões": "repressão",
    "represá": "represar",
    "represálias": "represália",
    "represámo": "represar",
    "represámos": "represar",
    "represáramo": "represar",
    "represáramos": "represar",
    "represárei": "represar",
    "represáreis": "represar",
    "represásseis": "represar",
    "represássemos": "represar",
    "represávamo": "represar",
    "represávamos": "represar",
    "represávei": "represar",
    "represáveis": "represar",
    "reprima": "reprimir",
    "reprimais": "reprimir",
    "reprimam": "reprimir",
    "reprimamo": "reprimir",
    "reprimamos": "reprimir",
    "reprimas": "reprimir",
    "reprime": "reprimir",
    "reprimem": "reprimir",
    "reprimendas": "reprimenda",
    "reprimes": "reprimir",
    "reprimi": "reprimir",
    "reprimia": "reprimir",
    "reprimiam": "reprimir",
    "reprimias": "reprimir",
    "reprimida": "reprimir",
    "reprimidas": "reprimir",
    "reprimido": "reprimir",
    "reprimidora": "reprimidor",
    "reprimidoras": "reprimidor",
    "reprimidores": "reprimidor",
    "reprimidos": "reprimir",
    "reprimidíssima": "reprimido",
    "reprimidíssimas": "reprimido",
    "reprimidíssimo": "reprimido",
    "reprimidíssimos": "reprimido",
    "reprimimo": "reprimir",
    "reprimimos": "reprimir",
    "reprimindo": "reprimir",
    "reprimira": "reprimir",
    "reprimiram": "reprimir",
    "reprimiras": "reprimir",
    "reprimirde": "reprimir",
    "reprimirdes": "reprimir",
    "reprimire": "reprimir",
    "reprimirei": "reprimir",
    "reprimireis": "reprimir",
    "reprimirem": "reprimir",
    "reprimiremos": "reprimir",
    "reprimires": "reprimir",
    "reprimiria": "reprimir",
    "reprimiriam": "reprimir",
    "reprimirias": "reprimir",
    "reprimirmo": "reprimir",
    "reprimirmos": "reprimir",
    "reprimirá": "reprimir",
    "reprimirás": "reprimir",
    "reprimirão": "reprimir",
    "reprimiríamos": "reprimir",
    "reprimiríeis": "reprimir",
    "reprimis": "reprimir",
    "reprimisse": "reprimir",
    "reprimissem": "reprimir",
    "reprimisses": "reprimir",
    "reprimiste": "reprimir",
    "reprimistes": "reprimir",
    "reprimiu": "reprimir",
    "reprimo": "reprimir",
    "reprimíamo": "reprimir",
    "reprimíamos": "reprimir",
    "reprimíei": "reprimir",
    "reprimíeis": "reprimir",
    "reprimíramo": "reprimir",
    "reprimíramos": "reprimir",
    "reprimírei": "reprimir",
    "reprimíreis": "reprimir",
    "reprimísseis": "reprimir",
    "reprimíssemos": "reprimir",
    "reprimíveis": "reprimível",
    "reprincipia": "reprincipiar",
    "reprincipiada": "reprincipiar",
    "reprincipiadas": "reprincipiar",
    "reprincipiado": "reprincipiar",
    "reprincipiados": "reprincipiar",
    "reprincipiai": "reprincipiar",
    "reprincipiais": "reprincipiar",
    "reprincipiam": "reprincipiar",
    "reprincipiamo": "reprincipiar",
    "reprincipiamos": "reprincipiar",
    "reprincipiando": "reprincipiar",
    "reprincipiara": "reprincipiar",
    "reprincipiaram": "reprincipiar",
    "reprincipiaras": "reprincipiar",
    "reprincipiarde": "reprincipiar",
    "reprincipiardes": "reprincipiar",
    "reprincipiare": "reprincipiar",
    "reprincipiarei": "reprincipiar",
    "reprincipiareis": "reprincipiar",
    "reprincipiarem": "reprincipiar",
    "reprincipiaremos": "reprincipiar",
    "reprincipiares": "reprincipiar",
    "reprincipiaria": "reprincipiar",
    "reprincipiariam": "reprincipiar",
    "reprincipiarias": "reprincipiar",
    "reprincipiarmo": "reprincipiar",
    "reprincipiarmos": "reprincipiar",
    "reprincipiará": "reprincipiar",
    "reprincipiarás": "reprincipiar",
    "reprincipiarão": "reprincipiar",
    "reprincipiaríamos": "reprincipiar",
    "reprincipiaríeis": "reprincipiar",
    "reprincipias": "reprincipiar",
    "reprincipiasse": "reprincipiar",
    "reprincipiassem": "reprincipiar",
    "reprincipiasses": "reprincipiar",
    "reprincipiaste": "reprincipiar",
    "reprincipiastes": "reprincipiar",
    "reprincipiava": "reprincipiar",
    "reprincipiavam": "reprincipiar",
    "reprincipiavas": "reprincipiar",
    "reprincipie": "reprincipiar",
    "reprincipiei": "reprincipiar",
    "reprincipieis": "reprincipiar",
    "reprincipiem": "reprincipiar",
    "reprincipiemo": "reprincipiar",
    "reprincipiemos": "reprincipiar",
    "reprincipies": "reprincipiar",
    "reprincipio": "reprincipiar",
    "reprincipiou": "reprincipiar",
    "reprincipiá": "reprincipiar",
    "reprincipiámo": "reprincipiar",
    "reprincipiámos": "reprincipiar",
    "reprincipiáramo": "reprincipiar",
    "reprincipiáramos": "reprincipiar",
    "reprincipiárei": "reprincipiar",
    "reprincipiáreis": "reprincipiar",
    "reprincipiásseis": "reprincipiar",
    "reprincipiássemos": "reprincipiar",
    "reprincipiávamo": "reprincipiar",
    "reprincipiávamos": "reprincipiar",
    "reprincipiávei": "reprincipiar",
    "reprincipiáveis": "reprincipiar",
    "reprises": "reprise",
    "repristinações": "repristinação",
    "reprivatiza": "reprivatizar",
    "reprivatizada": "reprivatizar",
    "reprivatizadas": "reprivatizar",
    "reprivatizado": "reprivatizar",
    "reprivatizados": "reprivatizar",
    "reprivatizai": "reprivatizar",
    "reprivatizais": "reprivatizar",
    "reprivatizam": "reprivatizar",
    "reprivatizamo": "reprivatizar",
    "reprivatizamos": "reprivatizar",
    "reprivatizando": "reprivatizar",
    "reprivatizara": "reprivatizar",
    "reprivatizaram": "reprivatizar",
    "reprivatizaras": "reprivatizar",
    "reprivatizarde": "reprivatizar",
    "reprivatizardes": "reprivatizar",
    "reprivatizare": "reprivatizar",
    "reprivatizarei": "reprivatizar",
    "reprivatizareis": "reprivatizar",
    "reprivatizarem": "reprivatizar",
    "reprivatizaremos": "reprivatizar",
    "reprivatizares": "reprivatizar",
    "reprivatizaria": "reprivatizar",
    "reprivatizariam": "reprivatizar",
    "reprivatizarias": "reprivatizar",
    "reprivatizarmo": "reprivatizar",
    "reprivatizarmos": "reprivatizar",
    "reprivatizará": "reprivatizar",
    "reprivatizarás": "reprivatizar",
    "reprivatizarão": "reprivatizar",
    "reprivatizaríamos": "reprivatizar",
    "reprivatizaríeis": "reprivatizar",
    "reprivatizas": "reprivatizar",
    "reprivatizasse": "reprivatizar",
    "reprivatizassem": "reprivatizar",
    "reprivatizasses": "reprivatizar",
    "reprivatizaste": "reprivatizar",
    "reprivatizastes": "reprivatizar",
    "reprivatizava": "reprivatizar",
    "reprivatizavam": "reprivatizar",
    "reprivatizavas": "reprivatizar",
    "reprivatizações": "reprivatização",
    "reprivatize": "reprivatizar",
    "reprivatizei": "reprivatizar",
    "reprivatizeis": "reprivatizar",
    "reprivatizem": "reprivatizar",
    "reprivatizemo": "reprivatizar",
    "reprivatizemos": "reprivatizar",
    "reprivatizes": "reprivatizar",
    "reprivatizo": "reprivatizar",
    "reprivatizou": "reprivatizar",
    "reprivatizá": "reprivatizar",
    "reprivatizámo": "reprivatizar",
    "reprivatizámos": "reprivatizar",
    "reprivatizáramo": "reprivatizar",
    "reprivatizáramos": "reprivatizar",
    "reprivatizárei": "reprivatizar",
    "reprivatizáreis": "reprivatizar",
    "reprivatizásseis": "reprivatizar",
    "reprivatizássemos": "reprivatizar",
    "reprivatizávamo": "reprivatizar",
    "reprivatizávamos": "reprivatizar",
    "reprivatizávei": "reprivatizar",
    "reprivatizáveis": "reprivatizar",
    "reprobatória": "reprobatório",
    "reprobatórias": "reprobatório",
    "reprobatórios": "reprobatório",
    "reprocessamentos": "reprocessamento",
    "reprocha": "reprochar",
    "reprochada": "reprochar",
    "reprochadas": "reprochar",
    "reprochado": "reprochar",
    "reprochados": "reprochar",
    "reprochai": "reprochar",
    "reprochais": "reprochar",
    "reprocham": "reprochar",
    "reprochamo": "reprochar",
    "reprochamos": "reprochar",
    "reprochando": "reprochar",
    "reprochara": "reprochar",
    "reprocharam": "reprochar",
    "reprocharas": "reprochar",
    "reprocharde": "reprochar",
    "reprochardes": "reprochar",
    "reprochare": "reprochar",
    "reprocharei": "reprochar",
    "reprochareis": "reprochar",
    "reprocharem": "reprochar",
    "reprocharemos": "reprochar",
    "reprochares": "reprochar",
    "reprocharia": "reprochar",
    "reprochariam": "reprochar",
    "reprocharias": "reprochar",
    "reprocharmo": "reprochar",
    "reprocharmos": "reprochar",
    "reprochará": "reprochar",
    "reprocharás": "reprochar",
    "reprocharão": "reprochar",
    "reprocharíamos": "reprochar",
    "reprocharíeis": "reprochar",
    "reprochas": "reprochar",
    "reprochasse": "reprochar",
    "reprochassem": "reprochar",
    "reprochasses": "reprochar",
    "reprochaste": "reprochar",
    "reprochastes": "reprochar",
    "reprochava": "reprochar",
    "reprochavam": "reprochar",
    "reprochavas": "reprochar",
    "reproche": "reprochar",
    "reprochei": "reprochar",
    "reprocheis": "reprochar",
    "reprochem": "reprochar",
    "reprochemo": "reprochar",
    "reprochemos": "reprochar",
    "reproches": "reproche",
    "reprocho": "reprochar",
    "reprochou": "reprochar",
    "reprochá": "reprochar",
    "reprochámo": "reprochar",
    "reprochámos": "reprochar",
    "reprocháramo": "reprochar",
    "reprocháramos": "reprochar",
    "reprochárei": "reprochar",
    "reprocháreis": "reprochar",
    "reprochásseis": "reprochar",
    "reprochássemos": "reprochar",
    "reprochávamo": "reprochar",
    "reprochávamos": "reprochar",
    "reprochávei": "reprochar",
    "reprocháveis": "reprochar",
    "reprodutibilidades": "reprodutibilidade",
    "reprodutiva": "reprodutivo",
    "reprodutivas": "reprodutivo",
    "reprodutivos": "reprodutivo",
    "reprodutora": "reprodutor",
    "reprodutoras": "reprodutor",
    "reprodutorazinha": "reprodutor",
    "reprodutorazinhas": "reprodutor",
    "reprodutorazita": "reprodutor",
    "reprodutorazitas": "reprodutor",
    "reprodutores": "reprodutor",
    "reprodutorzinho": "reprodutor",
    "reprodutorzinhos": "reprodutor",
    "reprodutorzito": "reprodutor",
    "reprodutorzitos": "reprodutor",
    "reprodutíveis": "reprodutível",
    "reproduz": "reproduzir",
    "reproduza": "reproduzir",
    "reproduzais": "reproduzir",
    "reproduzam": "reproduzir",
    "reproduzamo": "reproduzir",
    "reproduzamos": "reproduzir",
    "reproduzas": "reproduzir",
    "reproduze": "reproduzir",
    "reproduzem": "reproduzir",
    "reproduzes": "reproduzir",
    "reproduzi": "reproduzir",
    "reproduzia": "reproduzir",
    "reproduziam": "reproduzir",
    "reproduzias": "reproduzir",
    "reproduzida": "reproduzir",
    "reproduzidas": "reproduzir",
    "reproduzido": "reproduzir",
    "reproduzidos": "reproduzir",
    "reproduzimo": "reproduzir",
    "reproduzimos": "reproduzir",
    "reproduzindo": "reproduzir",
    "reproduzira": "reproduzir",
    "reproduziram": "reproduzir",
    "reproduziras": "reproduzir",
    "reproduzirde": "reproduzir",
    "reproduzirdes": "reproduzir",
    "reproduzire": "reproduzir",
    "reproduzirei": "reproduzir",
    "reproduzireis": "reproduzir",
    "reproduzirem": "reproduzir",
    "reproduziremos": "reproduzir",
    "reproduzires": "reproduzir",
    "reproduziria": "reproduzir",
    "reproduziriam": "reproduzir",
    "reproduzirias": "reproduzir",
    "reproduzirmo": "reproduzir",
    "reproduzirmos": "reproduzir",
    "reproduzirá": "reproduzir",
    "reproduzirás": "reproduzir",
    "reproduzirão": "reproduzir",
    "reproduziríamos": "reproduzir",
    "reproduziríeis": "reproduzir",
    "reproduzis": "reproduzir",
    "reproduzisse": "reproduzir",
    "reproduzissem": "reproduzir",
    "reproduzisses": "reproduzir",
    "reproduziste": "reproduzir",
    "reproduzistes": "reproduzir",
    "reproduziu": "reproduzir",
    "reproduzo": "reproduzir",
    "reproduzíamo": "reproduzir",
    "reproduzíamos": "reproduzir",
    "reproduzíei": "reproduzir",
    "reproduzíeis": "reproduzir",
    "reproduzíramo": "reproduzir",
    "reproduzíramos": "reproduzir",
    "reproduzírei": "reproduzir",
    "reproduzíreis": "reproduzir",
    "reproduzísseis": "reproduzir",
    "reproduzíssemos": "reproduzir",
    "reproduzíveis": "reproduzível",
    "reproduções": "reprodução",
    "reprofunda": "reprofundar",
    "reprofundada": "reprofundar",
    "reprofundadas": "reprofundar",
    "reprofundado": "reprofundar",
    "reprofundados": "reprofundar",
    "reprofundai": "reprofundar",
    "reprofundais": "reprofundar",
    "reprofundam": "reprofundar",
    "reprofundamo": "reprofundar",
    "reprofundamos": "reprofundar",
    "reprofundando": "reprofundar",
    "reprofundara": "reprofundar",
    "reprofundaram": "reprofundar",
    "reprofundaras": "reprofundar",
    "reprofundarde": "reprofundar",
    "reprofundardes": "reprofundar",
    "reprofundare": "reprofundar",
    "reprofundarei": "reprofundar",
    "reprofundareis": "reprofundar",
    "reprofundarem": "reprofundar",
    "reprofundaremos": "reprofundar",
    "reprofundares": "reprofundar",
    "reprofundaria": "reprofundar",
    "reprofundariam": "reprofundar",
    "reprofundarias": "reprofundar",
    "reprofundarmo": "reprofundar",
    "reprofundarmos": "reprofundar",
    "reprofundará": "reprofundar",
    "reprofundarás": "reprofundar",
    "reprofundarão": "reprofundar",
    "reprofundaríamos": "reprofundar",
    "reprofundaríeis": "reprofundar",
    "reprofundas": "reprofundar",
    "reprofundasse": "reprofundar",
    "reprofundassem": "reprofundar",
    "reprofundasses": "reprofundar",
    "reprofundaste": "reprofundar",
    "reprofundastes": "reprofundar",
    "reprofundava": "reprofundar",
    "reprofundavam": "reprofundar",
    "reprofundavas": "reprofundar",
    "reprofunde": "reprofundar",
    "reprofundei": "reprofundar",
    "reprofundeis": "reprofundar",
    "reprofundem": "reprofundar",
    "reprofundemo": "reprofundar",
    "reprofundemos": "reprofundar",
    "reprofundes": "reprofundar",
    "reprofundo": "reprofundar",
    "reprofundou": "reprofundar",
    "reprofundá": "reprofundar",
    "reprofundámo": "reprofundar",
    "reprofundámos": "reprofundar",
    "reprofundáramo": "reprofundar",
    "reprofundáramos": "reprofundar",
    "reprofundárei": "reprofundar",
    "reprofundáreis": "reprofundar",
    "reprofundásseis": "reprofundar",
    "reprofundássemos": "reprofundar",
    "reprofundávamo": "reprofundar",
    "reprofundávamos": "reprofundar",
    "reprofundávei": "reprofundar",
    "reprofundáveis": "reprofundar",
    "reprografias": "reprografia",
    "reprogramações": "reprogramação",
    "reprometa": "reprometer",
    "reprometais": "reprometer",
    "reprometam": "reprometer",
    "reprometamo": "reprometer",
    "reprometamos": "reprometer",
    "reprometas": "reprometer",
    "repromete": "reprometer",
    "reprometei": "reprometer",
    "reprometeis": "reprometer",
    "reprometem": "reprometer",
    "reprometemo": "reprometer",
    "reprometemos": "reprometer",
    "reprometendo": "reprometer",
    "reprometera": "reprometer",
    "reprometeram": "reprometer",
    "reprometeras": "reprometer",
    "reprometerde": "reprometer",
    "reprometerdes": "reprometer",
    "reprometere": "reprometer",
    "reprometerei": "reprometer",
    "reprometereis": "reprometer",
    "reprometerem": "reprometer",
    "reprometeremos": "reprometer",
    "reprometeres": "reprometer",
    "reprometeria": "reprometer",
    "reprometeriam": "reprometer",
    "reprometerias": "reprometer",
    "reprometermo": "reprometer",
    "reprometermos": "reprometer",
    "reprometerá": "reprometer",
    "reprometerás": "reprometer",
    "reprometerão": "reprometer",
    "reprometeríamos": "reprometer",
    "reprometeríeis": "reprometer",
    "reprometes": "reprometer",
    "reprometesse": "reprometer",
    "reprometessem": "reprometer",
    "reprometesses": "reprometer",
    "reprometeste": "reprometer",
    "reprometestes": "reprometer",
    "reprometeu": "reprometer",
    "reprometi": "reprometer",
    "reprometia": "reprometer",
    "reprometiam": "reprometer",
    "reprometias": "reprometer",
    "reprometida": "reprometer",
    "reprometidas": "reprometer",
    "reprometido": "reprometer",
    "reprometidos": "reprometer",
    "reprometo": "reprometer",
    "reprometê": "reprometer",
    "reprometêramo": "reprometer",
    "reprometêramos": "reprometer",
    "reprometêrei": "reprometer",
    "reprometêreis": "reprometer",
    "reprometêsseis": "reprometer",
    "reprometêssemos": "reprometer",
    "reprometíamo": "reprometer",
    "reprometíamos": "reprometer",
    "reprometíei": "reprometer",
    "reprometíeis": "reprometer",
    "repromissões": "repromissão",
    "reprova": "reprover",
    "reprovada": "reprovar",
    "reprovadas": "reprovar",
    "reprovadazinha": "reprovado",
    "reprovadazinhas": "reprovado",
    "reprovadazita": "reprovado",
    "reprovadazitas": "reprovado",
    "reprovadinha": "reprovado",
    "reprovadinhas": "reprovado",
    "reprovadinho": "reprovado",
    "reprovadinhos": "reprovado",
    "reprovadita": "reprovado",
    "reprovaditas": "reprovado",
    "reprovadito": "reprovado",
    "reprovaditos": "reprovado",
    "reprovado": "reprovar",
    "reprovadora": "reprovador",
    "reprovadoras": "reprovador",
    "reprovadores": "reprovador",
    "reprovados": "reprovar",
    "reprovadozinho": "reprovado",
    "reprovadozinhos": "reprovado",
    "reprovadozito": "reprovado",
    "reprovadozitos": "reprovado",
    "reprovai": "reprovar",
    "reprovais": "reprover",
    "reprovam": "reprover",
    "reprovamo": "reprover",
    "reprovamos": "reprover",
    "reprovando": "reprovar",
    "reprovara": "reprovar",
    "reprovaram": "reprovar",
    "reprovaras": "reprovar",
    "reprovarde": "reprovar",
    "reprovardes": "reprovar",
    "reprovare": "reprovar",
    "reprovarei": "reprovar",
    "reprovareis": "reprovar",
    "reprovarem": "reprovar",
    "reprovaremos": "reprovar",
    "reprovares": "reprovar",
    "reprovaria": "reprovar",
    "reprovariam": "reprovar",
    "reprovarias": "reprovar",
    "reprovarmo": "reprovar",
    "reprovarmos": "reprovar",
    "reprovará": "reprovar",
    "reprovarás": "reprovar",
    "reprovarão": "reprovar",
    "reprovaríamos": "reprovar",
    "reprovaríeis": "reprovar",
    "reprovas": "reprover",
    "reprovasse": "reprovar",
    "reprovassem": "reprovar",
    "reprovasses": "reprovar",
    "reprovaste": "reprovar",
    "reprovastes": "reprovar",
    "reprovava": "reprovar",
    "reprovavam": "reprovar",
    "reprovavas": "reprovar",
    "reprovações": "reprovação",
    "reprove": "reprover",
    "reprovei": "reprover",
    "reproveis": "reprover",
    "reprovem": "reprover",
    "reprovemo": "reprover",
    "reprovemos": "reprover",
    "reprovendo": "reprover",
    "reprovera": "reprover",
    "reproveram": "reprover",
    "reproveras": "reprover",
    "reproverde": "reprover",
    "reproverdes": "reprover",
    "reprovere": "reprover",
    "reproverei": "reprover",
    "reprovereis": "reprover",
    "reproverem": "reprover",
    "reproveremos": "reprover",
    "reproveres": "reprover",
    "reproveria": "reprover",
    "reproveriam": "reprover",
    "reproverias": "reprover",
    "reprovermo": "reprover",
    "reprovermos": "reprover",
    "reproverá": "reprover",
    "reproverás": "reprover",
    "reproverão": "reprover",
    "reproveríamos": "reprover",
    "reproveríeis": "reprover",
    "reproves": "reprover",
    "reprovesse": "reprover",
    "reprovessem": "reprover",
    "reprovesses": "reprover",
    "reproveste": "reprover",
    "reprovestes": "reprover",
    "reproveu": "reprover",
    "reprovi": "reprover",
    "reprovia": "reprover",
    "reproviam": "reprover",
    "reprovias": "reprover",
    "reprovida": "reprover",
    "reprovidas": "reprover",
    "reprovido": "reprover",
    "reprovidos": "reprover",
    "reprovo": "reprover",
    "reprovou": "reprovar",
    "reprová": "reprovar",
    "reprovámo": "reprovar",
    "reprovámos": "reprovar",
    "reprováramo": "reprovar",
    "reprováramos": "reprovar",
    "reprovárei": "reprovar",
    "reprováreis": "reprovar",
    "reprovásseis": "reprovar",
    "reprovássemos": "reprovar",
    "reprovávamo": "reprovar",
    "reprovávamos": "reprovar",
    "reprovávei": "reprovar",
    "reprováveis": "reprovável",
    "reprovê": "reprover",
    "reprovêramo": "reprover",
    "reprovêramos": "reprover",
    "reprovêrei": "reprover",
    "reprovêreis": "reprover",
    "reprovêsseis": "reprover",
    "reprovêssemos": "reprover",
    "reprovíamo": "reprover",
    "reprovíamos": "reprover",
    "reprovíei": "reprover",
    "reprovíeis": "reprover",
    "reprua": "repruir",
    "repruais": "repruir",
    "repruam": "repruir",
    "repruamo": "repruir",
    "repruamos": "repruir",
    "repruas": "repruir",
    "repruem": "repruir",
    "reprui": "repruir",
    "repruindo": "repruir",
    "repruirde": "repruir",
    "repruirdes": "repruir",
    "repruirei": "repruir",
    "repruireis": "repruir",
    "repruiremos": "repruir",
    "repruiria": "repruir",
    "repruiriam": "repruir",
    "repruirias": "repruir",
    "repruirmo": "repruir",
    "repruirmos": "repruir",
    "repruirá": "repruir",
    "repruirás": "repruir",
    "repruirão": "repruir",
    "repruiríamos": "repruir",
    "repruiríeis": "repruir",
    "repruis": "repruir",
    "repruiu": "repruir",
    "repruo": "repruir",
    "reprura": "reprurir",
    "reprurais": "reprurir",
    "repruram": "reprurir",
    "repruramo": "reprurir",
    "repruramos": "reprurir",
    "repruras": "reprurir",
    "reprure": "reprurir",
    "reprurem": "reprurir",
    "reprures": "reprurir",
    "repruri": "reprurir",
    "repruria": "reprurir",
    "repruriam": "reprurir",
    "reprurias": "reprurir",
    "reprurida": "reprurir",
    "repruridas": "reprurir",
    "reprurido": "reprurir",
    "repruridos": "reprurir",
    "reprurimo": "reprurir",
    "reprurimos": "reprurir",
    "reprurindo": "reprurir",
    "reprurira": "reprurir",
    "repruriram": "reprurir",
    "repruriras": "reprurir",
    "reprurirde": "reprurir",
    "reprurirdes": "reprurir",
    "reprurire": "reprurir",
    "reprurirei": "reprurir",
    "reprurireis": "reprurir",
    "reprurirem": "reprurir",
    "repruriremos": "reprurir",
    "reprurires": "reprurir",
    "repruriria": "reprurir",
    "repruririam": "reprurir",
    "repruririas": "reprurir",
    "reprurirmo": "reprurir",
    "reprurirmos": "reprurir",
    "reprurirá": "reprurir",
    "reprurirás": "reprurir",
    "reprurirão": "reprurir",
    "repruriríamos": "reprurir",
    "repruriríeis": "reprurir",
    "repruris": "reprurir",
    "reprurisse": "reprurir",
    "reprurissem": "reprurir",
    "reprurisses": "reprurir",
    "repruriste": "reprurir",
    "repruristes": "reprurir",
    "repruriu": "reprurir",
    "repruro": "reprurir",
    "repruríamo": "reprurir",
    "repruríamos": "reprurir",
    "repruríei": "reprurir",
    "repruríeis": "reprurir",
    "repruríramo": "reprurir",
    "repruríramos": "reprurir",
    "reprurírei": "reprurir",
    "repruríreis": "reprurir",
    "reprurísseis": "reprurir",
    "repruríssemos": "reprurir",
    "repruí": "repruir",
    "repruía": "repruir",
    "repruíam": "repruir",
    "repruíamo": "repruir",
    "repruíamos": "repruir",
    "repruías": "repruir",
    "repruída": "repruir",
    "repruídas": "repruir",
    "repruído": "repruir",
    "repruídos": "repruir",
    "repruíei": "repruir",
    "repruíeis": "repruir",
    "repruímo": "repruir",
    "repruímos": "repruir",
    "repruíra": "repruir",
    "repruíram": "repruir",
    "repruíramo": "repruir",
    "repruíramos": "repruir",
    "repruíras": "repruir",
    "repruíre": "repruir",
    "repruírei": "repruir",
    "repruíreis": "repruir",
    "repruírem": "repruir",
    "repruíres": "repruir",
    "repruís": "repruir",
    "repruísse": "repruir",
    "repruísseis": "repruir",
    "repruíssem": "repruir",
    "repruíssemos": "repruir",
    "repruísses": "repruir",
    "repruíste": "repruir",
    "repruístes": "repruir",
    "repta": "reptar",
    "reptada": "reptar",
    "reptadas": "reptar",
    "reptado": "reptar",
    "reptadora": "reptador",
    "reptadoras": "reptador",
    "reptadores": "reptador",
    "reptados": "reptar",
    "reptai": "reptar",
    "reptais": "reptar",
    "reptam": "reptar",
    "reptamentos": "reptamento",
    "reptamo": "reptar",
    "reptamos": "reptar",
    "reptando": "reptar",
    "reptantes": "reptante",
    "reptara": "reptar",
    "reptaram": "reptar",
    "reptaras": "reptar",
    "reptarde": "reptar",
    "reptardes": "reptar",
    "reptare": "reptar",
    "reptarei": "reptar",
    "reptareis": "reptar",
    "reptarem": "reptar",
    "reptaremos": "reptar",
    "reptares": "reptar",
    "reptaria": "reptar",
    "reptariam": "reptar",
    "reptarias": "reptar",
    "reptarmo": "reptar",
    "reptarmos": "reptar",
    "reptará": "reptar",
    "reptarás": "reptar",
    "reptarão": "reptar",
    "reptaríamos": "reptar",
    "reptaríeis": "reptar",
    "reptas": "reptar",
    "reptasse": "reptar",
    "reptassem": "reptar",
    "reptasses": "reptar",
    "reptaste": "reptar",
    "reptastes": "reptar",
    "reptava": "reptar",
    "reptavam": "reptar",
    "reptavas": "reptar",
    "reptações": "reptação",
    "repte": "reptar",
    "reptei": "reptar",
    "repteis": "reptar",
    "reptem": "reptar",
    "reptemo": "reptar",
    "reptemos": "reptar",
    "reptes": "reptar",
    "reptiliana": "reptiliano",
    "reptilianas": "reptiliano",
    "reptilianos": "reptiliano",
    "reptilária": "reptilário",
    "reptilárias": "reptilário",
    "reptilários": "reptilário",
    "repto": "reptar",
    "reptos": "repto",
    "reptou": "reptar",
    "reptá": "reptar",
    "reptámo": "reptar",
    "reptámos": "reptar",
    "reptáramo": "reptar",
    "reptáramos": "reptar",
    "reptárei": "reptar",
    "reptáreis": "reptar",
    "reptásseis": "reptar",
    "reptássemos": "reptar",
    "reptávamo": "reptar",
    "reptávamos": "reptar",
    "reptávei": "reptar",
    "reptáveis": "reptar",
    "reptícia": "reptício",
    "reptícias": "reptício",
    "reptícios": "reptício",
    "republica": "republicar",
    "republicada": "republicar",
    "republicadas": "republicar",
    "republicado": "republicar",
    "republicados": "republicar",
    "republicai": "republicar",
    "republicais": "republicar",
    "republicam": "republicar",
    "republicamo": "republicar",
    "republicamos": "republicar",
    "republicana": "republicano",
    "republicanas": "republicano",
    "republicanazinha": "republicano",
    "republicanazinhas": "republicano",
    "republicanazita": "republicano",
    "republicanazitas": "republicano",
    "republicando": "republicar",
    "republicanismos": "republicanismo",
    "republicanistas": "republicanista",
    "republicaniza": "republicanizar",
    "republicanizada": "republicanizar",
    "republicanizadas": "republicanizar",
    "republicanizado": "republicanizar",
    "republicanizados": "republicanizar",
    "republicanizai": "republicanizar",
    "republicanizais": "republicanizar",
    "republicanizam": "republicanizar",
    "republicanizamo": "republicanizar",
    "republicanizamos": "republicanizar",
    "republicanizando": "republicanizar",
    "republicanizara": "republicanizar",
    "republicanizaram": "republicanizar",
    "republicanizaras": "republicanizar",
    "republicanizarde": "republicanizar",
    "republicanizardes": "republicanizar",
    "republicanizare": "republicanizar",
    "republicanizarei": "republicanizar",
    "republicanizareis": "republicanizar",
    "republicanizarem": "republicanizar",
    "republicanizaremos": "republicanizar",
    "republicanizares": "republicanizar",
    "republicanizaria": "republicanizar",
    "republicanizariam": "republicanizar",
    "republicanizarias": "republicanizar",
    "republicanizarmo": "republicanizar",
    "republicanizarmos": "republicanizar",
    "republicanizará": "republicanizar",
    "republicanizarás": "republicanizar",
    "republicanizarão": "republicanizar",
    "republicanizaríamos": "republicanizar",
    "republicanizaríeis": "republicanizar",
    "republicanizas": "republicanizar",
    "republicanizasse": "republicanizar",
    "republicanizassem": "republicanizar",
    "republicanizasses": "republicanizar",
    "republicanizaste": "republicanizar",
    "republicanizastes": "republicanizar",
    "republicanizava": "republicanizar",
    "republicanizavam": "republicanizar",
    "republicanizavas": "republicanizar",
    "republicanizações": "republicanização",
    "republicanize": "republicanizar",
    "republicanizei": "republicanizar",
    "republicanizeis": "republicanizar",
    "republicanizem": "republicanizar",
    "republicanizemo": "republicanizar",
    "republicanizemos": "republicanizar",
    "republicanizes": "republicanizar",
    "republicanizo": "republicanizar",
    "republicanizou": "republicanizar",
    "republicanizá": "republicanizar",
    "republicanizámo": "republicanizar",
    "republicanizámos": "republicanizar",
    "republicanizáramo": "republicanizar",
    "republicanizáramos": "republicanizar",
    "republicanizárei": "republicanizar",
    "republicanizáreis": "republicanizar",
    "republicanizásseis": "republicanizar",
    "republicanizássemos": "republicanizar",
    "republicanizávamo": "republicanizar",
    "republicanizávamos": "republicanizar",
    "republicanizávei": "republicanizar",
    "republicanizáveis": "republicanizável",
    "republicanos": "republicano",
    "republicanozinho": "republicano",
    "republicanozinhos": "republicano",
    "republicanozito": "republicano",
    "republicanozitos": "republicano",
    "republicara": "republicar",
    "republicaram": "republicar",
    "republicaras": "republicar",
    "republicarde": "republicar",
    "republicardes": "republicar",
    "republicare": "republicar",
    "republicarei": "republicar",
    "republicareis": "republicar",
    "republicarem": "republicar",
    "republicaremos": "republicar",
    "republicares": "republicar",
    "republicaria": "republicar",
    "republicariam": "republicar",
    "republicarias": "republicar",
    "republicarmo": "republicar",
    "republicarmos": "republicar",
    "republicará": "republicar",
    "republicarás": "republicar",
    "republicarão": "republicar",
    "republicaríamos": "republicar",
    "republicaríeis": "republicar",
    "republicas": "republicar",
    "republicasse": "republicar",
    "republicassem": "republicar",
    "republicasses": "republicar",
    "republicaste": "republicar",
    "republicastes": "republicar",
    "republicava": "republicar",
    "republicavam": "republicar",
    "republicavas": "republicar",
    "republicações": "republicação",
    "republicidas": "republicida",
    "republico": "republicar",
    "republicou": "republicar",
    "republicá": "republicar",
    "republicámo": "republicar",
    "republicámos": "republicar",
    "republicáramo": "republicar",
    "republicáramos": "republicar",
    "republicárei": "republicar",
    "republicáreis": "republicar",
    "republicásseis": "republicar",
    "republicássemos": "republicar",
    "republicávamo": "republicar",
    "republicávamos": "republicar",
    "republicávei": "republicar",
    "republicáveis": "republicável",
    "republicídios": "republicídio",
    "republique": "republicar",
    "republiquei": "republicar",
    "republiqueira": "republiqueiro",
    "republiqueiras": "republiqueiro",
    "republiqueiros": "republiqueiro",
    "republiqueis": "republicar",
    "republiquem": "republicar",
    "republiquemo": "republicar",
    "republiquemos": "republicar",
    "republiques": "republicar",
    "repudia": "repudiar",
    "repudiada": "repudiar",
    "repudiadas": "repudiar",
    "repudiado": "repudiar",
    "repudiadora": "repudiador",
    "repudiadoras": "repudiador",
    "repudiadores": "repudiador",
    "repudiados": "repudiar",
    "repudiai": "repudiar",
    "repudiais": "repudiar",
    "repudiam": "repudiar",
    "repudiamo": "repudiar",
    "repudiamos": "repudiar",
    "repudiando": "repudiar",
    "repudiara": "repudiar",
    "repudiaram": "repudiar",
    "repudiaras": "repudiar",
    "repudiarde": "repudiar",
    "repudiardes": "repudiar",
    "repudiare": "repudiar",
    "repudiarei": "repudiar",
    "repudiareis": "repudiar",
    "repudiarem": "repudiar",
    "repudiaremos": "repudiar",
    "repudiares": "repudiar",
    "repudiaria": "repudiar",
    "repudiariam": "repudiar",
    "repudiarias": "repudiar",
    "repudiarmo": "repudiar",
    "repudiarmos": "repudiar",
    "repudiará": "repudiar",
    "repudiarás": "repudiar",
    "repudiarão": "repudiar",
    "repudiaríamos": "repudiar",
    "repudiaríeis": "repudiar",
    "repudias": "repudiar",
    "repudiasse": "repudiar",
    "repudiassem": "repudiar",
    "repudiasses": "repudiar",
    "repudiaste": "repudiar",
    "repudiastes": "repudiar",
    "repudiava": "repudiar",
    "repudiavam": "repudiar",
    "repudiavas": "repudiar",
    "repudiações": "repudiação",
    "repudie": "repudiar",
    "repudiei": "repudiar",
    "repudieis": "repudiar",
    "repudiem": "repudiar",
    "repudiemo": "repudiar",
    "repudiemos": "repudiar",
    "repudies": "repudiar",
    "repudio": "repudiar",
    "repudiou": "repudiar",
    "repudiváveis": "repudivável",
    "repudiá": "repudiar",
    "repudiámo": "repudiar",
    "repudiámos": "repudiar",
    "repudiáramo": "repudiar",
    "repudiáramos": "repudiar",
    "repudiárei": "repudiar",
    "repudiáreis": "repudiar",
    "repudiásseis": "repudiar",
    "repudiássemos": "repudiar",
    "repudiávamo": "repudiar",
    "repudiávamos": "repudiar",
    "repudiávei": "repudiar",
    "repudiáveis": "repudiar",
    "repugna": "repugnar",
    "repugnada": "repugnar",
    "repugnadas": "repugnar",
    "repugnado": "repugnar",
    "repugnadora": "repugnador",
    "repugnadoras": "repugnador",
    "repugnadores": "repugnador",
    "repugnados": "repugnar",
    "repugnai": "repugnar",
    "repugnais": "repugnar",
    "repugnam": "repugnar",
    "repugnamo": "repugnar",
    "repugnamos": "repugnar",
    "repugnando": "repugnar",
    "repugnantes": "repugnante",
    "repugnantíssima": "repugnante",
    "repugnantíssimas": "repugnante",
    "repugnantíssimo": "repugnante",
    "repugnantíssimos": "repugnante",
    "repugnara": "repugnar",
    "repugnaram": "repugnar",
    "repugnaras": "repugnar",
    "repugnardes": "repugnar",
    "repugnarei": "repugnar",
    "repugnareis": "repugnar",
    "repugnarem": "repugnar",
    "repugnaremos": "repugnar",
    "repugnares": "repugnar",
    "repugnaria": "repugnar",
    "repugnariam": "repugnar",
    "repugnarias": "repugnar",
    "repugnarmo": "repugnar",
    "repugnarmos": "repugnar",
    "repugnará": "repugnar",
    "repugnarás": "repugnar",
    "repugnarão": "repugnar",
    "repugnaríamos": "repugnar",
    "repugnaríeis": "repugnar",
    "repugnas": "repugnar",
    "repugnasse": "repugnar",
    "repugnassem": "repugnar",
    "repugnasses": "repugnar",
    "repugnaste": "repugnar",
    "repugnastes": "repugnar",
    "repugnava": "repugnar",
    "repugnavam": "repugnar",
    "repugnavas": "repugnar",
    "repugne": "repugnar",
    "repugnei": "repugnar",
    "repugneis": "repugnar",
    "repugnem": "repugnar",
    "repugnemo": "repugnar",
    "repugnemos": "repugnar",
    "repugnes": "repugnar",
    "repugno": "repugnar",
    "repugnou": "repugnar",
    "repugnámo": "repugnar",
    "repugnámos": "repugnar",
    "repugnáramo": "repugnar",
    "repugnáramos": "repugnar",
    "repugnáreis": "repugnar",
    "repugnásseis": "repugnar",
    "repugnássemos": "repugnar",
    "repugnávamo": "repugnar",
    "repugnávamos": "repugnar",
    "repugnáveis": "repugnar",
    "repugnâncias": "repugnância",
    "repulsa": "repulso",
    "repulsada": "repulsar",
    "repulsadas": "repulsar",
    "repulsado": "repulsar",
    "repulsados": "repulsar",
    "repulsai": "repulsar",
    "repulsais": "repulsar",
    "repulsam": "repulsar",
    "repulsamo": "repulsar",
    "repulsamos": "repulsar",
    "repulsando": "repulsar",
    "repulsara": "repulsar",
    "repulsaram": "repulsar",
    "repulsaras": "repulsar",
    "repulsarde": "repulsar",
    "repulsardes": "repulsar",
    "repulsare": "repulsar",
    "repulsarei": "repulsar",
    "repulsareis": "repulsar",
    "repulsarem": "repulsar",
    "repulsaremos": "repulsar",
    "repulsares": "repulsar",
    "repulsaria": "repulsar",
    "repulsariam": "repulsar",
    "repulsarias": "repulsar",
    "repulsarmo": "repulsar",
    "repulsarmos": "repulsar",
    "repulsará": "repulsar",
    "repulsarás": "repulsar",
    "repulsarão": "repulsar",
    "repulsaríamos": "repulsar",
    "repulsaríeis": "repulsar",
    "repulsas": "repulso",
    "repulsasse": "repulsar",
    "repulsassem": "repulsar",
    "repulsasses": "repulsar",
    "repulsaste": "repulsar",
    "repulsastes": "repulsar",
    "repulsava": "repulsar",
    "repulsavam": "repulsar",
    "repulsavas": "repulsar",
    "repulse": "repulsar",
    "repulsei": "repulsar",
    "repulseis": "repulsar",
    "repulsem": "repulsar",
    "repulsemo": "repulsar",
    "repulsemos": "repulsar",
    "repulses": "repulsar",
    "repulsiva": "repulsivo",
    "repulsivas": "repulsivo",
    "repulsivos": "repulsivo",
    "repulso": "repulsar",
    "repulsos": "repulso",
    "repulsou": "repulsar",
    "repulsá": "repulsar",
    "repulsámo": "repulsar",
    "repulsámos": "repulsar",
    "repulsáramo": "repulsar",
    "repulsáramos": "repulsar",
    "repulsárei": "repulsar",
    "repulsáreis": "repulsar",
    "repulsásseis": "repulsar",
    "repulsássemos": "repulsar",
    "repulsávamo": "repulsar",
    "repulsávamos": "repulsar",
    "repulsávei": "repulsar",
    "repulsáveis": "repulsar",
    "repulsões": "repulsão",
    "repulula": "repulular",
    "repululada": "repulular",
    "repululadas": "repulular",
    "repululado": "repulular",
    "repululados": "repulular",
    "repululai": "repulular",
    "repululais": "repulular",
    "repululam": "repulular",
    "repululamo": "repulular",
    "repululamos": "repulular",
    "repululando": "repulular",
    "repululara": "repulular",
    "repulularam": "repulular",
    "repulularas": "repulular",
    "repululardes": "repulular",
    "repulularei": "repulular",
    "repululareis": "repulular",
    "repulularem": "repulular",
    "repulularemos": "repulular",
    "repululares": "repulular",
    "repulularia": "repulular",
    "repululariam": "repulular",
    "repulularias": "repulular",
    "repulularmo": "repulular",
    "repulularmos": "repulular",
    "repululará": "repulular",
    "repulularás": "repulular",
    "repulularão": "repulular",
    "repulularíamos": "repulular",
    "repulularíeis": "repulular",
    "repululas": "repulular",
    "repululasse": "repulular",
    "repululassem": "repulular",
    "repululasses": "repulular",
    "repululaste": "repulular",
    "repululastes": "repulular",
    "repululava": "repulular",
    "repululavam": "repulular",
    "repululavas": "repulular",
    "repululações": "repululação",
    "repulule": "repulular",
    "repululei": "repulular",
    "repululeis": "repulular",
    "repululem": "repulular",
    "repululemo": "repulular",
    "repululemos": "repulular",
    "repulules": "repulular",
    "repululo": "repulular",
    "repululou": "repulular",
    "repululámo": "repulular",
    "repululámos": "repulular",
    "repululáramo": "repulular",
    "repululáramos": "repulular",
    "repululáreis": "repulular",
    "repululásseis": "repulular",
    "repululássemos": "repulular",
    "repululávamo": "repulular",
    "repululávamos": "repulular",
    "repululáveis": "repulular",
    "repunge": "repungir",
    "repungem": "repungir",
    "repunges": "repungir",
    "repungi": "repungir",
    "repungia": "repungir",
    "repungiam": "repungir",
    "repungias": "repungir",
    "repungida": "repungir",
    "repungidas": "repungir",
    "repungido": "repungir",
    "repungidos": "repungir",
    "repungimo": "repungir",
    "repungimos": "repungir",
    "repungindo": "repungir",
    "repungira": "repungir",
    "repungiram": "repungir",
    "repungiras": "repungir",
    "repungirde": "repungir",
    "repungirdes": "repungir",
    "repungire": "repungir",
    "repungirei": "repungir",
    "repungireis": "repungir",
    "repungirem": "repungir",
    "repungiremos": "repungir",
    "repungires": "repungir",
    "repungiria": "repungir",
    "repungiriam": "repungir",
    "repungirias": "repungir",
    "repungirmo": "repungir",
    "repungirmos": "repungir",
    "repungirá": "repungir",
    "repungirás": "repungir",
    "repungirão": "repungir",
    "repungiríamos": "repungir",
    "repungiríeis": "repungir",
    "repungis": "repungir",
    "repungisse": "repungir",
    "repungissem": "repungir",
    "repungisses": "repungir",
    "repungiste": "repungir",
    "repungistes": "repungir",
    "repungiu": "repungir",
    "repungíamo": "repungir",
    "repungíamos": "repungir",
    "repungíei": "repungir",
    "repungíeis": "repungir",
    "repungíramo": "repungir",
    "repungíramos": "repungir",
    "repungírei": "repungir",
    "repungíreis": "repungir",
    "repungísseis": "repungir",
    "repungíssemos": "repungir",
    "repunha": "repor",
    "repunham": "repor",
    "repunhas": "repor",
    "repunja": "repungir",
    "repunjais": "repungir",
    "repunjam": "repungir",
    "repunjamo": "repungir",
    "repunjamos": "repungir",
    "repunjas": "repungir",
    "repunjo": "repungir",
    "repurga": "repurgar",
    "repurgada": "repurgar",
    "repurgadas": "repurgar",
    "repurgado": "repurgar",
    "repurgados": "repurgar",
    "repurgai": "repurgar",
    "repurgais": "repurgar",
    "repurgam": "repurgar",
    "repurgamo": "repurgar",
    "repurgamos": "repurgar",
    "repurgando": "repurgar",
    "repurgara": "repurgar",
    "repurgaram": "repurgar",
    "repurgaras": "repurgar",
    "repurgarde": "repurgar",
    "repurgardes": "repurgar",
    "repurgare": "repurgar",
    "repurgarei": "repurgar",
    "repurgareis": "repurgar",
    "repurgarem": "repurgar",
    "repurgaremos": "repurgar",
    "repurgares": "repurgar",
    "repurgaria": "repurgar",
    "repurgariam": "repurgar",
    "repurgarias": "repurgar",
    "repurgarmo": "repurgar",
    "repurgarmos": "repurgar",
    "repurgará": "repurgar",
    "repurgarás": "repurgar",
    "repurgarão": "repurgar",
    "repurgaríamos": "repurgar",
    "repurgaríeis": "repurgar",
    "repurgas": "repurgar",
    "repurgasse": "repurgar",
    "repurgassem": "repurgar",
    "repurgasses": "repurgar",
    "repurgaste": "repurgar",
    "repurgastes": "repurgar",
    "repurgava": "repurgar",
    "repurgavam": "repurgar",
    "repurgavas": "repurgar",
    "repurgações": "repurgação",
    "repurgo": "repurgar",
    "repurgou": "repurgar",
    "repurgue": "repurgar",
    "repurguei": "repurgar",
    "repurgueis": "repurgar",
    "repurguem": "repurgar",
    "repurguemo": "repurgar",
    "repurguemos": "repurgar",
    "repurgues": "repurgar",
    "repurgá": "repurgar",
    "repurgámo": "repurgar",
    "repurgámos": "repurgar",
    "repurgáramo": "repurgar",
    "repurgáramos": "repurgar",
    "repurgárei": "repurgar",
    "repurgáreis": "repurgar",
    "repurgásseis": "repurgar",
    "repurgássemos": "repurgar",
    "repurgávamo": "repurgar",
    "repurgávamos": "repurgar",
    "repurgávei": "repurgar",
    "repurgáveis": "repurgar",
    "repurifica": "repurificar",
    "repurificada": "repurificar",
    "repurificadas": "repurificar",
    "repurificado": "repurificar",
    "repurificados": "repurificar",
    "repurificai": "repurificar",
    "repurificais": "repurificar",
    "repurificam": "repurificar",
    "repurificamo": "repurificar",
    "repurificamos": "repurificar",
    "repurificando": "repurificar",
    "repurificara": "repurificar",
    "repurificaram": "repurificar",
    "repurificaras": "repurificar",
    "repurificarde": "repurificar",
    "repurificardes": "repurificar",
    "repurificare": "repurificar",
    "repurificarei": "repurificar",
    "repurificareis": "repurificar",
    "repurificarem": "repurificar",
    "repurificaremos": "repurificar",
    "repurificares": "repurificar",
    "repurificaria": "repurificar",
    "repurificariam": "repurificar",
    "repurificarias": "repurificar",
    "repurificarmo": "repurificar",
    "repurificarmos": "repurificar",
    "repurificará": "repurificar",
    "repurificarás": "repurificar",
    "repurificarão": "repurificar",
    "repurificaríamos": "repurificar",
    "repurificaríeis": "repurificar",
    "repurificas": "repurificar",
    "repurificasse": "repurificar",
    "repurificassem": "repurificar",
    "repurificasses": "repurificar",
    "repurificaste": "repurificar",
    "repurificastes": "repurificar",
    "repurificava": "repurificar",
    "repurificavam": "repurificar",
    "repurificavas": "repurificar",
    "repurificações": "repurificação",
    "repurifico": "repurificar",
    "repurificou": "repurificar",
    "repurificá": "repurificar",
    "repurificámo": "repurificar",
    "repurificámos": "repurificar",
    "repurificáramo": "repurificar",
    "repurificáramos": "repurificar",
    "repurificárei": "repurificar",
    "repurificáreis": "repurificar",
    "repurificásseis": "repurificar",
    "repurificássemos": "repurificar",
    "repurificávamo": "repurificar",
    "repurificávamos": "repurificar",
    "repurificávei": "repurificar",
    "repurificáveis": "repurificar",
    "repurifique": "repurificar",
    "repurifiquei": "repurificar",
    "repurifiqueis": "repurificar",
    "repurifiquem": "repurificar",
    "repurifiquemo": "repurificar",
    "repurifiquemos": "repurificar",
    "repurifiques": "repurificar",
    "repus": "repor",
    "repusemo": "repor",
    "repusemos": "repor",
    "repuser": "repor",
    "repusera": "repor",
    "repuseram": "repor",
    "repuseras": "repor",
    "repuserdes": "repor",
    "repuserem": "repor",
    "repuseres": "repor",
    "repusermos": "repor",
    "repusesse": "repor",
    "repusessem": "repor",
    "repusesses": "repor",
    "repuseste": "repor",
    "repusestes": "repor",
    "repuséramo": "repor",
    "repuséramos": "repor",
    "repusérei": "repor",
    "repuséreis": "repor",
    "repusésseis": "repor",
    "repuséssemos": "repor",
    "reputa": "reputar",
    "reputada": "reputar",
    "reputadas": "reputar",
    "reputado": "reputar",
    "reputados": "reputar",
    "reputai": "reputar",
    "reputais": "reputar",
    "reputam": "reputar",
    "reputamo": "reputar",
    "reputamos": "reputar",
    "reputando": "reputar",
    "reputara": "reputar",
    "reputaram": "reputar",
    "reputaras": "reputar",
    "reputarde": "reputar",
    "reputardes": "reputar",
    "reputare": "reputar",
    "reputarei": "reputar",
    "reputareis": "reputar",
    "reputarem": "reputar",
    "reputaremos": "reputar",
    "reputares": "reputar",
    "reputaria": "reputar",
    "reputariam": "reputar",
    "reputarias": "reputar",
    "reputarmo": "reputar",
    "reputarmos": "reputar",
    "reputará": "reputar",
    "reputarás": "reputar",
    "reputarão": "reputar",
    "reputaríamos": "reputar",
    "reputaríeis": "reputar",
    "reputas": "reputar",
    "reputasse": "reputar",
    "reputassem": "reputar",
    "reputasses": "reputar",
    "reputaste": "reputar",
    "reputastes": "reputar",
    "reputava": "reputar",
    "reputavam": "reputar",
    "reputavas": "reputar",
    "reputações": "reputação",
    "repute": "reputar",
    "reputei": "reputar",
    "reputeis": "reputar",
    "reputem": "reputar",
    "reputemo": "reputar",
    "reputemos": "reputar",
    "reputes": "reputar",
    "reputo": "reputar",
    "reputou": "reputar",
    "reputá": "reputar",
    "reputámo": "reputar",
    "reputámos": "reputar",
    "reputáramo": "reputar",
    "reputáramos": "reputar",
    "reputárei": "reputar",
    "reputáreis": "reputar",
    "reputásseis": "reputar",
    "reputássemos": "reputar",
    "reputávamo": "reputar",
    "reputávamos": "reputar",
    "reputávei": "reputar",
    "reputáveis": "reputar",
    "repuxa": "repuxar",
    "repuxada": "repuxar",
    "repuxadas": "repuxar",
    "repuxado": "repuxar",
    "repuxados": "repuxar",
    "repuxai": "repuxar",
    "repuxais": "repuxar",
    "repuxam": "repuxar",
    "repuxamo": "repuxar",
    "repuxamos": "repuxar",
    "repuxando": "repuxar",
    "repuxara": "repuxar",
    "repuxaram": "repuxar",
    "repuxaras": "repuxar",
    "repuxarde": "repuxar",
    "repuxardes": "repuxar",
    "repuxare": "repuxar",
    "repuxarei": "repuxar",
    "repuxareis": "repuxar",
    "repuxarem": "repuxar",
    "repuxaremos": "repuxar",
    "repuxares": "repuxar",
    "repuxaria": "repuxar",
    "repuxariam": "repuxar",
    "repuxarias": "repuxar",
    "repuxarmo": "repuxar",
    "repuxarmos": "repuxar",
    "repuxará": "repuxar",
    "repuxarás": "repuxar",
    "repuxarão": "repuxar",
    "repuxaríamos": "repuxar",
    "repuxaríeis": "repuxar",
    "repuxas": "repuxar",
    "repuxasse": "repuxar",
    "repuxassem": "repuxar",
    "repuxasses": "repuxar",
    "repuxaste": "repuxar",
    "repuxastes": "repuxar",
    "repuxava": "repuxar",
    "repuxavam": "repuxar",
    "repuxavas": "repuxar",
    "repuxe": "repuxar",
    "repuxei": "repuxar",
    "repuxeis": "repuxar",
    "repuxem": "repuxar",
    "repuxemo": "repuxar",
    "repuxemos": "repuxar",
    "repuxes": "repuxar",
    "repuxinho": "repuxo",
    "repuxinhos": "repuxo",
    "repuxito": "repuxo",
    "repuxitos": "repuxo",
    "repuxo": "repuxar",
    "repuxos": "repuxo",
    "repuxou": "repuxar",
    "repuxá": "repuxar",
    "repuxámo": "repuxar",
    "repuxámos": "repuxar",
    "repuxáramo": "repuxar",
    "repuxáramos": "repuxar",
    "repuxárei": "repuxar",
    "repuxáreis": "repuxar",
    "repuxásseis": "repuxar",
    "repuxássemos": "repuxar",
    "repuxávamo": "repuxar",
    "repuxávamos": "repuxar",
    "repuxávei": "repuxar",
    "repuxáveis": "repuxar",
    "repuxões": "repuxão",
    "repórteres": "repórter",
    "repô": "repor",
    "repôncios": "repôncio",
    "repôs": "repor",
    "repõe": "repor",
    "repõem": "repor",
    "repões": "repor",
    "república": "repúblico",
    "repúblicas": "repúblico",
    "repúblicos": "repúblico",
    "repúdios": "repúdio",
    "repúnhamo": "repor",
    "repúnhamos": "repor",
    "repúnhei": "repor",
    "repúnheis": "repor",
    "requalifica": "requalificar",
    "requalificada": "requalificar",
    "requalificadas": "requalificar",
    "requalificado": "requalificar",
    "requalificados": "requalificar",
    "requalificai": "requalificar",
    "requalificais": "requalificar",
    "requalificam": "requalificar",
    "requalificamo": "requalificar",
    "requalificamos": "requalificar",
    "requalificando": "requalificar",
    "requalificara": "requalificar",
    "requalificaram": "requalificar",
    "requalificaras": "requalificar",
    "requalificarde": "requalificar",
    "requalificardes": "requalificar",
    "requalificare": "requalificar",
    "requalificarei": "requalificar",
    "requalificareis": "requalificar",
    "requalificarem": "requalificar",
    "requalificaremos": "requalificar",
    "requalificares": "requalificar",
    "requalificaria": "requalificar",
    "requalificariam": "requalificar",
    "requalificarias": "requalificar",
    "requalificarmo": "requalificar",
    "requalificarmos": "requalificar",
    "requalificará": "requalificar",
    "requalificarás": "requalificar",
    "requalificarão": "requalificar",
    "requalificaríamos": "requalificar",
    "requalificaríeis": "requalificar",
    "requalificas": "requalificar",
    "requalificasse": "requalificar",
    "requalificassem": "requalificar",
    "requalificasses": "requalificar",
    "requalificaste": "requalificar",
    "requalificastes": "requalificar",
    "requalificava": "requalificar",
    "requalificavam": "requalificar",
    "requalificavas": "requalificar",
    "requalificações": "requalificação",
    "requalifico": "requalificar",
    "requalificou": "requalificar",
    "requalificá": "requalificar",
    "requalificámo": "requalificar",
    "requalificámos": "requalificar",
    "requalificáramo": "requalificar",
    "requalificáramos": "requalificar",
    "requalificárei": "requalificar",
    "requalificáreis": "requalificar",
    "requalificásseis": "requalificar",
    "requalificássemos": "requalificar",
    "requalificávamo": "requalificar",
    "requalificávamos": "requalificar",
    "requalificávei": "requalificar",
    "requalificáveis": "requalificar",
    "requalifique": "requalificar",
    "requalifiquei": "requalificar",
    "requalifiqueis": "requalificar",
    "requalifiquem": "requalificar",
    "requalifiquemo": "requalificar",
    "requalifiquemos": "requalificar",
    "requalifiques": "requalificar",
    "requebra": "requebrar",
    "requebrada": "requebrar",
    "requebradas": "requebrar",
    "requebradazinha": "requebrado",
    "requebradazinhas": "requebrado",
    "requebradazita": "requebrado",
    "requebradazitas": "requebrado",
    "requebradinha": "requebrado",
    "requebradinhas": "requebrado",
    "requebradinho": "requebrado",
    "requebradinhos": "requebrado",
    "requebradita": "requebrado",
    "requebraditas": "requebrado",
    "requebradito": "requebrado",
    "requebraditos": "requebrado",
    "requebrado": "requebrar",
    "requebradora": "requebrador",
    "requebradoras": "requebrador",
    "requebradores": "requebrador",
    "requebrados": "requebrar",
    "requebradozinho": "requebrado",
    "requebradozinhos": "requebrado",
    "requebradozito": "requebrado",
    "requebradozitos": "requebrado",
    "requebradíssima": "requebrado",
    "requebradíssimas": "requebrado",
    "requebradíssimo": "requebrado",
    "requebradíssimos": "requebrado",
    "requebrai": "requebrar",
    "requebrais": "requebrar",
    "requebram": "requebrar",
    "requebramo": "requebrar",
    "requebramos": "requebrar",
    "requebrando": "requebrar",
    "requebrara": "requebrar",
    "requebraram": "requebrar",
    "requebraras": "requebrar",
    "requebrarde": "requebrar",
    "requebrardes": "requebrar",
    "requebrare": "requebrar",
    "requebrarei": "requebrar",
    "requebrareis": "requebrar",
    "requebrarem": "requebrar",
    "requebraremos": "requebrar",
    "requebrares": "requebrar",
    "requebraria": "requebrar",
    "requebrariam": "requebrar",
    "requebrarias": "requebrar",
    "requebrarmo": "requebrar",
    "requebrarmos": "requebrar",
    "requebrará": "requebrar",
    "requebrarás": "requebrar",
    "requebrarão": "requebrar",
    "requebraríamos": "requebrar",
    "requebraríeis": "requebrar",
    "requebras": "requebrar",
    "requebrasse": "requebrar",
    "requebrassem": "requebrar",
    "requebrasses": "requebrar",
    "requebraste": "requebrar",
    "requebrastes": "requebrar",
    "requebrava": "requebrar",
    "requebravam": "requebrar",
    "requebravas": "requebrar",
    "requebre": "requebrar",
    "requebrei": "requebrar",
    "requebreis": "requebrar",
    "requebrem": "requebrar",
    "requebremo": "requebrar",
    "requebremos": "requebrar",
    "requebres": "requebrar",
    "requebro": "requebrar",
    "requebros": "requebro",
    "requebrou": "requebrar",
    "requebrá": "requebrar",
    "requebrámo": "requebrar",
    "requebrámos": "requebrar",
    "requebráramo": "requebrar",
    "requebráramos": "requebrar",
    "requebrárei": "requebrar",
    "requebráreis": "requebrar",
    "requebrásseis": "requebrar",
    "requebrássemos": "requebrar",
    "requebrávamo": "requebrar",
    "requebrávamos": "requebrar",
    "requebrávei": "requebrar",
    "requebráveis": "requebrar",
    "requeijas": "requeija",
    "requeijões": "requeijão",
    "requeima": "requeimar",
    "requeimada": "requeimar",
    "requeimadas": "requeimar",
    "requeimado": "requeimar",
    "requeimados": "requeimar",
    "requeimai": "requeimar",
    "requeimais": "requeimar",
    "requeimam": "requeimar",
    "requeimamo": "requeimar",
    "requeimamos": "requeimar",
    "requeimando": "requeimar",
    "requeimara": "requeimar",
    "requeimaram": "requeimar",
    "requeimaras": "requeimar",
    "requeimarde": "requeimar",
    "requeimardes": "requeimar",
    "requeimare": "requeimar",
    "requeimarei": "requeimar",
    "requeimareis": "requeimar",
    "requeimarem": "requeimar",
    "requeimaremos": "requeimar",
    "requeimares": "requeimar",
    "requeimaria": "requeimar",
    "requeimariam": "requeimar",
    "requeimarias": "requeimar",
    "requeimarmo": "requeimar",
    "requeimarmos": "requeimar",
    "requeimará": "requeimar",
    "requeimarás": "requeimar",
    "requeimarão": "requeimar",
    "requeimaríamos": "requeimar",
    "requeimaríeis": "requeimar",
    "requeimas": "requeimar",
    "requeimasse": "requeimar",
    "requeimassem": "requeimar",
    "requeimasses": "requeimar",
    "requeimaste": "requeimar",
    "requeimastes": "requeimar",
    "requeimava": "requeimar",
    "requeimavam": "requeimar",
    "requeimavas": "requeimar",
    "requeimações": "requeimação",
    "requeime": "requeimar",
    "requeimei": "requeimar",
    "requeimeis": "requeimar",
    "requeimem": "requeimar",
    "requeimemo": "requeimar",
    "requeimemos": "requeimar",
    "requeimes": "requeime",
    "requeimo": "requeimar",
    "requeimos": "requeimo",
    "requeimou": "requeimar",
    "requeimá": "requeimar",
    "requeimámo": "requeimar",
    "requeimámos": "requeimar",
    "requeimáramo": "requeimar",
    "requeimáramos": "requeimar",
    "requeimárei": "requeimar",
    "requeimáreis": "requeimar",
    "requeimásseis": "requeimar",
    "requeimássemos": "requeimar",
    "requeimávamo": "requeimar",
    "requeimávamos": "requeimar",
    "requeimávei": "requeimar",
    "requeimáveis": "requeimar",
    "requeira": "requerer",
    "requeirais": "requerer",
    "requeiram": "requerer",
    "requeiramo": "requerer",
    "requeiramos": "requerer",
    "requeiras": "requerer",
    "requeiro": "requerer",
    "requenta": "requentar",
    "requentada": "requentar",
    "requentadas": "requentar",
    "requentado": "requentar",
    "requentados": "requentar",
    "requentai": "requentar",
    "requentais": "requentar",
    "requentam": "requentar",
    "requentamo": "requentar",
    "requentamos": "requentar",
    "requentando": "requentar",
    "requentara": "requentar",
    "requentaram": "requentar",
    "requentaras": "requentar",
    "requentarde": "requentar",
    "requentardes": "requentar",
    "requentare": "requentar",
    "requentarei": "requentar",
    "requentareis": "requentar",
    "requentarem": "requentar",
    "requentaremos": "requentar",
    "requentares": "requentar",
    "requentaria": "requentar",
    "requentariam": "requentar",
    "requentarias": "requentar",
    "requentarmo": "requentar",
    "requentarmos": "requentar",
    "requentará": "requentar",
    "requentarás": "requentar",
    "requentarão": "requentar",
    "requentaríamos": "requentar",
    "requentaríeis": "requentar",
    "requentas": "requentar",
    "requentasse": "requentar",
    "requentassem": "requentar",
    "requentasses": "requentar",
    "requentaste": "requentar",
    "requentastes": "requentar",
    "requentava": "requentar",
    "requentavam": "requentar",
    "requentavas": "requentar",
    "requente": "requentar",
    "requentei": "requentar",
    "requenteis": "requentar",
    "requentem": "requentar",
    "requentemo": "requentar",
    "requentemos": "requentar",
    "requentes": "requentar",
    "requento": "requentar",
    "requentou": "requentar",
    "requentá": "requentar",
    "requentámo": "requentar",
    "requentámos": "requentar",
    "requentáramo": "requentar",
    "requentáramos": "requentar",
    "requentárei": "requentar",
    "requentáreis": "requentar",
    "requentásseis": "requentar",
    "requentássemos": "requentar",
    "requentávamo": "requentar",
    "requentávamos": "requentar",
    "requentávei": "requentar",
    "requentáveis": "requentar",
    "requer": "requerer",
    "requere": "requerer",
    "requeredora": "requeredor",
    "requeredoras": "requeredor",
    "requeredores": "requeredor",
    "requerei": "requerer",
    "requereis": "requerer",
    "requerem": "requerer",
    "requeremo": "requerer",
    "requeremos": "requerer",
    "requerendo": "requerer",
    "requerentes": "requerente",
    "requerera": "requerer",
    "requereram": "requerer",
    "requereras": "requerer",
    "requererde": "requerer",
    "requererdes": "requerer",
    "requerere": "requerer",
    "requererei": "requerer",
    "requerereis": "requerer",
    "requererem": "requerer",
    "requereremos": "requerer",
    "requereres": "requerer",
    "requereria": "requerer",
    "requereriam": "requerer",
    "requererias": "requerer",
    "requerermo": "requerer",
    "requerermos": "requerer",
    "requererá": "requerer",
    "requererás": "requerer",
    "requererão": "requerer",
    "requereríamos": "requerer",
    "requereríeis": "requerer",
    "requeres": "requerer",
    "requeresse": "requerer",
    "requeressem": "requerer",
    "requeresses": "requerer",
    "requereste": "requerer",
    "requerestes": "requerer",
    "requereu": "requerer",
    "requeri": "requerer",
    "requeria": "requerer",
    "requeriam": "requerer",
    "requerias": "requerer",
    "requerida": "requerido",
    "requeridas": "requerido",
    "requerido": "requerer",
    "requeridos": "requerido",
    "requerimentos": "requerimento",
    "requerê": "requerer",
    "requerêramo": "requerer",
    "requerêramos": "requerer",
    "requerêrei": "requerer",
    "requerêreis": "requerer",
    "requerêsseis": "requerer",
    "requerêssemos": "requerer",
    "requeríamo": "requerer",
    "requeríamos": "requerer",
    "requeríei": "requerer",
    "requeríeis": "requerer",
    "requesta": "requestar",
    "requestada": "requestar",
    "requestadas": "requestar",
    "requestado": "requestar",
    "requestadora": "requestador",
    "requestadoras": "requestador",
    "requestadores": "requestador",
    "requestados": "requestar",
    "requestai": "requestar",
    "requestais": "requestar",
    "requestam": "requestar",
    "requestamo": "requestar",
    "requestamos": "requestar",
    "requestando": "requestar",
    "requestara": "requestar",
    "requestaram": "requestar",
    "requestaras": "requestar",
    "requestarde": "requestar",
    "requestardes": "requestar",
    "requestare": "requestar",
    "requestarei": "requestar",
    "requestareis": "requestar",
    "requestarem": "requestar",
    "requestaremos": "requestar",
    "requestares": "requestar",
    "requestaria": "requestar",
    "requestariam": "requestar",
    "requestarias": "requestar",
    "requestarmo": "requestar",
    "requestarmos": "requestar",
    "requestará": "requestar",
    "requestarás": "requestar",
    "requestarão": "requestar",
    "requestaríamos": "requestar",
    "requestaríeis": "requestar",
    "requestas": "requestar",
    "requestasse": "requestar",
    "requestassem": "requestar",
    "requestasses": "requestar",
    "requestaste": "requestar",
    "requestastes": "requestar",
    "requestava": "requestar",
    "requestavam": "requestar",
    "requestavas": "requestar",
    "requeste": "requestar",
    "requestei": "requestar",
    "requesteis": "requestar",
    "requestem": "requestar",
    "requestemo": "requestar",
    "requestemos": "requestar",
    "requestes": "requestar",
    "requesto": "requestar",
    "requestos": "requesto",
    "requestou": "requestar",
    "requestá": "requestar",
    "requestámo": "requestar",
    "requestámos": "requestar",
    "requestáramo": "requestar",
    "requestáramos": "requestar",
    "requestárei": "requestar",
    "requestáreis": "requestar",
    "requestásseis": "requestar",
    "requestássemos": "requestar",
    "requestávamo": "requestar",
    "requestávamos": "requestar",
    "requestávei": "requestar",
    "requestáveis": "requestar",
    "requiens": "requiem",
    "requietudes": "requietude",
    "requietórios": "requietório",
    "requifeira": "requifeiro",
    "requifeiras": "requifeiro",
    "requifeiros": "requifeiro",
    "requifes": "requife",
    "requinta": "requintar",
    "requintada": "requintar",
    "requintadas": "requintar",
    "requintadazinha": "requintado",
    "requintadazinhas": "requintado",
    "requintadazita": "requintado",
    "requintadazitas": "requintado",
    "requintadinha": "requintado",
    "requintadinhas": "requintado",
    "requintadinho": "requintado",
    "requintadinhos": "requintado",
    "requintadita": "requintado",
    "requintaditas": "requintado",
    "requintadito": "requintado",
    "requintaditos": "requintado",
    "requintado": "requintar",
    "requintados": "requintar",
    "requintadozinho": "requintado",
    "requintadozinhos": "requintado",
    "requintadozito": "requintado",
    "requintadozitos": "requintado",
    "requintadíssima": "requintado",
    "requintadíssimas": "requintado",
    "requintadíssimo": "requintado",
    "requintadíssimos": "requintado",
    "requintai": "requintar",
    "requintais": "requintar",
    "requintam": "requintar",
    "requintamo": "requintar",
    "requintamos": "requintar",
    "requintando": "requintar",
    "requintara": "requintar",
    "requintaram": "requintar",
    "requintaras": "requintar",
    "requintarde": "requintar",
    "requintardes": "requintar",
    "requintare": "requintar",
    "requintarei": "requintar",
    "requintareis": "requintar",
    "requintarem": "requintar",
    "requintaremos": "requintar",
    "requintares": "requintar",
    "requintaria": "requintar",
    "requintariam": "requintar",
    "requintarias": "requintar",
    "requintarmo": "requintar",
    "requintarmos": "requintar",
    "requintará": "requintar",
    "requintarás": "requintar",
    "requintarão": "requintar",
    "requintaríamos": "requintar",
    "requintaríeis": "requintar",
    "requintas": "requintar",
    "requintasse": "requintar",
    "requintassem": "requintar",
    "requintasses": "requintar",
    "requintaste": "requintar",
    "requintastes": "requintar",
    "requintava": "requintar",
    "requintavam": "requintar",
    "requintavas": "requintar",
    "requinte": "requintar",
    "requintei": "requintar",
    "requinteis": "requintar",
    "requintem": "requintar",
    "requintemo": "requintar",
    "requintemos": "requintar",
    "requintes": "requinte",
    "requintistas": "requintista",
    "requinto": "requintar",
    "requintou": "requintar",
    "requintá": "requintar",
    "requintámo": "requintar",
    "requintámos": "requintar",
    "requintáramo": "requintar",
    "requintáramos": "requintar",
    "requintárei": "requintar",
    "requintáreis": "requintar",
    "requintásseis": "requintar",
    "requintássemos": "requintar",
    "requintávamo": "requintar",
    "requintávamos": "requintar",
    "requintávei": "requintar",
    "requintáveis": "requintar",
    "requisita": "requisito",
    "requisitada": "requisitar",
    "requisitadas": "requisitar",
    "requisitado": "requisitar",
    "requisitados": "requisitar",
    "requisitai": "requisitar",
    "requisitais": "requisitar",
    "requisitam": "requisitar",
    "requisitamo": "requisitar",
    "requisitamos": "requisitar",
    "requisitando": "requisitar",
    "requisitantes": "requisitante",
    "requisitara": "requisitar",
    "requisitaram": "requisitar",
    "requisitaras": "requisitar",
    "requisitarde": "requisitar",
    "requisitardes": "requisitar",
    "requisitare": "requisitar",
    "requisitarei": "requisitar",
    "requisitareis": "requisitar",
    "requisitarem": "requisitar",
    "requisitaremos": "requisitar",
    "requisitares": "requisitar",
    "requisitaria": "requisitar",
    "requisitariam": "requisitar",
    "requisitarias": "requisitar",
    "requisitarmo": "requisitar",
    "requisitarmos": "requisitar",
    "requisitará": "requisitar",
    "requisitarás": "requisitar",
    "requisitarão": "requisitar",
    "requisitaríamos": "requisitar",
    "requisitaríeis": "requisitar",
    "requisitas": "requisito",
    "requisitasse": "requisitar",
    "requisitassem": "requisitar",
    "requisitasses": "requisitar",
    "requisitaste": "requisitar",
    "requisitastes": "requisitar",
    "requisitava": "requisitar",
    "requisitavam": "requisitar",
    "requisitavas": "requisitar",
    "requisite": "requisitar",
    "requisitei": "requisitar",
    "requisiteis": "requisitar",
    "requisitem": "requisitar",
    "requisitemo": "requisitar",
    "requisitemos": "requisitar",
    "requisites": "requisitar",
    "requisito": "requisitar",
    "requisitos": "requisito",
    "requisitou": "requisitar",
    "requisitá": "requisitar",
    "requisitámo": "requisitar",
    "requisitámos": "requisitar",
    "requisitáramo": "requisitar",
    "requisitáramos": "requisitar",
    "requisitárei": "requisitar",
    "requisitáreis": "requisitar",
    "requisitásseis": "requisitar",
    "requisitássemos": "requisitar",
    "requisitávamo": "requisitar",
    "requisitávamos": "requisitar",
    "requisitávei": "requisitar",
    "requisitáveis": "requisitável",
    "requisitória": "requisitório",
    "requisitórias": "requisitório",
    "requisitórios": "requisitório",
    "requisições": "requisição",
    "rerratificações": "rerratificação",
    "resalgares": "resalgar",
    "resalgários": "resalgário",
    "resbordos": "resbordo",
    "rescalda": "rescaldar",
    "rescaldada": "rescaldar",
    "rescaldadas": "rescaldar",
    "rescaldado": "rescaldar",
    "rescaldados": "rescaldar",
    "rescaldai": "rescaldar",
    "rescaldais": "rescaldar",
    "rescaldam": "rescaldar",
    "rescaldamo": "rescaldar",
    "rescaldamos": "rescaldar",
    "rescaldando": "rescaldar",
    "rescaldara": "rescaldar",
    "rescaldaram": "rescaldar",
    "rescaldaras": "rescaldar",
    "rescaldarde": "rescaldar",
    "rescaldardes": "rescaldar",
    "rescaldare": "rescaldar",
    "rescaldarei": "rescaldar",
    "rescaldareis": "rescaldar",
    "rescaldarem": "rescaldar",
    "rescaldaremos": "rescaldar",
    "rescaldares": "rescaldar",
    "rescaldaria": "rescaldar",
    "rescaldariam": "rescaldar",
    "rescaldarias": "rescaldar",
    "rescaldarmo": "rescaldar",
    "rescaldarmos": "rescaldar",
    "rescaldará": "rescaldar",
    "rescaldarás": "rescaldar",
    "rescaldarão": "rescaldar",
    "rescaldaríamos": "rescaldar",
    "rescaldaríeis": "rescaldar",
    "rescaldas": "rescaldar",
    "rescaldasse": "rescaldar",
    "rescaldassem": "rescaldar",
    "rescaldasses": "rescaldar",
    "rescaldaste": "rescaldar",
    "rescaldastes": "rescaldar",
    "rescaldava": "rescaldar",
    "rescaldavam": "rescaldar",
    "rescaldavas": "rescaldar",
    "rescalde": "rescaldar",
    "rescaldei": "rescaldar",
    "rescaldeiros": "rescaldeiro",
    "rescaldeis": "rescaldar",
    "rescaldem": "rescaldar",
    "rescaldemo": "rescaldar",
    "rescaldemos": "rescaldar",
    "rescaldes": "rescaldar",
    "rescaldo": "rescaldar",
    "rescaldos": "rescaldo",
    "rescaldou": "rescaldar",
    "rescaldá": "rescaldar",
    "rescaldámo": "rescaldar",
    "rescaldámos": "rescaldar",
    "rescaldáramo": "rescaldar",
    "rescaldáramos": "rescaldar",
    "rescaldárei": "rescaldar",
    "rescaldáreis": "rescaldar",
    "rescaldásseis": "rescaldar",
    "rescaldássemos": "rescaldar",
    "rescaldávamo": "rescaldar",
    "rescaldávamos": "rescaldar",
    "rescaldávei": "rescaldar",
    "rescaldáveis": "rescaldar",
    "rescenda": "rescender",
    "rescendais": "rescender",
    "rescendam": "rescender",
    "rescendamo": "rescender",
    "rescendamos": "rescender",
    "rescendas": "rescender",
    "rescende": "rescender",
    "rescendei": "rescender",
    "rescendeis": "rescender",
    "rescendem": "rescender",
    "rescendemo": "rescender",
    "rescendemos": "rescender",
    "rescendendo": "rescender",
    "rescendentes": "rescendente",
    "rescendera": "rescender",
    "rescenderam": "rescender",
    "rescenderas": "rescender",
    "rescenderdes": "rescender",
    "rescenderei": "rescender",
    "rescendereis": "rescender",
    "rescenderem": "rescender",
    "rescenderemos": "rescender",
    "rescenderes": "rescender",
    "rescenderia": "rescender",
    "rescenderiam": "rescender",
    "rescenderias": "rescender",
    "rescendermo": "rescender",
    "rescendermos": "rescender",
    "rescenderá": "rescender",
    "rescenderás": "rescender",
    "rescenderão": "rescender",
    "rescenderíamos": "rescender",
    "rescenderíeis": "rescender",
    "rescendes": "rescender",
    "rescendesse": "rescender",
    "rescendessem": "rescender",
    "rescendesses": "rescender",
    "rescendeste": "rescender",
    "rescendestes": "rescender",
    "rescendeu": "rescender",
    "rescendi": "rescender",
    "rescendia": "rescender",
    "rescendiam": "rescender",
    "rescendias": "rescender",
    "rescendida": "rescender",
    "rescendidas": "rescender",
    "rescendido": "rescender",
    "rescendidos": "rescender",
    "rescendo": "rescender",
    "rescendências": "rescendência",
    "rescendêramo": "rescender",
    "rescendêramos": "rescender",
    "rescendêreis": "rescender",
    "rescendêsseis": "rescender",
    "rescendêssemos": "rescender",
    "rescendíamo": "rescender",
    "rescendíamos": "rescender",
    "rescendíeis": "rescender",
    "rescinda": "rescindir",
    "rescindais": "rescindir",
    "rescindam": "rescindir",
    "rescindamo": "rescindir",
    "rescindamos": "rescindir",
    "rescindas": "rescindir",
    "rescinde": "rescindir",
    "rescindem": "rescindir",
    "rescindes": "rescindir",
    "rescindi": "rescindir",
    "rescindia": "rescindir",
    "rescindiam": "rescindir",
    "rescindias": "rescindir",
    "rescindibilidades": "rescindibilidade",
    "rescindida": "rescindir",
    "rescindidas": "rescindir",
    "rescindido": "rescindir",
    "rescindidos": "rescindir",
    "rescindimo": "rescindir",
    "rescindimos": "rescindir",
    "rescindindo": "rescindir",
    "rescindira": "rescindir",
    "rescindiram": "rescindir",
    "rescindiras": "rescindir",
    "rescindirde": "rescindir",
    "rescindirdes": "rescindir",
    "rescindire": "rescindir",
    "rescindirei": "rescindir",
    "rescindireis": "rescindir",
    "rescindirem": "rescindir",
    "rescindiremos": "rescindir",
    "rescindires": "rescindir",
    "rescindiria": "rescindir",
    "rescindiriam": "rescindir",
    "rescindirias": "rescindir",
    "rescindirmo": "rescindir",
    "rescindirmos": "rescindir",
    "rescindirá": "rescindir",
    "rescindirás": "rescindir",
    "rescindirão": "rescindir",
    "rescindiríamos": "rescindir",
    "rescindiríeis": "rescindir",
    "rescindis": "rescindir",
    "rescindisse": "rescindir",
    "rescindissem": "rescindir",
    "rescindisses": "rescindir",
    "rescindiste": "rescindir",
    "rescindistes": "rescindir",
    "rescindiu": "rescindir",
    "rescindo": "rescindir",
    "rescindências": "rescindência",
    "rescindíamo": "rescindir",
    "rescindíamos": "rescindir",
    "rescindíei": "rescindir",
    "rescindíeis": "rescindir",
    "rescindíramo": "rescindir",
    "rescindíramos": "rescindir",
    "rescindírei": "rescindir",
    "rescindíreis": "rescindir",
    "rescindísseis": "rescindir",
    "rescindíssemos": "rescindir",
    "rescindíveis": "rescindível",
    "rescisora": "rescisor",
    "rescisoras": "rescisor",
    "rescisores": "rescisor",
    "rescisória": "rescisório",
    "rescisórias": "rescisório",
    "rescisórios": "rescisório",
    "rescisões": "rescisão",
    "rescreva": "rescrever",
    "rescrevais": "rescrever",
    "rescrevam": "rescrever",
    "rescrevamo": "rescrever",
    "rescrevamos": "rescrever",
    "rescrevas": "rescrever",
    "rescreve": "rescrever",
    "rescrevei": "rescrever",
    "rescreveis": "rescrever",
    "rescrevem": "rescrever",
    "rescrevemo": "rescrever",
    "rescrevemos": "rescrever",
    "rescrevendo": "rescrever",
    "rescrevera": "rescrever",
    "rescreveram": "rescrever",
    "rescreveras": "rescrever",
    "rescreverde": "rescrever",
    "rescreverdes": "rescrever",
    "rescrevere": "rescrever",
    "rescreverei": "rescrever",
    "rescrevereis": "rescrever",
    "rescreverem": "rescrever",
    "rescreveremos": "rescrever",
    "rescreveres": "rescrever",
    "rescreveria": "rescrever",
    "rescreveriam": "rescrever",
    "rescreverias": "rescrever",
    "rescrevermo": "rescrever",
    "rescrevermos": "rescrever",
    "rescreverá": "rescrever",
    "rescreverás": "rescrever",
    "rescreverão": "rescrever",
    "rescreveríamos": "rescrever",
    "rescreveríeis": "rescrever",
    "rescreves": "rescrever",
    "rescrevesse": "rescrever",
    "rescrevessem": "rescrever",
    "rescrevesses": "rescrever",
    "rescreveste": "rescrever",
    "rescrevestes": "rescrever",
    "rescreveu": "rescrever",
    "rescrevi": "rescrever",
    "rescrevia": "rescrever",
    "rescreviam": "rescrever",
    "rescrevias": "rescrever",
    "rescrevida": "rescrever",
    "rescrevidas": "rescrever",
    "rescrevido": "rescrever",
    "rescrevidos": "rescrever",
    "rescrevo": "rescrever",
    "rescrevê": "rescrever",
    "rescrevêramo": "rescrever",
    "rescrevêramos": "rescrever",
    "rescrevêrei": "rescrever",
    "rescrevêreis": "rescrever",
    "rescrevêsseis": "rescrever",
    "rescrevêssemos": "rescrever",
    "rescrevíamo": "rescrever",
    "rescrevíamos": "rescrever",
    "rescrevíei": "rescrever",
    "rescrevíeis": "rescrever",
    "rescritos": "rescrito",
    "rescrições": "rescrição",
    "resedais": "resedal",
    "resedas": "reseda",
    "resedáceas": "resedácea",
    "resedíneas": "resedínea",
    "resenha": "resenhar",
    "resenhada": "resenhar",
    "resenhadas": "resenhar",
    "resenhado": "resenhar",
    "resenhados": "resenhar",
    "resenhai": "resenhar",
    "resenhais": "resenhar",
    "resenham": "resenhar",
    "resenhamo": "resenhar",
    "resenhamos": "resenhar",
    "resenhando": "resenhar",
    "resenhara": "resenhar",
    "resenharam": "resenhar",
    "resenharas": "resenhar",
    "resenharde": "resenhar",
    "resenhardes": "resenhar",
    "resenhare": "resenhar",
    "resenharei": "resenhar",
    "resenhareis": "resenhar",
    "resenharem": "resenhar",
    "resenharemos": "resenhar",
    "resenhares": "resenhar",
    "resenharia": "resenhar",
    "resenhariam": "resenhar",
    "resenharias": "resenhar",
    "resenharmo": "resenhar",
    "resenharmos": "resenhar",
    "resenhará": "resenhar",
    "resenharás": "resenhar",
    "resenharão": "resenhar",
    "resenharíamos": "resenhar",
    "resenharíeis": "resenhar",
    "resenhas": "resenhar",
    "resenhasse": "resenhar",
    "resenhassem": "resenhar",
    "resenhasses": "resenhar",
    "resenhaste": "resenhar",
    "resenhastes": "resenhar",
    "resenhava": "resenhar",
    "resenhavam": "resenhar",
    "resenhavas": "resenhar",
    "resenhe": "resenhar",
    "resenhei": "resenhar",
    "resenheis": "resenhar",
    "resenhem": "resenhar",
    "resenhemo": "resenhar",
    "resenhemos": "resenhar",
    "resenhes": "resenhar",
    "resenho": "resenhar",
    "resenhos": "resenho",
    "resenhou": "resenhar",
    "resenhá": "resenhar",
    "resenhámo": "resenhar",
    "resenhámos": "resenhar",
    "resenháramo": "resenhar",
    "resenháramos": "resenhar",
    "resenhárei": "resenhar",
    "resenháreis": "resenhar",
    "resenhásseis": "resenhar",
    "resenhássemos": "resenhar",
    "resenhávamo": "resenhar",
    "resenhávamos": "resenhar",
    "resenhávei": "resenhar",
    "resenháveis": "resenhar",
    "resentaduras": "resentadura",
    "reserpinas": "reserpina",
    "reserva": "reservar",
    "reservada": "reservar",
    "reservadas": "reservar",
    "reservadinha": "reservado",
    "reservadinhas": "reservado",
    "reservadinho": "reservado",
    "reservadinhos": "reservado",
    "reservadita": "reservado",
    "reservaditas": "reservado",
    "reservadito": "reservado",
    "reservaditos": "reservado",
    "reservado": "reservar",
    "reservadora": "reservador",
    "reservadoras": "reservador",
    "reservadores": "reservador",
    "reservados": "reservar",
    "reservadíssima": "reservado",
    "reservadíssimas": "reservado",
    "reservadíssimo": "reservado",
    "reservadíssimos": "reservado",
    "reservai": "reservar",
    "reservais": "reservar",
    "reservam": "reservar",
    "reservamo": "reservar",
    "reservamos": "reservar",
    "reservando": "reservar",
    "reservara": "reservar",
    "reservaram": "reservar",
    "reservaras": "reservar",
    "reservarde": "reservar",
    "reservardes": "reservar",
    "reservare": "reservar",
    "reservarei": "reservar",
    "reservareis": "reservar",
    "reservarem": "reservar",
    "reservaremos": "reservar",
    "reservares": "reservar",
    "reservaria": "reservar",
    "reservariam": "reservar",
    "reservarias": "reservar",
    "reservarmo": "reservar",
    "reservarmos": "reservar",
    "reservará": "reservar",
    "reservarás": "reservar",
    "reservarão": "reservar",
    "reservaríamos": "reservar",
    "reservaríeis": "reservar",
    "reservas": "reservar",
    "reservasse": "reservar",
    "reservassem": "reservar",
    "reservasses": "reservar",
    "reservaste": "reservar",
    "reservastes": "reservar",
    "reservativa": "reservativo",
    "reservativas": "reservativo",
    "reservativos": "reservativo",
    "reservatórios": "reservatório",
    "reservava": "reservar",
    "reservavam": "reservar",
    "reservavas": "reservar",
    "reservações": "reservação",
    "reserve": "reservar",
    "reservei": "reservar",
    "reserveis": "reservar",
    "reservem": "reservar",
    "reservemo": "reservar",
    "reservemos": "reservar",
    "reserves": "reservar",
    "reservistas": "reservista",
    "reservo": "reservar",
    "reservou": "reservar",
    "reservá": "reservar",
    "reservámo": "reservar",
    "reservámos": "reservar",
    "reserváramo": "reservar",
    "reserváramos": "reservar",
    "reservárei": "reservar",
    "reserváreis": "reservar",
    "reservásseis": "reservar",
    "reservássemos": "reservar",
    "reservávamo": "reservar",
    "reservávamos": "reservar",
    "reservávei": "reservar",
    "reserváveis": "reservar",
    "reses": "rês",
    "resfolega": "resfolegar",
    "resfolegada": "resfolegar",
    "resfolegadas": "resfolegar",
    "resfolegado": "resfolegar",
    "resfolegadoiros": "resfolegadoiro",
    "resfolegados": "resfolegar",
    "resfolegadouros": "resfolegadouro",
    "resfolegai": "resfolegar",
    "resfolegais": "resfolegar",
    "resfolegam": "resfolegar",
    "resfolegamo": "resfolegar",
    "resfolegamos": "resfolegar",
    "resfolegando": "resfolegar",
    "resfolegantes": "resfolegante",
    "resfolegara": "resfolegar",
    "resfolegaram": "resfolegar",
    "resfolegaras": "resfolegar",
    "resfolegardes": "resfolegar",
    "resfolegarei": "resfolegar",
    "resfolegareis": "resfolegar",
    "resfolegarem": "resfolegar",
    "resfolegaremos": "resfolegar",
    "resfolegares": "resfolegar",
    "resfolegaria": "resfolegar",
    "resfolegariam": "resfolegar",
    "resfolegarias": "resfolegar",
    "resfolegarmo": "resfolegar",
    "resfolegarmos": "resfolegar",
    "resfolegará": "resfolegar",
    "resfolegarás": "resfolegar",
    "resfolegarão": "resfolegar",
    "resfolegaríamos": "resfolegar",
    "resfolegaríeis": "resfolegar",
    "resfolegas": "resfolegar",
    "resfolegasse": "resfolegar",
    "resfolegassem": "resfolegar",
    "resfolegasses": "resfolegar",
    "resfolegaste": "resfolegar",
    "resfolegastes": "resfolegar",
    "resfolegava": "resfolegar",
    "resfolegavam": "resfolegar",
    "resfolegavas": "resfolegar",
    "resfolego": "resfolegar",
    "resfolegou": "resfolegar",
    "resfolegue": "resfolegar",
    "resfoleguei": "resfolegar",
    "resfolegueis": "resfolegar",
    "resfoleguem": "resfolegar",
    "resfoleguemo": "resfolegar",
    "resfoleguemos": "resfolegar",
    "resfolegues": "resfolegar",
    "resfolegámo": "resfolegar",
    "resfolegámos": "resfolegar",
    "resfolegáramo": "resfolegar",
    "resfolegáramos": "resfolegar",
    "resfolegáreis": "resfolegar",
    "resfolegásseis": "resfolegar",
    "resfolegássemos": "resfolegar",
    "resfolegávamo": "resfolegar",
    "resfolegávamos": "resfolegar",
    "resfolegáveis": "resfolegar",
    "resfolga": "resfolgar",
    "resfolgada": "resfolgar",
    "resfolgadas": "resfolgar",
    "resfolgado": "resfolgar",
    "resfolgadoiros": "resfolgadoiro",
    "resfolgados": "resfolgar",
    "resfolgadouros": "resfolgadouro",
    "resfolgai": "resfolgar",
    "resfolgais": "resfolgar",
    "resfolgam": "resfolgar",
    "resfolgamo": "resfolgar",
    "resfolgamos": "resfolgar",
    "resfolgando": "resfolgar",
    "resfolgantes": "resfolgante",
    "resfolgara": "resfolgar",
    "resfolgaram": "resfolgar",
    "resfolgaras": "resfolgar",
    "resfolgardes": "resfolgar",
    "resfolgarei": "resfolgar",
    "resfolgareis": "resfolgar",
    "resfolgarem": "resfolgar",
    "resfolgaremos": "resfolgar",
    "resfolgares": "resfolgar",
    "resfolgaria": "resfolgar",
    "resfolgariam": "resfolgar",
    "resfolgarias": "resfolgar",
    "resfolgarmo": "resfolgar",
    "resfolgarmos": "resfolgar",
    "resfolgará": "resfolgar",
    "resfolgarás": "resfolgar",
    "resfolgarão": "resfolgar",
    "resfolgaríamos": "resfolgar",
    "resfolgaríeis": "resfolgar",
    "resfolgas": "resfolgar",
    "resfolgasse": "resfolgar",
    "resfolgassem": "resfolgar",
    "resfolgasses": "resfolgar",
    "resfolgaste": "resfolgar",
    "resfolgastes": "resfolgar",
    "resfolgava": "resfolgar",
    "resfolgavam": "resfolgar",
    "resfolgavas": "resfolgar",
    "resfolgo": "resfolgar",
    "resfolgos": "resfolgo",
    "resfolgou": "resfolgar",
    "resfolgue": "resfolgar",
    "resfolguei": "resfolgar",
    "resfolgueis": "resfolgar",
    "resfolguem": "resfolgar",
    "resfolguemo": "resfolgar",
    "resfolguemos": "resfolgar",
    "resfolgues": "resfolgar",
    "resfolgámo": "resfolgar",
    "resfolgámos": "resfolgar",
    "resfolgáramo": "resfolgar",
    "resfolgáramos": "resfolgar",
    "resfolgáreis": "resfolgar",
    "resfolgásseis": "resfolgar",
    "resfolgássemos": "resfolgar",
    "resfolgávamo": "resfolgar",
    "resfolgávamos": "resfolgar",
    "resfolgáveis": "resfolgar",
    "resfria": "resfriar",
    "resfriada": "resfriar",
    "resfriadas": "resfriar",
    "resfriadinha": "resfriado",
    "resfriadinhas": "resfriado",
    "resfriadinho": "resfriado",
    "resfriadinhos": "resfriado",
    "resfriadita": "resfriado",
    "resfriaditas": "resfriado",
    "resfriadito": "resfriado",
    "resfriaditos": "resfriado",
    "resfriado": "resfriar",
    "resfriadora": "resfriador",
    "resfriadoras": "resfriador",
    "resfriadores": "resfriador",
    "resfriados": "resfriar",
    "resfriadouros": "resfriadouro",
    "resfriadíssima": "resfriado",
    "resfriadíssimas": "resfriado",
    "resfriadíssimo": "resfriado",
    "resfriadíssimos": "resfriado",
    "resfriai": "resfriar",
    "resfriais": "resfriar",
    "resfriam": "resfriar",
    "resfriamentos": "resfriamento",
    "resfriamo": "resfriar",
    "resfriamos": "resfriar",
    "resfriando": "resfriar",
    "resfriantes": "resfriante",
    "resfriara": "resfriar",
    "resfriaram": "resfriar",
    "resfriaras": "resfriar",
    "resfriarde": "resfriar",
    "resfriardes": "resfriar",
    "resfriare": "resfriar",
    "resfriarei": "resfriar",
    "resfriareis": "resfriar",
    "resfriarem": "resfriar",
    "resfriaremos": "resfriar",
    "resfriares": "resfriar",
    "resfriaria": "resfriar",
    "resfriariam": "resfriar",
    "resfriarias": "resfriar",
    "resfriarmo": "resfriar",
    "resfriarmos": "resfriar",
    "resfriará": "resfriar",
    "resfriarás": "resfriar",
    "resfriarão": "resfriar",
    "resfriaríamos": "resfriar",
    "resfriaríeis": "resfriar",
    "resfrias": "resfriar",
    "resfriasse": "resfriar",
    "resfriassem": "resfriar",
    "resfriasses": "resfriar",
    "resfriaste": "resfriar",
    "resfriastes": "resfriar",
    "resfriava": "resfriar",
    "resfriavam": "resfriar",
    "resfriavas": "resfriar",
    "resfrie": "resfriar",
    "resfriei": "resfriar",
    "resfrieis": "resfriar",
    "resfriem": "resfriar",
    "resfriemo": "resfriar",
    "resfriemos": "resfriar",
    "resfries": "resfriar",
    "resfrio": "resfriar",
    "resfriou": "resfriar",
    "resfriá": "resfriar",
    "resfriámo": "resfriar",
    "resfriámos": "resfriar",
    "resfriáramo": "resfriar",
    "resfriáramos": "resfriar",
    "resfriárei": "resfriar",
    "resfriáreis": "resfriar",
    "resfriásseis": "resfriar",
    "resfriássemos": "resfriar",
    "resfriávamo": "resfriar",
    "resfriávamos": "resfriar",
    "resfriávei": "resfriar",
    "resfriáveis": "resfriar",
    "resfôlegos": "resfôlego",
    "resgata": "resgatar",
    "resgatabilidades": "resgatabilidade",
    "resgatada": "resgatar",
    "resgatadas": "resgatar",
    "resgatado": "resgatar",
    "resgatadora": "resgatador",
    "resgatadoras": "resgatador",
    "resgatadores": "resgatador",
    "resgatados": "resgatar",
    "resgatai": "resgatar",
    "resgatais": "resgatar",
    "resgatam": "resgatar",
    "resgatamo": "resgatar",
    "resgatamos": "resgatar",
    "resgatando": "resgatar",
    "resgatara": "resgatar",
    "resgataram": "resgatar",
    "resgataras": "resgatar",
    "resgatarde": "resgatar",
    "resgatardes": "resgatar",
    "resgatare": "resgatar",
    "resgatarei": "resgatar",
    "resgatareis": "resgatar",
    "resgatarem": "resgatar",
    "resgataremos": "resgatar",
    "resgatares": "resgatar",
    "resgataria": "resgatar",
    "resgatariam": "resgatar",
    "resgatarias": "resgatar",
    "resgatarmo": "resgatar",
    "resgatarmos": "resgatar",
    "resgatará": "resgatar",
    "resgatarás": "resgatar",
    "resgatarão": "resgatar",
    "resgataríamos": "resgatar",
    "resgataríeis": "resgatar",
    "resgatas": "resgatar",
    "resgatasse": "resgatar",
    "resgatassem": "resgatar",
    "resgatasses": "resgatar",
    "resgataste": "resgatar",
    "resgatastes": "resgatar",
    "resgatava": "resgatar",
    "resgatavam": "resgatar",
    "resgatavas": "resgatar",
    "resgate": "resgatar",
    "resgatei": "resgatar",
    "resgateis": "resgatar",
    "resgatem": "resgatar",
    "resgatemo": "resgatar",
    "resgatemos": "resgatar",
    "resgates": "resgate",
    "resgato": "resgatar",
    "resgatou": "resgatar",
    "resgatá": "resgatar",
    "resgatámo": "resgatar",
    "resgatámos": "resgatar",
    "resgatáramo": "resgatar",
    "resgatáramos": "resgatar",
    "resgatárei": "resgatar",
    "resgatáreis": "resgatar",
    "resgatásseis": "resgatar",
    "resgatássemos": "resgatar",
    "resgatávamo": "resgatar",
    "resgatávamos": "resgatar",
    "resgatávei": "resgatar",
    "resgatáveis": "resgatável",
    "resguarda": "resguardar",
    "resguardada": "resguardar",
    "resguardadas": "resguardar",
    "resguardado": "resguardar",
    "resguardados": "resguardar",
    "resguardai": "resguardar",
    "resguardais": "resguardar",
    "resguardam": "resguardar",
    "resguardamo": "resguardar",
    "resguardamos": "resguardar",
    "resguardando": "resguardar",
    "resguardara": "resguardar",
    "resguardaram": "resguardar",
    "resguardaras": "resguardar",
    "resguardarde": "resguardar",
    "resguardardes": "resguardar",
    "resguardare": "resguardar",
    "resguardarei": "resguardar",
    "resguardareis": "resguardar",
    "resguardarem": "resguardar",
    "resguardaremos": "resguardar",
    "resguardares": "resguardar",
    "resguardaria": "resguardar",
    "resguardariam": "resguardar",
    "resguardarias": "resguardar",
    "resguardarmo": "resguardar",
    "resguardarmos": "resguardar",
    "resguardará": "resguardar",
    "resguardarás": "resguardar",
    "resguardarão": "resguardar",
    "resguardaríamos": "resguardar",
    "resguardaríeis": "resguardar",
    "resguardas": "resguardar",
    "resguardasse": "resguardar",
    "resguardassem": "resguardar",
    "resguardasses": "resguardar",
    "resguardaste": "resguardar",
    "resguardastes": "resguardar",
    "resguardava": "resguardar",
    "resguardavam": "resguardar",
    "resguardavas": "resguardar",
    "resguarde": "resguardar",
    "resguardei": "resguardar",
    "resguardeis": "resguardar",
    "resguardem": "resguardar",
    "resguardemo": "resguardar",
    "resguardemos": "resguardar",
    "resguardes": "resguardar",
    "resguardo": "resguardar",
    "resguardos": "resguardo",
    "resguardou": "resguardar",
    "resguardá": "resguardar",
    "resguardámo": "resguardar",
    "resguardámos": "resguardar",
    "resguardáramo": "resguardar",
    "resguardáramos": "resguardar",
    "resguardárei": "resguardar",
    "resguardáreis": "resguardar",
    "resguardásseis": "resguardar",
    "resguardássemos": "resguardar",
    "resguardávamo": "resguardar",
    "resguardávamos": "resguardar",
    "resguardávei": "resguardar",
    "resguardáveis": "resguardar",
    "resida": "residir",
    "residais": "residir",
    "residam": "residir",
    "residamo": "residir",
    "residamos": "residir",
    "residas": "residir",
    "reside": "residir",
    "residem": "residir",
    "residenciais": "residencial",
    "residentes": "residente",
    "resides": "residir",
    "residi": "residir",
    "residia": "residir",
    "residiam": "residir",
    "residias": "residir",
    "residida": "residir",
    "resididas": "residir",
    "residido": "residir",
    "resididos": "residir",
    "residimo": "residir",
    "residimos": "residir",
    "residindo": "residir",
    "residira": "residir",
    "residiram": "residir",
    "residiras": "residir",
    "residirdes": "residir",
    "residirei": "residir",
    "residireis": "residir",
    "residirem": "residir",
    "residiremos": "residir",
    "residires": "residir",
    "residiria": "residir",
    "residiriam": "residir",
    "residirias": "residir",
    "residirmo": "residir",
    "residirmos": "residir",
    "residirá": "residir",
    "residirás": "residir",
    "residirão": "residir",
    "residiríamos": "residir",
    "residiríeis": "residir",
    "residis": "residir",
    "residisse": "residir",
    "residissem": "residir",
    "residisses": "residir",
    "residiste": "residir",
    "residistes": "residir",
    "residiu": "residir",
    "resido": "residir",
    "residuais": "residual",
    "residuária": "residuário",
    "residuárias": "residuário",
    "residuários": "residuário",
    "residências": "residência",
    "residíamo": "residir",
    "residíamos": "residir",
    "residíeis": "residir",
    "residíramo": "residir",
    "residíramos": "residir",
    "residíreis": "residir",
    "residísseis": "residir",
    "residíssemos": "residir",
    "resigna": "resignar",
    "resignada": "resignar",
    "resignadas": "resignar",
    "resignadazinha": "resignado",
    "resignadazinhas": "resignado",
    "resignadazita": "resignado",
    "resignadazitas": "resignado",
    "resignadinha": "resignado",
    "resignadinhas": "resignado",
    "resignadinho": "resignado",
    "resignadinhos": "resignado",
    "resignadita": "resignado",
    "resignaditas": "resignado",
    "resignadito": "resignado",
    "resignaditos": "resignado",
    "resignado": "resignar",
    "resignados": "resignar",
    "resignadozinho": "resignado",
    "resignadozinhos": "resignado",
    "resignadozito": "resignado",
    "resignadozitos": "resignado",
    "resignadíssima": "resignado",
    "resignadíssimas": "resignado",
    "resignadíssimo": "resignado",
    "resignadíssimos": "resignado",
    "resignai": "resignar",
    "resignais": "resignar",
    "resignam": "resignar",
    "resignamo": "resignar",
    "resignamos": "resignar",
    "resignando": "resignar",
    "resignantes": "resignante",
    "resignara": "resignar",
    "resignaram": "resignar",
    "resignaras": "resignar",
    "resignarde": "resignar",
    "resignardes": "resignar",
    "resignare": "resignar",
    "resignarei": "resignar",
    "resignareis": "resignar",
    "resignarem": "resignar",
    "resignaremos": "resignar",
    "resignares": "resignar",
    "resignaria": "resignar",
    "resignariam": "resignar",
    "resignarias": "resignar",
    "resignarmo": "resignar",
    "resignarmos": "resignar",
    "resignará": "resignar",
    "resignarás": "resignar",
    "resignarão": "resignar",
    "resignaríamos": "resignar",
    "resignaríeis": "resignar",
    "resignas": "resignar",
    "resignasse": "resignar",
    "resignassem": "resignar",
    "resignasses": "resignar",
    "resignaste": "resignar",
    "resignastes": "resignar",
    "resignatária": "resignatário",
    "resignatárias": "resignatário",
    "resignatários": "resignatário",
    "resignava": "resignar",
    "resignavam": "resignar",
    "resignavas": "resignar",
    "resignações": "resignação",
    "resigne": "resignar",
    "resignei": "resignar",
    "resigneis": "resignar",
    "resignem": "resignar",
    "resignemo": "resignar",
    "resignemos": "resignar",
    "resignes": "resignar",
    "resigno": "resignar",
    "resignou": "resignar",
    "resigná": "resignar",
    "resignámo": "resignar",
    "resignámos": "resignar",
    "resignáramo": "resignar",
    "resignáramos": "resignar",
    "resignárei": "resignar",
    "resignáreis": "resignar",
    "resignásseis": "resignar",
    "resignássemos": "resignar",
    "resignávamo": "resignar",
    "resignávamos": "resignar",
    "resignávei": "resignar",
    "resignáveis": "resignável",
    "resila": "resilir",
    "resilais": "resilir",
    "resilam": "resilir",
    "resilamo": "resilir",
    "resilamos": "resilir",
    "resilas": "resilir",
    "resile": "resilir",
    "resilem": "resilir",
    "resiles": "resilir",
    "resili": "resilir",
    "resilia": "resilir",
    "resiliam": "resilir",
    "resilias": "resilir",
    "resilida": "resilir",
    "resilidas": "resilir",
    "resilido": "resilir",
    "resilidos": "resilir",
    "resilientes": "resiliente",
    "resilimo": "resilir",
    "resilimos": "resilir",
    "resilindo": "resilir",
    "resilira": "resilir",
    "resiliram": "resilir",
    "resiliras": "resilir",
    "resilirde": "resilir",
    "resilirdes": "resilir",
    "resilire": "resilir",
    "resilirei": "resilir",
    "resilireis": "resilir",
    "resilirem": "resilir",
    "resiliremos": "resilir",
    "resilires": "resilir",
    "resiliria": "resilir",
    "resiliriam": "resilir",
    "resilirias": "resilir",
    "resilirmo": "resilir",
    "resilirmos": "resilir",
    "resilirá": "resilir",
    "resilirás": "resilir",
    "resilirão": "resilir",
    "resiliríamos": "resilir",
    "resiliríeis": "resilir",
    "resilis": "resilir",
    "resilisse": "resilir",
    "resilissem": "resilir",
    "resilisses": "resilir",
    "resiliste": "resilir",
    "resilistes": "resilir",
    "resiliu": "resilir",
    "resiliências": "resiliência",
    "resilo": "resilir",
    "resilíamo": "resilir",
    "resilíamos": "resilir",
    "resilíei": "resilir",
    "resilíeis": "resilir",
    "resilíramo": "resilir",
    "resilíramos": "resilir",
    "resilírei": "resilir",
    "resilíreis": "resilir",
    "resilísseis": "resilir",
    "resilíssemos": "resilir",
    "resina": "resinar",
    "resinada": "resinar",
    "resinadas": "resinar",
    "resinado": "resinar",
    "resinados": "resinar",
    "resinagens": "resinagem",
    "resinai": "resinar",
    "resinais": "resinar",
    "resinam": "resinar",
    "resinamo": "resinar",
    "resinamos": "resinar",
    "resinando": "resinar",
    "resinara": "resinar",
    "resinaram": "resinar",
    "resinaras": "resinar",
    "resinarde": "resinar",
    "resinardes": "resinar",
    "resinare": "resinar",
    "resinarei": "resinar",
    "resinareis": "resinar",
    "resinarem": "resinar",
    "resinaremos": "resinar",
    "resinares": "resinar",
    "resinaria": "resinar",
    "resinariam": "resinar",
    "resinarias": "resinar",
    "resinarmo": "resinar",
    "resinarmos": "resinar",
    "resinará": "resinar",
    "resinarás": "resinar",
    "resinarão": "resinar",
    "resinaríamos": "resinar",
    "resinaríeis": "resinar",
    "resinas": "resinar",
    "resinasse": "resinar",
    "resinassem": "resinar",
    "resinasses": "resinar",
    "resinaste": "resinar",
    "resinastes": "resinar",
    "resinava": "resinar",
    "resinavam": "resinar",
    "resinavas": "resinar",
    "resinações": "resinação",
    "resine": "resinar",
    "resinei": "resinar",
    "resineira": "resineiro",
    "resineiras": "resineiro",
    "resineirazinha": "resineiro",
    "resineirazinhas": "resineiro",
    "resineirazita": "resineiro",
    "resineirazitas": "resineiro",
    "resineiros": "resineiro",
    "resineirozinho": "resineiro",
    "resineirozinhos": "resineiro",
    "resineirozito": "resineiro",
    "resineirozitos": "resineiro",
    "resineis": "resinar",
    "resinem": "resinar",
    "resinemo": "resinar",
    "resinemos": "resinar",
    "resinenta": "resinento",
    "resinentas": "resinento",
    "resinentos": "resinento",
    "resines": "resinar",
    "resinifica": "resinificar",
    "resinificada": "resinificar",
    "resinificadas": "resinificar",
    "resinificado": "resinificar",
    "resinificados": "resinificar",
    "resinificai": "resinificar",
    "resinificais": "resinificar",
    "resinificam": "resinificar",
    "resinificamo": "resinificar",
    "resinificamos": "resinificar",
    "resinificando": "resinificar",
    "resinificara": "resinificar",
    "resinificaram": "resinificar",
    "resinificaras": "resinificar",
    "resinificarde": "resinificar",
    "resinificardes": "resinificar",
    "resinificare": "resinificar",
    "resinificarei": "resinificar",
    "resinificareis": "resinificar",
    "resinificarem": "resinificar",
    "resinificaremos": "resinificar",
    "resinificares": "resinificar",
    "resinificaria": "resinificar",
    "resinificariam": "resinificar",
    "resinificarias": "resinificar",
    "resinificarmo": "resinificar",
    "resinificarmos": "resinificar",
    "resinificará": "resinificar",
    "resinificarás": "resinificar",
    "resinificarão": "resinificar",
    "resinificaríamos": "resinificar",
    "resinificaríeis": "resinificar",
    "resinificas": "resinificar",
    "resinificasse": "resinificar",
    "resinificassem": "resinificar",
    "resinificasses": "resinificar",
    "resinificaste": "resinificar",
    "resinificastes": "resinificar",
    "resinificava": "resinificar",
    "resinificavam": "resinificar",
    "resinificavas": "resinificar",
    "resinificações": "resinificação",
    "resinifico": "resinificar",
    "resinificou": "resinificar",
    "resinificá": "resinificar",
    "resinificámo": "resinificar",
    "resinificámos": "resinificar",
    "resinificáramo": "resinificar",
    "resinificáramos": "resinificar",
    "resinificárei": "resinificar",
    "resinificáreis": "resinificar",
    "resinificásseis": "resinificar",
    "resinificássemos": "resinificar",
    "resinificávamo": "resinificar",
    "resinificávamos": "resinificar",
    "resinificávei": "resinificar",
    "resinificáveis": "resinificável",
    "resinifique": "resinificar",
    "resinifiquei": "resinificar",
    "resinifiqueis": "resinificar",
    "resinifiquem": "resinificar",
    "resinifiquemo": "resinificar",
    "resinifiquemos": "resinificar",
    "resinifiques": "resinificar",
    "resiniformes": "resiniforme",
    "resino": "resinar",
    "resinosa": "resinoso",
    "resinosas": "resinoso",
    "resinosos": "resinoso",
    "resinou": "resinar",
    "resiná": "resinar",
    "resinámo": "resinar",
    "resinámos": "resinar",
    "resináramo": "resinar",
    "resináramos": "resinar",
    "resinárei": "resinar",
    "resináreis": "resinar",
    "resinásseis": "resinar",
    "resinássemos": "resinar",
    "resinávamo": "resinar",
    "resinávamos": "resinar",
    "resinávei": "resinar",
    "resináveis": "resinar",
    "resinífera": "resinífero",
    "resiníferas": "resinífero",
    "resiníferos": "resinífero",
    "resispicências": "resispicência",
    "resista": "resistir",
    "resistais": "resistir",
    "resistam": "resistir",
    "resistamo": "resistir",
    "resistamos": "resistir",
    "resistas": "resistir",
    "resiste": "resistir",
    "resistem": "resistir",
    "resistenciazinha": "resistência",
    "resistenciazinhas": "resistência",
    "resistenciazita": "resistência",
    "resistenciazitas": "resistência",
    "resistentes": "resistente",
    "resistentíssima": "resistente",
    "resistentíssimas": "resistente",
    "resistentíssimo": "resistente",
    "resistentíssimos": "resistente",
    "resistes": "resistir",
    "resisti": "resistir",
    "resistia": "resistir",
    "resistiam": "resistir",
    "resistias": "resistir",
    "resistibilidades": "resistibilidade",
    "resistida": "resistir",
    "resistidas": "resistir",
    "resistido": "resistir",
    "resistidos": "resistir",
    "resistimo": "resistir",
    "resistimos": "resistir",
    "resistindo": "resistir",
    "resistira": "resistir",
    "resistiram": "resistir",
    "resistiras": "resistir",
    "resistirdes": "resistir",
    "resistirei": "resistir",
    "resistireis": "resistir",
    "resistirem": "resistir",
    "resistiremos": "resistir",
    "resistires": "resistir",
    "resistiria": "resistir",
    "resistiriam": "resistir",
    "resistirias": "resistir",
    "resistirmo": "resistir",
    "resistirmos": "resistir",
    "resistirá": "resistir",
    "resistirás": "resistir",
    "resistirão": "resistir",
    "resistiríamos": "resistir",
    "resistiríeis": "resistir",
    "resistis": "resistir",
    "resistisse": "resistir",
    "resistissem": "resistir",
    "resistisses": "resistir",
    "resististe": "resistir",
    "resististes": "resistir",
    "resistiu": "resistir",
    "resistividades": "resistividade",
    "resisto": "resistir",
    "resistências": "resistência",
    "resistíamo": "resistir",
    "resistíamos": "resistir",
    "resistíeis": "resistir",
    "resistíramo": "resistir",
    "resistíramos": "resistir",
    "resistíreis": "resistir",
    "resistísseis": "resistir",
    "resistíssemos": "resistir",
    "resistíveis": "resistível",
    "reslumbra": "reslumbrar",
    "reslumbrada": "reslumbrar",
    "reslumbradas": "reslumbrar",
    "reslumbrado": "reslumbrar",
    "reslumbrados": "reslumbrar",
    "reslumbrai": "reslumbrar",
    "reslumbrais": "reslumbrar",
    "reslumbram": "reslumbrar",
    "reslumbramo": "reslumbrar",
    "reslumbramos": "reslumbrar",
    "reslumbrando": "reslumbrar",
    "reslumbrara": "reslumbrar",
    "reslumbraram": "reslumbrar",
    "reslumbraras": "reslumbrar",
    "reslumbrardes": "reslumbrar",
    "reslumbrarei": "reslumbrar",
    "reslumbrareis": "reslumbrar",
    "reslumbrarem": "reslumbrar",
    "reslumbraremos": "reslumbrar",
    "reslumbrares": "reslumbrar",
    "reslumbraria": "reslumbrar",
    "reslumbrariam": "reslumbrar",
    "reslumbrarias": "reslumbrar",
    "reslumbrarmo": "reslumbrar",
    "reslumbrarmos": "reslumbrar",
    "reslumbrará": "reslumbrar",
    "reslumbrarás": "reslumbrar",
    "reslumbrarão": "reslumbrar",
    "reslumbraríamos": "reslumbrar",
    "reslumbraríeis": "reslumbrar",
    "reslumbras": "reslumbrar",
    "reslumbrasse": "reslumbrar",
    "reslumbrassem": "reslumbrar",
    "reslumbrasses": "reslumbrar",
    "reslumbraste": "reslumbrar",
    "reslumbrastes": "reslumbrar",
    "reslumbrava": "reslumbrar",
    "reslumbravam": "reslumbrar",
    "reslumbravas": "reslumbrar",
    "reslumbre": "reslumbrar",
    "reslumbrei": "reslumbrar",
    "reslumbreis": "reslumbrar",
    "reslumbrem": "reslumbrar",
    "reslumbremo": "reslumbrar",
    "reslumbremos": "reslumbrar",
    "reslumbres": "reslumbrar",
    "reslumbro": "reslumbrar",
    "reslumbrou": "reslumbrar",
    "reslumbrámo": "reslumbrar",
    "reslumbrámos": "reslumbrar",
    "reslumbráramo": "reslumbrar",
    "reslumbráramos": "reslumbrar",
    "reslumbráreis": "reslumbrar",
    "reslumbrásseis": "reslumbrar",
    "reslumbrássemos": "reslumbrar",
    "reslumbrávamo": "reslumbrar",
    "reslumbrávamos": "reslumbrar",
    "reslumbráveis": "reslumbrar",
    "reslumbrâncias": "reslumbrância",
    "resmas": "resma",
    "resmoneada": "resmonear",
    "resmoneadas": "resmonear",
    "resmoneado": "resmonear",
    "resmoneadora": "resmoneador",
    "resmoneadoras": "resmoneador",
    "resmoneadores": "resmoneador",
    "resmoneados": "resmonear",
    "resmoneai": "resmonear",
    "resmoneais": "resmonear",
    "resmoneamo": "resmonear",
    "resmoneamos": "resmonear",
    "resmoneando": "resmonear",
    "resmoneara": "resmonear",
    "resmonearam": "resmonear",
    "resmonearas": "resmonear",
    "resmoneardes": "resmonear",
    "resmonearei": "resmonear",
    "resmoneareis": "resmonear",
    "resmonearem": "resmonear",
    "resmonearemos": "resmonear",
    "resmoneares": "resmonear",
    "resmonearia": "resmonear",
    "resmoneariam": "resmonear",
    "resmonearias": "resmonear",
    "resmonearmo": "resmonear",
    "resmonearmos": "resmonear",
    "resmoneará": "resmonear",
    "resmonearás": "resmonear",
    "resmonearão": "resmonear",
    "resmonearíamos": "resmonear",
    "resmonearíeis": "resmonear",
    "resmoneasse": "resmonear",
    "resmoneassem": "resmonear",
    "resmoneasses": "resmonear",
    "resmoneaste": "resmonear",
    "resmoneastes": "resmonear",
    "resmoneava": "resmonear",
    "resmoneavam": "resmonear",
    "resmoneavas": "resmonear",
    "resmoneei": "resmonear",
    "resmoneeis": "resmonear",
    "resmoneemo": "resmonear",
    "resmoneemos": "resmonear",
    "resmoneia": "resmonear",
    "resmoneiam": "resmonear",
    "resmoneias": "resmonear",
    "resmoneie": "resmonear",
    "resmoneiem": "resmonear",
    "resmoneies": "resmonear",
    "resmoneio": "resmonear",
    "resmoneios": "resmoneio",
    "resmoneou": "resmonear",
    "resmoneámo": "resmonear",
    "resmoneámos": "resmonear",
    "resmoneáramo": "resmonear",
    "resmoneáramos": "resmonear",
    "resmoneáreis": "resmonear",
    "resmoneásseis": "resmonear",
    "resmoneássemos": "resmonear",
    "resmoneávamo": "resmonear",
    "resmoneávamos": "resmonear",
    "resmoneáveis": "resmonear",
    "resmonos": "resmono",
    "resmudas": "resmuda",
    "resmunga": "resmungar",
    "resmungada": "resmungar",
    "resmungadas": "resmungar",
    "resmungado": "resmungar",
    "resmungados": "resmungar",
    "resmungai": "resmungar",
    "resmungais": "resmungar",
    "resmungam": "resmungar",
    "resmungamo": "resmungar",
    "resmungamos": "resmungar",
    "resmungando": "resmungar",
    "resmungara": "resmungar",
    "resmungaram": "resmungar",
    "resmungaras": "resmungar",
    "resmungardes": "resmungar",
    "resmungarei": "resmungar",
    "resmungareis": "resmungar",
    "resmungarem": "resmungar",
    "resmungaremos": "resmungar",
    "resmungares": "resmungar",
    "resmungaria": "resmungar",
    "resmungariam": "resmungar",
    "resmungarias": "resmungar",
    "resmungarmo": "resmungar",
    "resmungarmos": "resmungar",
    "resmungará": "resmungar",
    "resmungarás": "resmungar",
    "resmungarão": "resmungar",
    "resmungaríamos": "resmungar",
    "resmungaríeis": "resmungar",
    "resmungas": "resmungar",
    "resmungasse": "resmungar",
    "resmungassem": "resmungar",
    "resmungasses": "resmungar",
    "resmungaste": "resmungar",
    "resmungastes": "resmungar",
    "resmungava": "resmungar",
    "resmungavam": "resmungar",
    "resmungavas": "resmungar",
    "resmungo": "resmungar",
    "resmungona": "resmungão",
    "resmungonas": "resmungão",
    "resmungonazinha": "resmungão",
    "resmungonazinhas": "resmungão",
    "resmungonazita": "resmungão",
    "resmungonazitas": "resmungão",
    "resmungos": "resmungo",
    "resmungou": "resmungar",
    "resmungue": "resmungar",
    "resmunguei": "resmungar",
    "resmungueis": "resmungar",
    "resmunguem": "resmungar",
    "resmunguemo": "resmungar",
    "resmunguemos": "resmungar",
    "resmunguenta": "resmunguento",
    "resmunguentas": "resmunguento",
    "resmunguentos": "resmunguento",
    "resmungues": "resmungar",
    "resmunguices": "resmunguice",
    "resmungámo": "resmungar",
    "resmungámos": "resmungar",
    "resmungáramo": "resmungar",
    "resmungáramos": "resmungar",
    "resmungáreis": "resmungar",
    "resmungásseis": "resmungar",
    "resmungássemos": "resmungar",
    "resmungávamo": "resmungar",
    "resmungávamos": "resmungar",
    "resmungáveis": "resmungar",
    "resmungãozinho": "resmungão",
    "resmungãozito": "resmungão",
    "resmungões": "resmungão",
    "resmungõezinhos": "resmungão",
    "resmungõezitos": "resmungão",
    "resolubilidades": "resolubilidade",
    "resoluta": "resoluto",
    "resolutas": "resoluto",
    "resolutiva": "resolutivo",
    "resolutivas": "resolutivo",
    "resolutivos": "resolutivo",
    "resolutos": "resoluto",
    "resolutíssima": "resoluto",
    "resolutíssimas": "resoluto",
    "resolutíssimo": "resoluto",
    "resolutíssimos": "resoluto",
    "resolutória": "resolutório",
    "resolutórias": "resolutório",
    "resolutórios": "resolutório",
    "resoluções": "resolução",
    "resolva": "resolver",
    "resolvais": "resolver",
    "resolvam": "resolver",
    "resolvamo": "resolver",
    "resolvamos": "resolver",
    "resolvas": "resolver",
    "resolve": "resolver",
    "resolvei": "resolver",
    "resolveis": "resolver",
    "resolvem": "resolver",
    "resolvemo": "resolver",
    "resolvemos": "resolver",
    "resolvendo": "resolver",
    "resolventes": "resolvente",
    "resolvera": "resolver",
    "resolveram": "resolver",
    "resolveras": "resolver",
    "resolverde": "resolver",
    "resolverdes": "resolver",
    "resolvere": "resolver",
    "resolverei": "resolver",
    "resolvereis": "resolver",
    "resolverem": "resolver",
    "resolveremos": "resolver",
    "resolveres": "resolver",
    "resolveria": "resolver",
    "resolveriam": "resolver",
    "resolverias": "resolver",
    "resolvermo": "resolver",
    "resolvermos": "resolver",
    "resolverá": "resolver",
    "resolverás": "resolver",
    "resolverão": "resolver",
    "resolveríamos": "resolver",
    "resolveríeis": "resolver",
    "resolves": "resolver",
    "resolvesse": "resolver",
    "resolvessem": "resolver",
    "resolvesses": "resolver",
    "resolveste": "resolver",
    "resolvestes": "resolver",
    "resolveu": "resolver",
    "resolvi": "resolver",
    "resolvia": "resolver",
    "resolviam": "resolver",
    "resolvias": "resolver",
    "resolvida": "resolvido",
    "resolvidas": "resolvido",
    "resolvido": "resolver",
    "resolvidos": "resolvido",
    "resolvidíssima": "resolvido",
    "resolvidíssimas": "resolvido",
    "resolvidíssimo": "resolvido",
    "resolvidíssimos": "resolvido",
    "resolvo": "resolver",
    "resolvê": "resolver",
    "resolvêramo": "resolver",
    "resolvêramos": "resolver",
    "resolvêrei": "resolver",
    "resolvêreis": "resolver",
    "resolvêsseis": "resolver",
    "resolvêssemos": "resolver",
    "resolvíamo": "resolver",
    "resolvíamos": "resolver",
    "resolvíei": "resolver",
    "resolvíeis": "resolver",
    "resolvíveis": "resolvível",
    "resolíveis": "resolível",
    "resolúveis": "resolúvel",
    "resorcinas": "resorcina",
    "respalda": "respaldar",
    "respaldada": "respaldar",
    "respaldadas": "respaldar",
    "respaldado": "respaldar",
    "respaldados": "respaldar",
    "respaldai": "respaldar",
    "respaldais": "respaldar",
    "respaldam": "respaldar",
    "respaldamo": "respaldar",
    "respaldamos": "respaldar",
    "respaldando": "respaldar",
    "respaldara": "respaldar",
    "respaldaram": "respaldar",
    "respaldaras": "respaldar",
    "respaldarde": "respaldar",
    "respaldardes": "respaldar",
    "respaldare": "respaldar",
    "respaldarei": "respaldar",
    "respaldareis": "respaldar",
    "respaldarem": "respaldar",
    "respaldaremos": "respaldar",
    "respaldares": "respaldar",
    "respaldaria": "respaldar",
    "respaldariam": "respaldar",
    "respaldarias": "respaldar",
    "respaldarmo": "respaldar",
    "respaldarmos": "respaldar",
    "respaldará": "respaldar",
    "respaldarás": "respaldar",
    "respaldarão": "respaldar",
    "respaldaríamos": "respaldar",
    "respaldaríeis": "respaldar",
    "respaldas": "respaldar",
    "respaldasse": "respaldar",
    "respaldassem": "respaldar",
    "respaldasses": "respaldar",
    "respaldaste": "respaldar",
    "respaldastes": "respaldar",
    "respaldava": "respaldar",
    "respaldavam": "respaldar",
    "respaldavas": "respaldar",
    "respalde": "respaldar",
    "respaldei": "respaldar",
    "respaldeis": "respaldar",
    "respaldem": "respaldar",
    "respaldemo": "respaldar",
    "respaldemos": "respaldar",
    "respaldes": "respaldar",
    "respaldo": "respaldar",
    "respaldos": "respaldo",
    "respaldou": "respaldar",
    "respaldá": "respaldar",
    "respaldámo": "respaldar",
    "respaldámos": "respaldar",
    "respaldáramo": "respaldar",
    "respaldáramos": "respaldar",
    "respaldárei": "respaldar",
    "respaldáreis": "respaldar",
    "respaldásseis": "respaldar",
    "respaldássemos": "respaldar",
    "respaldávamo": "respaldar",
    "respaldávamos": "respaldar",
    "respaldávei": "respaldar",
    "respaldáveis": "respaldar",
    "respance": "respançar",
    "respancei": "respançar",
    "respanceis": "respançar",
    "respancem": "respançar",
    "respancemo": "respançar",
    "respancemos": "respançar",
    "respances": "respançar",
    "respança": "respançar",
    "respançada": "respançar",
    "respançadas": "respançar",
    "respançado": "respançar",
    "respançados": "respançar",
    "respançaduras": "respançadura",
    "respançai": "respançar",
    "respançais": "respançar",
    "respançam": "respançar",
    "respançamentos": "respançamento",
    "respançamo": "respançar",
    "respançamos": "respançar",
    "respançando": "respançar",
    "respançara": "respançar",
    "respançaram": "respançar",
    "respançaras": "respançar",
    "respançarde": "respançar",
    "respançardes": "respançar",
    "respançare": "respançar",
    "respançarei": "respançar",
    "respançareis": "respançar",
    "respançarem": "respançar",
    "respançaremos": "respançar",
    "respançares": "respançar",
    "respançaria": "respançar",
    "respançariam": "respançar",
    "respançarias": "respançar",
    "respançarmo": "respançar",
    "respançarmos": "respançar",
    "respançará": "respançar",
    "respançarás": "respançar",
    "respançarão": "respançar",
    "respançaríamos": "respançar",
    "respançaríeis": "respançar",
    "respanças": "respançar",
    "respançasse": "respançar",
    "respançassem": "respançar",
    "respançasses": "respançar",
    "respançaste": "respançar",
    "respançastes": "respançar",
    "respançava": "respançar",
    "respançavam": "respançar",
    "respançavas": "respançar",
    "respanço": "respançar",
    "respançou": "respançar",
    "respançá": "respançar",
    "respançámo": "respançar",
    "respançámos": "respançar",
    "respançáramo": "respançar",
    "respançáramos": "respançar",
    "respançárei": "respançar",
    "respançáreis": "respançar",
    "respançásseis": "respançar",
    "respançássemos": "respançar",
    "respançávamo": "respançar",
    "respançávamos": "respançar",
    "respançávei": "respançar",
    "respançáveis": "respançar",
    "respectiva": "respectivo",
    "respectivas": "respectivo",
    "respectivos": "respectivo",
    "respeita": "respeitar",
    "respeitabilidades": "respeitabilidade",
    "respeitabilíssima": "respeitável",
    "respeitabilíssimas": "respeitável",
    "respeitabilíssimo": "respeitável",
    "respeitabilíssimos": "respeitável",
    "respeitada": "respeitar",
    "respeitadas": "respeitar",
    "respeitadazinha": "respeitado",
    "respeitadazinhas": "respeitado",
    "respeitadazita": "respeitado",
    "respeitadazitas": "respeitado",
    "respeitadinha": "respeitado",
    "respeitadinhas": "respeitado",
    "respeitadinho": "respeitado",
    "respeitadinhos": "respeitado",
    "respeitadita": "respeitado",
    "respeitaditas": "respeitado",
    "respeitadito": "respeitado",
    "respeitaditos": "respeitado",
    "respeitado": "respeitar",
    "respeitadora": "respeitador",
    "respeitadoras": "respeitador",
    "respeitadores": "respeitador",
    "respeitados": "respeitar",
    "respeitadozinho": "respeitado",
    "respeitadozinhos": "respeitado",
    "respeitadozito": "respeitado",
    "respeitadozitos": "respeitado",
    "respeitadíssima": "respeitado",
    "respeitadíssimas": "respeitado",
    "respeitadíssimo": "respeitado",
    "respeitadíssimos": "respeitado",
    "respeitai": "respeitar",
    "respeitais": "respeitar",
    "respeitam": "respeitar",
    "respeitamo": "respeitar",
    "respeitamos": "respeitar",
    "respeitando": "respeitar",
    "respeitantes": "respeitante",
    "respeitara": "respeitar",
    "respeitaram": "respeitar",
    "respeitaras": "respeitar",
    "respeitarde": "respeitar",
    "respeitardes": "respeitar",
    "respeitare": "respeitar",
    "respeitarei": "respeitar",
    "respeitareis": "respeitar",
    "respeitarem": "respeitar",
    "respeitaremos": "respeitar",
    "respeitares": "respeitar",
    "respeitaria": "respeitar",
    "respeitariam": "respeitar",
    "respeitarias": "respeitar",
    "respeitarmo": "respeitar",
    "respeitarmos": "respeitar",
    "respeitará": "respeitar",
    "respeitarás": "respeitar",
    "respeitarão": "respeitar",
    "respeitaríamos": "respeitar",
    "respeitaríeis": "respeitar",
    "respeitas": "respeitar",
    "respeitasse": "respeitar",
    "respeitassem": "respeitar",
    "respeitasses": "respeitar",
    "respeitaste": "respeitar",
    "respeitastes": "respeitar",
    "respeitava": "respeitar",
    "respeitavam": "respeitar",
    "respeitavas": "respeitar",
    "respeitaveizinhas": "respeitável",
    "respeitaveizinhos": "respeitável",
    "respeitaveizitas": "respeitável",
    "respeitaveizitos": "respeitável",
    "respeitavelzinha": "respeitável",
    "respeitavelzinho": "respeitável",
    "respeitavelzita": "respeitável",
    "respeitavelzito": "respeitável",
    "respeite": "respeitar",
    "respeitei": "respeitar",
    "respeiteis": "respeitar",
    "respeitem": "respeitar",
    "respeitemo": "respeitar",
    "respeitemos": "respeitar",
    "respeites": "respeitar",
    "respeitinho": "respeito",
    "respeitinhos": "respeito",
    "respeitito": "respeito",
    "respeititos": "respeito",
    "respeito": "respeitar",
    "respeitos": "respeito",
    "respeitosa": "respeitoso",
    "respeitosas": "respeitoso",
    "respeitosos": "respeitoso",
    "respeitou": "respeitar",
    "respeitá": "respeitar",
    "respeitámo": "respeitar",
    "respeitámos": "respeitar",
    "respeitáramo": "respeitar",
    "respeitáramos": "respeitar",
    "respeitárei": "respeitar",
    "respeitáreis": "respeitar",
    "respeitásseis": "respeitar",
    "respeitássemos": "respeitar",
    "respeitávamo": "respeitar",
    "respeitávamos": "respeitar",
    "respeitávei": "respeitar",
    "respeitáveis": "respeitável",
    "respes": "respe",
    "respiga": "respigar",
    "respigada": "respigar",
    "respigadas": "respigar",
    "respigadeira": "respigador",
    "respigadeiras": "respigador",
    "respigado": "respigar",
    "respigadoiras": "respigadoira",
    "respigadora": "respigador",
    "respigadoras": "respigador",
    "respigadores": "respigador",
    "respigados": "respigar",
    "respigadouras": "respigadoura",
    "respigai": "respigar",
    "respigais": "respigar",
    "respigam": "respigar",
    "respigamo": "respigar",
    "respigamos": "respigar",
    "respigando": "respigar",
    "respigara": "respigar",
    "respigaram": "respigar",
    "respigaras": "respigar",
    "respigarde": "respigar",
    "respigardes": "respigar",
    "respigare": "respigar",
    "respigarei": "respigar",
    "respigareis": "respigar",
    "respigarem": "respigar",
    "respigaremos": "respigar",
    "respigares": "respigar",
    "respigaria": "respigar",
    "respigariam": "respigar",
    "respigarias": "respigar",
    "respigarmo": "respigar",
    "respigarmos": "respigar",
    "respigará": "respigar",
    "respigarás": "respigar",
    "respigarão": "respigar",
    "respigaríamos": "respigar",
    "respigaríeis": "respigar",
    "respigas": "respigar",
    "respigasse": "respigar",
    "respigassem": "respigar",
    "respigasses": "respigar",
    "respigaste": "respigar",
    "respigastes": "respigar",
    "respigava": "respigar",
    "respigavam": "respigar",
    "respigavas": "respigar",
    "respigazinha": "respiga",
    "respigazinhas": "respiga",
    "respigazita": "respiga",
    "respigazitas": "respiga",
    "respigo": "respigar",
    "respigona": "respigão",
    "respigonas": "respigão",
    "respigos": "respigo",
    "respigou": "respigar",
    "respigue": "respigar",
    "respiguei": "respigar",
    "respigueis": "respigar",
    "respiguem": "respigar",
    "respiguemo": "respigar",
    "respiguemos": "respigar",
    "respigues": "respigar",
    "respigá": "respigar",
    "respigámo": "respigar",
    "respigámos": "respigar",
    "respigáramo": "respigar",
    "respigáramos": "respigar",
    "respigárei": "respigar",
    "respigáreis": "respigar",
    "respigásseis": "respigar",
    "respigássemos": "respigar",
    "respigávamo": "respigar",
    "respigávamos": "respigar",
    "respigávei": "respigar",
    "respigáveis": "respigar",
    "respigões": "respigão",
    "respinga": "respingar",
    "respingada": "respingar",
    "respingadas": "respingar",
    "respingado": "respingar",
    "respingadora": "respingador",
    "respingadoras": "respingador",
    "respingadores": "respingador",
    "respingados": "respingar",
    "respingai": "respingar",
    "respingais": "respingar",
    "respingam": "respingar",
    "respingamo": "respingar",
    "respingamos": "respingar",
    "respingando": "respingar",
    "respingara": "respingar",
    "respingaram": "respingar",
    "respingaras": "respingar",
    "respingardes": "respingar",
    "respingarei": "respingar",
    "respingareis": "respingar",
    "respingarem": "respingar",
    "respingaremos": "respingar",
    "respingares": "respingar",
    "respingaria": "respingar",
    "respingariam": "respingar",
    "respingarias": "respingar",
    "respingarmo": "respingar",
    "respingarmos": "respingar",
    "respingará": "respingar",
    "respingarás": "respingar",
    "respingarão": "respingar",
    "respingaríamos": "respingar",
    "respingaríeis": "respingar",
    "respingas": "respingar",
    "respingasse": "respingar",
    "respingassem": "respingar",
    "respingasses": "respingar",
    "respingaste": "respingar",
    "respingastes": "respingar",
    "respingava": "respingar",
    "respingavam": "respingar",
    "respingavas": "respingar",
    "respingo": "respingar",
    "respingona": "respingão",
    "respingonas": "respingão",
    "respingonazinha": "respingão",
    "respingonazinhas": "respingão",
    "respingonazita": "respingão",
    "respingonazitas": "respingão",
    "respingos": "respingo",
    "respingou": "respingar",
    "respingue": "respingar",
    "respinguei": "respingar",
    "respingueis": "respingar",
    "respinguem": "respingar",
    "respinguemo": "respingar",
    "respinguemos": "respingar",
    "respingues": "respingar",
    "respingámo": "respingar",
    "respingámos": "respingar",
    "respingáramo": "respingar",
    "respingáramos": "respingar",
    "respingáreis": "respingar",
    "respingásseis": "respingar",
    "respingássemos": "respingar",
    "respingávamo": "respingar",
    "respingávamos": "respingar",
    "respingáveis": "respingar",
    "respingãozinho": "respingão",
    "respingãozito": "respingão",
    "respingões": "respingão",
    "respingõezinhos": "respingão",
    "respingõezitos": "respingão",
    "respira": "respirar",
    "respirabilidades": "respirabilidade",
    "respirada": "respirar",
    "respiradas": "respirar",
    "respirado": "respirar",
    "respiradoiros": "respiradoiro",
    "respiradora": "respirador",
    "respiradoras": "respirador",
    "respiradores": "respirador",
    "respirados": "respirar",
    "respiradouros": "respiradouro",
    "respirai": "respirar",
    "respirais": "respirar",
    "respiram": "respirar",
    "respiramentos": "respiramento",
    "respiramo": "respirar",
    "respiramos": "respirar",
    "respirando": "respirar",
    "respirara": "respirar",
    "respiraram": "respirar",
    "respiraras": "respirar",
    "respirarde": "respirar",
    "respirardes": "respirar",
    "respirare": "respirar",
    "respirarei": "respirar",
    "respirareis": "respirar",
    "respirarem": "respirar",
    "respiraremos": "respirar",
    "respirares": "respirar",
    "respiraria": "respirar",
    "respirariam": "respirar",
    "respirarias": "respirar",
    "respirarmo": "respirar",
    "respirarmos": "respirar",
    "respirará": "respirar",
    "respirarás": "respirar",
    "respirarão": "respirar",
    "respiraríamos": "respirar",
    "respiraríeis": "respirar",
    "respiras": "respirar",
    "respirasse": "respirar",
    "respirassem": "respirar",
    "respirasses": "respirar",
    "respiraste": "respirar",
    "respirastes": "respirar",
    "respiratória": "respiratório",
    "respiratórias": "respiratório",
    "respiratórios": "respiratório",
    "respirava": "respirar",
    "respiravam": "respirar",
    "respiravas": "respirar",
    "respirações": "respiração",
    "respire": "respirar",
    "respirei": "respirar",
    "respireis": "respirar",
    "respirem": "respirar",
    "respiremo": "respirar",
    "respiremos": "respirar",
    "respires": "respirar",
    "respiro": "respirar",
    "respiros": "respiro",
    "respirou": "respirar",
    "respirá": "respirar",
    "respiráculos": "respiráculo",
    "respirámo": "respirar",
    "respirámos": "respirar",
    "respiráramo": "respirar",
    "respiráramos": "respirar",
    "respirárei": "respirar",
    "respiráreis": "respirar",
    "respirásseis": "respirar",
    "respirássemos": "respirar",
    "respirávamo": "respirar",
    "respirávamos": "respirar",
    "respirávei": "respirar",
    "respiráveis": "respirável",
    "respitadores": "respitador",
    "resplandece": "resplandecer",
    "resplandecei": "resplandecer",
    "resplandeceis": "resplandecer",
    "resplandecem": "resplandecer",
    "resplandecemo": "resplandecer",
    "resplandecemos": "resplandecer",
    "resplandecendo": "resplandecer",
    "resplandecentes": "resplandecente",
    "resplandecentíssima": "resplandecente",
    "resplandecentíssimas": "resplandecente",
    "resplandecentíssimo": "resplandecente",
    "resplandecentíssimos": "resplandecente",
    "resplandecera": "resplandecer",
    "resplandeceram": "resplandecer",
    "resplandeceras": "resplandecer",
    "resplandecerdes": "resplandecer",
    "resplandecerei": "resplandecer",
    "resplandecereis": "resplandecer",
    "resplandecerem": "resplandecer",
    "resplandeceremos": "resplandecer",
    "resplandeceres": "resplandecer",
    "resplandeceria": "resplandecer",
    "resplandeceriam": "resplandecer",
    "resplandecerias": "resplandecer",
    "resplandecermo": "resplandecer",
    "resplandecermos": "resplandecer",
    "resplandecerá": "resplandecer",
    "resplandecerás": "resplandecer",
    "resplandecerão": "resplandecer",
    "resplandeceríamos": "resplandecer",
    "resplandeceríeis": "resplandecer",
    "resplandeces": "resplandecer",
    "resplandecesse": "resplandecer",
    "resplandecessem": "resplandecer",
    "resplandecesses": "resplandecer",
    "resplandeceste": "resplandecer",
    "resplandecestes": "resplandecer",
    "resplandeceu": "resplandecer",
    "resplandeci": "resplandecer",
    "resplandecia": "resplandecer",
    "resplandeciam": "resplandecer",
    "resplandecias": "resplandecer",
    "resplandecida": "resplandecer",
    "resplandecidas": "resplandecer",
    "resplandecido": "resplandecer",
    "resplandecidos": "resplandecer",
    "resplandecências": "resplandecência",
    "resplandecêramo": "resplandecer",
    "resplandecêramos": "resplandecer",
    "resplandecêreis": "resplandecer",
    "resplandecêsseis": "resplandecer",
    "resplandecêssemos": "resplandecer",
    "resplandecíamo": "resplandecer",
    "resplandecíamos": "resplandecer",
    "resplandecíeis": "resplandecer",
    "resplandeça": "resplandecer",
    "resplandeçais": "resplandecer",
    "resplandeçam": "resplandecer",
    "resplandeçamo": "resplandecer",
    "resplandeçamos": "resplandecer",
    "resplandeças": "resplandecer",
    "resplandeço": "resplandecer",
    "resplandores": "resplandor",
    "resplenda": "resplender",
    "resplendais": "resplender",
    "resplendam": "resplender",
    "resplendamo": "resplender",
    "resplendamos": "resplender",
    "resplendas": "resplender",
    "resplende": "resplender",
    "resplendece": "resplendecer",
    "resplendecei": "resplendecer",
    "resplendeceis": "resplendecer",
    "resplendecem": "resplendecer",
    "resplendecemo": "resplendecer",
    "resplendecemos": "resplendecer",
    "resplendecendo": "resplendecer",
    "resplendecera": "resplendecer",
    "resplendeceram": "resplendecer",
    "resplendeceras": "resplendecer",
    "resplendecerdes": "resplendecer",
    "resplendecerei": "resplendecer",
    "resplendecereis": "resplendecer",
    "resplendecerem": "resplendecer",
    "resplendeceremos": "resplendecer",
    "resplendeceres": "resplendecer",
    "resplendeceria": "resplendecer",
    "resplendeceriam": "resplendecer",
    "resplendecerias": "resplendecer",
    "resplendecermo": "resplendecer",
    "resplendecermos": "resplendecer",
    "resplendecerá": "resplendecer",
    "resplendecerás": "resplendecer",
    "resplendecerão": "resplendecer",
    "resplendeceríamos": "resplendecer",
    "resplendeceríeis": "resplendecer",
    "resplendeces": "resplendecer",
    "resplendecesse": "resplendecer",
    "resplendecessem": "resplendecer",
    "resplendecesses": "resplendecer",
    "resplendeceste": "resplendecer",
    "resplendecestes": "resplendecer",
    "resplendeceu": "resplendecer",
    "resplendeci": "resplendecer",
    "resplendecia": "resplendecer",
    "resplendeciam": "resplendecer",
    "resplendecias": "resplendecer",
    "resplendecida": "resplendecer",
    "resplendecidas": "resplendecer",
    "resplendecido": "resplendecer",
    "resplendecidos": "resplendecer",
    "resplendecêramo": "resplendecer",
    "resplendecêramos": "resplendecer",
    "resplendecêreis": "resplendecer",
    "resplendecêsseis": "resplendecer",
    "resplendecêssemos": "resplendecer",
    "resplendecíamo": "resplendecer",
    "resplendecíamos": "resplendecer",
    "resplendecíeis": "resplendecer",
    "resplendei": "resplender",
    "resplendeis": "resplender",
    "resplendem": "resplender",
    "resplendemo": "resplender",
    "resplendemos": "resplender",
    "resplendendo": "resplender",
    "resplendentes": "resplendente",
    "resplendentíssima": "resplendente",
    "resplendentíssimas": "resplendente",
    "resplendentíssimo": "resplendente",
    "resplendentíssimos": "resplendente",
    "resplendera": "resplender",
    "resplenderam": "resplender",
    "resplenderas": "resplender",
    "resplenderdes": "resplender",
    "resplenderei": "resplender",
    "resplendereis": "resplender",
    "resplenderem": "resplender",
    "resplenderemos": "resplender",
    "resplenderes": "resplender",
    "resplenderia": "resplender",
    "resplenderiam": "resplender",
    "resplenderias": "resplender",
    "resplendermo": "resplender",
    "resplendermos": "resplender",
    "resplenderá": "resplender",
    "resplenderás": "resplender",
    "resplenderão": "resplender",
    "resplenderíamos": "resplender",
    "resplenderíeis": "resplender",
    "resplendes": "resplender",
    "resplendesse": "resplender",
    "resplendessem": "resplender",
    "resplendesses": "resplender",
    "resplendeste": "resplender",
    "resplendestes": "resplender",
    "resplendeu": "resplender",
    "resplendeça": "resplendecer",
    "resplendeçais": "resplendecer",
    "resplendeçam": "resplendecer",
    "resplendeçamo": "resplendecer",
    "resplendeçamos": "resplendecer",
    "resplendeças": "resplendecer",
    "resplendeço": "resplendecer",
    "resplendi": "resplender",
    "resplendia": "resplender",
    "resplendiam": "resplender",
    "resplendias": "resplender",
    "resplendida": "resplender",
    "resplendidas": "resplender",
    "resplendido": "resplender",
    "resplendidos": "resplender",
    "resplendidíssima": "resplêndido",
    "resplendidíssimas": "resplêndido",
    "resplendidíssimo": "resplêndido",
    "resplendidíssimos": "resplêndido",
    "resplendo": "resplender",
    "resplendores": "resplendor",
    "resplendorosa": "resplendoroso",
    "resplendorosas": "resplendoroso",
    "resplendorosos": "resplendoroso",
    "resplendorosíssima": "resplendoroso",
    "resplendorosíssimas": "resplendoroso",
    "resplendorosíssimo": "resplendoroso",
    "resplendorosíssimos": "resplendoroso",
    "resplendências": "resplendência",
    "resplendêramo": "resplender",
    "resplendêramos": "resplender",
    "resplendêreis": "resplender",
    "resplendêsseis": "resplender",
    "resplendêssemos": "resplender",
    "resplendíamo": "resplender",
    "resplendíamos": "resplender",
    "resplendíeis": "resplender",
    "resplêndida": "resplêndido",
    "resplêndidas": "resplêndido",
    "resplêndidos": "resplêndido",
    "responda": "responder",
    "respondais": "responder",
    "respondam": "responder",
    "respondamo": "responder",
    "respondamos": "responder",
    "respondas": "responder",
    "responde": "responder",
    "respondedora": "respondedor",
    "respondedoras": "respondedor",
    "respondedorazinha": "respondedor",
    "respondedorazinhas": "respondedor",
    "respondedorazita": "respondedor",
    "respondedorazitas": "respondedor",
    "respondedores": "respondedor",
    "respondedorzinho": "respondedor",
    "respondedorzinhos": "respondedor",
    "respondedorzito": "respondedor",
    "respondedorzitos": "respondedor",
    "respondei": "responder",
    "respondeis": "responder",
    "respondem": "responder",
    "respondemo": "responder",
    "respondemos": "responder",
    "respondendo": "responder",
    "respondentes": "respondente",
    "respondera": "responder",
    "responderam": "responder",
    "responderas": "responder",
    "responderde": "responder",
    "responderdes": "responder",
    "respondere": "responder",
    "responderei": "responder",
    "respondereis": "responder",
    "responderem": "responder",
    "responderemos": "responder",
    "responderes": "responder",
    "responderia": "responder",
    "responderiam": "responder",
    "responderias": "responder",
    "respondermo": "responder",
    "respondermos": "responder",
    "responderá": "responder",
    "responderás": "responder",
    "responderão": "responder",
    "responderíamos": "responder",
    "responderíeis": "responder",
    "respondes": "responder",
    "respondesse": "responder",
    "respondessem": "responder",
    "respondesses": "responder",
    "respondeste": "responder",
    "respondestes": "responder",
    "respondeu": "responder",
    "respondi": "responder",
    "respondia": "responder",
    "respondiam": "responder",
    "respondias": "responder",
    "respondida": "respondido",
    "respondidas": "respondido",
    "respondido": "responder",
    "respondidos": "respondido",
    "respondo": "responder",
    "respondona": "respondão",
    "respondonas": "respondão",
    "respondonazinha": "respondão",
    "respondonazinhas": "respondão",
    "respondonazita": "respondão",
    "respondonazitas": "respondão",
    "respondãozinho": "respondão",
    "respondãozito": "respondão",
    "respondê": "responder",
    "respondências": "respondência",
    "respondêramo": "responder",
    "respondêramos": "responder",
    "respondêrei": "responder",
    "respondêreis": "responder",
    "respondêsseis": "responder",
    "respondêssemos": "responder",
    "respondíamo": "responder",
    "respondíamos": "responder",
    "respondíei": "responder",
    "respondíeis": "responder",
    "respondíveis": "respondível",
    "respondões": "respondão",
    "respondõezinhos": "respondão",
    "respondõezitos": "respondão",
    "responsa": "responso",
    "responsabilidades": "responsabilidade",
    "responsabiliza": "responsabilizar",
    "responsabilizada": "responsabilizar",
    "responsabilizadas": "responsabilizar",
    "responsabilizado": "responsabilizar",
    "responsabilizadora": "responsabilizador",
    "responsabilizadoras": "responsabilizador",
    "responsabilizadores": "responsabilizador",
    "responsabilizados": "responsabilizar",
    "responsabilizai": "responsabilizar",
    "responsabilizais": "responsabilizar",
    "responsabilizam": "responsabilizar",
    "responsabilizamo": "responsabilizar",
    "responsabilizamos": "responsabilizar",
    "responsabilizando": "responsabilizar",
    "responsabilizara": "responsabilizar",
    "responsabilizaram": "responsabilizar",
    "responsabilizaras": "responsabilizar",
    "responsabilizarde": "responsabilizar",
    "responsabilizardes": "responsabilizar",
    "responsabilizare": "responsabilizar",
    "responsabilizarei": "responsabilizar",
    "responsabilizareis": "responsabilizar",
    "responsabilizarem": "responsabilizar",
    "responsabilizaremos": "responsabilizar",
    "responsabilizares": "responsabilizar",
    "responsabilizaria": "responsabilizar",
    "responsabilizariam": "responsabilizar",
    "responsabilizarias": "responsabilizar",
    "responsabilizarmo": "responsabilizar",
    "responsabilizarmos": "responsabilizar",
    "responsabilizará": "responsabilizar",
    "responsabilizarás": "responsabilizar",
    "responsabilizarão": "responsabilizar",
    "responsabilizaríamos": "responsabilizar",
    "responsabilizaríeis": "responsabilizar",
    "responsabilizas": "responsabilizar",
    "responsabilizasse": "responsabilizar",
    "responsabilizassem": "responsabilizar",
    "responsabilizasses": "responsabilizar",
    "responsabilizaste": "responsabilizar",
    "responsabilizastes": "responsabilizar",
    "responsabilizava": "responsabilizar",
    "responsabilizavam": "responsabilizar",
    "responsabilizavas": "responsabilizar",
    "responsabilizações": "responsabilização",
    "responsabilize": "responsabilizar",
    "responsabilizei": "responsabilizar",
    "responsabilizeis": "responsabilizar",
    "responsabilizem": "responsabilizar",
    "responsabilizemo": "responsabilizar",
    "responsabilizemos": "responsabilizar",
    "responsabilizes": "responsabilizar",
    "responsabilizo": "responsabilizar",
    "responsabilizou": "responsabilizar",
    "responsabilizá": "responsabilizar",
    "responsabilizámo": "responsabilizar",
    "responsabilizámos": "responsabilizar",
    "responsabilizáramo": "responsabilizar",
    "responsabilizáramos": "responsabilizar",
    "responsabilizárei": "responsabilizar",
    "responsabilizáreis": "responsabilizar",
    "responsabilizásseis": "responsabilizar",
    "responsabilizássemos": "responsabilizar",
    "responsabilizávamo": "responsabilizar",
    "responsabilizávamos": "responsabilizar",
    "responsabilizávei": "responsabilizar",
    "responsabilizáveis": "responsabilizável",
    "responsada": "responsar",
    "responsadas": "responsar",
    "responsado": "responsar",
    "responsados": "responsar",
    "responsai": "responsar",
    "responsais": "responsar",
    "responsam": "responsar",
    "responsamo": "responsar",
    "responsamos": "responsar",
    "responsando": "responsar",
    "responsara": "responsar",
    "responsaram": "responsar",
    "responsaras": "responsar",
    "responsarde": "responsar",
    "responsardes": "responsar",
    "responsare": "responsar",
    "responsarei": "responsar",
    "responsareis": "responsar",
    "responsarem": "responsar",
    "responsaremos": "responsar",
    "responsares": "responsar",
    "responsaria": "responsar",
    "responsariam": "responsar",
    "responsarias": "responsar",
    "responsarmo": "responsar",
    "responsarmos": "responsar",
    "responsará": "responsar",
    "responsarás": "responsar",
    "responsarão": "responsar",
    "responsaríamos": "responsar",
    "responsaríeis": "responsar",
    "responsas": "responso",
    "responsasse": "responsar",
    "responsassem": "responsar",
    "responsasses": "responsar",
    "responsaste": "responsar",
    "responsastes": "responsar",
    "responsava": "responsar",
    "responsavam": "responsar",
    "responsavas": "responsar",
    "response": "responsar",
    "responsei": "responsar",
    "responseis": "responsar",
    "responsem": "responsar",
    "responsemo": "responsar",
    "responsemos": "responsar",
    "responses": "responsar",
    "responsiva": "responsivo",
    "responsivas": "responsivo",
    "responsivos": "responsivo",
    "responso": "responsar",
    "responsos": "responso",
    "responsou": "responsar",
    "responsá": "responsar",
    "responsámo": "responsar",
    "responsámos": "responsar",
    "responsáramo": "responsar",
    "responsáramos": "responsar",
    "responsárei": "responsar",
    "responsáreis": "responsar",
    "responsásseis": "responsar",
    "responsássemos": "responsar",
    "responsávamo": "responsar",
    "responsávamos": "responsar",
    "responsávei": "responsar",
    "responsáveis": "responsável",
    "responsórios": "responsório",
    "resposta": "respostar",
    "respostada": "respostar",
    "respostadas": "respostar",
    "respostado": "respostar",
    "respostados": "respostar",
    "respostai": "respostar",
    "respostais": "respostar",
    "respostam": "respostar",
    "respostamo": "respostar",
    "respostamos": "respostar",
    "respostando": "respostar",
    "respostara": "respostar",
    "respostaram": "respostar",
    "respostaras": "respostar",
    "respostardes": "respostar",
    "respostarei": "respostar",
    "respostareis": "respostar",
    "respostarem": "respostar",
    "respostaremos": "respostar",
    "respostares": "respostar",
    "respostaria": "respostar",
    "respostariam": "respostar",
    "respostarias": "respostar",
    "respostarmo": "respostar",
    "respostarmos": "respostar",
    "respostará": "respostar",
    "respostarás": "respostar",
    "respostarão": "respostar",
    "respostaríamos": "respostar",
    "respostaríeis": "respostar",
    "respostas": "respostar",
    "respostasse": "respostar",
    "respostassem": "respostar",
    "respostasses": "respostar",
    "respostaste": "respostar",
    "respostastes": "respostar",
    "respostava": "respostar",
    "respostavam": "respostar",
    "respostavas": "respostar",
    "resposte": "respostar",
    "respostei": "respostar",
    "resposteis": "respostar",
    "respostem": "respostar",
    "respostemo": "respostar",
    "respostemos": "respostar",
    "respostes": "respostar",
    "resposto": "respostar",
    "respostou": "respostar",
    "respostámo": "respostar",
    "respostámos": "respostar",
    "respostáramo": "respostar",
    "respostáramos": "respostar",
    "respostáreis": "respostar",
    "respostásseis": "respostar",
    "respostássemos": "respostar",
    "respostávamo": "respostar",
    "respostávamos": "respostar",
    "respostáveis": "respostar",
    "resquiada": "resquiado",
    "resquiadas": "resquiado",
    "resquiados": "resquiado",
    "resquícios": "resquício",
    "ressabe": "ressaber",
    "ressabei": "ressaber",
    "ressabeis": "ressaber",
    "ressabem": "ressaber",
    "ressabemo": "ressaber",
    "ressabemos": "ressaber",
    "ressabendo": "ressaber",
    "ressaberde": "ressaber",
    "ressaberdes": "ressaber",
    "ressabere": "ressaber",
    "ressaberei": "ressaber",
    "ressabereis": "ressaber",
    "ressaberem": "ressaber",
    "ressaberemos": "ressaber",
    "ressaberes": "ressaber",
    "ressaberia": "ressaber",
    "ressaberiam": "ressaber",
    "ressaberias": "ressaber",
    "ressabermo": "ressaber",
    "ressabermos": "ressaber",
    "ressaberá": "ressaber",
    "ressaberás": "ressaber",
    "ressaberão": "ressaber",
    "ressaberíamos": "ressaber",
    "ressaberíeis": "ressaber",
    "ressabes": "ressaber",
    "ressabia": "ressabiar",
    "ressabiada": "ressabiar",
    "ressabiadas": "ressabiar",
    "ressabiado": "ressabiar",
    "ressabiados": "ressabiar",
    "ressabiai": "ressabiar",
    "ressabiais": "ressabiar",
    "ressabiam": "ressabiar",
    "ressabiamo": "ressabiar",
    "ressabiamos": "ressabiar",
    "ressabiando": "ressabiar",
    "ressabiara": "ressabiar",
    "ressabiaram": "ressabiar",
    "ressabiaras": "ressabiar",
    "ressabiardes": "ressabiar",
    "ressabiarei": "ressabiar",
    "ressabiareis": "ressabiar",
    "ressabiarem": "ressabiar",
    "ressabiaremos": "ressabiar",
    "ressabiares": "ressabiar",
    "ressabiaria": "ressabiar",
    "ressabiariam": "ressabiar",
    "ressabiarias": "ressabiar",
    "ressabiarmo": "ressabiar",
    "ressabiarmos": "ressabiar",
    "ressabiará": "ressabiar",
    "ressabiarás": "ressabiar",
    "ressabiarão": "ressabiar",
    "ressabiaríamos": "ressabiar",
    "ressabiaríeis": "ressabiar",
    "ressabias": "ressabiar",
    "ressabiasse": "ressabiar",
    "ressabiassem": "ressabiar",
    "ressabiasses": "ressabiar",
    "ressabiaste": "ressabiar",
    "ressabiastes": "ressabiar",
    "ressabiava": "ressabiar",
    "ressabiavam": "ressabiar",
    "ressabiavas": "ressabiar",
    "ressabida": "ressabido",
    "ressabidas": "ressabido",
    "ressabido": "ressaber",
    "ressabidos": "ressabido",
    "ressabie": "ressabiar",
    "ressabiei": "ressabiar",
    "ressabieis": "ressabiar",
    "ressabiem": "ressabiar",
    "ressabiemo": "ressabiar",
    "ressabiemos": "ressabiar",
    "ressabies": "ressabiar",
    "ressabio": "ressabiar",
    "ressabiou": "ressabiar",
    "ressabiámo": "ressabiar",
    "ressabiámos": "ressabiar",
    "ressabiáramo": "ressabiar",
    "ressabiáramos": "ressabiar",
    "ressabiáreis": "ressabiar",
    "ressabiásseis": "ressabiar",
    "ressabiássemos": "ressabiar",
    "ressabiávamo": "ressabiar",
    "ressabiávamos": "ressabiar",
    "ressabiáveis": "ressabiar",
    "ressaboreada": "ressaborear",
    "ressaboreadas": "ressaborear",
    "ressaboreado": "ressaborear",
    "ressaboreados": "ressaborear",
    "ressaboreai": "ressaborear",
    "ressaboreais": "ressaborear",
    "ressaboreamo": "ressaborear",
    "ressaboreamos": "ressaborear",
    "ressaboreando": "ressaborear",
    "ressaboreara": "ressaborear",
    "ressaborearam": "ressaborear",
    "ressaborearas": "ressaborear",
    "ressaborearde": "ressaborear",
    "ressaboreardes": "ressaborear",
    "ressaboreare": "ressaborear",
    "ressaborearei": "ressaborear",
    "ressaboreareis": "ressaborear",
    "ressaborearem": "ressaborear",
    "ressaborearemos": "ressaborear",
    "ressaboreares": "ressaborear",
    "ressaborearia": "ressaborear",
    "ressaboreariam": "ressaborear",
    "ressaborearias": "ressaborear",
    "ressaborearmo": "ressaborear",
    "ressaborearmos": "ressaborear",
    "ressaboreará": "ressaborear",
    "ressaborearás": "ressaborear",
    "ressaborearão": "ressaborear",
    "ressaborearíamos": "ressaborear",
    "ressaborearíeis": "ressaborear",
    "ressaboreasse": "ressaborear",
    "ressaboreassem": "ressaborear",
    "ressaboreasses": "ressaborear",
    "ressaboreaste": "ressaborear",
    "ressaboreastes": "ressaborear",
    "ressaboreava": "ressaborear",
    "ressaboreavam": "ressaborear",
    "ressaboreavas": "ressaborear",
    "ressaboreei": "ressaborear",
    "ressaboreeis": "ressaborear",
    "ressaboreemo": "ressaborear",
    "ressaboreemos": "ressaborear",
    "ressaboreia": "ressaborear",
    "ressaboreiam": "ressaborear",
    "ressaboreias": "ressaborear",
    "ressaboreie": "ressaborear",
    "ressaboreiem": "ressaborear",
    "ressaboreies": "ressaborear",
    "ressaboreio": "ressaborear",
    "ressaboreou": "ressaborear",
    "ressaboreá": "ressaborear",
    "ressaboreámo": "ressaborear",
    "ressaboreámos": "ressaborear",
    "ressaboreáramo": "ressaborear",
    "ressaboreáramos": "ressaborear",
    "ressaboreárei": "ressaborear",
    "ressaboreáreis": "ressaborear",
    "ressaboreásseis": "ressaborear",
    "ressaboreássemos": "ressaborear",
    "ressaboreávamo": "ressaborear",
    "ressaboreávamos": "ressaborear",
    "ressaboreávei": "ressaborear",
    "ressaboreáveis": "ressaborear",
    "ressabê": "ressaber",
    "ressabíamo": "ressaber",
    "ressabíamos": "ressaber",
    "ressabíei": "ressaber",
    "ressabíeis": "ressaber",
    "ressaca": "ressacar",
    "ressacabilidades": "ressacabilidade",
    "ressacada": "ressacar",
    "ressacadas": "ressacar",
    "ressacado": "ressacar",
    "ressacados": "ressacar",
    "ressacai": "ressacar",
    "ressacais": "ressacar",
    "ressacam": "ressacar",
    "ressacamo": "ressacar",
    "ressacamos": "ressacar",
    "ressacando": "ressacar",
    "ressacara": "ressacar",
    "ressacaram": "ressacar",
    "ressacaras": "ressacar",
    "ressacarde": "ressacar",
    "ressacardes": "ressacar",
    "ressacare": "ressacar",
    "ressacarei": "ressacar",
    "ressacareis": "ressacar",
    "ressacarem": "ressacar",
    "ressacaremos": "ressacar",
    "ressacares": "ressacar",
    "ressacaria": "ressacar",
    "ressacariam": "ressacar",
    "ressacarias": "ressacar",
    "ressacarmo": "ressacar",
    "ressacarmos": "ressacar",
    "ressacará": "ressacar",
    "ressacarás": "ressacar",
    "ressacarão": "ressacar",
    "ressacaríamos": "ressacar",
    "ressacaríeis": "ressacar",
    "ressacas": "ressacar",
    "ressacasse": "ressacar",
    "ressacassem": "ressacar",
    "ressacasses": "ressacar",
    "ressacaste": "ressacar",
    "ressacastes": "ressacar",
    "ressacava": "ressacar",
    "ressacavam": "ressacar",
    "ressacavas": "ressacar",
    "ressaco": "ressacar",
    "ressacou": "ressacar",
    "ressacá": "ressacar",
    "ressacámo": "ressacar",
    "ressacámos": "ressacar",
    "ressacáramo": "ressacar",
    "ressacáramos": "ressacar",
    "ressacárei": "ressacar",
    "ressacáreis": "ressacar",
    "ressacásseis": "ressacar",
    "ressacássemos": "ressacar",
    "ressacávamo": "ressacar",
    "ressacávamos": "ressacar",
    "ressacávei": "ressacar",
    "ressacáveis": "ressacar",
    "ressaem": "ressair",
    "ressai": "ressair",
    "ressaia": "ressair",
    "ressaiais": "ressair",
    "ressaiam": "ressair",
    "ressaiamo": "ressair",
    "ressaiamos": "ressair",
    "ressaias": "ressair",
    "ressaiba": "ressaber",
    "ressaibais": "ressaber",
    "ressaibam": "ressaber",
    "ressaibamo": "ressaber",
    "ressaibamos": "ressaber",
    "ressaibas": "ressaber",
    "ressaibei": "ressaber",
    "ressaibos": "ressaibo",
    "ressaindo": "ressair",
    "ressaio": "ressair",
    "ressaios": "ressaio",
    "ressairdes": "ressair",
    "ressairei": "ressair",
    "ressaireis": "ressair",
    "ressairemos": "ressair",
    "ressairia": "ressair",
    "ressairiam": "ressair",
    "ressairias": "ressair",
    "ressairmo": "ressair",
    "ressairmos": "ressair",
    "ressairá": "ressair",
    "ressairás": "ressair",
    "ressairão": "ressair",
    "ressairíamos": "ressair",
    "ressairíeis": "ressair",
    "ressais": "ressair",
    "ressaiu": "ressair",
    "ressalga": "ressalgar",
    "ressalgada": "ressalgar",
    "ressalgadas": "ressalgar",
    "ressalgado": "ressalgar",
    "ressalgados": "ressalgar",
    "ressalgai": "ressalgar",
    "ressalgais": "ressalgar",
    "ressalgam": "ressalgar",
    "ressalgamo": "ressalgar",
    "ressalgamos": "ressalgar",
    "ressalgando": "ressalgar",
    "ressalgara": "ressalgar",
    "ressalgaram": "ressalgar",
    "ressalgaras": "ressalgar",
    "ressalgarde": "ressalgar",
    "ressalgardes": "ressalgar",
    "ressalgare": "ressalgar",
    "ressalgarei": "ressalgar",
    "ressalgareis": "ressalgar",
    "ressalgarem": "ressalgar",
    "ressalgaremos": "ressalgar",
    "ressalgares": "ressalgar",
    "ressalgaria": "ressalgar",
    "ressalgariam": "ressalgar",
    "ressalgarias": "ressalgar",
    "ressalgarmo": "ressalgar",
    "ressalgarmos": "ressalgar",
    "ressalgará": "ressalgar",
    "ressalgarás": "ressalgar",
    "ressalgarão": "ressalgar",
    "ressalgaríamos": "ressalgar",
    "ressalgaríeis": "ressalgar",
    "ressalgas": "ressalgar",
    "ressalgasse": "ressalgar",
    "ressalgassem": "ressalgar",
    "ressalgasses": "ressalgar",
    "ressalgaste": "ressalgar",
    "ressalgastes": "ressalgar",
    "ressalgava": "ressalgar",
    "ressalgavam": "ressalgar",
    "ressalgavas": "ressalgar",
    "ressalgo": "ressalgar",
    "ressalgou": "ressalgar",
    "ressalgue": "ressalgar",
    "ressalguei": "ressalgar",
    "ressalgueis": "ressalgar",
    "ressalguem": "ressalgar",
    "ressalguemo": "ressalgar",
    "ressalguemos": "ressalgar",
    "ressalgues": "ressalgar",
    "ressalgá": "ressalgar",
    "ressalgámo": "ressalgar",
    "ressalgámos": "ressalgar",
    "ressalgáramo": "ressalgar",
    "ressalgáramos": "ressalgar",
    "ressalgárei": "ressalgar",
    "ressalgáreis": "ressalgar",
    "ressalgásseis": "ressalgar",
    "ressalgássemos": "ressalgar",
    "ressalgávamo": "ressalgar",
    "ressalgávamos": "ressalgar",
    "ressalgávei": "ressalgar",
    "ressalgáveis": "ressalgar",
    "ressalta": "ressaltar",
    "ressaltada": "ressaltar",
    "ressaltadas": "ressaltar",
    "ressaltado": "ressaltar",
    "ressaltadora": "ressaltador",
    "ressaltadoras": "ressaltador",
    "ressaltadores": "ressaltador",
    "ressaltados": "ressaltar",
    "ressaltai": "ressaltar",
    "ressaltais": "ressaltar",
    "ressaltam": "ressaltar",
    "ressaltamo": "ressaltar",
    "ressaltamos": "ressaltar",
    "ressaltando": "ressaltar",
    "ressaltara": "ressaltar",
    "ressaltaram": "ressaltar",
    "ressaltaras": "ressaltar",
    "ressaltarde": "ressaltar",
    "ressaltardes": "ressaltar",
    "ressaltare": "ressaltar",
    "ressaltarei": "ressaltar",
    "ressaltareis": "ressaltar",
    "ressaltarem": "ressaltar",
    "ressaltaremos": "ressaltar",
    "ressaltares": "ressaltar",
    "ressaltaria": "ressaltar",
    "ressaltariam": "ressaltar",
    "ressaltarias": "ressaltar",
    "ressaltarmo": "ressaltar",
    "ressaltarmos": "ressaltar",
    "ressaltará": "ressaltar",
    "ressaltarás": "ressaltar",
    "ressaltarão": "ressaltar",
    "ressaltaríamos": "ressaltar",
    "ressaltaríeis": "ressaltar",
    "ressaltas": "ressaltar",
    "ressaltasse": "ressaltar",
    "ressaltassem": "ressaltar",
    "ressaltasses": "ressaltar",
    "ressaltaste": "ressaltar",
    "ressaltastes": "ressaltar",
    "ressaltava": "ressaltar",
    "ressaltavam": "ressaltar",
    "ressaltavas": "ressaltar",
    "ressalte": "ressaltar",
    "ressalteada": "ressaltear",
    "ressalteadas": "ressaltear",
    "ressalteado": "ressaltear",
    "ressalteados": "ressaltear",
    "ressalteai": "ressaltear",
    "ressalteais": "ressaltear",
    "ressalteamo": "ressaltear",
    "ressalteamos": "ressaltear",
    "ressalteando": "ressaltear",
    "ressalteara": "ressaltear",
    "ressaltearam": "ressaltear",
    "ressaltearas": "ressaltear",
    "ressaltearde": "ressaltear",
    "ressalteardes": "ressaltear",
    "ressalteare": "ressaltear",
    "ressaltearei": "ressaltear",
    "ressalteareis": "ressaltear",
    "ressaltearem": "ressaltear",
    "ressaltearemos": "ressaltear",
    "ressalteares": "ressaltear",
    "ressaltearia": "ressaltear",
    "ressalteariam": "ressaltear",
    "ressaltearias": "ressaltear",
    "ressaltearmo": "ressaltear",
    "ressaltearmos": "ressaltear",
    "ressalteará": "ressaltear",
    "ressaltearás": "ressaltear",
    "ressaltearão": "ressaltear",
    "ressaltearíamos": "ressaltear",
    "ressaltearíeis": "ressaltear",
    "ressalteasse": "ressaltear",
    "ressalteassem": "ressaltear",
    "ressalteasses": "ressaltear",
    "ressalteaste": "ressaltear",
    "ressalteastes": "ressaltear",
    "ressalteava": "ressaltear",
    "ressalteavam": "ressaltear",
    "ressalteavas": "ressaltear",
    "ressalteei": "ressaltear",
    "ressalteeis": "ressaltear",
    "ressalteemo": "ressaltear",
    "ressalteemos": "ressaltear",
    "ressaltei": "ressaltar",
    "ressalteia": "ressaltear",
    "ressalteiam": "ressaltear",
    "ressalteias": "ressaltear",
    "ressalteie": "ressaltear",
    "ressalteiem": "ressaltear",
    "ressalteies": "ressaltear",
    "ressalteio": "ressaltear",
    "ressalteis": "ressaltar",
    "ressaltem": "ressaltar",
    "ressaltemo": "ressaltar",
    "ressaltemos": "ressaltar",
    "ressalteou": "ressaltear",
    "ressaltes": "ressalte",
    "ressalteá": "ressaltear",
    "ressalteámo": "ressaltear",
    "ressalteámos": "ressaltear",
    "ressalteáramo": "ressaltear",
    "ressalteáramos": "ressaltear",
    "ressalteárei": "ressaltear",
    "ressalteáreis": "ressaltear",
    "ressalteásseis": "ressaltear",
    "ressalteássemos": "ressaltear",
    "ressalteávamo": "ressaltear",
    "ressalteávamos": "ressaltear",
    "ressalteávei": "ressaltear",
    "ressalteáveis": "ressaltear",
    "ressalto": "ressaltar",
    "ressaltos": "ressalto",
    "ressaltou": "ressaltar",
    "ressaltá": "ressaltar",
    "ressaltámo": "ressaltar",
    "ressaltámos": "ressaltar",
    "ressaltáramo": "ressaltar",
    "ressaltáramos": "ressaltar",
    "ressaltárei": "ressaltar",
    "ressaltáreis": "ressaltar",
    "ressaltásseis": "ressaltar",
    "ressaltássemos": "ressaltar",
    "ressaltávamo": "ressaltar",
    "ressaltávamos": "ressaltar",
    "ressaltávei": "ressaltar",
    "ressaltáveis": "ressaltar",
    "ressalva": "ressalvar",
    "ressalvada": "ressalvar",
    "ressalvadas": "ressalvar",
    "ressalvado": "ressalvar",
    "ressalvados": "ressalvar",
    "ressalvai": "ressalvar",
    "ressalvais": "ressalvar",
    "ressalvam": "ressalvar",
    "ressalvamo": "ressalvar",
    "ressalvamos": "ressalvar",
    "ressalvando": "ressalvar",
    "ressalvara": "ressalvar",
    "ressalvaram": "ressalvar",
    "ressalvaras": "ressalvar",
    "ressalvarde": "ressalvar",
    "ressalvardes": "ressalvar",
    "ressalvare": "ressalvar",
    "ressalvarei": "ressalvar",
    "ressalvareis": "ressalvar",
    "ressalvarem": "ressalvar",
    "ressalvaremos": "ressalvar",
    "ressalvares": "ressalvar",
    "ressalvaria": "ressalvar",
    "ressalvariam": "ressalvar",
    "ressalvarias": "ressalvar",
    "ressalvarmo": "ressalvar",
    "ressalvarmos": "ressalvar",
    "ressalvará": "ressalvar",
    "ressalvarás": "ressalvar",
    "ressalvarão": "ressalvar",
    "ressalvaríamos": "ressalvar",
    "ressalvaríeis": "ressalvar",
    "ressalvas": "ressalvar",
    "ressalvasse": "ressalvar",
    "ressalvassem": "ressalvar",
    "ressalvasses": "ressalvar",
    "ressalvaste": "ressalvar",
    "ressalvastes": "ressalvar",
    "ressalvava": "ressalvar",
    "ressalvavam": "ressalvar",
    "ressalvavas": "ressalvar",
    "ressalve": "ressalvar",
    "ressalvei": "ressalvar",
    "ressalveis": "ressalvar",
    "ressalvem": "ressalvar",
    "ressalvemo": "ressalvar",
    "ressalvemos": "ressalvar",
    "ressalves": "ressalvar",
    "ressalvo": "ressalvar",
    "ressalvos": "ressalvo",
    "ressalvou": "ressalvar",
    "ressalvá": "ressalvar",
    "ressalvámo": "ressalvar",
    "ressalvámos": "ressalvar",
    "ressalváramo": "ressalvar",
    "ressalváramos": "ressalvar",
    "ressalvárei": "ressalvar",
    "ressalváreis": "ressalvar",
    "ressalvásseis": "ressalvar",
    "ressalvássemos": "ressalvar",
    "ressalvávamo": "ressalvar",
    "ressalvávamos": "ressalvar",
    "ressalvávei": "ressalvar",
    "ressalváveis": "ressalvar",
    "ressaque": "ressacar",
    "ressaquei": "ressacar",
    "ressaqueis": "ressacar",
    "ressaquem": "ressacar",
    "ressaquemo": "ressacar",
    "ressaquemos": "ressacar",
    "ressaques": "ressaque",
    "ressarce": "ressarcir",
    "ressarcem": "ressarcir",
    "ressarces": "ressarcir",
    "ressarci": "ressarcir",
    "ressarcia": "ressarcir",
    "ressarciam": "ressarcir",
    "ressarcias": "ressarcir",
    "ressarcida": "ressarcir",
    "ressarcidas": "ressarcir",
    "ressarcido": "ressarcir",
    "ressarcidos": "ressarcir",
    "ressarcimentos": "ressarcimento",
    "ressarcimo": "ressarcir",
    "ressarcimos": "ressarcir",
    "ressarcindo": "ressarcir",
    "ressarcira": "ressarcir",
    "ressarciram": "ressarcir",
    "ressarciras": "ressarcir",
    "ressarcirde": "ressarcir",
    "ressarcirdes": "ressarcir",
    "ressarcire": "ressarcir",
    "ressarcirei": "ressarcir",
    "ressarcireis": "ressarcir",
    "ressarcirem": "ressarcir",
    "ressarciremos": "ressarcir",
    "ressarcires": "ressarcir",
    "ressarciria": "ressarcir",
    "ressarciriam": "ressarcir",
    "ressarcirias": "ressarcir",
    "ressarcirmo": "ressarcir",
    "ressarcirmos": "ressarcir",
    "ressarcirá": "ressarcir",
    "ressarcirás": "ressarcir",
    "ressarcirão": "ressarcir",
    "ressarciríamos": "ressarcir",
    "ressarciríeis": "ressarcir",
    "ressarcis": "ressarcir",
    "ressarcisse": "ressarcir",
    "ressarcissem": "ressarcir",
    "ressarcisses": "ressarcir",
    "ressarciste": "ressarcir",
    "ressarcistes": "ressarcir",
    "ressarciu": "ressarcir",
    "ressarcíamo": "ressarcir",
    "ressarcíamos": "ressarcir",
    "ressarcíei": "ressarcir",
    "ressarcíeis": "ressarcir",
    "ressarcíramo": "ressarcir",
    "ressarcíramos": "ressarcir",
    "ressarcírei": "ressarcir",
    "ressarcíreis": "ressarcir",
    "ressarcísseis": "ressarcir",
    "ressarcíssemos": "ressarcir",
    "ressarça": "ressarcir",
    "ressarçais": "ressarcir",
    "ressarçam": "ressarcir",
    "ressarçamo": "ressarcir",
    "ressarçamos": "ressarcir",
    "ressarças": "ressarcir",
    "ressarço": "ressarcir",
    "ressas": "ressa",
    "ressaudada": "ressaudar",
    "ressaudadas": "ressaudar",
    "ressaudado": "ressaudar",
    "ressaudados": "ressaudar",
    "ressaudai": "ressaudar",
    "ressaudais": "ressaudar",
    "ressaudamo": "ressaudar",
    "ressaudamos": "ressaudar",
    "ressaudando": "ressaudar",
    "ressaudara": "ressaudar",
    "ressaudaram": "ressaudar",
    "ressaudaras": "ressaudar",
    "ressaudarde": "ressaudar",
    "ressaudardes": "ressaudar",
    "ressaudare": "ressaudar",
    "ressaudarei": "ressaudar",
    "ressaudareis": "ressaudar",
    "ressaudarem": "ressaudar",
    "ressaudaremos": "ressaudar",
    "ressaudares": "ressaudar",
    "ressaudaria": "ressaudar",
    "ressaudariam": "ressaudar",
    "ressaudarias": "ressaudar",
    "ressaudarmo": "ressaudar",
    "ressaudarmos": "ressaudar",
    "ressaudará": "ressaudar",
    "ressaudarás": "ressaudar",
    "ressaudarão": "ressaudar",
    "ressaudaríamos": "ressaudar",
    "ressaudaríeis": "ressaudar",
    "ressaudasse": "ressaudar",
    "ressaudassem": "ressaudar",
    "ressaudasses": "ressaudar",
    "ressaudaste": "ressaudar",
    "ressaudastes": "ressaudar",
    "ressaudava": "ressaudar",
    "ressaudavam": "ressaudar",
    "ressaudavas": "ressaudar",
    "ressaudações": "ressaudação",
    "ressaudei": "ressaudar",
    "ressaudeis": "ressaudar",
    "ressaudemo": "ressaudar",
    "ressaudemos": "ressaudar",
    "ressaudou": "ressaudar",
    "ressaudá": "ressaudar",
    "ressaudámo": "ressaudar",
    "ressaudámos": "ressaudar",
    "ressaudáramo": "ressaudar",
    "ressaudáramos": "ressaudar",
    "ressaudárei": "ressaudar",
    "ressaudáreis": "ressaudar",
    "ressaudásseis": "ressaudar",
    "ressaudássemos": "ressaudar",
    "ressaudávamo": "ressaudar",
    "ressaudávamos": "ressaudar",
    "ressaudávei": "ressaudar",
    "ressaudáveis": "ressaudar",
    "ressaí": "ressair",
    "ressaía": "ressair",
    "ressaíam": "ressair",
    "ressaíamo": "ressair",
    "ressaíamos": "ressair",
    "ressaías": "ressair",
    "ressaída": "ressair",
    "ressaídas": "ressair",
    "ressaído": "ressair",
    "ressaídos": "ressair",
    "ressaíeis": "ressair",
    "ressaímo": "ressair",
    "ressaímos": "ressair",
    "ressaíra": "ressair",
    "ressaíram": "ressair",
    "ressaíramo": "ressair",
    "ressaíramos": "ressair",
    "ressaíras": "ressair",
    "ressaíreis": "ressair",
    "ressaírem": "ressair",
    "ressaíres": "ressair",
    "ressaís": "ressair",
    "ressaísse": "ressair",
    "ressaísseis": "ressair",
    "ressaíssem": "ressair",
    "ressaíssemos": "ressair",
    "ressaísses": "ressair",
    "ressaíste": "ressair",
    "ressaístes": "ressair",
    "ressaúda": "ressaudar",
    "ressaúdam": "ressaudar",
    "ressaúdas": "ressaudar",
    "ressaúde": "ressaudar",
    "ressaúdem": "ressaudar",
    "ressaúdes": "ressaudar",
    "ressaúdo": "ressaudar",
    "resseca": "resseco",
    "ressecada": "ressecar",
    "ressecadas": "ressecar",
    "ressecado": "ressecar",
    "ressecados": "ressecar",
    "ressecai": "ressecar",
    "ressecais": "ressecar",
    "ressecam": "ressecar",
    "ressecamo": "ressecar",
    "ressecamos": "ressecar",
    "ressecando": "ressecar",
    "ressecara": "ressecar",
    "ressecaram": "ressecar",
    "ressecaras": "ressecar",
    "ressecarde": "ressecar",
    "ressecardes": "ressecar",
    "ressecare": "ressecar",
    "ressecarei": "ressecar",
    "ressecareis": "ressecar",
    "ressecarem": "ressecar",
    "ressecaremos": "ressecar",
    "ressecares": "ressecar",
    "ressecaria": "ressecar",
    "ressecariam": "ressecar",
    "ressecarias": "ressecar",
    "ressecarmo": "ressecar",
    "ressecarmos": "ressecar",
    "ressecará": "ressecar",
    "ressecarás": "ressecar",
    "ressecarão": "ressecar",
    "ressecaríamos": "ressecar",
    "ressecaríeis": "ressecar",
    "ressecas": "resseco",
    "ressecasse": "ressecar",
    "ressecassem": "ressecar",
    "ressecasses": "ressecar",
    "ressecaste": "ressecar",
    "ressecastes": "ressecar",
    "ressecava": "ressecar",
    "ressecavam": "ressecar",
    "ressecavas": "ressecar",
    "ressecações": "ressecação",
    "resseco": "ressecar",
    "ressecos": "resseco",
    "ressecou": "ressecar",
    "ressecá": "ressecar",
    "ressecámo": "ressecar",
    "ressecámos": "ressecar",
    "ressecáramo": "ressecar",
    "ressecáramos": "ressecar",
    "ressecárei": "ressecar",
    "ressecáreis": "ressecar",
    "ressecásseis": "ressecar",
    "ressecássemos": "ressecar",
    "ressecávamo": "ressecar",
    "ressecávamos": "ressecar",
    "ressecávei": "ressecar",
    "ressecáveis": "ressecar",
    "ressecções": "ressecção",
    "ressega": "ressegar",
    "ressegada": "ressegar",
    "ressegadas": "ressegar",
    "ressegado": "ressegar",
    "ressegados": "ressegar",
    "ressegai": "ressegar",
    "ressegais": "ressegar",
    "ressegam": "ressegar",
    "ressegamo": "ressegar",
    "ressegamos": "ressegar",
    "ressegando": "ressegar",
    "ressegara": "ressegar",
    "ressegaram": "ressegar",
    "ressegaras": "ressegar",
    "ressegarde": "ressegar",
    "ressegardes": "ressegar",
    "ressegare": "ressegar",
    "ressegarei": "ressegar",
    "ressegareis": "ressegar",
    "ressegarem": "ressegar",
    "ressegaremos": "ressegar",
    "ressegares": "ressegar",
    "ressegaria": "ressegar",
    "ressegariam": "ressegar",
    "ressegarias": "ressegar",
    "ressegarmo": "ressegar",
    "ressegarmos": "ressegar",
    "ressegará": "ressegar",
    "ressegarás": "ressegar",
    "ressegarão": "ressegar",
    "ressegaríamos": "ressegar",
    "ressegaríeis": "ressegar",
    "ressegas": "ressegar",
    "ressegasse": "ressegar",
    "ressegassem": "ressegar",
    "ressegasses": "ressegar",
    "ressegaste": "ressegar",
    "ressegastes": "ressegar",
    "ressegava": "ressegar",
    "ressegavam": "ressegar",
    "ressegavas": "ressegar",
    "ressego": "ressegar",
    "ressegou": "ressegar",
    "ressegue": "ressegar",
    "resseguei": "ressegar",
    "ressegueis": "ressegar",
    "resseguem": "ressegar",
    "resseguemo": "ressegar",
    "resseguemos": "ressegar",
    "ressegues": "ressegar",
    "ressegura": "resseguro",
    "resseguras": "resseguro",
    "resseguros": "resseguro",
    "ressegá": "ressegar",
    "ressegámo": "ressegar",
    "ressegámos": "ressegar",
    "ressegáramo": "ressegar",
    "ressegáramos": "ressegar",
    "ressegárei": "ressegar",
    "ressegáreis": "ressegar",
    "ressegásseis": "ressegar",
    "ressegássemos": "ressegar",
    "ressegávamo": "ressegar",
    "ressegávamos": "ressegar",
    "ressegávei": "ressegar",
    "ressegáveis": "ressegar",
    "ressei": "ressaber",
    "ressela": "resselar",
    "resselada": "resselar",
    "resseladas": "resselar",
    "resselado": "resselar",
    "resselados": "resselar",
    "resselai": "resselar",
    "resselais": "resselar",
    "resselam": "resselar",
    "resselamo": "resselar",
    "resselamos": "resselar",
    "resselando": "resselar",
    "resselara": "resselar",
    "resselaram": "resselar",
    "resselaras": "resselar",
    "resselarde": "resselar",
    "resselardes": "resselar",
    "resselare": "resselar",
    "resselarei": "resselar",
    "resselareis": "resselar",
    "resselarem": "resselar",
    "resselaremos": "resselar",
    "resselares": "resselar",
    "resselaria": "resselar",
    "resselariam": "resselar",
    "resselarias": "resselar",
    "resselarmo": "resselar",
    "resselarmos": "resselar",
    "resselará": "resselar",
    "resselarás": "resselar",
    "resselarão": "resselar",
    "resselaríamos": "resselar",
    "resselaríeis": "resselar",
    "resselas": "resselar",
    "resselasse": "resselar",
    "resselassem": "resselar",
    "resselasses": "resselar",
    "resselaste": "resselar",
    "resselastes": "resselar",
    "resselava": "resselar",
    "resselavam": "resselar",
    "resselavas": "resselar",
    "ressele": "resselar",
    "resselei": "resselar",
    "resseleis": "resselar",
    "resselem": "resselar",
    "resselemo": "resselar",
    "resselemos": "resselar",
    "resseles": "resselar",
    "resselo": "resselar",
    "resselou": "resselar",
    "resselá": "resselar",
    "resselámo": "resselar",
    "resselámos": "resselar",
    "resseláramo": "resselar",
    "resseláramos": "resselar",
    "resselárei": "resselar",
    "resseláreis": "resselar",
    "resselásseis": "resselar",
    "resselássemos": "resselar",
    "resselávamo": "resselar",
    "resselávamos": "resselar",
    "resselávei": "resselar",
    "resseláveis": "resselar",
    "ressemeada": "ressemear",
    "ressemeadas": "ressemear",
    "ressemeado": "ressemear",
    "ressemeados": "ressemear",
    "ressemeaduras": "ressemeadura",
    "ressemeai": "ressemear",
    "ressemeais": "ressemear",
    "ressemeamo": "ressemear",
    "ressemeamos": "ressemear",
    "ressemeando": "ressemear",
    "ressemeara": "ressemear",
    "ressemearam": "ressemear",
    "ressemearas": "ressemear",
    "ressemearde": "ressemear",
    "ressemeardes": "ressemear",
    "ressemeare": "ressemear",
    "ressemearei": "ressemear",
    "ressemeareis": "ressemear",
    "ressemearem": "ressemear",
    "ressemearemos": "ressemear",
    "ressemeares": "ressemear",
    "ressemearia": "ressemear",
    "ressemeariam": "ressemear",
    "ressemearias": "ressemear",
    "ressemearmo": "ressemear",
    "ressemearmos": "ressemear",
    "ressemeará": "ressemear",
    "ressemearás": "ressemear",
    "ressemearão": "ressemear",
    "ressemearíamos": "ressemear",
    "ressemearíeis": "ressemear",
    "ressemeasse": "ressemear",
    "ressemeassem": "ressemear",
    "ressemeasses": "ressemear",
    "ressemeaste": "ressemear",
    "ressemeastes": "ressemear",
    "ressemeava": "ressemear",
    "ressemeavam": "ressemear",
    "ressemeavas": "ressemear",
    "ressemeei": "ressemear",
    "ressemeeis": "ressemear",
    "ressemeemo": "ressemear",
    "ressemeemos": "ressemear",
    "ressemeia": "ressemear",
    "ressemeiam": "ressemear",
    "ressemeias": "ressemear",
    "ressemeie": "ressemear",
    "ressemeiem": "ressemear",
    "ressemeies": "ressemear",
    "ressemeio": "ressemear",
    "ressemeou": "ressemear",
    "ressemeá": "ressemear",
    "ressemeámo": "ressemear",
    "ressemeámos": "ressemear",
    "ressemeáramo": "ressemear",
    "ressemeáramos": "ressemear",
    "ressemeárei": "ressemear",
    "ressemeáreis": "ressemear",
    "ressemeásseis": "ressemear",
    "ressemeássemos": "ressemear",
    "ressemeávamo": "ressemear",
    "ressemeávamos": "ressemear",
    "ressemeávei": "ressemear",
    "ressemeáveis": "ressemear",
    "ressente": "ressentir",
    "ressentem": "ressentir",
    "ressentes": "ressentir",
    "ressenti": "ressentir",
    "ressentia": "ressentir",
    "ressentiam": "ressentir",
    "ressentias": "ressentir",
    "ressentida": "ressentir",
    "ressentidas": "ressentir",
    "ressentido": "ressentir",
    "ressentidos": "ressentir",
    "ressentidíssima": "ressentido",
    "ressentidíssimas": "ressentido",
    "ressentidíssimo": "ressentido",
    "ressentidíssimos": "ressentido",
    "ressentimentos": "ressentimento",
    "ressentimo": "ressentir",
    "ressentimos": "ressentir",
    "ressentindo": "ressentir",
    "ressentira": "ressentir",
    "ressentiram": "ressentir",
    "ressentiras": "ressentir",
    "ressentirde": "ressentir",
    "ressentirdes": "ressentir",
    "ressentire": "ressentir",
    "ressentirei": "ressentir",
    "ressentireis": "ressentir",
    "ressentirem": "ressentir",
    "ressentiremos": "ressentir",
    "ressentires": "ressentir",
    "ressentiria": "ressentir",
    "ressentiriam": "ressentir",
    "ressentirias": "ressentir",
    "ressentirmo": "ressentir",
    "ressentirmos": "ressentir",
    "ressentirá": "ressentir",
    "ressentirás": "ressentir",
    "ressentirão": "ressentir",
    "ressentiríamos": "ressentir",
    "ressentiríeis": "ressentir",
    "ressentis": "ressentir",
    "ressentisse": "ressentir",
    "ressentissem": "ressentir",
    "ressentisses": "ressentir",
    "ressentiste": "ressentir",
    "ressentistes": "ressentir",
    "ressentiu": "ressentir",
    "ressentíamo": "ressentir",
    "ressentíamos": "ressentir",
    "ressentíei": "ressentir",
    "ressentíeis": "ressentir",
    "ressentíramo": "ressentir",
    "ressentíramos": "ressentir",
    "ressentírei": "ressentir",
    "ressentíreis": "ressentir",
    "ressentísseis": "ressentir",
    "ressentíssemos": "ressentir",
    "resseque": "ressecar",
    "ressequei": "ressecar",
    "ressequeis": "ressecar",
    "ressequem": "ressecar",
    "ressequemo": "ressecar",
    "ressequemos": "ressecar",
    "resseques": "ressecar",
    "ressequi": "ressequir",
    "ressequia": "ressequir",
    "ressequiam": "ressequir",
    "ressequias": "ressequir",
    "ressequida": "ressequir",
    "ressequidas": "ressequir",
    "ressequidazinha": "ressequido",
    "ressequidazinhas": "ressequido",
    "ressequidazita": "ressequido",
    "ressequidazitas": "ressequido",
    "ressequidinha": "ressequido",
    "ressequidinhas": "ressequido",
    "ressequidinho": "ressequido",
    "ressequidinhos": "ressequido",
    "ressequidita": "ressequido",
    "ressequiditas": "ressequido",
    "ressequidito": "ressequido",
    "ressequiditos": "ressequido",
    "ressequido": "ressequir",
    "ressequidos": "ressequir",
    "ressequidozinho": "ressequido",
    "ressequidozinhos": "ressequido",
    "ressequidozito": "ressequido",
    "ressequidozitos": "ressequido",
    "ressequidíssima": "ressequido",
    "ressequidíssimas": "ressequido",
    "ressequidíssimo": "ressequido",
    "ressequidíssimos": "ressequido",
    "ressequimo": "ressequir",
    "ressequimos": "ressequir",
    "ressequindo": "ressequir",
    "ressequira": "ressequir",
    "ressequiram": "ressequir",
    "ressequiras": "ressequir",
    "ressequirde": "ressequir",
    "ressequirdes": "ressequir",
    "ressequire": "ressequir",
    "ressequirei": "ressequir",
    "ressequireis": "ressequir",
    "ressequirem": "ressequir",
    "ressequiremos": "ressequir",
    "ressequires": "ressequir",
    "ressequiria": "ressequir",
    "ressequiriam": "ressequir",
    "ressequirias": "ressequir",
    "ressequirmo": "ressequir",
    "ressequirmos": "ressequir",
    "ressequirá": "ressequir",
    "ressequirás": "ressequir",
    "ressequirão": "ressequir",
    "ressequiríamos": "ressequir",
    "ressequiríeis": "ressequir",
    "ressequis": "ressequir",
    "ressequisse": "ressequir",
    "ressequissem": "ressequir",
    "ressequisses": "ressequir",
    "ressequiste": "ressequir",
    "ressequistes": "ressequir",
    "ressequiu": "ressequir",
    "ressequíamo": "ressequir",
    "ressequíamos": "ressequir",
    "ressequíei": "ressequir",
    "ressequíeis": "ressequir",
    "ressequíramo": "ressequir",
    "ressequíramos": "ressequir",
    "ressequírei": "ressequir",
    "ressequíreis": "ressequir",
    "ressequísseis": "ressequir",
    "ressequíssemos": "ressequir",
    "resserena": "ressereno",
    "resserenada": "resserenar",
    "resserenadas": "resserenar",
    "resserenado": "resserenar",
    "resserenados": "resserenar",
    "resserenai": "resserenar",
    "resserenais": "resserenar",
    "resserenam": "resserenar",
    "resserenamo": "resserenar",
    "resserenamos": "resserenar",
    "resserenando": "resserenar",
    "resserenara": "resserenar",
    "resserenaram": "resserenar",
    "resserenaras": "resserenar",
    "resserenarde": "resserenar",
    "resserenardes": "resserenar",
    "resserenare": "resserenar",
    "resserenarei": "resserenar",
    "resserenareis": "resserenar",
    "resserenarem": "resserenar",
    "resserenaremos": "resserenar",
    "resserenares": "resserenar",
    "resserenaria": "resserenar",
    "resserenariam": "resserenar",
    "resserenarias": "resserenar",
    "resserenarmo": "resserenar",
    "resserenarmos": "resserenar",
    "resserenará": "resserenar",
    "resserenarás": "resserenar",
    "resserenarão": "resserenar",
    "resserenaríamos": "resserenar",
    "resserenaríeis": "resserenar",
    "resserenas": "ressereno",
    "resserenasse": "resserenar",
    "resserenassem": "resserenar",
    "resserenasses": "resserenar",
    "resserenaste": "resserenar",
    "resserenastes": "resserenar",
    "resserenava": "resserenar",
    "resserenavam": "resserenar",
    "resserenavas": "resserenar",
    "resserene": "resserenar",
    "resserenei": "resserenar",
    "ressereneis": "resserenar",
    "resserenem": "resserenar",
    "resserenemo": "resserenar",
    "resserenemos": "resserenar",
    "resserenes": "resserenar",
    "ressereno": "resserenar",
    "resserenos": "ressereno",
    "resserenou": "resserenar",
    "resserená": "resserenar",
    "resserenámo": "resserenar",
    "resserenámos": "resserenar",
    "resserenáramo": "resserenar",
    "resserenáramos": "resserenar",
    "resserenárei": "resserenar",
    "resserenáreis": "resserenar",
    "resserenásseis": "resserenar",
    "resserenássemos": "resserenar",
    "resserenávamo": "resserenar",
    "resserenávamos": "resserenar",
    "resserenávei": "resserenar",
    "resserenáveis": "resserenar",
    "ressessa": "ressesso",
    "ressessas": "ressesso",
    "ressessos": "ressesso",
    "ressica": "ressicar",
    "ressicada": "ressicar",
    "ressicadas": "ressicar",
    "ressicado": "ressicar",
    "ressicados": "ressicar",
    "ressicai": "ressicar",
    "ressicais": "ressicar",
    "ressicam": "ressicar",
    "ressicamo": "ressicar",
    "ressicamos": "ressicar",
    "ressicando": "ressicar",
    "ressicara": "ressicar",
    "ressicaram": "ressicar",
    "ressicaras": "ressicar",
    "ressicarde": "ressicar",
    "ressicardes": "ressicar",
    "ressicare": "ressicar",
    "ressicarei": "ressicar",
    "ressicareis": "ressicar",
    "ressicarem": "ressicar",
    "ressicaremos": "ressicar",
    "ressicares": "ressicar",
    "ressicaria": "ressicar",
    "ressicariam": "ressicar",
    "ressicarias": "ressicar",
    "ressicarmo": "ressicar",
    "ressicarmos": "ressicar",
    "ressicará": "ressicar",
    "ressicarás": "ressicar",
    "ressicarão": "ressicar",
    "ressicaríamos": "ressicar",
    "ressicaríeis": "ressicar",
    "ressicas": "ressicar",
    "ressicasse": "ressicar",
    "ressicassem": "ressicar",
    "ressicasses": "ressicar",
    "ressicaste": "ressicar",
    "ressicastes": "ressicar",
    "ressicava": "ressicar",
    "ressicavam": "ressicar",
    "ressicavas": "ressicar",
    "ressicações": "ressicação",
    "ressico": "ressicar",
    "ressicou": "ressicar",
    "ressicá": "ressicar",
    "ressicámo": "ressicar",
    "ressicámos": "ressicar",
    "ressicáramo": "ressicar",
    "ressicáramos": "ressicar",
    "ressicárei": "ressicar",
    "ressicáreis": "ressicar",
    "ressicásseis": "ressicar",
    "ressicássemos": "ressicar",
    "ressicávamo": "ressicar",
    "ressicávamos": "ressicar",
    "ressicávei": "ressicar",
    "ressicáveis": "ressicar",
    "ressincroniza": "ressincronizar",
    "ressincronizada": "ressincronizar",
    "ressincronizadas": "ressincronizar",
    "ressincronizado": "ressincronizar",
    "ressincronizados": "ressincronizar",
    "ressincronizai": "ressincronizar",
    "ressincronizais": "ressincronizar",
    "ressincronizam": "ressincronizar",
    "ressincronizamo": "ressincronizar",
    "ressincronizamos": "ressincronizar",
    "ressincronizando": "ressincronizar",
    "ressincronizara": "ressincronizar",
    "ressincronizaram": "ressincronizar",
    "ressincronizaras": "ressincronizar",
    "ressincronizarde": "ressincronizar",
    "ressincronizardes": "ressincronizar",
    "ressincronizare": "ressincronizar",
    "ressincronizarei": "ressincronizar",
    "ressincronizareis": "ressincronizar",
    "ressincronizarem": "ressincronizar",
    "ressincronizaremos": "ressincronizar",
    "ressincronizares": "ressincronizar",
    "ressincronizaria": "ressincronizar",
    "ressincronizariam": "ressincronizar",
    "ressincronizarias": "ressincronizar",
    "ressincronizarmo": "ressincronizar",
    "ressincronizarmos": "ressincronizar",
    "ressincronizará": "ressincronizar",
    "ressincronizarás": "ressincronizar",
    "ressincronizarão": "ressincronizar",
    "ressincronizaríamos": "ressincronizar",
    "ressincronizaríeis": "ressincronizar",
    "ressincronizas": "ressincronizar",
    "ressincronizasse": "ressincronizar",
    "ressincronizassem": "ressincronizar",
    "ressincronizasses": "ressincronizar",
    "ressincronizaste": "ressincronizar",
    "ressincronizastes": "ressincronizar",
    "ressincronizava": "ressincronizar",
    "ressincronizavam": "ressincronizar",
    "ressincronizavas": "ressincronizar",
    "ressincronizações": "ressincronização",
    "ressincronize": "ressincronizar",
    "ressincronizei": "ressincronizar",
    "ressincronizeis": "ressincronizar",
    "ressincronizem": "ressincronizar",
    "ressincronizemo": "ressincronizar",
    "ressincronizemos": "ressincronizar",
    "ressincronizes": "ressincronizar",
    "ressincronizo": "ressincronizar",
    "ressincronizou": "ressincronizar",
    "ressincronizá": "ressincronizar",
    "ressincronizámo": "ressincronizar",
    "ressincronizámos": "ressincronizar",
    "ressincronizáramo": "ressincronizar",
    "ressincronizáramos": "ressincronizar",
    "ressincronizárei": "ressincronizar",
    "ressincronizáreis": "ressincronizar",
    "ressincronizásseis": "ressincronizar",
    "ressincronizássemos": "ressincronizar",
    "ressincronizávamo": "ressincronizar",
    "ressincronizávamos": "ressincronizar",
    "ressincronizávei": "ressincronizar",
    "ressincronizáveis": "ressincronizar",
    "ressinta": "ressentir",
    "ressintais": "ressentir",
    "ressintam": "ressentir",
    "ressintamo": "ressentir",
    "ressintamos": "ressentir",
    "ressintas": "ressentir",
    "ressinto": "ressentir",
    "ressios": "ressio",
    "ressique": "ressicar",
    "ressiquei": "ressicar",
    "ressiqueis": "ressicar",
    "ressiquem": "ressicar",
    "ressiquemo": "ressicar",
    "ressiquemos": "ressicar",
    "ressiques": "ressicar",
    "ressoa": "ressoar",
    "ressoada": "ressoar",
    "ressoadas": "ressoar",
    "ressoado": "ressoar",
    "ressoadora": "ressoador",
    "ressoadoras": "ressoador",
    "ressoadores": "ressoador",
    "ressoados": "ressoar",
    "ressoai": "ressoar",
    "ressoais": "ressoar",
    "ressoam": "ressoar",
    "ressoamo": "ressoar",
    "ressoamos": "ressoar",
    "ressoando": "ressoar",
    "ressoantes": "ressoante",
    "ressoara": "ressoar",
    "ressoaram": "ressoar",
    "ressoaras": "ressoar",
    "ressoarde": "ressoar",
    "ressoardes": "ressoar",
    "ressoare": "ressoar",
    "ressoarei": "ressoar",
    "ressoareis": "ressoar",
    "ressoarem": "ressoar",
    "ressoaremos": "ressoar",
    "ressoares": "ressoar",
    "ressoaria": "ressoar",
    "ressoariam": "ressoar",
    "ressoarias": "ressoar",
    "ressoarmo": "ressoar",
    "ressoarmos": "ressoar",
    "ressoará": "ressoar",
    "ressoarás": "ressoar",
    "ressoarão": "ressoar",
    "ressoaríamos": "ressoar",
    "ressoaríeis": "ressoar",
    "ressoas": "ressoar",
    "ressoasse": "ressoar",
    "ressoassem": "ressoar",
    "ressoasses": "ressoar",
    "ressoaste": "ressoar",
    "ressoastes": "ressoar",
    "ressoava": "ressoar",
    "ressoavam": "ressoar",
    "ressoavas": "ressoar",
    "ressobe": "ressubir",
    "ressobem": "ressubir",
    "ressobes": "ressubir",
    "ressobra": "ressobrar",
    "ressobrada": "ressobrar",
    "ressobradas": "ressobrar",
    "ressobrado": "ressobrar",
    "ressobrados": "ressobrar",
    "ressobrai": "ressobrar",
    "ressobrais": "ressobrar",
    "ressobram": "ressobrar",
    "ressobramo": "ressobrar",
    "ressobramos": "ressobrar",
    "ressobrando": "ressobrar",
    "ressobrara": "ressobrar",
    "ressobraram": "ressobrar",
    "ressobraras": "ressobrar",
    "ressobrarde": "ressobrar",
    "ressobrardes": "ressobrar",
    "ressobrare": "ressobrar",
    "ressobrarei": "ressobrar",
    "ressobrareis": "ressobrar",
    "ressobrarem": "ressobrar",
    "ressobraremos": "ressobrar",
    "ressobrares": "ressobrar",
    "ressobraria": "ressobrar",
    "ressobrariam": "ressobrar",
    "ressobrarias": "ressobrar",
    "ressobrarmo": "ressobrar",
    "ressobrarmos": "ressobrar",
    "ressobrará": "ressobrar",
    "ressobrarás": "ressobrar",
    "ressobrarão": "ressobrar",
    "ressobraríamos": "ressobrar",
    "ressobraríeis": "ressobrar",
    "ressobras": "ressobrar",
    "ressobrasse": "ressobrar",
    "ressobrassem": "ressobrar",
    "ressobrasses": "ressobrar",
    "ressobraste": "ressobrar",
    "ressobrastes": "ressobrar",
    "ressobrava": "ressobrar",
    "ressobravam": "ressobrar",
    "ressobravas": "ressobrar",
    "ressobre": "ressobrar",
    "ressobrei": "ressobrar",
    "ressobreis": "ressobrar",
    "ressobrem": "ressobrar",
    "ressobremo": "ressobrar",
    "ressobremos": "ressobrar",
    "ressobres": "ressobrar",
    "ressobro": "ressobrar",
    "ressobrou": "ressobrar",
    "ressobrá": "ressobrar",
    "ressobrámo": "ressobrar",
    "ressobrámos": "ressobrar",
    "ressobráramo": "ressobrar",
    "ressobráramos": "ressobrar",
    "ressobrárei": "ressobrar",
    "ressobráreis": "ressobrar",
    "ressobrásseis": "ressobrar",
    "ressobrássemos": "ressobrar",
    "ressobrávamo": "ressobrar",
    "ressobrávamos": "ressobrar",
    "ressobrávei": "ressobrar",
    "ressobráveis": "ressobrar",
    "ressocas": "ressoca",
    "ressocializantes": "ressocializante",
    "ressocializações": "ressocialização",
    "ressoe": "ressoar",
    "ressoei": "ressoar",
    "ressoeis": "ressoar",
    "ressoem": "ressoar",
    "ressoemo": "ressoar",
    "ressoemos": "ressoar",
    "ressoes": "ressoar",
    "ressolda": "ressoldar",
    "ressoldada": "ressoldar",
    "ressoldadas": "ressoldar",
    "ressoldado": "ressoldar",
    "ressoldados": "ressoldar",
    "ressoldai": "ressoldar",
    "ressoldais": "ressoldar",
    "ressoldam": "ressoldar",
    "ressoldamo": "ressoldar",
    "ressoldamos": "ressoldar",
    "ressoldando": "ressoldar",
    "ressoldara": "ressoldar",
    "ressoldaram": "ressoldar",
    "ressoldaras": "ressoldar",
    "ressoldarde": "ressoldar",
    "ressoldardes": "ressoldar",
    "ressoldare": "ressoldar",
    "ressoldarei": "ressoldar",
    "ressoldareis": "ressoldar",
    "ressoldarem": "ressoldar",
    "ressoldaremos": "ressoldar",
    "ressoldares": "ressoldar",
    "ressoldaria": "ressoldar",
    "ressoldariam": "ressoldar",
    "ressoldarias": "ressoldar",
    "ressoldarmo": "ressoldar",
    "ressoldarmos": "ressoldar",
    "ressoldará": "ressoldar",
    "ressoldarás": "ressoldar",
    "ressoldarão": "ressoldar",
    "ressoldaríamos": "ressoldar",
    "ressoldaríeis": "ressoldar",
    "ressoldas": "ressoldar",
    "ressoldasse": "ressoldar",
    "ressoldassem": "ressoldar",
    "ressoldasses": "ressoldar",
    "ressoldaste": "ressoldar",
    "ressoldastes": "ressoldar",
    "ressoldava": "ressoldar",
    "ressoldavam": "ressoldar",
    "ressoldavas": "ressoldar",
    "ressolde": "ressoldar",
    "ressoldei": "ressoldar",
    "ressoldeis": "ressoldar",
    "ressoldem": "ressoldar",
    "ressoldemo": "ressoldar",
    "ressoldemos": "ressoldar",
    "ressoldes": "ressoldar",
    "ressoldo": "ressoldar",
    "ressoldou": "ressoldar",
    "ressoldá": "ressoldar",
    "ressoldámo": "ressoldar",
    "ressoldámos": "ressoldar",
    "ressoldáramo": "ressoldar",
    "ressoldáramos": "ressoldar",
    "ressoldárei": "ressoldar",
    "ressoldáreis": "ressoldar",
    "ressoldásseis": "ressoldar",
    "ressoldássemos": "ressoldar",
    "ressoldávamo": "ressoldar",
    "ressoldávamos": "ressoldar",
    "ressoldávei": "ressoldar",
    "ressoldáveis": "ressoldar",
    "ressolha": "ressolhar",
    "ressolhada": "ressolhar",
    "ressolhadas": "ressolhar",
    "ressolhado": "ressolhar",
    "ressolhados": "ressolhar",
    "ressolhai": "ressolhar",
    "ressolhais": "ressolhar",
    "ressolham": "ressolhar",
    "ressolhamo": "ressolhar",
    "ressolhamos": "ressolhar",
    "ressolhando": "ressolhar",
    "ressolhara": "ressolhar",
    "ressolharam": "ressolhar",
    "ressolharas": "ressolhar",
    "ressolharde": "ressolhar",
    "ressolhardes": "ressolhar",
    "ressolhare": "ressolhar",
    "ressolharei": "ressolhar",
    "ressolhareis": "ressolhar",
    "ressolharem": "ressolhar",
    "ressolharemos": "ressolhar",
    "ressolhares": "ressolhar",
    "ressolharia": "ressolhar",
    "ressolhariam": "ressolhar",
    "ressolharias": "ressolhar",
    "ressolharmo": "ressolhar",
    "ressolharmos": "ressolhar",
    "ressolhará": "ressolhar",
    "ressolharás": "ressolhar",
    "ressolharão": "ressolhar",
    "ressolharíamos": "ressolhar",
    "ressolharíeis": "ressolhar",
    "ressolhas": "ressolhar",
    "ressolhasse": "ressolhar",
    "ressolhassem": "ressolhar",
    "ressolhasses": "ressolhar",
    "ressolhaste": "ressolhar",
    "ressolhastes": "ressolhar",
    "ressolhava": "ressolhar",
    "ressolhavam": "ressolhar",
    "ressolhavas": "ressolhar",
    "ressolhe": "ressolhar",
    "ressolhei": "ressolhar",
    "ressolheis": "ressolhar",
    "ressolhem": "ressolhar",
    "ressolhemo": "ressolhar",
    "ressolhemos": "ressolhar",
    "ressolhes": "ressolhar",
    "ressolho": "ressolhar",
    "ressolhos": "ressolho",
    "ressolhou": "ressolhar",
    "ressolhá": "ressolhar",
    "ressolhámo": "ressolhar",
    "ressolhámos": "ressolhar",
    "ressolháramo": "ressolhar",
    "ressolháramos": "ressolhar",
    "ressolhárei": "ressolhar",
    "ressolháreis": "ressolhar",
    "ressolhásseis": "ressolhar",
    "ressolhássemos": "ressolhar",
    "ressolhávamo": "ressolhar",
    "ressolhávamos": "ressolhar",
    "ressolhávei": "ressolhar",
    "ressolháveis": "ressolhar",
    "ressona": "ressonar",
    "ressonada": "ressonar",
    "ressonadas": "ressonar",
    "ressonadelas": "ressonadela",
    "ressonado": "ressonar",
    "ressonadora": "ressonador",
    "ressonadoras": "ressonador",
    "ressonadorazinha": "ressonador",
    "ressonadorazinhas": "ressonador",
    "ressonadorazita": "ressonador",
    "ressonadorazitas": "ressonador",
    "ressonadores": "ressonador",
    "ressonadorzinho": "ressonador",
    "ressonadorzinhos": "ressonador",
    "ressonadorzito": "ressonador",
    "ressonadorzitos": "ressonador",
    "ressonados": "ressonar",
    "ressonai": "ressonar",
    "ressonais": "ressonar",
    "ressonam": "ressonar",
    "ressonamo": "ressonar",
    "ressonamos": "ressonar",
    "ressonando": "ressonar",
    "ressonantes": "ressonante",
    "ressonara": "ressonar",
    "ressonaram": "ressonar",
    "ressonaras": "ressonar",
    "ressonarde": "ressonar",
    "ressonardes": "ressonar",
    "ressonare": "ressonar",
    "ressonarei": "ressonar",
    "ressonareis": "ressonar",
    "ressonarem": "ressonar",
    "ressonaremos": "ressonar",
    "ressonares": "ressonar",
    "ressonaria": "ressonar",
    "ressonariam": "ressonar",
    "ressonarias": "ressonar",
    "ressonarmo": "ressonar",
    "ressonarmos": "ressonar",
    "ressonará": "ressonar",
    "ressonarás": "ressonar",
    "ressonarão": "ressonar",
    "ressonaríamos": "ressonar",
    "ressonaríeis": "ressonar",
    "ressonas": "ressonar",
    "ressonasse": "ressonar",
    "ressonassem": "ressonar",
    "ressonasses": "ressonar",
    "ressonaste": "ressonar",
    "ressonastes": "ressonar",
    "ressonava": "ressonar",
    "ressonavam": "ressonar",
    "ressonavas": "ressonar",
    "ressone": "ressonar",
    "ressonei": "ressonar",
    "ressoneis": "ressonar",
    "ressonem": "ressonar",
    "ressonemo": "ressonar",
    "ressonemos": "ressonar",
    "ressones": "ressonar",
    "ressono": "ressonar",
    "ressonou": "ressonar",
    "ressoná": "ressonar",
    "ressonámo": "ressonar",
    "ressonámos": "ressonar",
    "ressonáramo": "ressonar",
    "ressonáramos": "ressonar",
    "ressonárei": "ressonar",
    "ressonáreis": "ressonar",
    "ressonásseis": "ressonar",
    "ressonássemos": "ressonar",
    "ressonávamo": "ressonar",
    "ressonávamos": "ressonar",
    "ressonávei": "ressonar",
    "ressonáveis": "ressonar",
    "ressonâncias": "ressonância",
    "ressoo": "ressoar",
    "ressoos": "ressoo",
    "ressoou": "ressoar",
    "ressopra": "ressoprar",
    "ressoprada": "ressoprar",
    "ressopradas": "ressoprar",
    "ressoprado": "ressoprar",
    "ressoprados": "ressoprar",
    "ressoprai": "ressoprar",
    "ressoprais": "ressoprar",
    "ressopram": "ressoprar",
    "ressopramo": "ressoprar",
    "ressopramos": "ressoprar",
    "ressoprando": "ressoprar",
    "ressoprara": "ressoprar",
    "ressopraram": "ressoprar",
    "ressopraras": "ressoprar",
    "ressoprarde": "ressoprar",
    "ressoprardes": "ressoprar",
    "ressoprare": "ressoprar",
    "ressoprarei": "ressoprar",
    "ressoprareis": "ressoprar",
    "ressoprarem": "ressoprar",
    "ressopraremos": "ressoprar",
    "ressoprares": "ressoprar",
    "ressopraria": "ressoprar",
    "ressoprariam": "ressoprar",
    "ressoprarias": "ressoprar",
    "ressoprarmo": "ressoprar",
    "ressoprarmos": "ressoprar",
    "ressoprará": "ressoprar",
    "ressoprarás": "ressoprar",
    "ressoprarão": "ressoprar",
    "ressopraríamos": "ressoprar",
    "ressopraríeis": "ressoprar",
    "ressopras": "ressoprar",
    "ressoprasse": "ressoprar",
    "ressoprassem": "ressoprar",
    "ressoprasses": "ressoprar",
    "ressopraste": "ressoprar",
    "ressoprastes": "ressoprar",
    "ressoprava": "ressoprar",
    "ressopravam": "ressoprar",
    "ressopravas": "ressoprar",
    "ressopre": "ressoprar",
    "ressoprei": "ressoprar",
    "ressopreis": "ressoprar",
    "ressoprem": "ressoprar",
    "ressopremo": "ressoprar",
    "ressopremos": "ressoprar",
    "ressopres": "ressoprar",
    "ressopro": "ressoprar",
    "ressoprou": "ressoprar",
    "ressoprá": "ressoprar",
    "ressoprámo": "ressoprar",
    "ressoprámos": "ressoprar",
    "ressopráramo": "ressoprar",
    "ressopráramos": "ressoprar",
    "ressoprárei": "ressoprar",
    "ressopráreis": "ressoprar",
    "ressoprásseis": "ressoprar",
    "ressoprássemos": "ressoprar",
    "ressoprávamo": "ressoprar",
    "ressoprávamos": "ressoprar",
    "ressoprávei": "ressoprar",
    "ressopráveis": "ressoprar",
    "ressorcinas": "ressorcina",
    "ressorva": "ressorver",
    "ressorvais": "ressorver",
    "ressorvam": "ressorver",
    "ressorvamo": "ressorver",
    "ressorvamos": "ressorver",
    "ressorvas": "ressorver",
    "ressorve": "ressorver",
    "ressorvei": "ressorver",
    "ressorveis": "ressorver",
    "ressorvem": "ressorver",
    "ressorvemo": "ressorver",
    "ressorvemos": "ressorver",
    "ressorvendo": "ressorver",
    "ressorvera": "ressorver",
    "ressorveram": "ressorver",
    "ressorveras": "ressorver",
    "ressorverde": "ressorver",
    "ressorverdes": "ressorver",
    "ressorvere": "ressorver",
    "ressorverei": "ressorver",
    "ressorvereis": "ressorver",
    "ressorverem": "ressorver",
    "ressorveremos": "ressorver",
    "ressorveres": "ressorver",
    "ressorveria": "ressorver",
    "ressorveriam": "ressorver",
    "ressorverias": "ressorver",
    "ressorvermo": "ressorver",
    "ressorvermos": "ressorver",
    "ressorverá": "ressorver",
    "ressorverás": "ressorver",
    "ressorverão": "ressorver",
    "ressorveríamos": "ressorver",
    "ressorveríeis": "ressorver",
    "ressorves": "ressorver",
    "ressorvesse": "ressorver",
    "ressorvessem": "ressorver",
    "ressorvesses": "ressorver",
    "ressorveste": "ressorver",
    "ressorvestes": "ressorver",
    "ressorveu": "ressorver",
    "ressorvi": "ressorver",
    "ressorvia": "ressorver",
    "ressorviam": "ressorver",
    "ressorvias": "ressorver",
    "ressorvida": "ressorver",
    "ressorvidas": "ressorver",
    "ressorvido": "ressorver",
    "ressorvidos": "ressorver",
    "ressorvo": "ressorver",
    "ressorvê": "ressorver",
    "ressorvêramo": "ressorver",
    "ressorvêramos": "ressorver",
    "ressorvêrei": "ressorver",
    "ressorvêreis": "ressorver",
    "ressorvêsseis": "ressorver",
    "ressorvêssemos": "ressorver",
    "ressorvíamo": "ressorver",
    "ressorvíamos": "ressorver",
    "ressorvíei": "ressorver",
    "ressorvíeis": "ressorver",
    "ressorções": "ressorção",
    "ressoube": "ressaber",
    "ressoubemo": "ressaber",
    "ressoubemos": "ressaber",
    "ressouber": "ressaber",
    "ressoubera": "ressaber",
    "ressouberam": "ressaber",
    "ressouberas": "ressaber",
    "ressouberdes": "ressaber",
    "ressouberem": "ressaber",
    "ressouberes": "ressaber",
    "ressoubermos": "ressaber",
    "ressoubesse": "ressaber",
    "ressoubessem": "ressaber",
    "ressoubesses": "ressaber",
    "ressoubeste": "ressaber",
    "ressoubestes": "ressaber",
    "ressoubéramo": "ressaber",
    "ressoubéramos": "ressaber",
    "ressoubérei": "ressaber",
    "ressoubéreis": "ressaber",
    "ressoubésseis": "ressaber",
    "ressoubéssemos": "ressaber",
    "ressoá": "ressoar",
    "ressoámo": "ressoar",
    "ressoámos": "ressoar",
    "ressoáramo": "ressoar",
    "ressoáramos": "ressoar",
    "ressoárei": "ressoar",
    "ressoáreis": "ressoar",
    "ressoásseis": "ressoar",
    "ressoássemos": "ressoar",
    "ressoávamo": "ressoar",
    "ressoávamos": "ressoar",
    "ressoávei": "ressoar",
    "ressoáveis": "ressoar",
    "ressua": "ressuar",
    "ressuada": "ressuar",
    "ressuadas": "ressuar",
    "ressuado": "ressuar",
    "ressuados": "ressuar",
    "ressuai": "ressuar",
    "ressuais": "ressuar",
    "ressuam": "ressuar",
    "ressuamo": "ressuar",
    "ressuamos": "ressuar",
    "ressuando": "ressuar",
    "ressuara": "ressuar",
    "ressuaram": "ressuar",
    "ressuaras": "ressuar",
    "ressuardes": "ressuar",
    "ressuarei": "ressuar",
    "ressuareis": "ressuar",
    "ressuarem": "ressuar",
    "ressuaremos": "ressuar",
    "ressuares": "ressuar",
    "ressuaria": "ressuar",
    "ressuariam": "ressuar",
    "ressuarias": "ressuar",
    "ressuarmo": "ressuar",
    "ressuarmos": "ressuar",
    "ressuará": "ressuar",
    "ressuarás": "ressuar",
    "ressuarão": "ressuar",
    "ressuaríamos": "ressuar",
    "ressuaríeis": "ressuar",
    "ressuas": "ressuar",
    "ressuasse": "ressuar",
    "ressuassem": "ressuar",
    "ressuasses": "ressuar",
    "ressuaste": "ressuar",
    "ressuastes": "ressuar",
    "ressuava": "ressuar",
    "ressuavam": "ressuar",
    "ressuavas": "ressuar",
    "ressuba": "ressubir",
    "ressubais": "ressubir",
    "ressubam": "ressubir",
    "ressubamo": "ressubir",
    "ressubamos": "ressubir",
    "ressubas": "ressubir",
    "ressubi": "ressubir",
    "ressubia": "ressubir",
    "ressubiam": "ressubir",
    "ressubias": "ressubir",
    "ressubida": "ressubir",
    "ressubidas": "ressubir",
    "ressubido": "ressubir",
    "ressubidos": "ressubir",
    "ressubimo": "ressubir",
    "ressubimos": "ressubir",
    "ressubindo": "ressubir",
    "ressubira": "ressubir",
    "ressubiram": "ressubir",
    "ressubiras": "ressubir",
    "ressubirde": "ressubir",
    "ressubirdes": "ressubir",
    "ressubire": "ressubir",
    "ressubirei": "ressubir",
    "ressubireis": "ressubir",
    "ressubirem": "ressubir",
    "ressubiremos": "ressubir",
    "ressubires": "ressubir",
    "ressubiria": "ressubir",
    "ressubiriam": "ressubir",
    "ressubirias": "ressubir",
    "ressubirmo": "ressubir",
    "ressubirmos": "ressubir",
    "ressubirá": "ressubir",
    "ressubirás": "ressubir",
    "ressubirão": "ressubir",
    "ressubiríamos": "ressubir",
    "ressubiríeis": "ressubir",
    "ressubis": "ressubir",
    "ressubisse": "ressubir",
    "ressubissem": "ressubir",
    "ressubisses": "ressubir",
    "ressubiste": "ressubir",
    "ressubistes": "ressubir",
    "ressubiu": "ressubir",
    "ressubo": "ressubir",
    "ressubíamo": "ressubir",
    "ressubíamos": "ressubir",
    "ressubíei": "ressubir",
    "ressubíeis": "ressubir",
    "ressubíramo": "ressubir",
    "ressubíramos": "ressubir",
    "ressubírei": "ressubir",
    "ressubíreis": "ressubir",
    "ressubísseis": "ressubir",
    "ressubíssemos": "ressubir",
    "ressuda": "ressudar",
    "ressudada": "ressudar",
    "ressudadas": "ressudar",
    "ressudado": "ressudar",
    "ressudados": "ressudar",
    "ressudai": "ressudar",
    "ressudais": "ressudar",
    "ressudam": "ressudar",
    "ressudamo": "ressudar",
    "ressudamos": "ressudar",
    "ressudando": "ressudar",
    "ressudara": "ressudar",
    "ressudaram": "ressudar",
    "ressudaras": "ressudar",
    "ressudarde": "ressudar",
    "ressudardes": "ressudar",
    "ressudare": "ressudar",
    "ressudarei": "ressudar",
    "ressudareis": "ressudar",
    "ressudarem": "ressudar",
    "ressudaremos": "ressudar",
    "ressudares": "ressudar",
    "ressudaria": "ressudar",
    "ressudariam": "ressudar",
    "ressudarias": "ressudar",
    "ressudarmo": "ressudar",
    "ressudarmos": "ressudar",
    "ressudará": "ressudar",
    "ressudarás": "ressudar",
    "ressudarão": "ressudar",
    "ressudaríamos": "ressudar",
    "ressudaríeis": "ressudar",
    "ressudas": "ressudar",
    "ressudasse": "ressudar",
    "ressudassem": "ressudar",
    "ressudasses": "ressudar",
    "ressudaste": "ressudar",
    "ressudastes": "ressudar",
    "ressudava": "ressudar",
    "ressudavam": "ressudar",
    "ressudavas": "ressudar",
    "ressudações": "ressudação",
    "ressude": "ressudar",
    "ressudei": "ressudar",
    "ressudeis": "ressudar",
    "ressudem": "ressudar",
    "ressudemo": "ressudar",
    "ressudemos": "ressudar",
    "ressudes": "ressudar",
    "ressudo": "ressudar",
    "ressudou": "ressudar",
    "ressudá": "ressudar",
    "ressudámo": "ressudar",
    "ressudámos": "ressudar",
    "ressudáramo": "ressudar",
    "ressudáramos": "ressudar",
    "ressudárei": "ressudar",
    "ressudáreis": "ressudar",
    "ressudásseis": "ressudar",
    "ressudássemos": "ressudar",
    "ressudávamo": "ressudar",
    "ressudávamos": "ressudar",
    "ressudávei": "ressudar",
    "ressudáveis": "ressudar",
    "ressue": "ressuar",
    "ressuei": "ressuar",
    "ressueis": "ressuar",
    "ressuem": "ressuar",
    "ressuemo": "ressuar",
    "ressuemos": "ressuar",
    "ressues": "ressuar",
    "ressulca": "ressulcar",
    "ressulcada": "ressulcar",
    "ressulcadas": "ressulcar",
    "ressulcado": "ressulcar",
    "ressulcados": "ressulcar",
    "ressulcai": "ressulcar",
    "ressulcais": "ressulcar",
    "ressulcam": "ressulcar",
    "ressulcamo": "ressulcar",
    "ressulcamos": "ressulcar",
    "ressulcando": "ressulcar",
    "ressulcara": "ressulcar",
    "ressulcaram": "ressulcar",
    "ressulcaras": "ressulcar",
    "ressulcarde": "ressulcar",
    "ressulcardes": "ressulcar",
    "ressulcare": "ressulcar",
    "ressulcarei": "ressulcar",
    "ressulcareis": "ressulcar",
    "ressulcarem": "ressulcar",
    "ressulcaremos": "ressulcar",
    "ressulcares": "ressulcar",
    "ressulcaria": "ressulcar",
    "ressulcariam": "ressulcar",
    "ressulcarias": "ressulcar",
    "ressulcarmo": "ressulcar",
    "ressulcarmos": "ressulcar",
    "ressulcará": "ressulcar",
    "ressulcarás": "ressulcar",
    "ressulcarão": "ressulcar",
    "ressulcaríamos": "ressulcar",
    "ressulcaríeis": "ressulcar",
    "ressulcas": "ressulcar",
    "ressulcasse": "ressulcar",
    "ressulcassem": "ressulcar",
    "ressulcasses": "ressulcar",
    "ressulcaste": "ressulcar",
    "ressulcastes": "ressulcar",
    "ressulcava": "ressulcar",
    "ressulcavam": "ressulcar",
    "ressulcavas": "ressulcar",
    "ressulco": "ressulcar",
    "ressulcou": "ressulcar",
    "ressulcá": "ressulcar",
    "ressulcámo": "ressulcar",
    "ressulcámos": "ressulcar",
    "ressulcáramo": "ressulcar",
    "ressulcáramos": "ressulcar",
    "ressulcárei": "ressulcar",
    "ressulcáreis": "ressulcar",
    "ressulcásseis": "ressulcar",
    "ressulcássemos": "ressulcar",
    "ressulcávamo": "ressulcar",
    "ressulcávamos": "ressulcar",
    "ressulcávei": "ressulcar",
    "ressulcáveis": "ressulcar",
    "ressulque": "ressulcar",
    "ressulquei": "ressulcar",
    "ressulqueis": "ressulcar",
    "ressulquem": "ressulcar",
    "ressulquemo": "ressulcar",
    "ressulquemos": "ressulcar",
    "ressulques": "ressulcar",
    "ressuma": "ressumar",
    "ressumada": "ressumar",
    "ressumadas": "ressumar",
    "ressumado": "ressumar",
    "ressumados": "ressumar",
    "ressumai": "ressumar",
    "ressumais": "ressumar",
    "ressumam": "ressumar",
    "ressumamo": "ressumar",
    "ressumamos": "ressumar",
    "ressumando": "ressumar",
    "ressumara": "ressumar",
    "ressumaram": "ressumar",
    "ressumaras": "ressumar",
    "ressumardes": "ressumar",
    "ressumarei": "ressumar",
    "ressumareis": "ressumar",
    "ressumarem": "ressumar",
    "ressumaremos": "ressumar",
    "ressumares": "ressumar",
    "ressumaria": "ressumar",
    "ressumariam": "ressumar",
    "ressumarias": "ressumar",
    "ressumarmo": "ressumar",
    "ressumarmos": "ressumar",
    "ressumará": "ressumar",
    "ressumarás": "ressumar",
    "ressumarão": "ressumar",
    "ressumaríamos": "ressumar",
    "ressumaríeis": "ressumar",
    "ressumas": "ressumar",
    "ressumasse": "ressumar",
    "ressumassem": "ressumar",
    "ressumasses": "ressumar",
    "ressumaste": "ressumar",
    "ressumastes": "ressumar",
    "ressumava": "ressumar",
    "ressumavam": "ressumar",
    "ressumavas": "ressumar",
    "ressumações": "ressumação",
    "ressumbra": "ressumbrar",
    "ressumbrada": "ressumbrar",
    "ressumbradas": "ressumbrar",
    "ressumbrado": "ressumbrar",
    "ressumbrados": "ressumbrar",
    "ressumbrai": "ressumbrar",
    "ressumbrais": "ressumbrar",
    "ressumbram": "ressumbrar",
    "ressumbramo": "ressumbrar",
    "ressumbramos": "ressumbrar",
    "ressumbrando": "ressumbrar",
    "ressumbrantes": "ressumbrante",
    "ressumbrara": "ressumbrar",
    "ressumbraram": "ressumbrar",
    "ressumbraras": "ressumbrar",
    "ressumbrarde": "ressumbrar",
    "ressumbrardes": "ressumbrar",
    "ressumbrare": "ressumbrar",
    "ressumbrarei": "ressumbrar",
    "ressumbrareis": "ressumbrar",
    "ressumbrarem": "ressumbrar",
    "ressumbraremos": "ressumbrar",
    "ressumbrares": "ressumbrar",
    "ressumbraria": "ressumbrar",
    "ressumbrariam": "ressumbrar",
    "ressumbrarias": "ressumbrar",
    "ressumbrarmo": "ressumbrar",
    "ressumbrarmos": "ressumbrar",
    "ressumbrará": "ressumbrar",
    "ressumbrarás": "ressumbrar",
    "ressumbrarão": "ressumbrar",
    "ressumbraríamos": "ressumbrar",
    "ressumbraríeis": "ressumbrar",
    "ressumbras": "ressumbrar",
    "ressumbrasse": "ressumbrar",
    "ressumbrassem": "ressumbrar",
    "ressumbrasses": "ressumbrar",
    "ressumbraste": "ressumbrar",
    "ressumbrastes": "ressumbrar",
    "ressumbrava": "ressumbrar",
    "ressumbravam": "ressumbrar",
    "ressumbravas": "ressumbrar",
    "ressumbre": "ressumbrar",
    "ressumbrei": "ressumbrar",
    "ressumbreis": "ressumbrar",
    "ressumbrem": "ressumbrar",
    "ressumbremo": "ressumbrar",
    "ressumbremos": "ressumbrar",
    "ressumbres": "ressumbrar",
    "ressumbro": "ressumbrar",
    "ressumbros": "ressumbro",
    "ressumbrou": "ressumbrar",
    "ressumbrá": "ressumbrar",
    "ressumbrámo": "ressumbrar",
    "ressumbrámos": "ressumbrar",
    "ressumbráramo": "ressumbrar",
    "ressumbráramos": "ressumbrar",
    "ressumbrárei": "ressumbrar",
    "ressumbráreis": "ressumbrar",
    "ressumbrásseis": "ressumbrar",
    "ressumbrássemos": "ressumbrar",
    "ressumbrávamo": "ressumbrar",
    "ressumbrávamos": "ressumbrar",
    "ressumbrávei": "ressumbrar",
    "ressumbráveis": "ressumbrar",
    "ressume": "ressumar",
    "ressumei": "ressumar",
    "ressumeis": "ressumar",
    "ressumem": "ressumar",
    "ressumemo": "ressumar",
    "ressumemos": "ressumar",
    "ressumes": "ressumar",
    "ressumo": "ressumar",
    "ressumou": "ressumar",
    "ressumámo": "ressumar",
    "ressumámos": "ressumar",
    "ressumáramo": "ressumar",
    "ressumáramos": "ressumar",
    "ressumáreis": "ressumar",
    "ressumásseis": "ressumar",
    "ressumássemos": "ressumar",
    "ressumávamo": "ressumar",
    "ressumávamos": "ressumar",
    "ressumáveis": "ressumar",
    "ressunções": "ressunção",
    "ressuo": "ressuar",
    "ressuou": "ressuar",
    "ressupina": "ressupino",
    "ressupinada": "ressupinar",
    "ressupinadas": "ressupinar",
    "ressupinado": "ressupinar",
    "ressupinados": "ressupinar",
    "ressupinai": "ressupinar",
    "ressupinais": "ressupinar",
    "ressupinam": "ressupinar",
    "ressupinamo": "ressupinar",
    "ressupinamos": "ressupinar",
    "ressupinando": "ressupinar",
    "ressupinara": "ressupinar",
    "ressupinaram": "ressupinar",
    "ressupinaras": "ressupinar",
    "ressupinarde": "ressupinar",
    "ressupinardes": "ressupinar",
    "ressupinare": "ressupinar",
    "ressupinarei": "ressupinar",
    "ressupinareis": "ressupinar",
    "ressupinarem": "ressupinar",
    "ressupinaremos": "ressupinar",
    "ressupinares": "ressupinar",
    "ressupinaria": "ressupinar",
    "ressupinariam": "ressupinar",
    "ressupinarias": "ressupinar",
    "ressupinarmo": "ressupinar",
    "ressupinarmos": "ressupinar",
    "ressupinará": "ressupinar",
    "ressupinarás": "ressupinar",
    "ressupinarão": "ressupinar",
    "ressupinaríamos": "ressupinar",
    "ressupinaríeis": "ressupinar",
    "ressupinas": "ressupino",
    "ressupinasse": "ressupinar",
    "ressupinassem": "ressupinar",
    "ressupinasses": "ressupinar",
    "ressupinaste": "ressupinar",
    "ressupinastes": "ressupinar",
    "ressupinava": "ressupinar",
    "ressupinavam": "ressupinar",
    "ressupinavas": "ressupinar",
    "ressupinações": "ressupinação",
    "ressupine": "ressupinar",
    "ressupinei": "ressupinar",
    "ressupineis": "ressupinar",
    "ressupinem": "ressupinar",
    "ressupinemo": "ressupinar",
    "ressupinemos": "ressupinar",
    "ressupines": "ressupinar",
    "ressupino": "ressupinar",
    "ressupinos": "ressupino",
    "ressupinou": "ressupinar",
    "ressupiná": "ressupinar",
    "ressupinámo": "ressupinar",
    "ressupinámos": "ressupinar",
    "ressupináramo": "ressupinar",
    "ressupináramos": "ressupinar",
    "ressupinárei": "ressupinar",
    "ressupináreis": "ressupinar",
    "ressupinásseis": "ressupinar",
    "ressupinássemos": "ressupinar",
    "ressupinávamo": "ressupinar",
    "ressupinávamos": "ressupinar",
    "ressupinávei": "ressupinar",
    "ressupináveis": "ressupinar",
    "ressurecta": "ressurecto",
    "ressurectas": "ressurecto",
    "ressurectos": "ressurecto",
    "ressurge": "ressurgir",
    "ressurgem": "ressurgir",
    "ressurgentes": "ressurgente",
    "ressurges": "ressurgir",
    "ressurgi": "ressurgir",
    "ressurgia": "ressurgir",
    "ressurgiam": "ressurgir",
    "ressurgias": "ressurgir",
    "ressurgida": "ressurgir",
    "ressurgidas": "ressurgir",
    "ressurgido": "ressurgir",
    "ressurgidos": "ressurgir",
    "ressurgimentos": "ressurgimento",
    "ressurgimo": "ressurgir",
    "ressurgimos": "ressurgir",
    "ressurgindo": "ressurgir",
    "ressurgira": "ressurgir",
    "ressurgiram": "ressurgir",
    "ressurgiras": "ressurgir",
    "ressurgirdes": "ressurgir",
    "ressurgirei": "ressurgir",
    "ressurgireis": "ressurgir",
    "ressurgirem": "ressurgir",
    "ressurgiremos": "ressurgir",
    "ressurgires": "ressurgir",
    "ressurgiria": "ressurgir",
    "ressurgiriam": "ressurgir",
    "ressurgirias": "ressurgir",
    "ressurgirmo": "ressurgir",
    "ressurgirmos": "ressurgir",
    "ressurgirá": "ressurgir",
    "ressurgirás": "ressurgir",
    "ressurgirão": "ressurgir",
    "ressurgiríamos": "ressurgir",
    "ressurgiríeis": "ressurgir",
    "ressurgis": "ressurgir",
    "ressurgisse": "ressurgir",
    "ressurgissem": "ressurgir",
    "ressurgisses": "ressurgir",
    "ressurgiste": "ressurgir",
    "ressurgistes": "ressurgir",
    "ressurgiu": "ressurgir",
    "ressurgências": "ressurgência",
    "ressurgíamo": "ressurgir",
    "ressurgíamos": "ressurgir",
    "ressurgíeis": "ressurgir",
    "ressurgíramo": "ressurgir",
    "ressurgíramos": "ressurgir",
    "ressurgíreis": "ressurgir",
    "ressurgísseis": "ressurgir",
    "ressurgíssemos": "ressurgir",
    "ressurja": "ressurgir",
    "ressurjais": "ressurgir",
    "ressurjam": "ressurgir",
    "ressurjamo": "ressurgir",
    "ressurjamos": "ressurgir",
    "ressurjas": "ressurgir",
    "ressurjo": "ressurgir",
    "ressurreccionais": "ressurreccional",
    "ressurreições": "ressurreição",
    "ressurta": "ressurtir",
    "ressurtais": "ressurtir",
    "ressurtam": "ressurtir",
    "ressurtamo": "ressurtir",
    "ressurtamos": "ressurtir",
    "ressurtas": "ressurtir",
    "ressurte": "ressurtir",
    "ressurtem": "ressurtir",
    "ressurtes": "ressurtir",
    "ressurti": "ressurtir",
    "ressurtia": "ressurtir",
    "ressurtiam": "ressurtir",
    "ressurtias": "ressurtir",
    "ressurtida": "ressurtir",
    "ressurtidas": "ressurtir",
    "ressurtido": "ressurtir",
    "ressurtidos": "ressurtir",
    "ressurtimo": "ressurtir",
    "ressurtimos": "ressurtir",
    "ressurtindo": "ressurtir",
    "ressurtira": "ressurtir",
    "ressurtiram": "ressurtir",
    "ressurtiras": "ressurtir",
    "ressurtirdes": "ressurtir",
    "ressurtirei": "ressurtir",
    "ressurtireis": "ressurtir",
    "ressurtirem": "ressurtir",
    "ressurtiremos": "ressurtir",
    "ressurtires": "ressurtir",
    "ressurtiria": "ressurtir",
    "ressurtiriam": "ressurtir",
    "ressurtirias": "ressurtir",
    "ressurtirmo": "ressurtir",
    "ressurtirmos": "ressurtir",
    "ressurtirá": "ressurtir",
    "ressurtirás": "ressurtir",
    "ressurtirão": "ressurtir",
    "ressurtiríamos": "ressurtir",
    "ressurtiríeis": "ressurtir",
    "ressurtis": "ressurtir",
    "ressurtisse": "ressurtir",
    "ressurtissem": "ressurtir",
    "ressurtisses": "ressurtir",
    "ressurtiste": "ressurtir",
    "ressurtistes": "ressurtir",
    "ressurtiu": "ressurtir",
    "ressurto": "ressurtir",
    "ressurtíamo": "ressurtir",
    "ressurtíamos": "ressurtir",
    "ressurtíeis": "ressurtir",
    "ressurtíramo": "ressurtir",
    "ressurtíramos": "ressurtir",
    "ressurtíreis": "ressurtir",
    "ressurtísseis": "ressurtir",
    "ressurtíssemos": "ressurtir",
    "ressuscita": "ressuscitar",
    "ressuscitada": "ressuscitar",
    "ressuscitadas": "ressuscitar",
    "ressuscitadinha": "ressuscitado",
    "ressuscitadinhas": "ressuscitado",
    "ressuscitadinho": "ressuscitado",
    "ressuscitadinhos": "ressuscitado",
    "ressuscitadita": "ressuscitado",
    "ressuscitaditas": "ressuscitado",
    "ressuscitadito": "ressuscitado",
    "ressuscitaditos": "ressuscitado",
    "ressuscitado": "ressuscitar",
    "ressuscitadora": "ressuscitador",
    "ressuscitadoras": "ressuscitador",
    "ressuscitadores": "ressuscitador",
    "ressuscitados": "ressuscitar",
    "ressuscitadíssima": "ressuscitado",
    "ressuscitadíssimas": "ressuscitado",
    "ressuscitadíssimo": "ressuscitado",
    "ressuscitadíssimos": "ressuscitado",
    "ressuscitai": "ressuscitar",
    "ressuscitais": "ressuscitar",
    "ressuscitam": "ressuscitar",
    "ressuscitamo": "ressuscitar",
    "ressuscitamos": "ressuscitar",
    "ressuscitando": "ressuscitar",
    "ressuscitara": "ressuscitar",
    "ressuscitaram": "ressuscitar",
    "ressuscitaras": "ressuscitar",
    "ressuscitarde": "ressuscitar",
    "ressuscitardes": "ressuscitar",
    "ressuscitare": "ressuscitar",
    "ressuscitarei": "ressuscitar",
    "ressuscitareis": "ressuscitar",
    "ressuscitarem": "ressuscitar",
    "ressuscitaremos": "ressuscitar",
    "ressuscitares": "ressuscitar",
    "ressuscitaria": "ressuscitar",
    "ressuscitariam": "ressuscitar",
    "ressuscitarias": "ressuscitar",
    "ressuscitarmo": "ressuscitar",
    "ressuscitarmos": "ressuscitar",
    "ressuscitará": "ressuscitar",
    "ressuscitarás": "ressuscitar",
    "ressuscitarão": "ressuscitar",
    "ressuscitaríamos": "ressuscitar",
    "ressuscitaríeis": "ressuscitar",
    "ressuscitas": "ressuscitar",
    "ressuscitasse": "ressuscitar",
    "ressuscitassem": "ressuscitar",
    "ressuscitasses": "ressuscitar",
    "ressuscitaste": "ressuscitar",
    "ressuscitastes": "ressuscitar",
    "ressuscitava": "ressuscitar",
    "ressuscitavam": "ressuscitar",
    "ressuscitavas": "ressuscitar",
    "ressuscitações": "ressuscitação",
    "ressuscite": "ressuscitar",
    "ressuscitei": "ressuscitar",
    "ressusciteis": "ressuscitar",
    "ressuscitem": "ressuscitar",
    "ressuscitemo": "ressuscitar",
    "ressuscitemos": "ressuscitar",
    "ressuscites": "ressuscitar",
    "ressuscito": "ressuscitar",
    "ressuscitou": "ressuscitar",
    "ressuscitá": "ressuscitar",
    "ressuscitámo": "ressuscitar",
    "ressuscitámos": "ressuscitar",
    "ressuscitáramo": "ressuscitar",
    "ressuscitáramos": "ressuscitar",
    "ressuscitárei": "ressuscitar",
    "ressuscitáreis": "ressuscitar",
    "ressuscitásseis": "ressuscitar",
    "ressuscitássemos": "ressuscitar",
    "ressuscitávamo": "ressuscitar",
    "ressuscitávamos": "ressuscitar",
    "ressuscitávei": "ressuscitar",
    "ressuscitáveis": "ressuscitável",
    "ressuámo": "ressuar",
    "ressuámos": "ressuar",
    "ressuáramo": "ressuar",
    "ressuáramos": "ressuar",
    "ressuáreis": "ressuar",
    "ressuásseis": "ressuar",
    "ressuássemos": "ressuar",
    "ressuávamo": "ressuar",
    "ressuávamos": "ressuar",
    "ressuáveis": "ressuar",
    "ressábios": "ressábio",
    "ressôos": "ressôo",
    "resta": "restar",
    "restabelece": "restabelecer",
    "restabelecei": "restabelecer",
    "restabeleceis": "restabelecer",
    "restabelecem": "restabelecer",
    "restabelecemo": "restabelecer",
    "restabelecemos": "restabelecer",
    "restabelecendo": "restabelecer",
    "restabelecera": "restabelecer",
    "restabeleceram": "restabelecer",
    "restabeleceras": "restabelecer",
    "restabelecerde": "restabelecer",
    "restabelecerdes": "restabelecer",
    "restabelecere": "restabelecer",
    "restabelecerei": "restabelecer",
    "restabelecereis": "restabelecer",
    "restabelecerem": "restabelecer",
    "restabeleceremos": "restabelecer",
    "restabeleceres": "restabelecer",
    "restabeleceria": "restabelecer",
    "restabeleceriam": "restabelecer",
    "restabelecerias": "restabelecer",
    "restabelecermo": "restabelecer",
    "restabelecermos": "restabelecer",
    "restabelecerá": "restabelecer",
    "restabelecerás": "restabelecer",
    "restabelecerão": "restabelecer",
    "restabeleceríamos": "restabelecer",
    "restabeleceríeis": "restabelecer",
    "restabeleces": "restabelecer",
    "restabelecesse": "restabelecer",
    "restabelecessem": "restabelecer",
    "restabelecesses": "restabelecer",
    "restabeleceste": "restabelecer",
    "restabelecestes": "restabelecer",
    "restabeleceu": "restabelecer",
    "restabeleci": "restabelecer",
    "restabelecia": "restabelecer",
    "restabeleciam": "restabelecer",
    "restabelecias": "restabelecer",
    "restabelecida": "restabelecido",
    "restabelecidas": "restabelecido",
    "restabelecido": "restabelecer",
    "restabelecidos": "restabelecido",
    "restabelecimentos": "restabelecimento",
    "restabelecê": "restabelecer",
    "restabelecêramo": "restabelecer",
    "restabelecêramos": "restabelecer",
    "restabelecêrei": "restabelecer",
    "restabelecêreis": "restabelecer",
    "restabelecêsseis": "restabelecer",
    "restabelecêssemos": "restabelecer",
    "restabelecíamo": "restabelecer",
    "restabelecíamos": "restabelecer",
    "restabelecíei": "restabelecer",
    "restabelecíeis": "restabelecer",
    "restabeleça": "restabelecer",
    "restabeleçais": "restabelecer",
    "restabeleçam": "restabelecer",
    "restabeleçamo": "restabelecer",
    "restabeleçamos": "restabelecer",
    "restabeleças": "restabelecer",
    "restabeleço": "restabelecer",
    "restada": "restar",
    "restadas": "restar",
    "restado": "restar",
    "restados": "restar",
    "restagnações": "restagnação",
    "restai": "restar",
    "restais": "restar",
    "restaleja": "restalejar",
    "restalejada": "restalejar",
    "restalejadas": "restalejar",
    "restalejado": "restalejar",
    "restalejados": "restalejar",
    "restalejai": "restalejar",
    "restalejais": "restalejar",
    "restalejam": "restalejar",
    "restalejamo": "restalejar",
    "restalejamos": "restalejar",
    "restalejando": "restalejar",
    "restalejara": "restalejar",
    "restalejaram": "restalejar",
    "restalejaras": "restalejar",
    "restalejarde": "restalejar",
    "restalejardes": "restalejar",
    "restalejare": "restalejar",
    "restalejarei": "restalejar",
    "restalejareis": "restalejar",
    "restalejarem": "restalejar",
    "restalejaremos": "restalejar",
    "restalejares": "restalejar",
    "restalejaria": "restalejar",
    "restalejariam": "restalejar",
    "restalejarias": "restalejar",
    "restalejarmo": "restalejar",
    "restalejarmos": "restalejar",
    "restalejará": "restalejar",
    "restalejarás": "restalejar",
    "restalejarão": "restalejar",
    "restalejaríamos": "restalejar",
    "restalejaríeis": "restalejar",
    "restalejas": "restalejar",
    "restalejasse": "restalejar",
    "restalejassem": "restalejar",
    "restalejasses": "restalejar",
    "restalejaste": "restalejar",
    "restalejastes": "restalejar",
    "restalejava": "restalejar",
    "restalejavam": "restalejar",
    "restalejavas": "restalejar",
    "restaleje": "restalejar",
    "restalejei": "restalejar",
    "restalejeis": "restalejar",
    "restalejem": "restalejar",
    "restalejemo": "restalejar",
    "restalejemos": "restalejar",
    "restalejes": "restalejar",
    "restalejo": "restalejar",
    "restalejou": "restalejar",
    "restalejá": "restalejar",
    "restalejámo": "restalejar",
    "restalejámos": "restalejar",
    "restalejáramo": "restalejar",
    "restalejáramos": "restalejar",
    "restalejárei": "restalejar",
    "restalejáreis": "restalejar",
    "restalejásseis": "restalejar",
    "restalejássemos": "restalejar",
    "restalejávamo": "restalejar",
    "restalejávamos": "restalejar",
    "restalejávei": "restalejar",
    "restalejáveis": "restalejar",
    "restam": "restar",
    "restamo": "restar",
    "restamos": "restar",
    "restampa": "restampar",
    "restampada": "restampar",
    "restampadas": "restampar",
    "restampado": "restampar",
    "restampados": "restampar",
    "restampai": "restampar",
    "restampais": "restampar",
    "restampam": "restampar",
    "restampamo": "restampar",
    "restampamos": "restampar",
    "restampando": "restampar",
    "restampara": "restampar",
    "restamparam": "restampar",
    "restamparas": "restampar",
    "restamparde": "restampar",
    "restampardes": "restampar",
    "restampare": "restampar",
    "restamparei": "restampar",
    "restampareis": "restampar",
    "restamparem": "restampar",
    "restamparemos": "restampar",
    "restampares": "restampar",
    "restamparia": "restampar",
    "restampariam": "restampar",
    "restamparias": "restampar",
    "restamparmo": "restampar",
    "restamparmos": "restampar",
    "restampará": "restampar",
    "restamparás": "restampar",
    "restamparão": "restampar",
    "restamparíamos": "restampar",
    "restamparíeis": "restampar",
    "restampas": "restampar",
    "restampasse": "restampar",
    "restampassem": "restampar",
    "restampasses": "restampar",
    "restampaste": "restampar",
    "restampastes": "restampar",
    "restampava": "restampar",
    "restampavam": "restampar",
    "restampavas": "restampar",
    "restampe": "restampar",
    "restampei": "restampar",
    "restampeis": "restampar",
    "restampem": "restampar",
    "restampemo": "restampar",
    "restampemos": "restampar",
    "restampes": "restampar",
    "restampo": "restampar",
    "restampou": "restampar",
    "restampá": "restampar",
    "restampámo": "restampar",
    "restampámos": "restampar",
    "restampáramo": "restampar",
    "restampáramos": "restampar",
    "restampárei": "restampar",
    "restampáreis": "restampar",
    "restampásseis": "restampar",
    "restampássemos": "restampar",
    "restampávamo": "restampar",
    "restampávamos": "restampar",
    "restampávei": "restampar",
    "restampáveis": "restampar",
    "restando": "restar",
    "restantes": "restante",
    "restara": "restar",
    "restaram": "restar",
    "restaras": "restar",
    "restardes": "restar",
    "restarei": "restar",
    "restareis": "restar",
    "restarem": "restar",
    "restaremos": "restar",
    "restares": "restar",
    "restaria": "restar",
    "restariam": "restar",
    "restarias": "restar",
    "restarmo": "restar",
    "restarmos": "restar",
    "restará": "restar",
    "restarás": "restar",
    "restarão": "restar",
    "restaríamos": "restar",
    "restaríeis": "restar",
    "restas": "restar",
    "restasse": "restar",
    "restassem": "restar",
    "restasses": "restar",
    "restaste": "restar",
    "restastes": "restar",
    "restaura": "restaurar",
    "restaurada": "restaurar",
    "restauradas": "restaurar",
    "restaurado": "restaurar",
    "restauradora": "restaurador",
    "restauradoras": "restaurador",
    "restauradores": "restaurador",
    "restaurados": "restaurar",
    "restaurai": "restaurar",
    "restaurais": "restaurar",
    "restauram": "restaurar",
    "restauramo": "restaurar",
    "restauramos": "restaurar",
    "restaurando": "restaurar",
    "restaurantes": "restaurante",
    "restaurara": "restaurar",
    "restauraram": "restaurar",
    "restauraras": "restaurar",
    "restaurarde": "restaurar",
    "restaurardes": "restaurar",
    "restaurare": "restaurar",
    "restaurarei": "restaurar",
    "restaurareis": "restaurar",
    "restaurarem": "restaurar",
    "restauraremos": "restaurar",
    "restaurares": "restaurar",
    "restauraria": "restaurar",
    "restaurariam": "restaurar",
    "restaurarias": "restaurar",
    "restaurarmo": "restaurar",
    "restaurarmos": "restaurar",
    "restaurará": "restaurar",
    "restaurarás": "restaurar",
    "restaurarão": "restaurar",
    "restauraríamos": "restaurar",
    "restauraríeis": "restaurar",
    "restauras": "restaurar",
    "restaurasse": "restaurar",
    "restaurassem": "restaurar",
    "restaurasses": "restaurar",
    "restauraste": "restaurar",
    "restaurastes": "restaurar",
    "restaurativa": "restaurativo",
    "restaurativas": "restaurativo",
    "restaurativos": "restaurativo",
    "restaurava": "restaurar",
    "restauravam": "restaurar",
    "restauravas": "restaurar",
    "restaurações": "restauração",
    "restaure": "restaurar",
    "restaurei": "restaurar",
    "restaureis": "restaurar",
    "restaurem": "restaurar",
    "restauremo": "restaurar",
    "restauremos": "restaurar",
    "restaures": "restaurar",
    "restauro": "restaurar",
    "restauros": "restauro",
    "restaurou": "restaurar",
    "restaurá": "restaurar",
    "restaurámo": "restaurar",
    "restaurámos": "restaurar",
    "restauráramo": "restaurar",
    "restauráramos": "restaurar",
    "restaurárei": "restaurar",
    "restauráreis": "restaurar",
    "restaurásseis": "restaurar",
    "restaurássemos": "restaurar",
    "restaurávamo": "restaurar",
    "restaurávamos": "restaurar",
    "restaurávei": "restaurar",
    "restauráveis": "restaurável",
    "restava": "restar",
    "restavam": "restar",
    "restavas": "restar",
    "reste": "restar",
    "restei": "restar",
    "resteis": "restar",
    "restela": "restelar",
    "restelada": "restelar",
    "resteladas": "restelar",
    "restelado": "restelar",
    "restelados": "restelar",
    "restelai": "restelar",
    "restelais": "restelar",
    "restelam": "restelar",
    "restelamo": "restelar",
    "restelamos": "restelar",
    "restelando": "restelar",
    "restelara": "restelar",
    "restelaram": "restelar",
    "restelaras": "restelar",
    "restelarde": "restelar",
    "restelardes": "restelar",
    "restelare": "restelar",
    "restelarei": "restelar",
    "restelareis": "restelar",
    "restelarem": "restelar",
    "restelaremos": "restelar",
    "restelares": "restelar",
    "restelaria": "restelar",
    "restelariam": "restelar",
    "restelarias": "restelar",
    "restelarmo": "restelar",
    "restelarmos": "restelar",
    "restelará": "restelar",
    "restelarás": "restelar",
    "restelarão": "restelar",
    "restelaríamos": "restelar",
    "restelaríeis": "restelar",
    "restelas": "restelar",
    "restelasse": "restelar",
    "restelassem": "restelar",
    "restelasses": "restelar",
    "restelaste": "restelar",
    "restelastes": "restelar",
    "restelava": "restelar",
    "restelavam": "restelar",
    "restelavas": "restelar",
    "restele": "restelar",
    "restelei": "restelar",
    "resteleis": "restelar",
    "restelem": "restelar",
    "restelemo": "restelar",
    "restelemos": "restelar",
    "resteles": "restelar",
    "restelo": "restelar",
    "restelos": "restelo",
    "restelou": "restelar",
    "restelá": "restelar",
    "restelámo": "restelar",
    "restelámos": "restelar",
    "resteláramo": "restelar",
    "resteláramos": "restelar",
    "restelárei": "restelar",
    "resteláreis": "restelar",
    "restelásseis": "restelar",
    "restelássemos": "restelar",
    "restelávamo": "restelar",
    "restelávamos": "restelar",
    "restelávei": "restelar",
    "resteláveis": "restelar",
    "restem": "restar",
    "restemo": "restar",
    "restemos": "restar",
    "restes": "reste",
    "restevas": "resteva",
    "restiformes": "restiforme",
    "restila": "restilar",
    "restilada": "restilar",
    "restiladas": "restilar",
    "restilado": "restilar",
    "restilados": "restilar",
    "restilai": "restilar",
    "restilais": "restilar",
    "restilam": "restilar",
    "restilamo": "restilar",
    "restilamos": "restilar",
    "restilando": "restilar",
    "restilara": "restilar",
    "restilaram": "restilar",
    "restilaras": "restilar",
    "restilarde": "restilar",
    "restilardes": "restilar",
    "restilare": "restilar",
    "restilarei": "restilar",
    "restilareis": "restilar",
    "restilarem": "restilar",
    "restilaremos": "restilar",
    "restilares": "restilar",
    "restilaria": "restilar",
    "restilariam": "restilar",
    "restilarias": "restilar",
    "restilarmo": "restilar",
    "restilarmos": "restilar",
    "restilará": "restilar",
    "restilarás": "restilar",
    "restilarão": "restilar",
    "restilaríamos": "restilar",
    "restilaríeis": "restilar",
    "restilas": "restilar",
    "restilasse": "restilar",
    "restilassem": "restilar",
    "restilasses": "restilar",
    "restilaste": "restilar",
    "restilastes": "restilar",
    "restilava": "restilar",
    "restilavam": "restilar",
    "restilavas": "restilar",
    "restilações": "restilação",
    "restile": "restilar",
    "restilei": "restilar",
    "restileis": "restilar",
    "restilem": "restilar",
    "restilemo": "restilar",
    "restilemos": "restilar",
    "restiles": "restilar",
    "restilo": "restilar",
    "restilos": "restilo",
    "restilou": "restilar",
    "restilá": "restilar",
    "restilámo": "restilar",
    "restilámos": "restilar",
    "restiláramo": "restilar",
    "restiláramos": "restilar",
    "restilárei": "restilar",
    "restiláreis": "restilar",
    "restilásseis": "restilar",
    "restilássemos": "restilar",
    "restilávamo": "restilar",
    "restilávamos": "restilar",
    "restilávei": "restilar",
    "restiláveis": "restilar",
    "restinga": "restinguir",
    "restingais": "restinguir",
    "restingam": "restinguir",
    "restingamo": "restinguir",
    "restingamos": "restinguir",
    "restingas": "restinguir",
    "restingo": "restinguir",
    "restingue": "restinguir",
    "restinguem": "restinguir",
    "restingues": "restinguir",
    "restingui": "restinguir",
    "restinguia": "restinguir",
    "restinguiam": "restinguir",
    "restinguias": "restinguir",
    "restinguida": "restinguir",
    "restinguidas": "restinguir",
    "restinguido": "restinguir",
    "restinguidos": "restinguir",
    "restinguimo": "restinguir",
    "restinguimos": "restinguir",
    "restinguindo": "restinguir",
    "restinguira": "restinguir",
    "restinguiram": "restinguir",
    "restinguiras": "restinguir",
    "restinguirde": "restinguir",
    "restinguirdes": "restinguir",
    "restinguire": "restinguir",
    "restinguirei": "restinguir",
    "restinguireis": "restinguir",
    "restinguirem": "restinguir",
    "restinguiremos": "restinguir",
    "restinguires": "restinguir",
    "restinguiria": "restinguir",
    "restinguiriam": "restinguir",
    "restinguirias": "restinguir",
    "restinguirmo": "restinguir",
    "restinguirmos": "restinguir",
    "restinguirá": "restinguir",
    "restinguirás": "restinguir",
    "restinguirão": "restinguir",
    "restinguiríamos": "restinguir",
    "restinguiríeis": "restinguir",
    "restinguis": "restinguir",
    "restinguisse": "restinguir",
    "restinguissem": "restinguir",
    "restinguisses": "restinguir",
    "restinguiste": "restinguir",
    "restinguistes": "restinguir",
    "restinguiu": "restinguir",
    "restinguíamo": "restinguir",
    "restinguíamos": "restinguir",
    "restinguíei": "restinguir",
    "restinguíeis": "restinguir",
    "restinguíramo": "restinguir",
    "restinguíramos": "restinguir",
    "restinguírei": "restinguir",
    "restinguíreis": "restinguir",
    "restinguísseis": "restinguir",
    "restinguíssemos": "restinguir",
    "restingões": "restingão",
    "restinho": "resto",
    "restinhos": "resto",
    "restionáceas": "restionácea",
    "restito": "resto",
    "restitos": "resto",
    "restitua": "restituir",
    "restituais": "restituir",
    "restituam": "restituir",
    "restituamo": "restituir",
    "restituamos": "restituir",
    "restituas": "restituir",
    "restituem": "restituir",
    "restitui": "restituir",
    "restituidora": "restituidor",
    "restituidoras": "restituidor",
    "restituidores": "restituidor",
    "restituindo": "restituir",
    "restituirde": "restituir",
    "restituirdes": "restituir",
    "restituirei": "restituir",
    "restituireis": "restituir",
    "restituiremos": "restituir",
    "restituiria": "restituir",
    "restituiriam": "restituir",
    "restituirias": "restituir",
    "restituirmo": "restituir",
    "restituirmos": "restituir",
    "restituirá": "restituir",
    "restituirás": "restituir",
    "restituirão": "restituir",
    "restituiríamos": "restituir",
    "restituiríeis": "restituir",
    "restituis": "restituir",
    "restituiu": "restituir",
    "restituições": "restituição",
    "restituo": "restituir",
    "restitutória": "restitutório",
    "restitutórias": "restitutório",
    "restitutórios": "restitutório",
    "restituí": "restituir",
    "restituía": "restituir",
    "restituíam": "restituir",
    "restituíamo": "restituir",
    "restituíamos": "restituir",
    "restituías": "restituir",
    "restituída": "restituir",
    "restituídas": "restituir",
    "restituído": "restituir",
    "restituídos": "restituir",
    "restituíei": "restituir",
    "restituíeis": "restituir",
    "restituímo": "restituir",
    "restituímos": "restituir",
    "restituíra": "restituir",
    "restituíram": "restituir",
    "restituíramo": "restituir",
    "restituíramos": "restituir",
    "restituíras": "restituir",
    "restituíre": "restituir",
    "restituírei": "restituir",
    "restituíreis": "restituir",
    "restituírem": "restituir",
    "restituíres": "restituir",
    "restituís": "restituir",
    "restituísse": "restituir",
    "restituísseis": "restituir",
    "restituíssem": "restituir",
    "restituíssemos": "restituir",
    "restituísses": "restituir",
    "restituíste": "restituir",
    "restituístes": "restituir",
    "restituíveis": "restituível",
    "restiva": "restivar",
    "restivada": "restivar",
    "restivadas": "restivar",
    "restivado": "restivar",
    "restivados": "restivar",
    "restivai": "restivar",
    "restivais": "restivar",
    "restivam": "restivar",
    "restivamo": "restivar",
    "restivamos": "restivar",
    "restivando": "restivar",
    "restivara": "restivar",
    "restivaram": "restivar",
    "restivaras": "restivar",
    "restivarde": "restivar",
    "restivardes": "restivar",
    "restivare": "restivar",
    "restivarei": "restivar",
    "restivareis": "restivar",
    "restivarem": "restivar",
    "restivaremos": "restivar",
    "restivares": "restivar",
    "restivaria": "restivar",
    "restivariam": "restivar",
    "restivarias": "restivar",
    "restivarmo": "restivar",
    "restivarmos": "restivar",
    "restivará": "restivar",
    "restivarás": "restivar",
    "restivarão": "restivar",
    "restivaríamos": "restivar",
    "restivaríeis": "restivar",
    "restivas": "restivar",
    "restivasse": "restivar",
    "restivassem": "restivar",
    "restivasses": "restivar",
    "restivaste": "restivar",
    "restivastes": "restivar",
    "restivava": "restivar",
    "restivavam": "restivar",
    "restivavas": "restivar",
    "restive": "restivar",
    "restivei": "restivar",
    "restiveis": "restivar",
    "restivem": "restivar",
    "restivemo": "restivar",
    "restivemos": "restivar",
    "restives": "restivar",
    "restivo": "restivar",
    "restivos": "restivo",
    "restivou": "restivar",
    "restivá": "restivar",
    "restivámo": "restivar",
    "restivámos": "restivar",
    "restiváramo": "restivar",
    "restiváramos": "restivar",
    "restivárei": "restivar",
    "restiváreis": "restivar",
    "restivásseis": "restivar",
    "restivássemos": "restivar",
    "restivávamo": "restivar",
    "restivávamos": "restivar",
    "restivávei": "restivar",
    "restiváveis": "restivar",
    "resto": "restar",
    "restolha": "restolhar",
    "restolhada": "restolhar",
    "restolhadas": "restolhar",
    "restolhado": "restolhar",
    "restolhados": "restolhar",
    "restolhai": "restolhar",
    "restolhais": "restolhar",
    "restolham": "restolhar",
    "restolhamo": "restolhar",
    "restolhamos": "restolhar",
    "restolhando": "restolhar",
    "restolhara": "restolhar",
    "restolharam": "restolhar",
    "restolharas": "restolhar",
    "restolhardes": "restolhar",
    "restolharei": "restolhar",
    "restolhareis": "restolhar",
    "restolharem": "restolhar",
    "restolharemos": "restolhar",
    "restolhares": "restolhar",
    "restolharia": "restolhar",
    "restolhariam": "restolhar",
    "restolharias": "restolhar",
    "restolharmo": "restolhar",
    "restolharmos": "restolhar",
    "restolhará": "restolhar",
    "restolharás": "restolhar",
    "restolharão": "restolhar",
    "restolharíamos": "restolhar",
    "restolharíeis": "restolhar",
    "restolhas": "restolhar",
    "restolhasse": "restolhar",
    "restolhassem": "restolhar",
    "restolhasses": "restolhar",
    "restolhaste": "restolhar",
    "restolhastes": "restolhar",
    "restolhava": "restolhar",
    "restolhavam": "restolhar",
    "restolhavas": "restolhar",
    "restolhe": "restolhar",
    "restolhei": "restolhar",
    "restolheiras": "restolheira",
    "restolheis": "restolhar",
    "restolhem": "restolhar",
    "restolhemo": "restolhar",
    "restolhemos": "restolhar",
    "restolhes": "restolhar",
    "restolho": "restolhar",
    "restolhos": "restolho",
    "restolhou": "restolhar",
    "restolhámo": "restolhar",
    "restolhámos": "restolhar",
    "restolháramo": "restolhar",
    "restolháramos": "restolhar",
    "restolháreis": "restolhar",
    "restolhásseis": "restolhar",
    "restolhássemos": "restolhar",
    "restolhávamo": "restolhar",
    "restolhávamos": "restolhar",
    "restolháveis": "restolhar",
    "restos": "resto",
    "restou": "restar",
    "restriba": "restribar",
    "restribada": "restribar",
    "restribadas": "restribar",
    "restribado": "restribar",
    "restribados": "restribar",
    "restribai": "restribar",
    "restribais": "restribar",
    "restribam": "restribar",
    "restribamo": "restribar",
    "restribamos": "restribar",
    "restribando": "restribar",
    "restribara": "restribar",
    "restribaram": "restribar",
    "restribaras": "restribar",
    "restribardes": "restribar",
    "restribarei": "restribar",
    "restribareis": "restribar",
    "restribarem": "restribar",
    "restribaremos": "restribar",
    "restribares": "restribar",
    "restribaria": "restribar",
    "restribariam": "restribar",
    "restribarias": "restribar",
    "restribarmo": "restribar",
    "restribarmos": "restribar",
    "restribará": "restribar",
    "restribarás": "restribar",
    "restribarão": "restribar",
    "restribaríamos": "restribar",
    "restribaríeis": "restribar",
    "restribas": "restribar",
    "restribasse": "restribar",
    "restribassem": "restribar",
    "restribasses": "restribar",
    "restribaste": "restribar",
    "restribastes": "restribar",
    "restribava": "restribar",
    "restribavam": "restribar",
    "restribavas": "restribar",
    "restribe": "restribar",
    "restribei": "restribar",
    "restribeis": "restribar",
    "restribem": "restribar",
    "restribemo": "restribar",
    "restribemos": "restribar",
    "restribes": "restribar",
    "restribo": "restribar",
    "restribou": "restribar",
    "restribámo": "restribar",
    "restribámos": "restribar",
    "restribáramo": "restribar",
    "restribáramos": "restribar",
    "restribáreis": "restribar",
    "restribásseis": "restribar",
    "restribássemos": "restribar",
    "restribávamo": "restribar",
    "restribávamos": "restribar",
    "restribáveis": "restribar",
    "restringe": "restringir",
    "restringem": "restringir",
    "restringentes": "restringente",
    "restringes": "restringir",
    "restringi": "restringir",
    "restringia": "restringir",
    "restringiam": "restringir",
    "restringias": "restringir",
    "restringida": "restringir",
    "restringidas": "restringir",
    "restringido": "restringir",
    "restringidos": "restringir",
    "restringimentos": "restringimento",
    "restringimo": "restringir",
    "restringimos": "restringir",
    "restringindo": "restringir",
    "restringira": "restringir",
    "restringiram": "restringir",
    "restringiras": "restringir",
    "restringirde": "restringir",
    "restringirdes": "restringir",
    "restringire": "restringir",
    "restringirei": "restringir",
    "restringireis": "restringir",
    "restringirem": "restringir",
    "restringiremos": "restringir",
    "restringires": "restringir",
    "restringiria": "restringir",
    "restringiriam": "restringir",
    "restringirias": "restringir",
    "restringirmo": "restringir",
    "restringirmos": "restringir",
    "restringirá": "restringir",
    "restringirás": "restringir",
    "restringirão": "restringir",
    "restringiríamos": "restringir",
    "restringiríeis": "restringir",
    "restringis": "restringir",
    "restringisse": "restringir",
    "restringissem": "restringir",
    "restringisses": "restringir",
    "restringiste": "restringir",
    "restringistes": "restringir",
    "restringiu": "restringir",
    "restringências": "restringência",
    "restringíamo": "restringir",
    "restringíamos": "restringir",
    "restringíei": "restringir",
    "restringíeis": "restringir",
    "restringíramo": "restringir",
    "restringíramos": "restringir",
    "restringírei": "restringir",
    "restringíreis": "restringir",
    "restringísseis": "restringir",
    "restringíssemos": "restringir",
    "restringíveis": "restringível",
    "restrinja": "restringir",
    "restrinjais": "restringir",
    "restrinjam": "restringir",
    "restrinjamo": "restringir",
    "restrinjamos": "restringir",
    "restrinjas": "restringir",
    "restrinjo": "restringir",
    "restrita": "restrito",
    "restritas": "restrito",
    "restritiva": "restritivo",
    "restritivas": "restritivo",
    "restritivos": "restritivo",
    "restritos": "restrito",
    "restritíssima": "restrito",
    "restritíssimas": "restrito",
    "restritíssimo": "restrito",
    "restritíssimos": "restrito",
    "restrições": "restrição",
    "restruge": "restrugir",
    "restrugem": "restrugir",
    "restruges": "restrugir",
    "restrugi": "restrugir",
    "restrugia": "restrugir",
    "restrugiam": "restrugir",
    "restrugias": "restrugir",
    "restrugida": "restrugir",
    "restrugidas": "restrugir",
    "restrugido": "restrugir",
    "restrugidos": "restrugir",
    "restrugimo": "restrugir",
    "restrugimos": "restrugir",
    "restrugindo": "restrugir",
    "restrugira": "restrugir",
    "restrugiram": "restrugir",
    "restrugiras": "restrugir",
    "restrugirdes": "restrugir",
    "restrugirei": "restrugir",
    "restrugireis": "restrugir",
    "restrugirem": "restrugir",
    "restrugiremos": "restrugir",
    "restrugires": "restrugir",
    "restrugiria": "restrugir",
    "restrugiriam": "restrugir",
    "restrugirias": "restrugir",
    "restrugirmo": "restrugir",
    "restrugirmos": "restrugir",
    "restrugirá": "restrugir",
    "restrugirás": "restrugir",
    "restrugirão": "restrugir",
    "restrugiríamos": "restrugir",
    "restrugiríeis": "restrugir",
    "restrugis": "restrugir",
    "restrugisse": "restrugir",
    "restrugissem": "restrugir",
    "restrugisses": "restrugir",
    "restrugiste": "restrugir",
    "restrugistes": "restrugir",
    "restrugiu": "restrugir",
    "restrugíamo": "restrugir",
    "restrugíamos": "restrugir",
    "restrugíeis": "restrugir",
    "restrugíramo": "restrugir",
    "restrugíramos": "restrugir",
    "restrugíreis": "restrugir",
    "restrugísseis": "restrugir",
    "restrugíssemos": "restrugir",
    "restruja": "restrugir",
    "restrujais": "restrugir",
    "restrujam": "restrugir",
    "restrujamo": "restrugir",
    "restrujamos": "restrugir",
    "restrujas": "restrugir",
    "restrujo": "restrugir",
    "restruturada": "restruturado",
    "restruturadas": "restruturado",
    "restruturados": "restruturado",
    "restruturações": "restruturação",
    "restuca": "restucar",
    "restucada": "restucar",
    "restucadas": "restucar",
    "restucado": "restucar",
    "restucados": "restucar",
    "restucai": "restucar",
    "restucais": "restucar",
    "restucam": "restucar",
    "restucamo": "restucar",
    "restucamos": "restucar",
    "restucando": "restucar",
    "restucara": "restucar",
    "restucaram": "restucar",
    "restucaras": "restucar",
    "restucarde": "restucar",
    "restucardes": "restucar",
    "restucare": "restucar",
    "restucarei": "restucar",
    "restucareis": "restucar",
    "restucarem": "restucar",
    "restucaremos": "restucar",
    "restucares": "restucar",
    "restucaria": "restucar",
    "restucariam": "restucar",
    "restucarias": "restucar",
    "restucarmo": "restucar",
    "restucarmos": "restucar",
    "restucará": "restucar",
    "restucarás": "restucar",
    "restucarão": "restucar",
    "restucaríamos": "restucar",
    "restucaríeis": "restucar",
    "restucas": "restucar",
    "restucasse": "restucar",
    "restucassem": "restucar",
    "restucasses": "restucar",
    "restucaste": "restucar",
    "restucastes": "restucar",
    "restucava": "restucar",
    "restucavam": "restucar",
    "restucavas": "restucar",
    "restuco": "restucar",
    "restucou": "restucar",
    "restucá": "restucar",
    "restucámo": "restucar",
    "restucámos": "restucar",
    "restucáramo": "restucar",
    "restucáramos": "restucar",
    "restucárei": "restucar",
    "restucáreis": "restucar",
    "restucásseis": "restucar",
    "restucássemos": "restucar",
    "restucávamo": "restucar",
    "restucávamos": "restucar",
    "restucávei": "restucar",
    "restucáveis": "restucar",
    "restuque": "restucar",
    "restuquei": "restucar",
    "restuqueis": "restucar",
    "restuquem": "restucar",
    "restuquemo": "restucar",
    "restuquemos": "restucar",
    "restuques": "restucar",
    "restámo": "restar",
    "restámos": "restar",
    "restáramo": "restar",
    "restáramos": "restar",
    "restáreis": "restar",
    "restásseis": "restar",
    "restássemos": "restar",
    "restávamo": "restar",
    "restávamos": "restar",
    "restáveis": "restar",
    "resulta": "resultar",
    "resultada": "resultar",
    "resultadas": "resultar",
    "resultado": "resultar",
    "resultados": "resultar",
    "resultai": "resultar",
    "resultais": "resultar",
    "resultam": "resultar",
    "resultamo": "resultar",
    "resultamos": "resultar",
    "resultando": "resultar",
    "resultantes": "resultante",
    "resultara": "resultar",
    "resultaram": "resultar",
    "resultaras": "resultar",
    "resultardes": "resultar",
    "resultarei": "resultar",
    "resultareis": "resultar",
    "resultarem": "resultar",
    "resultaremos": "resultar",
    "resultares": "resultar",
    "resultaria": "resultar",
    "resultariam": "resultar",
    "resultarias": "resultar",
    "resultarmo": "resultar",
    "resultarmos": "resultar",
    "resultará": "resultar",
    "resultarás": "resultar",
    "resultarão": "resultar",
    "resultaríamos": "resultar",
    "resultaríeis": "resultar",
    "resultas": "resultar",
    "resultasse": "resultar",
    "resultassem": "resultar",
    "resultasses": "resultar",
    "resultaste": "resultar",
    "resultastes": "resultar",
    "resultava": "resultar",
    "resultavam": "resultar",
    "resultavas": "resultar",
    "resulte": "resultar",
    "resultei": "resultar",
    "resulteis": "resultar",
    "resultem": "resultar",
    "resultemo": "resultar",
    "resultemos": "resultar",
    "resultes": "resultar",
    "resulto": "resultar",
    "resultou": "resultar",
    "resultámo": "resultar",
    "resultámos": "resultar",
    "resultáramo": "resultar",
    "resultáramos": "resultar",
    "resultáreis": "resultar",
    "resultásseis": "resultar",
    "resultássemos": "resultar",
    "resultávamo": "resultar",
    "resultávamos": "resultar",
    "resultáveis": "resultar",
    "resultâncias": "resultância",
    "resuma": "resumir",
    "resumais": "resumir",
    "resumam": "resumir",
    "resumamo": "resumir",
    "resumamos": "resumir",
    "resumas": "resumir",
    "resume": "resumir",
    "resumem": "resumir",
    "resumes": "resumir",
    "resumi": "resumir",
    "resumia": "resumir",
    "resumiam": "resumir",
    "resumias": "resumir",
    "resumida": "resumir",
    "resumidas": "resumir",
    "resumido": "resumir",
    "resumidora": "resumidor",
    "resumidoras": "resumidor",
    "resumidores": "resumidor",
    "resumidos": "resumir",
    "resumidíssima": "resumido",
    "resumidíssimas": "resumido",
    "resumidíssimo": "resumido",
    "resumidíssimos": "resumido",
    "resumimo": "resumir",
    "resumimos": "resumir",
    "resumindo": "resumir",
    "resumira": "resumir",
    "resumiram": "resumir",
    "resumiras": "resumir",
    "resumirdes": "resumir",
    "resumirei": "resumir",
    "resumireis": "resumir",
    "resumirem": "resumir",
    "resumiremos": "resumir",
    "resumires": "resumir",
    "resumiria": "resumir",
    "resumiriam": "resumir",
    "resumirias": "resumir",
    "resumirmo": "resumir",
    "resumirmos": "resumir",
    "resumirá": "resumir",
    "resumirás": "resumir",
    "resumirão": "resumir",
    "resumiríamos": "resumir",
    "resumiríeis": "resumir",
    "resumis": "resumir",
    "resumisse": "resumir",
    "resumissem": "resumir",
    "resumisses": "resumir",
    "resumiste": "resumir",
    "resumistes": "resumir",
    "resumiu": "resumir",
    "resumo": "resumir",
    "resumos": "resumo",
    "resumíamo": "resumir",
    "resumíamos": "resumir",
    "resumíeis": "resumir",
    "resumíramo": "resumir",
    "resumíramos": "resumir",
    "resumíreis": "resumir",
    "resumísseis": "resumir",
    "resumíssemos": "resumir",
    "resumíveis": "resumível",
    "resvala": "resvalar",
    "resvalada": "resvalar",
    "resvaladas": "resvalar",
    "resvaladeiros": "resvaladeiro",
    "resvaladia": "resvaladio",
    "resvaladias": "resvaladio",
    "resvaladios": "resvaladio",
    "resvaladiça": "resvaladiço",
    "resvaladiças": "resvaladiço",
    "resvaladiços": "resvaladiço",
    "resvalado": "resvalar",
    "resvaladoiros": "resvaladoiro",
    "resvalados": "resvalar",
    "resvaladouros": "resvaladouro",
    "resvaladuras": "resvaladura",
    "resvalai": "resvalar",
    "resvalais": "resvalar",
    "resvalam": "resvalar",
    "resvalamentos": "resvalamento",
    "resvalamo": "resvalar",
    "resvalamos": "resvalar",
    "resvalando": "resvalar",
    "resvalantes": "resvalante",
    "resvalara": "resvalar",
    "resvalaram": "resvalar",
    "resvalaras": "resvalar",
    "resvalardes": "resvalar",
    "resvalarei": "resvalar",
    "resvalareis": "resvalar",
    "resvalarem": "resvalar",
    "resvalaremos": "resvalar",
    "resvalares": "resvalar",
    "resvalaria": "resvalar",
    "resvalariam": "resvalar",
    "resvalarias": "resvalar",
    "resvalarmo": "resvalar",
    "resvalarmos": "resvalar",
    "resvalará": "resvalar",
    "resvalarás": "resvalar",
    "resvalarão": "resvalar",
    "resvalaríamos": "resvalar",
    "resvalaríeis": "resvalar",
    "resvalas": "resvalar",
    "resvalasse": "resvalar",
    "resvalassem": "resvalar",
    "resvalasses": "resvalar",
    "resvalaste": "resvalar",
    "resvalastes": "resvalar",
    "resvalava": "resvalar",
    "resvalavam": "resvalar",
    "resvalavas": "resvalar",
    "resvale": "resvalar",
    "resvalei": "resvalar",
    "resvaleis": "resvalar",
    "resvalem": "resvalar",
    "resvalemo": "resvalar",
    "resvalemos": "resvalar",
    "resvales": "resvalar",
    "resvalo": "resvalar",
    "resvalos": "resvalo",
    "resvalou": "resvalar",
    "resvalámo": "resvalar",
    "resvalámos": "resvalar",
    "resvaláramo": "resvalar",
    "resvaláramos": "resvalar",
    "resvaláreis": "resvalar",
    "resvalásseis": "resvalar",
    "resvalássemos": "resvalar",
    "resvalávamo": "resvalar",
    "resvalávamos": "resvalar",
    "resvaláveis": "resvalar",
    "resídua": "resíduo",
    "resíduas": "resíduo",
    "resíduos": "resíduo",
    "retabulares": "retabular",
    "retaca": "retacar",
    "retacada": "retacar",
    "retacadas": "retacar",
    "retacado": "retacar",
    "retacados": "retacar",
    "retacai": "retacar",
    "retacais": "retacar",
    "retacam": "retacar",
    "retacamo": "retacar",
    "retacamos": "retacar",
    "retacando": "retacar",
    "retacara": "retacar",
    "retacaram": "retacar",
    "retacaras": "retacar",
    "retacarde": "retacar",
    "retacardes": "retacar",
    "retacare": "retacar",
    "retacarei": "retacar",
    "retacareis": "retacar",
    "retacarem": "retacar",
    "retacaremos": "retacar",
    "retacares": "retacar",
    "retacaria": "retacar",
    "retacariam": "retacar",
    "retacarias": "retacar",
    "retacarmo": "retacar",
    "retacarmos": "retacar",
    "retacará": "retacar",
    "retacarás": "retacar",
    "retacarão": "retacar",
    "retacaríamos": "retacar",
    "retacaríeis": "retacar",
    "retacas": "retacar",
    "retacasse": "retacar",
    "retacassem": "retacar",
    "retacasses": "retacar",
    "retacaste": "retacar",
    "retacastes": "retacar",
    "retacava": "retacar",
    "retacavam": "retacar",
    "retacavas": "retacar",
    "retaco": "retacar",
    "retacou": "retacar",
    "retacá": "retacar",
    "retacámo": "retacar",
    "retacámos": "retacar",
    "retacáramo": "retacar",
    "retacáramos": "retacar",
    "retacárei": "retacar",
    "retacáreis": "retacar",
    "retacásseis": "retacar",
    "retacássemos": "retacar",
    "retacávamo": "retacar",
    "retacávamos": "retacar",
    "retacávei": "retacar",
    "retacáveis": "retacar",
    "retadas": "retada",
    "retaguardas": "retaguarda",
    "retalha": "retalhar",
    "retalhada": "retalhar",
    "retalhadas": "retalhar",
    "retalhadinha": "retalhado",
    "retalhadinhas": "retalhado",
    "retalhadinho": "retalhado",
    "retalhadinhos": "retalhado",
    "retalhadita": "retalhado",
    "retalhaditas": "retalhado",
    "retalhadito": "retalhado",
    "retalhaditos": "retalhado",
    "retalhado": "retalhar",
    "retalhadora": "retalhador",
    "retalhadoras": "retalhador",
    "retalhadores": "retalhador",
    "retalhados": "retalhar",
    "retalhaduras": "retalhadura",
    "retalhadíssima": "retalhado",
    "retalhadíssimas": "retalhado",
    "retalhadíssimo": "retalhado",
    "retalhadíssimos": "retalhado",
    "retalhai": "retalhar",
    "retalhais": "retalhar",
    "retalham": "retalhar",
    "retalhamentos": "retalhamento",
    "retalhamo": "retalhar",
    "retalhamos": "retalhar",
    "retalhando": "retalhar",
    "retalhara": "retalhar",
    "retalharam": "retalhar",
    "retalharas": "retalhar",
    "retalharde": "retalhar",
    "retalhardes": "retalhar",
    "retalhare": "retalhar",
    "retalharei": "retalhar",
    "retalhareis": "retalhar",
    "retalharem": "retalhar",
    "retalharemos": "retalhar",
    "retalhares": "retalhar",
    "retalharia": "retalhar",
    "retalhariam": "retalhar",
    "retalharias": "retalhar",
    "retalharmo": "retalhar",
    "retalharmos": "retalhar",
    "retalhará": "retalhar",
    "retalharás": "retalhar",
    "retalharão": "retalhar",
    "retalharíamos": "retalhar",
    "retalharíeis": "retalhar",
    "retalhas": "retalhar",
    "retalhasse": "retalhar",
    "retalhassem": "retalhar",
    "retalhasses": "retalhar",
    "retalhaste": "retalhar",
    "retalhastes": "retalhar",
    "retalhava": "retalhar",
    "retalhavam": "retalhar",
    "retalhavas": "retalhar",
    "retalhe": "retalhar",
    "retalhei": "retalhar",
    "retalheira": "retalheiro",
    "retalheiras": "retalheiro",
    "retalheiros": "retalheiro",
    "retalheis": "retalhar",
    "retalhem": "retalhar",
    "retalhemo": "retalhar",
    "retalhemos": "retalhar",
    "retalhes": "retalhar",
    "retalhistas": "retalhista",
    "retalho": "retalhar",
    "retalhos": "retalho",
    "retalhou": "retalhar",
    "retalhá": "retalhar",
    "retalhámo": "retalhar",
    "retalhámos": "retalhar",
    "retalháramo": "retalhar",
    "retalháramos": "retalhar",
    "retalhárei": "retalhar",
    "retalháreis": "retalhar",
    "retalhásseis": "retalhar",
    "retalhássemos": "retalhar",
    "retalhávamo": "retalhar",
    "retalhávamos": "retalhar",
    "retalhávei": "retalhar",
    "retalháveis": "retalhável",
    "retalia": "retaliar",
    "retaliada": "retaliar",
    "retaliadas": "retaliar",
    "retaliado": "retaliar",
    "retaliadora": "retaliador",
    "retaliadoras": "retaliador",
    "retaliadores": "retaliador",
    "retaliados": "retaliar",
    "retaliai": "retaliar",
    "retaliais": "retaliar",
    "retaliam": "retaliar",
    "retaliamo": "retaliar",
    "retaliamos": "retaliar",
    "retaliando": "retaliar",
    "retaliara": "retaliar",
    "retaliaram": "retaliar",
    "retaliaras": "retaliar",
    "retaliarde": "retaliar",
    "retaliardes": "retaliar",
    "retaliare": "retaliar",
    "retaliarei": "retaliar",
    "retaliareis": "retaliar",
    "retaliarem": "retaliar",
    "retaliaremos": "retaliar",
    "retaliares": "retaliar",
    "retaliaria": "retaliar",
    "retaliariam": "retaliar",
    "retaliarias": "retaliar",
    "retaliarmo": "retaliar",
    "retaliarmos": "retaliar",
    "retaliará": "retaliar",
    "retaliarás": "retaliar",
    "retaliarão": "retaliar",
    "retaliaríamos": "retaliar",
    "retaliaríeis": "retaliar",
    "retalias": "retaliar",
    "retaliasse": "retaliar",
    "retaliassem": "retaliar",
    "retaliasses": "retaliar",
    "retaliaste": "retaliar",
    "retaliastes": "retaliar",
    "retaliativa": "retaliativo",
    "retaliativas": "retaliativo",
    "retaliativos": "retaliativo",
    "retaliatória": "retaliatório",
    "retaliatórias": "retaliatório",
    "retaliatórios": "retaliatório",
    "retaliava": "retaliar",
    "retaliavam": "retaliar",
    "retaliavas": "retaliar",
    "retaliações": "retaliação",
    "retalie": "retaliar",
    "retaliei": "retaliar",
    "retalieis": "retaliar",
    "retaliem": "retaliar",
    "retaliemo": "retaliar",
    "retaliemos": "retaliar",
    "retalies": "retaliar",
    "retalio": "retaliar",
    "retaliou": "retaliar",
    "retaliá": "retaliar",
    "retaliámo": "retaliar",
    "retaliámos": "retaliar",
    "retaliáramo": "retaliar",
    "retaliáramos": "retaliar",
    "retaliárei": "retaliar",
    "retaliáreis": "retaliar",
    "retaliásseis": "retaliar",
    "retaliássemos": "retaliar",
    "retaliávamo": "retaliar",
    "retaliávamos": "retaliar",
    "retaliávei": "retaliar",
    "retaliáveis": "retaliar",
    "retambanas": "retambana",
    "retames": "retame",
    "retancha": "retanchar",
    "retanchada": "retanchar",
    "retanchadas": "retanchar",
    "retanchado": "retanchar",
    "retanchados": "retanchar",
    "retanchai": "retanchar",
    "retanchais": "retanchar",
    "retancham": "retanchar",
    "retanchamo": "retanchar",
    "retanchamos": "retanchar",
    "retanchando": "retanchar",
    "retanchara": "retanchar",
    "retancharam": "retanchar",
    "retancharas": "retanchar",
    "retancharde": "retanchar",
    "retanchardes": "retanchar",
    "retanchare": "retanchar",
    "retancharei": "retanchar",
    "retanchareis": "retanchar",
    "retancharem": "retanchar",
    "retancharemos": "retanchar",
    "retanchares": "retanchar",
    "retancharia": "retanchar",
    "retanchariam": "retanchar",
    "retancharias": "retanchar",
    "retancharmo": "retanchar",
    "retancharmos": "retanchar",
    "retanchará": "retanchar",
    "retancharás": "retanchar",
    "retancharão": "retanchar",
    "retancharíamos": "retanchar",
    "retancharíeis": "retanchar",
    "retanchas": "retanchar",
    "retanchasse": "retanchar",
    "retanchassem": "retanchar",
    "retanchasses": "retanchar",
    "retanchaste": "retanchar",
    "retanchastes": "retanchar",
    "retanchava": "retanchar",
    "retanchavam": "retanchar",
    "retanchavas": "retanchar",
    "retanche": "retanchar",
    "retanchei": "retanchar",
    "retancheis": "retanchar",
    "retanchem": "retanchar",
    "retanchemo": "retanchar",
    "retanchemos": "retanchar",
    "retanches": "retanchar",
    "retancho": "retanchar",
    "retanchoas": "retanchoa",
    "retanchou": "retanchar",
    "retanchá": "retanchar",
    "retanchámo": "retanchar",
    "retanchámos": "retanchar",
    "retancháramo": "retanchar",
    "retancháramos": "retanchar",
    "retanchárei": "retanchar",
    "retancháreis": "retanchar",
    "retanchásseis": "retanchar",
    "retanchássemos": "retanchar",
    "retanchávamo": "retanchar",
    "retanchávamos": "retanchar",
    "retanchávei": "retanchar",
    "retancháveis": "retanchar",
    "retaque": "retacar",
    "retaquei": "retacar",
    "retaqueis": "retacar",
    "retaquem": "retacar",
    "retaquemo": "retacar",
    "retaquemos": "retacar",
    "retaques": "retacar",
    "retarda": "retardar",
    "retardada": "retardar",
    "retardadas": "retardar",
    "retardado": "retardar",
    "retardadora": "retardador",
    "retardadoras": "retardador",
    "retardadores": "retardador",
    "retardados": "retardar",
    "retardai": "retardar",
    "retardais": "retardar",
    "retardam": "retardar",
    "retardamentos": "retardamento",
    "retardamo": "retardar",
    "retardamos": "retardar",
    "retardando": "retardar",
    "retardanças": "retardança",
    "retardara": "retardar",
    "retardaram": "retardar",
    "retardaras": "retardar",
    "retardarde": "retardar",
    "retardardes": "retardar",
    "retardare": "retardar",
    "retardarei": "retardar",
    "retardareis": "retardar",
    "retardarem": "retardar",
    "retardaremos": "retardar",
    "retardares": "retardar",
    "retardaria": "retardar",
    "retardariam": "retardar",
    "retardarias": "retardar",
    "retardarmo": "retardar",
    "retardarmos": "retardar",
    "retardará": "retardar",
    "retardarás": "retardar",
    "retardarão": "retardar",
    "retardaríamos": "retardar",
    "retardaríeis": "retardar",
    "retardas": "retardar",
    "retardasse": "retardar",
    "retardassem": "retardar",
    "retardasses": "retardar",
    "retardaste": "retardar",
    "retardastes": "retardar",
    "retardativa": "retardativo",
    "retardativas": "retardativo",
    "retardativos": "retardativo",
    "retardatária": "retardatário",
    "retardatárias": "retardatário",
    "retardatários": "retardatário",
    "retardava": "retardar",
    "retardavam": "retardar",
    "retardavas": "retardar",
    "retardações": "retardação",
    "retarde": "retardar",
    "retardei": "retardar",
    "retardeis": "retardar",
    "retardem": "retardar",
    "retardemo": "retardar",
    "retardemos": "retardar",
    "retardes": "retarde",
    "retardo": "retardar",
    "retardona": "retardão",
    "retardonas": "retardão",
    "retardou": "retardar",
    "retardá": "retardar",
    "retardámo": "retardar",
    "retardámos": "retardar",
    "retardáramo": "retardar",
    "retardáramos": "retardar",
    "retardárei": "retardar",
    "retardáreis": "retardar",
    "retardásseis": "retardar",
    "retardássemos": "retardar",
    "retardávamo": "retardar",
    "retardávamos": "retardar",
    "retardávei": "retardar",
    "retardáveis": "retardar",
    "retardões": "retardão",
    "reteima": "reteimar",
    "reteimada": "reteimar",
    "reteimadas": "reteimar",
    "reteimado": "reteimar",
    "reteimados": "reteimar",
    "reteimai": "reteimar",
    "reteimais": "reteimar",
    "reteimam": "reteimar",
    "reteimamo": "reteimar",
    "reteimamos": "reteimar",
    "reteimando": "reteimar",
    "reteimara": "reteimar",
    "reteimaram": "reteimar",
    "reteimaras": "reteimar",
    "reteimardes": "reteimar",
    "reteimarei": "reteimar",
    "reteimareis": "reteimar",
    "reteimarem": "reteimar",
    "reteimaremos": "reteimar",
    "reteimares": "reteimar",
    "reteimaria": "reteimar",
    "reteimariam": "reteimar",
    "reteimarias": "reteimar",
    "reteimarmo": "reteimar",
    "reteimarmos": "reteimar",
    "reteimará": "reteimar",
    "reteimarás": "reteimar",
    "reteimarão": "reteimar",
    "reteimaríamos": "reteimar",
    "reteimaríeis": "reteimar",
    "reteimas": "reteimar",
    "reteimasse": "reteimar",
    "reteimassem": "reteimar",
    "reteimasses": "reteimar",
    "reteimaste": "reteimar",
    "reteimastes": "reteimar",
    "reteimava": "reteimar",
    "reteimavam": "reteimar",
    "reteimavas": "reteimar",
    "reteime": "reteimar",
    "reteimei": "reteimar",
    "reteimeis": "reteimar",
    "reteimem": "reteimar",
    "reteimemo": "reteimar",
    "reteimemos": "reteimar",
    "reteimes": "reteimar",
    "reteimo": "reteimar",
    "reteimou": "reteimar",
    "reteimámo": "reteimar",
    "reteimámos": "reteimar",
    "reteimáramo": "reteimar",
    "reteimáramos": "reteimar",
    "reteimáreis": "reteimar",
    "reteimásseis": "reteimar",
    "reteimássemos": "reteimar",
    "reteimávamo": "reteimar",
    "reteimávamos": "reteimar",
    "reteimáveis": "reteimar",
    "retelha": "retelhar",
    "retelhada": "retelhar",
    "retelhadas": "retelhar",
    "retelhado": "retelhar",
    "retelhados": "retelhar",
    "retelhaduras": "retelhadura",
    "retelhai": "retelhar",
    "retelhais": "retelhar",
    "retelham": "retelhar",
    "retelhamo": "retelhar",
    "retelhamos": "retelhar",
    "retelhando": "retelhar",
    "retelhara": "retelhar",
    "retelharam": "retelhar",
    "retelharas": "retelhar",
    "retelharde": "retelhar",
    "retelhardes": "retelhar",
    "retelhare": "retelhar",
    "retelharei": "retelhar",
    "retelhareis": "retelhar",
    "retelharem": "retelhar",
    "retelharemos": "retelhar",
    "retelhares": "retelhar",
    "retelharia": "retelhar",
    "retelhariam": "retelhar",
    "retelharias": "retelhar",
    "retelharmo": "retelhar",
    "retelharmos": "retelhar",
    "retelhará": "retelhar",
    "retelharás": "retelhar",
    "retelharão": "retelhar",
    "retelharíamos": "retelhar",
    "retelharíeis": "retelhar",
    "retelhas": "retelhar",
    "retelhasse": "retelhar",
    "retelhassem": "retelhar",
    "retelhasses": "retelhar",
    "retelhaste": "retelhar",
    "retelhastes": "retelhar",
    "retelhava": "retelhar",
    "retelhavam": "retelhar",
    "retelhavas": "retelhar",
    "retelhações": "retelhação",
    "retelhe": "retelhar",
    "retelhei": "retelhar",
    "retelheis": "retelhar",
    "retelhem": "retelhar",
    "retelhemo": "retelhar",
    "retelhemos": "retelhar",
    "retelhes": "retelhar",
    "retelho": "retelhar",
    "retelhou": "retelhar",
    "retelhá": "retelhar",
    "retelhámo": "retelhar",
    "retelhámos": "retelhar",
    "retelháramo": "retelhar",
    "retelháramos": "retelhar",
    "retelhárei": "retelhar",
    "retelháreis": "retelhar",
    "retelhásseis": "retelhar",
    "retelhássemos": "retelhar",
    "retelhávamo": "retelhar",
    "retelhávamos": "retelhar",
    "retelhávei": "retelhar",
    "retelháveis": "retelhar",
    "retemo": "reter",
    "retemos": "reter",
    "retempera": "retemperar",
    "retemperada": "retemperar",
    "retemperadas": "retemperar",
    "retemperado": "retemperar",
    "retemperadora": "retemperador",
    "retemperadoras": "retemperador",
    "retemperadores": "retemperador",
    "retemperados": "retemperar",
    "retemperai": "retemperar",
    "retemperais": "retemperar",
    "retemperam": "retemperar",
    "retemperamo": "retemperar",
    "retemperamos": "retemperar",
    "retemperando": "retemperar",
    "retemperantes": "retemperante",
    "retemperara": "retemperar",
    "retemperaram": "retemperar",
    "retemperaras": "retemperar",
    "retemperarde": "retemperar",
    "retemperardes": "retemperar",
    "retemperare": "retemperar",
    "retemperarei": "retemperar",
    "retemperareis": "retemperar",
    "retemperarem": "retemperar",
    "retemperaremos": "retemperar",
    "retemperares": "retemperar",
    "retemperaria": "retemperar",
    "retemperariam": "retemperar",
    "retemperarias": "retemperar",
    "retemperarmo": "retemperar",
    "retemperarmos": "retemperar",
    "retemperará": "retemperar",
    "retemperarás": "retemperar",
    "retemperarão": "retemperar",
    "retemperaríamos": "retemperar",
    "retemperaríeis": "retemperar",
    "retemperas": "retemperar",
    "retemperasse": "retemperar",
    "retemperassem": "retemperar",
    "retemperasses": "retemperar",
    "retemperaste": "retemperar",
    "retemperastes": "retemperar",
    "retemperava": "retemperar",
    "retemperavam": "retemperar",
    "retemperavas": "retemperar",
    "retemperações": "retemperação",
    "retempere": "retemperar",
    "retemperei": "retemperar",
    "retempereis": "retemperar",
    "retemperem": "retemperar",
    "retemperemo": "retemperar",
    "retemperemos": "retemperar",
    "retemperes": "retemperar",
    "retempero": "retemperar",
    "retemperou": "retemperar",
    "retemperá": "retemperar",
    "retemperámo": "retemperar",
    "retemperámos": "retemperar",
    "retemperáramo": "retemperar",
    "retemperáramos": "retemperar",
    "retemperárei": "retemperar",
    "retemperáreis": "retemperar",
    "retemperásseis": "retemperar",
    "retemperássemos": "retemperar",
    "retemperávamo": "retemperar",
    "retemperávamos": "retemperar",
    "retemperávei": "retemperar",
    "retemperáveis": "retemperar",
    "retempos": "retempo",
    "retende": "reter",
    "retendes": "reter",
    "retendo": "reter",
    "retenha": "reter",
    "retenhais": "reter",
    "retenham": "reter",
    "retenhamo": "reter",
    "retenhamos": "reter",
    "retenhas": "reter",
    "retenho": "reter",
    "retenidas": "retenida",
    "retensões": "retensão",
    "retentiva": "retentivo",
    "retentivas": "retentivo",
    "retentividades": "retentividade",
    "retentivos": "retentivo",
    "retentora": "retentor",
    "retentoras": "retentor",
    "retentores": "retentor",
    "retentriz": "retentor",
    "retentrizes": "retentor",
    "retenções": "retenção",
    "reterde": "reter",
    "reterdes": "reter",
    "retere": "reter",
    "reterei": "reter",
    "retereis": "reter",
    "reterem": "reter",
    "reteremos": "reter",
    "reteres": "reter",
    "reteria": "reter",
    "reteriam": "reter",
    "reterias": "reter",
    "retermo": "reter",
    "retermos": "reter",
    "reterá": "reter",
    "reterás": "reter",
    "reterão": "reter",
    "reteríamos": "reter",
    "reteríeis": "reter",
    "retesa": "reteso",
    "retesada": "retesar",
    "retesadas": "retesar",
    "retesado": "retesar",
    "retesadores": "retesador",
    "retesados": "retesar",
    "retesai": "retesar",
    "retesais": "retesar",
    "retesam": "retesar",
    "retesamentos": "retesamento",
    "retesamo": "retesar",
    "retesamos": "retesar",
    "retesando": "retesar",
    "retesara": "retesar",
    "retesaram": "retesar",
    "retesaras": "retesar",
    "retesarde": "retesar",
    "retesardes": "retesar",
    "retesare": "retesar",
    "retesarei": "retesar",
    "retesareis": "retesar",
    "retesarem": "retesar",
    "retesaremos": "retesar",
    "retesares": "retesar",
    "retesaria": "retesar",
    "retesariam": "retesar",
    "retesarias": "retesar",
    "retesarmo": "retesar",
    "retesarmos": "retesar",
    "retesará": "retesar",
    "retesarás": "retesar",
    "retesarão": "retesar",
    "retesaríamos": "retesar",
    "retesaríeis": "retesar",
    "retesas": "reteso",
    "retesasse": "retesar",
    "retesassem": "retesar",
    "retesasses": "retesar",
    "retesaste": "retesar",
    "retesastes": "retesar",
    "retesava": "retesar",
    "retesavam": "retesar",
    "retesavas": "retesar",
    "retese": "retesar",
    "retesei": "retesar",
    "reteseis": "retesar",
    "retesem": "retesar",
    "retesemo": "retesar",
    "retesemos": "retesar",
    "reteses": "retesar",
    "retesia": "retesiar",
    "retesiada": "retesiar",
    "retesiadas": "retesiar",
    "retesiado": "retesiar",
    "retesiados": "retesiar",
    "retesiai": "retesiar",
    "retesiais": "retesiar",
    "retesiam": "retesiar",
    "retesiamo": "retesiar",
    "retesiamos": "retesiar",
    "retesiando": "retesiar",
    "retesiara": "retesiar",
    "retesiaram": "retesiar",
    "retesiaras": "retesiar",
    "retesiardes": "retesiar",
    "retesiarei": "retesiar",
    "retesiareis": "retesiar",
    "retesiarem": "retesiar",
    "retesiaremos": "retesiar",
    "retesiares": "retesiar",
    "retesiaria": "retesiar",
    "retesiariam": "retesiar",
    "retesiarias": "retesiar",
    "retesiarmo": "retesiar",
    "retesiarmos": "retesiar",
    "retesiará": "retesiar",
    "retesiarás": "retesiar",
    "retesiarão": "retesiar",
    "retesiaríamos": "retesiar",
    "retesiaríeis": "retesiar",
    "retesias": "retesiar",
    "retesiasse": "retesiar",
    "retesiassem": "retesiar",
    "retesiasses": "retesiar",
    "retesiaste": "retesiar",
    "retesiastes": "retesiar",
    "retesiava": "retesiar",
    "retesiavam": "retesiar",
    "retesiavas": "retesiar",
    "retesie": "retesiar",
    "retesiei": "retesiar",
    "retesieis": "retesiar",
    "retesiem": "retesiar",
    "retesiemo": "retesiar",
    "retesiemos": "retesiar",
    "retesies": "retesiar",
    "retesio": "retesiar",
    "retesiou": "retesiar",
    "retesiámo": "retesiar",
    "retesiámos": "retesiar",
    "retesiáramo": "retesiar",
    "retesiáramos": "retesiar",
    "retesiáreis": "retesiar",
    "retesiásseis": "retesiar",
    "retesiássemos": "retesiar",
    "retesiávamo": "retesiar",
    "retesiávamos": "retesiar",
    "retesiáveis": "retesiar",
    "reteso": "retesar",
    "retesos": "reteso",
    "retesou": "retesar",
    "retesá": "retesar",
    "retesámo": "retesar",
    "retesámos": "retesar",
    "retesáramo": "retesar",
    "retesáramos": "retesar",
    "retesárei": "retesar",
    "retesáreis": "retesar",
    "retesásseis": "retesar",
    "retesássemos": "retesar",
    "retesávamo": "retesar",
    "retesávamos": "retesar",
    "retesávei": "retesar",
    "retesáveis": "retesar",
    "reteve": "reter",
    "retianos": "retiano",
    "reticencia": "reticenciar",
    "reticenciada": "reticenciar",
    "reticenciadas": "reticenciar",
    "reticenciado": "reticenciar",
    "reticenciados": "reticenciar",
    "reticenciai": "reticenciar",
    "reticenciais": "reticenciar",
    "reticenciam": "reticenciar",
    "reticenciamo": "reticenciar",
    "reticenciamos": "reticenciar",
    "reticenciando": "reticenciar",
    "reticenciara": "reticenciar",
    "reticenciaram": "reticenciar",
    "reticenciaras": "reticenciar",
    "reticenciarde": "reticenciar",
    "reticenciardes": "reticenciar",
    "reticenciare": "reticenciar",
    "reticenciarei": "reticenciar",
    "reticenciareis": "reticenciar",
    "reticenciarem": "reticenciar",
    "reticenciaremos": "reticenciar",
    "reticenciares": "reticenciar",
    "reticenciaria": "reticenciar",
    "reticenciariam": "reticenciar",
    "reticenciarias": "reticenciar",
    "reticenciarmo": "reticenciar",
    "reticenciarmos": "reticenciar",
    "reticenciará": "reticenciar",
    "reticenciarás": "reticenciar",
    "reticenciarão": "reticenciar",
    "reticenciaríamos": "reticenciar",
    "reticenciaríeis": "reticenciar",
    "reticencias": "reticenciar",
    "reticenciasse": "reticenciar",
    "reticenciassem": "reticenciar",
    "reticenciasses": "reticenciar",
    "reticenciaste": "reticenciar",
    "reticenciastes": "reticenciar",
    "reticenciava": "reticenciar",
    "reticenciavam": "reticenciar",
    "reticenciavas": "reticenciar",
    "reticencie": "reticenciar",
    "reticenciei": "reticenciar",
    "reticencieis": "reticenciar",
    "reticenciem": "reticenciar",
    "reticenciemo": "reticenciar",
    "reticenciemos": "reticenciar",
    "reticencies": "reticenciar",
    "reticencio": "reticenciar",
    "reticenciosa": "reticencioso",
    "reticenciosas": "reticencioso",
    "reticenciosos": "reticencioso",
    "reticenciou": "reticenciar",
    "reticenciá": "reticenciar",
    "reticenciámo": "reticenciar",
    "reticenciámos": "reticenciar",
    "reticenciáramo": "reticenciar",
    "reticenciáramos": "reticenciar",
    "reticenciárei": "reticenciar",
    "reticenciáreis": "reticenciar",
    "reticenciásseis": "reticenciar",
    "reticenciássemos": "reticenciar",
    "reticenciávamo": "reticenciar",
    "reticenciávamos": "reticenciar",
    "reticenciávei": "reticenciar",
    "reticenciáveis": "reticenciar",
    "reticentes": "reticente",
    "reticulada": "reticulado",
    "reticuladas": "reticulado",
    "reticulados": "reticulado",
    "reticulares": "reticular",
    "reticulações": "reticulação",
    "reticências": "reticência",
    "retida": "retido",
    "retidas": "retido",
    "retido": "reter",
    "retidos": "retido",
    "retiformes": "retiforme",
    "retilinta": "retilintar",
    "retilintada": "retilintar",
    "retilintadas": "retilintar",
    "retilintado": "retilintar",
    "retilintados": "retilintar",
    "retilintai": "retilintar",
    "retilintais": "retilintar",
    "retilintam": "retilintar",
    "retilintamo": "retilintar",
    "retilintamos": "retilintar",
    "retilintando": "retilintar",
    "retilintara": "retilintar",
    "retilintaram": "retilintar",
    "retilintaras": "retilintar",
    "retilintardes": "retilintar",
    "retilintarei": "retilintar",
    "retilintareis": "retilintar",
    "retilintarem": "retilintar",
    "retilintaremos": "retilintar",
    "retilintares": "retilintar",
    "retilintaria": "retilintar",
    "retilintariam": "retilintar",
    "retilintarias": "retilintar",
    "retilintarmo": "retilintar",
    "retilintarmos": "retilintar",
    "retilintará": "retilintar",
    "retilintarás": "retilintar",
    "retilintarão": "retilintar",
    "retilintaríamos": "retilintar",
    "retilintaríeis": "retilintar",
    "retilintas": "retilintar",
    "retilintasse": "retilintar",
    "retilintassem": "retilintar",
    "retilintasses": "retilintar",
    "retilintaste": "retilintar",
    "retilintastes": "retilintar",
    "retilintava": "retilintar",
    "retilintavam": "retilintar",
    "retilintavas": "retilintar",
    "retilinte": "retilintar",
    "retilintei": "retilintar",
    "retilinteis": "retilintar",
    "retilintem": "retilintar",
    "retilintemo": "retilintar",
    "retilintemos": "retilintar",
    "retilintes": "retilintar",
    "retilinto": "retilintar",
    "retilintou": "retilintar",
    "retilintámo": "retilintar",
    "retilintámos": "retilintar",
    "retilintáramo": "retilintar",
    "retilintáramos": "retilintar",
    "retilintáreis": "retilintar",
    "retilintásseis": "retilintar",
    "retilintássemos": "retilintar",
    "retilintávamo": "retilintar",
    "retilintávamos": "retilintar",
    "retilintáveis": "retilintar",
    "retina": "retinir",
    "retinais": "retinir",
    "retinam": "retinir",
    "retinamo": "retinir",
    "retinamos": "retinir",
    "retinas": "retinir",
    "retine": "retinir",
    "retinem": "retinir",
    "retinentes": "retinente",
    "retines": "retinir",
    "retinge": "retingir",
    "retingem": "retingir",
    "retinges": "retingir",
    "retingi": "retingir",
    "retingia": "retingir",
    "retingiam": "retingir",
    "retingias": "retingir",
    "retingida": "retingir",
    "retingidas": "retingir",
    "retingido": "retingir",
    "retingidos": "retingir",
    "retingimo": "retingir",
    "retingimos": "retingir",
    "retingindo": "retingir",
    "retingira": "retingir",
    "retingiram": "retingir",
    "retingiras": "retingir",
    "retingirde": "retingir",
    "retingirdes": "retingir",
    "retingire": "retingir",
    "retingirei": "retingir",
    "retingireis": "retingir",
    "retingirem": "retingir",
    "retingiremos": "retingir",
    "retingires": "retingir",
    "retingiria": "retingir",
    "retingiriam": "retingir",
    "retingirias": "retingir",
    "retingirmo": "retingir",
    "retingirmos": "retingir",
    "retingirá": "retingir",
    "retingirás": "retingir",
    "retingirão": "retingir",
    "retingiríamos": "retingir",
    "retingiríeis": "retingir",
    "retingis": "retingir",
    "retingisse": "retingir",
    "retingissem": "retingir",
    "retingisses": "retingir",
    "retingiste": "retingir",
    "retingistes": "retingir",
    "retingiu": "retingir",
    "retingíamo": "retingir",
    "retingíamos": "retingir",
    "retingíei": "retingir",
    "retingíeis": "retingir",
    "retingíramo": "retingir",
    "retingíramos": "retingir",
    "retingírei": "retingir",
    "retingíreis": "retingir",
    "retingísseis": "retingir",
    "retingíssemos": "retingir",
    "retinha": "reter",
    "retinham": "reter",
    "retinhas": "reter",
    "retini": "retinir",
    "retinia": "retinir",
    "retiniam": "retinir",
    "retiniana": "retiniano",
    "retinianas": "retiniano",
    "retinianos": "retiniano",
    "retinias": "retinir",
    "retinida": "retinir",
    "retinidas": "retinir",
    "retinido": "retinir",
    "retinidos": "retinir",
    "retinimo": "retinir",
    "retinimos": "retinir",
    "retinindo": "retinir",
    "retinira": "retinir",
    "retiniram": "retinir",
    "retiniras": "retinir",
    "retinirdes": "retinir",
    "retinirei": "retinir",
    "retinireis": "retinir",
    "retinirem": "retinir",
    "retiniremos": "retinir",
    "retinires": "retinir",
    "retiniria": "retinir",
    "retiniriam": "retinir",
    "retinirias": "retinir",
    "retinirmo": "retinir",
    "retinirmos": "retinir",
    "retinirá": "retinir",
    "retinirás": "retinir",
    "retinirão": "retinir",
    "retiniríamos": "retinir",
    "retiniríeis": "retinir",
    "retinis": "retinir",
    "retinisse": "retinir",
    "retinissem": "retinir",
    "retinisses": "retinir",
    "retiniste": "retinir",
    "retinistes": "retinir",
    "retinites": "retinite",
    "retinitos": "retinito",
    "retiniu": "retinir",
    "retinja": "retingir",
    "retinjais": "retingir",
    "retinjam": "retingir",
    "retinjamo": "retingir",
    "retinjamos": "retingir",
    "retinjas": "retingir",
    "retinjo": "retingir",
    "retino": "retinir",
    "retinta": "retinto",
    "retintais": "retintir",
    "retintam": "retintir",
    "retintamo": "retintir",
    "retintamos": "retintir",
    "retintas": "retinto",
    "retinte": "retintir",
    "retintem": "retintir",
    "retintes": "retintir",
    "retinti": "retintir",
    "retintia": "retintir",
    "retintiam": "retintir",
    "retintias": "retintir",
    "retintida": "retintir",
    "retintidas": "retintir",
    "retintido": "retintir",
    "retintidos": "retintir",
    "retintimo": "retintir",
    "retintimos": "retintir",
    "retintindo": "retintir",
    "retintins": "retintim",
    "retintira": "retintir",
    "retintiram": "retintir",
    "retintiras": "retintir",
    "retintirdes": "retintir",
    "retintirei": "retintir",
    "retintireis": "retintir",
    "retintirem": "retintir",
    "retintiremos": "retintir",
    "retintires": "retintir",
    "retintiria": "retintir",
    "retintiriam": "retintir",
    "retintirias": "retintir",
    "retintirmo": "retintir",
    "retintirmos": "retintir",
    "retintirá": "retintir",
    "retintirás": "retintir",
    "retintirão": "retintir",
    "retintiríamos": "retintir",
    "retintiríeis": "retintir",
    "retintis": "retintir",
    "retintisse": "retintir",
    "retintissem": "retintir",
    "retintisses": "retintir",
    "retintiste": "retintir",
    "retintistes": "retintir",
    "retintiu": "retintir",
    "retinto": "retintir",
    "retintos": "retinto",
    "retintíamo": "retintir",
    "retintíamos": "retintir",
    "retintíeis": "retintir",
    "retintíramo": "retintir",
    "retintíramos": "retintir",
    "retintíreis": "retintir",
    "retintísseis": "retintir",
    "retintíssemos": "retintir",
    "retintórios": "retintório",
    "retináculos": "retináculo",
    "retinérvea": "retinérveo",
    "retinérveas": "retinérveo",
    "retinérveos": "retinérveo",
    "retinências": "retinência",
    "retiníamo": "retinir",
    "retiníamos": "retinir",
    "retiníeis": "retinir",
    "retiníramo": "retinir",
    "retiníramos": "retinir",
    "retiníreis": "retinir",
    "retinísseis": "retinir",
    "retiníssemos": "retinir",
    "retira": "retirar",
    "retirada": "retirar",
    "retiradas": "retirar",
    "retiradazinha": "retirado",
    "retiradazinhas": "retirado",
    "retiradazita": "retirado",
    "retiradazitas": "retirado",
    "retiradinha": "retirado",
    "retiradinhas": "retirado",
    "retiradinho": "retirado",
    "retiradinhos": "retirado",
    "retiradita": "retirado",
    "retiraditas": "retirado",
    "retiradito": "retirado",
    "retiraditos": "retirado",
    "retirado": "retirar",
    "retirados": "retirar",
    "retiradozinho": "retirado",
    "retiradozinhos": "retirado",
    "retiradozito": "retirado",
    "retiradozitos": "retirado",
    "retiradíssima": "retirado",
    "retiradíssimas": "retirado",
    "retiradíssimo": "retirado",
    "retiradíssimos": "retirado",
    "retirai": "retirar",
    "retirais": "retirar",
    "retiram": "retirar",
    "retiramentos": "retiramento",
    "retiramo": "retirar",
    "retiramos": "retirar",
    "retirando": "retirar",
    "retirara": "retirar",
    "retiraram": "retirar",
    "retiraras": "retirar",
    "retirarde": "retirar",
    "retirardes": "retirar",
    "retirare": "retirar",
    "retirarei": "retirar",
    "retirareis": "retirar",
    "retirarem": "retirar",
    "retiraremos": "retirar",
    "retirares": "retirar",
    "retiraria": "retirar",
    "retirariam": "retirar",
    "retirarias": "retirar",
    "retirarmo": "retirar",
    "retirarmos": "retirar",
    "retirará": "retirar",
    "retirarás": "retirar",
    "retirarão": "retirar",
    "retiraríamos": "retirar",
    "retiraríeis": "retirar",
    "retiras": "retirar",
    "retirasse": "retirar",
    "retirassem": "retirar",
    "retirasses": "retirar",
    "retiraste": "retirar",
    "retirastes": "retirar",
    "retirava": "retirar",
    "retiravam": "retirar",
    "retiravas": "retirar",
    "retirações": "retiração",
    "retire": "retirar",
    "retirei": "retirar",
    "retireis": "retirar",
    "retirem": "retirar",
    "retiremo": "retirar",
    "retiremos": "retirar",
    "retires": "retirar",
    "retiro": "retirar",
    "retiros": "retiro",
    "retirou": "retirar",
    "retirá": "retirar",
    "retirámo": "retirar",
    "retirámos": "retirar",
    "retiráramo": "retirar",
    "retiráramos": "retirar",
    "retirárei": "retirar",
    "retiráreis": "retirar",
    "retirásseis": "retirar",
    "retirássemos": "retirar",
    "retirávamo": "retirar",
    "retirávamos": "retirar",
    "retirávei": "retirar",
    "retiráveis": "retirável",
    "retive": "reter",
    "retivemo": "reter",
    "retivemos": "reter",
    "retiver": "reter",
    "retivera": "reter",
    "retiveram": "reter",
    "retiveras": "reter",
    "retiverdes": "reter",
    "retiverem": "reter",
    "retiveres": "reter",
    "retivermos": "reter",
    "retivesse": "reter",
    "retivessem": "reter",
    "retivesses": "reter",
    "retiveste": "reter",
    "retivestes": "reter",
    "retivéramo": "reter",
    "retivéramos": "reter",
    "retivérei": "reter",
    "retivéreis": "reter",
    "retivésseis": "reter",
    "retivéssemos": "reter",
    "retoca": "retocar",
    "retocada": "retocar",
    "retocadas": "retocar",
    "retocado": "retocar",
    "retocadora": "retocador",
    "retocadoras": "retocador",
    "retocadores": "retocador",
    "retocados": "retocar",
    "retocai": "retocar",
    "retocais": "retocar",
    "retocam": "retocar",
    "retocamo": "retocar",
    "retocamos": "retocar",
    "retocando": "retocar",
    "retocara": "retocar",
    "retocaram": "retocar",
    "retocaras": "retocar",
    "retocarde": "retocar",
    "retocardes": "retocar",
    "retocare": "retocar",
    "retocarei": "retocar",
    "retocareis": "retocar",
    "retocarem": "retocar",
    "retocaremos": "retocar",
    "retocares": "retocar",
    "retocaria": "retocar",
    "retocariam": "retocar",
    "retocarias": "retocar",
    "retocarmo": "retocar",
    "retocarmos": "retocar",
    "retocará": "retocar",
    "retocarás": "retocar",
    "retocarão": "retocar",
    "retocaríamos": "retocar",
    "retocaríeis": "retocar",
    "retocas": "retocar",
    "retocasse": "retocar",
    "retocassem": "retocar",
    "retocasses": "retocar",
    "retocaste": "retocar",
    "retocastes": "retocar",
    "retocava": "retocar",
    "retocavam": "retocar",
    "retocavas": "retocar",
    "retoco": "retocar",
    "retocou": "retocar",
    "retocá": "retocar",
    "retocámo": "retocar",
    "retocámos": "retocar",
    "retocáramo": "retocar",
    "retocáramos": "retocar",
    "retocárei": "retocar",
    "retocáreis": "retocar",
    "retocásseis": "retocar",
    "retocássemos": "retocar",
    "retocávamo": "retocar",
    "retocávamos": "retocar",
    "retocávei": "retocar",
    "retocáveis": "retocável",
    "retoice": "retoiçar",
    "retoicei": "retoiçar",
    "retoiceis": "retoiçar",
    "retoicem": "retoiçar",
    "retoicemo": "retoiçar",
    "retoicemos": "retoiçar",
    "retoices": "retoiçar",
    "retoiça": "retoiçar",
    "retoiçada": "retoiçar",
    "retoiçadas": "retoiçar",
    "retoiçado": "retoiçar",
    "retoiçadora": "retoiçador",
    "retoiçadoras": "retoiçador",
    "retoiçadores": "retoiçador",
    "retoiçados": "retoiçar",
    "retoiçai": "retoiçar",
    "retoiçais": "retoiçar",
    "retoiçam": "retoiçar",
    "retoiçamo": "retoiçar",
    "retoiçamos": "retoiçar",
    "retoiçando": "retoiçar",
    "retoiçara": "retoiçar",
    "retoiçaram": "retoiçar",
    "retoiçaras": "retoiçar",
    "retoiçarde": "retoiçar",
    "retoiçardes": "retoiçar",
    "retoiçare": "retoiçar",
    "retoiçarei": "retoiçar",
    "retoiçareis": "retoiçar",
    "retoiçarem": "retoiçar",
    "retoiçaremos": "retoiçar",
    "retoiçares": "retoiçar",
    "retoiçaria": "retoiçar",
    "retoiçariam": "retoiçar",
    "retoiçarias": "retoiçar",
    "retoiçarmo": "retoiçar",
    "retoiçarmos": "retoiçar",
    "retoiçará": "retoiçar",
    "retoiçarás": "retoiçar",
    "retoiçarão": "retoiçar",
    "retoiçaríamos": "retoiçar",
    "retoiçaríeis": "retoiçar",
    "retoiças": "retoiçar",
    "retoiçasse": "retoiçar",
    "retoiçassem": "retoiçar",
    "retoiçasses": "retoiçar",
    "retoiçaste": "retoiçar",
    "retoiçastes": "retoiçar",
    "retoiçava": "retoiçar",
    "retoiçavam": "retoiçar",
    "retoiçavas": "retoiçar",
    "retoiço": "retoiçar",
    "retoiçoa": "retoição",
    "retoiçoas": "retoição",
    "retoiçona": "retoição",
    "retoiçonas": "retoição",
    "retoiços": "retoiço",
    "retoiçou": "retoiçar",
    "retoiçá": "retoiçar",
    "retoiçámo": "retoiçar",
    "retoiçámos": "retoiçar",
    "retoiçáramo": "retoiçar",
    "retoiçáramos": "retoiçar",
    "retoiçárei": "retoiçar",
    "retoiçáreis": "retoiçar",
    "retoiçásseis": "retoiçar",
    "retoiçássemos": "retoiçar",
    "retoiçávamo": "retoiçar",
    "retoiçávamos": "retoiçar",
    "retoiçávei": "retoiçar",
    "retoiçáveis": "retoiçar",
    "retoições": "retoição",
    "retoma": "retomar",
    "retomada": "retomar",
    "retomadas": "retomar",
    "retomado": "retomar",
    "retomados": "retomar",
    "retomai": "retomar",
    "retomais": "retomar",
    "retomam": "retomar",
    "retomamo": "retomar",
    "retomamos": "retomar",
    "retomando": "retomar",
    "retomara": "retomar",
    "retomaram": "retomar",
    "retomaras": "retomar",
    "retomarde": "retomar",
    "retomardes": "retomar",
    "retomare": "retomar",
    "retomarei": "retomar",
    "retomareis": "retomar",
    "retomarem": "retomar",
    "retomaremos": "retomar",
    "retomares": "retomar",
    "retomaria": "retomar",
    "retomariam": "retomar",
    "retomarias": "retomar",
    "retomarmo": "retomar",
    "retomarmos": "retomar",
    "retomará": "retomar",
    "retomarás": "retomar",
    "retomarão": "retomar",
    "retomaríamos": "retomar",
    "retomaríeis": "retomar",
    "retomas": "retomar",
    "retomasse": "retomar",
    "retomassem": "retomar",
    "retomasses": "retomar",
    "retomaste": "retomar",
    "retomastes": "retomar",
    "retomava": "retomar",
    "retomavam": "retomar",
    "retomavas": "retomar",
    "retome": "retomar",
    "retomei": "retomar",
    "retomeis": "retomar",
    "retomem": "retomar",
    "retomemo": "retomar",
    "retomemos": "retomar",
    "retomes": "retomar",
    "retomo": "retomar",
    "retomou": "retomar",
    "retomá": "retomar",
    "retomámo": "retomar",
    "retomámos": "retomar",
    "retomáramo": "retomar",
    "retomáramos": "retomar",
    "retomárei": "retomar",
    "retomáreis": "retomar",
    "retomásseis": "retomar",
    "retomássemos": "retomar",
    "retomávamo": "retomar",
    "retomávamos": "retomar",
    "retomávei": "retomar",
    "retomáveis": "retomável",
    "retoque": "retocar",
    "retoquei": "retocar",
    "retoqueis": "retocar",
    "retoquem": "retocar",
    "retoquemo": "retocar",
    "retoquemos": "retocar",
    "retoques": "retoque",
    "retorce": "retorcer",
    "retorcedeiras": "retorcedeira",
    "retorceduras": "retorcedura",
    "retorcei": "retorcer",
    "retorceis": "retorcer",
    "retorcem": "retorcer",
    "retorcemo": "retorcer",
    "retorcemos": "retorcer",
    "retorcendo": "retorcer",
    "retorcera": "retorcer",
    "retorceram": "retorcer",
    "retorceras": "retorcer",
    "retorcerde": "retorcer",
    "retorcerdes": "retorcer",
    "retorcere": "retorcer",
    "retorcerei": "retorcer",
    "retorcereis": "retorcer",
    "retorcerem": "retorcer",
    "retorceremos": "retorcer",
    "retorceres": "retorcer",
    "retorceria": "retorcer",
    "retorceriam": "retorcer",
    "retorcerias": "retorcer",
    "retorcermo": "retorcer",
    "retorcermos": "retorcer",
    "retorcerá": "retorcer",
    "retorcerás": "retorcer",
    "retorcerão": "retorcer",
    "retorceríamos": "retorcer",
    "retorceríeis": "retorcer",
    "retorces": "retorcer",
    "retorcesse": "retorcer",
    "retorcessem": "retorcer",
    "retorcesses": "retorcer",
    "retorceste": "retorcer",
    "retorcestes": "retorcer",
    "retorceu": "retorcer",
    "retorci": "retorcer",
    "retorcia": "retorcer",
    "retorciam": "retorcer",
    "retorcias": "retorcer",
    "retorcida": "retorcido",
    "retorcidas": "retorcido",
    "retorcidazinha": "retorcido",
    "retorcidazinhas": "retorcido",
    "retorcidazita": "retorcido",
    "retorcidazitas": "retorcido",
    "retorcidinha": "retorcido",
    "retorcidinhas": "retorcido",
    "retorcidinho": "retorcido",
    "retorcidinhos": "retorcido",
    "retorcidita": "retorcido",
    "retorciditas": "retorcido",
    "retorcidito": "retorcido",
    "retorciditos": "retorcido",
    "retorcido": "retorcer",
    "retorcidos": "retorcido",
    "retorcidozinho": "retorcido",
    "retorcidozinhos": "retorcido",
    "retorcidozito": "retorcido",
    "retorcidozitos": "retorcido",
    "retorcidíssima": "retorcido",
    "retorcidíssimas": "retorcido",
    "retorcidíssimo": "retorcido",
    "retorcidíssimos": "retorcido",
    "retorcê": "retorcer",
    "retorcêramo": "retorcer",
    "retorcêramos": "retorcer",
    "retorcêrei": "retorcer",
    "retorcêreis": "retorcer",
    "retorcêsseis": "retorcer",
    "retorcêssemos": "retorcer",
    "retorcíamo": "retorcer",
    "retorcíamos": "retorcer",
    "retorcíei": "retorcer",
    "retorcíeis": "retorcer",
    "retores": "retor",
    "retorica": "retoricar",
    "retoricada": "retoricar",
    "retoricadas": "retoricar",
    "retoricado": "retoricar",
    "retoricados": "retoricar",
    "retoricais": "retoricar",
    "retoricam": "retoricar",
    "retoricamo": "retoricar",
    "retoricamos": "retoricar",
    "retoricando": "retoricar",
    "retoricara": "retoricar",
    "retoricaram": "retoricar",
    "retoricaras": "retoricar",
    "retoricardes": "retoricar",
    "retoricarei": "retoricar",
    "retoricareis": "retoricar",
    "retoricarem": "retoricar",
    "retoricaremos": "retoricar",
    "retoricares": "retoricar",
    "retoricaria": "retoricar",
    "retoricariam": "retoricar",
    "retoricarias": "retoricar",
    "retoricarmo": "retoricar",
    "retoricarmos": "retoricar",
    "retoricará": "retoricar",
    "retoricarás": "retoricar",
    "retoricarão": "retoricar",
    "retoricaríamos": "retoricar",
    "retoricaríeis": "retoricar",
    "retoricas": "retoricar",
    "retoricasse": "retoricar",
    "retoricassem": "retoricar",
    "retoricasses": "retoricar",
    "retoricaste": "retoricar",
    "retoricastes": "retoricar",
    "retoricava": "retoricar",
    "retoricavam": "retoricar",
    "retoricavas": "retoricar",
    "retoricismos": "retoricismo",
    "retorico": "retoricar",
    "retoricona": "retoricão",
    "retoriconas": "retoricão",
    "retoricou": "retoricar",
    "retoricámo": "retoricar",
    "retoricámos": "retoricar",
    "retoricáramo": "retoricar",
    "retoricáramos": "retoricar",
    "retoricáreis": "retoricar",
    "retoricásseis": "retoricar",
    "retoricássemos": "retoricar",
    "retoricávamo": "retoricar",
    "retoricávamos": "retoricar",
    "retoricáveis": "retoricar",
    "retoricões": "retoricão",
    "retorique": "retoricar",
    "retoriquei": "retoricar",
    "retoriqueis": "retoricar",
    "retoriquem": "retoricar",
    "retoriquemos": "retoricar",
    "retoriques": "retoricar",
    "retorismos": "retorismo",
    "retorna": "retornar",
    "retornada": "retornar",
    "retornadas": "retornar",
    "retornado": "retornar",
    "retornados": "retornar",
    "retornai": "retornar",
    "retornais": "retornar",
    "retornam": "retornar",
    "retornamentos": "retornamento",
    "retornamo": "retornar",
    "retornamos": "retornar",
    "retornando": "retornar",
    "retornanças": "retornança",
    "retornara": "retornar",
    "retornaram": "retornar",
    "retornaras": "retornar",
    "retornardes": "retornar",
    "retornarei": "retornar",
    "retornareis": "retornar",
    "retornarem": "retornar",
    "retornaremos": "retornar",
    "retornares": "retornar",
    "retornaria": "retornar",
    "retornariam": "retornar",
    "retornarias": "retornar",
    "retornarmo": "retornar",
    "retornarmos": "retornar",
    "retornará": "retornar",
    "retornarás": "retornar",
    "retornarão": "retornar",
    "retornaríamos": "retornar",
    "retornaríeis": "retornar",
    "retornas": "retornar",
    "retornasse": "retornar",
    "retornassem": "retornar",
    "retornasses": "retornar",
    "retornaste": "retornar",
    "retornastes": "retornar",
    "retornava": "retornar",
    "retornavam": "retornar",
    "retornavas": "retornar",
    "retorne": "retornar",
    "retornei": "retornar",
    "retorneis": "retornar",
    "retornelos": "retornelo",
    "retornem": "retornar",
    "retornemo": "retornar",
    "retornemos": "retornar",
    "retornes": "retornar",
    "retorno": "retornar",
    "retornos": "retorno",
    "retornou": "retornar",
    "retornámo": "retornar",
    "retornámos": "retornar",
    "retornáramo": "retornar",
    "retornáramos": "retornar",
    "retornáreis": "retornar",
    "retornásseis": "retornar",
    "retornássemos": "retornar",
    "retornávamo": "retornar",
    "retornávamos": "retornar",
    "retornáveis": "retornável",
    "retorque": "retorquir",
    "retorquem": "retorquir",
    "retorques": "retorquir",
    "retorqui": "retorquir",
    "retorquia": "retorquir",
    "retorquiam": "retorquir",
    "retorquias": "retorquir",
    "retorquida": "retorquir",
    "retorquidas": "retorquir",
    "retorquido": "retorquir",
    "retorquidos": "retorquir",
    "retorquimo": "retorquir",
    "retorquimos": "retorquir",
    "retorquindo": "retorquir",
    "retorquira": "retorquir",
    "retorquiram": "retorquir",
    "retorquiras": "retorquir",
    "retorquirde": "retorquir",
    "retorquirdes": "retorquir",
    "retorquire": "retorquir",
    "retorquirei": "retorquir",
    "retorquireis": "retorquir",
    "retorquirem": "retorquir",
    "retorquiremos": "retorquir",
    "retorquires": "retorquir",
    "retorquiria": "retorquir",
    "retorquiriam": "retorquir",
    "retorquirias": "retorquir",
    "retorquirmo": "retorquir",
    "retorquirmos": "retorquir",
    "retorquirá": "retorquir",
    "retorquirás": "retorquir",
    "retorquirão": "retorquir",
    "retorquiríamos": "retorquir",
    "retorquiríeis": "retorquir",
    "retorquis": "retorquir",
    "retorquisse": "retorquir",
    "retorquissem": "retorquir",
    "retorquisses": "retorquir",
    "retorquiste": "retorquir",
    "retorquistes": "retorquir",
    "retorquiu": "retorquir",
    "retorquíamo": "retorquir",
    "retorquíamos": "retorquir",
    "retorquíei": "retorquir",
    "retorquíeis": "retorquir",
    "retorquíramo": "retorquir",
    "retorquíramos": "retorquir",
    "retorquírei": "retorquir",
    "retorquíreis": "retorquir",
    "retorquísseis": "retorquir",
    "retorquíssemos": "retorquir",
    "retorquíveis": "retorquível",
    "retorsões": "retorsão",
    "retorta": "retorto",
    "retortas": "retorto",
    "retortos": "retorto",
    "retorça": "retorcer",
    "retorçais": "retorcer",
    "retorçam": "retorcer",
    "retorçamo": "retorcer",
    "retorçamos": "retorcer",
    "retorças": "retorcer",
    "retorço": "retorcer",
    "retorções": "retorção",
    "retosta": "retostar",
    "retostada": "retostar",
    "retostadas": "retostar",
    "retostado": "retostar",
    "retostados": "retostar",
    "retostai": "retostar",
    "retostais": "retostar",
    "retostam": "retostar",
    "retostamo": "retostar",
    "retostamos": "retostar",
    "retostando": "retostar",
    "retostara": "retostar",
    "retostaram": "retostar",
    "retostaras": "retostar",
    "retostarde": "retostar",
    "retostardes": "retostar",
    "retostare": "retostar",
    "retostarei": "retostar",
    "retostareis": "retostar",
    "retostarem": "retostar",
    "retostaremos": "retostar",
    "retostares": "retostar",
    "retostaria": "retostar",
    "retostariam": "retostar",
    "retostarias": "retostar",
    "retostarmo": "retostar",
    "retostarmos": "retostar",
    "retostará": "retostar",
    "retostarás": "retostar",
    "retostarão": "retostar",
    "retostaríamos": "retostar",
    "retostaríeis": "retostar",
    "retostas": "retostar",
    "retostasse": "retostar",
    "retostassem": "retostar",
    "retostasses": "retostar",
    "retostaste": "retostar",
    "retostastes": "retostar",
    "retostava": "retostar",
    "retostavam": "retostar",
    "retostavas": "retostar",
    "retoste": "retostar",
    "retostei": "retostar",
    "retosteis": "retostar",
    "retostem": "retostar",
    "retostemo": "retostar",
    "retostemos": "retostar",
    "retostes": "retostar",
    "retosto": "retostar",
    "retostou": "retostar",
    "retostá": "retostar",
    "retostámo": "retostar",
    "retostámos": "retostar",
    "retostáramo": "retostar",
    "retostáramos": "retostar",
    "retostárei": "retostar",
    "retostáreis": "retostar",
    "retostásseis": "retostar",
    "retostássemos": "retostar",
    "retostávamo": "retostar",
    "retostávamos": "retostar",
    "retostávei": "retostar",
    "retostáveis": "retostar",
    "retouca": "retoucar",
    "retoucada": "retoucar",
    "retoucadas": "retoucar",
    "retoucado": "retoucar",
    "retoucados": "retoucar",
    "retoucai": "retoucar",
    "retoucais": "retoucar",
    "retoucam": "retoucar",
    "retoucamo": "retoucar",
    "retoucamos": "retoucar",
    "retoucando": "retoucar",
    "retoucara": "retoucar",
    "retoucaram": "retoucar",
    "retoucaras": "retoucar",
    "retoucarde": "retoucar",
    "retoucardes": "retoucar",
    "retoucare": "retoucar",
    "retoucarei": "retoucar",
    "retoucareis": "retoucar",
    "retoucarem": "retoucar",
    "retoucaremos": "retoucar",
    "retoucares": "retoucar",
    "retoucaria": "retoucar",
    "retoucariam": "retoucar",
    "retoucarias": "retoucar",
    "retoucarmo": "retoucar",
    "retoucarmos": "retoucar",
    "retoucará": "retoucar",
    "retoucarás": "retoucar",
    "retoucarão": "retoucar",
    "retoucaríamos": "retoucar",
    "retoucaríeis": "retoucar",
    "retoucas": "retoucar",
    "retoucasse": "retoucar",
    "retoucassem": "retoucar",
    "retoucasses": "retoucar",
    "retoucaste": "retoucar",
    "retoucastes": "retoucar",
    "retoucava": "retoucar",
    "retoucavam": "retoucar",
    "retoucavas": "retoucar",
    "retouce": "retouçar",
    "retoucei": "retouçar",
    "retouceis": "retouçar",
    "retoucem": "retouçar",
    "retoucemo": "retouçar",
    "retoucemos": "retouçar",
    "retouces": "retouçar",
    "retouco": "retoucar",
    "retoucou": "retoucar",
    "retoucá": "retoucar",
    "retoucámo": "retoucar",
    "retoucámos": "retoucar",
    "retoucáramo": "retoucar",
    "retoucáramos": "retoucar",
    "retoucárei": "retoucar",
    "retoucáreis": "retoucar",
    "retoucásseis": "retoucar",
    "retoucássemos": "retoucar",
    "retoucávamo": "retoucar",
    "retoucávamos": "retoucar",
    "retoucávei": "retoucar",
    "retoucáveis": "retoucar",
    "retouque": "retoucar",
    "retouquei": "retoucar",
    "retouqueis": "retoucar",
    "retouquem": "retoucar",
    "retouquemo": "retoucar",
    "retouquemos": "retoucar",
    "retouques": "retoucar",
    "retouça": "retouçar",
    "retouçada": "retouçar",
    "retouçadas": "retouçar",
    "retouçado": "retouçar",
    "retouçadora": "retouçador",
    "retouçadoras": "retouçador",
    "retouçadores": "retouçador",
    "retouçados": "retouçar",
    "retouçai": "retouçar",
    "retouçais": "retouçar",
    "retouçam": "retouçar",
    "retouçamo": "retouçar",
    "retouçamos": "retouçar",
    "retouçando": "retouçar",
    "retouçara": "retouçar",
    "retouçaram": "retouçar",
    "retouçaras": "retouçar",
    "retouçardes": "retouçar",
    "retouçarei": "retouçar",
    "retouçareis": "retouçar",
    "retouçarem": "retouçar",
    "retouçaremos": "retouçar",
    "retouçares": "retouçar",
    "retouçaria": "retouçar",
    "retouçariam": "retouçar",
    "retouçarias": "retouçar",
    "retouçarmo": "retouçar",
    "retouçarmos": "retouçar",
    "retouçará": "retouçar",
    "retouçarás": "retouçar",
    "retouçarão": "retouçar",
    "retouçaríamos": "retouçar",
    "retouçaríeis": "retouçar",
    "retouças": "retouçar",
    "retouçasse": "retouçar",
    "retouçassem": "retouçar",
    "retouçasses": "retouçar",
    "retouçaste": "retouçar",
    "retouçastes": "retouçar",
    "retouçava": "retouçar",
    "retouçavam": "retouçar",
    "retouçavas": "retouçar",
    "retouço": "retouçar",
    "retouçoa": "retoução",
    "retouçoas": "retoução",
    "retouçona": "retoução",
    "retouçonas": "retoução",
    "retouços": "retouço",
    "retouçou": "retouçar",
    "retouçámo": "retouçar",
    "retouçámos": "retouçar",
    "retouçáramo": "retouçar",
    "retouçáramos": "retouçar",
    "retouçáreis": "retouçar",
    "retouçásseis": "retouçar",
    "retouçássemos": "retouçar",
    "retouçávamo": "retouçar",
    "retouçávamos": "retouçar",
    "retouçáveis": "retouçar",
    "retouções": "retoução",
    "retrace": "retraçar",
    "retracei": "retraçar",
    "retraceis": "retraçar",
    "retracem": "retraçar",
    "retracemo": "retraçar",
    "retracemos": "retraçar",
    "retraces": "retraçar",
    "retracta": "retracto",
    "retractada": "retractar",
    "retractadas": "retractar",
    "retractado": "retractar",
    "retractados": "retractar",
    "retractai": "retractar",
    "retractais": "retractar",
    "retractam": "retractar",
    "retractamo": "retractar",
    "retractamos": "retractar",
    "retractando": "retractar",
    "retractara": "retractar",
    "retractaram": "retractar",
    "retractaras": "retractar",
    "retractarde": "retractar",
    "retractardes": "retractar",
    "retractare": "retractar",
    "retractarei": "retractar",
    "retractareis": "retractar",
    "retractarem": "retractar",
    "retractaremos": "retractar",
    "retractares": "retractar",
    "retractaria": "retractar",
    "retractariam": "retractar",
    "retractarias": "retractar",
    "retractarmo": "retractar",
    "retractarmos": "retractar",
    "retractará": "retractar",
    "retractarás": "retractar",
    "retractarão": "retractar",
    "retractaríamos": "retractar",
    "retractaríeis": "retractar",
    "retractas": "retracto",
    "retractasse": "retractar",
    "retractassem": "retractar",
    "retractasses": "retractar",
    "retractaste": "retractar",
    "retractastes": "retractar",
    "retractava": "retractar",
    "retractavam": "retractar",
    "retractavas": "retractar",
    "retractações": "retractação",
    "retracte": "retractar",
    "retractei": "retractar",
    "retracteis": "retractil",
    "retractem": "retractar",
    "retractemo": "retractar",
    "retractemos": "retractar",
    "retractes": "retractar",
    "retractilidades": "retractilidade",
    "retractiva": "retractivo",
    "retractivas": "retractivo",
    "retractivos": "retractivo",
    "retracto": "retractar",
    "retractora": "retractor",
    "retractoras": "retractor",
    "retractores": "retractor",
    "retractos": "retracto",
    "retractou": "retractar",
    "retractá": "retractar",
    "retractámo": "retractar",
    "retractámos": "retractar",
    "retractáramo": "retractar",
    "retractáramos": "retractar",
    "retractárei": "retractar",
    "retractáreis": "retractar",
    "retractásseis": "retractar",
    "retractássemos": "retractar",
    "retractávamo": "retractar",
    "retractávamos": "retractar",
    "retractávei": "retractar",
    "retractáveis": "retractável",
    "retracções": "retracção",
    "retraduz": "retraduzir",
    "retraduza": "retraduzir",
    "retraduzais": "retraduzir",
    "retraduzam": "retraduzir",
    "retraduzamo": "retraduzir",
    "retraduzamos": "retraduzir",
    "retraduzas": "retraduzir",
    "retraduze": "retraduzir",
    "retraduzem": "retraduzir",
    "retraduzes": "retraduzir",
    "retraduzi": "retraduzir",
    "retraduzia": "retraduzir",
    "retraduziam": "retraduzir",
    "retraduzias": "retraduzir",
    "retraduzida": "retraduzir",
    "retraduzidas": "retraduzir",
    "retraduzido": "retraduzir",
    "retraduzidos": "retraduzir",
    "retraduzimo": "retraduzir",
    "retraduzimos": "retraduzir",
    "retraduzindo": "retraduzir",
    "retraduzira": "retraduzir",
    "retraduziram": "retraduzir",
    "retraduziras": "retraduzir",
    "retraduzirde": "retraduzir",
    "retraduzirdes": "retraduzir",
    "retraduzire": "retraduzir",
    "retraduzirei": "retraduzir",
    "retraduzireis": "retraduzir",
    "retraduzirem": "retraduzir",
    "retraduziremos": "retraduzir",
    "retraduzires": "retraduzir",
    "retraduziria": "retraduzir",
    "retraduziriam": "retraduzir",
    "retraduzirias": "retraduzir",
    "retraduzirmo": "retraduzir",
    "retraduzirmos": "retraduzir",
    "retraduzirá": "retraduzir",
    "retraduzirás": "retraduzir",
    "retraduzirão": "retraduzir",
    "retraduziríamos": "retraduzir",
    "retraduziríeis": "retraduzir",
    "retraduzis": "retraduzir",
    "retraduzisse": "retraduzir",
    "retraduzissem": "retraduzir",
    "retraduzisses": "retraduzir",
    "retraduziste": "retraduzir",
    "retraduzistes": "retraduzir",
    "retraduziu": "retraduzir",
    "retraduzo": "retraduzir",
    "retraduzíamo": "retraduzir",
    "retraduzíamos": "retraduzir",
    "retraduzíei": "retraduzir",
    "retraduzíeis": "retraduzir",
    "retraduzíramo": "retraduzir",
    "retraduzíramos": "retraduzir",
    "retraduzírei": "retraduzir",
    "retraduzíreis": "retraduzir",
    "retraduzísseis": "retraduzir",
    "retraduzíssemos": "retraduzir",
    "retraduções": "retradução",
    "retraem": "retrair",
    "retraga": "retrazer",
    "retragais": "retrazer",
    "retragam": "retrazer",
    "retragamo": "retrazer",
    "retragamos": "retrazer",
    "retragas": "retrazer",
    "retrago": "retrazer",
    "retrai": "retrair",
    "retraia": "retrair",
    "retraiais": "retrair",
    "retraiam": "retrair",
    "retraiamo": "retrair",
    "retraiamos": "retrair",
    "retraias": "retrair",
    "retraidazinha": "retraído",
    "retraidazinhas": "retraído",
    "retraidazita": "retraído",
    "retraidazitas": "retraído",
    "retraidinha": "retraído",
    "retraidinhas": "retraído",
    "retraidinho": "retraído",
    "retraidinhos": "retraído",
    "retraidita": "retraído",
    "retraiditas": "retraído",
    "retraidito": "retraído",
    "retraiditos": "retraído",
    "retraidozinho": "retraído",
    "retraidozinhos": "retraído",
    "retraidozito": "retraído",
    "retraidozitos": "retraído",
    "retraidíssima": "retraído",
    "retraidíssimas": "retraído",
    "retraidíssimo": "retraído",
    "retraidíssimos": "retraído",
    "retraimentos": "retraimento",
    "retraindo": "retrair",
    "retraio": "retrair",
    "retrairde": "retrair",
    "retrairdes": "retrair",
    "retrairei": "retrair",
    "retraireis": "retrair",
    "retrairemos": "retrair",
    "retrairia": "retrair",
    "retrairiam": "retrair",
    "retrairias": "retrair",
    "retrairmo": "retrair",
    "retrairmos": "retrair",
    "retrairá": "retrair",
    "retrairás": "retrair",
    "retrairão": "retrair",
    "retrairíamos": "retrair",
    "retrairíeis": "retrair",
    "retrais": "retrair",
    "retraiu": "retrair",
    "retrama": "retramar",
    "retramada": "retramar",
    "retramadas": "retramar",
    "retramado": "retramar",
    "retramados": "retramar",
    "retramai": "retramar",
    "retramais": "retramar",
    "retramam": "retramar",
    "retramamo": "retramar",
    "retramamos": "retramar",
    "retramando": "retramar",
    "retramara": "retramar",
    "retramaram": "retramar",
    "retramaras": "retramar",
    "retramarde": "retramar",
    "retramardes": "retramar",
    "retramare": "retramar",
    "retramarei": "retramar",
    "retramareis": "retramar",
    "retramarem": "retramar",
    "retramaremos": "retramar",
    "retramares": "retramar",
    "retramaria": "retramar",
    "retramariam": "retramar",
    "retramarias": "retramar",
    "retramarmo": "retramar",
    "retramarmos": "retramar",
    "retramará": "retramar",
    "retramarás": "retramar",
    "retramarão": "retramar",
    "retramaríamos": "retramar",
    "retramaríeis": "retramar",
    "retramas": "retramar",
    "retramasse": "retramar",
    "retramassem": "retramar",
    "retramasses": "retramar",
    "retramaste": "retramar",
    "retramastes": "retramar",
    "retramava": "retramar",
    "retramavam": "retramar",
    "retramavas": "retramar",
    "retrame": "retramar",
    "retramei": "retramar",
    "retrameis": "retramar",
    "retramem": "retramar",
    "retramemo": "retramar",
    "retramemos": "retramar",
    "retrames": "retramar",
    "retramo": "retramar",
    "retramou": "retramar",
    "retramá": "retramar",
    "retramámo": "retramar",
    "retramámos": "retramar",
    "retramáramo": "retramar",
    "retramáramos": "retramar",
    "retramárei": "retramar",
    "retramáreis": "retramar",
    "retramásseis": "retramar",
    "retramássemos": "retramar",
    "retramávamo": "retramar",
    "retramávamos": "retramar",
    "retramávei": "retramar",
    "retramáveis": "retramar",
    "retranca": "retrancar",
    "retrancada": "retrancar",
    "retrancadas": "retrancar",
    "retrancado": "retrancar",
    "retrancados": "retrancar",
    "retrancai": "retrancar",
    "retrancais": "retrancar",
    "retrancam": "retrancar",
    "retrancamo": "retrancar",
    "retrancamos": "retrancar",
    "retrancando": "retrancar",
    "retrancara": "retrancar",
    "retrancaram": "retrancar",
    "retrancaras": "retrancar",
    "retrancarde": "retrancar",
    "retrancardes": "retrancar",
    "retrancare": "retrancar",
    "retrancarei": "retrancar",
    "retrancareis": "retrancar",
    "retrancarem": "retrancar",
    "retrancaremos": "retrancar",
    "retrancares": "retrancar",
    "retrancaria": "retrancar",
    "retrancariam": "retrancar",
    "retrancarias": "retrancar",
    "retrancarmo": "retrancar",
    "retrancarmos": "retrancar",
    "retrancará": "retrancar",
    "retrancarás": "retrancar",
    "retrancarão": "retrancar",
    "retrancaríamos": "retrancar",
    "retrancaríeis": "retrancar",
    "retrancas": "retrancar",
    "retrancasse": "retrancar",
    "retrancassem": "retrancar",
    "retrancasses": "retrancar",
    "retrancaste": "retrancar",
    "retrancastes": "retrancar",
    "retrancava": "retrancar",
    "retrancavam": "retrancar",
    "retrancavas": "retrancar",
    "retrance": "retrançar",
    "retrancei": "retrançar",
    "retranceis": "retrançar",
    "retrancem": "retrançar",
    "retrancemo": "retrançar",
    "retrancemos": "retrançar",
    "retrances": "retrançar",
    "retranco": "retrancar",
    "retrancou": "retrancar",
    "retrancá": "retrancar",
    "retrancámo": "retrancar",
    "retrancámos": "retrancar",
    "retrancáramo": "retrancar",
    "retrancáramos": "retrancar",
    "retrancárei": "retrancar",
    "retrancáreis": "retrancar",
    "retrancásseis": "retrancar",
    "retrancássemos": "retrancar",
    "retrancávamo": "retrancar",
    "retrancávamos": "retrancar",
    "retrancávei": "retrancar",
    "retrancáveis": "retrancar",
    "retranque": "retrancar",
    "retranquei": "retrancar",
    "retranqueis": "retrancar",
    "retranquem": "retrancar",
    "retranquemo": "retrancar",
    "retranquemos": "retrancar",
    "retranques": "retrancar",
    "retransa": "retransir",
    "retransais": "retransir",
    "retransam": "retransir",
    "retransamo": "retransir",
    "retransamos": "retransir",
    "retransas": "retransir",
    "retranse": "retransir",
    "retransem": "retransir",
    "retranses": "retransir",
    "retransi": "retransir",
    "retransia": "retransir",
    "retransiam": "retransir",
    "retransias": "retransir",
    "retransida": "retransir",
    "retransidas": "retransir",
    "retransido": "retransir",
    "retransidos": "retransir",
    "retransimo": "retransir",
    "retransimos": "retransir",
    "retransindo": "retransir",
    "retransira": "retransir",
    "retransiram": "retransir",
    "retransiras": "retransir",
    "retransirde": "retransir",
    "retransirdes": "retransir",
    "retransire": "retransir",
    "retransirei": "retransir",
    "retransireis": "retransir",
    "retransirem": "retransir",
    "retransiremos": "retransir",
    "retransires": "retransir",
    "retransiria": "retransir",
    "retransiriam": "retransir",
    "retransirias": "retransir",
    "retransirmo": "retransir",
    "retransirmos": "retransir",
    "retransirá": "retransir",
    "retransirás": "retransir",
    "retransirão": "retransir",
    "retransiríamos": "retransir",
    "retransiríeis": "retransir",
    "retransis": "retransir",
    "retransisse": "retransir",
    "retransissem": "retransir",
    "retransisses": "retransir",
    "retransiste": "retransir",
    "retransistes": "retransir",
    "retransiu": "retransir",
    "retransmissora": "retransmissor",
    "retransmissoraes": "retransmissora",
    "retransmissoras": "retransmissor",
    "retransmissores": "retransmissor",
    "retransmissíveis": "retransmissível",
    "retransmissões": "retransmissão",
    "retransmita": "retransmitir",
    "retransmitais": "retransmitir",
    "retransmitam": "retransmitir",
    "retransmitamo": "retransmitir",
    "retransmitamos": "retransmitir",
    "retransmitas": "retransmitir",
    "retransmite": "retransmitir",
    "retransmitem": "retransmitir",
    "retransmites": "retransmitir",
    "retransmiti": "retransmitir",
    "retransmitia": "retransmitir",
    "retransmitiam": "retransmitir",
    "retransmitias": "retransmitir",
    "retransmitida": "retransmitir",
    "retransmitidas": "retransmitir",
    "retransmitido": "retransmitir",
    "retransmitidos": "retransmitir",
    "retransmitimo": "retransmitir",
    "retransmitimos": "retransmitir",
    "retransmitindo": "retransmitir",
    "retransmitira": "retransmitir",
    "retransmitiram": "retransmitir",
    "retransmitiras": "retransmitir",
    "retransmitirde": "retransmitir",
    "retransmitirdes": "retransmitir",
    "retransmitire": "retransmitir",
    "retransmitirei": "retransmitir",
    "retransmitireis": "retransmitir",
    "retransmitirem": "retransmitir",
    "retransmitiremos": "retransmitir",
    "retransmitires": "retransmitir",
    "retransmitiria": "retransmitir",
    "retransmitiriam": "retransmitir",
    "retransmitirias": "retransmitir",
    "retransmitirmo": "retransmitir",
    "retransmitirmos": "retransmitir",
    "retransmitirá": "retransmitir",
    "retransmitirás": "retransmitir",
    "retransmitirão": "retransmitir",
    "retransmitiríamos": "retransmitir",
    "retransmitiríeis": "retransmitir",
    "retransmitis": "retransmitir",
    "retransmitisse": "retransmitir",
    "retransmitissem": "retransmitir",
    "retransmitisses": "retransmitir",
    "retransmitiste": "retransmitir",
    "retransmitistes": "retransmitir",
    "retransmitiu": "retransmitir",
    "retransmito": "retransmitir",
    "retransmitíamo": "retransmitir",
    "retransmitíamos": "retransmitir",
    "retransmitíei": "retransmitir",
    "retransmitíeis": "retransmitir",
    "retransmitíramo": "retransmitir",
    "retransmitíramos": "retransmitir",
    "retransmitírei": "retransmitir",
    "retransmitíreis": "retransmitir",
    "retransmitísseis": "retransmitir",
    "retransmitíssemos": "retransmitir",
    "retranso": "retransir",
    "retransíamo": "retransir",
    "retransíamos": "retransir",
    "retransíei": "retransir",
    "retransíeis": "retransir",
    "retransíramo": "retransir",
    "retransíramos": "retransir",
    "retransírei": "retransir",
    "retransíreis": "retransir",
    "retransísseis": "retransir",
    "retransíssemos": "retransir",
    "retrança": "retrançar",
    "retrançada": "retrançar",
    "retrançadas": "retrançar",
    "retrançado": "retrançar",
    "retrançados": "retrançar",
    "retrançai": "retrançar",
    "retrançais": "retrançar",
    "retrançam": "retrançar",
    "retrançamo": "retrançar",
    "retrançamos": "retrançar",
    "retrançando": "retrançar",
    "retrançara": "retrançar",
    "retrançaram": "retrançar",
    "retrançaras": "retrançar",
    "retrançarde": "retrançar",
    "retrançardes": "retrançar",
    "retrançare": "retrançar",
    "retrançarei": "retrançar",
    "retrançareis": "retrançar",
    "retrançarem": "retrançar",
    "retrançaremos": "retrançar",
    "retrançares": "retrançar",
    "retrançaria": "retrançar",
    "retrançariam": "retrançar",
    "retrançarias": "retrançar",
    "retrançarmo": "retrançar",
    "retrançarmos": "retrançar",
    "retrançará": "retrançar",
    "retrançarás": "retrançar",
    "retrançarão": "retrançar",
    "retrançaríamos": "retrançar",
    "retrançaríeis": "retrançar",
    "retranças": "retrançar",
    "retrançasse": "retrançar",
    "retrançassem": "retrançar",
    "retrançasses": "retrançar",
    "retrançaste": "retrançar",
    "retrançastes": "retrançar",
    "retrançava": "retrançar",
    "retrançavam": "retrançar",
    "retrançavas": "retrançar",
    "retranço": "retrançar",
    "retrançou": "retrançar",
    "retrançá": "retrançar",
    "retrançámo": "retrançar",
    "retrançámos": "retrançar",
    "retrançáramo": "retrançar",
    "retrançáramos": "retrançar",
    "retrançárei": "retrançar",
    "retrançáreis": "retrançar",
    "retrançásseis": "retrançar",
    "retrançássemos": "retrançar",
    "retrançávamo": "retrançar",
    "retrançávamos": "retrançar",
    "retrançávei": "retrançar",
    "retrançáveis": "retrançar",
    "retrarei": "retrazer",
    "retrareis": "retrazer",
    "retraremos": "retrazer",
    "retraria": "retrazer",
    "retrariam": "retrazer",
    "retrarias": "retrazer",
    "retrará": "retrazer",
    "retrarás": "retrazer",
    "retrarão": "retrazer",
    "retraríamos": "retrazer",
    "retraríeis": "retrazer",
    "retrata": "retratar",
    "retratabilidades": "retratabilidade",
    "retratada": "retratar",
    "retratadas": "retratar",
    "retratado": "retratar",
    "retratadora": "retratador",
    "retratadoras": "retratador",
    "retratadores": "retratador",
    "retratados": "retratar",
    "retratai": "retratar",
    "retratais": "retratar",
    "retratam": "retratar",
    "retratamo": "retratar",
    "retratamos": "retratar",
    "retratando": "retratar",
    "retratara": "retratar",
    "retrataram": "retratar",
    "retrataras": "retratar",
    "retratarde": "retratar",
    "retratardes": "retratar",
    "retratare": "retratar",
    "retratarei": "retratar",
    "retratareis": "retratar",
    "retratarem": "retratar",
    "retrataremos": "retratar",
    "retratares": "retratar",
    "retrataria": "retratar",
    "retratariam": "retratar",
    "retratarias": "retratar",
    "retratarmo": "retratar",
    "retratarmos": "retratar",
    "retratará": "retratar",
    "retratarás": "retratar",
    "retratarão": "retratar",
    "retrataríamos": "retratar",
    "retrataríeis": "retratar",
    "retratas": "retratar",
    "retratasse": "retratar",
    "retratassem": "retratar",
    "retratasses": "retratar",
    "retrataste": "retratar",
    "retratastes": "retratar",
    "retratava": "retratar",
    "retratavam": "retratar",
    "retratavas": "retratar",
    "retratações": "retratação",
    "retrate": "retratar",
    "retratei": "retratar",
    "retrateis": "retratar",
    "retratem": "retratar",
    "retratemo": "retratar",
    "retratemos": "retratar",
    "retrates": "retratar",
    "retratinho": "retrato",
    "retratinhos": "retrato",
    "retratistas": "retratista",
    "retratito": "retrato",
    "retratitos": "retrato",
    "retrato": "retratar",
    "retratos": "retrato",
    "retratou": "retratar",
    "retratozinho": "retrato",
    "retratozinhos": "retrato",
    "retratozito": "retrato",
    "retratozitos": "retrato",
    "retratuais": "retratual",
    "retratá": "retratar",
    "retratámo": "retratar",
    "retratámos": "retratar",
    "retratáramo": "retratar",
    "retratáramos": "retratar",
    "retratárei": "retratar",
    "retratáreis": "retratar",
    "retratásseis": "retratar",
    "retratássemos": "retratar",
    "retratávamo": "retratar",
    "retratávamos": "retratar",
    "retratávei": "retratar",
    "retratáveis": "retratar",
    "retrava": "retravar",
    "retravada": "retravar",
    "retravadas": "retravar",
    "retravado": "retravar",
    "retravados": "retravar",
    "retravai": "retravar",
    "retravais": "retravar",
    "retravam": "retravar",
    "retravamo": "retravar",
    "retravamos": "retravar",
    "retravando": "retravar",
    "retravara": "retravar",
    "retravaram": "retravar",
    "retravaras": "retravar",
    "retravarde": "retravar",
    "retravardes": "retravar",
    "retravare": "retravar",
    "retravarei": "retravar",
    "retravareis": "retravar",
    "retravarem": "retravar",
    "retravaremos": "retravar",
    "retravares": "retravar",
    "retravaria": "retravar",
    "retravariam": "retravar",
    "retravarias": "retravar",
    "retravarmo": "retravar",
    "retravarmos": "retravar",
    "retravará": "retravar",
    "retravarás": "retravar",
    "retravarão": "retravar",
    "retravaríamos": "retravar",
    "retravaríeis": "retravar",
    "retravas": "retravar",
    "retravasse": "retravar",
    "retravassem": "retravar",
    "retravasses": "retravar",
    "retravaste": "retravar",
    "retravastes": "retravar",
    "retravava": "retravar",
    "retravavam": "retravar",
    "retravavas": "retravar",
    "retrave": "retravar",
    "retravei": "retravar",
    "retraveis": "retravar",
    "retravem": "retravar",
    "retravemo": "retravar",
    "retravemos": "retravar",
    "retraves": "retravar",
    "retravo": "retravar",
    "retravou": "retravar",
    "retravá": "retravar",
    "retravámo": "retravar",
    "retravámos": "retravar",
    "retraváramo": "retravar",
    "retraváramos": "retravar",
    "retravárei": "retravar",
    "retraváreis": "retravar",
    "retravásseis": "retravar",
    "retravássemos": "retravar",
    "retravávamo": "retravar",
    "retravávamos": "retravar",
    "retravávei": "retravar",
    "retraváveis": "retravar",
    "retraz": "retrazer",
    "retraze": "retrazer",
    "retrazei": "retrazer",
    "retrazeis": "retrazer",
    "retrazem": "retrazer",
    "retrazemo": "retrazer",
    "retrazemos": "retrazer",
    "retrazendo": "retrazer",
    "retrazerde": "retrazer",
    "retrazerdes": "retrazer",
    "retrazere": "retrazer",
    "retrazerem": "retrazer",
    "retrazeres": "retrazer",
    "retrazermo": "retrazer",
    "retrazermos": "retrazer",
    "retrazes": "retrazer",
    "retrazia": "retrazer",
    "retraziam": "retrazer",
    "retrazias": "retrazer",
    "retrazida": "retrazer",
    "retrazidas": "retrazer",
    "retrazido": "retrazer",
    "retrazidos": "retrazer",
    "retrazê": "retrazer",
    "retrazíamo": "retrazer",
    "retrazíamos": "retrazer",
    "retrazíei": "retrazer",
    "retrazíeis": "retrazer",
    "retraça": "retraçar",
    "retraçada": "retraçar",
    "retraçadas": "retraçar",
    "retraçado": "retraçar",
    "retraçados": "retraçar",
    "retraçai": "retraçar",
    "retraçais": "retraçar",
    "retraçam": "retraçar",
    "retraçamo": "retraçar",
    "retraçamos": "retraçar",
    "retraçando": "retraçar",
    "retraçara": "retraçar",
    "retraçaram": "retraçar",
    "retraçaras": "retraçar",
    "retraçarde": "retraçar",
    "retraçardes": "retraçar",
    "retraçare": "retraçar",
    "retraçarei": "retraçar",
    "retraçareis": "retraçar",
    "retraçarem": "retraçar",
    "retraçaremos": "retraçar",
    "retraçares": "retraçar",
    "retraçaria": "retraçar",
    "retraçariam": "retraçar",
    "retraçarias": "retraçar",
    "retraçarmo": "retraçar",
    "retraçarmos": "retraçar",
    "retraçará": "retraçar",
    "retraçarás": "retraçar",
    "retraçarão": "retraçar",
    "retraçaríamos": "retraçar",
    "retraçaríeis": "retraçar",
    "retraças": "retraçar",
    "retraçasse": "retraçar",
    "retraçassem": "retraçar",
    "retraçasses": "retraçar",
    "retraçaste": "retraçar",
    "retraçastes": "retraçar",
    "retraçava": "retraçar",
    "retraçavam": "retraçar",
    "retraçavas": "retraçar",
    "retraço": "retraçar",
    "retraços": "retraço",
    "retraçou": "retraçar",
    "retraçá": "retraçar",
    "retraçámo": "retraçar",
    "retraçámos": "retraçar",
    "retraçáramo": "retraçar",
    "retraçáramos": "retraçar",
    "retraçárei": "retraçar",
    "retraçáreis": "retraçar",
    "retraçásseis": "retraçar",
    "retraçássemos": "retraçar",
    "retraçávamo": "retraçar",
    "retraçávamos": "retraçar",
    "retraçávei": "retraçar",
    "retraçáveis": "retraçável",
    "retraí": "retrair",
    "retraía": "retrair",
    "retraíam": "retrair",
    "retraíamo": "retrair",
    "retraíamos": "retrair",
    "retraías": "retrair",
    "retraída": "retrair",
    "retraídas": "retrair",
    "retraído": "retrair",
    "retraídos": "retrair",
    "retraíei": "retrair",
    "retraíeis": "retrair",
    "retraímo": "retrair",
    "retraímos": "retrair",
    "retraíra": "retrair",
    "retraíram": "retrair",
    "retraíramo": "retrair",
    "retraíramos": "retrair",
    "retraíras": "retrair",
    "retraíre": "retrair",
    "retraírei": "retrair",
    "retraíreis": "retrair",
    "retraírem": "retrair",
    "retraíres": "retrair",
    "retraís": "retrair",
    "retraísse": "retrair",
    "retraísseis": "retrair",
    "retraíssem": "retrair",
    "retraíssemos": "retrair",
    "retraísses": "retrair",
    "retraíste": "retrair",
    "retraístes": "retrair",
    "retrema": "retremer",
    "retremais": "retremer",
    "retremam": "retremer",
    "retremamo": "retremer",
    "retremamos": "retremer",
    "retremas": "retremer",
    "retreme": "retremer",
    "retremei": "retremer",
    "retremeis": "retremer",
    "retremem": "retremer",
    "retrememo": "retremer",
    "retrememos": "retremer",
    "retremendo": "retremer",
    "retremera": "retremer",
    "retremeram": "retremer",
    "retremeras": "retremer",
    "retremerdes": "retremer",
    "retremerei": "retremer",
    "retremereis": "retremer",
    "retremerem": "retremer",
    "retremeremos": "retremer",
    "retremeres": "retremer",
    "retremeria": "retremer",
    "retremeriam": "retremer",
    "retremerias": "retremer",
    "retremermo": "retremer",
    "retremermos": "retremer",
    "retremerá": "retremer",
    "retremerás": "retremer",
    "retremerão": "retremer",
    "retremeríamos": "retremer",
    "retremeríeis": "retremer",
    "retremes": "retremer",
    "retremesse": "retremer",
    "retremessem": "retremer",
    "retremesses": "retremer",
    "retremeste": "retremer",
    "retremestes": "retremer",
    "retremeu": "retremer",
    "retremi": "retremer",
    "retremia": "retremer",
    "retremiam": "retremer",
    "retremias": "retremer",
    "retremida": "retremer",
    "retremidas": "retremer",
    "retremido": "retremer",
    "retremidos": "retremer",
    "retremo": "retremer",
    "retremêramo": "retremer",
    "retremêramos": "retremer",
    "retremêreis": "retremer",
    "retremêsseis": "retremer",
    "retremêssemos": "retremer",
    "retremíamo": "retremer",
    "retremíamos": "retremer",
    "retremíeis": "retremer",
    "retretas": "retreta",
    "retretes": "retrete",
    "retretistas": "retretista",
    "retribua": "retribuir",
    "retribuais": "retribuir",
    "retribuam": "retribuir",
    "retribuamo": "retribuir",
    "retribuamos": "retribuir",
    "retribuas": "retribuir",
    "retribuem": "retribuir",
    "retribui": "retribuir",
    "retribuidora": "retribuidor",
    "retribuidoras": "retribuidor",
    "retribuidores": "retribuidor",
    "retribuindo": "retribuir",
    "retribuirde": "retribuir",
    "retribuirdes": "retribuir",
    "retribuirei": "retribuir",
    "retribuireis": "retribuir",
    "retribuiremos": "retribuir",
    "retribuiria": "retribuir",
    "retribuiriam": "retribuir",
    "retribuirias": "retribuir",
    "retribuirmo": "retribuir",
    "retribuirmos": "retribuir",
    "retribuirá": "retribuir",
    "retribuirás": "retribuir",
    "retribuirão": "retribuir",
    "retribuiríamos": "retribuir",
    "retribuiríeis": "retribuir",
    "retribuis": "retribuir",
    "retribuiu": "retribuir",
    "retribuições": "retribuição",
    "retribuo": "retribuir",
    "retributiva": "retributivo",
    "retributivas": "retributivo",
    "retributivos": "retributivo",
    "retribuí": "retribuir",
    "retribuía": "retribuir",
    "retribuíam": "retribuir",
    "retribuíamo": "retribuir",
    "retribuíamos": "retribuir",
    "retribuías": "retribuir",
    "retribuída": "retribuir",
    "retribuídas": "retribuir",
    "retribuído": "retribuir",
    "retribuídos": "retribuir",
    "retribuíei": "retribuir",
    "retribuíeis": "retribuir",
    "retribuímo": "retribuir",
    "retribuímos": "retribuir",
    "retribuíra": "retribuir",
    "retribuíram": "retribuir",
    "retribuíramo": "retribuir",
    "retribuíramos": "retribuir",
    "retribuíras": "retribuir",
    "retribuíre": "retribuir",
    "retribuírei": "retribuir",
    "retribuíreis": "retribuir",
    "retribuírem": "retribuir",
    "retribuíres": "retribuir",
    "retribuís": "retribuir",
    "retribuísse": "retribuir",
    "retribuísseis": "retribuir",
    "retribuíssem": "retribuir",
    "retribuíssemos": "retribuir",
    "retribuísses": "retribuir",
    "retribuíste": "retribuir",
    "retribuístes": "retribuir",
    "retribuíveis": "retribuível",
    "retrilha": "retrilhar",
    "retrilhada": "retrilhar",
    "retrilhadas": "retrilhar",
    "retrilhado": "retrilhar",
    "retrilhados": "retrilhar",
    "retrilhai": "retrilhar",
    "retrilhais": "retrilhar",
    "retrilham": "retrilhar",
    "retrilhamo": "retrilhar",
    "retrilhamos": "retrilhar",
    "retrilhando": "retrilhar",
    "retrilhara": "retrilhar",
    "retrilharam": "retrilhar",
    "retrilharas": "retrilhar",
    "retrilharde": "retrilhar",
    "retrilhardes": "retrilhar",
    "retrilhare": "retrilhar",
    "retrilharei": "retrilhar",
    "retrilhareis": "retrilhar",
    "retrilharem": "retrilhar",
    "retrilharemos": "retrilhar",
    "retrilhares": "retrilhar",
    "retrilharia": "retrilhar",
    "retrilhariam": "retrilhar",
    "retrilharias": "retrilhar",
    "retrilharmo": "retrilhar",
    "retrilharmos": "retrilhar",
    "retrilhará": "retrilhar",
    "retrilharás": "retrilhar",
    "retrilharão": "retrilhar",
    "retrilharíamos": "retrilhar",
    "retrilharíeis": "retrilhar",
    "retrilhas": "retrilhar",
    "retrilhasse": "retrilhar",
    "retrilhassem": "retrilhar",
    "retrilhasses": "retrilhar",
    "retrilhaste": "retrilhar",
    "retrilhastes": "retrilhar",
    "retrilhava": "retrilhar",
    "retrilhavam": "retrilhar",
    "retrilhavas": "retrilhar",
    "retrilhe": "retrilhar",
    "retrilhei": "retrilhar",
    "retrilheis": "retrilhar",
    "retrilhem": "retrilhar",
    "retrilhemo": "retrilhar",
    "retrilhemos": "retrilhar",
    "retrilhes": "retrilhar",
    "retrilho": "retrilhar",
    "retrilhou": "retrilhar",
    "retrilhá": "retrilhar",
    "retrilhámo": "retrilhar",
    "retrilhámos": "retrilhar",
    "retrilháramo": "retrilhar",
    "retrilháramos": "retrilhar",
    "retrilhárei": "retrilhar",
    "retrilháreis": "retrilhar",
    "retrilhásseis": "retrilhar",
    "retrilhássemos": "retrilhar",
    "retrilhávamo": "retrilhar",
    "retrilhávamos": "retrilhar",
    "retrilhávei": "retrilhar",
    "retrilháveis": "retrilhar",
    "retrinca": "retrincar",
    "retrincada": "retrincar",
    "retrincadas": "retrincar",
    "retrincado": "retrincar",
    "retrincados": "retrincar",
    "retrincai": "retrincar",
    "retrincais": "retrincar",
    "retrincam": "retrincar",
    "retrincamo": "retrincar",
    "retrincamos": "retrincar",
    "retrincando": "retrincar",
    "retrincara": "retrincar",
    "retrincaram": "retrincar",
    "retrincaras": "retrincar",
    "retrincarde": "retrincar",
    "retrincardes": "retrincar",
    "retrincare": "retrincar",
    "retrincarei": "retrincar",
    "retrincareis": "retrincar",
    "retrincarem": "retrincar",
    "retrincaremos": "retrincar",
    "retrincares": "retrincar",
    "retrincaria": "retrincar",
    "retrincariam": "retrincar",
    "retrincarias": "retrincar",
    "retrincarmo": "retrincar",
    "retrincarmos": "retrincar",
    "retrincará": "retrincar",
    "retrincarás": "retrincar",
    "retrincarão": "retrincar",
    "retrincaríamos": "retrincar",
    "retrincaríeis": "retrincar",
    "retrincas": "retrincar",
    "retrincasse": "retrincar",
    "retrincassem": "retrincar",
    "retrincasses": "retrincar",
    "retrincaste": "retrincar",
    "retrincastes": "retrincar",
    "retrincava": "retrincar",
    "retrincavam": "retrincar",
    "retrincavas": "retrincar",
    "retrinco": "retrincar",
    "retrincou": "retrincar",
    "retrincá": "retrincar",
    "retrincámo": "retrincar",
    "retrincámos": "retrincar",
    "retrincáramo": "retrincar",
    "retrincáramos": "retrincar",
    "retrincárei": "retrincar",
    "retrincáreis": "retrincar",
    "retrincásseis": "retrincar",
    "retrincássemos": "retrincar",
    "retrincávamo": "retrincar",
    "retrincávamos": "retrincar",
    "retrincávei": "retrincar",
    "retrincáveis": "retrincar",
    "retrinque": "retrincar",
    "retrinquei": "retrincar",
    "retrinqueis": "retrincar",
    "retrinquem": "retrincar",
    "retrinquemo": "retrincar",
    "retrinquemos": "retrincar",
    "retrinques": "retrincar",
    "retrizes": "retriz",
    "retroa": "retroar",
    "retroactiva": "retroactivo",
    "retroactivas": "retroactivo",
    "retroactividades": "retroactividade",
    "retroactivos": "retroactivo",
    "retroactora": "retroactor",
    "retroactoras": "retroactor",
    "retroactores": "retroactor",
    "retroacções": "retroacção",
    "retroada": "retroar",
    "retroadas": "retroar",
    "retroado": "retroar",
    "retroados": "retroar",
    "retroage": "retroagir",
    "retroagem": "retroagir",
    "retroages": "retroagir",
    "retroagi": "retroagir",
    "retroagia": "retroagir",
    "retroagiam": "retroagir",
    "retroagias": "retroagir",
    "retroagida": "retroagir",
    "retroagidas": "retroagir",
    "retroagido": "retroagir",
    "retroagidos": "retroagir",
    "retroagimo": "retroagir",
    "retroagimos": "retroagir",
    "retroagindo": "retroagir",
    "retroagira": "retroagir",
    "retroagiram": "retroagir",
    "retroagiras": "retroagir",
    "retroagirdes": "retroagir",
    "retroagirei": "retroagir",
    "retroagireis": "retroagir",
    "retroagirem": "retroagir",
    "retroagiremos": "retroagir",
    "retroagires": "retroagir",
    "retroagiria": "retroagir",
    "retroagiriam": "retroagir",
    "retroagirias": "retroagir",
    "retroagirmo": "retroagir",
    "retroagirmos": "retroagir",
    "retroagirá": "retroagir",
    "retroagirás": "retroagir",
    "retroagirão": "retroagir",
    "retroagiríamos": "retroagir",
    "retroagiríeis": "retroagir",
    "retroagis": "retroagir",
    "retroagisse": "retroagir",
    "retroagissem": "retroagir",
    "retroagisses": "retroagir",
    "retroagiste": "retroagir",
    "retroagistes": "retroagir",
    "retroagiu": "retroagir",
    "retroagíamo": "retroagir",
    "retroagíamos": "retroagir",
    "retroagíeis": "retroagir",
    "retroagíramo": "retroagir",
    "retroagíramos": "retroagir",
    "retroagíreis": "retroagir",
    "retroagísseis": "retroagir",
    "retroagíssemos": "retroagir",
    "retroai": "retroar",
    "retroais": "retroar",
    "retroaja": "retroagir",
    "retroajais": "retroagir",
    "retroajam": "retroagir",
    "retroajamo": "retroagir",
    "retroajamos": "retroagir",
    "retroajas": "retroagir",
    "retroajo": "retroagir",
    "retroam": "retroar",
    "retroamo": "retroar",
    "retroamos": "retroar",
    "retroando": "retroar",
    "retroara": "retroar",
    "retroaram": "retroar",
    "retroaras": "retroar",
    "retroardes": "retroar",
    "retroarei": "retroar",
    "retroareis": "retroar",
    "retroarem": "retroar",
    "retroaremos": "retroar",
    "retroares": "retroar",
    "retroaria": "retroar",
    "retroariam": "retroar",
    "retroarias": "retroar",
    "retroarmo": "retroar",
    "retroarmos": "retroar",
    "retroará": "retroar",
    "retroarás": "retroar",
    "retroarão": "retroar",
    "retroaríamos": "retroar",
    "retroaríeis": "retroar",
    "retroas": "retroar",
    "retroasse": "retroar",
    "retroassem": "retroar",
    "retroasses": "retroar",
    "retroaste": "retroar",
    "retroastes": "retroar",
    "retroava": "retroar",
    "retroavam": "retroar",
    "retroavas": "retroar",
    "retrocargas": "retrocarga",
    "retroceda": "retroceder",
    "retrocedais": "retroceder",
    "retrocedam": "retroceder",
    "retrocedamo": "retroceder",
    "retrocedamos": "retroceder",
    "retrocedas": "retroceder",
    "retrocede": "retroceder",
    "retrocedei": "retroceder",
    "retrocedeis": "retroceder",
    "retrocedem": "retroceder",
    "retrocedemo": "retroceder",
    "retrocedemos": "retroceder",
    "retrocedendo": "retroceder",
    "retrocedentes": "retrocedente",
    "retrocedera": "retroceder",
    "retrocederam": "retroceder",
    "retrocederas": "retroceder",
    "retrocederdes": "retroceder",
    "retrocederei": "retroceder",
    "retrocedereis": "retroceder",
    "retrocederem": "retroceder",
    "retrocederemos": "retroceder",
    "retrocederes": "retroceder",
    "retrocederia": "retroceder",
    "retrocederiam": "retroceder",
    "retrocederias": "retroceder",
    "retrocedermo": "retroceder",
    "retrocedermos": "retroceder",
    "retrocederá": "retroceder",
    "retrocederás": "retroceder",
    "retrocederão": "retroceder",
    "retrocederíamos": "retroceder",
    "retrocederíeis": "retroceder",
    "retrocedes": "retroceder",
    "retrocedesse": "retroceder",
    "retrocedessem": "retroceder",
    "retrocedesses": "retroceder",
    "retrocedeste": "retroceder",
    "retrocedestes": "retroceder",
    "retrocedeu": "retroceder",
    "retrocedi": "retroceder",
    "retrocedia": "retroceder",
    "retrocediam": "retroceder",
    "retrocedias": "retroceder",
    "retrocedida": "retroceder",
    "retrocedidas": "retroceder",
    "retrocedido": "retroceder",
    "retrocedidos": "retroceder",
    "retrocedimentos": "retrocedimento",
    "retrocedo": "retroceder",
    "retrocedêramo": "retroceder",
    "retrocedêramos": "retroceder",
    "retrocedêreis": "retroceder",
    "retrocedêsseis": "retroceder",
    "retrocedêssemos": "retroceder",
    "retrocedíamo": "retroceder",
    "retrocedíamos": "retroceder",
    "retrocedíeis": "retroceder",
    "retrocessiva": "retrocessivo",
    "retrocessivas": "retrocessivo",
    "retrocessivos": "retrocessivo",
    "retrocessos": "retrocesso",
    "retrocessões": "retrocessão",
    "retrocontagens": "retrocontagem",
    "retrocruzamentos": "retrocruzamento",
    "retrodata": "retrodatar",
    "retrodatada": "retrodatar",
    "retrodatadas": "retrodatar",
    "retrodatado": "retrodatar",
    "retrodatados": "retrodatar",
    "retrodatai": "retrodatar",
    "retrodatais": "retrodatar",
    "retrodatam": "retrodatar",
    "retrodatamo": "retrodatar",
    "retrodatamos": "retrodatar",
    "retrodatando": "retrodatar",
    "retrodatara": "retrodatar",
    "retrodataram": "retrodatar",
    "retrodataras": "retrodatar",
    "retrodatarde": "retrodatar",
    "retrodatardes": "retrodatar",
    "retrodatare": "retrodatar",
    "retrodatarei": "retrodatar",
    "retrodatareis": "retrodatar",
    "retrodatarem": "retrodatar",
    "retrodataremos": "retrodatar",
    "retrodatares": "retrodatar",
    "retrodataria": "retrodatar",
    "retrodatariam": "retrodatar",
    "retrodatarias": "retrodatar",
    "retrodatarmo": "retrodatar",
    "retrodatarmos": "retrodatar",
    "retrodatará": "retrodatar",
    "retrodatarás": "retrodatar",
    "retrodatarão": "retrodatar",
    "retrodataríamos": "retrodatar",
    "retrodataríeis": "retrodatar",
    "retrodatas": "retrodatar",
    "retrodatasse": "retrodatar",
    "retrodatassem": "retrodatar",
    "retrodatasses": "retrodatar",
    "retrodataste": "retrodatar",
    "retrodatastes": "retrodatar",
    "retrodatava": "retrodatar",
    "retrodatavam": "retrodatar",
    "retrodatavas": "retrodatar",
    "retrodate": "retrodatar",
    "retrodatei": "retrodatar",
    "retrodateis": "retrodatar",
    "retrodatem": "retrodatar",
    "retrodatemo": "retrodatar",
    "retrodatemos": "retrodatar",
    "retrodates": "retrodatar",
    "retrodato": "retrodatar",
    "retrodatou": "retrodatar",
    "retrodatá": "retrodatar",
    "retrodatámo": "retrodatar",
    "retrodatámos": "retrodatar",
    "retrodatáramo": "retrodatar",
    "retrodatáramos": "retrodatar",
    "retrodatárei": "retrodatar",
    "retrodatáreis": "retrodatar",
    "retrodatásseis": "retrodatar",
    "retrodatássemos": "retrodatar",
    "retrodatávamo": "retrodatar",
    "retrodatávamos": "retrodatar",
    "retrodatávei": "retrodatar",
    "retrodatáveis": "retrodatar",
    "retrodesvios": "retrodesvio",
    "retrodifusões": "retrodifusão",
    "retroe": "retroar",
    "retroei": "retroar",
    "retroeis": "retroar",
    "retroem": "retroar",
    "retroemo": "retroar",
    "retroemos": "retroar",
    "retroes": "retroar",
    "retroescavadoras": "retroescavadora",
    "retroflectida": "retroflectido",
    "retroflectidas": "retroflectido",
    "retroflectidos": "retroflectido",
    "retroflexa": "retroflexo",
    "retroflexas": "retroflexo",
    "retroflexos": "retroflexo",
    "retroflexões": "retroflexão",
    "retrofoguetes": "retrofoguete",
    "retrograda": "retrogradar",
    "retrogradada": "retrogradar",
    "retrogradadas": "retrogradar",
    "retrogradado": "retrogradar",
    "retrogradados": "retrogradar",
    "retrogradai": "retrogradar",
    "retrogradais": "retrogradar",
    "retrogradam": "retrogradar",
    "retrogradamo": "retrogradar",
    "retrogradamos": "retrogradar",
    "retrogradando": "retrogradar",
    "retrogradara": "retrogradar",
    "retrogradaram": "retrogradar",
    "retrogradaras": "retrogradar",
    "retrogradardes": "retrogradar",
    "retrogradarei": "retrogradar",
    "retrogradareis": "retrogradar",
    "retrogradarem": "retrogradar",
    "retrogradaremos": "retrogradar",
    "retrogradares": "retrogradar",
    "retrogradaria": "retrogradar",
    "retrogradariam": "retrogradar",
    "retrogradarias": "retrogradar",
    "retrogradarmo": "retrogradar",
    "retrogradarmos": "retrogradar",
    "retrogradará": "retrogradar",
    "retrogradarás": "retrogradar",
    "retrogradarão": "retrogradar",
    "retrogradaríamos": "retrogradar",
    "retrogradaríeis": "retrogradar",
    "retrogradas": "retrogradar",
    "retrogradasse": "retrogradar",
    "retrogradassem": "retrogradar",
    "retrogradasses": "retrogradar",
    "retrogradaste": "retrogradar",
    "retrogradastes": "retrogradar",
    "retrogradava": "retrogradar",
    "retrogradavam": "retrogradar",
    "retrogradavas": "retrogradar",
    "retrogradações": "retrogradação",
    "retrograde": "retrogradar",
    "retrogradei": "retrogradar",
    "retrogradeis": "retrogradar",
    "retrogradem": "retrogradar",
    "retrogrademo": "retrogradar",
    "retrogrademos": "retrogradar",
    "retrogrades": "retrogradar",
    "retrogrado": "retrogradar",
    "retrogradou": "retrogradar",
    "retrogradámo": "retrogradar",
    "retrogradámos": "retrogradar",
    "retrogradáramo": "retrogradar",
    "retrogradáramos": "retrogradar",
    "retrogradáreis": "retrogradar",
    "retrogradásseis": "retrogradar",
    "retrogradássemos": "retrogradar",
    "retrogradávamo": "retrogradar",
    "retrogradávamos": "retrogradar",
    "retrogradáveis": "retrogradar",
    "retrogressiva": "retrogressivo",
    "retrogressivas": "retrogressivo",
    "retrogressivos": "retrogressivo",
    "retrogressões": "retrogressão",
    "retroo": "retroar",
    "retroou": "retroar",
    "retroovária": "retroovário",
    "retroovárias": "retroovário",
    "retroovários": "retroovário",
    "retropedala": "retropedalar",
    "retropedalada": "retropedalar",
    "retropedaladas": "retropedalar",
    "retropedalado": "retropedalar",
    "retropedalados": "retropedalar",
    "retropedalagens": "retropedalagem",
    "retropedalai": "retropedalar",
    "retropedalais": "retropedalar",
    "retropedalam": "retropedalar",
    "retropedalamo": "retropedalar",
    "retropedalamos": "retropedalar",
    "retropedalando": "retropedalar",
    "retropedalara": "retropedalar",
    "retropedalaram": "retropedalar",
    "retropedalaras": "retropedalar",
    "retropedalardes": "retropedalar",
    "retropedalarei": "retropedalar",
    "retropedalareis": "retropedalar",
    "retropedalarem": "retropedalar",
    "retropedalaremos": "retropedalar",
    "retropedalares": "retropedalar",
    "retropedalaria": "retropedalar",
    "retropedalariam": "retropedalar",
    "retropedalarias": "retropedalar",
    "retropedalarmo": "retropedalar",
    "retropedalarmos": "retropedalar",
    "retropedalará": "retropedalar",
    "retropedalarás": "retropedalar",
    "retropedalarão": "retropedalar",
    "retropedalaríamos": "retropedalar",
    "retropedalaríeis": "retropedalar",
    "retropedalas": "retropedalar",
    "retropedalasse": "retropedalar",
    "retropedalassem": "retropedalar",
    "retropedalasses": "retropedalar",
    "retropedalaste": "retropedalar",
    "retropedalastes": "retropedalar",
    "retropedalava": "retropedalar",
    "retropedalavam": "retropedalar",
    "retropedalavas": "retropedalar",
    "retropedale": "retropedalar",
    "retropedalei": "retropedalar",
    "retropedaleis": "retropedalar",
    "retropedalem": "retropedalar",
    "retropedalemo": "retropedalar",
    "retropedalemos": "retropedalar",
    "retropedales": "retropedalar",
    "retropedalo": "retropedalar",
    "retropedalou": "retropedalar",
    "retropedalámo": "retropedalar",
    "retropedalámos": "retropedalar",
    "retropedaláramo": "retropedalar",
    "retropedaláramos": "retropedalar",
    "retropedaláreis": "retropedalar",
    "retropedalásseis": "retropedalar",
    "retropedalássemos": "retropedalar",
    "retropedalávamo": "retropedalar",
    "retropedalávamos": "retropedalar",
    "retropedaláveis": "retropedalar",
    "retroprojectores": "retroprojector",
    "retrorsa": "retrorso",
    "retrorsas": "retrorso",
    "retrorsos": "retrorso",
    "retros": "retro",
    "retrosarias": "retrosaria",
    "retroseira": "retroseiro",
    "retroseiras": "retroseiro",
    "retroseiros": "retroseiro",
    "retrospectiva": "retrospectivo",
    "retrospectivas": "retrospectivo",
    "retrospectividades": "retrospectividade",
    "retrospectivos": "retrospectivo",
    "retrospectos": "retrospecto",
    "retrospecções": "retrospecção",
    "retrossegue": "retrosseguir",
    "retrosseguem": "retrosseguir",
    "retrossegues": "retrosseguir",
    "retrossegui": "retrosseguir",
    "retrosseguia": "retrosseguir",
    "retrosseguiam": "retrosseguir",
    "retrosseguias": "retrosseguir",
    "retrosseguida": "retrosseguir",
    "retrosseguidas": "retrosseguir",
    "retrosseguido": "retrosseguir",
    "retrosseguidos": "retrosseguir",
    "retrosseguimo": "retrosseguir",
    "retrosseguimos": "retrosseguir",
    "retrosseguindo": "retrosseguir",
    "retrosseguira": "retrosseguir",
    "retrosseguiram": "retrosseguir",
    "retrosseguiras": "retrosseguir",
    "retrosseguirde": "retrosseguir",
    "retrosseguirdes": "retrosseguir",
    "retrosseguire": "retrosseguir",
    "retrosseguirei": "retrosseguir",
    "retrosseguireis": "retrosseguir",
    "retrosseguirem": "retrosseguir",
    "retrosseguiremos": "retrosseguir",
    "retrosseguires": "retrosseguir",
    "retrosseguiria": "retrosseguir",
    "retrosseguiriam": "retrosseguir",
    "retrosseguirias": "retrosseguir",
    "retrosseguirmo": "retrosseguir",
    "retrosseguirmos": "retrosseguir",
    "retrosseguirá": "retrosseguir",
    "retrosseguirás": "retrosseguir",
    "retrosseguirão": "retrosseguir",
    "retrosseguiríamos": "retrosseguir",
    "retrosseguiríeis": "retrosseguir",
    "retrosseguis": "retrosseguir",
    "retrosseguisse": "retrosseguir",
    "retrosseguissem": "retrosseguir",
    "retrosseguisses": "retrosseguir",
    "retrosseguiste": "retrosseguir",
    "retrosseguistes": "retrosseguir",
    "retrosseguiu": "retrosseguir",
    "retrosseguíamo": "retrosseguir",
    "retrosseguíamos": "retrosseguir",
    "retrosseguíei": "retrosseguir",
    "retrosseguíeis": "retrosseguir",
    "retrosseguíramo": "retrosseguir",
    "retrosseguíramos": "retrosseguir",
    "retrosseguírei": "retrosseguir",
    "retrosseguíreis": "retrosseguir",
    "retrosseguísseis": "retrosseguir",
    "retrosseguíssemos": "retrosseguir",
    "retrossiga": "retrosseguir",
    "retrossigais": "retrosseguir",
    "retrossigam": "retrosseguir",
    "retrossigamo": "retrosseguir",
    "retrossigamos": "retrosseguir",
    "retrossigas": "retrosseguir",
    "retrossigo": "retrosseguir",
    "retrotracções": "retrotracção",
    "retrotraem": "retrotrair",
    "retrotrai": "retrotrair",
    "retrotraia": "retrotrair",
    "retrotraiais": "retrotrair",
    "retrotraiam": "retrotrair",
    "retrotraiamo": "retrotrair",
    "retrotraiamos": "retrotrair",
    "retrotraias": "retrotrair",
    "retrotraindo": "retrotrair",
    "retrotraio": "retrotrair",
    "retrotrairde": "retrotrair",
    "retrotrairdes": "retrotrair",
    "retrotrairei": "retrotrair",
    "retrotraireis": "retrotrair",
    "retrotrairemos": "retrotrair",
    "retrotrairia": "retrotrair",
    "retrotrairiam": "retrotrair",
    "retrotrairias": "retrotrair",
    "retrotrairmo": "retrotrair",
    "retrotrairmos": "retrotrair",
    "retrotrairá": "retrotrair",
    "retrotrairás": "retrotrair",
    "retrotrairão": "retrotrair",
    "retrotrairíamos": "retrotrair",
    "retrotrairíeis": "retrotrair",
    "retrotrais": "retrotrair",
    "retrotraiu": "retrotrair",
    "retrotraí": "retrotrair",
    "retrotraía": "retrotrair",
    "retrotraíam": "retrotrair",
    "retrotraíamo": "retrotrair",
    "retrotraíamos": "retrotrair",
    "retrotraías": "retrotrair",
    "retrotraída": "retrotrair",
    "retrotraídas": "retrotrair",
    "retrotraído": "retrotrair",
    "retrotraídos": "retrotrair",
    "retrotraíei": "retrotrair",
    "retrotraíeis": "retrotrair",
    "retrotraímo": "retrotrair",
    "retrotraímos": "retrotrair",
    "retrotraíra": "retrotrair",
    "retrotraíram": "retrotrair",
    "retrotraíramo": "retrotrair",
    "retrotraíramos": "retrotrair",
    "retrotraíras": "retrotrair",
    "retrotraíre": "retrotrair",
    "retrotraírei": "retrotrair",
    "retrotraíreis": "retrotrair",
    "retrotraírem": "retrotrair",
    "retrotraíres": "retrotrair",
    "retrotraís": "retrotrair",
    "retrotraísse": "retrotrair",
    "retrotraísseis": "retrotrair",
    "retrotraíssem": "retrotrair",
    "retrotraíssemos": "retrotrair",
    "retrotraísses": "retrotrair",
    "retrotraíste": "retrotrair",
    "retrotraístes": "retrotrair",
    "retrouxe": "retrazer",
    "retrouxemo": "retrazer",
    "retrouxemos": "retrazer",
    "retrouxer": "retrazer",
    "retrouxera": "retrazer",
    "retrouxeram": "retrazer",
    "retrouxeras": "retrazer",
    "retrouxerdes": "retrazer",
    "retrouxerem": "retrazer",
    "retrouxeres": "retrazer",
    "retrouxermos": "retrazer",
    "retrouxesse": "retrazer",
    "retrouxessem": "retrazer",
    "retrouxesses": "retrazer",
    "retrouxeste": "retrazer",
    "retrouxestes": "retrazer",
    "retrouxéramo": "retrazer",
    "retrouxéramos": "retrazer",
    "retrouxérei": "retrazer",
    "retrouxéreis": "retrazer",
    "retrouxésseis": "retrazer",
    "retrouxéssemos": "retrazer",
    "retrovenda": "retrovender",
    "retrovendais": "retrovender",
    "retrovendam": "retrovender",
    "retrovendamo": "retrovender",
    "retrovendamos": "retrovender",
    "retrovendas": "retrovender",
    "retrovende": "retrovender",
    "retrovendei": "retrovender",
    "retrovendeis": "retrovender",
    "retrovendem": "retrovender",
    "retrovendemo": "retrovender",
    "retrovendemos": "retrovender",
    "retrovendendo": "retrovender",
    "retrovendera": "retrovender",
    "retrovenderam": "retrovender",
    "retrovenderas": "retrovender",
    "retrovenderde": "retrovender",
    "retrovenderdes": "retrovender",
    "retrovendere": "retrovender",
    "retrovenderei": "retrovender",
    "retrovendereis": "retrovender",
    "retrovenderem": "retrovender",
    "retrovenderemos": "retrovender",
    "retrovenderes": "retrovender",
    "retrovenderia": "retrovender",
    "retrovenderiam": "retrovender",
    "retrovenderias": "retrovender",
    "retrovendermo": "retrovender",
    "retrovendermos": "retrovender",
    "retrovenderá": "retrovender",
    "retrovenderás": "retrovender",
    "retrovenderão": "retrovender",
    "retrovenderíamos": "retrovender",
    "retrovenderíeis": "retrovender",
    "retrovendes": "retrovender",
    "retrovendesse": "retrovender",
    "retrovendessem": "retrovender",
    "retrovendesses": "retrovender",
    "retrovendeste": "retrovender",
    "retrovendestes": "retrovender",
    "retrovendeu": "retrovender",
    "retrovendi": "retrovender",
    "retrovendia": "retrovender",
    "retrovendiam": "retrovender",
    "retrovendias": "retrovender",
    "retrovendida": "retrovender",
    "retrovendidas": "retrovender",
    "retrovendido": "retrovender",
    "retrovendidos": "retrovender",
    "retrovendições": "retrovendição",
    "retrovendo": "retrovender",
    "retrovendê": "retrovender",
    "retrovendêramo": "retrovender",
    "retrovendêramos": "retrovender",
    "retrovendêrei": "retrovender",
    "retrovendêreis": "retrovender",
    "retrovendêsseis": "retrovender",
    "retrovendêssemos": "retrovender",
    "retrovendíamo": "retrovender",
    "retrovendíamos": "retrovender",
    "retrovendíei": "retrovender",
    "retrovendíeis": "retrovender",
    "retroversidades": "retroversidade",
    "retroversiva": "retroversivo",
    "retroversivas": "retroversivo",
    "retroversivos": "retroversivo",
    "retroversões": "retroversão",
    "retroverta": "retroverter",
    "retrovertais": "retroverter",
    "retrovertam": "retroverter",
    "retrovertamo": "retroverter",
    "retrovertamos": "retroverter",
    "retrovertas": "retroverter",
    "retroverte": "retroverter",
    "retrovertei": "retroverter",
    "retroverteis": "retroverter",
    "retrovertem": "retroverter",
    "retrovertemo": "retroverter",
    "retrovertemos": "retroverter",
    "retrovertendo": "retroverter",
    "retrovertera": "retroverter",
    "retroverteram": "retroverter",
    "retroverteras": "retroverter",
    "retroverterde": "retroverter",
    "retroverterdes": "retroverter",
    "retrovertere": "retroverter",
    "retroverterei": "retroverter",
    "retrovertereis": "retroverter",
    "retroverterem": "retroverter",
    "retroverteremos": "retroverter",
    "retroverteres": "retroverter",
    "retroverteria": "retroverter",
    "retroverteriam": "retroverter",
    "retroverterias": "retroverter",
    "retrovertermo": "retroverter",
    "retrovertermos": "retroverter",
    "retroverterá": "retroverter",
    "retroverterás": "retroverter",
    "retroverterão": "retroverter",
    "retroverteríamos": "retroverter",
    "retroverteríeis": "retroverter",
    "retrovertes": "retroverter",
    "retrovertesse": "retroverter",
    "retrovertessem": "retroverter",
    "retrovertesses": "retroverter",
    "retroverteste": "retroverter",
    "retrovertestes": "retroverter",
    "retroverteu": "retroverter",
    "retroverti": "retroverter",
    "retrovertia": "retroverter",
    "retrovertiam": "retroverter",
    "retrovertias": "retroverter",
    "retrovertida": "retrovertido",
    "retrovertidas": "retrovertido",
    "retrovertido": "retroverter",
    "retrovertidos": "retrovertido",
    "retroverto": "retroverter",
    "retrovertê": "retroverter",
    "retrovertêramo": "retroverter",
    "retrovertêramos": "retroverter",
    "retrovertêrei": "retroverter",
    "retrovertêreis": "retroverter",
    "retrovertêsseis": "retroverter",
    "retrovertêssemos": "retroverter",
    "retrovertíamo": "retroverter",
    "retrovertíamos": "retroverter",
    "retrovertíei": "retroverter",
    "retrovertíeis": "retroverter",
    "retrovisora": "retrovisor",
    "retrovisoras": "retrovisor",
    "retrovisores": "retrovisor",
    "retrovíros": "retrovírus",
    "retroámo": "retroar",
    "retroámos": "retroar",
    "retroáramo": "retroar",
    "retroáramos": "retroar",
    "retroáreis": "retroar",
    "retroásseis": "retroar",
    "retroássemos": "retroar",
    "retroávamo": "retroar",
    "retroávamos": "retroar",
    "retroáveis": "retroar",
    "retruca": "retrucar",
    "retrucada": "retrucar",
    "retrucadas": "retrucar",
    "retrucado": "retrucar",
    "retrucados": "retrucar",
    "retrucais": "retrucar",
    "retrucam": "retrucar",
    "retrucamo": "retrucar",
    "retrucamos": "retrucar",
    "retrucando": "retrucar",
    "retrucara": "retrucar",
    "retrucaram": "retrucar",
    "retrucaras": "retrucar",
    "retrucardes": "retrucar",
    "retrucarei": "retrucar",
    "retrucareis": "retrucar",
    "retrucarem": "retrucar",
    "retrucaremos": "retrucar",
    "retrucares": "retrucar",
    "retrucaria": "retrucar",
    "retrucariam": "retrucar",
    "retrucarias": "retrucar",
    "retrucarmo": "retrucar",
    "retrucarmos": "retrucar",
    "retrucará": "retrucar",
    "retrucarás": "retrucar",
    "retrucarão": "retrucar",
    "retrucaríamos": "retrucar",
    "retrucaríeis": "retrucar",
    "retrucas": "retrucar",
    "retrucasse": "retrucar",
    "retrucassem": "retrucar",
    "retrucasses": "retrucar",
    "retrucaste": "retrucar",
    "retrucastes": "retrucar",
    "retrucava": "retrucar",
    "retrucavam": "retrucar",
    "retrucavas": "retrucar",
    "retruco": "retrucar",
    "retrucou": "retrucar",
    "retrucámo": "retrucar",
    "retrucámos": "retrucar",
    "retrucáramo": "retrucar",
    "retrucáramos": "retrucar",
    "retrucáreis": "retrucar",
    "retrucásseis": "retrucar",
    "retrucássemos": "retrucar",
    "retrucávamo": "retrucar",
    "retrucávamos": "retrucar",
    "retrucáveis": "retrucar",
    "retruque": "retrucar",
    "retruquei": "retrucar",
    "retruqueis": "retrucar",
    "retruquem": "retrucar",
    "retruquemos": "retrucar",
    "retruques": "retruque",
    "retrá": "retrazer",
    "retrógrada": "retrógrado",
    "retrógradas": "retrógrado",
    "retrógrados": "retrógrado",
    "retrógrafos": "retrógrafo",
    "retróses": "retrós",
    "retumba": "retumbar",
    "retumbada": "retumbar",
    "retumbadas": "retumbar",
    "retumbado": "retumbar",
    "retumbados": "retumbar",
    "retumbai": "retumbar",
    "retumbais": "retumbar",
    "retumbam": "retumbar",
    "retumbamo": "retumbar",
    "retumbamos": "retumbar",
    "retumbando": "retumbar",
    "retumbantes": "retumbante",
    "retumbara": "retumbar",
    "retumbaram": "retumbar",
    "retumbaras": "retumbar",
    "retumbardes": "retumbar",
    "retumbarei": "retumbar",
    "retumbareis": "retumbar",
    "retumbarem": "retumbar",
    "retumbaremos": "retumbar",
    "retumbares": "retumbar",
    "retumbaria": "retumbar",
    "retumbariam": "retumbar",
    "retumbarias": "retumbar",
    "retumbarmo": "retumbar",
    "retumbarmos": "retumbar",
    "retumbará": "retumbar",
    "retumbarás": "retumbar",
    "retumbarão": "retumbar",
    "retumbaríamos": "retumbar",
    "retumbaríeis": "retumbar",
    "retumbas": "retumbar",
    "retumbasse": "retumbar",
    "retumbassem": "retumbar",
    "retumbasses": "retumbar",
    "retumbaste": "retumbar",
    "retumbastes": "retumbar",
    "retumbava": "retumbar",
    "retumbavam": "retumbar",
    "retumbavas": "retumbar",
    "retumbe": "retumbar",
    "retumbei": "retumbar",
    "retumbeis": "retumbar",
    "retumbem": "retumbar",
    "retumbemo": "retumbar",
    "retumbemos": "retumbar",
    "retumbes": "retumbar",
    "retumbo": "retumbar",
    "retumbos": "retumbo",
    "retumbou": "retumbar",
    "retumbámo": "retumbar",
    "retumbámos": "retumbar",
    "retumbáramo": "retumbar",
    "retumbáramos": "retumbar",
    "retumbáreis": "retumbar",
    "retumbásseis": "retumbar",
    "retumbássemos": "retumbar",
    "retumbávamo": "retumbar",
    "retumbávamos": "retumbar",
    "retumbáveis": "retumbar",
    "retumbâncias": "retumbância",
    "retunda": "retundir",
    "retundais": "retundir",
    "retundam": "retundir",
    "retundamo": "retundir",
    "retundamos": "retundir",
    "retundas": "retundir",
    "retunde": "retundir",
    "retundem": "retundir",
    "retundes": "retundir",
    "retundi": "retundir",
    "retundia": "retundir",
    "retundiam": "retundir",
    "retundias": "retundir",
    "retundida": "retundir",
    "retundidas": "retundir",
    "retundido": "retundir",
    "retundidos": "retundir",
    "retundimo": "retundir",
    "retundimos": "retundir",
    "retundindo": "retundir",
    "retundira": "retundir",
    "retundiram": "retundir",
    "retundiras": "retundir",
    "retundirde": "retundir",
    "retundirdes": "retundir",
    "retundire": "retundir",
    "retundirei": "retundir",
    "retundireis": "retundir",
    "retundirem": "retundir",
    "retundiremos": "retundir",
    "retundires": "retundir",
    "retundiria": "retundir",
    "retundiriam": "retundir",
    "retundirias": "retundir",
    "retundirmo": "retundir",
    "retundirmos": "retundir",
    "retundirá": "retundir",
    "retundirás": "retundir",
    "retundirão": "retundir",
    "retundiríamos": "retundir",
    "retundiríeis": "retundir",
    "retundis": "retundir",
    "retundisse": "retundir",
    "retundissem": "retundir",
    "retundisses": "retundir",
    "retundiste": "retundir",
    "retundistes": "retundir",
    "retundiu": "retundir",
    "retundo": "retundir",
    "retundíamo": "retundir",
    "retundíamos": "retundir",
    "retundíei": "retundir",
    "retundíeis": "retundir",
    "retundíramo": "retundir",
    "retundíramos": "retundir",
    "retundírei": "retundir",
    "retundíreis": "retundir",
    "retundísseis": "retundir",
    "retundíssemos": "retundir",
    "returca": "retorquir",
    "returcais": "retorquir",
    "returcam": "retorquir",
    "returcamo": "retorquir",
    "returcamos": "retorquir",
    "returcas": "retorquir",
    "returco": "retorquir",
    "returque": "retorquir",
    "returquem": "retorquir",
    "returques": "retorquir",
    "retábulos": "retábulo",
    "retém": "reter",
    "reténs": "reter",
    "retê": "reter",
    "retêm": "reter",
    "retêmperas": "retêmpera",
    "retículas": "retícula",
    "retículos": "retículo",
    "retínhamo": "reter",
    "retínhamos": "reter",
    "retínhei": "reter",
    "retínheis": "reter",
    "retínica": "retínico",
    "retínicas": "retínico",
    "retínicos": "retínico",
    "retípedes": "retípede",
    "retórica": "retórico",
    "retóricas": "retórico",
    "retóricos": "retórico",
    "reuchliniana": "reuchliniano",
    "reuchlinianas": "reuchliniano",
    "reuchlinianos": "reuchliniano",
    "reumas": "reuma",
    "reumatalgias": "reumatalgia",
    "reumatismais": "reumatismal",
    "reumatismos": "reumatismo",
    "reumatologias": "reumatologia",
    "reumatologistas": "reumatologista",
    "reumatológica": "reumatológico",
    "reumatológicas": "reumatológico",
    "reumatológicos": "reumatológico",
    "reumatálgica": "reumatálgico",
    "reumatálgicas": "reumatálgico",
    "reumatálgicos": "reumatálgico",
    "reumatóides": "reumatóide",
    "reumatóloga": "reumatólogo",
    "reumatólogas": "reumatólogo",
    "reumatólogos": "reumatólogo",
    "reumática": "reumático",
    "reumáticas": "reumático",
    "reumáticos": "reumático",
    "reunais": "reunir",
    "reunamo": "reunir",
    "reunamos": "reunir",
    "reuni": "reunir",
    "reunia": "reunir",
    "reuniam": "reunir",
    "reunias": "reunir",
    "reunida": "reunir",
    "reunidas": "reunir",
    "reunido": "reunir",
    "reunidora": "reunidor",
    "reunidoras": "reunidor",
    "reunidores": "reunidor",
    "reunidos": "reunir",
    "reunifica": "reunificar",
    "reunificada": "reunificar",
    "reunificadas": "reunificar",
    "reunificado": "reunificar",
    "reunificadores": "reunificador",
    "reunificados": "reunificar",
    "reunificai": "reunificar",
    "reunificais": "reunificar",
    "reunificam": "reunificar",
    "reunificamo": "reunificar",
    "reunificamos": "reunificar",
    "reunificando": "reunificar",
    "reunificara": "reunificar",
    "reunificaram": "reunificar",
    "reunificaras": "reunificar",
    "reunificarde": "reunificar",
    "reunificardes": "reunificar",
    "reunificare": "reunificar",
    "reunificarei": "reunificar",
    "reunificareis": "reunificar",
    "reunificarem": "reunificar",
    "reunificaremos": "reunificar",
    "reunificares": "reunificar",
    "reunificaria": "reunificar",
    "reunificariam": "reunificar",
    "reunificarias": "reunificar",
    "reunificarmo": "reunificar",
    "reunificarmos": "reunificar",
    "reunificará": "reunificar",
    "reunificarás": "reunificar",
    "reunificarão": "reunificar",
    "reunificaríamos": "reunificar",
    "reunificaríeis": "reunificar",
    "reunificas": "reunificar",
    "reunificasse": "reunificar",
    "reunificassem": "reunificar",
    "reunificasses": "reunificar",
    "reunificaste": "reunificar",
    "reunificastes": "reunificar",
    "reunificava": "reunificar",
    "reunificavam": "reunificar",
    "reunificavas": "reunificar",
    "reunificações": "reunificação",
    "reunifico": "reunificar",
    "reunificou": "reunificar",
    "reunificá": "reunificar",
    "reunificámo": "reunificar",
    "reunificámos": "reunificar",
    "reunificáramo": "reunificar",
    "reunificáramos": "reunificar",
    "reunificárei": "reunificar",
    "reunificáreis": "reunificar",
    "reunificásseis": "reunificar",
    "reunificássemos": "reunificar",
    "reunificávamo": "reunificar",
    "reunificávamos": "reunificar",
    "reunificávei": "reunificar",
    "reunificáveis": "reunificável",
    "reunifique": "reunificar",
    "reunifiquei": "reunificar",
    "reunifiqueis": "reunificar",
    "reunifiquem": "reunificar",
    "reunifiquemo": "reunificar",
    "reunifiquemos": "reunificar",
    "reunifiques": "reunificar",
    "reunimo": "reunir",
    "reunimos": "reunir",
    "reunindo": "reunir",
    "reunira": "reunir",
    "reuniram": "reunir",
    "reuniras": "reunir",
    "reunirde": "reunir",
    "reunirdes": "reunir",
    "reunire": "reunir",
    "reunirei": "reunir",
    "reunireis": "reunir",
    "reunirem": "reunir",
    "reuniremos": "reunir",
    "reunires": "reunir",
    "reuniria": "reunir",
    "reuniriam": "reunir",
    "reunirias": "reunir",
    "reunirmo": "reunir",
    "reunirmos": "reunir",
    "reunirá": "reunir",
    "reunirás": "reunir",
    "reunirão": "reunir",
    "reuniríamos": "reunir",
    "reuniríeis": "reunir",
    "reunis": "reunir",
    "reunisse": "reunir",
    "reunissem": "reunir",
    "reunisses": "reunir",
    "reuniste": "reunir",
    "reunistes": "reunir",
    "reuniu": "reunir",
    "reuniões": "reunião",
    "reuníamo": "reunir",
    "reuníamos": "reunir",
    "reuníei": "reunir",
    "reuníeis": "reunir",
    "reuníramo": "reunir",
    "reuníramos": "reunir",
    "reunírei": "reunir",
    "reuníreis": "reunir",
    "reunísseis": "reunir",
    "reuníssemos": "reunir",
    "reurbanizações": "reurbanização",
    "reutilizada": "reutilizado",
    "reutilizadas": "reutilizado",
    "reutilizados": "reutilizado",
    "reutilizações": "reutilização",
    "reutilizáveis": "reutilizável",
    "revacina": "revacinar",
    "revacinada": "revacinar",
    "revacinadas": "revacinar",
    "revacinado": "revacinar",
    "revacinados": "revacinar",
    "revacinai": "revacinar",
    "revacinais": "revacinar",
    "revacinam": "revacinar",
    "revacinamo": "revacinar",
    "revacinamos": "revacinar",
    "revacinando": "revacinar",
    "revacinara": "revacinar",
    "revacinaram": "revacinar",
    "revacinaras": "revacinar",
    "revacinarde": "revacinar",
    "revacinardes": "revacinar",
    "revacinare": "revacinar",
    "revacinarei": "revacinar",
    "revacinareis": "revacinar",
    "revacinarem": "revacinar",
    "revacinaremos": "revacinar",
    "revacinares": "revacinar",
    "revacinaria": "revacinar",
    "revacinariam": "revacinar",
    "revacinarias": "revacinar",
    "revacinarmo": "revacinar",
    "revacinarmos": "revacinar",
    "revacinará": "revacinar",
    "revacinarás": "revacinar",
    "revacinarão": "revacinar",
    "revacinaríamos": "revacinar",
    "revacinaríeis": "revacinar",
    "revacinas": "revacinar",
    "revacinasse": "revacinar",
    "revacinassem": "revacinar",
    "revacinasses": "revacinar",
    "revacinaste": "revacinar",
    "revacinastes": "revacinar",
    "revacinava": "revacinar",
    "revacinavam": "revacinar",
    "revacinavas": "revacinar",
    "revacinações": "revacinação",
    "revacine": "revacinar",
    "revacinei": "revacinar",
    "revacineis": "revacinar",
    "revacinem": "revacinar",
    "revacinemo": "revacinar",
    "revacinemos": "revacinar",
    "revacines": "revacinar",
    "revacino": "revacinar",
    "revacinou": "revacinar",
    "revaciná": "revacinar",
    "revacinámo": "revacinar",
    "revacinámos": "revacinar",
    "revacináramo": "revacinar",
    "revacináramos": "revacinar",
    "revacinárei": "revacinar",
    "revacináreis": "revacinar",
    "revacinásseis": "revacinar",
    "revacinássemos": "revacinar",
    "revacinávamo": "revacinar",
    "revacinávamos": "revacinar",
    "revacinávei": "revacinar",
    "revacináveis": "revacinar",
    "revalentas": "revalenta",
    "revalida": "revalidar",
    "revalidada": "revalidar",
    "revalidadas": "revalidar",
    "revalidado": "revalidar",
    "revalidados": "revalidar",
    "revalidai": "revalidar",
    "revalidais": "revalidar",
    "revalidam": "revalidar",
    "revalidamo": "revalidar",
    "revalidamos": "revalidar",
    "revalidando": "revalidar",
    "revalidara": "revalidar",
    "revalidaram": "revalidar",
    "revalidaras": "revalidar",
    "revalidarde": "revalidar",
    "revalidardes": "revalidar",
    "revalidare": "revalidar",
    "revalidarei": "revalidar",
    "revalidareis": "revalidar",
    "revalidarem": "revalidar",
    "revalidaremos": "revalidar",
    "revalidares": "revalidar",
    "revalidaria": "revalidar",
    "revalidariam": "revalidar",
    "revalidarias": "revalidar",
    "revalidarmo": "revalidar",
    "revalidarmos": "revalidar",
    "revalidará": "revalidar",
    "revalidarás": "revalidar",
    "revalidarão": "revalidar",
    "revalidaríamos": "revalidar",
    "revalidaríeis": "revalidar",
    "revalidas": "revalidar",
    "revalidasse": "revalidar",
    "revalidassem": "revalidar",
    "revalidasses": "revalidar",
    "revalidaste": "revalidar",
    "revalidastes": "revalidar",
    "revalidava": "revalidar",
    "revalidavam": "revalidar",
    "revalidavas": "revalidar",
    "revalidações": "revalidação",
    "revalide": "revalidar",
    "revalidei": "revalidar",
    "revalideis": "revalidar",
    "revalidem": "revalidar",
    "revalidemo": "revalidar",
    "revalidemos": "revalidar",
    "revalides": "revalidar",
    "revalido": "revalidar",
    "revalidou": "revalidar",
    "revalidá": "revalidar",
    "revalidámo": "revalidar",
    "revalidámos": "revalidar",
    "revalidáramo": "revalidar",
    "revalidáramos": "revalidar",
    "revalidárei": "revalidar",
    "revalidáreis": "revalidar",
    "revalidásseis": "revalidar",
    "revalidássemos": "revalidar",
    "revalidávamo": "revalidar",
    "revalidávamos": "revalidar",
    "revalidávei": "revalidar",
    "revalidáveis": "revalidar",
    "revaloriza": "revalorizar",
    "revalorizada": "revalorizar",
    "revalorizadas": "revalorizar",
    "revalorizado": "revalorizar",
    "revalorizados": "revalorizar",
    "revalorizai": "revalorizar",
    "revalorizais": "revalorizar",
    "revalorizam": "revalorizar",
    "revalorizamo": "revalorizar",
    "revalorizamos": "revalorizar",
    "revalorizando": "revalorizar",
    "revalorizara": "revalorizar",
    "revalorizaram": "revalorizar",
    "revalorizaras": "revalorizar",
    "revalorizarde": "revalorizar",
    "revalorizardes": "revalorizar",
    "revalorizare": "revalorizar",
    "revalorizarei": "revalorizar",
    "revalorizareis": "revalorizar",
    "revalorizarem": "revalorizar",
    "revalorizaremos": "revalorizar",
    "revalorizares": "revalorizar",
    "revalorizaria": "revalorizar",
    "revalorizariam": "revalorizar",
    "revalorizarias": "revalorizar",
    "revalorizarmo": "revalorizar",
    "revalorizarmos": "revalorizar",
    "revalorizará": "revalorizar",
    "revalorizarás": "revalorizar",
    "revalorizarão": "revalorizar",
    "revalorizaríamos": "revalorizar",
    "revalorizaríeis": "revalorizar",
    "revalorizas": "revalorizar",
    "revalorizasse": "revalorizar",
    "revalorizassem": "revalorizar",
    "revalorizasses": "revalorizar",
    "revalorizaste": "revalorizar",
    "revalorizastes": "revalorizar",
    "revalorizava": "revalorizar",
    "revalorizavam": "revalorizar",
    "revalorizavas": "revalorizar",
    "revalorizações": "revalorização",
    "revalorize": "revalorizar",
    "revalorizei": "revalorizar",
    "revalorizeis": "revalorizar",
    "revalorizem": "revalorizar",
    "revalorizemo": "revalorizar",
    "revalorizemos": "revalorizar",
    "revalorizes": "revalorizar",
    "revalorizo": "revalorizar",
    "revalorizou": "revalorizar",
    "revalorizá": "revalorizar",
    "revalorizámo": "revalorizar",
    "revalorizámos": "revalorizar",
    "revalorizáramo": "revalorizar",
    "revalorizáramos": "revalorizar",
    "revalorizárei": "revalorizar",
    "revalorizáreis": "revalorizar",
    "revalorizásseis": "revalorizar",
    "revalorizássemos": "revalorizar",
    "revalorizávamo": "revalorizar",
    "revalorizávamos": "revalorizar",
    "revalorizávei": "revalorizar",
    "revalorizáveis": "revalorizável",
    "revanches": "revanche",
    "revanchismos": "revanchismo",
    "revanchistas": "revanchista",
    "revede": "rever",
    "revedes": "rever",
    "revedora": "revedor",
    "revedoras": "revedor",
    "revedores": "revedor",
    "reveillons": "reveillon",
    "reveio": "revir",
    "reveis": "revel",
    "reveja": "rever",
    "revejais": "rever",
    "revejam": "rever",
    "revejamo": "rever",
    "revejamos": "rever",
    "revejas": "rever",
    "revejo": "rever",
    "revela": "revelar",
    "revelada": "revelar",
    "reveladas": "revelar",
    "revelado": "revelar",
    "reveladora": "revelador",
    "reveladoras": "revelador",
    "reveladores": "revelador",
    "revelados": "revelar",
    "revelai": "revelar",
    "revelais": "revelar",
    "revelam": "revelar",
    "revelamo": "revelar",
    "revelamos": "revelar",
    "revelando": "revelar",
    "revelantismos": "revelantismo",
    "revelantistas": "revelantista",
    "revelara": "revelar",
    "revelaram": "revelar",
    "revelaras": "revelar",
    "revelarde": "revelar",
    "revelardes": "revelar",
    "revelare": "revelar",
    "revelarei": "revelar",
    "revelareis": "revelar",
    "revelarem": "revelar",
    "revelaremos": "revelar",
    "revelares": "revelar",
    "revelaria": "revelar",
    "revelariam": "revelar",
    "revelarias": "revelar",
    "revelarmo": "revelar",
    "revelarmos": "revelar",
    "revelará": "revelar",
    "revelarás": "revelar",
    "revelarão": "revelar",
    "revelaríamos": "revelar",
    "revelaríeis": "revelar",
    "revelas": "revelar",
    "revelasse": "revelar",
    "revelassem": "revelar",
    "revelasses": "revelar",
    "revelaste": "revelar",
    "revelastes": "revelar",
    "revelava": "revelar",
    "revelavam": "revelar",
    "revelavas": "revelar",
    "revelações": "revelação",
    "revele": "revelir",
    "revelei": "revelar",
    "reveleis": "revelar",
    "revelem": "revelir",
    "revelemo": "revelar",
    "revelemos": "revelar",
    "reveles": "revelir",
    "revelha": "revelho",
    "revelhas": "revelho",
    "revelhos": "revelho",
    "revelhusca": "revelhusco",
    "revelhuscas": "revelhusco",
    "revelhuscos": "revelhusco",
    "reveli": "revelir",
    "revelia": "revelir",
    "reveliam": "revelir",
    "revelias": "revelir",
    "revelida": "revelir",
    "revelidas": "revelir",
    "revelido": "revelir",
    "revelidos": "revelir",
    "revelimo": "revelir",
    "revelimos": "revelir",
    "revelindo": "revelir",
    "revelins": "revelim",
    "revelira": "revelir",
    "reveliram": "revelir",
    "reveliras": "revelir",
    "revelirde": "revelir",
    "revelirdes": "revelir",
    "revelire": "revelir",
    "revelirei": "revelir",
    "revelireis": "revelir",
    "revelirem": "revelir",
    "reveliremos": "revelir",
    "revelires": "revelir",
    "reveliria": "revelir",
    "reveliriam": "revelir",
    "revelirias": "revelir",
    "revelirmo": "revelir",
    "revelirmos": "revelir",
    "revelirá": "revelir",
    "revelirás": "revelir",
    "revelirão": "revelir",
    "reveliríamos": "revelir",
    "reveliríeis": "revelir",
    "revelis": "revelir",
    "revelisse": "revelir",
    "revelissem": "revelir",
    "revelisses": "revelir",
    "reveliste": "revelir",
    "revelistes": "revelir",
    "reveliu": "revelir",
    "revelo": "revelar",
    "revelou": "revelar",
    "revelá": "revelar",
    "revelámo": "revelar",
    "revelámos": "revelar",
    "reveláramo": "revelar",
    "reveláramos": "revelar",
    "revelárei": "revelar",
    "reveláreis": "revelar",
    "revelásseis": "revelar",
    "revelássemos": "revelar",
    "revelávamo": "revelar",
    "revelávamos": "revelar",
    "revelávei": "revelar",
    "reveláveis": "revelável",
    "revelíamo": "revelir",
    "revelíamos": "revelir",
    "revelíei": "revelir",
    "revelíeis": "revelir",
    "revelíramo": "revelir",
    "revelíramos": "revelir",
    "revelírei": "revelir",
    "revelíreis": "revelir",
    "revelísseis": "revelir",
    "revelíssemos": "revelir",
    "revem": "revir",
    "revemo": "rever",
    "revemos": "rever",
    "revenda": "revender",
    "revendais": "revender",
    "revendam": "revender",
    "revendamo": "revender",
    "revendamos": "revender",
    "revendas": "revender",
    "revende": "revender",
    "revendedeira": "revendedor",
    "revendedeiras": "revendedor",
    "revendedora": "revendedor",
    "revendedoras": "revendedor",
    "revendedores": "revendedor",
    "revendei": "revender",
    "revendeis": "revender",
    "revendem": "revender",
    "revendemo": "revender",
    "revendemos": "revender",
    "revendendo": "revender",
    "revendera": "revender",
    "revenderam": "revender",
    "revenderas": "revender",
    "revenderde": "revender",
    "revenderdes": "revender",
    "revendere": "revender",
    "revenderei": "revender",
    "revendereis": "revender",
    "revenderem": "revender",
    "revenderemos": "revender",
    "revenderes": "revender",
    "revenderia": "revender",
    "revenderiam": "revender",
    "revenderias": "revender",
    "revendermo": "revender",
    "revendermos": "revender",
    "revenderá": "revender",
    "revenderás": "revender",
    "revenderão": "revender",
    "revenderíamos": "revender",
    "revenderíeis": "revender",
    "revendes": "revender",
    "revendesse": "revender",
    "revendessem": "revender",
    "revendesses": "revender",
    "revendeste": "revender",
    "revendestes": "revender",
    "revendeu": "revender",
    "revendi": "revender",
    "revendia": "revender",
    "revendiam": "revender",
    "revendias": "revender",
    "revendida": "revender",
    "revendidas": "revender",
    "revendido": "revender",
    "revendidos": "revender",
    "revendilhona": "revendilhão",
    "revendilhonas": "revendilhão",
    "revendilhões": "revendilhão",
    "revendições": "revendição",
    "revendo": "rever",
    "revendona": "revendão",
    "revendonas": "revendão",
    "revendê": "revender",
    "revendêramo": "revender",
    "revendêramos": "revender",
    "revendêrei": "revender",
    "revendêreis": "revender",
    "revendêsseis": "revender",
    "revendêssemos": "revender",
    "revendíamo": "revender",
    "revendíamos": "revender",
    "revendíei": "revender",
    "revendíeis": "revender",
    "revendões": "revendão",
    "revenera": "revenerar",
    "revenerada": "revenerar",
    "reveneradas": "revenerar",
    "revenerado": "revenerar",
    "revenerados": "revenerar",
    "revenerai": "revenerar",
    "revenerais": "revenerar",
    "reveneram": "revenerar",
    "reveneramo": "revenerar",
    "reveneramos": "revenerar",
    "revenerando": "revenerar",
    "revenerara": "revenerar",
    "reveneraram": "revenerar",
    "reveneraras": "revenerar",
    "revenerarde": "revenerar",
    "revenerardes": "revenerar",
    "revenerare": "revenerar",
    "revenerarei": "revenerar",
    "revenerareis": "revenerar",
    "revenerarem": "revenerar",
    "reveneraremos": "revenerar",
    "revenerares": "revenerar",
    "reveneraria": "revenerar",
    "revenerariam": "revenerar",
    "revenerarias": "revenerar",
    "revenerarmo": "revenerar",
    "revenerarmos": "revenerar",
    "revenerará": "revenerar",
    "revenerarás": "revenerar",
    "revenerarão": "revenerar",
    "reveneraríamos": "revenerar",
    "reveneraríeis": "revenerar",
    "reveneras": "revenerar",
    "revenerasse": "revenerar",
    "revenerassem": "revenerar",
    "revenerasses": "revenerar",
    "reveneraste": "revenerar",
    "revenerastes": "revenerar",
    "revenerava": "revenerar",
    "reveneravam": "revenerar",
    "reveneravas": "revenerar",
    "revenere": "revenerar",
    "revenerei": "revenerar",
    "revenereis": "revenerar",
    "revenerem": "revenerar",
    "reveneremo": "revenerar",
    "reveneremos": "revenerar",
    "reveneres": "revenerar",
    "revenero": "revenerar",
    "revenerou": "revenerar",
    "revenerá": "revenerar",
    "revenerámo": "revenerar",
    "revenerámos": "revenerar",
    "reveneráramo": "revenerar",
    "reveneráramos": "revenerar",
    "revenerárei": "revenerar",
    "reveneráreis": "revenerar",
    "revenerásseis": "revenerar",
    "revenerássemos": "revenerar",
    "revenerávamo": "revenerar",
    "revenerávamos": "revenerar",
    "revenerávei": "revenerar",
    "reveneráveis": "revenerar",
    "revenha": "revir",
    "revenhais": "revir",
    "revenham": "revir",
    "revenhamo": "revir",
    "revenhamos": "revir",
    "revenhas": "revir",
    "revenho": "revir",
    "reveni": "revenir",
    "revenia": "revenir",
    "reveniam": "revenir",
    "revenias": "revenir",
    "revenida": "revenir",
    "revenidas": "revenir",
    "revenido": "revenir",
    "revenidos": "revenir",
    "revenimo": "revenir",
    "revenimos": "revenir",
    "revenindo": "revenir",
    "revenira": "revenir",
    "reveniram": "revenir",
    "reveniras": "revenir",
    "revenirde": "revenir",
    "revenirdes": "revenir",
    "revenire": "revenir",
    "revenirei": "revenir",
    "revenireis": "revenir",
    "revenirem": "revenir",
    "reveniremos": "revenir",
    "revenires": "revenir",
    "reveniria": "revenir",
    "reveniriam": "revenir",
    "revenirias": "revenir",
    "revenirmo": "revenir",
    "revenirmos": "revenir",
    "revenirá": "revenir",
    "revenirás": "revenir",
    "revenirão": "revenir",
    "reveniríamos": "revenir",
    "reveniríeis": "revenir",
    "revenis": "revenir",
    "revenisse": "revenir",
    "revenissem": "revenir",
    "revenisses": "revenir",
    "reveniste": "revenir",
    "revenistes": "revenir",
    "reveniu": "revenir",
    "reveníamo": "revenir",
    "reveníamos": "revenir",
    "reveníei": "revenir",
    "reveníeis": "revenir",
    "reveníramo": "revenir",
    "reveníramos": "revenir",
    "revenírei": "revenir",
    "reveníreis": "revenir",
    "revenísseis": "revenir",
    "reveníssemos": "revenir",
    "reverbera": "reverberar",
    "reverberada": "reverberar",
    "reverberadas": "reverberar",
    "reverberado": "reverberar",
    "reverberados": "reverberar",
    "reverberai": "reverberar",
    "reverberais": "reverberar",
    "reverberam": "reverberar",
    "reverberamo": "reverberar",
    "reverberamos": "reverberar",
    "reverberando": "reverberar",
    "reverberantes": "reverberante",
    "reverberara": "reverberar",
    "reverberaram": "reverberar",
    "reverberaras": "reverberar",
    "reverberarde": "reverberar",
    "reverberardes": "reverberar",
    "reverberare": "reverberar",
    "reverberarei": "reverberar",
    "reverberareis": "reverberar",
    "reverberarem": "reverberar",
    "reverberaremos": "reverberar",
    "reverberares": "reverberar",
    "reverberaria": "reverberar",
    "reverberariam": "reverberar",
    "reverberarias": "reverberar",
    "reverberarmo": "reverberar",
    "reverberarmos": "reverberar",
    "reverberará": "reverberar",
    "reverberarás": "reverberar",
    "reverberarão": "reverberar",
    "reverberaríamos": "reverberar",
    "reverberaríeis": "reverberar",
    "reverberas": "reverberar",
    "reverberasse": "reverberar",
    "reverberassem": "reverberar",
    "reverberasses": "reverberar",
    "reverberaste": "reverberar",
    "reverberastes": "reverberar",
    "reverberatória": "reverberatório",
    "reverberatórias": "reverberatório",
    "reverberatórios": "reverberatório",
    "reverberava": "reverberar",
    "reverberavam": "reverberar",
    "reverberavas": "reverberar",
    "reverberações": "reverberação",
    "reverbere": "reverberar",
    "reverberei": "reverberar",
    "reverbereis": "reverberar",
    "reverberem": "reverberar",
    "reverberemo": "reverberar",
    "reverberemos": "reverberar",
    "reverberes": "reverberar",
    "reverbero": "reverberar",
    "reverberou": "reverberar",
    "reverberá": "reverberar",
    "reverberámo": "reverberar",
    "reverberámos": "reverberar",
    "reverberáramo": "reverberar",
    "reverberáramos": "reverberar",
    "reverberárei": "reverberar",
    "reverberáreis": "reverberar",
    "reverberásseis": "reverberar",
    "reverberássemos": "reverberar",
    "reverberávamo": "reverberar",
    "reverberávamos": "reverberar",
    "reverberávei": "reverberar",
    "reverberáveis": "reverberar",
    "reverde": "rever",
    "reverdece": "reverdecer",
    "reverdecei": "reverdecer",
    "reverdeceis": "reverdecer",
    "reverdecem": "reverdecer",
    "reverdecemo": "reverdecer",
    "reverdecemos": "reverdecer",
    "reverdecendo": "reverdecer",
    "reverdecera": "reverdecer",
    "reverdeceram": "reverdecer",
    "reverdeceras": "reverdecer",
    "reverdecerde": "reverdecer",
    "reverdecerdes": "reverdecer",
    "reverdecere": "reverdecer",
    "reverdecerei": "reverdecer",
    "reverdecereis": "reverdecer",
    "reverdecerem": "reverdecer",
    "reverdeceremos": "reverdecer",
    "reverdeceres": "reverdecer",
    "reverdeceria": "reverdecer",
    "reverdeceriam": "reverdecer",
    "reverdecerias": "reverdecer",
    "reverdecermo": "reverdecer",
    "reverdecermos": "reverdecer",
    "reverdecerá": "reverdecer",
    "reverdecerás": "reverdecer",
    "reverdecerão": "reverdecer",
    "reverdeceríamos": "reverdecer",
    "reverdeceríeis": "reverdecer",
    "reverdeces": "reverdecer",
    "reverdecesse": "reverdecer",
    "reverdecessem": "reverdecer",
    "reverdecesses": "reverdecer",
    "reverdeceste": "reverdecer",
    "reverdecestes": "reverdecer",
    "reverdeceu": "reverdecer",
    "reverdeci": "reverdecer",
    "reverdecia": "reverdecer",
    "reverdeciam": "reverdecer",
    "reverdecias": "reverdecer",
    "reverdecida": "reverdecido",
    "reverdecidas": "reverdecido",
    "reverdecido": "reverdecer",
    "reverdecidos": "reverdecido",
    "reverdecê": "reverdecer",
    "reverdecêramo": "reverdecer",
    "reverdecêramos": "reverdecer",
    "reverdecêrei": "reverdecer",
    "reverdecêreis": "reverdecer",
    "reverdecêsseis": "reverdecer",
    "reverdecêssemos": "reverdecer",
    "reverdecíamo": "reverdecer",
    "reverdecíamos": "reverdecer",
    "reverdecíei": "reverdecer",
    "reverdecíeis": "reverdecer",
    "reverdeja": "reverdejar",
    "reverdejada": "reverdejar",
    "reverdejadas": "reverdejar",
    "reverdejado": "reverdejar",
    "reverdejados": "reverdejar",
    "reverdejai": "reverdejar",
    "reverdejais": "reverdejar",
    "reverdejam": "reverdejar",
    "reverdejamo": "reverdejar",
    "reverdejamos": "reverdejar",
    "reverdejando": "reverdejar",
    "reverdejantes": "reverdejante",
    "reverdejara": "reverdejar",
    "reverdejaram": "reverdejar",
    "reverdejaras": "reverdejar",
    "reverdejardes": "reverdejar",
    "reverdejarei": "reverdejar",
    "reverdejareis": "reverdejar",
    "reverdejarem": "reverdejar",
    "reverdejaremos": "reverdejar",
    "reverdejares": "reverdejar",
    "reverdejaria": "reverdejar",
    "reverdejariam": "reverdejar",
    "reverdejarias": "reverdejar",
    "reverdejarmo": "reverdejar",
    "reverdejarmos": "reverdejar",
    "reverdejará": "reverdejar",
    "reverdejarás": "reverdejar",
    "reverdejarão": "reverdejar",
    "reverdejaríamos": "reverdejar",
    "reverdejaríeis": "reverdejar",
    "reverdejas": "reverdejar",
    "reverdejasse": "reverdejar",
    "reverdejassem": "reverdejar",
    "reverdejasses": "reverdejar",
    "reverdejaste": "reverdejar",
    "reverdejastes": "reverdejar",
    "reverdejava": "reverdejar",
    "reverdejavam": "reverdejar",
    "reverdejavas": "reverdejar",
    "reverdeje": "reverdejar",
    "reverdejei": "reverdejar",
    "reverdejeis": "reverdejar",
    "reverdejem": "reverdejar",
    "reverdejemo": "reverdejar",
    "reverdejemos": "reverdejar",
    "reverdejes": "reverdejar",
    "reverdejo": "reverdejar",
    "reverdejou": "reverdejar",
    "reverdejámo": "reverdejar",
    "reverdejámos": "reverdejar",
    "reverdejáramo": "reverdejar",
    "reverdejáramos": "reverdejar",
    "reverdejáreis": "reverdejar",
    "reverdejásseis": "reverdejar",
    "reverdejássemos": "reverdejar",
    "reverdejávamo": "reverdejar",
    "reverdejávamos": "reverdejar",
    "reverdejáveis": "reverdejar",
    "reverdes": "rever",
    "reverdeça": "reverdecer",
    "reverdeçais": "reverdecer",
    "reverdeçam": "reverdecer",
    "reverdeçamo": "reverdecer",
    "reverdeçamos": "reverdecer",
    "reverdeças": "reverdecer",
    "reverdeço": "reverdecer",
    "revere": "rever",
    "reverei": "rever",
    "revereis": "rever",
    "reverem": "rever",
    "reveremos": "rever",
    "reverencia": "reverenciar",
    "reverenciada": "reverenciar",
    "reverenciadas": "reverenciar",
    "reverenciado": "reverenciar",
    "reverenciadora": "reverenciador",
    "reverenciadoras": "reverenciador",
    "reverenciadores": "reverenciador",
    "reverenciados": "reverenciar",
    "reverenciai": "reverenciar",
    "reverenciais": "reverenciar",
    "reverenciam": "reverenciar",
    "reverenciamo": "reverenciar",
    "reverenciamos": "reverenciar",
    "reverenciando": "reverenciar",
    "reverenciara": "reverenciar",
    "reverenciaram": "reverenciar",
    "reverenciaras": "reverenciar",
    "reverenciarde": "reverenciar",
    "reverenciardes": "reverenciar",
    "reverenciare": "reverenciar",
    "reverenciarei": "reverenciar",
    "reverenciareis": "reverenciar",
    "reverenciarem": "reverenciar",
    "reverenciaremos": "reverenciar",
    "reverenciares": "reverenciar",
    "reverenciaria": "reverenciar",
    "reverenciariam": "reverenciar",
    "reverenciarias": "reverenciar",
    "reverenciarmo": "reverenciar",
    "reverenciarmos": "reverenciar",
    "reverenciará": "reverenciar",
    "reverenciarás": "reverenciar",
    "reverenciarão": "reverenciar",
    "reverenciaríamos": "reverenciar",
    "reverenciaríeis": "reverenciar",
    "reverencias": "reverenciar",
    "reverenciasse": "reverenciar",
    "reverenciassem": "reverenciar",
    "reverenciasses": "reverenciar",
    "reverenciaste": "reverenciar",
    "reverenciastes": "reverenciar",
    "reverenciava": "reverenciar",
    "reverenciavam": "reverenciar",
    "reverenciavas": "reverenciar",
    "reverencie": "reverenciar",
    "reverenciei": "reverenciar",
    "reverencieis": "reverenciar",
    "reverenciem": "reverenciar",
    "reverenciemo": "reverenciar",
    "reverenciemos": "reverenciar",
    "reverencies": "reverenciar",
    "reverencio": "reverenciar",
    "reverenciosa": "reverencioso",
    "reverenciosas": "reverencioso",
    "reverenciosos": "reverencioso",
    "reverenciou": "reverenciar",
    "reverenciá": "reverenciar",
    "reverenciámo": "reverenciar",
    "reverenciámos": "reverenciar",
    "reverenciáramo": "reverenciar",
    "reverenciáramos": "reverenciar",
    "reverenciárei": "reverenciar",
    "reverenciáreis": "reverenciar",
    "reverenciásseis": "reverenciar",
    "reverenciássemos": "reverenciar",
    "reverenciávamo": "reverenciar",
    "reverenciávamos": "reverenciar",
    "reverenciávei": "reverenciar",
    "reverenciáveis": "reverenciar",
    "reverenda": "reverendo",
    "reverendas": "reverendo",
    "reverendaça": "reverendaço",
    "reverendaças": "reverendaço",
    "reverendaços": "reverendaço",
    "reverendos": "reverendo",
    "reverendíssima": "reverendo",
    "reverendíssimas": "reverendo",
    "reverendíssimo": "reverendo",
    "reverendíssimos": "reverendo",
    "reverentes": "reverente",
    "reverentíssima": "reverente",
    "reverentíssimas": "reverente",
    "reverentíssimo": "reverente",
    "reverentíssimos": "reverente",
    "reveres": "rever",
    "reveria": "rever",
    "reveriam": "rever",
    "reverias": "reveria",
    "reverifica": "reverificar",
    "reverificada": "reverificar",
    "reverificadas": "reverificar",
    "reverificado": "reverificar",
    "reverificadora": "reverificador",
    "reverificadoras": "reverificador",
    "reverificadores": "reverificador",
    "reverificados": "reverificar",
    "reverificai": "reverificar",
    "reverificais": "reverificar",
    "reverificam": "reverificar",
    "reverificamo": "reverificar",
    "reverificamos": "reverificar",
    "reverificando": "reverificar",
    "reverificara": "reverificar",
    "reverificaram": "reverificar",
    "reverificaras": "reverificar",
    "reverificarde": "reverificar",
    "reverificardes": "reverificar",
    "reverificare": "reverificar",
    "reverificarei": "reverificar",
    "reverificareis": "reverificar",
    "reverificarem": "reverificar",
    "reverificaremos": "reverificar",
    "reverificares": "reverificar",
    "reverificaria": "reverificar",
    "reverificariam": "reverificar",
    "reverificarias": "reverificar",
    "reverificarmo": "reverificar",
    "reverificarmos": "reverificar",
    "reverificará": "reverificar",
    "reverificarás": "reverificar",
    "reverificarão": "reverificar",
    "reverificaríamos": "reverificar",
    "reverificaríeis": "reverificar",
    "reverificas": "reverificar",
    "reverificasse": "reverificar",
    "reverificassem": "reverificar",
    "reverificasses": "reverificar",
    "reverificaste": "reverificar",
    "reverificastes": "reverificar",
    "reverificava": "reverificar",
    "reverificavam": "reverificar",
    "reverificavas": "reverificar",
    "reverificações": "reverificação",
    "reverifico": "reverificar",
    "reverificou": "reverificar",
    "reverificá": "reverificar",
    "reverificámo": "reverificar",
    "reverificámos": "reverificar",
    "reverificáramo": "reverificar",
    "reverificáramos": "reverificar",
    "reverificárei": "reverificar",
    "reverificáreis": "reverificar",
    "reverificásseis": "reverificar",
    "reverificássemos": "reverificar",
    "reverificávamo": "reverificar",
    "reverificávamos": "reverificar",
    "reverificávei": "reverificar",
    "reverificáveis": "reverificar",
    "reverifique": "reverificar",
    "reverifiquei": "reverificar",
    "reverifiqueis": "reverificar",
    "reverifiquem": "reverificar",
    "reverifiquemo": "reverificar",
    "reverifiquemos": "reverificar",
    "reverifiques": "reverificar",
    "revermo": "rever",
    "revermos": "rever",
    "reversa": "reverso",
    "reversada": "reversar",
    "reversadas": "reversar",
    "reversado": "reversar",
    "reversados": "reversar",
    "reversai": "reversar",
    "reversais": "reversar",
    "reversam": "reversar",
    "reversamo": "reversar",
    "reversamos": "reversar",
    "reversando": "reversar",
    "reversara": "reversar",
    "reversaram": "reversar",
    "reversaras": "reversar",
    "reversardes": "reversar",
    "reversarei": "reversar",
    "reversareis": "reversar",
    "reversarem": "reversar",
    "reversaremos": "reversar",
    "reversares": "reversar",
    "reversaria": "reversar",
    "reversariam": "reversar",
    "reversarias": "reversar",
    "reversarmo": "reversar",
    "reversarmos": "reversar",
    "reversará": "reversar",
    "reversarás": "reversar",
    "reversarão": "reversar",
    "reversaríamos": "reversar",
    "reversaríeis": "reversar",
    "reversas": "reverso",
    "reversasse": "reversar",
    "reversassem": "reversar",
    "reversasses": "reversar",
    "reversaste": "reversar",
    "reversastes": "reversar",
    "reversava": "reversar",
    "reversavam": "reversar",
    "reversavas": "reversar",
    "reverse": "reversar",
    "reversei": "reversar",
    "reverseis": "reversar",
    "reversem": "reversar",
    "reversemo": "reversar",
    "reversemos": "reversar",
    "reverses": "reversar",
    "reversibilidades": "reversibilidade",
    "reversiva": "reversivo",
    "reversivas": "reversivo",
    "reversivos": "reversivo",
    "reverso": "reversar",
    "reversos": "reverso",
    "reversou": "reversar",
    "reversámo": "reversar",
    "reversámos": "reversar",
    "reversáramo": "reversar",
    "reversáramos": "reversar",
    "reversáreis": "reversar",
    "reversásseis": "reversar",
    "reversássemos": "reversar",
    "reversávamo": "reversar",
    "reversávamos": "reversar",
    "reversáveis": "reversar",
    "reversíveis": "reversível",
    "reversões": "reversão",
    "reverta": "reverter",
    "revertais": "reverter",
    "revertam": "reverter",
    "revertamo": "reverter",
    "revertamos": "reverter",
    "revertas": "reverter",
    "reverte": "reverter",
    "revertei": "reverter",
    "reverteis": "reverter",
    "revertem": "reverter",
    "revertemo": "reverter",
    "revertemos": "reverter",
    "revertendo": "reverter",
    "revertera": "reverter",
    "reverteram": "reverter",
    "reverteras": "reverter",
    "reverterdes": "reverter",
    "reverterei": "reverter",
    "revertereis": "reverter",
    "reverterem": "reverter",
    "reverteremos": "reverter",
    "reverteres": "reverter",
    "reverteria": "reverter",
    "reverteriam": "reverter",
    "reverterias": "reverter",
    "revertermo": "reverter",
    "revertermos": "reverter",
    "reverterá": "reverter",
    "reverterás": "reverter",
    "reverterão": "reverter",
    "reverteríamos": "reverter",
    "reverteríeis": "reverter",
    "revertes": "reverter",
    "revertesse": "reverter",
    "revertessem": "reverter",
    "revertesses": "reverter",
    "reverteste": "reverter",
    "revertestes": "reverter",
    "reverteu": "reverter",
    "reverti": "reverter",
    "revertia": "reverter",
    "revertiam": "reverter",
    "revertias": "reverter",
    "revertida": "revertido",
    "revertidas": "revertido",
    "revertido": "reverter",
    "revertidos": "revertido",
    "reverto": "reverter",
    "revertêramo": "reverter",
    "revertêramos": "reverter",
    "revertêreis": "reverter",
    "revertêsseis": "reverter",
    "revertêssemos": "reverter",
    "revertíamo": "reverter",
    "revertíamos": "reverter",
    "revertíeis": "reverter",
    "revertíveis": "revertível",
    "reverá": "rever",
    "reverás": "rever",
    "reverão": "rever",
    "reverências": "reverência",
    "reveríamos": "rever",
    "reveríeis": "rever",
    "reveses": "revés",
    "revesilhos": "revesilho",
    "revessa": "revesso",
    "revessada": "revessar",
    "revessadas": "revessar",
    "revessado": "revessar",
    "revessados": "revessar",
    "revessai": "revessar",
    "revessais": "revessar",
    "revessam": "revessar",
    "revessamo": "revessar",
    "revessamos": "revessar",
    "revessando": "revessar",
    "revessara": "revessar",
    "revessaram": "revessar",
    "revessaras": "revessar",
    "revessarde": "revessar",
    "revessardes": "revessar",
    "revessare": "revessar",
    "revessarei": "revessar",
    "revessareis": "revessar",
    "revessarem": "revessar",
    "revessaremos": "revessar",
    "revessares": "revessar",
    "revessaria": "revessar",
    "revessariam": "revessar",
    "revessarias": "revessar",
    "revessarmo": "revessar",
    "revessarmos": "revessar",
    "revessará": "revessar",
    "revessarás": "revessar",
    "revessarão": "revessar",
    "revessaríamos": "revessar",
    "revessaríeis": "revessar",
    "revessas": "revesso",
    "revessasse": "revessar",
    "revessassem": "revessar",
    "revessasses": "revessar",
    "revessaste": "revessar",
    "revessastes": "revessar",
    "revessava": "revessar",
    "revessavam": "revessar",
    "revessavas": "revessar",
    "revesse": "revessar",
    "revessei": "revessar",
    "revesseis": "revessar",
    "revessem": "revessar",
    "revessemo": "revessar",
    "revessemos": "revessar",
    "revesses": "revessar",
    "revesso": "revessar",
    "revessos": "revesso",
    "revessou": "revessar",
    "revessá": "revessar",
    "revessámo": "revessar",
    "revessámos": "revessar",
    "revessáramo": "revessar",
    "revessáramos": "revessar",
    "revessárei": "revessar",
    "revessáreis": "revessar",
    "revessásseis": "revessar",
    "revessássemos": "revessar",
    "revessávamo": "revessar",
    "revessávamos": "revessar",
    "revessávei": "revessar",
    "revessáveis": "revessar",
    "reveste": "revestir",
    "revestem": "revestir",
    "revestes": "revestir",
    "revesti": "revestir",
    "revestia": "revestir",
    "revestiam": "revestir",
    "revestias": "revestir",
    "revestida": "revestir",
    "revestidas": "revestir",
    "revestido": "revestir",
    "revestidos": "revestir",
    "revestimentos": "revestimento",
    "revestimo": "revestir",
    "revestimos": "revestir",
    "revestindo": "revestir",
    "revestira": "revestir",
    "revestiram": "revestir",
    "revestiras": "revestir",
    "revestirde": "revestir",
    "revestirdes": "revestir",
    "revestire": "revestir",
    "revestirei": "revestir",
    "revestireis": "revestir",
    "revestirem": "revestir",
    "revestiremos": "revestir",
    "revestires": "revestir",
    "revestiria": "revestir",
    "revestiriam": "revestir",
    "revestirias": "revestir",
    "revestirmo": "revestir",
    "revestirmos": "revestir",
    "revestirá": "revestir",
    "revestirás": "revestir",
    "revestirão": "revestir",
    "revestiríamos": "revestir",
    "revestiríeis": "revestir",
    "revestis": "revestir",
    "revestisse": "revestir",
    "revestissem": "revestir",
    "revestisses": "revestir",
    "revestiste": "revestir",
    "revestistes": "revestir",
    "revestiu": "revestir",
    "revestíamo": "revestir",
    "revestíamos": "revestir",
    "revestíei": "revestir",
    "revestíeis": "revestir",
    "revestíramo": "revestir",
    "revestíramos": "revestir",
    "revestírei": "revestir",
    "revestíreis": "revestir",
    "revestísseis": "revestir",
    "revestíssemos": "revestir",
    "reveza": "revezar",
    "revezada": "revezar",
    "revezadas": "revezar",
    "revezado": "revezar",
    "revezadora": "revezador",
    "revezadoras": "revezador",
    "revezadores": "revezador",
    "revezados": "revezar",
    "revezai": "revezar",
    "revezais": "revezar",
    "revezam": "revezar",
    "revezamentos": "revezamento",
    "revezamo": "revezar",
    "revezamos": "revezar",
    "revezando": "revezar",
    "revezara": "revezar",
    "revezaram": "revezar",
    "revezaras": "revezar",
    "revezarde": "revezar",
    "revezardes": "revezar",
    "revezare": "revezar",
    "revezarei": "revezar",
    "revezareis": "revezar",
    "revezarem": "revezar",
    "revezaremos": "revezar",
    "revezares": "revezar",
    "revezaria": "revezar",
    "revezariam": "revezar",
    "revezarias": "revezar",
    "revezarmo": "revezar",
    "revezarmos": "revezar",
    "revezará": "revezar",
    "revezarás": "revezar",
    "revezarão": "revezar",
    "revezaríamos": "revezar",
    "revezaríeis": "revezar",
    "revezas": "revezar",
    "revezasse": "revezar",
    "revezassem": "revezar",
    "revezasses": "revezar",
    "revezaste": "revezar",
    "revezastes": "revezar",
    "revezava": "revezar",
    "revezavam": "revezar",
    "revezavas": "revezar",
    "reveze": "revezar",
    "revezei": "revezar",
    "revezeis": "revezar",
    "revezem": "revezar",
    "revezemo": "revezar",
    "revezemos": "revezar",
    "revezes": "revezar",
    "revezo": "revezar",
    "revezos": "revezo",
    "revezou": "revezar",
    "revezá": "revezar",
    "revezámo": "revezar",
    "revezámos": "revezar",
    "revezáramo": "revezar",
    "revezáramos": "revezar",
    "revezárei": "revezar",
    "revezáreis": "revezar",
    "revezásseis": "revezar",
    "revezássemos": "revezar",
    "revezávamo": "revezar",
    "revezávamos": "revezar",
    "revezávei": "revezar",
    "revezáveis": "revezar",
    "revi": "rever",
    "revia": "rever",
    "reviam": "rever",
    "revias": "rever",
    "revibra": "revibrar",
    "revibrada": "revibrar",
    "revibradas": "revibrar",
    "revibrado": "revibrar",
    "revibrados": "revibrar",
    "revibrai": "revibrar",
    "revibrais": "revibrar",
    "revibram": "revibrar",
    "revibramo": "revibrar",
    "revibramos": "revibrar",
    "revibrando": "revibrar",
    "revibrara": "revibrar",
    "revibraram": "revibrar",
    "revibraras": "revibrar",
    "revibrarde": "revibrar",
    "revibrardes": "revibrar",
    "revibrare": "revibrar",
    "revibrarei": "revibrar",
    "revibrareis": "revibrar",
    "revibrarem": "revibrar",
    "revibraremos": "revibrar",
    "revibrares": "revibrar",
    "revibraria": "revibrar",
    "revibrariam": "revibrar",
    "revibrarias": "revibrar",
    "revibrarmo": "revibrar",
    "revibrarmos": "revibrar",
    "revibrará": "revibrar",
    "revibrarás": "revibrar",
    "revibrarão": "revibrar",
    "revibraríamos": "revibrar",
    "revibraríeis": "revibrar",
    "revibras": "revibrar",
    "revibrasse": "revibrar",
    "revibrassem": "revibrar",
    "revibrasses": "revibrar",
    "revibraste": "revibrar",
    "revibrastes": "revibrar",
    "revibrava": "revibrar",
    "revibravam": "revibrar",
    "revibravas": "revibrar",
    "revibrações": "revibração",
    "revibre": "revibrar",
    "revibrei": "revibrar",
    "revibreis": "revibrar",
    "revibrem": "revibrar",
    "revibremo": "revibrar",
    "revibremos": "revibrar",
    "revibres": "revibrar",
    "revibro": "revibrar",
    "revibrou": "revibrar",
    "revibrá": "revibrar",
    "revibrámo": "revibrar",
    "revibrámos": "revibrar",
    "revibráramo": "revibrar",
    "revibráramos": "revibrar",
    "revibrárei": "revibrar",
    "revibráreis": "revibrar",
    "revibrásseis": "revibrar",
    "revibrássemos": "revibrar",
    "revibrávamo": "revibrar",
    "revibrávamos": "revibrar",
    "revibrávei": "revibrar",
    "revibráveis": "revibrar",
    "revice": "reviçar",
    "revicei": "reviçar",
    "reviceis": "reviçar",
    "revicem": "reviçar",
    "revicemo": "reviçar",
    "revicemos": "reviçar",
    "revices": "reviçar",
    "revida": "revidar",
    "revidada": "revidar",
    "revidadas": "revidar",
    "revidado": "revidar",
    "revidados": "revidar",
    "revidai": "revidar",
    "revidais": "revidar",
    "revidam": "revidar",
    "revidamo": "revidar",
    "revidamos": "revidar",
    "revidando": "revidar",
    "revidara": "revidar",
    "revidaram": "revidar",
    "revidaras": "revidar",
    "revidarde": "revidar",
    "revidardes": "revidar",
    "revidare": "revidar",
    "revidarei": "revidar",
    "revidareis": "revidar",
    "revidarem": "revidar",
    "revidaremos": "revidar",
    "revidares": "revidar",
    "revidaria": "revidar",
    "revidariam": "revidar",
    "revidarias": "revidar",
    "revidarmo": "revidar",
    "revidarmos": "revidar",
    "revidará": "revidar",
    "revidarás": "revidar",
    "revidarão": "revidar",
    "revidaríamos": "revidar",
    "revidaríeis": "revidar",
    "revidas": "revidar",
    "revidasse": "revidar",
    "revidassem": "revidar",
    "revidasses": "revidar",
    "revidaste": "revidar",
    "revidastes": "revidar",
    "revidava": "revidar",
    "revidavam": "revidar",
    "revidavas": "revidar",
    "revidações": "revidação",
    "revide": "revidar",
    "revidei": "revidar",
    "revideis": "revidar",
    "revidem": "revidar",
    "revidemo": "revidar",
    "revidemos": "revidar",
    "revides": "revide",
    "revido": "revidar",
    "revidos": "revido",
    "revidou": "revidar",
    "revidá": "revidar",
    "revidámo": "revidar",
    "revidámos": "revidar",
    "revidáramo": "revidar",
    "revidáramos": "revidar",
    "revidárei": "revidar",
    "revidáreis": "revidar",
    "revidásseis": "revidar",
    "revidássemos": "revidar",
    "revidávamo": "revidar",
    "revidávamos": "revidar",
    "revidávei": "revidar",
    "revidáveis": "revidar",
    "reviemo": "revir",
    "reviemos": "revir",
    "revier": "revir",
    "reviera": "revir",
    "revieram": "revir",
    "revieras": "revir",
    "revierdes": "revir",
    "revierem": "revir",
    "revieres": "revir",
    "reviermos": "revir",
    "reviesse": "revir",
    "reviessem": "revir",
    "reviesses": "revir",
    "revieste": "revir",
    "reviestes": "revir",
    "revigiramentos": "revigiramento",
    "revigora": "revigorar",
    "revigorada": "revigorar",
    "revigoradas": "revigorar",
    "revigorado": "revigorar",
    "revigorados": "revigorar",
    "revigorai": "revigorar",
    "revigorais": "revigorar",
    "revigoram": "revigorar",
    "revigoramo": "revigorar",
    "revigoramos": "revigorar",
    "revigorando": "revigorar",
    "revigorantes": "revigorante",
    "revigorara": "revigorar",
    "revigoraram": "revigorar",
    "revigoraras": "revigorar",
    "revigorarde": "revigorar",
    "revigorardes": "revigorar",
    "revigorare": "revigorar",
    "revigorarei": "revigorar",
    "revigorareis": "revigorar",
    "revigorarem": "revigorar",
    "revigoraremos": "revigorar",
    "revigorares": "revigorar",
    "revigoraria": "revigorar",
    "revigorariam": "revigorar",
    "revigorarias": "revigorar",
    "revigorarmo": "revigorar",
    "revigorarmos": "revigorar",
    "revigorará": "revigorar",
    "revigorarás": "revigorar",
    "revigorarão": "revigorar",
    "revigoraríamos": "revigorar",
    "revigoraríeis": "revigorar",
    "revigoras": "revigorar",
    "revigorasse": "revigorar",
    "revigorassem": "revigorar",
    "revigorasses": "revigorar",
    "revigoraste": "revigorar",
    "revigorastes": "revigorar",
    "revigorava": "revigorar",
    "revigoravam": "revigorar",
    "revigoravas": "revigorar",
    "revigore": "revigorar",
    "revigorei": "revigorar",
    "revigoreis": "revigorar",
    "revigorem": "revigorar",
    "revigoremo": "revigorar",
    "revigoremos": "revigorar",
    "revigores": "revigorar",
    "revigoro": "revigorar",
    "revigorou": "revigorar",
    "revigorá": "revigorar",
    "revigorámo": "revigorar",
    "revigorámos": "revigorar",
    "revigoráramo": "revigorar",
    "revigoráramos": "revigorar",
    "revigorárei": "revigorar",
    "revigoráreis": "revigorar",
    "revigorásseis": "revigorar",
    "revigorássemos": "revigorar",
    "revigorávamo": "revigorar",
    "revigorávamos": "revigorar",
    "revigorávei": "revigorar",
    "revigoráveis": "revigorar",
    "revila": "revelir",
    "revilais": "revelir",
    "revilam": "revelir",
    "revilamo": "revelir",
    "revilamos": "revelir",
    "revilas": "revelir",
    "revilo": "revelir",
    "revim": "revir",
    "revimentos": "revimento",
    "revimo": "revir",
    "revimos": "revir",
    "revina": "revenir",
    "revinais": "revenir",
    "revinam": "revenir",
    "revinamo": "revenir",
    "revinamos": "revenir",
    "revinas": "revenir",
    "revinda": "revir",
    "revindas": "revir",
    "revinde": "revir",
    "revindes": "revir",
    "revindicações": "revindicação",
    "revindictas": "revindicta",
    "revindo": "revir",
    "revindos": "revir",
    "revine": "revenir",
    "revinem": "revenir",
    "revines": "revenir",
    "revinga": "revingar",
    "revingada": "revingar",
    "revingadas": "revingar",
    "revingado": "revingar",
    "revingados": "revingar",
    "revingai": "revingar",
    "revingais": "revingar",
    "revingam": "revingar",
    "revingamo": "revingar",
    "revingamos": "revingar",
    "revingando": "revingar",
    "revingara": "revingar",
    "revingaram": "revingar",
    "revingaras": "revingar",
    "revingarde": "revingar",
    "revingardes": "revingar",
    "revingare": "revingar",
    "revingarei": "revingar",
    "revingareis": "revingar",
    "revingarem": "revingar",
    "revingaremos": "revingar",
    "revingares": "revingar",
    "revingaria": "revingar",
    "revingariam": "revingar",
    "revingarias": "revingar",
    "revingarmo": "revingar",
    "revingarmos": "revingar",
    "revingará": "revingar",
    "revingarás": "revingar",
    "revingarão": "revingar",
    "revingaríamos": "revingar",
    "revingaríeis": "revingar",
    "revingas": "revingar",
    "revingasse": "revingar",
    "revingassem": "revingar",
    "revingasses": "revingar",
    "revingaste": "revingar",
    "revingastes": "revingar",
    "revingava": "revingar",
    "revingavam": "revingar",
    "revingavas": "revingar",
    "revingo": "revingar",
    "revingou": "revingar",
    "revingue": "revingar",
    "revinguei": "revingar",
    "revingueis": "revingar",
    "revinguem": "revingar",
    "revinguemo": "revingar",
    "revinguemos": "revingar",
    "revingues": "revingar",
    "revingá": "revingar",
    "revingámo": "revingar",
    "revingámos": "revingar",
    "revingáramo": "revingar",
    "revingáramos": "revingar",
    "revingárei": "revingar",
    "revingáreis": "revingar",
    "revingásseis": "revingar",
    "revingássemos": "revingar",
    "revingávamo": "revingar",
    "revingávamos": "revingar",
    "revingávei": "revingar",
    "revingáveis": "revingar",
    "revinha": "revir",
    "revinham": "revir",
    "revinhas": "revir",
    "revino": "revenir",
    "revir": "rever",
    "revira": "revirar",
    "revirada": "revirar",
    "reviradas": "revirar",
    "revirado": "revirar",
    "revirados": "revirar",
    "revirai": "revirar",
    "revirais": "revirar",
    "reviralhistas": "reviralhista",
    "reviralhos": "reviralho",
    "reviram": "revirar",
    "reviramentos": "reviramento",
    "reviramo": "revirar",
    "reviramos": "revirar",
    "revirando": "revirar",
    "revirara": "revirar",
    "reviraram": "revirar",
    "reviraras": "revirar",
    "revirarde": "revirar",
    "revirardes": "revirar",
    "revirare": "revirar",
    "revirarei": "revirar",
    "revirareis": "revirar",
    "revirarem": "revirar",
    "reviraremos": "revirar",
    "revirares": "revirar",
    "reviraria": "revirar",
    "revirariam": "revirar",
    "revirarias": "revirar",
    "revirarmo": "revirar",
    "revirarmos": "revirar",
    "revirará": "revirar",
    "revirarás": "revirar",
    "revirarão": "revirar",
    "reviraríamos": "revirar",
    "reviraríeis": "revirar",
    "reviras": "revirar",
    "revirasse": "revirar",
    "revirassem": "revirar",
    "revirasses": "revirar",
    "reviraste": "revirar",
    "revirastes": "revirar",
    "revirava": "revirar",
    "reviravam": "revirar",
    "reviravas": "revirar",
    "reviravoltas": "reviravolta",
    "revirdes": "revir",
    "revire": "revirar",
    "revirei": "revirar",
    "revireis": "revirar",
    "revirem": "revirar",
    "reviremo": "revirar",
    "reviremos": "revirar",
    "revires": "revirar",
    "reviretes": "revirete",
    "revirgina": "revirginar",
    "revirginada": "revirginar",
    "revirginadas": "revirginar",
    "revirginado": "revirginar",
    "revirginados": "revirginar",
    "revirginai": "revirginar",
    "revirginais": "revirginar",
    "revirginam": "revirginar",
    "revirginamo": "revirginar",
    "revirginamos": "revirginar",
    "revirginando": "revirginar",
    "revirginara": "revirginar",
    "revirginaram": "revirginar",
    "revirginaras": "revirginar",
    "revirginarde": "revirginar",
    "revirginardes": "revirginar",
    "revirginare": "revirginar",
    "revirginarei": "revirginar",
    "revirginareis": "revirginar",
    "revirginarem": "revirginar",
    "revirginaremos": "revirginar",
    "revirginares": "revirginar",
    "revirginaria": "revirginar",
    "revirginariam": "revirginar",
    "revirginarias": "revirginar",
    "revirginarmo": "revirginar",
    "revirginarmos": "revirginar",
    "revirginará": "revirginar",
    "revirginarás": "revirginar",
    "revirginarão": "revirginar",
    "revirginaríamos": "revirginar",
    "revirginaríeis": "revirginar",
    "revirginas": "revirginar",
    "revirginasse": "revirginar",
    "revirginassem": "revirginar",
    "revirginasses": "revirginar",
    "revirginaste": "revirginar",
    "revirginastes": "revirginar",
    "revirginava": "revirginar",
    "revirginavam": "revirginar",
    "revirginavas": "revirginar",
    "revirgine": "revirginar",
    "revirginei": "revirginar",
    "revirgineis": "revirginar",
    "revirginem": "revirginar",
    "revirginemo": "revirginar",
    "revirginemos": "revirginar",
    "revirgines": "revirginar",
    "revirgino": "revirginar",
    "revirginou": "revirginar",
    "revirginá": "revirginar",
    "revirginámo": "revirginar",
    "revirginámos": "revirginar",
    "revirgináramo": "revirginar",
    "revirgináramos": "revirginar",
    "revirginárei": "revirginar",
    "revirgináreis": "revirginar",
    "revirginásseis": "revirginar",
    "revirginássemos": "revirginar",
    "revirginávamo": "revirginar",
    "revirginávamos": "revirginar",
    "revirginávei": "revirginar",
    "revirgináveis": "revirginar",
    "reviria": "revir",
    "reviriam": "revir",
    "revirias": "revir",
    "revirmo": "revir",
    "revirmos": "revir",
    "reviro": "revirar",
    "revirou": "revirar",
    "revirá": "revirar",
    "revirámo": "revirar",
    "revirámos": "revirar",
    "reviráramo": "revirar",
    "reviráramos": "revirar",
    "revirárei": "revirar",
    "reviráreis": "revirar",
    "revirás": "revir",
    "revirásseis": "revirar",
    "revirássemos": "revirar",
    "revirávamo": "revirar",
    "revirávamos": "revirar",
    "revirávei": "revirar",
    "reviráveis": "revirar",
    "revirão": "revir",
    "reviríamos": "revir",
    "reviríeis": "revir",
    "revirões": "revirão",
    "revisa": "revisar",
    "revisada": "revisar",
    "revisadas": "revisar",
    "revisado": "revisar",
    "revisados": "revisar",
    "revisai": "revisar",
    "revisais": "revisar",
    "revisam": "revisar",
    "revisamo": "revisar",
    "revisamos": "revisar",
    "revisando": "revisar",
    "revisara": "revisar",
    "revisaram": "revisar",
    "revisaras": "revisar",
    "revisarde": "revisar",
    "revisardes": "revisar",
    "revisare": "revisar",
    "revisarei": "revisar",
    "revisareis": "revisar",
    "revisarem": "revisar",
    "revisaremos": "revisar",
    "revisares": "revisar",
    "revisaria": "revisar",
    "revisariam": "revisar",
    "revisarias": "revisar",
    "revisarmo": "revisar",
    "revisarmos": "revisar",
    "revisará": "revisar",
    "revisarás": "revisar",
    "revisarão": "revisar",
    "revisaríamos": "revisar",
    "revisaríeis": "revisar",
    "revisas": "revisar",
    "revisasse": "revisar",
    "revisassem": "revisar",
    "revisasses": "revisar",
    "revisaste": "revisar",
    "revisastes": "revisar",
    "revisava": "revisar",
    "revisavam": "revisar",
    "revisavas": "revisar",
    "revise": "revisar",
    "revisei": "revisar",
    "reviseis": "revisar",
    "revisem": "revisar",
    "revisemo": "revisar",
    "revisemos": "revisar",
    "revises": "revisar",
    "revisibilidades": "revisibilidade",
    "revisionismos": "revisionismo",
    "revisionistas": "revisionista",
    "revisionistazinha": "revisionista",
    "revisionistazinhas": "revisionista",
    "revisionistazinho": "revisionista",
    "revisionistazinhos": "revisionista",
    "revisionistazita": "revisionista",
    "revisionistazitas": "revisionista",
    "revisionistazito": "revisionista",
    "revisionistazitos": "revisionista",
    "revisita": "revisitar",
    "revisitada": "revisitar",
    "revisitadas": "revisitar",
    "revisitado": "revisitar",
    "revisitados": "revisitar",
    "revisitai": "revisitar",
    "revisitais": "revisitar",
    "revisitam": "revisitar",
    "revisitamo": "revisitar",
    "revisitamos": "revisitar",
    "revisitando": "revisitar",
    "revisitara": "revisitar",
    "revisitaram": "revisitar",
    "revisitaras": "revisitar",
    "revisitarde": "revisitar",
    "revisitardes": "revisitar",
    "revisitare": "revisitar",
    "revisitarei": "revisitar",
    "revisitareis": "revisitar",
    "revisitarem": "revisitar",
    "revisitaremos": "revisitar",
    "revisitares": "revisitar",
    "revisitaria": "revisitar",
    "revisitariam": "revisitar",
    "revisitarias": "revisitar",
    "revisitarmo": "revisitar",
    "revisitarmos": "revisitar",
    "revisitará": "revisitar",
    "revisitarás": "revisitar",
    "revisitarão": "revisitar",
    "revisitaríamos": "revisitar",
    "revisitaríeis": "revisitar",
    "revisitas": "revisitar",
    "revisitasse": "revisitar",
    "revisitassem": "revisitar",
    "revisitasses": "revisitar",
    "revisitaste": "revisitar",
    "revisitastes": "revisitar",
    "revisitava": "revisitar",
    "revisitavam": "revisitar",
    "revisitavas": "revisitar",
    "revisitações": "revisitação",
    "revisite": "revisitar",
    "revisitei": "revisitar",
    "revisiteis": "revisitar",
    "revisitem": "revisitar",
    "revisitemo": "revisitar",
    "revisitemos": "revisitar",
    "revisites": "revisitar",
    "revisito": "revisitar",
    "revisitou": "revisitar",
    "revisitá": "revisitar",
    "revisitámo": "revisitar",
    "revisitámos": "revisitar",
    "revisitáramo": "revisitar",
    "revisitáramos": "revisitar",
    "revisitárei": "revisitar",
    "revisitáreis": "revisitar",
    "revisitásseis": "revisitar",
    "revisitássemos": "revisitar",
    "revisitávamo": "revisitar",
    "revisitávamos": "revisitar",
    "revisitávei": "revisitar",
    "revisitáveis": "revisitar",
    "reviso": "revisar",
    "revisora": "revisor",
    "revisoras": "revisor",
    "revisorazinha": "revisor",
    "revisorazinhas": "revisor",
    "revisorazita": "revisor",
    "revisorazitas": "revisor",
    "revisores": "revisor",
    "revisorzinho": "revisor",
    "revisorzinhos": "revisor",
    "revisorzito": "revisor",
    "revisorzitos": "revisor",
    "revisou": "revisar",
    "revisse": "rever",
    "revissem": "rever",
    "revisses": "rever",
    "revista": "revisto",
    "revistada": "revistar",
    "revistadas": "revistar",
    "revistado": "revistar",
    "revistadora": "revistador",
    "revistadoras": "revistador",
    "revistadores": "revistador",
    "revistados": "revistar",
    "revistai": "revistar",
    "revistais": "revistar",
    "revistam": "revistar",
    "revistamo": "revistar",
    "revistamos": "revistar",
    "revistando": "revistar",
    "revistara": "revistar",
    "revistaram": "revistar",
    "revistaras": "revistar",
    "revistarde": "revistar",
    "revistardes": "revistar",
    "revistare": "revistar",
    "revistarei": "revistar",
    "revistareis": "revistar",
    "revistarem": "revistar",
    "revistaremos": "revistar",
    "revistares": "revistar",
    "revistaria": "revistar",
    "revistariam": "revistar",
    "revistarias": "revistar",
    "revistarmo": "revistar",
    "revistarmos": "revistar",
    "revistará": "revistar",
    "revistarás": "revistar",
    "revistarão": "revistar",
    "revistaríamos": "revistar",
    "revistaríeis": "revistar",
    "revistas": "revisto",
    "revistasse": "revistar",
    "revistassem": "revistar",
    "revistasses": "revistar",
    "revistaste": "revistar",
    "revistastes": "revistar",
    "revistava": "revistar",
    "revistavam": "revistar",
    "revistavas": "revistar",
    "reviste": "revistar",
    "revistecas": "revisteca",
    "revistei": "revistar",
    "revisteira": "revisteiro",
    "revisteiras": "revisteiro",
    "revisteiros": "revisteiro",
    "revisteis": "revistar",
    "revistem": "revistar",
    "revistemo": "revistar",
    "revistemos": "revistar",
    "revistes": "revistar",
    "revisto": "revistar",
    "revistos": "revisto",
    "revistou": "revistar",
    "revistá": "revistar",
    "revistámo": "revistar",
    "revistámos": "revistar",
    "revistáramo": "revistar",
    "revistáramos": "revistar",
    "revistárei": "revistar",
    "revistáreis": "revistar",
    "revistásseis": "revistar",
    "revistássemos": "revistar",
    "revistávamo": "revistar",
    "revistávamos": "revistar",
    "revistávei": "revistar",
    "revistáveis": "revistar",
    "revisá": "revisar",
    "revisámo": "revisar",
    "revisámos": "revisar",
    "revisáramo": "revisar",
    "revisáramos": "revisar",
    "revisárei": "revisar",
    "revisáreis": "revisar",
    "revisásseis": "revisar",
    "revisássemos": "revisar",
    "revisávamo": "revisar",
    "revisávamos": "revisar",
    "revisávei": "revisar",
    "revisáveis": "revisar",
    "revisória": "revisório",
    "revisórias": "revisório",
    "revisórios": "revisório",
    "revisões": "revisão",
    "revitaliza": "revitalizar",
    "revitalizada": "revitalizar",
    "revitalizadas": "revitalizar",
    "revitalizado": "revitalizar",
    "revitalizados": "revitalizar",
    "revitalizai": "revitalizar",
    "revitalizais": "revitalizar",
    "revitalizam": "revitalizar",
    "revitalizamo": "revitalizar",
    "revitalizamos": "revitalizar",
    "revitalizando": "revitalizar",
    "revitalizara": "revitalizar",
    "revitalizaram": "revitalizar",
    "revitalizaras": "revitalizar",
    "revitalizarde": "revitalizar",
    "revitalizardes": "revitalizar",
    "revitalizare": "revitalizar",
    "revitalizarei": "revitalizar",
    "revitalizareis": "revitalizar",
    "revitalizarem": "revitalizar",
    "revitalizaremos": "revitalizar",
    "revitalizares": "revitalizar",
    "revitalizaria": "revitalizar",
    "revitalizariam": "revitalizar",
    "revitalizarias": "revitalizar",
    "revitalizarmo": "revitalizar",
    "revitalizarmos": "revitalizar",
    "revitalizará": "revitalizar",
    "revitalizarás": "revitalizar",
    "revitalizarão": "revitalizar",
    "revitalizaríamos": "revitalizar",
    "revitalizaríeis": "revitalizar",
    "revitalizas": "revitalizar",
    "revitalizasse": "revitalizar",
    "revitalizassem": "revitalizar",
    "revitalizasses": "revitalizar",
    "revitalizaste": "revitalizar",
    "revitalizastes": "revitalizar",
    "revitalizava": "revitalizar",
    "revitalizavam": "revitalizar",
    "revitalizavas": "revitalizar",
    "revitalizações": "revitalização",
    "revitalize": "revitalizar",
    "revitalizei": "revitalizar",
    "revitalizeis": "revitalizar",
    "revitalizem": "revitalizar",
    "revitalizemo": "revitalizar",
    "revitalizemos": "revitalizar",
    "revitalizes": "revitalizar",
    "revitalizo": "revitalizar",
    "revitalizou": "revitalizar",
    "revitalizá": "revitalizar",
    "revitalizámo": "revitalizar",
    "revitalizámos": "revitalizar",
    "revitalizáramo": "revitalizar",
    "revitalizáramos": "revitalizar",
    "revitalizárei": "revitalizar",
    "revitalizáreis": "revitalizar",
    "revitalizásseis": "revitalizar",
    "revitalizássemos": "revitalizar",
    "revitalizávamo": "revitalizar",
    "revitalizávamos": "revitalizar",
    "revitalizávei": "revitalizar",
    "revitalizáveis": "revitalizar",
    "reviu": "rever",
    "reviva": "revivo",
    "revivais": "reviver",
    "revivalismos": "revivalismo",
    "revivalistas": "revivalista",
    "revivam": "reviver",
    "revivamo": "reviver",
    "revivamos": "reviver",
    "revivas": "revivo",
    "revive": "reviver",
    "revivei": "reviver",
    "reviveis": "reviver",
    "revivem": "reviver",
    "revivemo": "reviver",
    "revivemos": "reviver",
    "revivendo": "reviver",
    "reviventes": "revivente",
    "revivera": "reviver",
    "reviveram": "reviver",
    "reviveras": "reviver",
    "reviverdes": "reviver",
    "reviverei": "reviver",
    "revivereis": "reviver",
    "reviverem": "reviver",
    "reviveremos": "reviver",
    "reviveres": "reviver",
    "reviveria": "reviver",
    "reviveriam": "reviver",
    "reviverias": "reviver",
    "revivermo": "reviver",
    "revivermos": "reviver",
    "reviverá": "reviver",
    "reviverás": "reviver",
    "reviverão": "reviver",
    "reviveríamos": "reviver",
    "reviveríeis": "reviver",
    "revives": "reviver",
    "revivesce": "revivescer",
    "revivescei": "revivescer",
    "revivesceis": "revivescer",
    "revivescem": "revivescer",
    "revivescemo": "revivescer",
    "revivescemos": "revivescer",
    "revivescendo": "revivescer",
    "revivescentes": "revivescente",
    "revivescera": "revivescer",
    "revivesceram": "revivescer",
    "revivesceras": "revivescer",
    "revivescerdes": "revivescer",
    "revivescerei": "revivescer",
    "revivescereis": "revivescer",
    "revivescerem": "revivescer",
    "revivesceremos": "revivescer",
    "revivesceres": "revivescer",
    "revivesceria": "revivescer",
    "revivesceriam": "revivescer",
    "revivescerias": "revivescer",
    "revivescermo": "revivescer",
    "revivescermos": "revivescer",
    "revivescerá": "revivescer",
    "revivescerás": "revivescer",
    "revivescerão": "revivescer",
    "revivesceríamos": "revivescer",
    "revivesceríeis": "revivescer",
    "revivesces": "revivescer",
    "revivescesse": "revivescer",
    "revivescessem": "revivescer",
    "revivescesses": "revivescer",
    "revivesceste": "revivescer",
    "revivescestes": "revivescer",
    "revivesceu": "revivescer",
    "revivesci": "revivescer",
    "revivescia": "revivescer",
    "revivesciam": "revivescer",
    "revivescias": "revivescer",
    "revivescida": "revivescer",
    "revivescidas": "revivescer",
    "revivescido": "revivescer",
    "revivescidos": "revivescer",
    "revivescências": "revivescência",
    "revivescêramo": "revivescer",
    "revivescêramos": "revivescer",
    "revivescêreis": "revivescer",
    "revivescêsseis": "revivescer",
    "revivescêssemos": "revivescer",
    "revivescíamo": "revivescer",
    "revivescíamos": "revivescer",
    "revivescíeis": "revivescer",
    "revivescíveis": "revivescível",
    "revivesse": "reviver",
    "revivessem": "reviver",
    "revivesses": "reviver",
    "reviveste": "reviver",
    "revivestes": "reviver",
    "revivesça": "revivescer",
    "revivesçais": "revivescer",
    "revivesçam": "revivescer",
    "revivesçamo": "revivescer",
    "revivesçamos": "revivescer",
    "revivesças": "revivescer",
    "revivesço": "revivescer",
    "reviveu": "reviver",
    "revivi": "reviver",
    "revivia": "reviver",
    "reviviam": "reviver",
    "revivias": "reviver",
    "revivida": "revivido",
    "revividas": "revivido",
    "revivido": "reviver",
    "revividos": "revivido",
    "revivifica": "revivificar",
    "revivificada": "revivificar",
    "revivificadas": "revivificar",
    "revivificado": "revivificar",
    "revivificadora": "revivificador",
    "revivificadoras": "revivificador",
    "revivificadores": "revivificador",
    "revivificados": "revivificar",
    "revivificai": "revivificar",
    "revivificais": "revivificar",
    "revivificam": "revivificar",
    "revivificamentos": "revivificamento",
    "revivificamo": "revivificar",
    "revivificamos": "revivificar",
    "revivificando": "revivificar",
    "revivificara": "revivificar",
    "revivificaram": "revivificar",
    "revivificaras": "revivificar",
    "revivificarde": "revivificar",
    "revivificardes": "revivificar",
    "revivificare": "revivificar",
    "revivificarei": "revivificar",
    "revivificareis": "revivificar",
    "revivificarem": "revivificar",
    "revivificaremos": "revivificar",
    "revivificares": "revivificar",
    "revivificaria": "revivificar",
    "revivificariam": "revivificar",
    "revivificarias": "revivificar",
    "revivificarmo": "revivificar",
    "revivificarmos": "revivificar",
    "revivificará": "revivificar",
    "revivificarás": "revivificar",
    "revivificarão": "revivificar",
    "revivificaríamos": "revivificar",
    "revivificaríeis": "revivificar",
    "revivificas": "revivificar",
    "revivificasse": "revivificar",
    "revivificassem": "revivificar",
    "revivificasses": "revivificar",
    "revivificaste": "revivificar",
    "revivificastes": "revivificar",
    "revivificava": "revivificar",
    "revivificavam": "revivificar",
    "revivificavas": "revivificar",
    "revivificações": "revivificação",
    "revivifico": "revivificar",
    "revivificou": "revivificar",
    "revivificá": "revivificar",
    "revivificámo": "revivificar",
    "revivificámos": "revivificar",
    "revivificáramo": "revivificar",
    "revivificáramos": "revivificar",
    "revivificárei": "revivificar",
    "revivificáreis": "revivificar",
    "revivificásseis": "revivificar",
    "revivificássemos": "revivificar",
    "revivificávamo": "revivificar",
    "revivificávamos": "revivificar",
    "revivificávei": "revivificar",
    "revivificáveis": "revivificar",
    "revivifique": "revivificar",
    "revivifiquei": "revivificar",
    "revivifiqueis": "revivificar",
    "revivifiquem": "revivificar",
    "revivifiquemo": "revivificar",
    "revivifiquemos": "revivificar",
    "revivifiques": "revivificar",
    "revivo": "reviver",
    "revivos": "revivo",
    "revivências": "revivência",
    "revivêramo": "reviver",
    "revivêramos": "reviver",
    "revivêreis": "reviver",
    "revivêsseis": "reviver",
    "revivêssemos": "reviver",
    "revivíamo": "reviver",
    "revivíamos": "reviver",
    "revivíeis": "reviver",
    "reviça": "reviçar",
    "reviçada": "reviçar",
    "reviçadas": "reviçar",
    "reviçado": "reviçar",
    "reviçados": "reviçar",
    "reviçai": "reviçar",
    "reviçais": "reviçar",
    "reviçam": "reviçar",
    "reviçamo": "reviçar",
    "reviçamos": "reviçar",
    "reviçando": "reviçar",
    "reviçara": "reviçar",
    "reviçaram": "reviçar",
    "reviçaras": "reviçar",
    "reviçardes": "reviçar",
    "reviçarei": "reviçar",
    "reviçareis": "reviçar",
    "reviçarem": "reviçar",
    "reviçaremos": "reviçar",
    "reviçares": "reviçar",
    "reviçaria": "reviçar",
    "reviçariam": "reviçar",
    "reviçarias": "reviçar",
    "reviçarmo": "reviçar",
    "reviçarmos": "reviçar",
    "reviçará": "reviçar",
    "reviçarás": "reviçar",
    "reviçarão": "reviçar",
    "reviçaríamos": "reviçar",
    "reviçaríeis": "reviçar",
    "reviças": "reviçar",
    "reviçasse": "reviçar",
    "reviçassem": "reviçar",
    "reviçasses": "reviçar",
    "reviçaste": "reviçar",
    "reviçastes": "reviçar",
    "reviçava": "reviçar",
    "reviçavam": "reviçar",
    "reviçavas": "reviçar",
    "reviço": "reviçar",
    "reviços": "reviço",
    "reviçou": "reviçar",
    "reviçámo": "reviçar",
    "reviçámos": "reviçar",
    "reviçáramo": "reviçar",
    "reviçáramos": "reviçar",
    "reviçáreis": "reviçar",
    "reviçásseis": "reviçar",
    "reviçássemos": "reviçar",
    "reviçávamo": "reviçar",
    "reviçávamos": "reviçar",
    "reviçáveis": "reviçar",
    "reviéramo": "revir",
    "reviéramos": "revir",
    "reviéreis": "revir",
    "reviésseis": "revir",
    "reviéssemos": "revir",
    "revoa": "revoar",
    "revoada": "revoar",
    "revoadas": "revoar",
    "revoado": "revoar",
    "revoados": "revoar",
    "revoai": "revoar",
    "revoais": "revoar",
    "revoam": "revoar",
    "revoamo": "revoar",
    "revoamos": "revoar",
    "revoando": "revoar",
    "revoara": "revoar",
    "revoaram": "revoar",
    "revoaras": "revoar",
    "revoardes": "revoar",
    "revoarei": "revoar",
    "revoareis": "revoar",
    "revoarem": "revoar",
    "revoaremos": "revoar",
    "revoares": "revoar",
    "revoaria": "revoar",
    "revoariam": "revoar",
    "revoarias": "revoar",
    "revoarmo": "revoar",
    "revoarmos": "revoar",
    "revoará": "revoar",
    "revoarás": "revoar",
    "revoarão": "revoar",
    "revoaríamos": "revoar",
    "revoaríeis": "revoar",
    "revoas": "revoar",
    "revoasse": "revoar",
    "revoassem": "revoar",
    "revoasses": "revoar",
    "revoaste": "revoar",
    "revoastes": "revoar",
    "revoava": "revoar",
    "revoavam": "revoar",
    "revoavas": "revoar",
    "revoca": "revocar",
    "revocada": "revocar",
    "revocadas": "revocar",
    "revocado": "revocar",
    "revocados": "revocar",
    "revocai": "revocar",
    "revocais": "revocar",
    "revocam": "revocar",
    "revocamo": "revocar",
    "revocamos": "revocar",
    "revocando": "revocar",
    "revocara": "revocar",
    "revocaram": "revocar",
    "revocaras": "revocar",
    "revocarde": "revocar",
    "revocardes": "revocar",
    "revocare": "revocar",
    "revocarei": "revocar",
    "revocareis": "revocar",
    "revocarem": "revocar",
    "revocaremos": "revocar",
    "revocares": "revocar",
    "revocaria": "revocar",
    "revocariam": "revocar",
    "revocarias": "revocar",
    "revocarmo": "revocar",
    "revocarmos": "revocar",
    "revocará": "revocar",
    "revocarás": "revocar",
    "revocarão": "revocar",
    "revocaríamos": "revocar",
    "revocaríeis": "revocar",
    "revocas": "revocar",
    "revocasse": "revocar",
    "revocassem": "revocar",
    "revocasses": "revocar",
    "revocaste": "revocar",
    "revocastes": "revocar",
    "revocatória": "revocatório",
    "revocatórias": "revocatório",
    "revocatórios": "revocatório",
    "revocava": "revocar",
    "revocavam": "revocar",
    "revocavas": "revocar",
    "revocações": "revocação",
    "revoco": "revocar",
    "revocou": "revocar",
    "revocá": "revocar",
    "revocámo": "revocar",
    "revocámos": "revocar",
    "revocáramo": "revocar",
    "revocáramos": "revocar",
    "revocárei": "revocar",
    "revocáreis": "revocar",
    "revocásseis": "revocar",
    "revocássemos": "revocar",
    "revocávamo": "revocar",
    "revocávamos": "revocar",
    "revocávei": "revocar",
    "revocáveis": "revocável",
    "revoe": "revoar",
    "revoei": "revoar",
    "revoeis": "revoar",
    "revoejos": "revoejo",
    "revoem": "revoar",
    "revoemo": "revoar",
    "revoemos": "revoar",
    "revoes": "revoar",
    "revoga": "revogar",
    "revogabilidades": "revogabilidade",
    "revogada": "revogar",
    "revogadas": "revogar",
    "revogado": "revogar",
    "revogadora": "revogador",
    "revogadoras": "revogador",
    "revogadorazinha": "revogador",
    "revogadorazinhas": "revogador",
    "revogadorazita": "revogador",
    "revogadorazitas": "revogador",
    "revogadores": "revogador",
    "revogadorzinho": "revogador",
    "revogadorzinhos": "revogador",
    "revogadorzito": "revogador",
    "revogadorzitos": "revogador",
    "revogados": "revogar",
    "revogai": "revogar",
    "revogais": "revogar",
    "revogam": "revogar",
    "revogamo": "revogar",
    "revogamos": "revogar",
    "revogando": "revogar",
    "revogantes": "revogante",
    "revogara": "revogar",
    "revogaram": "revogar",
    "revogaras": "revogar",
    "revogarde": "revogar",
    "revogardes": "revogar",
    "revogare": "revogar",
    "revogarei": "revogar",
    "revogareis": "revogar",
    "revogarem": "revogar",
    "revogaremos": "revogar",
    "revogares": "revogar",
    "revogaria": "revogar",
    "revogariam": "revogar",
    "revogarias": "revogar",
    "revogarmo": "revogar",
    "revogarmos": "revogar",
    "revogará": "revogar",
    "revogarás": "revogar",
    "revogarão": "revogar",
    "revogaríamos": "revogar",
    "revogaríeis": "revogar",
    "revogas": "revogar",
    "revogasse": "revogar",
    "revogassem": "revogar",
    "revogasses": "revogar",
    "revogaste": "revogar",
    "revogastes": "revogar",
    "revogatória": "revogatório",
    "revogatórias": "revogatório",
    "revogatórios": "revogatório",
    "revogava": "revogar",
    "revogavam": "revogar",
    "revogavas": "revogar",
    "revogações": "revogação",
    "revogo": "revogar",
    "revogou": "revogar",
    "revogue": "revogar",
    "revoguei": "revogar",
    "revogueis": "revogar",
    "revoguem": "revogar",
    "revoguemo": "revogar",
    "revoguemos": "revogar",
    "revogues": "revogar",
    "revogá": "revogar",
    "revogámo": "revogar",
    "revogámos": "revogar",
    "revogáramo": "revogar",
    "revogáramos": "revogar",
    "revogárei": "revogar",
    "revogáreis": "revogar",
    "revogásseis": "revogar",
    "revogássemos": "revogar",
    "revogávamo": "revogar",
    "revogávamos": "revogar",
    "revogávei": "revogar",
    "revogáveis": "revogável",
    "revolta": "revolto",
    "revoltada": "revoltar",
    "revoltadas": "revoltar",
    "revoltadazinha": "revoltado",
    "revoltadazinhas": "revoltado",
    "revoltadazita": "revoltado",
    "revoltadazitas": "revoltado",
    "revoltado": "revoltar",
    "revoltadora": "revoltador",
    "revoltadoras": "revoltador",
    "revoltadores": "revoltador",
    "revoltados": "revoltar",
    "revoltadozinho": "revoltado",
    "revoltadozinhos": "revoltado",
    "revoltadozito": "revoltado",
    "revoltadozitos": "revoltado",
    "revoltadíssima": "revoltado",
    "revoltadíssimas": "revoltado",
    "revoltadíssimo": "revoltado",
    "revoltadíssimos": "revoltado",
    "revoltai": "revoltar",
    "revoltais": "revoltar",
    "revoltam": "revoltar",
    "revoltamo": "revoltar",
    "revoltamos": "revoltar",
    "revoltando": "revoltar",
    "revoltantes": "revoltante",
    "revoltara": "revoltar",
    "revoltaram": "revoltar",
    "revoltaras": "revoltar",
    "revoltarde": "revoltar",
    "revoltardes": "revoltar",
    "revoltare": "revoltar",
    "revoltarei": "revoltar",
    "revoltareis": "revoltar",
    "revoltarem": "revoltar",
    "revoltaremos": "revoltar",
    "revoltares": "revoltar",
    "revoltaria": "revoltar",
    "revoltariam": "revoltar",
    "revoltarias": "revoltar",
    "revoltarmo": "revoltar",
    "revoltarmos": "revoltar",
    "revoltará": "revoltar",
    "revoltarás": "revoltar",
    "revoltarão": "revoltar",
    "revoltaríamos": "revoltar",
    "revoltaríeis": "revoltar",
    "revoltas": "revolto",
    "revoltasse": "revoltar",
    "revoltassem": "revoltar",
    "revoltasses": "revoltar",
    "revoltaste": "revoltar",
    "revoltastes": "revoltar",
    "revoltava": "revoltar",
    "revoltavam": "revoltar",
    "revoltavas": "revoltar",
    "revolte": "revoltar",
    "revolteada": "revoltear",
    "revolteadas": "revoltear",
    "revolteado": "revoltear",
    "revolteados": "revoltear",
    "revolteai": "revoltear",
    "revolteais": "revoltear",
    "revolteamo": "revoltear",
    "revolteamos": "revoltear",
    "revolteando": "revoltear",
    "revolteara": "revoltear",
    "revoltearam": "revoltear",
    "revoltearas": "revoltear",
    "revoltearde": "revoltear",
    "revolteardes": "revoltear",
    "revolteare": "revoltear",
    "revoltearei": "revoltear",
    "revolteareis": "revoltear",
    "revoltearem": "revoltear",
    "revoltearemos": "revoltear",
    "revolteares": "revoltear",
    "revoltearia": "revoltear",
    "revolteariam": "revoltear",
    "revoltearias": "revoltear",
    "revoltearmo": "revoltear",
    "revoltearmos": "revoltear",
    "revolteará": "revoltear",
    "revoltearás": "revoltear",
    "revoltearão": "revoltear",
    "revoltearíamos": "revoltear",
    "revoltearíeis": "revoltear",
    "revolteasse": "revoltear",
    "revolteassem": "revoltear",
    "revolteasses": "revoltear",
    "revolteaste": "revoltear",
    "revolteastes": "revoltear",
    "revolteava": "revoltear",
    "revolteavam": "revoltear",
    "revolteavas": "revoltear",
    "revolteei": "revoltear",
    "revolteeis": "revoltear",
    "revolteemo": "revoltear",
    "revolteemos": "revoltear",
    "revoltei": "revoltar",
    "revolteia": "revoltear",
    "revolteiam": "revoltear",
    "revolteias": "revoltear",
    "revolteie": "revoltear",
    "revolteiem": "revoltear",
    "revolteies": "revoltear",
    "revolteio": "revoltear",
    "revolteios": "revolteio",
    "revolteis": "revoltar",
    "revoltem": "revoltar",
    "revoltemo": "revoltar",
    "revoltemos": "revoltar",
    "revolteou": "revoltear",
    "revoltes": "revoltar",
    "revolteá": "revoltear",
    "revolteámo": "revoltear",
    "revolteámos": "revoltear",
    "revolteáramo": "revoltear",
    "revolteáramos": "revoltear",
    "revolteárei": "revoltear",
    "revolteáreis": "revoltear",
    "revolteásseis": "revoltear",
    "revolteássemos": "revoltear",
    "revolteávamo": "revoltear",
    "revolteávamos": "revoltear",
    "revolteávei": "revoltear",
    "revolteáveis": "revoltear",
    "revolto": "revoltar",
    "revoltos": "revolto",
    "revoltosa": "revoltoso",
    "revoltosas": "revoltoso",
    "revoltosos": "revoltoso",
    "revoltou": "revoltar",
    "revoltá": "revoltar",
    "revoltámo": "revoltar",
    "revoltámos": "revoltar",
    "revoltáramo": "revoltar",
    "revoltáramos": "revoltar",
    "revoltárei": "revoltar",
    "revoltáreis": "revoltar",
    "revoltásseis": "revoltar",
    "revoltássemos": "revoltar",
    "revoltávamo": "revoltar",
    "revoltávamos": "revoltar",
    "revoltávei": "revoltar",
    "revoltáveis": "revoltar",
    "revoltões": "revoltão",
    "revoluciona": "revolucionar",
    "revolucionada": "revolucionar",
    "revolucionadas": "revolucionar",
    "revolucionado": "revolucionar",
    "revolucionados": "revolucionar",
    "revolucionai": "revolucionar",
    "revolucionais": "revolucionar",
    "revolucionam": "revolucionar",
    "revolucionamentos": "revolucionamento",
    "revolucionamo": "revolucionar",
    "revolucionamos": "revolucionar",
    "revolucionando": "revolucionar",
    "revolucionara": "revolucionar",
    "revolucionaram": "revolucionar",
    "revolucionaras": "revolucionar",
    "revolucionarde": "revolucionar",
    "revolucionardes": "revolucionar",
    "revolucionare": "revolucionar",
    "revolucionarei": "revolucionar",
    "revolucionareis": "revolucionar",
    "revolucionarem": "revolucionar",
    "revolucionaremos": "revolucionar",
    "revolucionares": "revolucionar",
    "revolucionaria": "revolucionar",
    "revolucionariam": "revolucionar",
    "revolucionarias": "revolucionar",
    "revolucionarmo": "revolucionar",
    "revolucionarmos": "revolucionar",
    "revolucionará": "revolucionar",
    "revolucionarás": "revolucionar",
    "revolucionarão": "revolucionar",
    "revolucionaríamos": "revolucionar",
    "revolucionaríeis": "revolucionar",
    "revolucionaríssima": "revolucionário",
    "revolucionaríssimas": "revolucionário",
    "revolucionaríssimo": "revolucionário",
    "revolucionaríssimos": "revolucionário",
    "revolucionas": "revolucionar",
    "revolucionasse": "revolucionar",
    "revolucionassem": "revolucionar",
    "revolucionasses": "revolucionar",
    "revolucionaste": "revolucionar",
    "revolucionastes": "revolucionar",
    "revolucionava": "revolucionar",
    "revolucionavam": "revolucionar",
    "revolucionavas": "revolucionar",
    "revolucione": "revolucionar",
    "revolucionei": "revolucionar",
    "revolucioneis": "revolucionar",
    "revolucionem": "revolucionar",
    "revolucionemo": "revolucionar",
    "revolucionemos": "revolucionar",
    "revoluciones": "revolucionar",
    "revoluciono": "revolucionar",
    "revolucionou": "revolucionar",
    "revolucioná": "revolucionar",
    "revolucionámo": "revolucionar",
    "revolucionámos": "revolucionar",
    "revolucionáramo": "revolucionar",
    "revolucionáramos": "revolucionar",
    "revolucionárei": "revolucionar",
    "revolucionáreis": "revolucionar",
    "revolucionária": "revolucionário",
    "revolucionárias": "revolucionário",
    "revolucionários": "revolucionário",
    "revolucionásseis": "revolucionar",
    "revolucionássemos": "revolucionar",
    "revolucionávamo": "revolucionar",
    "revolucionávamos": "revolucionar",
    "revolucionávei": "revolucionar",
    "revolucionáveis": "revolucionar",
    "revoluta": "revoluto",
    "revolutas": "revoluto",
    "revoluteada": "revolutear",
    "revoluteadas": "revolutear",
    "revoluteado": "revolutear",
    "revoluteados": "revolutear",
    "revoluteai": "revolutear",
    "revoluteais": "revolutear",
    "revoluteamo": "revolutear",
    "revoluteamos": "revolutear",
    "revoluteando": "revolutear",
    "revoluteantes": "revoluteante",
    "revoluteara": "revolutear",
    "revolutearam": "revolutear",
    "revolutearas": "revolutear",
    "revoluteardes": "revolutear",
    "revolutearei": "revolutear",
    "revoluteareis": "revolutear",
    "revolutearem": "revolutear",
    "revolutearemos": "revolutear",
    "revoluteares": "revolutear",
    "revolutearia": "revolutear",
    "revoluteariam": "revolutear",
    "revolutearias": "revolutear",
    "revolutearmo": "revolutear",
    "revolutearmos": "revolutear",
    "revoluteará": "revolutear",
    "revolutearás": "revolutear",
    "revolutearão": "revolutear",
    "revolutearíamos": "revolutear",
    "revolutearíeis": "revolutear",
    "revoluteasse": "revolutear",
    "revoluteassem": "revolutear",
    "revoluteasses": "revolutear",
    "revoluteaste": "revolutear",
    "revoluteastes": "revolutear",
    "revoluteava": "revolutear",
    "revoluteavam": "revolutear",
    "revoluteavas": "revolutear",
    "revoluteei": "revolutear",
    "revoluteeis": "revolutear",
    "revoluteemo": "revolutear",
    "revoluteemos": "revolutear",
    "revoluteia": "revolutear",
    "revoluteiam": "revolutear",
    "revoluteias": "revolutear",
    "revoluteie": "revolutear",
    "revoluteiem": "revolutear",
    "revoluteies": "revolutear",
    "revoluteio": "revolutear",
    "revoluteou": "revolutear",
    "revoluteámo": "revolutear",
    "revoluteámos": "revolutear",
    "revoluteáramo": "revolutear",
    "revoluteáramos": "revolutear",
    "revoluteáreis": "revolutear",
    "revoluteásseis": "revolutear",
    "revoluteássemos": "revolutear",
    "revoluteávamo": "revolutear",
    "revoluteávamos": "revolutear",
    "revoluteáveis": "revolutear",
    "revolutiva": "revolutivo",
    "revolutivas": "revolutivo",
    "revolutivos": "revolutivo",
    "revolutos": "revoluto",
    "revolutosa": "revolutoso",
    "revolutosas": "revolutoso",
    "revolutosos": "revolutoso",
    "revoluções": "revolução",
    "revolva": "revolver",
    "revolvais": "revolver",
    "revolvam": "revolver",
    "revolvamo": "revolver",
    "revolvamos": "revolver",
    "revolvas": "revolver",
    "revolve": "revolver",
    "revolvedora": "revolvedor",
    "revolvedoras": "revolvedor",
    "revolvedores": "revolvedor",
    "revolvei": "revolver",
    "revolveis": "revolver",
    "revolvem": "revolver",
    "revolvemo": "revolver",
    "revolvemos": "revolver",
    "revolvendo": "revolver",
    "revolvera": "revolver",
    "revolveram": "revolver",
    "revolveras": "revolver",
    "revolverde": "revolver",
    "revolverdes": "revolver",
    "revolvere": "revolver",
    "revolverei": "revolver",
    "revolvereis": "revolver",
    "revolverem": "revolver",
    "revolveremos": "revolver",
    "revolveres": "revolver",
    "revolveria": "revolver",
    "revolveriam": "revolver",
    "revolverias": "revolver",
    "revolvermo": "revolver",
    "revolvermos": "revolver",
    "revolverá": "revolver",
    "revolverás": "revolver",
    "revolverão": "revolver",
    "revolveríamos": "revolver",
    "revolveríeis": "revolver",
    "revolves": "revolver",
    "revolvesse": "revolver",
    "revolvessem": "revolver",
    "revolvesses": "revolver",
    "revolveste": "revolver",
    "revolvestes": "revolver",
    "revolveu": "revolver",
    "revolvi": "revolver",
    "revolvia": "revolver",
    "revolviam": "revolver",
    "revolvias": "revolver",
    "revolvida": "revolvido",
    "revolvidas": "revolvido",
    "revolvido": "revolver",
    "revolvidos": "revolvido",
    "revolvimentos": "revolvimento",
    "revolvo": "revolver",
    "revolvê": "revolver",
    "revolvêramo": "revolver",
    "revolvêramos": "revolver",
    "revolvêrei": "revolver",
    "revolvêreis": "revolver",
    "revolvêsseis": "revolver",
    "revolvêssemos": "revolver",
    "revolvíamo": "revolver",
    "revolvíamos": "revolver",
    "revolvíei": "revolver",
    "revolvíeis": "revolver",
    "revoo": "revoar",
    "revoos": "revoo",
    "revoou": "revoar",
    "revoque": "revocar",
    "revoquei": "revocar",
    "revoqueis": "revocar",
    "revoquem": "revocar",
    "revoquemo": "revocar",
    "revoquemos": "revocar",
    "revoques": "revocar",
    "revoámo": "revoar",
    "revoámos": "revoar",
    "revoáramo": "revoar",
    "revoáramos": "revoar",
    "revoáreis": "revoar",
    "revoásseis": "revoar",
    "revoássemos": "revoar",
    "revoávamo": "revoar",
    "revoávamos": "revoar",
    "revoáveis": "revoar",
    "revulsa": "revulsar",
    "revulsada": "revulsar",
    "revulsadas": "revulsar",
    "revulsado": "revulsar",
    "revulsados": "revulsar",
    "revulsai": "revulsar",
    "revulsais": "revulsar",
    "revulsam": "revulsar",
    "revulsamo": "revulsar",
    "revulsamos": "revulsar",
    "revulsando": "revulsar",
    "revulsara": "revulsar",
    "revulsaram": "revulsar",
    "revulsaras": "revulsar",
    "revulsarde": "revulsar",
    "revulsardes": "revulsar",
    "revulsare": "revulsar",
    "revulsarei": "revulsar",
    "revulsareis": "revulsar",
    "revulsarem": "revulsar",
    "revulsaremos": "revulsar",
    "revulsares": "revulsar",
    "revulsaria": "revulsar",
    "revulsariam": "revulsar",
    "revulsarias": "revulsar",
    "revulsarmo": "revulsar",
    "revulsarmos": "revulsar",
    "revulsará": "revulsar",
    "revulsarás": "revulsar",
    "revulsarão": "revulsar",
    "revulsaríamos": "revulsar",
    "revulsaríeis": "revulsar",
    "revulsas": "revulsar",
    "revulsasse": "revulsar",
    "revulsassem": "revulsar",
    "revulsasses": "revulsar",
    "revulsaste": "revulsar",
    "revulsastes": "revulsar",
    "revulsava": "revulsar",
    "revulsavam": "revulsar",
    "revulsavas": "revulsar",
    "revulse": "revulsar",
    "revulsei": "revulsar",
    "revulseis": "revulsar",
    "revulsem": "revulsar",
    "revulsemo": "revulsar",
    "revulsemos": "revulsar",
    "revulses": "revulsar",
    "revulsiva": "revulsivo",
    "revulsivas": "revulsivo",
    "revulsivos": "revulsivo",
    "revulso": "revulsar",
    "revulsores": "revulsor",
    "revulsou": "revulsar",
    "revulsá": "revulsar",
    "revulsámo": "revulsar",
    "revulsámos": "revulsar",
    "revulsáramo": "revulsar",
    "revulsáramos": "revulsar",
    "revulsárei": "revulsar",
    "revulsáreis": "revulsar",
    "revulsásseis": "revulsar",
    "revulsássemos": "revulsar",
    "revulsávamo": "revulsar",
    "revulsávamos": "revulsar",
    "revulsávei": "revulsar",
    "revulsáveis": "revulsar",
    "revulsória": "revulsório",
    "revulsórias": "revulsório",
    "revulsórios": "revulsório",
    "revulsões": "revulsão",
    "revém": "revir",
    "revéns": "revir",
    "revérberos": "revérbero",
    "revê": "rever",
    "revêem": "rever",
    "revêm": "revir",
    "revês": "rever",
    "revíamo": "rever",
    "revíamos": "rever",
    "revíei": "rever",
    "revíeis": "rever",
    "revínhamo": "revir",
    "revínhamos": "revir",
    "revínheis": "revir",
    "revíramo": "rever",
    "revíramos": "rever",
    "revírei": "rever",
    "revíreis": "rever",
    "revísseis": "rever",
    "revíssemos": "rever",
    "revólveres": "revólver",
    "rexelos": "rexelo",
    "rexertas": "rexerta",
    "rexios": "rexio",
    "reza": "rezar",
    "rezada": "rezar",
    "rezadas": "rezar",
    "rezadeira": "rezadeiro",
    "rezadeiras": "rezadeiro",
    "rezadeiros": "rezadeiro",
    "rezado": "rezar",
    "rezadora": "rezador",
    "rezadoras": "rezador",
    "rezadores": "rezador",
    "rezados": "rezar",
    "rezai": "rezar",
    "rezais": "rezar",
    "rezam": "rezar",
    "rezamo": "rezar",
    "rezamos": "rezar",
    "rezando": "rezar",
    "rezara": "rezar",
    "rezaram": "rezar",
    "rezaras": "rezar",
    "rezarde": "rezar",
    "rezardes": "rezar",
    "rezare": "rezar",
    "rezarei": "rezar",
    "rezareis": "rezar",
    "rezarem": "rezar",
    "rezaremos": "rezar",
    "rezares": "rezar",
    "rezaria": "rezar",
    "rezariam": "rezar",
    "rezarias": "rezaria",
    "rezarmo": "rezar",
    "rezarmos": "rezar",
    "rezará": "rezar",
    "rezarás": "rezar",
    "rezarão": "rezar",
    "rezaríamos": "rezar",
    "rezaríeis": "rezar",
    "rezas": "rezar",
    "rezasse": "rezar",
    "rezassem": "rezar",
    "rezasses": "rezar",
    "rezaste": "rezar",
    "rezastes": "rezar",
    "rezava": "rezar",
    "rezavam": "rezar",
    "rezavas": "rezar",
    "reze": "rezar",
    "rezei": "rezar",
    "rezeis": "rezar",
    "rezem": "rezar",
    "rezemo": "rezar",
    "rezemos": "rezar",
    "rezenta": "rezento",
    "rezentais": "rezental",
    "rezentaleiras": "rezentaleira",
    "rezentas": "rezento",
    "rezentos": "rezento",
    "rezes": "rezar",
    "rezinas": "rezina",
    "rezinazinha": "rezina",
    "rezinazinhas": "rezina",
    "rezinazinho": "rezina",
    "rezinazinhos": "rezina",
    "rezinazita": "rezina",
    "rezinazitas": "rezina",
    "rezinazito": "rezina",
    "rezinazitos": "rezina",
    "rezinga": "rezingar",
    "rezingada": "rezingar",
    "rezingadas": "rezingar",
    "rezingado": "rezingar",
    "rezingados": "rezingar",
    "rezingai": "rezingar",
    "rezingais": "rezingar",
    "rezingam": "rezingar",
    "rezingamo": "rezingar",
    "rezingamos": "rezingar",
    "rezingando": "rezingar",
    "rezingara": "rezingar",
    "rezingaram": "rezingar",
    "rezingaras": "rezingar",
    "rezingardes": "rezingar",
    "rezingarei": "rezingar",
    "rezingareis": "rezingar",
    "rezingarem": "rezingar",
    "rezingaremos": "rezingar",
    "rezingares": "rezingar",
    "rezingaria": "rezingar",
    "rezingariam": "rezingar",
    "rezingarias": "rezingar",
    "rezingarmo": "rezingar",
    "rezingarmos": "rezingar",
    "rezingará": "rezingar",
    "rezingarás": "rezingar",
    "rezingarão": "rezingar",
    "rezingaríamos": "rezingar",
    "rezingaríeis": "rezingar",
    "rezingas": "rezingar",
    "rezingasse": "rezingar",
    "rezingassem": "rezingar",
    "rezingasses": "rezingar",
    "rezingaste": "rezingar",
    "rezingastes": "rezingar",
    "rezingava": "rezingar",
    "rezingavam": "rezingar",
    "rezingavas": "rezingar",
    "rezingo": "rezingar",
    "rezingona": "rezingão",
    "rezingonas": "rezingão",
    "rezingonazinha": "rezingão",
    "rezingonazinhas": "rezingão",
    "rezingonazita": "rezingão",
    "rezingonazitas": "rezingão",
    "rezingou": "rezingar",
    "rezingue": "rezingar",
    "rezinguei": "rezingar",
    "rezingueira": "rezingueiro",
    "rezingueiras": "rezingueiro",
    "rezingueirazinha": "rezingueiro",
    "rezingueirazinhas": "rezingueiro",
    "rezingueirazita": "rezingueiro",
    "rezingueirazitas": "rezingueiro",
    "rezingueiros": "rezingueiro",
    "rezingueirozinho": "rezingueiro",
    "rezingueirozinhos": "rezingueiro",
    "rezingueirozito": "rezingueiro",
    "rezingueirozitos": "rezingueiro",
    "rezingueis": "rezingar",
    "rezinguem": "rezingar",
    "rezinguemo": "rezingar",
    "rezinguemos": "rezingar",
    "rezingues": "rezingar",
    "rezingámo": "rezingar",
    "rezingámos": "rezingar",
    "rezingáramo": "rezingar",
    "rezingáramos": "rezingar",
    "rezingáreis": "rezingar",
    "rezingásseis": "rezingar",
    "rezingássemos": "rezingar",
    "rezingávamo": "rezingar",
    "rezingávamos": "rezingar",
    "rezingáveis": "rezingar",
    "rezingãozinho": "rezingão",
    "rezingãozito": "rezingão",
    "rezingões": "rezingão",
    "rezingõezinhos": "rezingão",
    "rezingõezitos": "rezingão",
    "rezo": "rezar",
    "rezona": "rezão",
    "rezonas": "rezão",
    "rezou": "rezar",
    "rezá": "rezar",
    "rezámo": "rezar",
    "rezámos": "rezar",
    "rezáramo": "rezar",
    "rezáramos": "rezar",
    "rezárei": "rezar",
    "rezáreis": "rezar",
    "rezásseis": "rezar",
    "rezássemos": "rezar",
    "rezávamo": "rezar",
    "rezávamos": "rezar",
    "rezávei": "rezar",
    "rezáveis": "rezar",
    "rezões": "rezão",
    "reídeos": "reídeo",
    "reófila": "reófilo",
    "reófilas": "reófilo",
    "reófilos": "reófilo",
    "reófoba": "reófobo",
    "reófobas": "reófobo",
    "reófobos": "reófobo",
    "reóforos": "reóforo",
    "reógrafos": "reógrafo",
    "reómetros": "reómetro",
    "reóstatos": "reóstato",
    "reúna": "reunir",
    "reúnam": "reunir",
    "reúnas": "reunir",
    "reúne": "reunir",
    "reúnem": "reunir",
    "reúnes": "reunir",
    "reúno": "reunir",
    "ri": "rir",
    "ria": "rir",
    "riachos": "riacho",
    "riais": "rir",
    "riam": "rir",
    "riambas": "riamba",
    "riamo": "rir",
    "riamos": "rir",
    "rias": "rir",
    "ribacudana": "ribacudano",
    "ribacudanas": "ribacudano",
    "ribacudanos": "ribacudano",
    "ribacudenses": "ribacudense",
    "ribadas": "ribada",
    "ribalda": "ribaldo",
    "ribaldada": "ribaldar",
    "ribaldadas": "ribaldar",
    "ribaldado": "ribaldar",
    "ribaldados": "ribaldar",
    "ribaldai": "ribaldar",
    "ribaldais": "ribaldar",
    "ribaldam": "ribaldar",
    "ribaldamo": "ribaldar",
    "ribaldamos": "ribaldar",
    "ribaldando": "ribaldar",
    "ribaldara": "ribaldar",
    "ribaldaram": "ribaldar",
    "ribaldaras": "ribaldar",
    "ribaldardes": "ribaldar",
    "ribaldarei": "ribaldar",
    "ribaldareis": "ribaldar",
    "ribaldarem": "ribaldar",
    "ribaldaremos": "ribaldar",
    "ribaldares": "ribaldar",
    "ribaldaria": "ribaldar",
    "ribaldariam": "ribaldar",
    "ribaldarias": "ribaldaria",
    "ribaldarmo": "ribaldar",
    "ribaldarmos": "ribaldar",
    "ribaldará": "ribaldar",
    "ribaldarás": "ribaldar",
    "ribaldarão": "ribaldar",
    "ribaldaríamos": "ribaldar",
    "ribaldaríeis": "ribaldar",
    "ribaldas": "ribaldo",
    "ribaldasse": "ribaldar",
    "ribaldassem": "ribaldar",
    "ribaldasses": "ribaldar",
    "ribaldaste": "ribaldar",
    "ribaldastes": "ribaldar",
    "ribaldava": "ribaldar",
    "ribaldavam": "ribaldar",
    "ribaldavas": "ribaldar",
    "ribalde": "ribaldar",
    "ribaldei": "ribaldar",
    "ribaldeira": "ribaldeiro",
    "ribaldeiras": "ribaldeiro",
    "ribaldeiros": "ribaldeiro",
    "ribaldeis": "ribaldar",
    "ribaldem": "ribaldar",
    "ribaldemo": "ribaldar",
    "ribaldemos": "ribaldar",
    "ribaldes": "ribaldar",
    "ribaldia": "ribaldio",
    "ribaldias": "ribaldio",
    "ribaldios": "ribaldio",
    "ribaldo": "ribaldar",
    "ribaldos": "ribaldo",
    "ribaldou": "ribaldar",
    "ribaldámo": "ribaldar",
    "ribaldámos": "ribaldar",
    "ribaldáramo": "ribaldar",
    "ribaldáramos": "ribaldar",
    "ribaldáreis": "ribaldar",
    "ribaldásseis": "ribaldar",
    "ribaldássemos": "ribaldar",
    "ribaldávamo": "ribaldar",
    "ribaldávamos": "ribaldar",
    "ribaldáveis": "ribaldar",
    "ribaltas": "ribalta",
    "ribamares": "ribamar",
    "ribanas": "ribana",
    "ribanceiras": "ribanceira",
    "ribanças": "ribança",
    "ribas": "riba",
    "ribatejana": "ribatejano",
    "ribatejanas": "ribatejano",
    "ribatejanos": "ribatejano",
    "ribeiradas": "ribeirada",
    "ribeiradios": "ribeiradio",
    "ribeiras": "ribeira",
    "ribeirinha": "ribeirinho",
    "ribeirinhas": "ribeirinho",
    "ribeirinho": "ribeiro",
    "ribeirinhos": "ribeiro",
    "ribeirita": "ribeira",
    "ribeiritas": "ribeira",
    "ribeirito": "ribeiro",
    "ribeiritos": "ribeiro",
    "ribeiros": "ribeiro",
    "ribeirões": "ribeirão",
    "ribesiácea": "ribesiáceo",
    "ribesiáceas": "ribesiáceo",
    "ribesiáceos": "ribesiáceo",
    "ribetes": "ribete",
    "ribomba": "ribombar",
    "ribombada": "ribombar",
    "ribombadas": "ribombar",
    "ribombado": "ribombar",
    "ribombados": "ribombar",
    "ribombai": "ribombar",
    "ribombais": "ribombar",
    "ribombam": "ribombar",
    "ribombamo": "ribombar",
    "ribombamos": "ribombar",
    "ribombando": "ribombar",
    "ribombantes": "ribombante",
    "ribombara": "ribombar",
    "ribombaram": "ribombar",
    "ribombaras": "ribombar",
    "ribombardes": "ribombar",
    "ribombarei": "ribombar",
    "ribombareis": "ribombar",
    "ribombarem": "ribombar",
    "ribombaremos": "ribombar",
    "ribombares": "ribombar",
    "ribombaria": "ribombar",
    "ribombariam": "ribombar",
    "ribombarias": "ribombar",
    "ribombarmo": "ribombar",
    "ribombarmos": "ribombar",
    "ribombará": "ribombar",
    "ribombarás": "ribombar",
    "ribombarão": "ribombar",
    "ribombaríamos": "ribombar",
    "ribombaríeis": "ribombar",
    "ribombas": "ribombar",
    "ribombasse": "ribombar",
    "ribombassem": "ribombar",
    "ribombasses": "ribombar",
    "ribombaste": "ribombar",
    "ribombastes": "ribombar",
    "ribombava": "ribombar",
    "ribombavam": "ribombar",
    "ribombavas": "ribombar",
    "ribombe": "ribombar",
    "ribombei": "ribombar",
    "ribombeis": "ribombar",
    "ribombem": "ribombar",
    "ribombemo": "ribombar",
    "ribombemos": "ribombar",
    "ribombes": "ribombar",
    "ribombo": "ribombar",
    "ribombos": "ribombo",
    "ribombou": "ribombar",
    "ribombámo": "ribombar",
    "ribombámos": "ribombar",
    "ribombáramo": "ribombar",
    "ribombáramos": "ribombar",
    "ribombáreis": "ribombar",
    "ribombásseis": "ribombar",
    "ribombássemos": "ribombar",
    "ribombávamo": "ribombar",
    "ribombávamos": "ribombar",
    "ribombáveis": "ribombar",
    "ribombâncias": "ribombância",
    "ribonucleica": "ribonucleico",
    "ribonucleicas": "ribonucleico",
    "ribonucleicos": "ribonucleico",
    "ribozimas": "ribozima",
    "ribrica": "ribricar",
    "ribricada": "ribricar",
    "ribricadas": "ribricar",
    "ribricado": "ribricar",
    "ribricados": "ribricar",
    "ribricai": "ribricar",
    "ribricais": "ribricar",
    "ribricam": "ribricar",
    "ribricamo": "ribricar",
    "ribricamos": "ribricar",
    "ribricando": "ribricar",
    "ribricara": "ribricar",
    "ribricaram": "ribricar",
    "ribricaras": "ribricar",
    "ribricarde": "ribricar",
    "ribricardes": "ribricar",
    "ribricare": "ribricar",
    "ribricarei": "ribricar",
    "ribricareis": "ribricar",
    "ribricarem": "ribricar",
    "ribricaremos": "ribricar",
    "ribricares": "ribricar",
    "ribricaria": "ribricar",
    "ribricariam": "ribricar",
    "ribricarias": "ribricar",
    "ribricarmo": "ribricar",
    "ribricarmos": "ribricar",
    "ribricará": "ribricar",
    "ribricarás": "ribricar",
    "ribricarão": "ribricar",
    "ribricaríamos": "ribricar",
    "ribricaríeis": "ribricar",
    "ribricas": "ribricar",
    "ribricasse": "ribricar",
    "ribricassem": "ribricar",
    "ribricasses": "ribricar",
    "ribricaste": "ribricar",
    "ribricastes": "ribricar",
    "ribricava": "ribricar",
    "ribricavam": "ribricar",
    "ribricavas": "ribricar",
    "ribrico": "ribricar",
    "ribricou": "ribricar",
    "ribricá": "ribricar",
    "ribricámo": "ribricar",
    "ribricámos": "ribricar",
    "ribricáramo": "ribricar",
    "ribricáramos": "ribricar",
    "ribricárei": "ribricar",
    "ribricáreis": "ribricar",
    "ribricásseis": "ribricar",
    "ribricássemos": "ribricar",
    "ribricávamo": "ribricar",
    "ribricávamos": "ribricar",
    "ribricávei": "ribricar",
    "ribricáveis": "ribricar",
    "ribrique": "ribricar",
    "ribriquei": "ribricar",
    "ribriqueis": "ribricar",
    "ribriquem": "ribricar",
    "ribriquemo": "ribricar",
    "ribriquemos": "ribricar",
    "ribriques": "ribricar",
    "ribésias": "ribésia",
    "rica": "rico",
    "ricalhaça": "ricalhaço",
    "ricalhaças": "ricalhaço",
    "ricalhaços": "ricalhaço",
    "ricalhoiça": "ricalhoiço",
    "ricalhoiças": "ricalhoiço",
    "ricalhoiços": "ricalhoiço",
    "ricalhouça": "ricalhouço",
    "ricalhouças": "ricalhouço",
    "ricalhouços": "ricalhouço",
    "ricanha": "ricanho",
    "ricanhas": "ricanho",
    "ricanhos": "ricanho",
    "ricardos": "ricardo",
    "ricas": "rico",
    "ricaça": "ricaço",
    "ricaças": "ricaço",
    "ricaços": "ricaço",
    "ricciáceas": "ricciácea",
    "rice": "riçar",
    "ricei": "riçar",
    "riceis": "riçar",
    "ricem": "riçar",
    "ricemo": "riçar",
    "ricemos": "riçar",
    "rices": "riçar",
    "richartes": "richarte",
    "ricináceas": "ricinácea",
    "ricocheteada": "ricochetear",
    "ricocheteadas": "ricochetear",
    "ricocheteado": "ricochetear",
    "ricocheteados": "ricochetear",
    "ricocheteai": "ricochetear",
    "ricocheteais": "ricochetear",
    "ricocheteamo": "ricochetear",
    "ricocheteamos": "ricochetear",
    "ricocheteando": "ricochetear",
    "ricocheteara": "ricochetear",
    "ricochetearam": "ricochetear",
    "ricochetearas": "ricochetear",
    "ricocheteardes": "ricochetear",
    "ricochetearei": "ricochetear",
    "ricocheteareis": "ricochetear",
    "ricochetearem": "ricochetear",
    "ricochetearemos": "ricochetear",
    "ricocheteares": "ricochetear",
    "ricochetearia": "ricochetear",
    "ricocheteariam": "ricochetear",
    "ricochetearias": "ricochetear",
    "ricochetearmo": "ricochetear",
    "ricochetearmos": "ricochetear",
    "ricocheteará": "ricochetear",
    "ricochetearás": "ricochetear",
    "ricochetearão": "ricochetear",
    "ricochetearíamos": "ricochetear",
    "ricochetearíeis": "ricochetear",
    "ricocheteasse": "ricochetear",
    "ricocheteassem": "ricochetear",
    "ricocheteasses": "ricochetear",
    "ricocheteaste": "ricochetear",
    "ricocheteastes": "ricochetear",
    "ricocheteava": "ricochetear",
    "ricocheteavam": "ricochetear",
    "ricocheteavas": "ricochetear",
    "ricocheteei": "ricochetear",
    "ricocheteeis": "ricochetear",
    "ricocheteemo": "ricochetear",
    "ricocheteemos": "ricochetear",
    "ricocheteia": "ricochetear",
    "ricocheteiam": "ricochetear",
    "ricocheteias": "ricochetear",
    "ricocheteie": "ricochetear",
    "ricocheteiem": "ricochetear",
    "ricocheteies": "ricochetear",
    "ricocheteio": "ricochetear",
    "ricocheteou": "ricochetear",
    "ricochetes": "ricochete",
    "ricocheteámo": "ricochetear",
    "ricocheteámos": "ricochetear",
    "ricocheteáramo": "ricochetear",
    "ricocheteáramos": "ricochetear",
    "ricocheteáreis": "ricochetear",
    "ricocheteásseis": "ricochetear",
    "ricocheteássemos": "ricochetear",
    "ricocheteávamo": "ricochetear",
    "ricocheteávamos": "ricochetear",
    "ricocheteáveis": "ricochetear",
    "ricos": "rico",
    "rictos": "ricto",
    "rida": "rir",
    "ridas": "rir",
    "ride": "rir",
    "ridentes": "ridente",
    "rides": "rir",
    "ridicularias": "ridicularia",
    "ridiculariza": "ridicularizar",
    "ridicularizada": "ridicularizar",
    "ridicularizadas": "ridicularizar",
    "ridicularizado": "ridicularizar",
    "ridicularizadora": "ridicularizador",
    "ridicularizadoras": "ridicularizador",
    "ridicularizadores": "ridicularizador",
    "ridicularizados": "ridicularizar",
    "ridicularizai": "ridicularizar",
    "ridicularizais": "ridicularizar",
    "ridicularizam": "ridicularizar",
    "ridicularizamo": "ridicularizar",
    "ridicularizamos": "ridicularizar",
    "ridicularizando": "ridicularizar",
    "ridicularizantes": "ridicularizante",
    "ridicularizara": "ridicularizar",
    "ridicularizaram": "ridicularizar",
    "ridicularizaras": "ridicularizar",
    "ridicularizarde": "ridicularizar",
    "ridicularizardes": "ridicularizar",
    "ridicularizare": "ridicularizar",
    "ridicularizarei": "ridicularizar",
    "ridicularizareis": "ridicularizar",
    "ridicularizarem": "ridicularizar",
    "ridicularizaremos": "ridicularizar",
    "ridicularizares": "ridicularizar",
    "ridicularizaria": "ridicularizar",
    "ridicularizariam": "ridicularizar",
    "ridicularizarias": "ridicularizar",
    "ridicularizarmo": "ridicularizar",
    "ridicularizarmos": "ridicularizar",
    "ridicularizará": "ridicularizar",
    "ridicularizarás": "ridicularizar",
    "ridicularizarão": "ridicularizar",
    "ridicularizaríamos": "ridicularizar",
    "ridicularizaríeis": "ridicularizar",
    "ridicularizas": "ridicularizar",
    "ridicularizasse": "ridicularizar",
    "ridicularizassem": "ridicularizar",
    "ridicularizasses": "ridicularizar",
    "ridicularizaste": "ridicularizar",
    "ridicularizastes": "ridicularizar",
    "ridicularizava": "ridicularizar",
    "ridicularizavam": "ridicularizar",
    "ridicularizavas": "ridicularizar",
    "ridicularizações": "ridicularização",
    "ridicularize": "ridicularizar",
    "ridicularizei": "ridicularizar",
    "ridicularizeis": "ridicularizar",
    "ridicularizem": "ridicularizar",
    "ridicularizemo": "ridicularizar",
    "ridicularizemos": "ridicularizar",
    "ridicularizes": "ridicularizar",
    "ridicularizo": "ridicularizar",
    "ridicularizou": "ridicularizar",
    "ridicularizá": "ridicularizar",
    "ridicularizámo": "ridicularizar",
    "ridicularizámos": "ridicularizar",
    "ridicularizáramo": "ridicularizar",
    "ridicularizáramos": "ridicularizar",
    "ridicularizárei": "ridicularizar",
    "ridicularizáreis": "ridicularizar",
    "ridicularizásseis": "ridicularizar",
    "ridicularizássemos": "ridicularizar",
    "ridicularizávamo": "ridicularizar",
    "ridicularizávamos": "ridicularizar",
    "ridicularizávei": "ridicularizar",
    "ridicularizáveis": "ridicularizável",
    "ridiculazinha": "ridículo",
    "ridiculazinhas": "ridículo",
    "ridiculazita": "ridículo",
    "ridiculazitas": "ridículo",
    "ridiculezas": "ridiculeza",
    "ridiculezes": "ridiculez",
    "ridiculiza": "ridiculizar",
    "ridiculizada": "ridiculizar",
    "ridiculizadas": "ridiculizar",
    "ridiculizado": "ridiculizar",
    "ridiculizados": "ridiculizar",
    "ridiculizai": "ridiculizar",
    "ridiculizais": "ridiculizar",
    "ridiculizam": "ridiculizar",
    "ridiculizamo": "ridiculizar",
    "ridiculizamos": "ridiculizar",
    "ridiculizando": "ridiculizar",
    "ridiculizara": "ridiculizar",
    "ridiculizaram": "ridiculizar",
    "ridiculizaras": "ridiculizar",
    "ridiculizarde": "ridiculizar",
    "ridiculizardes": "ridiculizar",
    "ridiculizare": "ridiculizar",
    "ridiculizarei": "ridiculizar",
    "ridiculizareis": "ridiculizar",
    "ridiculizarem": "ridiculizar",
    "ridiculizaremos": "ridiculizar",
    "ridiculizares": "ridiculizar",
    "ridiculizaria": "ridiculizar",
    "ridiculizariam": "ridiculizar",
    "ridiculizarias": "ridiculizar",
    "ridiculizarmo": "ridiculizar",
    "ridiculizarmos": "ridiculizar",
    "ridiculizará": "ridiculizar",
    "ridiculizarás": "ridiculizar",
    "ridiculizarão": "ridiculizar",
    "ridiculizaríamos": "ridiculizar",
    "ridiculizaríeis": "ridiculizar",
    "ridiculizas": "ridiculizar",
    "ridiculizasse": "ridiculizar",
    "ridiculizassem": "ridiculizar",
    "ridiculizasses": "ridiculizar",
    "ridiculizaste": "ridiculizar",
    "ridiculizastes": "ridiculizar",
    "ridiculizava": "ridiculizar",
    "ridiculizavam": "ridiculizar",
    "ridiculizavas": "ridiculizar",
    "ridiculize": "ridiculizar",
    "ridiculizei": "ridiculizar",
    "ridiculizeis": "ridiculizar",
    "ridiculizem": "ridiculizar",
    "ridiculizemo": "ridiculizar",
    "ridiculizemos": "ridiculizar",
    "ridiculizes": "ridiculizar",
    "ridiculizo": "ridiculizar",
    "ridiculizou": "ridiculizar",
    "ridiculizá": "ridiculizar",
    "ridiculizámo": "ridiculizar",
    "ridiculizámos": "ridiculizar",
    "ridiculizáramo": "ridiculizar",
    "ridiculizáramos": "ridiculizar",
    "ridiculizárei": "ridiculizar",
    "ridiculizáreis": "ridiculizar",
    "ridiculizásseis": "ridiculizar",
    "ridiculizássemos": "ridiculizar",
    "ridiculizávamo": "ridiculizar",
    "ridiculizávamos": "ridiculizar",
    "ridiculizávei": "ridiculizar",
    "ridiculizáveis": "ridiculizável",
    "ridiculosa": "ridiculoso",
    "ridiculosas": "ridiculoso",
    "ridiculosos": "ridiculoso",
    "ridiculozinho": "ridículo",
    "ridiculozinhos": "ridículo",
    "ridiculozito": "ridículo",
    "ridiculozitos": "ridículo",
    "rido": "rir",
    "ridos": "rir",
    "ridências": "ridência",
    "ridícula": "ridículo",
    "ridículas": "ridículo",
    "ridículos": "ridículo",
    "riem": "rir",
    "rifa": "rifar",
    "rifada": "rifar",
    "rifadas": "rifar",
    "rifado": "rifar",
    "rifadora": "rifador",
    "rifadoras": "rifador",
    "rifadores": "rifador",
    "rifados": "rifar",
    "rifai": "rifar",
    "rifais": "rifar",
    "rifam": "rifar",
    "rifamo": "rifar",
    "rifamos": "rifar",
    "rifando": "rifar",
    "rifara": "rifar",
    "rifaram": "rifar",
    "rifaras": "rifar",
    "rifarde": "rifar",
    "rifardes": "rifar",
    "rifare": "rifar",
    "rifarei": "rifar",
    "rifareis": "rifar",
    "rifarem": "rifar",
    "rifaremos": "rifar",
    "rifares": "rifar",
    "rifaria": "rifar",
    "rifariam": "rifar",
    "rifarias": "rifar",
    "rifarmo": "rifar",
    "rifarmos": "rifar",
    "rifará": "rifar",
    "rifarás": "rifar",
    "rifarão": "rifar",
    "rifaríamos": "rifar",
    "rifaríeis": "rifar",
    "rifas": "rifar",
    "rifasse": "rifar",
    "rifassem": "rifar",
    "rifasses": "rifar",
    "rifaste": "rifar",
    "rifastes": "rifar",
    "rifava": "rifar",
    "rifavam": "rifar",
    "rifavas": "rifar",
    "rife": "rifar",
    "rifei": "rifar",
    "rifeis": "rifar",
    "rifem": "rifar",
    "rifemo": "rifar",
    "rifemos": "rifar",
    "rifenha": "rifenho",
    "rifenhas": "rifenho",
    "rifenhos": "rifenho",
    "rifes": "rifar",
    "rifladas": "riflada",
    "rifles": "rifle",
    "rifo": "rifar",
    "rifou": "rifar",
    "rifá": "rifar",
    "rifámo": "rifar",
    "rifámos": "rifar",
    "rifáramo": "rifar",
    "rifáramos": "rifar",
    "rifárei": "rifar",
    "rifáreis": "rifar",
    "rifásseis": "rifar",
    "rifássemos": "rifar",
    "rifávamo": "rifar",
    "rifávamos": "rifar",
    "rifávei": "rifar",
    "rifáveis": "rifar",
    "rifões": "rifão",
    "rigas": "riga",
    "rigentes": "rigente",
    "rigidazinha": "rígido",
    "rigidazinhas": "rígido",
    "rigidazita": "rígido",
    "rigidazitas": "rígido",
    "rigidezes": "rigidez",
    "rigidozinho": "rígido",
    "rigidozinhos": "rígido",
    "rigidozito": "rígido",
    "rigidozitos": "rígido",
    "rigidíssima": "rígido",
    "rigidíssimas": "rígido",
    "rigidíssimo": "rígido",
    "rigidíssimos": "rígido",
    "rigodões": "rigodão",
    "rigores": "rigor",
    "rigorismos": "rigorismo",
    "rigoristas": "rigorista",
    "rigorosa": "rigoroso",
    "rigorosas": "rigoroso",
    "rigorosazinha": "rigoroso",
    "rigorosazinhas": "rigoroso",
    "rigorosazita": "rigoroso",
    "rigorosazitas": "rigoroso",
    "rigorosidades": "rigorosidade",
    "rigorosos": "rigoroso",
    "rigorosozinho": "rigoroso",
    "rigorosozinhos": "rigoroso",
    "rigorosozito": "rigoroso",
    "rigorosozitos": "rigoroso",
    "rigorosíssima": "rigoroso",
    "rigorosíssimas": "rigoroso",
    "rigorosíssimo": "rigoroso",
    "rigorosíssimos": "rigoroso",
    "rija": "rijo",
    "rijada": "rijar",
    "rijadas": "rijar",
    "rijado": "rijar",
    "rijados": "rijar",
    "rijai": "rijar",
    "rijais": "rijar",
    "rijam": "rijar",
    "rijamo": "rijar",
    "rijamos": "rijar",
    "rijando": "rijar",
    "rijara": "rijar",
    "rijaram": "rijar",
    "rijaras": "rijar",
    "rijarde": "rijar",
    "rijardes": "rijar",
    "rijare": "rijar",
    "rijarei": "rijar",
    "rijareis": "rijar",
    "rijarem": "rijar",
    "rijaremos": "rijar",
    "rijares": "rijar",
    "rijaria": "rijar",
    "rijariam": "rijar",
    "rijarias": "rijar",
    "rijarmo": "rijar",
    "rijarmos": "rijar",
    "rijará": "rijar",
    "rijarás": "rijar",
    "rijarão": "rijar",
    "rijaríamos": "rijar",
    "rijaríeis": "rijar",
    "rijas": "rijo",
    "rijasse": "rijar",
    "rijassem": "rijar",
    "rijasses": "rijar",
    "rijaste": "rijar",
    "rijastes": "rijar",
    "rijava": "rijar",
    "rijavam": "rijar",
    "rijavas": "rijar",
    "rijazinha": "rijo",
    "rijazinhas": "rijo",
    "rijazita": "rijo",
    "rijazitas": "rijo",
    "rije": "rijar",
    "rijei": "rijar",
    "rijeis": "rijar",
    "rijem": "rijar",
    "rijemo": "rijar",
    "rijemos": "rijar",
    "rijes": "rijar",
    "rijezas": "rijeza",
    "rijinha": "rijo",
    "rijinhas": "rijo",
    "rijinho": "rijo",
    "rijinhos": "rijo",
    "rijita": "rijo",
    "rijitas": "rijo",
    "rijito": "rijo",
    "rijitos": "rijo",
    "rijo": "rijar",
    "rijos": "rijo",
    "rijou": "rijar",
    "rijozinho": "rijo",
    "rijozinhos": "rijo",
    "rijozito": "rijo",
    "rijozitos": "rijo",
    "rijá": "rijar",
    "rijámo": "rijar",
    "rijámos": "rijar",
    "rijáramo": "rijar",
    "rijáramos": "rijar",
    "rijárei": "rijar",
    "rijáreis": "rijar",
    "rijásseis": "rijar",
    "rijássemos": "rijar",
    "rijávamo": "rijar",
    "rijávamos": "rijar",
    "rijávei": "rijar",
    "rijáveis": "rijar",
    "rijíssima": "rijo",
    "rijíssimas": "rijo",
    "rijíssimo": "rijo",
    "rijíssimos": "rijo",
    "rijões": "rijão",
    "riladas": "rilada",
    "rilha": "rilhar",
    "rilhada": "rilhar",
    "rilhadas": "rilhar",
    "rilhado": "rilhar",
    "rilhadora": "rilhador",
    "rilhadoras": "rilhador",
    "rilhadores": "rilhador",
    "rilhados": "rilhar",
    "rilhaduras": "rilhadura",
    "rilhafolesca": "rilhafolesco",
    "rilhafolescas": "rilhafolesco",
    "rilhafolescos": "rilhafolesco",
    "rilhai": "rilhar",
    "rilhais": "rilhar",
    "rilham": "rilhar",
    "rilhamo": "rilhar",
    "rilhamos": "rilhar",
    "rilhando": "rilhar",
    "rilhara": "rilhar",
    "rilharam": "rilhar",
    "rilharas": "rilhar",
    "rilharde": "rilhar",
    "rilhardes": "rilhar",
    "rilhare": "rilhar",
    "rilharei": "rilhar",
    "rilhareis": "rilhar",
    "rilharem": "rilhar",
    "rilharemos": "rilhar",
    "rilhares": "rilhar",
    "rilharia": "rilhar",
    "rilhariam": "rilhar",
    "rilharias": "rilhar",
    "rilharmo": "rilhar",
    "rilharmos": "rilhar",
    "rilhará": "rilhar",
    "rilharás": "rilhar",
    "rilharão": "rilhar",
    "rilharíamos": "rilhar",
    "rilharíeis": "rilhar",
    "rilhas": "rilhar",
    "rilhasse": "rilhar",
    "rilhassem": "rilhar",
    "rilhasses": "rilhar",
    "rilhaste": "rilhar",
    "rilhastes": "rilhar",
    "rilhava": "rilhar",
    "rilhavam": "rilhar",
    "rilhavas": "rilhar",
    "rilhe": "rilhar",
    "rilhei": "rilhar",
    "rilheira": "rilheiro",
    "rilheiras": "rilheiro",
    "rilheiros": "rilheiro",
    "rilheis": "rilhar",
    "rilhem": "rilhar",
    "rilhemo": "rilhar",
    "rilhemos": "rilhar",
    "rilhes": "rilhar",
    "rilho": "rilhar",
    "rilhotos": "rilhoto",
    "rilhou": "rilhar",
    "rilhá": "rilhar",
    "rilhámo": "rilhar",
    "rilhámos": "rilhar",
    "rilháramo": "rilhar",
    "rilháramos": "rilhar",
    "rilhárei": "rilhar",
    "rilháreis": "rilhar",
    "rilhásseis": "rilhar",
    "rilhássemos": "rilhar",
    "rilhávamo": "rilhar",
    "rilhávamos": "rilhar",
    "rilhávei": "rilhar",
    "rilháveis": "rilhar",
    "rima": "rimar",
    "rimada": "rimar",
    "rimadas": "rimar",
    "rimado": "rimar",
    "rimadora": "rimador",
    "rimadoras": "rimador",
    "rimadores": "rimador",
    "rimados": "rimar",
    "rimai": "rimar",
    "rimais": "rimar",
    "rimam": "rimar",
    "rimamo": "rimar",
    "rimamos": "rimar",
    "rimances": "rimance",
    "rimando": "rimar",
    "rimara": "rimar",
    "rimaram": "rimar",
    "rimaras": "rimar",
    "rimarde": "rimar",
    "rimardes": "rimar",
    "rimare": "rimar",
    "rimarei": "rimar",
    "rimareis": "rimar",
    "rimarem": "rimar",
    "rimaremos": "rimar",
    "rimares": "rimar",
    "rimaria": "rimar",
    "rimariam": "rimar",
    "rimarias": "rimar",
    "rimarmo": "rimar",
    "rimarmos": "rimar",
    "rimará": "rimar",
    "rimarás": "rimar",
    "rimarão": "rimar",
    "rimaríamos": "rimar",
    "rimaríeis": "rimar",
    "rimas": "rimar",
    "rimasse": "rimar",
    "rimassem": "rimar",
    "rimasses": "rimar",
    "rimaste": "rimar",
    "rimastes": "rimar",
    "rimava": "rimar",
    "rimavam": "rimar",
    "rimavas": "rimar",
    "rimbombâncias": "rimbombância",
    "rime": "rimar",
    "rimei": "rimar",
    "rimeis": "rimar",
    "rimem": "rimar",
    "rimemo": "rimar",
    "rimemos": "rimar",
    "rimes": "rimar",
    "rimiformes": "rimiforme",
    "rimo": "rir",
    "rimos": "rir",
    "rimosa": "rimoso",
    "rimosas": "rimoso",
    "rimosos": "rimoso",
    "rimou": "rimar",
    "rimá": "rimar",
    "rimámo": "rimar",
    "rimámos": "rimar",
    "rimáramo": "rimar",
    "rimáramos": "rimar",
    "rimárei": "rimar",
    "rimáreis": "rimar",
    "rimários": "rimário",
    "rimásseis": "rimar",
    "rimássemos": "rimar",
    "rimávamo": "rimar",
    "rimávamos": "rimar",
    "rimávei": "rimar",
    "rimáveis": "rimar",
    "rinalgias": "rinalgia",
    "rinantáceas": "rinantácea",
    "rincantos": "rincanto",
    "rincha": "rinchar",
    "rinchada": "rinchar",
    "rinchadas": "rinchar",
    "rinchado": "rinchar",
    "rinchados": "rinchar",
    "rinchai": "rinchar",
    "rinchais": "rinchar",
    "rincham": "rinchar",
    "rinchamo": "rinchar",
    "rinchamos": "rinchar",
    "rinchando": "rinchar",
    "rinchantes": "rinchante",
    "rinchara": "rinchar",
    "rincharam": "rinchar",
    "rincharas": "rinchar",
    "rinchardes": "rinchar",
    "rincharei": "rinchar",
    "rinchareis": "rinchar",
    "rincharem": "rinchar",
    "rincharemos": "rinchar",
    "rinchares": "rinchar",
    "rincharia": "rinchar",
    "rinchariam": "rinchar",
    "rincharias": "rinchar",
    "rincharmo": "rinchar",
    "rincharmos": "rinchar",
    "rinchará": "rinchar",
    "rincharás": "rinchar",
    "rincharão": "rinchar",
    "rincharíamos": "rinchar",
    "rincharíeis": "rinchar",
    "rinchas": "rinchar",
    "rinchasse": "rinchar",
    "rinchassem": "rinchar",
    "rinchasses": "rinchar",
    "rinchaste": "rinchar",
    "rinchastes": "rinchar",
    "rinchava": "rinchar",
    "rinchavam": "rinchar",
    "rinchavas": "rinchar",
    "rinchavelha": "rinchavelhar",
    "rinchavelhada": "rinchavelhar",
    "rinchavelhadas": "rinchavelhar",
    "rinchavelhado": "rinchavelhar",
    "rinchavelhados": "rinchavelhar",
    "rinchavelhai": "rinchavelhar",
    "rinchavelhais": "rinchavelhar",
    "rinchavelham": "rinchavelhar",
    "rinchavelhamo": "rinchavelhar",
    "rinchavelhamos": "rinchavelhar",
    "rinchavelhando": "rinchavelhar",
    "rinchavelhara": "rinchavelhar",
    "rinchavelharam": "rinchavelhar",
    "rinchavelharas": "rinchavelhar",
    "rinchavelhardes": "rinchavelhar",
    "rinchavelharei": "rinchavelhar",
    "rinchavelhareis": "rinchavelhar",
    "rinchavelharem": "rinchavelhar",
    "rinchavelharemos": "rinchavelhar",
    "rinchavelhares": "rinchavelhar",
    "rinchavelharia": "rinchavelhar",
    "rinchavelhariam": "rinchavelhar",
    "rinchavelharias": "rinchavelhar",
    "rinchavelharmo": "rinchavelhar",
    "rinchavelharmos": "rinchavelhar",
    "rinchavelhará": "rinchavelhar",
    "rinchavelharás": "rinchavelhar",
    "rinchavelharão": "rinchavelhar",
    "rinchavelharíamos": "rinchavelhar",
    "rinchavelharíeis": "rinchavelhar",
    "rinchavelhas": "rinchavelhar",
    "rinchavelhasse": "rinchavelhar",
    "rinchavelhassem": "rinchavelhar",
    "rinchavelhasses": "rinchavelhar",
    "rinchavelhaste": "rinchavelhar",
    "rinchavelhastes": "rinchavelhar",
    "rinchavelhava": "rinchavelhar",
    "rinchavelhavam": "rinchavelhar",
    "rinchavelhavas": "rinchavelhar",
    "rinchavelhe": "rinchavelhar",
    "rinchavelhei": "rinchavelhar",
    "rinchavelheis": "rinchavelhar",
    "rinchavelhem": "rinchavelhar",
    "rinchavelhemo": "rinchavelhar",
    "rinchavelhemos": "rinchavelhar",
    "rinchavelhes": "rinchavelhar",
    "rinchavelho": "rinchavelhar",
    "rinchavelhos": "rinchavelho",
    "rinchavelhou": "rinchavelhar",
    "rinchavelhámo": "rinchavelhar",
    "rinchavelhámos": "rinchavelhar",
    "rinchavelháramo": "rinchavelhar",
    "rinchavelháramos": "rinchavelhar",
    "rinchavelháreis": "rinchavelhar",
    "rinchavelhásseis": "rinchavelhar",
    "rinchavelhássemos": "rinchavelhar",
    "rinchavelhávamo": "rinchavelhar",
    "rinchavelhávamos": "rinchavelhar",
    "rinchavelháveis": "rinchavelhar",
    "rinche": "rinchar",
    "rinchei": "rinchar",
    "rincheis": "rinchar",
    "rinchem": "rinchar",
    "rinchemo": "rinchar",
    "rinchemos": "rinchar",
    "rinches": "rinchar",
    "rincho": "rinchar",
    "rinchona": "rinchão",
    "rinchonas": "rinchão",
    "rinchos": "rincho",
    "rinchou": "rinchar",
    "rinchámo": "rinchar",
    "rinchámos": "rinchar",
    "rincháramo": "rinchar",
    "rincháramos": "rinchar",
    "rincháreis": "rinchar",
    "rinchásseis": "rinchar",
    "rinchássemos": "rinchar",
    "rinchávamo": "rinchar",
    "rinchávamos": "rinchar",
    "rincháveis": "rinchar",
    "rinchões": "rinchão",
    "rincolheiras": "rincolheira",
    "rincões": "rincão",
    "rindo": "rir",
    "rinencefálica": "rinencefálico",
    "rinencefálicas": "rinencefálico",
    "rinencefálicos": "rinencefálico",
    "rinencéfalos": "rinencéfalo",
    "ringe": "ringir",
    "ringei": "ringer",
    "ringeis": "ringer",
    "ringem": "ringir",
    "ringemo": "ringer",
    "ringemos": "ringer",
    "ringendo": "ringer",
    "ringera": "ringer",
    "ringeram": "ringer",
    "ringeras": "ringer",
    "ringerde": "ringer",
    "ringerdes": "ringer",
    "ringere": "ringer",
    "ringerei": "ringer",
    "ringereis": "ringer",
    "ringerem": "ringer",
    "ringeremos": "ringer",
    "ringeres": "ringer",
    "ringeria": "ringer",
    "ringeriam": "ringer",
    "ringerias": "ringer",
    "ringermo": "ringer",
    "ringermos": "ringer",
    "ringerá": "ringer",
    "ringerás": "ringer",
    "ringerão": "ringer",
    "ringeríamos": "ringer",
    "ringeríeis": "ringer",
    "ringes": "ringir",
    "ringesse": "ringer",
    "ringessem": "ringer",
    "ringesses": "ringer",
    "ringeste": "ringer",
    "ringestes": "ringer",
    "ringeu": "ringer",
    "ringi": "ringir",
    "ringia": "ringir",
    "ringiam": "ringir",
    "ringias": "ringir",
    "ringida": "ringir",
    "ringidas": "ringir",
    "ringido": "ringir",
    "ringidos": "ringir",
    "ringimo": "ringir",
    "ringimos": "ringir",
    "ringindo": "ringir",
    "ringira": "ringir",
    "ringiram": "ringir",
    "ringiras": "ringir",
    "ringirde": "ringir",
    "ringirdes": "ringir",
    "ringire": "ringir",
    "ringirei": "ringir",
    "ringireis": "ringir",
    "ringirem": "ringir",
    "ringiremos": "ringir",
    "ringires": "ringir",
    "ringiria": "ringir",
    "ringiriam": "ringir",
    "ringirias": "ringir",
    "ringirmo": "ringir",
    "ringirmos": "ringir",
    "ringirá": "ringir",
    "ringirás": "ringir",
    "ringirão": "ringir",
    "ringiríamos": "ringir",
    "ringiríeis": "ringir",
    "ringis": "ringir",
    "ringisse": "ringir",
    "ringissem": "ringir",
    "ringisses": "ringir",
    "ringiste": "ringir",
    "ringistes": "ringir",
    "ringiu": "ringir",
    "rings": "ring",
    "ringues": "ringue",
    "ringê": "ringer",
    "ringêramo": "ringer",
    "ringêramos": "ringer",
    "ringêrei": "ringer",
    "ringêreis": "ringer",
    "ringêsseis": "ringer",
    "ringêssemos": "ringer",
    "ringíamo": "ringir",
    "ringíamos": "ringir",
    "ringíei": "ringir",
    "ringíeis": "ringir",
    "ringíramo": "ringir",
    "ringíramos": "ringir",
    "ringírei": "ringir",
    "ringíreis": "ringir",
    "ringísseis": "ringir",
    "ringíssemos": "ringir",
    "rinha": "rinhar",
    "rinhada": "rinhar",
    "rinhadas": "rinhar",
    "rinhado": "rinhar",
    "rinhados": "rinhar",
    "rinhai": "rinhar",
    "rinhais": "rinhar",
    "rinham": "rinhar",
    "rinhamo": "rinhar",
    "rinhamos": "rinhar",
    "rinhando": "rinhar",
    "rinhara": "rinhar",
    "rinharam": "rinhar",
    "rinharas": "rinhar",
    "rinhardes": "rinhar",
    "rinharei": "rinhar",
    "rinhareis": "rinhar",
    "rinharem": "rinhar",
    "rinharemos": "rinhar",
    "rinhares": "rinhar",
    "rinharia": "rinhar",
    "rinhariam": "rinhar",
    "rinharias": "rinhar",
    "rinharmo": "rinhar",
    "rinharmos": "rinhar",
    "rinhará": "rinhar",
    "rinharás": "rinhar",
    "rinharão": "rinhar",
    "rinharíamos": "rinhar",
    "rinharíeis": "rinhar",
    "rinhas": "rinhar",
    "rinhasse": "rinhar",
    "rinhassem": "rinhar",
    "rinhasses": "rinhar",
    "rinhaste": "rinhar",
    "rinhastes": "rinhar",
    "rinhava": "rinhar",
    "rinhavam": "rinhar",
    "rinhavas": "rinhar",
    "rinhe": "rinhar",
    "rinhei": "rinhar",
    "rinheis": "rinhar",
    "rinhem": "rinhar",
    "rinhemo": "rinhar",
    "rinhemos": "rinhar",
    "rinhes": "rinhar",
    "rinho": "rinhar",
    "rinhou": "rinhar",
    "rinhámo": "rinhar",
    "rinhámos": "rinhar",
    "rinháramo": "rinhar",
    "rinháramos": "rinhar",
    "rinháreis": "rinhar",
    "rinhásseis": "rinhar",
    "rinhássemos": "rinhar",
    "rinhávamo": "rinhar",
    "rinhávamos": "rinhar",
    "rinháveis": "rinhar",
    "rinismos": "rinismo",
    "rinites": "rinite",
    "rinja": "ringir",
    "rinjais": "ringir",
    "rinjam": "ringir",
    "rinjamo": "ringir",
    "rinjamos": "ringir",
    "rinjas": "ringir",
    "rinjo": "ringir",
    "rinobronquites": "rinobronquite",
    "rinobronquítica": "rinobronquítico",
    "rinobronquíticas": "rinobronquítico",
    "rinobronquíticos": "rinobronquítico",
    "rinocerontes": "rinoceronte",
    "rinocerotes": "rinocerote",
    "rinocerotídeos": "rinocerotídeo",
    "rinocerótidas": "rinocerótida",
    "rinocéfala": "rinocéfalo",
    "rinocéfalas": "rinocéfalo",
    "rinocéfalos": "rinocéfalo",
    "rinofaringes": "rinofaringe",
    "rinofaringites": "rinofaringite",
    "rinofaringítica": "rinofaringítico",
    "rinofaringíticas": "rinofaringítico",
    "rinofaringíticos": "rinofaringítico",
    "rinofaríngica": "rinofaríngico",
    "rinofaríngicas": "rinofaríngico",
    "rinofaríngicos": "rinofaríngico",
    "rinofonias": "rinofonia",
    "rinofónica": "rinofónico",
    "rinofónicas": "rinofónico",
    "rinofónicos": "rinofónico",
    "rinolalias": "rinolalia",
    "rinologias": "rinologia",
    "rinologistas": "rinologista",
    "rinolálica": "rinolálico",
    "rinolálicas": "rinolálico",
    "rinolálicos": "rinolálico",
    "rinológica": "rinológico",
    "rinológicas": "rinológico",
    "rinológicos": "rinológico",
    "rinopatias": "rinopatia",
    "rinoplastias": "rinoplastia",
    "rinoplástica": "rinoplástico",
    "rinoplásticas": "rinoplástico",
    "rinoplásticos": "rinoplástico",
    "rinopática": "rinopático",
    "rinopáticas": "rinopático",
    "rinopáticos": "rinopático",
    "rinorragias": "rinorragia",
    "rinorreias": "rinorreia",
    "rinorrágica": "rinorrágico",
    "rinorrágicas": "rinorrágico",
    "rinorrágicos": "rinorrágico",
    "rinoscopias": "rinoscopia",
    "rinoscópica": "rinoscópico",
    "rinoscópicas": "rinoscópico",
    "rinoscópicos": "rinoscópico",
    "rinoscópios": "rinoscópio",
    "rinotomias": "rinotomia",
    "rinotómica": "rinotómico",
    "rinotómicas": "rinotómico",
    "rinotómicos": "rinotómico",
    "rins": "rim",
    "rinálgica": "rinálgico",
    "rinálgicas": "rinálgico",
    "rinálgicos": "rinálgico",
    "rinítica": "rinítico",
    "riníticas": "rinítico",
    "riníticos": "rinítico",
    "rio": "rir",
    "riodonoresa": "riodonorês",
    "riodonoresas": "riodonorês",
    "riodonoreses": "riodonorês",
    "rionoresa": "rionorês",
    "rionoresas": "rionorês",
    "rionoreses": "rionorês",
    "rios": "rio",
    "ripa": "ripar",
    "ripada": "ripar",
    "ripadas": "ripar",
    "ripadeiras": "ripadeira",
    "ripado": "ripar",
    "ripadores": "ripador",
    "ripados": "ripar",
    "ripaduras": "ripadura",
    "ripagens": "ripagem",
    "ripai": "ripar",
    "ripais": "ripar",
    "ripam": "ripar",
    "ripamo": "ripar",
    "ripamos": "ripar",
    "ripance": "ripançar",
    "ripancei": "ripançar",
    "ripanceis": "ripançar",
    "ripancem": "ripançar",
    "ripancemo": "ripançar",
    "ripancemos": "ripançar",
    "ripances": "ripançar",
    "ripando": "ripar",
    "ripança": "ripançar",
    "ripançada": "ripançar",
    "ripançadas": "ripançar",
    "ripançado": "ripançar",
    "ripançados": "ripançar",
    "ripançai": "ripançar",
    "ripançais": "ripançar",
    "ripançam": "ripançar",
    "ripançamo": "ripançar",
    "ripançamos": "ripançar",
    "ripançando": "ripançar",
    "ripançara": "ripançar",
    "ripançaram": "ripançar",
    "ripançaras": "ripançar",
    "ripançarde": "ripançar",
    "ripançardes": "ripançar",
    "ripançare": "ripançar",
    "ripançarei": "ripançar",
    "ripançareis": "ripançar",
    "ripançarem": "ripançar",
    "ripançaremos": "ripançar",
    "ripançares": "ripançar",
    "ripançaria": "ripançar",
    "ripançariam": "ripançar",
    "ripançarias": "ripançar",
    "ripançarmo": "ripançar",
    "ripançarmos": "ripançar",
    "ripançará": "ripançar",
    "ripançarás": "ripançar",
    "ripançarão": "ripançar",
    "ripançaríamos": "ripançar",
    "ripançaríeis": "ripançar",
    "ripanças": "ripançar",
    "ripançasse": "ripançar",
    "ripançassem": "ripançar",
    "ripançasses": "ripançar",
    "ripançaste": "ripançar",
    "ripançastes": "ripançar",
    "ripançava": "ripançar",
    "ripançavam": "ripançar",
    "ripançavas": "ripançar",
    "ripanço": "ripançar",
    "ripanços": "ripanço",
    "ripançou": "ripançar",
    "ripançá": "ripançar",
    "ripançámo": "ripançar",
    "ripançámos": "ripançar",
    "ripançáramo": "ripançar",
    "ripançáramos": "ripançar",
    "ripançárei": "ripançar",
    "ripançáreis": "ripançar",
    "ripançásseis": "ripançar",
    "ripançássemos": "ripançar",
    "ripançávamo": "ripançar",
    "ripançávamos": "ripançar",
    "ripançávei": "ripançar",
    "ripançáveis": "ripançar",
    "ripara": "ripar",
    "riparam": "ripar",
    "riparas": "ripar",
    "riparde": "ripar",
    "ripardes": "ripar",
    "ripare": "ripar",
    "riparei": "ripar",
    "ripareis": "ripar",
    "riparem": "ripar",
    "riparemos": "ripar",
    "ripares": "ripar",
    "riparia": "ripar",
    "ripariam": "ripar",
    "riparias": "ripar",
    "riparmo": "ripar",
    "riparmos": "ripar",
    "ripará": "ripar",
    "riparás": "ripar",
    "riparão": "ripar",
    "riparíamos": "ripar",
    "riparíeis": "ripar",
    "ripas": "ripar",
    "ripasse": "ripar",
    "ripassem": "ripar",
    "ripasses": "ripar",
    "ripaste": "ripar",
    "ripastes": "ripar",
    "ripava": "ripar",
    "ripavam": "ripar",
    "ripavas": "ripar",
    "ripe": "ripar",
    "ripei": "ripar",
    "ripeiradas": "ripeirada",
    "ripeiras": "ripeira",
    "ripeiros": "ripeiro",
    "ripeis": "ripar",
    "ripem": "ripar",
    "ripemo": "ripar",
    "ripemos": "ripar",
    "ripes": "ripe",
    "ripiada": "ripiado",
    "ripiadas": "ripiado",
    "ripiados": "ripiado",
    "ripinha": "ripa",
    "ripinhas": "ripa",
    "ripita": "ripa",
    "ripitas": "ripa",
    "ripo": "ripar",
    "riposta": "ripostar",
    "ripostada": "ripostar",
    "ripostadas": "ripostar",
    "ripostado": "ripostar",
    "ripostados": "ripostar",
    "ripostai": "ripostar",
    "ripostais": "ripostar",
    "ripostam": "ripostar",
    "ripostamo": "ripostar",
    "ripostamos": "ripostar",
    "ripostando": "ripostar",
    "ripostara": "ripostar",
    "ripostaram": "ripostar",
    "ripostaras": "ripostar",
    "ripostardes": "ripostar",
    "ripostarei": "ripostar",
    "ripostareis": "ripostar",
    "ripostarem": "ripostar",
    "ripostaremos": "ripostar",
    "ripostares": "ripostar",
    "ripostaria": "ripostar",
    "ripostariam": "ripostar",
    "ripostarias": "ripostar",
    "ripostarmo": "ripostar",
    "ripostarmos": "ripostar",
    "ripostará": "ripostar",
    "ripostarás": "ripostar",
    "ripostarão": "ripostar",
    "ripostaríamos": "ripostar",
    "ripostaríeis": "ripostar",
    "ripostas": "ripostar",
    "ripostasse": "ripostar",
    "ripostassem": "ripostar",
    "ripostasses": "ripostar",
    "ripostaste": "ripostar",
    "ripostastes": "ripostar",
    "ripostava": "ripostar",
    "ripostavam": "ripostar",
    "ripostavas": "ripostar",
    "riposte": "ripostar",
    "ripostei": "ripostar",
    "riposteis": "ripostar",
    "ripostem": "ripostar",
    "ripostemo": "ripostar",
    "ripostemos": "ripostar",
    "ripostes": "ripostar",
    "riposto": "ripostar",
    "ripostou": "ripostar",
    "ripostámo": "ripostar",
    "ripostámos": "ripostar",
    "ripostáramo": "ripostar",
    "ripostáramos": "ripostar",
    "ripostáreis": "ripostar",
    "ripostásseis": "ripostar",
    "ripostássemos": "ripostar",
    "ripostávamo": "ripostar",
    "ripostávamos": "ripostar",
    "ripostáveis": "ripostar",
    "ripou": "ripar",
    "ripá": "ripar",
    "ripámo": "ripar",
    "ripámos": "ripar",
    "ripáramo": "ripar",
    "ripáramos": "ripar",
    "ripárei": "ripar",
    "ripáreis": "ripar",
    "ripária": "ripário",
    "ripárias": "ripário",
    "ripários": "ripário",
    "ripásseis": "ripar",
    "ripássemos": "ripar",
    "ripávamo": "ripar",
    "ripávamos": "ripar",
    "ripávei": "ripar",
    "ripáveis": "ripar",
    "ripícolas": "ripícola",
    "riquenha": "riquenho",
    "riquenhas": "riquenho",
    "riquenhos": "riquenho",
    "riquexós": "riquexó",
    "riquezas": "riqueza",
    "riquinha": "rico",
    "riquinhas": "rico",
    "riquinho": "rico",
    "riquinhos": "rico",
    "riquita": "rico",
    "riquitas": "rico",
    "riquito": "rico",
    "riquitos": "rico",
    "riquíssima": "rico",
    "riquíssimas": "rico",
    "riquíssimo": "rico",
    "riquíssimos": "rico",
    "rira": "rir",
    "riram": "rir",
    "riras": "rir",
    "rirdes": "rir",
    "rirei": "rir",
    "rireis": "rir",
    "rirem": "rir",
    "riremos": "rir",
    "rires": "rir",
    "riria": "rir",
    "ririam": "rir",
    "ririas": "rir",
    "rirmo": "rir",
    "rirmos": "rir",
    "rirá": "rir",
    "rirás": "rir",
    "rirão": "rir",
    "riríamos": "rir",
    "riríeis": "rir",
    "ris": "rir",
    "risadas": "risada",
    "risadinha": "risada",
    "risadinhas": "risada",
    "risadita": "risada",
    "risaditas": "risada",
    "risbordos": "risbordo",
    "risca": "riscar",
    "riscada": "riscar",
    "riscadas": "riscar",
    "riscadeira": "riscador",
    "riscadeiras": "riscador",
    "riscadilhos": "riscadilho",
    "riscadinha": "riscado",
    "riscadinhas": "riscado",
    "riscadinho": "riscado",
    "riscadinhos": "riscado",
    "riscadita": "riscado",
    "riscaditas": "riscado",
    "riscadito": "riscado",
    "riscaditos": "riscado",
    "riscado": "riscar",
    "riscadora": "riscador",
    "riscadoras": "riscador",
    "riscadores": "riscador",
    "riscados": "riscar",
    "riscaduras": "riscadura",
    "riscadíssima": "riscado",
    "riscadíssimas": "riscado",
    "riscadíssimo": "riscado",
    "riscadíssimos": "riscado",
    "riscais": "riscar",
    "riscam": "riscar",
    "riscamo": "riscar",
    "riscamos": "riscar",
    "riscando": "riscar",
    "riscara": "riscar",
    "riscaram": "riscar",
    "riscaras": "riscar",
    "riscardes": "riscar",
    "riscarei": "riscar",
    "riscareis": "riscar",
    "riscarem": "riscar",
    "riscaremos": "riscar",
    "riscares": "riscar",
    "riscaria": "riscar",
    "riscariam": "riscar",
    "riscarias": "riscar",
    "riscarmo": "riscar",
    "riscarmos": "riscar",
    "riscará": "riscar",
    "riscarás": "riscar",
    "riscarão": "riscar",
    "riscaríamos": "riscar",
    "riscaríeis": "riscar",
    "riscas": "riscar",
    "riscasse": "riscar",
    "riscassem": "riscar",
    "riscasses": "riscar",
    "riscaste": "riscar",
    "riscastes": "riscar",
    "riscava": "riscar",
    "riscavam": "riscar",
    "riscavas": "riscar",
    "risco": "riscar",
    "riscos": "risco",
    "riscotes": "riscote",
    "riscou": "riscar",
    "riscámo": "riscar",
    "riscámos": "riscar",
    "riscáramo": "riscar",
    "riscáramos": "riscar",
    "riscáreis": "riscar",
    "riscásseis": "riscar",
    "riscássemos": "riscar",
    "riscávamo": "riscar",
    "riscávamos": "riscar",
    "riscáveis": "riscável",
    "risibilidades": "risibilidade",
    "risinho": "riso",
    "risinhos": "riso",
    "risito": "riso",
    "risitos": "riso",
    "risonha": "risonho",
    "risonhas": "risonho",
    "risonhazinha": "risonho",
    "risonhazinhas": "risonho",
    "risonhazita": "risonho",
    "risonhazitas": "risonho",
    "risonhos": "risonho",
    "risonhozinho": "risonho",
    "risonhozinhos": "risonho",
    "risonhozito": "risonho",
    "risonhozitos": "risonho",
    "risos": "riso",
    "risota": "risote",
    "risotas": "risote",
    "risotes": "risote",
    "risotos": "risoto",
    "rispidazinha": "ríspido",
    "rispidazinhas": "ríspido",
    "rispidazita": "ríspido",
    "rispidazitas": "ríspido",
    "rispidezas": "rispideza",
    "rispidozinho": "ríspido",
    "rispidozinhos": "ríspido",
    "rispidozito": "ríspido",
    "rispidozitos": "ríspido",
    "rispidíssima": "ríspido",
    "rispidíssimas": "ríspido",
    "rispidíssimo": "ríspido",
    "rispidíssimos": "ríspido",
    "risque": "riscar",
    "risquei": "riscar",
    "risqueis": "riscar",
    "risquem": "riscar",
    "risquemos": "riscar",
    "risques": "riscar",
    "risquinha": "risca",
    "risquinhas": "risca",
    "risquinho": "risco",
    "risquinhos": "risco",
    "risquita": "risca",
    "risquitas": "risca",
    "risquito": "risco",
    "risquitos": "risco",
    "risse": "rir",
    "rissem": "rir",
    "risses": "rir",
    "rissóis": "rissol",
    "riste": "rir",
    "ristes": "riste",
    "risíveis": "risível",
    "risórios": "risório",
    "ritidomas": "ritidoma",
    "ritma": "ritmar",
    "ritmada": "ritmar",
    "ritmadas": "ritmar",
    "ritmadazinha": "ritmado",
    "ritmadazinhas": "ritmado",
    "ritmadazita": "ritmado",
    "ritmadazitas": "ritmado",
    "ritmadinha": "ritmado",
    "ritmadinhas": "ritmado",
    "ritmadinho": "ritmado",
    "ritmadinhos": "ritmado",
    "ritmadita": "ritmado",
    "ritmaditas": "ritmado",
    "ritmadito": "ritmado",
    "ritmaditos": "ritmado",
    "ritmado": "ritmar",
    "ritmados": "ritmar",
    "ritmadozinho": "ritmado",
    "ritmadozinhos": "ritmado",
    "ritmadozito": "ritmado",
    "ritmadozitos": "ritmado",
    "ritmadíssima": "ritmado",
    "ritmadíssimas": "ritmado",
    "ritmadíssimo": "ritmado",
    "ritmadíssimos": "ritmado",
    "ritmai": "ritmar",
    "ritmais": "ritmar",
    "ritmam": "ritmar",
    "ritmamo": "ritmar",
    "ritmamos": "ritmar",
    "ritmando": "ritmar",
    "ritmara": "ritmar",
    "ritmaram": "ritmar",
    "ritmaras": "ritmar",
    "ritmarde": "ritmar",
    "ritmardes": "ritmar",
    "ritmare": "ritmar",
    "ritmarei": "ritmar",
    "ritmareis": "ritmar",
    "ritmarem": "ritmar",
    "ritmaremos": "ritmar",
    "ritmares": "ritmar",
    "ritmaria": "ritmar",
    "ritmariam": "ritmar",
    "ritmarias": "ritmar",
    "ritmarmo": "ritmar",
    "ritmarmos": "ritmar",
    "ritmará": "ritmar",
    "ritmarás": "ritmar",
    "ritmarão": "ritmar",
    "ritmaríamos": "ritmar",
    "ritmaríeis": "ritmar",
    "ritmas": "ritmar",
    "ritmasse": "ritmar",
    "ritmassem": "ritmar",
    "ritmasses": "ritmar",
    "ritmaste": "ritmar",
    "ritmastes": "ritmar",
    "ritmava": "ritmar",
    "ritmavam": "ritmar",
    "ritmavas": "ritmar",
    "ritme": "ritmar",
    "ritmei": "ritmar",
    "ritmeis": "ritmar",
    "ritmem": "ritmar",
    "ritmemo": "ritmar",
    "ritmemos": "ritmar",
    "ritmes": "ritmar",
    "ritmo": "ritmar",
    "ritmopeias": "ritmopeia",
    "ritmos": "ritmo",
    "ritmou": "ritmar",
    "ritmá": "ritmar",
    "ritmámo": "ritmar",
    "ritmámos": "ritmar",
    "ritmáramo": "ritmar",
    "ritmáramos": "ritmar",
    "ritmárei": "ritmar",
    "ritmáreis": "ritmar",
    "ritmásseis": "ritmar",
    "ritmássemos": "ritmar",
    "ritmávamo": "ritmar",
    "ritmávamos": "ritmar",
    "ritmávei": "ritmar",
    "ritmáveis": "ritmar",
    "ritornelos": "ritornelo",
    "ritos": "rito",
    "rituais": "ritual",
    "ritualismos": "ritualismo",
    "ritualistas": "ritualista",
    "ritualizações": "ritualização",
    "ritões": "ritão",
    "riu": "rir",
    "rivais": "rival",
    "rivalidades": "rivalidade",
    "rivaliza": "rivalizar",
    "rivalizada": "rivalizar",
    "rivalizadas": "rivalizar",
    "rivalizado": "rivalizar",
    "rivalizados": "rivalizar",
    "rivalizai": "rivalizar",
    "rivalizais": "rivalizar",
    "rivalizam": "rivalizar",
    "rivalizamo": "rivalizar",
    "rivalizamos": "rivalizar",
    "rivalizando": "rivalizar",
    "rivalizara": "rivalizar",
    "rivalizaram": "rivalizar",
    "rivalizaras": "rivalizar",
    "rivalizardes": "rivalizar",
    "rivalizarei": "rivalizar",
    "rivalizareis": "rivalizar",
    "rivalizarem": "rivalizar",
    "rivalizaremos": "rivalizar",
    "rivalizares": "rivalizar",
    "rivalizaria": "rivalizar",
    "rivalizariam": "rivalizar",
    "rivalizarias": "rivalizar",
    "rivalizarmo": "rivalizar",
    "rivalizarmos": "rivalizar",
    "rivalizará": "rivalizar",
    "rivalizarás": "rivalizar",
    "rivalizarão": "rivalizar",
    "rivalizaríamos": "rivalizar",
    "rivalizaríeis": "rivalizar",
    "rivalizas": "rivalizar",
    "rivalizasse": "rivalizar",
    "rivalizassem": "rivalizar",
    "rivalizasses": "rivalizar",
    "rivalizaste": "rivalizar",
    "rivalizastes": "rivalizar",
    "rivalizava": "rivalizar",
    "rivalizavam": "rivalizar",
    "rivalizavas": "rivalizar",
    "rivalize": "rivalizar",
    "rivalizei": "rivalizar",
    "rivalizeis": "rivalizar",
    "rivalizem": "rivalizar",
    "rivalizemo": "rivalizar",
    "rivalizemos": "rivalizar",
    "rivalizes": "rivalizar",
    "rivalizo": "rivalizar",
    "rivalizou": "rivalizar",
    "rivalizámo": "rivalizar",
    "rivalizámos": "rivalizar",
    "rivalizáramo": "rivalizar",
    "rivalizáramos": "rivalizar",
    "rivalizáreis": "rivalizar",
    "rivalizásseis": "rivalizar",
    "rivalizássemos": "rivalizar",
    "rivalizávamo": "rivalizar",
    "rivalizávamos": "rivalizar",
    "rivalizáveis": "rivalizável",
    "rixa": "rixar",
    "rixada": "rixar",
    "rixadas": "rixar",
    "rixado": "rixar",
    "rixadora": "rixador",
    "rixadoras": "rixador",
    "rixadores": "rixador",
    "rixados": "rixar",
    "rixai": "rixar",
    "rixais": "rixar",
    "rixam": "rixar",
    "rixamo": "rixar",
    "rixamos": "rixar",
    "rixando": "rixar",
    "rixara": "rixar",
    "rixaram": "rixar",
    "rixaras": "rixar",
    "rixardes": "rixar",
    "rixarei": "rixar",
    "rixareis": "rixar",
    "rixarem": "rixar",
    "rixaremos": "rixar",
    "rixares": "rixar",
    "rixaria": "rixar",
    "rixariam": "rixar",
    "rixarias": "rixar",
    "rixarmo": "rixar",
    "rixarmos": "rixar",
    "rixará": "rixar",
    "rixarás": "rixar",
    "rixarão": "rixar",
    "rixaríamos": "rixar",
    "rixaríeis": "rixar",
    "rixas": "rixar",
    "rixasse": "rixar",
    "rixassem": "rixar",
    "rixasses": "rixar",
    "rixaste": "rixar",
    "rixastes": "rixar",
    "rixava": "rixar",
    "rixavam": "rixar",
    "rixavas": "rixar",
    "rixe": "rixar",
    "rixei": "rixar",
    "rixeis": "rixar",
    "rixem": "rixar",
    "rixemo": "rixar",
    "rixemos": "rixar",
    "rixes": "rixar",
    "rixo": "rixar",
    "rixosa": "rixoso",
    "rixosas": "rixoso",
    "rixosos": "rixoso",
    "rixou": "rixar",
    "rixámo": "rixar",
    "rixámos": "rixar",
    "rixáramo": "rixar",
    "rixáramos": "rixar",
    "rixáreis": "rixar",
    "rixásseis": "rixar",
    "rixássemos": "rixar",
    "rixávamo": "rixar",
    "rixávamos": "rixar",
    "rixáveis": "rixar",
    "riza": "rizar",
    "rizada": "rizar",
    "rizadas": "rizar",
    "rizado": "rizar",
    "rizados": "rizar",
    "rizaduras": "rizadura",
    "rizai": "rizar",
    "rizais": "rizar",
    "rizam": "rizar",
    "rizamo": "rizar",
    "rizamos": "rizar",
    "rizando": "rizar",
    "rizanta": "rizanto",
    "rizantas": "rizanto",
    "rizantos": "rizanto",
    "rizara": "rizar",
    "rizaram": "rizar",
    "rizaras": "rizar",
    "rizarde": "rizar",
    "rizardes": "rizar",
    "rizare": "rizar",
    "rizarei": "rizar",
    "rizareis": "rizar",
    "rizarem": "rizar",
    "rizaremos": "rizar",
    "rizares": "rizar",
    "rizaria": "rizar",
    "rizariam": "rizar",
    "rizarias": "rizar",
    "rizarmo": "rizar",
    "rizarmos": "rizar",
    "rizará": "rizar",
    "rizarás": "rizar",
    "rizarão": "rizar",
    "rizaríamos": "rizar",
    "rizaríeis": "rizar",
    "rizas": "rizar",
    "rizasse": "rizar",
    "rizassem": "rizar",
    "rizasses": "rizar",
    "rizaste": "rizar",
    "rizastes": "rizar",
    "rizava": "rizar",
    "rizavam": "rizar",
    "rizavas": "rizar",
    "rize": "rizar",
    "rizei": "rizar",
    "rizeis": "rizar",
    "rizem": "rizar",
    "rizemo": "rizar",
    "rizemos": "rizar",
    "rizes": "rizar",
    "rizicultora": "rizicultor",
    "rizicultoras": "rizicultor",
    "rizicultores": "rizicultor",
    "riziculturas": "rizicultura",
    "rizinas": "rizina",
    "rizo": "rizar",
    "rizoboláceas": "rizobolácea",
    "rizocarpa": "rizocarpo",
    "rizocarpas": "rizocarpo",
    "rizocarpos": "rizocarpo",
    "rizocárpia": "rizocárpio",
    "rizocárpias": "rizocárpio",
    "rizocárpica": "rizocárpico",
    "rizocárpicas": "rizocárpico",
    "rizocárpicos": "rizocárpico",
    "rizocárpios": "rizocárpio",
    "rizocéfala": "rizocéfalo",
    "rizocéfalas": "rizocéfalo",
    "rizocéfalos": "rizocéfalo",
    "rizofagias": "rizofagia",
    "rizofila": "rizofilo",
    "rizofilas": "rizofilo",
    "rizofilos": "rizofilo",
    "rizoflagelada": "rizoflagelado",
    "rizoflageladas": "rizoflagelado",
    "rizoflagelados": "rizoflagelado",
    "rizoforáceas": "rizoforácea",
    "rizomas": "rizoma",
    "rizomatosa": "rizomatoso",
    "rizomatosas": "rizomatoso",
    "rizomatosos": "rizomatoso",
    "rizomorfa": "rizomorfo",
    "rizomorfas": "rizomorfo",
    "rizomorfos": "rizomorfo",
    "rizosperma": "rizospermo",
    "rizospermas": "rizospermo",
    "rizospermos": "rizospermo",
    "rizostomídeos": "rizostomídeo",
    "rizostómidas": "rizostómida",
    "rizotaxias": "rizotaxia",
    "rizotomias": "rizotomia",
    "rizotos": "rizoto",
    "rizotónica": "rizotónico",
    "rizotónicas": "rizotónico",
    "rizotónicos": "rizotónico",
    "rizou": "rizar",
    "rizá": "rizar",
    "rizámo": "rizar",
    "rizámos": "rizar",
    "rizáramo": "rizar",
    "rizáramos": "rizar",
    "rizárei": "rizar",
    "rizáreis": "rizar",
    "rizásseis": "rizar",
    "rizássemos": "rizar",
    "rizávamo": "rizar",
    "rizávamos": "rizar",
    "rizávei": "rizar",
    "rizáveis": "rizar",
    "rizântea": "rizânteo",
    "rizânteas": "rizânteo",
    "rizânteos": "rizânteo",
    "rizófaga": "rizófago",
    "rizófagas": "rizófago",
    "rizófagos": "rizófago",
    "rizófila": "rizófilo",
    "rizófilas": "rizófilo",
    "rizófilos": "rizófilo",
    "rizófora": "rizóforo",
    "rizóforas": "rizóforo",
    "rizóforos": "rizóforo",
    "rizóides": "rizóide",
    "rizópodes": "rizópode",
    "rizóstoma": "rizóstomo",
    "rizóstomas": "rizóstomo",
    "rizóstomos": "rizóstomo",
    "riça": "riço",
    "riçada": "riçar",
    "riçadas": "riçar",
    "riçado": "riçar",
    "riçados": "riçar",
    "riçai": "riçar",
    "riçais": "riçar",
    "riçam": "riçar",
    "riçamo": "riçar",
    "riçamos": "riçar",
    "riçando": "riçar",
    "riçara": "riçar",
    "riçaram": "riçar",
    "riçaras": "riçar",
    "riçarde": "riçar",
    "riçardes": "riçar",
    "riçare": "riçar",
    "riçarei": "riçar",
    "riçareis": "riçar",
    "riçarem": "riçar",
    "riçaremos": "riçar",
    "riçares": "riçar",
    "riçaria": "riçar",
    "riçariam": "riçar",
    "riçarias": "riçar",
    "riçarmo": "riçar",
    "riçarmos": "riçar",
    "riçará": "riçar",
    "riçarás": "riçar",
    "riçarão": "riçar",
    "riçaríamos": "riçar",
    "riçaríeis": "riçar",
    "riças": "riço",
    "riçasse": "riçar",
    "riçassem": "riçar",
    "riçasses": "riçar",
    "riçaste": "riçar",
    "riçastes": "riçar",
    "riçava": "riçar",
    "riçavam": "riçar",
    "riçavas": "riçar",
    "riço": "riçar",
    "riços": "riço",
    "riçou": "riçar",
    "riçá": "riçar",
    "riçámo": "riçar",
    "riçámos": "riçar",
    "riçáramo": "riçar",
    "riçáramos": "riçar",
    "riçárei": "riçar",
    "riçáreis": "riçar",
    "riçásseis": "riçar",
    "riçássemos": "riçar",
    "riçávamo": "riçar",
    "riçávamos": "riçar",
    "riçávei": "riçar",
    "riçáveis": "riçar",
    "riçóis": "riçol",
    "riólitos": "riólito",
    "roa": "roer",
    "roais": "roer",
    "roam": "roer",
    "roamo": "roer",
    "roamos": "roer",
    "roas": "roer",
    "roazes": "roaz",
    "robaleiras": "robaleira",
    "robaletes": "robalete",
    "robalinhos": "robalinho",
    "robalos": "robalo",
    "roberta": "roberto",
    "robertas": "roberto",
    "robertos": "roberto",
    "robes": "robe",
    "robledos": "robledo",
    "robles": "roble",
    "robora": "roborar",
    "roborada": "roborar",
    "roboradas": "roborar",
    "roborado": "roborar",
    "roborados": "roborar",
    "roborai": "roborar",
    "roborais": "roborar",
    "roboram": "roborar",
    "roboramo": "roborar",
    "roboramos": "roborar",
    "roborando": "roborar",
    "roborantes": "roborante",
    "roborara": "roborar",
    "roboraram": "roborar",
    "roboraras": "roborar",
    "roborarde": "roborar",
    "roborardes": "roborar",
    "roborare": "roborar",
    "roborarei": "roborar",
    "roborareis": "roborar",
    "roborarem": "roborar",
    "roboraremos": "roborar",
    "roborares": "roborar",
    "roboraria": "roborar",
    "roborariam": "roborar",
    "roborarias": "roborar",
    "roborarmo": "roborar",
    "roborarmos": "roborar",
    "roborará": "roborar",
    "roborarás": "roborar",
    "roborarão": "roborar",
    "roboraríamos": "roborar",
    "roboraríeis": "roborar",
    "roboras": "roborar",
    "roborasse": "roborar",
    "roborassem": "roborar",
    "roborasses": "roborar",
    "roboraste": "roborar",
    "roborastes": "roborar",
    "roborativa": "roborativo",
    "roborativas": "roborativo",
    "roborativos": "roborativo",
    "roborava": "roborar",
    "roboravam": "roborar",
    "roboravas": "roborar",
    "roborações": "roboração",
    "robore": "roborar",
    "roboreda": "roboredo",
    "roboredas": "roboredo",
    "roboredos": "roboredo",
    "roborei": "roborar",
    "roboreis": "roborar",
    "roborem": "roborar",
    "roboremo": "roborar",
    "roboremos": "roborar",
    "robores": "roborar",
    "roboriza": "roborizar",
    "roborizada": "roborizar",
    "roborizadas": "roborizar",
    "roborizado": "roborizar",
    "roborizados": "roborizar",
    "roborizai": "roborizar",
    "roborizais": "roborizar",
    "roborizam": "roborizar",
    "roborizamo": "roborizar",
    "roborizamos": "roborizar",
    "roborizando": "roborizar",
    "roborizara": "roborizar",
    "roborizaram": "roborizar",
    "roborizaras": "roborizar",
    "roborizarde": "roborizar",
    "roborizardes": "roborizar",
    "roborizare": "roborizar",
    "roborizarei": "roborizar",
    "roborizareis": "roborizar",
    "roborizarem": "roborizar",
    "roborizaremos": "roborizar",
    "roborizares": "roborizar",
    "roborizaria": "roborizar",
    "roborizariam": "roborizar",
    "roborizarias": "roborizar",
    "roborizarmo": "roborizar",
    "roborizarmos": "roborizar",
    "roborizará": "roborizar",
    "roborizarás": "roborizar",
    "roborizarão": "roborizar",
    "roborizaríamos": "roborizar",
    "roborizaríeis": "roborizar",
    "roborizas": "roborizar",
    "roborizasse": "roborizar",
    "roborizassem": "roborizar",
    "roborizasses": "roborizar",
    "roborizaste": "roborizar",
    "roborizastes": "roborizar",
    "roborizava": "roborizar",
    "roborizavam": "roborizar",
    "roborizavas": "roborizar",
    "roborize": "roborizar",
    "roborizei": "roborizar",
    "roborizeis": "roborizar",
    "roborizem": "roborizar",
    "roborizemo": "roborizar",
    "roborizemos": "roborizar",
    "roborizes": "roborizar",
    "roborizo": "roborizar",
    "roborizou": "roborizar",
    "roborizá": "roborizar",
    "roborizámo": "roborizar",
    "roborizámos": "roborizar",
    "roborizáramo": "roborizar",
    "roborizáramos": "roborizar",
    "roborizárei": "roborizar",
    "roborizáreis": "roborizar",
    "roborizásseis": "roborizar",
    "roborizássemos": "roborizar",
    "roborizávamo": "roborizar",
    "roborizávamos": "roborizar",
    "roborizávei": "roborizar",
    "roborizáveis": "roborizar",
    "roboro": "roborar",
    "roborou": "roborar",
    "roborá": "roborar",
    "roborámo": "roborar",
    "roborámos": "roborar",
    "roboráramo": "roborar",
    "roboráramos": "roborar",
    "roborárei": "roborar",
    "roboráreis": "roborar",
    "roborásseis": "roborar",
    "roborássemos": "roborar",
    "roborávamo": "roborar",
    "roborávamos": "roborar",
    "roborávei": "roborar",
    "roboráveis": "roborar",
    "robotizada": "robotizado",
    "robotizadas": "robotizado",
    "robotizados": "robotizado",
    "robotizações": "robotização",
    "robots": "robot",
    "robusta": "robusto",
    "robustas": "robusto",
    "robustece": "robustecer",
    "robustecedora": "robustecedor",
    "robustecedoras": "robustecedor",
    "robustecedores": "robustecedor",
    "robustecei": "robustecer",
    "robusteceis": "robustecer",
    "robustecem": "robustecer",
    "robustecemo": "robustecer",
    "robustecemos": "robustecer",
    "robustecendo": "robustecer",
    "robustecera": "robustecer",
    "robusteceram": "robustecer",
    "robusteceras": "robustecer",
    "robustecerde": "robustecer",
    "robustecerdes": "robustecer",
    "robustecere": "robustecer",
    "robustecerei": "robustecer",
    "robustecereis": "robustecer",
    "robustecerem": "robustecer",
    "robusteceremos": "robustecer",
    "robusteceres": "robustecer",
    "robusteceria": "robustecer",
    "robusteceriam": "robustecer",
    "robustecerias": "robustecer",
    "robustecermo": "robustecer",
    "robustecermos": "robustecer",
    "robustecerá": "robustecer",
    "robustecerás": "robustecer",
    "robustecerão": "robustecer",
    "robusteceríamos": "robustecer",
    "robusteceríeis": "robustecer",
    "robusteces": "robustecer",
    "robustecesse": "robustecer",
    "robustecessem": "robustecer",
    "robustecesses": "robustecer",
    "robusteceste": "robustecer",
    "robustecestes": "robustecer",
    "robusteceu": "robustecer",
    "robusteci": "robustecer",
    "robustecia": "robustecer",
    "robusteciam": "robustecer",
    "robustecias": "robustecer",
    "robustecida": "robustecido",
    "robustecidas": "robustecido",
    "robustecido": "robustecer",
    "robustecidos": "robustecido",
    "robustecimentos": "robustecimento",
    "robustecê": "robustecer",
    "robustecêramo": "robustecer",
    "robustecêramos": "robustecer",
    "robustecêrei": "robustecer",
    "robustecêreis": "robustecer",
    "robustecêsseis": "robustecer",
    "robustecêssemos": "robustecer",
    "robustecíamo": "robustecer",
    "robustecíamos": "robustecer",
    "robustecíei": "robustecer",
    "robustecíeis": "robustecer",
    "robustezas": "robusteza",
    "robusteça": "robustecer",
    "robusteçais": "robustecer",
    "robusteçam": "robustecer",
    "robusteçamo": "robustecer",
    "robusteçamos": "robustecer",
    "robusteças": "robustecer",
    "robusteço": "robustecer",
    "robustos": "robusto",
    "robustíssima": "robusto",
    "robustíssimas": "robusto",
    "robustíssimo": "robusto",
    "robustíssimos": "robusto",
    "robótica": "robótico",
    "robóticas": "robótico",
    "robóticos": "robótico",
    "robôs": "robô",
    "roca": "rocar",
    "rocada": "rocar",
    "rocadas": "rocar",
    "rocado": "rocar",
    "rocados": "rocar",
    "rocais": "rocar",
    "rocalhas": "rocalha",
    "rocam": "rocar",
    "rocamboles": "rocambole",
    "rocambolesca": "rocambolesco",
    "rocambolescas": "rocambolesco",
    "rocambolescos": "rocambolesco",
    "rocambolismos": "rocambolismo",
    "rocamo": "rocar",
    "rocamos": "rocar",
    "rocando": "rocar",
    "rocara": "rocar",
    "rocaram": "rocar",
    "rocaras": "rocar",
    "rocardes": "rocar",
    "rocarei": "rocar",
    "rocareis": "rocar",
    "rocarem": "rocar",
    "rocaremos": "rocar",
    "rocares": "rocar",
    "rocaria": "rocar",
    "rocariam": "rocar",
    "rocarias": "rocar",
    "rocarmo": "rocar",
    "rocarmos": "rocar",
    "rocará": "rocar",
    "rocarás": "rocar",
    "rocarão": "rocar",
    "rocaríamos": "rocar",
    "rocaríeis": "rocar",
    "rocas": "rocar",
    "rocasse": "rocar",
    "rocassem": "rocar",
    "rocasses": "rocar",
    "rocaste": "rocar",
    "rocastes": "rocar",
    "rocava": "rocar",
    "rocavam": "rocar",
    "rocavas": "rocar",
    "rocazes": "rocaz",
    "roce": "roçar",
    "rocega": "rocegar",
    "rocegada": "rocegar",
    "rocegadas": "rocegar",
    "rocegado": "rocegar",
    "rocegados": "rocegar",
    "rocegai": "rocegar",
    "rocegais": "rocegar",
    "rocegam": "rocegar",
    "rocegamo": "rocegar",
    "rocegamos": "rocegar",
    "rocegando": "rocegar",
    "rocegara": "rocegar",
    "rocegaram": "rocegar",
    "rocegaras": "rocegar",
    "rocegarde": "rocegar",
    "rocegardes": "rocegar",
    "rocegare": "rocegar",
    "rocegarei": "rocegar",
    "rocegareis": "rocegar",
    "rocegarem": "rocegar",
    "rocegaremos": "rocegar",
    "rocegares": "rocegar",
    "rocegaria": "rocegar",
    "rocegariam": "rocegar",
    "rocegarias": "rocegar",
    "rocegarmo": "rocegar",
    "rocegarmos": "rocegar",
    "rocegará": "rocegar",
    "rocegarás": "rocegar",
    "rocegarão": "rocegar",
    "rocegaríamos": "rocegar",
    "rocegaríeis": "rocegar",
    "rocegas": "rocegar",
    "rocegasse": "rocegar",
    "rocegassem": "rocegar",
    "rocegasses": "rocegar",
    "rocegaste": "rocegar",
    "rocegastes": "rocegar",
    "rocegava": "rocegar",
    "rocegavam": "rocegar",
    "rocegavas": "rocegar",
    "rocego": "rocegar",
    "rocegou": "rocegar",
    "rocegue": "rocegar",
    "roceguei": "rocegar",
    "rocegueis": "rocegar",
    "roceguem": "rocegar",
    "roceguemo": "rocegar",
    "roceguemos": "rocegar",
    "rocegues": "rocegar",
    "rocegá": "rocegar",
    "rocegámo": "rocegar",
    "rocegámos": "rocegar",
    "rocegáramo": "rocegar",
    "rocegáramos": "rocegar",
    "rocegárei": "rocegar",
    "rocegáreis": "rocegar",
    "rocegásseis": "rocegar",
    "rocegássemos": "rocegar",
    "rocegávamo": "rocegar",
    "rocegávamos": "rocegar",
    "rocegávei": "rocegar",
    "rocegáveis": "rocegar",
    "rocei": "roçar",
    "roceira": "roceiro",
    "roceiras": "roceiro",
    "roceiros": "roceiro",
    "roceis": "roçar",
    "rocem": "roçar",
    "rocemo": "roçar",
    "rocemos": "roçar",
    "roces": "roçar",
    "rochas": "rocha",
    "rochazes": "rochaz",
    "rochedos": "rochedo",
    "rochosa": "rochoso",
    "rochosas": "rochoso",
    "rochosos": "rochoso",
    "rocia": "rociar",
    "rociada": "rociar",
    "rociadas": "rociar",
    "rociado": "rociar",
    "rociados": "rociar",
    "rociai": "rociar",
    "rociais": "rociar",
    "rociam": "rociar",
    "rociamo": "rociar",
    "rociamos": "rociar",
    "rociando": "rociar",
    "rociara": "rociar",
    "rociaram": "rociar",
    "rociaras": "rociar",
    "rociarde": "rociar",
    "rociardes": "rociar",
    "rociare": "rociar",
    "rociarei": "rociar",
    "rociareis": "rociar",
    "rociarem": "rociar",
    "rociaremos": "rociar",
    "rociares": "rociar",
    "rociaria": "rociar",
    "rociariam": "rociar",
    "rociarias": "rociar",
    "rociarmo": "rociar",
    "rociarmos": "rociar",
    "rociará": "rociar",
    "rociarás": "rociar",
    "rociarão": "rociar",
    "rociaríamos": "rociar",
    "rociaríeis": "rociar",
    "rocias": "rociar",
    "rociasse": "rociar",
    "rociassem": "rociar",
    "rociasses": "rociar",
    "rociaste": "rociar",
    "rociastes": "rociar",
    "rociava": "rociar",
    "rociavam": "rociar",
    "rociavas": "rociar",
    "rocie": "rociar",
    "rociei": "rociar",
    "rocieis": "rociar",
    "rociem": "rociar",
    "rociemo": "rociar",
    "rociemos": "rociar",
    "rocies": "rociar",
    "rocinantes": "rocinante",
    "rocins": "rocim",
    "rocio": "rociar",
    "rocios": "rocio",
    "rociosa": "rocioso",
    "rociosas": "rocioso",
    "rociosos": "rocioso",
    "rociou": "rociar",
    "rociá": "rociar",
    "rociámo": "rociar",
    "rociámos": "rociar",
    "rociáramo": "rociar",
    "rociáramos": "rociar",
    "rociárei": "rociar",
    "rociáreis": "rociar",
    "rociásseis": "rociar",
    "rociássemos": "rociar",
    "rociávamo": "rociar",
    "rociávamos": "rociar",
    "rociávei": "rociar",
    "rociáveis": "rociar",
    "rockeira": "rockeiro",
    "rockeiras": "rockeiro",
    "rockeiros": "rockeiro",
    "rockes": "rock",
    "rockets": "rocket",
    "rockzinho": "rock",
    "rockzinhos": "rock",
    "rockzito": "rock",
    "rockzitos": "rock",
    "roclorós": "rocloró",
    "roclós": "rocló",
    "roco": "rocar",
    "rococós": "rococó",
    "rocou": "rocar",
    "rocámo": "rocar",
    "rocámos": "rocar",
    "rocáramo": "rocar",
    "rocáramos": "rocar",
    "rocáreis": "rocar",
    "rocásseis": "rocar",
    "rocássemos": "rocar",
    "rocávamo": "rocar",
    "rocávamos": "rocar",
    "rocáveis": "rocar",
    "rocões": "rocão",
    "roda": "rodar",
    "rodada": "rodar",
    "rodadas": "rodar",
    "rodadazinha": "rodado",
    "rodadazinhas": "rodado",
    "rodadazita": "rodado",
    "rodadazitas": "rodado",
    "rodadinha": "rodado",
    "rodadinhas": "rodado",
    "rodadinho": "rodado",
    "rodadinhos": "rodado",
    "rodadita": "rodado",
    "rodaditas": "rodado",
    "rodadito": "rodado",
    "rodaditos": "rodado",
    "rodado": "rodar",
    "rodados": "rodar",
    "rodadozinho": "rodado",
    "rodadozinhos": "rodado",
    "rodadozito": "rodado",
    "rodadozitos": "rodado",
    "rodadíssima": "rodado",
    "rodadíssimas": "rodado",
    "rodadíssimo": "rodado",
    "rodadíssimos": "rodado",
    "rodagens": "rodagem",
    "rodai": "rodar",
    "rodais": "rodar",
    "rodalhos": "rodalho",
    "rodam": "rodar",
    "rodamites": "rodamite",
    "rodamo": "rodar",
    "rodamos": "rodar",
    "rodando": "rodar",
    "rodantes": "rodante",
    "rodapés": "rodapé",
    "rodaques": "rodaque",
    "rodara": "rodar",
    "rodaram": "rodar",
    "rodaras": "rodar",
    "rodarde": "rodar",
    "rodardes": "rodar",
    "rodare": "rodar",
    "rodarei": "rodar",
    "rodareis": "rodar",
    "rodarem": "rodar",
    "rodaremos": "rodar",
    "rodares": "rodar",
    "rodaria": "rodar",
    "rodariam": "rodar",
    "rodarias": "rodar",
    "rodarmo": "rodar",
    "rodarmos": "rodar",
    "rodará": "rodar",
    "rodarás": "rodar",
    "rodarão": "rodar",
    "rodaríamos": "rodar",
    "rodaríeis": "rodar",
    "rodas": "rodar",
    "rodasse": "rodar",
    "rodassem": "rodar",
    "rodasses": "rodar",
    "rodaste": "rodar",
    "rodastes": "rodar",
    "rodava": "rodar",
    "rodavam": "rodar",
    "rodavas": "rodar",
    "rode": "rodar",
    "rodeada": "rodear",
    "rodeadas": "rodear",
    "rodeado": "rodear",
    "rodeadora": "rodeador",
    "rodeadoras": "rodeador",
    "rodeadores": "rodeador",
    "rodeados": "rodear",
    "rodeai": "rodear",
    "rodeais": "rodear",
    "rodeamentos": "rodeamento",
    "rodeamo": "rodear",
    "rodeamos": "rodear",
    "rodeando": "rodear",
    "rodeara": "rodear",
    "rodearam": "rodear",
    "rodearas": "rodear",
    "rodearde": "rodear",
    "rodeardes": "rodear",
    "rodeare": "rodear",
    "rodearei": "rodear",
    "rodeareis": "rodear",
    "rodearem": "rodear",
    "rodearemos": "rodear",
    "rodeares": "rodear",
    "rodearia": "rodear",
    "rodeariam": "rodear",
    "rodearias": "rodear",
    "rodearmo": "rodear",
    "rodearmos": "rodear",
    "rodeará": "rodear",
    "rodearás": "rodear",
    "rodearão": "rodear",
    "rodearíamos": "rodear",
    "rodearíeis": "rodear",
    "rodeasse": "rodear",
    "rodeassem": "rodear",
    "rodeasses": "rodear",
    "rodeaste": "rodear",
    "rodeastes": "rodear",
    "rodeava": "rodear",
    "rodeavam": "rodear",
    "rodeavas": "rodear",
    "rodeei": "rodear",
    "rodeeis": "rodear",
    "rodeemo": "rodear",
    "rodeemos": "rodear",
    "rodei": "rodar",
    "rodeia": "rodear",
    "rodeiam": "rodear",
    "rodeias": "rodear",
    "rodeie": "rodear",
    "rodeiem": "rodear",
    "rodeies": "rodear",
    "rodeio": "rodear",
    "rodeios": "rodeio",
    "rodeira": "rodeiro",
    "rodeiras": "rodeiro",
    "rodeiros": "rodeiro",
    "rodeis": "rodar",
    "rodelas": "rodela",
    "rodeleira": "rodeleiro",
    "rodeleiras": "rodeleiro",
    "rodeleiros": "rodeleiro",
    "rodelinha": "rodela",
    "rodelinhas": "rodela",
    "rodelita": "rodela",
    "rodelitas": "rodela",
    "rodelos": "rodelo",
    "rodem": "rodar",
    "rodemo": "rodar",
    "rodemos": "rodar",
    "rodeou": "rodear",
    "rodes": "rodar",
    "rodesiana": "rodesiano",
    "rodesianas": "rodesiano",
    "rodesianos": "rodesiano",
    "rodetas": "rodeta",
    "rodetes": "rodete",
    "rodeá": "rodear",
    "rodeámo": "rodear",
    "rodeámos": "rodear",
    "rodeáramo": "rodear",
    "rodeáramos": "rodear",
    "rodeárei": "rodear",
    "rodeáreis": "rodear",
    "rodeásseis": "rodear",
    "rodeássemos": "rodear",
    "rodeávamo": "rodear",
    "rodeávamos": "rodear",
    "rodeávei": "rodear",
    "rodeáveis": "rodeável",
    "rodilha": "rodilho",
    "rodilhada": "rodilhar",
    "rodilhadas": "rodilhar",
    "rodilhado": "rodilhar",
    "rodilhados": "rodilhar",
    "rodilhai": "rodilhar",
    "rodilhais": "rodilhar",
    "rodilham": "rodilhar",
    "rodilhamo": "rodilhar",
    "rodilhamos": "rodilhar",
    "rodilhando": "rodilhar",
    "rodilhara": "rodilhar",
    "rodilharam": "rodilhar",
    "rodilharas": "rodilhar",
    "rodilharde": "rodilhar",
    "rodilhardes": "rodilhar",
    "rodilhare": "rodilhar",
    "rodilharei": "rodilhar",
    "rodilhareis": "rodilhar",
    "rodilharem": "rodilhar",
    "rodilharemos": "rodilhar",
    "rodilhares": "rodilhar",
    "rodilharia": "rodilhar",
    "rodilhariam": "rodilhar",
    "rodilharias": "rodilhar",
    "rodilharmo": "rodilhar",
    "rodilharmos": "rodilhar",
    "rodilhará": "rodilhar",
    "rodilharás": "rodilhar",
    "rodilharão": "rodilhar",
    "rodilharíamos": "rodilhar",
    "rodilharíeis": "rodilhar",
    "rodilhas": "rodilho",
    "rodilhasse": "rodilhar",
    "rodilhassem": "rodilhar",
    "rodilhasses": "rodilhar",
    "rodilhaste": "rodilhar",
    "rodilhastes": "rodilhar",
    "rodilhava": "rodilhar",
    "rodilhavam": "rodilhar",
    "rodilhavas": "rodilhar",
    "rodilhe": "rodilhar",
    "rodilhei": "rodilhar",
    "rodilheis": "rodilhar",
    "rodilhem": "rodilhar",
    "rodilhemo": "rodilhar",
    "rodilhemos": "rodilhar",
    "rodilhes": "rodilhar",
    "rodilho": "rodilhar",
    "rodilhona": "rodilhão",
    "rodilhonas": "rodilhão",
    "rodilhos": "rodilho",
    "rodilhou": "rodilhar",
    "rodilhá": "rodilhar",
    "rodilhámo": "rodilhar",
    "rodilhámos": "rodilhar",
    "rodilháramo": "rodilhar",
    "rodilháramos": "rodilhar",
    "rodilhárei": "rodilhar",
    "rodilháreis": "rodilhar",
    "rodilhásseis": "rodilhar",
    "rodilhássemos": "rodilhar",
    "rodilhávamo": "rodilhar",
    "rodilhávamos": "rodilhar",
    "rodilhávei": "rodilhar",
    "rodilháveis": "rodilhar",
    "rodilhões": "rodilhão",
    "rodinha": "roda",
    "rodinhas": "roda",
    "rodins": "rodim",
    "rodioscas": "rodiosca",
    "rodiotas": "rodiota",
    "rodita": "roda",
    "roditas": "roda",
    "rodites": "rodite",
    "rodo": "rodar",
    "rodocrosites": "rodocrosite",
    "rododendros": "rododendro",
    "rododendráceas": "rododendrácea",
    "rodoferroviária": "rodoferroviário",
    "rodoferroviárias": "rodoferroviário",
    "rodoferroviários": "rodoferroviário",
    "rodofíceas": "rodofícea",
    "rodoiças": "rodoiça",
    "rodologias": "rodologia",
    "rodomeis": "rodomel",
    "rodonites": "rodonite",
    "rodopelos": "rodopelo",
    "rodopia": "rodopiar",
    "rodopiada": "rodopiar",
    "rodopiadas": "rodopiar",
    "rodopiado": "rodopiar",
    "rodopiados": "rodopiar",
    "rodopiai": "rodopiar",
    "rodopiais": "rodopiar",
    "rodopiam": "rodopiar",
    "rodopiamo": "rodopiar",
    "rodopiamos": "rodopiar",
    "rodopiando": "rodopiar",
    "rodopiantes": "rodopiante",
    "rodopiara": "rodopiar",
    "rodopiaram": "rodopiar",
    "rodopiaras": "rodopiar",
    "rodopiardes": "rodopiar",
    "rodopiarei": "rodopiar",
    "rodopiareis": "rodopiar",
    "rodopiarem": "rodopiar",
    "rodopiaremos": "rodopiar",
    "rodopiares": "rodopiar",
    "rodopiaria": "rodopiar",
    "rodopiariam": "rodopiar",
    "rodopiarias": "rodopiar",
    "rodopiarmo": "rodopiar",
    "rodopiarmos": "rodopiar",
    "rodopiará": "rodopiar",
    "rodopiarás": "rodopiar",
    "rodopiarão": "rodopiar",
    "rodopiaríamos": "rodopiar",
    "rodopiaríeis": "rodopiar",
    "rodopias": "rodopiar",
    "rodopiasse": "rodopiar",
    "rodopiassem": "rodopiar",
    "rodopiasses": "rodopiar",
    "rodopiaste": "rodopiar",
    "rodopiastes": "rodopiar",
    "rodopiava": "rodopiar",
    "rodopiavam": "rodopiar",
    "rodopiavas": "rodopiar",
    "rodopie": "rodopiar",
    "rodopiei": "rodopiar",
    "rodopieis": "rodopiar",
    "rodopiem": "rodopiar",
    "rodopiemo": "rodopiar",
    "rodopiemos": "rodopiar",
    "rodopies": "rodopiar",
    "rodopio": "rodopiar",
    "rodopios": "rodopio",
    "rodopiou": "rodopiar",
    "rodopiámo": "rodopiar",
    "rodopiámos": "rodopiar",
    "rodopiáramo": "rodopiar",
    "rodopiáramos": "rodopiar",
    "rodopiáreis": "rodopiar",
    "rodopiásseis": "rodopiar",
    "rodopiássemos": "rodopiar",
    "rodopiávamo": "rodopiar",
    "rodopiávamos": "rodopiar",
    "rodopiáveis": "rodopiar",
    "rodopsinas": "rodopsina",
    "rodos": "rodo",
    "rodou": "rodar",
    "rodouças": "rodouça",
    "rodovalhos": "rodovalho",
    "rodovias": "rodovia",
    "rodoviária": "rodoviário",
    "rodoviárias": "rodoviário",
    "rodoviários": "rodoviário",
    "rodriga": "rodrigar",
    "rodrigada": "rodrigar",
    "rodrigadas": "rodrigar",
    "rodrigado": "rodrigar",
    "rodrigados": "rodrigar",
    "rodrigai": "rodrigar",
    "rodrigais": "rodrigar",
    "rodrigam": "rodrigar",
    "rodrigamo": "rodrigar",
    "rodrigamos": "rodrigar",
    "rodrigando": "rodrigar",
    "rodrigara": "rodrigar",
    "rodrigaram": "rodrigar",
    "rodrigaras": "rodrigar",
    "rodrigarde": "rodrigar",
    "rodrigardes": "rodrigar",
    "rodrigare": "rodrigar",
    "rodrigarei": "rodrigar",
    "rodrigareis": "rodrigar",
    "rodrigarem": "rodrigar",
    "rodrigaremos": "rodrigar",
    "rodrigares": "rodrigar",
    "rodrigaria": "rodrigar",
    "rodrigariam": "rodrigar",
    "rodrigarias": "rodrigar",
    "rodrigarmo": "rodrigar",
    "rodrigarmos": "rodrigar",
    "rodrigará": "rodrigar",
    "rodrigarás": "rodrigar",
    "rodrigarão": "rodrigar",
    "rodrigaríamos": "rodrigar",
    "rodrigaríeis": "rodrigar",
    "rodrigas": "rodrigar",
    "rodrigasse": "rodrigar",
    "rodrigassem": "rodrigar",
    "rodrigasses": "rodrigar",
    "rodrigaste": "rodrigar",
    "rodrigastes": "rodrigar",
    "rodrigava": "rodrigar",
    "rodrigavam": "rodrigar",
    "rodrigavas": "rodrigar",
    "rodrigo": "rodrigar",
    "rodrigou": "rodrigar",
    "rodrigue": "rodrigar",
    "rodriguei": "rodrigar",
    "rodrigueis": "rodrigar",
    "rodriguem": "rodrigar",
    "rodriguemo": "rodrigar",
    "rodriguemos": "rodrigar",
    "rodrigues": "rodrigar",
    "rodriguinhos": "rodriguinho",
    "rodrigá": "rodrigar",
    "rodrigámo": "rodrigar",
    "rodrigámos": "rodrigar",
    "rodrigáramo": "rodrigar",
    "rodrigáramos": "rodrigar",
    "rodrigárei": "rodrigar",
    "rodrigáreis": "rodrigar",
    "rodrigásseis": "rodrigar",
    "rodrigássemos": "rodrigar",
    "rodrigávamo": "rodrigar",
    "rodrigávamos": "rodrigar",
    "rodrigávei": "rodrigar",
    "rodrigáveis": "rodrigar",
    "rodrigões": "rodrigão",
    "roduras": "rodura",
    "rodá": "rodar",
    "rodámo": "rodar",
    "rodámos": "rodar",
    "rodáramo": "rodar",
    "rodáramos": "rodar",
    "rodárei": "rodar",
    "rodáreis": "rodar",
    "rodásseis": "rodar",
    "rodássemos": "rodar",
    "rodávamo": "rodar",
    "rodávamos": "rodar",
    "rodávei": "rodar",
    "rodáveis": "rodar",
    "rodícios": "rodício",
    "rodízios": "rodízio",
    "rodógrafa": "rodógrafo",
    "rodógrafas": "rodógrafo",
    "rodógrafos": "rodógrafo",
    "roedora": "roedor",
    "roedoras": "roedor",
    "roedorazinha": "roedor",
    "roedorazinhas": "roedor",
    "roedorazita": "roedor",
    "roedorazitas": "roedor",
    "roedores": "roedor",
    "roedorzinho": "roedor",
    "roedorzinhos": "roedor",
    "roedorzito": "roedor",
    "roedorzitos": "roedor",
    "roeduras": "roedura",
    "roei": "roer",
    "roeis": "roer",
    "roem": "roer",
    "roemo": "roer",
    "roemos": "roer",
    "roendo": "roer",
    "roentgens": "roentgen",
    "roentgenterapias": "roentgenterapia",
    "roera": "roer",
    "roeram": "roer",
    "roeras": "roer",
    "roerde": "roer",
    "roerdes": "roer",
    "roere": "roer",
    "roerei": "roer",
    "roereis": "roer",
    "roerem": "roer",
    "roeremos": "roer",
    "roeres": "roer",
    "roeria": "roer",
    "roeriam": "roer",
    "roerias": "roer",
    "roermo": "roer",
    "roermos": "roer",
    "roerá": "roer",
    "roerás": "roer",
    "roerão": "roer",
    "roeríamos": "roer",
    "roeríeis": "roer",
    "roesse": "roer",
    "roessem": "roer",
    "roesses": "roer",
    "roeste": "roer",
    "roestes": "roer",
    "roeu": "roer",
    "rofa": "rofo",
    "rofas": "rofo",
    "rofegos": "rofego",
    "rofos": "rofo",
    "roga": "rogar",
    "rogada": "rogar",
    "rogadas": "rogar",
    "rogadazinha": "rogado",
    "rogadazinhas": "rogado",
    "rogadazita": "rogado",
    "rogadazitas": "rogado",
    "rogadinha": "rogado",
    "rogadinhas": "rogado",
    "rogadinho": "rogado",
    "rogadinhos": "rogado",
    "rogadita": "rogado",
    "rogaditas": "rogado",
    "rogadito": "rogado",
    "rogaditos": "rogado",
    "rogado": "rogar",
    "rogadora": "rogador",
    "rogadoras": "rogador",
    "rogadores": "rogador",
    "rogados": "rogar",
    "rogadozinho": "rogado",
    "rogadozinhos": "rogado",
    "rogadozito": "rogado",
    "rogadozitos": "rogado",
    "rogadíssima": "rogado",
    "rogadíssimas": "rogado",
    "rogadíssimo": "rogado",
    "rogadíssimos": "rogado",
    "rogai": "rogar",
    "rogais": "rogar",
    "rogam": "rogar",
    "rogamo": "rogar",
    "rogamos": "rogar",
    "rogando": "rogar",
    "rogara": "rogar",
    "rogaram": "rogar",
    "rogaras": "rogar",
    "rogarde": "rogar",
    "rogardes": "rogar",
    "rogare": "rogar",
    "rogarei": "rogar",
    "rogareis": "rogar",
    "rogarem": "rogar",
    "rogaremos": "rogar",
    "rogares": "rogar",
    "rogaria": "rogar",
    "rogariam": "rogar",
    "rogarias": "rogar",
    "rogarmo": "rogar",
    "rogarmos": "rogar",
    "rogará": "rogar",
    "rogarás": "rogar",
    "rogarão": "rogar",
    "rogaríamos": "rogar",
    "rogaríeis": "rogar",
    "rogas": "rogar",
    "rogasse": "rogar",
    "rogassem": "rogar",
    "rogasses": "rogar",
    "rogaste": "rogar",
    "rogastes": "rogar",
    "rogativa": "rogativo",
    "rogativas": "rogativo",
    "rogativos": "rogativo",
    "rogatórias": "rogatória",
    "rogatórios": "rogatório",
    "rogava": "rogar",
    "rogavam": "rogar",
    "rogavas": "rogar",
    "rogações": "rogação",
    "rogo": "rogar",
    "rogos": "rogo",
    "rogou": "rogar",
    "rogue": "rogar",
    "roguei": "rogar",
    "rogueis": "rogar",
    "roguem": "rogar",
    "roguemo": "rogar",
    "roguemos": "rogar",
    "rogues": "rogar",
    "rogá": "rogar",
    "rogámo": "rogar",
    "rogámos": "rogar",
    "rogáramo": "rogar",
    "rogáramos": "rogar",
    "rogárei": "rogar",
    "rogáreis": "rogar",
    "rogásseis": "rogar",
    "rogássemos": "rogar",
    "rogávamo": "rogar",
    "rogávamos": "rogar",
    "rogávei": "rogar",
    "rogáveis": "rogar",
    "roidinha": "roído",
    "roidinhas": "roído",
    "roidinho": "roído",
    "roidinhos": "roído",
    "roidita": "roído",
    "roiditas": "roído",
    "roidito": "roído",
    "roiditos": "roído",
    "roidíssima": "roído",
    "roidíssimas": "roído",
    "roidíssimo": "roído",
    "roidíssimos": "roído",
    "roja": "rojo",
    "rojada": "rojar",
    "rojadas": "rojar",
    "rojado": "rojar",
    "rojadora": "rojador",
    "rojadoras": "rojador",
    "rojadores": "rojador",
    "rojados": "rojar",
    "rojai": "rojar",
    "rojais": "rojar",
    "rojam": "rojar",
    "rojamo": "rojar",
    "rojamos": "rojar",
    "rojando": "rojar",
    "rojara": "rojar",
    "rojaram": "rojar",
    "rojaras": "rojar",
    "rojarde": "rojar",
    "rojardes": "rojar",
    "rojare": "rojar",
    "rojarei": "rojar",
    "rojareis": "rojar",
    "rojarem": "rojar",
    "rojaremos": "rojar",
    "rojares": "rojar",
    "rojaria": "rojar",
    "rojariam": "rojar",
    "rojarias": "rojar",
    "rojarmo": "rojar",
    "rojarmos": "rojar",
    "rojará": "rojar",
    "rojarás": "rojar",
    "rojarão": "rojar",
    "rojaríamos": "rojar",
    "rojaríeis": "rojar",
    "rojas": "rojo",
    "rojasse": "rojar",
    "rojassem": "rojar",
    "rojasses": "rojar",
    "rojaste": "rojar",
    "rojastes": "rojar",
    "rojava": "rojar",
    "rojavam": "rojar",
    "rojavas": "rojar",
    "roje": "rojar",
    "rojei": "rojar",
    "rojeis": "rojar",
    "rojem": "rojar",
    "rojemo": "rojar",
    "rojemos": "rojar",
    "rojes": "rojar",
    "rojo": "rojar",
    "rojos": "rojo",
    "rojou": "rojar",
    "rojá": "rojar",
    "rojámo": "rojar",
    "rojámos": "rojar",
    "rojáramo": "rojar",
    "rojáramos": "rojar",
    "rojárei": "rojar",
    "rojáreis": "rojar",
    "rojásseis": "rojar",
    "rojássemos": "rojar",
    "rojávamo": "rojar",
    "rojávamos": "rojar",
    "rojávei": "rojar",
    "rojáveis": "rojar",
    "rojões": "rojão",
    "rola": "rolo",
    "rolada": "rolar",
    "roladas": "rolar",
    "rolado": "rolar",
    "roladora": "rolador",
    "roladoras": "rolador",
    "roladores": "rolador",
    "rolados": "rolar",
    "rolagens": "rolagem",
    "rolai": "rolar",
    "rolais": "rolar",
    "rolam": "rolar",
    "rolamentos": "rolamento",
    "rolamo": "rolar",
    "rolamos": "rolar",
    "rolandiana": "rolandiano",
    "rolandianas": "rolandiano",
    "rolandianos": "rolandiano",
    "rolando": "rolar",
    "rolantes": "rolante",
    "rolara": "rolar",
    "rolaram": "rolar",
    "rolaras": "rolar",
    "rolarde": "rolar",
    "rolardes": "rolar",
    "rolare": "rolar",
    "rolarei": "rolar",
    "rolareis": "rolar",
    "rolarem": "rolar",
    "rolaremos": "rolar",
    "rolares": "rolar",
    "rolaria": "rolar",
    "rolariam": "rolar",
    "rolarias": "rolar",
    "rolarmo": "rolar",
    "rolarmos": "rolar",
    "rolará": "rolar",
    "rolarás": "rolar",
    "rolarão": "rolar",
    "rolaríamos": "rolar",
    "rolaríeis": "rolar",
    "rolas": "rolo",
    "rolasse": "rolar",
    "rolassem": "rolar",
    "rolasses": "rolar",
    "rolaste": "rolar",
    "rolastes": "rolar",
    "rolava": "rolar",
    "rolavam": "rolar",
    "rolavas": "rolar",
    "roldanas": "roldana",
    "roldeada": "roldear",
    "roldeadas": "roldear",
    "roldeado": "roldear",
    "roldeados": "roldear",
    "roldeai": "roldear",
    "roldeais": "roldear",
    "roldeamo": "roldear",
    "roldeamos": "roldear",
    "roldeando": "roldear",
    "roldeara": "roldear",
    "roldearam": "roldear",
    "roldearas": "roldear",
    "roldearde": "roldear",
    "roldeardes": "roldear",
    "roldeare": "roldear",
    "roldearei": "roldear",
    "roldeareis": "roldear",
    "roldearem": "roldear",
    "roldearemos": "roldear",
    "roldeares": "roldear",
    "roldearia": "roldear",
    "roldeariam": "roldear",
    "roldearias": "roldear",
    "roldearmo": "roldear",
    "roldearmos": "roldear",
    "roldeará": "roldear",
    "roldearás": "roldear",
    "roldearão": "roldear",
    "roldearíamos": "roldear",
    "roldearíeis": "roldear",
    "roldeasse": "roldear",
    "roldeassem": "roldear",
    "roldeasses": "roldear",
    "roldeaste": "roldear",
    "roldeastes": "roldear",
    "roldeava": "roldear",
    "roldeavam": "roldear",
    "roldeavas": "roldear",
    "roldeei": "roldear",
    "roldeeis": "roldear",
    "roldeemo": "roldear",
    "roldeemos": "roldear",
    "roldeia": "roldear",
    "roldeiam": "roldear",
    "roldeias": "roldear",
    "roldeie": "roldear",
    "roldeiem": "roldear",
    "roldeies": "roldear",
    "roldeio": "roldear",
    "roldeou": "roldear",
    "roldeá": "roldear",
    "roldeámo": "roldear",
    "roldeámos": "roldear",
    "roldeáramo": "roldear",
    "roldeáramos": "roldear",
    "roldeárei": "roldear",
    "roldeáreis": "roldear",
    "roldeásseis": "roldear",
    "roldeássemos": "roldear",
    "roldeávamo": "roldear",
    "roldeávamos": "roldear",
    "roldeávei": "roldear",
    "roldeáveis": "roldear",
    "roldoniana": "roldoniano",
    "roldonianas": "roldoniano",
    "roldonianos": "roldoniano",
    "roldões": "roldão",
    "role": "rolar",
    "rolei": "rolar",
    "roleira": "roleiro",
    "roleiras": "roleiro",
    "roleiros": "roleiro",
    "roleis": "rolar",
    "rolem": "rolar",
    "rolemo": "rolar",
    "rolemos": "rolar",
    "roles": "rolar",
    "roletas": "roleta",
    "roletes": "rolete",
    "rolha": "rolho",
    "rolhada": "rolhar",
    "rolhadas": "rolhar",
    "rolhado": "rolhar",
    "rolhadores": "rolhador",
    "rolhados": "rolhar",
    "rolhaduras": "rolhadura",
    "rolhagens": "rolhagem",
    "rolhai": "rolhar",
    "rolhais": "rolhar",
    "rolham": "rolhar",
    "rolhamo": "rolhar",
    "rolhamos": "rolhar",
    "rolhando": "rolhar",
    "rolhara": "rolhar",
    "rolharam": "rolhar",
    "rolharas": "rolhar",
    "rolharde": "rolhar",
    "rolhardes": "rolhar",
    "rolhare": "rolhar",
    "rolharei": "rolhar",
    "rolhareis": "rolhar",
    "rolharem": "rolhar",
    "rolharemos": "rolhar",
    "rolhares": "rolhar",
    "rolharia": "rolhar",
    "rolhariam": "rolhar",
    "rolharias": "rolhar",
    "rolharmo": "rolhar",
    "rolharmos": "rolhar",
    "rolhará": "rolhar",
    "rolharás": "rolhar",
    "rolharão": "rolhar",
    "rolharíamos": "rolhar",
    "rolharíeis": "rolhar",
    "rolhas": "rolho",
    "rolhasse": "rolhar",
    "rolhassem": "rolhar",
    "rolhasses": "rolhar",
    "rolhaste": "rolhar",
    "rolhastes": "rolhar",
    "rolhava": "rolhar",
    "rolhavam": "rolhar",
    "rolhavas": "rolhar",
    "rolhe": "rolhar",
    "rolhei": "rolhar",
    "rolheira": "rolheiro",
    "rolheiras": "rolheiro",
    "rolheiros": "rolheiro",
    "rolheis": "rolhar",
    "rolhem": "rolhar",
    "rolhemo": "rolhar",
    "rolhemos": "rolhar",
    "rolhes": "rolhar",
    "rolhinha": "rolha",
    "rolhinhas": "rolha",
    "rolhistas": "rolhista",
    "rolhita": "rolha",
    "rolhitas": "rolha",
    "rolho": "rolhar",
    "rolhos": "rolho",
    "rolhou": "rolhar",
    "rolhá": "rolhar",
    "rolhámo": "rolhar",
    "rolhámos": "rolhar",
    "rolháramo": "rolhar",
    "rolháramos": "rolhar",
    "rolhárei": "rolhar",
    "rolháreis": "rolhar",
    "rolhásseis": "rolhar",
    "rolhássemos": "rolhar",
    "rolhávamo": "rolhar",
    "rolhávamos": "rolhar",
    "rolhávei": "rolhar",
    "rolháveis": "rolhar",
    "rolice": "roliçar",
    "rolicei": "roliçar",
    "roliceis": "roliçar",
    "rolicem": "roliçar",
    "rolicemo": "roliçar",
    "rolicemos": "roliçar",
    "rolices": "roliçar",
    "rolicinha": "roliço",
    "rolicinhas": "roliço",
    "rolicinho": "roliço",
    "rolicinhos": "roliço",
    "rolicita": "roliço",
    "rolicitas": "roliço",
    "rolicito": "roliço",
    "rolicitos": "roliço",
    "rolicíssima": "roliço",
    "rolicíssimas": "roliço",
    "rolicíssimo": "roliço",
    "rolicíssimos": "roliço",
    "rolieiros": "rolieiro",
    "rolinhas": "rolinha",
    "rolinho": "rolo",
    "rolinhos": "rolo",
    "rolins": "rolim",
    "rolis": "roli",
    "rolito": "rolo",
    "rolitos": "rolo",
    "roliça": "roliço",
    "roliçada": "roliçar",
    "roliçadas": "roliçar",
    "roliçado": "roliçar",
    "roliçados": "roliçar",
    "roliçai": "roliçar",
    "roliçais": "roliçar",
    "roliçam": "roliçar",
    "roliçamo": "roliçar",
    "roliçamos": "roliçar",
    "roliçando": "roliçar",
    "roliçara": "roliçar",
    "roliçaram": "roliçar",
    "roliçaras": "roliçar",
    "roliçarde": "roliçar",
    "roliçardes": "roliçar",
    "roliçare": "roliçar",
    "roliçarei": "roliçar",
    "roliçareis": "roliçar",
    "roliçarem": "roliçar",
    "roliçaremos": "roliçar",
    "roliçares": "roliçar",
    "roliçaria": "roliçar",
    "roliçariam": "roliçar",
    "roliçarias": "roliçar",
    "roliçarmo": "roliçar",
    "roliçarmos": "roliçar",
    "roliçará": "roliçar",
    "roliçarás": "roliçar",
    "roliçarão": "roliçar",
    "roliçaríamos": "roliçar",
    "roliçaríeis": "roliçar",
    "roliças": "roliço",
    "roliçasse": "roliçar",
    "roliçassem": "roliçar",
    "roliçasses": "roliçar",
    "roliçaste": "roliçar",
    "roliçastes": "roliçar",
    "roliçava": "roliçar",
    "roliçavam": "roliçar",
    "roliçavas": "roliçar",
    "roliçazinha": "roliço",
    "roliçazinhas": "roliço",
    "roliçazita": "roliço",
    "roliçazitas": "roliço",
    "roliço": "roliçar",
    "roliços": "roliço",
    "roliçou": "roliçar",
    "roliçozinho": "roliço",
    "roliçozinhos": "roliço",
    "roliçozito": "roliço",
    "roliçozitos": "roliço",
    "roliçá": "roliçar",
    "roliçámo": "roliçar",
    "roliçámos": "roliçar",
    "roliçáramo": "roliçar",
    "roliçáramos": "roliçar",
    "roliçárei": "roliçar",
    "roliçáreis": "roliçar",
    "roliçásseis": "roliçar",
    "roliçássemos": "roliçar",
    "roliçávamo": "roliçar",
    "roliçávamos": "roliçar",
    "roliçávei": "roliçar",
    "roliçáveis": "roliçar",
    "rolo": "rolar",
    "rolos": "rolo",
    "rolotes": "rolote",
    "rolou": "rolar",
    "rolá": "rolar",
    "rolámo": "rolar",
    "rolámos": "rolar",
    "roláramo": "rolar",
    "roláramos": "rolar",
    "rolárei": "rolar",
    "roláreis": "rolar",
    "rolásseis": "rolar",
    "rolássemos": "rolar",
    "rolávamo": "rolar",
    "rolávamos": "rolar",
    "rolávei": "rolar",
    "roláveis": "rolar",
    "rolões": "rolão",
    "romagens": "romagem",
    "romaica": "romaico",
    "romaicas": "romaico",
    "romaicos": "romaico",
    "romana": "romano",
    "romanas": "romano",
    "romanceada": "romancear",
    "romanceadas": "romancear",
    "romanceado": "romancear",
    "romanceados": "romancear",
    "romanceai": "romancear",
    "romanceais": "romancear",
    "romanceamo": "romancear",
    "romanceamos": "romancear",
    "romanceando": "romancear",
    "romanceara": "romancear",
    "romancearam": "romancear",
    "romancearas": "romancear",
    "romancearde": "romancear",
    "romanceardes": "romancear",
    "romanceare": "romancear",
    "romancearei": "romancear",
    "romanceareis": "romancear",
    "romancearem": "romancear",
    "romancearemos": "romancear",
    "romanceares": "romancear",
    "romancearia": "romancear",
    "romanceariam": "romancear",
    "romancearias": "romancear",
    "romancearmo": "romancear",
    "romancearmos": "romancear",
    "romanceará": "romancear",
    "romancearás": "romancear",
    "romancearão": "romancear",
    "romancearíamos": "romancear",
    "romancearíeis": "romancear",
    "romanceasse": "romancear",
    "romanceassem": "romancear",
    "romanceasses": "romancear",
    "romanceaste": "romancear",
    "romanceastes": "romancear",
    "romanceava": "romancear",
    "romanceavam": "romancear",
    "romanceavas": "romancear",
    "romanceações": "romanceação",
    "romancecos": "romanceco",
    "romanceei": "romancear",
    "romanceeis": "romancear",
    "romanceemo": "romancear",
    "romanceemos": "romancear",
    "romanceia": "romancear",
    "romanceiam": "romancear",
    "romanceias": "romancear",
    "romanceie": "romancear",
    "romanceiem": "romancear",
    "romanceies": "romancear",
    "romanceio": "romancear",
    "romanceiros": "romanceiro",
    "romanceou": "romancear",
    "romances": "romance",
    "romancetes": "romancete",
    "romancezinho": "romance",
    "romancezinhos": "romance",
    "romancezito": "romance",
    "romancezitos": "romance",
    "romanceá": "romancear",
    "romanceámo": "romancear",
    "romanceámos": "romancear",
    "romanceáramo": "romancear",
    "romanceáramos": "romancear",
    "romanceárei": "romancear",
    "romanceáreis": "romancear",
    "romanceásseis": "romancear",
    "romanceássemos": "romancear",
    "romanceávamo": "romancear",
    "romanceávamos": "romancear",
    "romanceávei": "romancear",
    "romanceáveis": "romanceável",
    "romanches": "romanche",
    "romancices": "romancice",
    "romancinho": "romance",
    "romancinhos": "romance",
    "romancismos": "romancismo",
    "romancistas": "romancista",
    "romancito": "romance",
    "romancitos": "romance",
    "romanda": "romando",
    "romandas": "romando",
    "romandos": "romando",
    "romanesca": "romanesco",
    "romanescas": "romanesco",
    "romanescos": "romanesco",
    "romanhos": "romanho",
    "romanins": "romanim",
    "romanisca": "romanisco",
    "romaniscas": "romanisco",
    "romaniscos": "romanisco",
    "romanismos": "romanismo",
    "romanistas": "romanista",
    "romaniza": "romanizar",
    "romanizada": "romanizar",
    "romanizadas": "romanizar",
    "romanizado": "romanizar",
    "romanizados": "romanizar",
    "romanizai": "romanizar",
    "romanizais": "romanizar",
    "romanizam": "romanizar",
    "romanizamo": "romanizar",
    "romanizamos": "romanizar",
    "romanizando": "romanizar",
    "romanizara": "romanizar",
    "romanizaram": "romanizar",
    "romanizaras": "romanizar",
    "romanizarde": "romanizar",
    "romanizardes": "romanizar",
    "romanizare": "romanizar",
    "romanizarei": "romanizar",
    "romanizareis": "romanizar",
    "romanizarem": "romanizar",
    "romanizaremos": "romanizar",
    "romanizares": "romanizar",
    "romanizaria": "romanizar",
    "romanizariam": "romanizar",
    "romanizarias": "romanizar",
    "romanizarmo": "romanizar",
    "romanizarmos": "romanizar",
    "romanizará": "romanizar",
    "romanizarás": "romanizar",
    "romanizarão": "romanizar",
    "romanizaríamos": "romanizar",
    "romanizaríeis": "romanizar",
    "romanizas": "romanizar",
    "romanizasse": "romanizar",
    "romanizassem": "romanizar",
    "romanizasses": "romanizar",
    "romanizaste": "romanizar",
    "romanizastes": "romanizar",
    "romanizava": "romanizar",
    "romanizavam": "romanizar",
    "romanizavas": "romanizar",
    "romanizações": "romanização",
    "romanize": "romanizar",
    "romanizei": "romanizar",
    "romanizeis": "romanizar",
    "romanizem": "romanizar",
    "romanizemo": "romanizar",
    "romanizemos": "romanizar",
    "romanizes": "romanizar",
    "romanizo": "romanizar",
    "romanizou": "romanizar",
    "romanizá": "romanizar",
    "romanizámo": "romanizar",
    "romanizámos": "romanizar",
    "romanizáramo": "romanizar",
    "romanizáramos": "romanizar",
    "romanizárei": "romanizar",
    "romanizáreis": "romanizar",
    "romanizásseis": "romanizar",
    "romanizássemos": "romanizar",
    "romanizávamo": "romanizar",
    "romanizávamos": "romanizar",
    "romanizávei": "romanizar",
    "romanizáveis": "romanizável",
    "romanologias": "romanologia",
    "romanologistas": "romanologista",
    "romanológica": "romanológico",
    "romanológicas": "romanológico",
    "romanológicos": "romanológico",
    "romanos": "romano",
    "romantices": "romantice",
    "romanticismos": "romanticismo",
    "romantismos": "romantismo",
    "romantiza": "romantizar",
    "romantizada": "romantizar",
    "romantizadas": "romantizar",
    "romantizado": "romantizar",
    "romantizados": "romantizar",
    "romantizai": "romantizar",
    "romantizais": "romantizar",
    "romantizam": "romantizar",
    "romantizamo": "romantizar",
    "romantizamos": "romantizar",
    "romantizando": "romantizar",
    "romantizara": "romantizar",
    "romantizaram": "romantizar",
    "romantizaras": "romantizar",
    "romantizarde": "romantizar",
    "romantizardes": "romantizar",
    "romantizare": "romantizar",
    "romantizarei": "romantizar",
    "romantizareis": "romantizar",
    "romantizarem": "romantizar",
    "romantizaremos": "romantizar",
    "romantizares": "romantizar",
    "romantizaria": "romantizar",
    "romantizariam": "romantizar",
    "romantizarias": "romantizar",
    "romantizarmo": "romantizar",
    "romantizarmos": "romantizar",
    "romantizará": "romantizar",
    "romantizarás": "romantizar",
    "romantizarão": "romantizar",
    "romantizaríamos": "romantizar",
    "romantizaríeis": "romantizar",
    "romantizas": "romantizar",
    "romantizasse": "romantizar",
    "romantizassem": "romantizar",
    "romantizasses": "romantizar",
    "romantizaste": "romantizar",
    "romantizastes": "romantizar",
    "romantizava": "romantizar",
    "romantizavam": "romantizar",
    "romantizavas": "romantizar",
    "romantize": "romantizar",
    "romantizei": "romantizar",
    "romantizeis": "romantizar",
    "romantizem": "romantizar",
    "romantizemo": "romantizar",
    "romantizemos": "romantizar",
    "romantizes": "romantizar",
    "romantizo": "romantizar",
    "romantizou": "romantizar",
    "romantizá": "romantizar",
    "romantizámo": "romantizar",
    "romantizámos": "romantizar",
    "romantizáramo": "romantizar",
    "romantizáramos": "romantizar",
    "romantizárei": "romantizar",
    "romantizáreis": "romantizar",
    "romantizásseis": "romantizar",
    "romantizássemos": "romantizar",
    "romantizávamo": "romantizar",
    "romantizávamos": "romantizar",
    "romantizávei": "romantizar",
    "romantizáveis": "romantizar",
    "romanzas": "romanza",
    "romançadas": "romançada",
    "romançarias": "romançaria",
    "romanças": "romança",
    "romanços": "romanço",
    "romanística": "romanístico",
    "romanísticas": "romanístico",
    "romanísticos": "romanístico",
    "romanóloga": "romanólogo",
    "romanólogas": "romanólogo",
    "romanólogos": "romanólogo",
    "romarias": "romaria",
    "romba": "rombo",
    "rombas": "rombo",
    "rombiformes": "rombiforme",
    "rombododecaedros": "rombododecaedro",
    "romboedros": "romboedro",
    "romboidais": "romboidal",
    "rombos": "rombo",
    "romboédrica": "romboédrico",
    "romboédricas": "romboédrico",
    "romboédricos": "romboédrico",
    "rombuda": "rombudo",
    "rombudas": "rombudo",
    "rombudos": "rombudo",
    "rombóides": "rombóide",
    "romeira": "romeiro",
    "romeirais": "romeiral",
    "romeiras": "romeiro",
    "romeirinhos": "romeirinho",
    "romeiros": "romeiro",
    "romena": "romeno",
    "romenas": "romeno",
    "romenhos": "romenho",
    "romenos": "romeno",
    "romona": "romão",
    "romonas": "romão",
    "rompa": "romper",
    "rompais": "romper",
    "rompam": "romper",
    "rompamo": "romper",
    "rompamos": "romper",
    "rompantes": "rompante",
    "rompas": "romper",
    "rompe": "romper",
    "rompedeira": "rompedor",
    "rompedeiras": "rompedor",
    "rompedora": "rompedor",
    "rompedoras": "rompedor",
    "rompedores": "rompedor",
    "rompeduras": "rompedura",
    "rompei": "romper",
    "rompeis": "romper",
    "rompem": "romper",
    "rompemo": "romper",
    "rompemos": "romper",
    "rompendo": "romper",
    "rompentes": "rompente",
    "rompera": "romper",
    "romperam": "romper",
    "romperas": "romper",
    "romperde": "romper",
    "romperdes": "romper",
    "rompere": "romper",
    "romperei": "romper",
    "rompereis": "romper",
    "romperem": "romper",
    "romperemos": "romper",
    "romperes": "romper",
    "romperia": "romper",
    "romperiam": "romper",
    "romperias": "romper",
    "rompermo": "romper",
    "rompermos": "romper",
    "romperá": "romper",
    "romperás": "romper",
    "romperão": "romper",
    "romperíamos": "romper",
    "romperíeis": "romper",
    "rompes": "romper",
    "rompesse": "romper",
    "rompessem": "romper",
    "rompesses": "romper",
    "rompeste": "romper",
    "rompestes": "romper",
    "rompeu": "romper",
    "rompi": "romper",
    "rompia": "romper",
    "rompiam": "romper",
    "rompias": "romper",
    "rompida": "rompido",
    "rompidas": "rompido",
    "rompido": "romper",
    "rompidos": "rompido",
    "rompimentos": "rompimento",
    "rompo": "romper",
    "rompê": "romper",
    "rompêramo": "romper",
    "rompêramos": "romper",
    "rompêrei": "romper",
    "rompêreis": "romper",
    "rompêsseis": "romper",
    "rompêssemos": "romper",
    "rompíamo": "romper",
    "rompíamos": "romper",
    "rompíei": "romper",
    "rompíeis": "romper",
    "rompões": "rompão",
    "românias": "românia",
    "românica": "românico",
    "românicas": "românico",
    "românicos": "românico",
    "romântica": "romântico",
    "românticas": "romântico",
    "românticos": "romântico",
    "romãs": "romã",
    "romãzeirais": "romãzeiral",
    "romãzeiras": "romãzeira",
    "romões": "romão",
    "ronca": "roncar",
    "roncada": "roncar",
    "roncadas": "roncar",
    "roncado": "roncar",
    "roncadora": "roncador",
    "roncadoras": "roncador",
    "roncadores": "roncador",
    "roncados": "roncar",
    "roncaduras": "roncadura",
    "roncais": "roncar",
    "roncam": "roncar",
    "roncamo": "roncar",
    "roncamos": "roncar",
    "roncando": "roncar",
    "roncantes": "roncante",
    "roncara": "roncar",
    "roncaram": "roncar",
    "roncaras": "roncar",
    "roncardes": "roncar",
    "roncarei": "roncar",
    "roncareis": "roncar",
    "roncarem": "roncar",
    "roncaremos": "roncar",
    "roncares": "roncar",
    "roncaria": "roncar",
    "roncariam": "roncar",
    "roncarias": "roncaria",
    "roncarmo": "roncar",
    "roncarmos": "roncar",
    "roncará": "roncar",
    "roncarás": "roncar",
    "roncarão": "roncar",
    "roncaríamos": "roncar",
    "roncaríeis": "roncar",
    "roncas": "roncar",
    "roncasse": "roncar",
    "roncassem": "roncar",
    "roncasses": "roncar",
    "roncaste": "roncar",
    "roncastes": "roncar",
    "roncava": "roncar",
    "roncavam": "roncar",
    "roncavas": "roncar",
    "ronceada": "roncear",
    "ronceadas": "roncear",
    "ronceado": "roncear",
    "ronceados": "roncear",
    "ronceai": "roncear",
    "ronceais": "roncear",
    "ronceamo": "roncear",
    "ronceamos": "roncear",
    "ronceando": "roncear",
    "ronceara": "roncear",
    "roncearam": "roncear",
    "roncearas": "roncear",
    "ronceardes": "roncear",
    "roncearei": "roncear",
    "ronceareis": "roncear",
    "roncearem": "roncear",
    "roncearemos": "roncear",
    "ronceares": "roncear",
    "roncearia": "roncear",
    "ronceariam": "roncear",
    "roncearias": "roncear",
    "roncearmo": "roncear",
    "roncearmos": "roncear",
    "ronceará": "roncear",
    "roncearás": "roncear",
    "roncearão": "roncear",
    "roncearíamos": "roncear",
    "roncearíeis": "roncear",
    "ronceasse": "roncear",
    "ronceassem": "roncear",
    "ronceasses": "roncear",
    "ronceaste": "roncear",
    "ronceastes": "roncear",
    "ronceava": "roncear",
    "ronceavam": "roncear",
    "ronceavas": "roncear",
    "ronceei": "roncear",
    "ronceeis": "roncear",
    "ronceemo": "roncear",
    "ronceemos": "roncear",
    "ronceia": "roncear",
    "ronceiam": "roncear",
    "ronceias": "roncear",
    "ronceie": "roncear",
    "ronceiem": "roncear",
    "ronceies": "roncear",
    "ronceio": "roncear",
    "ronceira": "ronceiro",
    "ronceiras": "ronceiro",
    "ronceirices": "ronceirice",
    "ronceirismos": "ronceirismo",
    "ronceiros": "ronceiro",
    "ronceou": "roncear",
    "ronceámo": "roncear",
    "ronceámos": "roncear",
    "ronceáramo": "roncear",
    "ronceáramos": "roncear",
    "ronceáreis": "roncear",
    "ronceásseis": "roncear",
    "ronceássemos": "roncear",
    "ronceávamo": "roncear",
    "ronceávamos": "roncear",
    "ronceáveis": "roncear",
    "ronchas": "roncha",
    "roncices": "roncice",
    "roncinadas": "roncinada",
    "ronco": "roncar",
    "roncolha": "roncolho",
    "roncolhas": "roncolho",
    "roncolhos": "roncolho",
    "roncona": "roncão",
    "ronconas": "roncão",
    "roncos": "ronco",
    "roncou": "roncar",
    "roncámo": "roncar",
    "roncámos": "roncar",
    "roncáramo": "roncar",
    "roncáramos": "roncar",
    "roncáreis": "roncar",
    "roncásseis": "roncar",
    "roncássemos": "roncar",
    "roncávamo": "roncar",
    "roncávamos": "roncar",
    "roncáveis": "roncar",
    "roncões": "roncão",
    "ronda": "rondar",
    "rondada": "rondar",
    "rondadas": "rondar",
    "rondado": "rondar",
    "rondadora": "rondador",
    "rondadoras": "rondador",
    "rondadores": "rondador",
    "rondados": "rondar",
    "rondai": "rondar",
    "rondais": "rondar",
    "rondam": "rondar",
    "rondamo": "rondar",
    "rondamos": "rondar",
    "rondando": "rondar",
    "rondantes": "rondante",
    "rondara": "rondar",
    "rondaram": "rondar",
    "rondaras": "rondar",
    "rondarde": "rondar",
    "rondardes": "rondar",
    "rondare": "rondar",
    "rondarei": "rondar",
    "rondareis": "rondar",
    "rondarem": "rondar",
    "rondaremos": "rondar",
    "rondares": "rondar",
    "rondaria": "rondar",
    "rondariam": "rondar",
    "rondarias": "rondar",
    "rondarmo": "rondar",
    "rondarmos": "rondar",
    "rondará": "rondar",
    "rondarás": "rondar",
    "rondarão": "rondar",
    "rondaríamos": "rondar",
    "rondaríeis": "rondar",
    "rondas": "rondar",
    "rondasse": "rondar",
    "rondassem": "rondar",
    "rondasses": "rondar",
    "rondaste": "rondar",
    "rondastes": "rondar",
    "rondava": "rondar",
    "rondavam": "rondar",
    "rondavas": "rondar",
    "ronde": "rondar",
    "rondeada": "rondear",
    "rondeadas": "rondear",
    "rondeado": "rondear",
    "rondeados": "rondear",
    "rondeai": "rondear",
    "rondeais": "rondear",
    "rondeamo": "rondear",
    "rondeamos": "rondear",
    "rondeando": "rondear",
    "rondeara": "rondear",
    "rondearam": "rondear",
    "rondearas": "rondear",
    "rondeardes": "rondear",
    "rondearei": "rondear",
    "rondeareis": "rondear",
    "rondearem": "rondear",
    "rondearemos": "rondear",
    "rondeares": "rondear",
    "rondearia": "rondear",
    "rondeariam": "rondear",
    "rondearias": "rondear",
    "rondearmo": "rondear",
    "rondearmos": "rondear",
    "rondeará": "rondear",
    "rondearás": "rondear",
    "rondearão": "rondear",
    "rondearíamos": "rondear",
    "rondearíeis": "rondear",
    "rondeasse": "rondear",
    "rondeassem": "rondear",
    "rondeasses": "rondear",
    "rondeaste": "rondear",
    "rondeastes": "rondear",
    "rondeava": "rondear",
    "rondeavam": "rondear",
    "rondeavas": "rondear",
    "rondeei": "rondear",
    "rondeeis": "rondear",
    "rondeemo": "rondear",
    "rondeemos": "rondear",
    "rondei": "rondar",
    "rondeia": "rondear",
    "rondeiam": "rondear",
    "rondeias": "rondear",
    "rondeie": "rondear",
    "rondeiem": "rondear",
    "rondeies": "rondear",
    "rondeio": "rondear",
    "rondeis": "rondar",
    "rondem": "rondar",
    "rondemo": "rondar",
    "rondemos": "rondar",
    "rondeou": "rondear",
    "rondes": "rondar",
    "rondeámo": "rondear",
    "rondeámos": "rondear",
    "rondeáramo": "rondear",
    "rondeáramos": "rondear",
    "rondeáreis": "rondear",
    "rondeásseis": "rondear",
    "rondeássemos": "rondear",
    "rondeávamo": "rondear",
    "rondeávamos": "rondear",
    "rondeáveis": "rondear",
    "rondistas": "rondista",
    "rondo": "rondar",
    "rondos": "rondo",
    "rondou": "rondar",
    "rondá": "rondar",
    "rondámo": "rondar",
    "rondámos": "rondar",
    "rondáramo": "rondar",
    "rondáramos": "rondar",
    "rondárei": "rondar",
    "rondáreis": "rondar",
    "rondásseis": "rondar",
    "rondássemos": "rondar",
    "rondávamo": "rondar",
    "rondávamos": "rondar",
    "rondávei": "rondar",
    "rondáveis": "rondar",
    "rondós": "rondó",
    "rondões": "rondão",
    "ronhas": "ronha",
    "ronhenta": "ronhento",
    "ronhentas": "ronhento",
    "ronhentos": "ronhento",
    "ronhosa": "ronhoso",
    "ronhosas": "ronhoso",
    "ronhosos": "ronhoso",
    "ronque": "roncar",
    "ronqueada": "ronquear",
    "ronqueadas": "ronquear",
    "ronqueado": "ronquear",
    "ronqueados": "ronquear",
    "ronqueai": "ronquear",
    "ronqueais": "ronquear",
    "ronqueamo": "ronquear",
    "ronqueamos": "ronquear",
    "ronqueando": "ronquear",
    "ronqueara": "ronquear",
    "ronquearam": "ronquear",
    "ronquearas": "ronquear",
    "ronquearde": "ronquear",
    "ronqueardes": "ronquear",
    "ronqueare": "ronquear",
    "ronquearei": "ronquear",
    "ronqueareis": "ronquear",
    "ronquearem": "ronquear",
    "ronquearemos": "ronquear",
    "ronqueares": "ronquear",
    "ronquearia": "ronquear",
    "ronqueariam": "ronquear",
    "ronquearias": "ronquear",
    "ronquearmo": "ronquear",
    "ronquearmos": "ronquear",
    "ronqueará": "ronquear",
    "ronquearás": "ronquear",
    "ronquearão": "ronquear",
    "ronquearíamos": "ronquear",
    "ronquearíeis": "ronquear",
    "ronqueasse": "ronquear",
    "ronqueassem": "ronquear",
    "ronqueasses": "ronquear",
    "ronqueaste": "ronquear",
    "ronqueastes": "ronquear",
    "ronqueava": "ronquear",
    "ronqueavam": "ronquear",
    "ronqueavas": "ronquear",
    "ronqueei": "ronquear",
    "ronqueeis": "ronquear",
    "ronqueemo": "ronquear",
    "ronqueemos": "ronquear",
    "ronquei": "roncar",
    "ronqueia": "ronquear",
    "ronqueiam": "ronquear",
    "ronqueias": "ronquear",
    "ronqueie": "ronquear",
    "ronqueiem": "ronquear",
    "ronqueies": "ronquear",
    "ronqueio": "ronquear",
    "ronqueiras": "ronqueira",
    "ronqueis": "roncar",
    "ronqueja": "ronquejar",
    "ronquejada": "ronquejar",
    "ronquejadas": "ronquejar",
    "ronquejado": "ronquejar",
    "ronquejados": "ronquejar",
    "ronquejai": "ronquejar",
    "ronquejais": "ronquejar",
    "ronquejam": "ronquejar",
    "ronquejamo": "ronquejar",
    "ronquejamos": "ronquejar",
    "ronquejando": "ronquejar",
    "ronquejantes": "ronquejante",
    "ronquejara": "ronquejar",
    "ronquejaram": "ronquejar",
    "ronquejaras": "ronquejar",
    "ronquejardes": "ronquejar",
    "ronquejarei": "ronquejar",
    "ronquejareis": "ronquejar",
    "ronquejarem": "ronquejar",
    "ronquejaremos": "ronquejar",
    "ronquejares": "ronquejar",
    "ronquejaria": "ronquejar",
    "ronquejariam": "ronquejar",
    "ronquejarias": "ronquejar",
    "ronquejarmo": "ronquejar",
    "ronquejarmos": "ronquejar",
    "ronquejará": "ronquejar",
    "ronquejarás": "ronquejar",
    "ronquejarão": "ronquejar",
    "ronquejaríamos": "ronquejar",
    "ronquejaríeis": "ronquejar",
    "ronquejas": "ronquejar",
    "ronquejasse": "ronquejar",
    "ronquejassem": "ronquejar",
    "ronquejasses": "ronquejar",
    "ronquejaste": "ronquejar",
    "ronquejastes": "ronquejar",
    "ronquejava": "ronquejar",
    "ronquejavam": "ronquejar",
    "ronquejavas": "ronquejar",
    "ronqueje": "ronquejar",
    "ronquejei": "ronquejar",
    "ronquejeis": "ronquejar",
    "ronquejem": "ronquejar",
    "ronquejemo": "ronquejar",
    "ronquejemos": "ronquejar",
    "ronquejes": "ronquejar",
    "ronquejo": "ronquejar",
    "ronquejou": "ronquejar",
    "ronquejámo": "ronquejar",
    "ronquejámos": "ronquejar",
    "ronquejáramo": "ronquejar",
    "ronquejáramos": "ronquejar",
    "ronquejáreis": "ronquejar",
    "ronquejásseis": "ronquejar",
    "ronquejássemos": "ronquejar",
    "ronquejávamo": "ronquejar",
    "ronquejávamos": "ronquejar",
    "ronquejáveis": "ronquejar",
    "ronquem": "roncar",
    "ronquemos": "roncar",
    "ronquenha": "ronquenho",
    "ronquenhas": "ronquenho",
    "ronquenhos": "ronquenho",
    "ronqueou": "ronquear",
    "ronques": "roncar",
    "ronqueá": "ronquear",
    "ronqueámo": "ronquear",
    "ronqueámos": "ronquear",
    "ronqueáramo": "ronquear",
    "ronqueáramos": "ronquear",
    "ronqueárei": "ronquear",
    "ronqueáreis": "ronquear",
    "ronqueásseis": "ronquear",
    "ronqueássemos": "ronquear",
    "ronqueávamo": "ronquear",
    "ronqueávamos": "ronquear",
    "ronqueávei": "ronquear",
    "ronqueáveis": "ronquear",
    "ronquidos": "ronquido",
    "ronquidões": "ronquidão",
    "ronrona": "ronronar",
    "ronronada": "ronronar",
    "ronronadas": "ronronar",
    "ronronado": "ronronar",
    "ronronados": "ronronar",
    "ronronai": "ronronar",
    "ronronais": "ronronar",
    "ronronam": "ronronar",
    "ronronamo": "ronronar",
    "ronronamos": "ronronar",
    "ronronando": "ronronar",
    "ronronantes": "ronronante",
    "ronronara": "ronronar",
    "ronronaram": "ronronar",
    "ronronaras": "ronronar",
    "ronronardes": "ronronar",
    "ronronarei": "ronronar",
    "ronronareis": "ronronar",
    "ronronarem": "ronronar",
    "ronronaremos": "ronronar",
    "ronronares": "ronronar",
    "ronronaria": "ronronar",
    "ronronariam": "ronronar",
    "ronronarias": "ronronar",
    "ronronarmo": "ronronar",
    "ronronarmos": "ronronar",
    "ronronará": "ronronar",
    "ronronarás": "ronronar",
    "ronronarão": "ronronar",
    "ronronaríamos": "ronronar",
    "ronronaríeis": "ronronar",
    "ronronas": "ronronar",
    "ronronasse": "ronronar",
    "ronronassem": "ronronar",
    "ronronasses": "ronronar",
    "ronronaste": "ronronar",
    "ronronastes": "ronronar",
    "ronronava": "ronronar",
    "ronronavam": "ronronar",
    "ronronavas": "ronronar",
    "ronrone": "ronronar",
    "ronronei": "ronronar",
    "ronroneis": "ronronar",
    "ronronem": "ronronar",
    "ronronemo": "ronronar",
    "ronronemos": "ronronar",
    "ronrones": "ronronar",
    "ronrono": "ronronar",
    "ronronou": "ronronar",
    "ronrons": "ronrom",
    "ronronámo": "ronronar",
    "ronronámos": "ronronar",
    "ronronáramo": "ronronar",
    "ronronáramos": "ronronar",
    "ronronáreis": "ronronar",
    "ronronásseis": "ronronar",
    "ronronássemos": "ronronar",
    "ronronávamo": "ronronar",
    "ronronávamos": "ronronar",
    "ronronáveis": "ronronar",
    "ronçarias": "ronçaria",
    "roo": "roer",
    "ropografias": "ropografia",
    "ropográfica": "ropográfico",
    "ropográficas": "ropográfico",
    "ropográficos": "ropográfico",
    "ropógrafa": "ropógrafo",
    "ropógrafas": "ropógrafo",
    "ropógrafos": "ropógrafo",
    "roque": "rocar",
    "roquei": "rocar",
    "roqueira": "roqueiro",
    "roqueiradas": "roqueirada",
    "roqueiras": "roqueiro",
    "roqueiros": "roqueiro",
    "roqueis": "rocar",
    "roquem": "rocar",
    "roquemos": "rocar",
    "roques": "roque",
    "roquetes": "roquete",
    "roquezinho": "roque",
    "roquezinhos": "roque",
    "roquezito": "roque",
    "roquezitos": "roque",
    "roquinhas": "roquinha",
    "rorantes": "rorante",
    "roreja": "rorejar",
    "rorejada": "rorejar",
    "rorejadas": "rorejar",
    "rorejado": "rorejar",
    "rorejados": "rorejar",
    "rorejai": "rorejar",
    "rorejais": "rorejar",
    "rorejam": "rorejar",
    "rorejamo": "rorejar",
    "rorejamos": "rorejar",
    "rorejando": "rorejar",
    "rorejantes": "rorejante",
    "rorejara": "rorejar",
    "rorejaram": "rorejar",
    "rorejaras": "rorejar",
    "rorejarde": "rorejar",
    "rorejardes": "rorejar",
    "rorejare": "rorejar",
    "rorejarei": "rorejar",
    "rorejareis": "rorejar",
    "rorejarem": "rorejar",
    "rorejaremos": "rorejar",
    "rorejares": "rorejar",
    "rorejaria": "rorejar",
    "rorejariam": "rorejar",
    "rorejarias": "rorejar",
    "rorejarmo": "rorejar",
    "rorejarmos": "rorejar",
    "rorejará": "rorejar",
    "rorejarás": "rorejar",
    "rorejarão": "rorejar",
    "rorejaríamos": "rorejar",
    "rorejaríeis": "rorejar",
    "rorejas": "rorejar",
    "rorejasse": "rorejar",
    "rorejassem": "rorejar",
    "rorejasses": "rorejar",
    "rorejaste": "rorejar",
    "rorejastes": "rorejar",
    "rorejava": "rorejar",
    "rorejavam": "rorejar",
    "rorejavas": "rorejar",
    "roreje": "rorejar",
    "rorejei": "rorejar",
    "rorejeis": "rorejar",
    "rorejem": "rorejar",
    "rorejemo": "rorejar",
    "rorejemos": "rorejar",
    "rorejes": "rorejar",
    "rorejo": "rorejar",
    "rorejos": "rorejo",
    "rorejou": "rorejar",
    "rorejá": "rorejar",
    "rorejámo": "rorejar",
    "rorejámos": "rorejar",
    "rorejáramo": "rorejar",
    "rorejáramos": "rorejar",
    "rorejárei": "rorejar",
    "rorejáreis": "rorejar",
    "rorejásseis": "rorejar",
    "rorejássemos": "rorejar",
    "rorejávamo": "rorejar",
    "rorejávamos": "rorejar",
    "rorejávei": "rorejar",
    "rorejáveis": "rorejar",
    "rorelas": "rorela",
    "rores": "ror",
    "rorquais": "rorqual",
    "rorífera": "rorífero",
    "roríferas": "rorífero",
    "roríferos": "rorífero",
    "roríflua": "rorífluo",
    "rorífluas": "rorífluo",
    "rorífluos": "rorífluo",
    "rosa": "rosar",
    "rosacruciana": "rosacruciano",
    "rosacrucianas": "rosacruciano",
    "rosacrucianos": "rosacruciano",
    "rosada": "rosar",
    "rosadas": "rosar",
    "rosadinha": "rosado",
    "rosadinhas": "rosado",
    "rosadinho": "rosado",
    "rosadinhos": "rosado",
    "rosadita": "rosado",
    "rosaditas": "rosado",
    "rosadito": "rosado",
    "rosaditos": "rosado",
    "rosado": "rosar",
    "rosados": "rosar",
    "rosadíssima": "rosado",
    "rosadíssimas": "rosado",
    "rosadíssimo": "rosado",
    "rosadíssimos": "rosado",
    "rosai": "rosar",
    "rosais": "rosar",
    "rosalgares": "rosalgar",
    "rosam": "rosar",
    "rosamo": "rosar",
    "rosamos": "rosar",
    "rosando": "rosar",
    "rosara": "rosar",
    "rosaram": "rosar",
    "rosaras": "rosar",
    "rosardes": "rosar",
    "rosarei": "rosar",
    "rosareis": "rosar",
    "rosarem": "rosar",
    "rosaremos": "rosar",
    "rosares": "rosar",
    "rosaria": "rosar",
    "rosariam": "rosar",
    "rosarias": "rosar",
    "rosarmo": "rosar",
    "rosarmos": "rosar",
    "rosará": "rosar",
    "rosarás": "rosar",
    "rosarão": "rosar",
    "rosaríamos": "rosar",
    "rosaríeis": "rosar",
    "rosas": "rosar",
    "rosasse": "rosar",
    "rosassem": "rosar",
    "rosasses": "rosar",
    "rosaste": "rosar",
    "rosastes": "rosar",
    "rosava": "rosar",
    "rosavam": "rosar",
    "rosavas": "rosar",
    "rosbifes": "rosbife",
    "rosca": "roscar",
    "roscada": "roscar",
    "roscadas": "roscar",
    "roscado": "roscar",
    "roscados": "roscar",
    "roscai": "roscar",
    "roscais": "roscar",
    "roscam": "roscar",
    "roscamo": "roscar",
    "roscamos": "roscar",
    "roscando": "roscar",
    "roscara": "roscar",
    "roscaram": "roscar",
    "roscaras": "roscar",
    "roscarde": "roscar",
    "roscardes": "roscar",
    "roscare": "roscar",
    "roscarei": "roscar",
    "roscareis": "roscar",
    "roscarem": "roscar",
    "roscaremos": "roscar",
    "roscares": "roscar",
    "roscaria": "roscar",
    "roscariam": "roscar",
    "roscarias": "roscar",
    "roscarmo": "roscar",
    "roscarmos": "roscar",
    "roscará": "roscar",
    "roscarás": "roscar",
    "roscarão": "roscar",
    "roscaríamos": "roscar",
    "roscaríeis": "roscar",
    "roscas": "roscar",
    "roscasse": "roscar",
    "roscassem": "roscar",
    "roscasses": "roscar",
    "roscaste": "roscar",
    "roscastes": "roscar",
    "roscava": "roscar",
    "roscavam": "roscar",
    "roscavas": "roscar",
    "rosco": "roscar",
    "roscou": "roscar",
    "roscá": "roscar",
    "roscámo": "roscar",
    "roscámos": "roscar",
    "roscáramo": "roscar",
    "roscáramos": "roscar",
    "roscárei": "roscar",
    "roscáreis": "roscar",
    "roscásseis": "roscar",
    "roscássemos": "roscar",
    "roscávamo": "roscar",
    "roscávamos": "roscar",
    "roscávei": "roscar",
    "roscáveis": "roscar",
    "rose": "rosar",
    "roseada": "rosear",
    "roseadas": "rosear",
    "roseado": "rosear",
    "roseados": "rosear",
    "roseai": "rosear",
    "roseais": "rosear",
    "roseamo": "rosear",
    "roseamos": "rosear",
    "roseando": "rosear",
    "roseara": "rosear",
    "rosearam": "rosear",
    "rosearas": "rosear",
    "roseardes": "rosear",
    "rosearei": "rosear",
    "roseareis": "rosear",
    "rosearem": "rosear",
    "rosearemos": "rosear",
    "roseares": "rosear",
    "rosearia": "rosear",
    "roseariam": "rosear",
    "rosearias": "rosear",
    "rosearmo": "rosear",
    "rosearmos": "rosear",
    "roseará": "rosear",
    "rosearás": "rosear",
    "rosearão": "rosear",
    "rosearíamos": "rosear",
    "rosearíeis": "rosear",
    "roseasse": "rosear",
    "roseassem": "rosear",
    "roseasses": "rosear",
    "roseaste": "rosear",
    "roseastes": "rosear",
    "roseava": "rosear",
    "roseavam": "rosear",
    "roseavas": "rosear",
    "roseei": "rosear",
    "roseeis": "rosear",
    "roseemo": "rosear",
    "roseemos": "rosear",
    "rosei": "rosar",
    "roseia": "rosear",
    "roseiam": "rosear",
    "roseias": "rosear",
    "roseie": "rosear",
    "roseiem": "rosear",
    "roseies": "rosear",
    "roseio": "rosear",
    "roseirais": "roseiral",
    "roseiras": "roseira",
    "roseiristas": "roseirista",
    "roseis": "rosar",
    "roselhas": "roselha",
    "rosem": "rosar",
    "rosemo": "rosar",
    "rosemos": "rosar",
    "roseou": "rosear",
    "roses": "rosar",
    "rosetas": "roseta",
    "rosetes": "rosete",
    "rosetões": "rosetão",
    "roseámo": "rosear",
    "roseámos": "rosear",
    "roseáramo": "rosear",
    "roseáramos": "rosear",
    "roseáreis": "rosear",
    "roseásseis": "rosear",
    "roseássemos": "rosear",
    "roseávamo": "rosear",
    "roseávamos": "rosear",
    "roseáveis": "rosear",
    "rosiclera": "rosicler",
    "rosicleras": "rosicler",
    "rosicleres": "rosicler",
    "rosiflores": "rosiflor",
    "rosilha": "rosilho",
    "rosilhas": "rosilho",
    "rosilhos": "rosilho",
    "rosinha": "rosa",
    "rosinhas": "rosinha",
    "rosita": "rosa",
    "rositas": "rosa",
    "rosmaninhais": "rosmaninhal",
    "rosmaninhos": "rosmaninho",
    "rosmaninos": "rosmanino",
    "rosmanos": "rosmano",
    "rosmarinhos": "rosmarinho",
    "rosna": "rosnar",
    "rosnada": "rosnar",
    "rosnadas": "rosnar",
    "rosnadelas": "rosnadela",
    "rosnado": "rosnar",
    "rosnadora": "rosnador",
    "rosnadoras": "rosnador",
    "rosnadores": "rosnador",
    "rosnados": "rosnar",
    "rosnaduras": "rosnadura",
    "rosnai": "rosnar",
    "rosnais": "rosnar",
    "rosnam": "rosnar",
    "rosnamo": "rosnar",
    "rosnamos": "rosnar",
    "rosnando": "rosnar",
    "rosnara": "rosnar",
    "rosnaram": "rosnar",
    "rosnaras": "rosnar",
    "rosnardes": "rosnar",
    "rosnarei": "rosnar",
    "rosnareis": "rosnar",
    "rosnarem": "rosnar",
    "rosnaremos": "rosnar",
    "rosnares": "rosnar",
    "rosnaria": "rosnar",
    "rosnariam": "rosnar",
    "rosnarias": "rosnar",
    "rosnarmo": "rosnar",
    "rosnarmos": "rosnar",
    "rosnará": "rosnar",
    "rosnarás": "rosnar",
    "rosnarão": "rosnar",
    "rosnaríamos": "rosnar",
    "rosnaríeis": "rosnar",
    "rosnas": "rosnar",
    "rosnasse": "rosnar",
    "rosnassem": "rosnar",
    "rosnasses": "rosnar",
    "rosnaste": "rosnar",
    "rosnastes": "rosnar",
    "rosnava": "rosnar",
    "rosnavam": "rosnar",
    "rosnavas": "rosnar",
    "rosne": "rosnar",
    "rosnei": "rosnar",
    "rosneis": "rosnar",
    "rosnem": "rosnar",
    "rosnemo": "rosnar",
    "rosnemos": "rosnar",
    "rosnenta": "rosnento",
    "rosnentas": "rosnento",
    "rosnentos": "rosnento",
    "rosnes": "rosnar",
    "rosnidos": "rosnido",
    "rosno": "rosnar",
    "rosnou": "rosnar",
    "rosnámo": "rosnar",
    "rosnámos": "rosnar",
    "rosnáramo": "rosnar",
    "rosnáramos": "rosnar",
    "rosnáreis": "rosnar",
    "rosnásseis": "rosnar",
    "rosnássemos": "rosnar",
    "rosnávamo": "rosnar",
    "rosnávamos": "rosnar",
    "rosnáveis": "rosnar",
    "roso": "rosar",
    "rosou": "rosar",
    "rosque": "roscar",
    "rosqueada": "rosquear",
    "rosqueadas": "rosquear",
    "rosqueado": "rosquear",
    "rosqueados": "rosquear",
    "rosqueai": "rosquear",
    "rosqueais": "rosquear",
    "rosqueamo": "rosquear",
    "rosqueamos": "rosquear",
    "rosqueando": "rosquear",
    "rosqueara": "rosquear",
    "rosquearam": "rosquear",
    "rosquearas": "rosquear",
    "rosqueardes": "rosquear",
    "rosquearei": "rosquear",
    "rosqueareis": "rosquear",
    "rosquearem": "rosquear",
    "rosquearemos": "rosquear",
    "rosqueares": "rosquear",
    "rosquearia": "rosquear",
    "rosqueariam": "rosquear",
    "rosquearias": "rosquear",
    "rosquearmo": "rosquear",
    "rosquearmos": "rosquear",
    "rosqueará": "rosquear",
    "rosquearás": "rosquear",
    "rosquearão": "rosquear",
    "rosquearíamos": "rosquear",
    "rosquearíeis": "rosquear",
    "rosqueasse": "rosquear",
    "rosqueassem": "rosquear",
    "rosqueasses": "rosquear",
    "rosqueaste": "rosquear",
    "rosqueastes": "rosquear",
    "rosqueava": "rosquear",
    "rosqueavam": "rosquear",
    "rosqueavas": "rosquear",
    "rosqueei": "rosquear",
    "rosqueeis": "rosquear",
    "rosqueemo": "rosquear",
    "rosqueemos": "rosquear",
    "rosquei": "roscar",
    "rosqueia": "rosquear",
    "rosqueiam": "rosquear",
    "rosqueias": "rosquear",
    "rosqueie": "rosquear",
    "rosqueiem": "rosquear",
    "rosqueies": "rosquear",
    "rosqueio": "rosquear",
    "rosqueis": "roscar",
    "rosquem": "roscar",
    "rosquemo": "roscar",
    "rosquemos": "roscar",
    "rosqueou": "rosquear",
    "rosques": "roscar",
    "rosqueámo": "rosquear",
    "rosqueámos": "rosquear",
    "rosqueáramo": "rosquear",
    "rosqueáramos": "rosquear",
    "rosqueáreis": "rosquear",
    "rosqueásseis": "rosquear",
    "rosqueássemos": "rosquear",
    "rosqueávamo": "rosquear",
    "rosqueávamos": "rosquear",
    "rosqueáveis": "rosquear",
    "rosquilhas": "rosquilha",
    "rosquilhos": "rosquilho",
    "rosquinha": "rosca",
    "rosquinhas": "rosca",
    "rosquita": "rosca",
    "rosquitas": "rosca",
    "rossios": "rossio",
    "rosta": "rostir",
    "rostais": "rostir",
    "rostam": "rostir",
    "rostamo": "rostir",
    "rostamos": "rostir",
    "rostas": "rostir",
    "roste": "rostir",
    "rostem": "rostir",
    "rostes": "rostir",
    "rosti": "rostir",
    "rostia": "rostir",
    "rostiam": "rostir",
    "rostias": "rostir",
    "rostida": "rostir",
    "rostidas": "rostir",
    "rostido": "rostir",
    "rostidos": "rostir",
    "rostilhadas": "rostilhada",
    "rostimo": "rostir",
    "rostimos": "rostir",
    "rostindo": "rostir",
    "rostinho": "rosto",
    "rostinhos": "rosto",
    "rostira": "rostir",
    "rostiram": "rostir",
    "rostiras": "rostir",
    "rostirde": "rostir",
    "rostirdes": "rostir",
    "rostire": "rostir",
    "rostirei": "rostir",
    "rostireis": "rostir",
    "rostirem": "rostir",
    "rostiremos": "rostir",
    "rostires": "rostir",
    "rostiria": "rostir",
    "rostiriam": "rostir",
    "rostirias": "rostir",
    "rostirmo": "rostir",
    "rostirmos": "rostir",
    "rostirá": "rostir",
    "rostirás": "rostir",
    "rostirão": "rostir",
    "rostiríamos": "rostir",
    "rostiríeis": "rostir",
    "rostis": "rostir",
    "rostisse": "rostir",
    "rostissem": "rostir",
    "rostisses": "rostir",
    "rostiste": "rostir",
    "rostistes": "rostir",
    "rostito": "rosto",
    "rostitos": "rosto",
    "rostiu": "rostir",
    "rosto": "rostir",
    "rostolhos": "rostolho",
    "rostos": "rosto",
    "rostozinho": "rosto",
    "rostozinhos": "rosto",
    "rostozito": "rosto",
    "rostozitos": "rosto",
    "rostrada": "rostrado",
    "rostradas": "rostrado",
    "rostrados": "rostrado",
    "rostrais": "rostral",
    "rostricórnea": "rostricórneo",
    "rostricórneas": "rostricórneo",
    "rostricórneos": "rostricórneo",
    "rostriformes": "rostriforme",
    "rostrilhos": "rostrilho",
    "rostros": "rostro",
    "rostrífera": "rostrífero",
    "rostríferas": "rostrífero",
    "rostríferos": "rostrífero",
    "rostíamo": "rostir",
    "rostíamos": "rostir",
    "rostíei": "rostir",
    "rostíeis": "rostir",
    "rostíramo": "rostir",
    "rostíramos": "rostir",
    "rostírei": "rostir",
    "rostíreis": "rostir",
    "rostísseis": "rostir",
    "rostíssemos": "rostir",
    "rosácea": "rosáceo",
    "rosáceas": "rosáceo",
    "rosáceos": "rosáceo",
    "rosálias": "rosália",
    "rosámo": "rosar",
    "rosámos": "rosar",
    "rosáramo": "rosar",
    "rosáramos": "rosar",
    "rosáreis": "rosar",
    "rosários": "rosário",
    "rosásseis": "rosar",
    "rosássemos": "rosar",
    "rosávamo": "rosar",
    "rosávamos": "rosar",
    "rosáveis": "rosar",
    "roséolas": "roséola",
    "rosés": "rosé",
    "rosólios": "rosólio",
    "rota": "roto",
    "rotacionais": "rotacional",
    "rotacismos": "rotacismo",
    "rotada": "rotar",
    "rotadas": "rotar",
    "rotado": "rotar",
    "rotadora": "rotador",
    "rotadoras": "rotador",
    "rotadores": "rotador",
    "rotados": "rotar",
    "rotai": "rotar",
    "rotais": "rotar",
    "rotam": "rotar",
    "rotamo": "rotar",
    "rotamos": "rotar",
    "rotando": "rotar",
    "rotantes": "rotante",
    "rotara": "rotar",
    "rotaram": "rotar",
    "rotaras": "rotar",
    "rotardes": "rotar",
    "rotarei": "rotar",
    "rotareis": "rotar",
    "rotarem": "rotar",
    "rotaremos": "rotar",
    "rotares": "rotar",
    "rotaria": "rotar",
    "rotariam": "rotar",
    "rotarias": "rotar",
    "rotarmo": "rotar",
    "rotarmos": "rotar",
    "rotará": "rotar",
    "rotarás": "rotar",
    "rotarão": "rotar",
    "rotaríamos": "rotar",
    "rotaríeis": "rotar",
    "rotas": "roto",
    "rotasse": "rotar",
    "rotassem": "rotar",
    "rotasses": "rotar",
    "rotaste": "rotar",
    "rotastes": "rotar",
    "rotativa": "rotativo",
    "rotativada": "rotativar",
    "rotativadas": "rotativar",
    "rotativado": "rotativar",
    "rotativados": "rotativar",
    "rotativai": "rotativar",
    "rotativais": "rotativar",
    "rotativam": "rotativar",
    "rotativamo": "rotativar",
    "rotativamos": "rotativar",
    "rotativando": "rotativar",
    "rotativara": "rotativar",
    "rotativaram": "rotativar",
    "rotativaras": "rotativar",
    "rotativardes": "rotativar",
    "rotativarei": "rotativar",
    "rotativareis": "rotativar",
    "rotativarem": "rotativar",
    "rotativaremos": "rotativar",
    "rotativares": "rotativar",
    "rotativaria": "rotativar",
    "rotativariam": "rotativar",
    "rotativarias": "rotativar",
    "rotativarmo": "rotativar",
    "rotativarmos": "rotativar",
    "rotativará": "rotativar",
    "rotativarás": "rotativar",
    "rotativarão": "rotativar",
    "rotativaríamos": "rotativar",
    "rotativaríeis": "rotativar",
    "rotativas": "rotativo",
    "rotativasse": "rotativar",
    "rotativassem": "rotativar",
    "rotativasses": "rotativar",
    "rotativaste": "rotativar",
    "rotativastes": "rotativar",
    "rotativava": "rotativar",
    "rotativavam": "rotativar",
    "rotativavas": "rotativar",
    "rotative": "rotativar",
    "rotativei": "rotativar",
    "rotativeis": "rotativar",
    "rotativem": "rotativar",
    "rotativemo": "rotativar",
    "rotativemos": "rotativar",
    "rotatives": "rotativar",
    "rotatividades": "rotatividade",
    "rotativismos": "rotativismo",
    "rotativistas": "rotativista",
    "rotativo": "rotativar",
    "rotativos": "rotativo",
    "rotativou": "rotativar",
    "rotativámo": "rotativar",
    "rotativámos": "rotativar",
    "rotativáramo": "rotativar",
    "rotativáramos": "rotativar",
    "rotativáreis": "rotativar",
    "rotativásseis": "rotativar",
    "rotativássemos": "rotativar",
    "rotativávamo": "rotativar",
    "rotativávamos": "rotativar",
    "rotativáveis": "rotativar",
    "rotatória": "rotatório",
    "rotatórias": "rotatório",
    "rotatórios": "rotatório",
    "rotava": "rotar",
    "rotavam": "rotar",
    "rotavas": "rotar",
    "rotazinha": "roto",
    "rotazinhas": "roto",
    "rotazita": "roto",
    "rotazitas": "roto",
    "rotações": "rotação",
    "rote": "rotar",
    "roteada": "rotear",
    "roteadas": "rotear",
    "roteado": "rotear",
    "roteados": "rotear",
    "roteai": "rotear",
    "roteais": "rotear",
    "roteamo": "rotear",
    "roteamos": "rotear",
    "roteando": "rotear",
    "roteara": "rotear",
    "rotearam": "rotear",
    "rotearas": "rotear",
    "roteardes": "rotear",
    "rotearei": "rotear",
    "roteareis": "rotear",
    "rotearem": "rotear",
    "rotearemos": "rotear",
    "roteares": "rotear",
    "rotearia": "rotear",
    "roteariam": "rotear",
    "rotearias": "rotearia",
    "rotearmo": "rotear",
    "rotearmos": "rotear",
    "roteará": "rotear",
    "rotearás": "rotear",
    "rotearão": "rotear",
    "rotearíamos": "rotear",
    "rotearíeis": "rotear",
    "roteasse": "rotear",
    "roteassem": "rotear",
    "roteasses": "rotear",
    "roteaste": "rotear",
    "roteastes": "rotear",
    "roteava": "rotear",
    "roteavam": "rotear",
    "roteavas": "rotear",
    "roteei": "rotear",
    "roteeis": "rotear",
    "roteemo": "rotear",
    "roteemos": "rotear",
    "rotei": "rotar",
    "roteia": "rotear",
    "roteiam": "rotear",
    "roteias": "roteia",
    "roteie": "rotear",
    "roteiem": "rotear",
    "roteies": "rotear",
    "roteio": "rotear",
    "roteiristas": "roteirista",
    "roteiros": "roteiro",
    "roteis": "rotar",
    "rotem": "rotar",
    "rotemo": "rotar",
    "rotemos": "rotar",
    "rotenonas": "rotenona",
    "roteou": "rotear",
    "rotes": "rotar",
    "roteámo": "rotear",
    "roteámos": "rotear",
    "roteáramo": "rotear",
    "roteáramos": "rotear",
    "roteáreis": "rotear",
    "roteásseis": "rotear",
    "roteássemos": "rotear",
    "roteávamo": "rotear",
    "roteávamos": "rotear",
    "roteáveis": "rotear",
    "rotfones": "rotfone",
    "rotiformes": "rotiforme",
    "rotinas": "rotina",
    "rotineira": "rotineiro",
    "rotineiras": "rotineiro",
    "rotineiros": "rotineiro",
    "rotinha": "roto",
    "rotinhas": "roto",
    "rotinho": "roto",
    "rotinhos": "roto",
    "rotins": "rotim",
    "rotita": "roto",
    "rotitas": "roto",
    "rotito": "roto",
    "rotitos": "roto",
    "roto": "rotar",
    "rotogravuras": "rotogravura",
    "rotores": "rotor",
    "rotos": "roto",
    "rotou": "rotar",
    "rotozinho": "roto",
    "rotozinhos": "roto",
    "rotozito": "roto",
    "rotozitos": "roto",
    "rots": "rot",
    "rotula": "rotular",
    "rotulada": "rotular",
    "rotuladas": "rotular",
    "rotulado": "rotular",
    "rotulados": "rotular",
    "rotulagens": "rotulagem",
    "rotulai": "rotular",
    "rotulais": "rotular",
    "rotulam": "rotular",
    "rotulamo": "rotular",
    "rotulamos": "rotular",
    "rotulando": "rotular",
    "rotulara": "rotular",
    "rotularam": "rotular",
    "rotularas": "rotular",
    "rotularde": "rotular",
    "rotulardes": "rotular",
    "rotulare": "rotular",
    "rotularei": "rotular",
    "rotulareis": "rotular",
    "rotularem": "rotular",
    "rotularemos": "rotular",
    "rotulares": "rotular",
    "rotularia": "rotular",
    "rotulariam": "rotular",
    "rotularias": "rotular",
    "rotularmo": "rotular",
    "rotularmos": "rotular",
    "rotulará": "rotular",
    "rotularás": "rotular",
    "rotularão": "rotular",
    "rotularíamos": "rotular",
    "rotularíeis": "rotular",
    "rotulas": "rotular",
    "rotulasse": "rotular",
    "rotulassem": "rotular",
    "rotulasses": "rotular",
    "rotulaste": "rotular",
    "rotulastes": "rotular",
    "rotulava": "rotular",
    "rotulavam": "rotular",
    "rotulavas": "rotular",
    "rotulações": "rotulação",
    "rotule": "rotular",
    "rotulei": "rotular",
    "rotuleis": "rotular",
    "rotulem": "rotular",
    "rotulemo": "rotular",
    "rotulemos": "rotular",
    "rotules": "rotular",
    "rotulo": "rotular",
    "rotulou": "rotular",
    "rotulá": "rotular",
    "rotulámo": "rotular",
    "rotulámos": "rotular",
    "rotuláramo": "rotular",
    "rotuláramos": "rotular",
    "rotulárei": "rotular",
    "rotuláreis": "rotular",
    "rotulásseis": "rotular",
    "rotulássemos": "rotular",
    "rotulávamo": "rotular",
    "rotulávamos": "rotular",
    "rotulávei": "rotular",
    "rotuláveis": "rotulável",
    "rotunda": "rotundo",
    "rotundas": "rotundo",
    "rotundicola": "rotundicolo",
    "rotundicolas": "rotundicolo",
    "rotundicolos": "rotundicolo",
    "rotundidades": "rotundidade",
    "rotundos": "rotundo",
    "rotundíssima": "rotundo",
    "rotundíssimas": "rotundo",
    "rotundíssimo": "rotundo",
    "rotundíssimos": "rotundo",
    "roturas": "rotura",
    "rotácea": "rotáceo",
    "rotáceas": "rotáceo",
    "rotáceos": "rotáceo",
    "rotámo": "rotar",
    "rotámos": "rotar",
    "rotáramo": "rotar",
    "rotáramos": "rotar",
    "rotáreis": "rotar",
    "rotária": "rotário",
    "rotárias": "rotário",
    "rotários": "rotário",
    "rotásseis": "rotar",
    "rotássemos": "rotar",
    "rotávamo": "rotar",
    "rotávamos": "rotar",
    "rotáveis": "rotar",
    "rotâmetros": "rotâmetro",
    "rotífera": "rotífero",
    "rotíferas": "rotífero",
    "rotíferos": "rotífero",
    "rotíssima": "roto",
    "rotíssimas": "roto",
    "rotíssimo": "roto",
    "rotíssimos": "roto",
    "rouba": "roubar",
    "roubada": "roubar",
    "roubadas": "roubar",
    "roubado": "roubar",
    "roubadora": "roubador",
    "roubadoras": "roubador",
    "roubadores": "roubador",
    "roubados": "roubar",
    "roubai": "roubar",
    "roubais": "roubar",
    "roubalheiras": "roubalheira",
    "roubam": "roubar",
    "roubamo": "roubar",
    "roubamos": "roubar",
    "roubando": "roubar",
    "roubara": "roubar",
    "roubaram": "roubar",
    "roubaras": "roubar",
    "roubarde": "roubar",
    "roubardes": "roubar",
    "roubare": "roubar",
    "roubarei": "roubar",
    "roubareis": "roubar",
    "roubarem": "roubar",
    "roubaremos": "roubar",
    "roubares": "roubar",
    "roubaria": "roubar",
    "roubariam": "roubar",
    "roubarias": "roubar",
    "roubarmo": "roubar",
    "roubarmos": "roubar",
    "roubará": "roubar",
    "roubarás": "roubar",
    "roubarão": "roubar",
    "roubaríamos": "roubar",
    "roubaríeis": "roubar",
    "roubas": "roubar",
    "roubasse": "roubar",
    "roubassem": "roubar",
    "roubasses": "roubar",
    "roubaste": "roubar",
    "roubastes": "roubar",
    "roubava": "roubar",
    "roubavam": "roubar",
    "roubavas": "roubar",
    "roube": "roubar",
    "roubei": "roubar",
    "roubeis": "roubar",
    "roubem": "roubar",
    "roubemo": "roubar",
    "roubemos": "roubar",
    "roubes": "roubar",
    "roubo": "roubar",
    "roubos": "roubo",
    "roubou": "roubar",
    "roubá": "roubar",
    "roubámo": "roubar",
    "roubámos": "roubar",
    "roubáramo": "roubar",
    "roubáramos": "roubar",
    "roubárei": "roubar",
    "roubáreis": "roubar",
    "roubásseis": "roubar",
    "roubássemos": "roubar",
    "roubávamo": "roubar",
    "roubávamos": "roubar",
    "roubávei": "roubar",
    "roubáveis": "roubável",
    "rouca": "rouco",
    "roucas": "rouco",
    "roucazinha": "rouco",
    "roucazinhas": "rouco",
    "roucazita": "rouco",
    "roucazitas": "rouco",
    "roucos": "rouco",
    "roucozinho": "rouco",
    "roucozinhos": "rouco",
    "roucozito": "rouco",
    "roucozitos": "rouco",
    "roufenha": "roufenho",
    "roufenhada": "roufenhar",
    "roufenhadas": "roufenhar",
    "roufenhado": "roufenhar",
    "roufenhados": "roufenhar",
    "roufenhai": "roufenhar",
    "roufenhais": "roufenhar",
    "roufenham": "roufenhar",
    "roufenhamo": "roufenhar",
    "roufenhamos": "roufenhar",
    "roufenhando": "roufenhar",
    "roufenhara": "roufenhar",
    "roufenharam": "roufenhar",
    "roufenharas": "roufenhar",
    "roufenhardes": "roufenhar",
    "roufenharei": "roufenhar",
    "roufenhareis": "roufenhar",
    "roufenharem": "roufenhar",
    "roufenharemos": "roufenhar",
    "roufenhares": "roufenhar",
    "roufenharia": "roufenhar",
    "roufenhariam": "roufenhar",
    "roufenharias": "roufenhar",
    "roufenharmo": "roufenhar",
    "roufenharmos": "roufenhar",
    "roufenhará": "roufenhar",
    "roufenharás": "roufenhar",
    "roufenharão": "roufenhar",
    "roufenharíamos": "roufenhar",
    "roufenharíeis": "roufenhar",
    "roufenhas": "roufenho",
    "roufenhasse": "roufenhar",
    "roufenhassem": "roufenhar",
    "roufenhasses": "roufenhar",
    "roufenhaste": "roufenhar",
    "roufenhastes": "roufenhar",
    "roufenhava": "roufenhar",
    "roufenhavam": "roufenhar",
    "roufenhavas": "roufenhar",
    "roufenhe": "roufenhar",
    "roufenhei": "roufenhar",
    "roufenheis": "roufenhar",
    "roufenhem": "roufenhar",
    "roufenhemo": "roufenhar",
    "roufenhemos": "roufenhar",
    "roufenhes": "roufenhar",
    "roufenho": "roufenhar",
    "roufenhos": "roufenho",
    "roufenhou": "roufenhar",
    "roufenhámo": "roufenhar",
    "roufenhámos": "roufenhar",
    "roufenháramo": "roufenhar",
    "roufenháramos": "roufenhar",
    "roufenháreis": "roufenhar",
    "roufenhásseis": "roufenhar",
    "roufenhássemos": "roufenhar",
    "roufenhávamo": "roufenhar",
    "roufenhávamos": "roufenhar",
    "roufenháveis": "roufenhar",
    "roulottes": "roulotte",
    "rounds": "round",
    "roupa": "roupar",
    "roupada": "roupar",
    "roupadas": "roupar",
    "roupado": "roupar",
    "roupados": "roupar",
    "roupagens": "roupagem",
    "roupai": "roupar",
    "roupais": "roupar",
    "roupam": "roupar",
    "roupamo": "roupar",
    "roupamos": "roupar",
    "roupando": "roupar",
    "roupara": "roupar",
    "rouparam": "roupar",
    "rouparas": "roupar",
    "roupardes": "roupar",
    "rouparei": "roupar",
    "roupareis": "roupar",
    "rouparem": "roupar",
    "rouparemos": "roupar",
    "roupares": "roupar",
    "rouparia": "roupar",
    "roupariam": "roupar",
    "rouparias": "rouparia",
    "rouparmo": "roupar",
    "rouparmos": "roupar",
    "roupará": "roupar",
    "rouparás": "roupar",
    "rouparão": "roupar",
    "rouparíamos": "roupar",
    "rouparíeis": "roupar",
    "roupas": "roupar",
    "roupasse": "roupar",
    "roupassem": "roupar",
    "roupasses": "roupar",
    "roupaste": "roupar",
    "roupastes": "roupar",
    "roupava": "roupar",
    "roupavam": "roupar",
    "roupavas": "roupar",
    "roupe": "roupar",
    "roupei": "roupar",
    "roupeira": "roupeiro",
    "roupeiras": "roupeiro",
    "roupeiros": "roupeiro",
    "roupeis": "roupar",
    "roupem": "roupar",
    "roupemo": "roupar",
    "roupemos": "roupar",
    "roupes": "roupar",
    "roupetas": "roupeta",
    "roupida": "roupido",
    "roupidas": "roupido",
    "roupidos": "roupido",
    "roupinha": "roupa",
    "roupinhas": "roupinha",
    "roupita": "roupa",
    "roupitas": "roupa",
    "roupo": "roupar",
    "roupou": "roupar",
    "roupámo": "roupar",
    "roupámos": "roupar",
    "roupáramo": "roupar",
    "roupáramos": "roupar",
    "roupáreis": "roupar",
    "roupásseis": "roupar",
    "roupássemos": "roupar",
    "roupávamo": "roupar",
    "roupávamos": "roupar",
    "roupáveis": "roupar",
    "roupões": "roupão",
    "rouqueiras": "rouqueira",
    "rouqueja": "rouquejar",
    "rouquejada": "rouquejar",
    "rouquejadas": "rouquejar",
    "rouquejado": "rouquejar",
    "rouquejados": "rouquejar",
    "rouquejai": "rouquejar",
    "rouquejais": "rouquejar",
    "rouquejam": "rouquejar",
    "rouquejamo": "rouquejar",
    "rouquejamos": "rouquejar",
    "rouquejando": "rouquejar",
    "rouquejara": "rouquejar",
    "rouquejaram": "rouquejar",
    "rouquejaras": "rouquejar",
    "rouquejardes": "rouquejar",
    "rouquejarei": "rouquejar",
    "rouquejareis": "rouquejar",
    "rouquejarem": "rouquejar",
    "rouquejaremos": "rouquejar",
    "rouquejares": "rouquejar",
    "rouquejaria": "rouquejar",
    "rouquejariam": "rouquejar",
    "rouquejarias": "rouquejar",
    "rouquejarmo": "rouquejar",
    "rouquejarmos": "rouquejar",
    "rouquejará": "rouquejar",
    "rouquejarás": "rouquejar",
    "rouquejarão": "rouquejar",
    "rouquejaríamos": "rouquejar",
    "rouquejaríeis": "rouquejar",
    "rouquejas": "rouquejar",
    "rouquejasse": "rouquejar",
    "rouquejassem": "rouquejar",
    "rouquejasses": "rouquejar",
    "rouquejaste": "rouquejar",
    "rouquejastes": "rouquejar",
    "rouquejava": "rouquejar",
    "rouquejavam": "rouquejar",
    "rouquejavas": "rouquejar",
    "rouqueje": "rouquejar",
    "rouquejei": "rouquejar",
    "rouquejeis": "rouquejar",
    "rouquejem": "rouquejar",
    "rouquejemo": "rouquejar",
    "rouquejemos": "rouquejar",
    "rouquejes": "rouquejar",
    "rouquejo": "rouquejar",
    "rouquejou": "rouquejar",
    "rouquejámo": "rouquejar",
    "rouquejámos": "rouquejar",
    "rouquejáramo": "rouquejar",
    "rouquejáramos": "rouquejar",
    "rouquejáreis": "rouquejar",
    "rouquejásseis": "rouquejar",
    "rouquejássemos": "rouquejar",
    "rouquejávamo": "rouquejar",
    "rouquejávamos": "rouquejar",
    "rouquejáveis": "rouquejar",
    "rouquenha": "rouquenho",
    "rouquenhas": "rouquenho",
    "rouquenhos": "rouquenho",
    "rouquices": "rouquice",
    "rouquidos": "rouquido",
    "rouquidões": "rouquidão",
    "rouquinha": "rouco",
    "rouquinhas": "rouco",
    "rouquinho": "rouco",
    "rouquinhos": "rouco",
    "rouquita": "rouco",
    "rouquitas": "rouco",
    "rouquito": "rouco",
    "rouquitos": "rouco",
    "rouquíssima": "rouco",
    "rouquíssimas": "rouco",
    "rouquíssimo": "rouco",
    "rouquíssimos": "rouco",
    "roussa": "roussar",
    "roussada": "roussar",
    "roussadas": "roussar",
    "roussado": "roussar",
    "roussados": "roussar",
    "roussai": "roussar",
    "roussais": "roussar",
    "roussam": "roussar",
    "roussamo": "roussar",
    "roussamos": "roussar",
    "roussando": "roussar",
    "roussara": "roussar",
    "roussaram": "roussar",
    "roussaras": "roussar",
    "roussarde": "roussar",
    "roussardes": "roussar",
    "roussare": "roussar",
    "roussarei": "roussar",
    "roussareis": "roussar",
    "roussarem": "roussar",
    "roussaremos": "roussar",
    "roussares": "roussar",
    "roussaria": "roussar",
    "roussariam": "roussar",
    "roussarias": "roussar",
    "roussarmo": "roussar",
    "roussarmos": "roussar",
    "roussará": "roussar",
    "roussarás": "roussar",
    "roussarão": "roussar",
    "roussaríamos": "roussar",
    "roussaríeis": "roussar",
    "roussas": "roussar",
    "roussasse": "roussar",
    "roussassem": "roussar",
    "roussasses": "roussar",
    "roussaste": "roussar",
    "roussastes": "roussar",
    "roussava": "roussar",
    "roussavam": "roussar",
    "roussavas": "roussar",
    "rousse": "roussar",
    "roussei": "roussar",
    "rousseis": "roussar",
    "roussem": "roussar",
    "roussemo": "roussar",
    "roussemos": "roussar",
    "rousses": "roussar",
    "rousso": "roussar",
    "roussos": "rousso",
    "roussou": "roussar",
    "roussá": "roussar",
    "roussámo": "roussar",
    "roussámos": "roussar",
    "roussáramo": "roussar",
    "roussáramos": "roussar",
    "roussárei": "roussar",
    "roussáreis": "roussar",
    "roussásseis": "roussar",
    "roussássemos": "roussar",
    "roussávamo": "roussar",
    "roussávamos": "roussar",
    "roussávei": "roussar",
    "roussáveis": "roussar",
    "rouxinoleada": "rouxinolear",
    "rouxinoleadas": "rouxinolear",
    "rouxinoleado": "rouxinolear",
    "rouxinoleados": "rouxinolear",
    "rouxinoleai": "rouxinolear",
    "rouxinoleais": "rouxinolear",
    "rouxinoleamo": "rouxinolear",
    "rouxinoleamos": "rouxinolear",
    "rouxinoleando": "rouxinolear",
    "rouxinoleara": "rouxinolear",
    "rouxinolearam": "rouxinolear",
    "rouxinolearas": "rouxinolear",
    "rouxinoleardes": "rouxinolear",
    "rouxinolearei": "rouxinolear",
    "rouxinoleareis": "rouxinolear",
    "rouxinolearem": "rouxinolear",
    "rouxinolearemos": "rouxinolear",
    "rouxinoleares": "rouxinolear",
    "rouxinolearia": "rouxinolear",
    "rouxinoleariam": "rouxinolear",
    "rouxinolearias": "rouxinolear",
    "rouxinolearmo": "rouxinolear",
    "rouxinolearmos": "rouxinolear",
    "rouxinoleará": "rouxinolear",
    "rouxinolearás": "rouxinolear",
    "rouxinolearão": "rouxinolear",
    "rouxinolearíamos": "rouxinolear",
    "rouxinolearíeis": "rouxinolear",
    "rouxinoleasse": "rouxinolear",
    "rouxinoleassem": "rouxinolear",
    "rouxinoleasses": "rouxinolear",
    "rouxinoleaste": "rouxinolear",
    "rouxinoleastes": "rouxinolear",
    "rouxinoleava": "rouxinolear",
    "rouxinoleavam": "rouxinolear",
    "rouxinoleavas": "rouxinolear",
    "rouxinoleei": "rouxinolear",
    "rouxinoleeis": "rouxinolear",
    "rouxinoleemo": "rouxinolear",
    "rouxinoleemos": "rouxinolear",
    "rouxinoleia": "rouxinolear",
    "rouxinoleiam": "rouxinolear",
    "rouxinoleias": "rouxinolear",
    "rouxinoleie": "rouxinolear",
    "rouxinoleiem": "rouxinolear",
    "rouxinoleies": "rouxinolear",
    "rouxinoleio": "rouxinolear",
    "rouxinoleou": "rouxinolear",
    "rouxinoleámo": "rouxinolear",
    "rouxinoleámos": "rouxinolear",
    "rouxinoleáramo": "rouxinolear",
    "rouxinoleáramos": "rouxinolear",
    "rouxinoleáreis": "rouxinolear",
    "rouxinoleásseis": "rouxinolear",
    "rouxinoleássemos": "rouxinolear",
    "rouxinoleávamo": "rouxinolear",
    "rouxinoleávamos": "rouxinolear",
    "rouxinoleáveis": "rouxinolear",
    "rouxinóis": "rouxinol",
    "rouços": "rouço",
    "roxa": "roxo",
    "roxas": "roxo",
    "roxazinha": "roxo",
    "roxazinhas": "roxo",
    "roxazita": "roxo",
    "roxazitas": "roxo",
    "roxeada": "roxear",
    "roxeadas": "roxear",
    "roxeado": "roxear",
    "roxeados": "roxear",
    "roxeai": "roxear",
    "roxeais": "roxear",
    "roxeamo": "roxear",
    "roxeamos": "roxear",
    "roxeando": "roxear",
    "roxeara": "roxear",
    "roxearam": "roxear",
    "roxearas": "roxear",
    "roxearde": "roxear",
    "roxeardes": "roxear",
    "roxeare": "roxear",
    "roxearei": "roxear",
    "roxeareis": "roxear",
    "roxearem": "roxear",
    "roxearemos": "roxear",
    "roxeares": "roxear",
    "roxearia": "roxear",
    "roxeariam": "roxear",
    "roxearias": "roxear",
    "roxearmo": "roxear",
    "roxearmos": "roxear",
    "roxeará": "roxear",
    "roxearás": "roxear",
    "roxearão": "roxear",
    "roxearíamos": "roxear",
    "roxearíeis": "roxear",
    "roxeasse": "roxear",
    "roxeassem": "roxear",
    "roxeasses": "roxear",
    "roxeaste": "roxear",
    "roxeastes": "roxear",
    "roxeava": "roxear",
    "roxeavam": "roxear",
    "roxeavas": "roxear",
    "roxeei": "roxear",
    "roxeeis": "roxear",
    "roxeemo": "roxear",
    "roxeemos": "roxear",
    "roxeia": "roxear",
    "roxeiam": "roxear",
    "roxeias": "roxear",
    "roxeie": "roxear",
    "roxeiem": "roxear",
    "roxeies": "roxear",
    "roxeio": "roxear",
    "roxeou": "roxear",
    "roxeá": "roxear",
    "roxeámo": "roxear",
    "roxeámos": "roxear",
    "roxeáramo": "roxear",
    "roxeáramos": "roxear",
    "roxeárei": "roxear",
    "roxeáreis": "roxear",
    "roxeásseis": "roxear",
    "roxeássemos": "roxear",
    "roxeávamo": "roxear",
    "roxeávamos": "roxear",
    "roxeávei": "roxear",
    "roxeáveis": "roxear",
    "roxidões": "roxidão",
    "roxinha": "roxo",
    "roxinhas": "roxo",
    "roxinho": "roxo",
    "roxinhos": "roxo",
    "roxita": "roxo",
    "roxitas": "roxo",
    "roxito": "roxo",
    "roxitos": "roxo",
    "roxos": "roxo",
    "roxozinho": "roxo",
    "roxozinhos": "roxo",
    "roxozito": "roxo",
    "roxozitos": "roxo",
    "roxíssima": "roxo",
    "roxíssimas": "roxo",
    "roxíssimo": "roxo",
    "roxíssimos": "roxo",
    "royalities": "royality",
    "roça": "roçar",
    "roçada": "roçar",
    "roçadas": "roçar",
    "roçadazinha": "roçado",
    "roçadazinhas": "roçado",
    "roçadazita": "roçado",
    "roçadazitas": "roçado",
    "roçadeira": "roçadeiro",
    "roçadeiras": "roçadeiro",
    "roçadeiros": "roçadeiro",
    "roçadelas": "roçadela",
    "roçadinha": "roçado",
    "roçadinhas": "roçado",
    "roçadinho": "roçado",
    "roçadinhos": "roçado",
    "roçadita": "roçado",
    "roçaditas": "roçado",
    "roçadito": "roçado",
    "roçaditos": "roçado",
    "roçado": "roçar",
    "roçadoira": "roçadoiro",
    "roçadoiras": "roçadoiro",
    "roçadoiros": "roçadoiro",
    "roçadora": "roçador",
    "roçadoras": "roçador",
    "roçadores": "roçador",
    "roçados": "roçar",
    "roçadoura": "roçadouro",
    "roçadouras": "roçadouro",
    "roçadouros": "roçadouro",
    "roçadozinho": "roçado",
    "roçadozinhos": "roçado",
    "roçadozito": "roçado",
    "roçadozitos": "roçado",
    "roçaduras": "roçadura",
    "roçadíssima": "roçado",
    "roçadíssimas": "roçado",
    "roçadíssimo": "roçado",
    "roçadíssimos": "roçado",
    "roçaga": "roçagar",
    "roçagada": "roçagar",
    "roçagadas": "roçagar",
    "roçagado": "roçagar",
    "roçagados": "roçagar",
    "roçagai": "roçagar",
    "roçagais": "roçagar",
    "roçagam": "roçagar",
    "roçagamo": "roçagar",
    "roçagamos": "roçagar",
    "roçagando": "roçagar",
    "roçagantes": "roçagante",
    "roçagar": "agar",
    "roçagara": "roçagar",
    "roçagaram": "roçagar",
    "roçagaras": "roçagar",
    "roçagardes": "roçagar",
    "roçagarei": "roçagar",
    "roçagareis": "roçagar",
    "roçagarem": "roçagar",
    "roçagaremos": "roçagar",
    "roçagares": "roçagar",
    "roçagaria": "roçagar",
    "roçagariam": "roçagar",
    "roçagarias": "roçagar",
    "roçagarmo": "roçagar",
    "roçagarmos": "roçagar",
    "roçagará": "roçagar",
    "roçagarás": "roçagar",
    "roçagarão": "roçagar",
    "roçagaríamos": "roçagar",
    "roçagaríeis": "roçagar",
    "roçagas": "roçagar",
    "roçagasse": "roçagar",
    "roçagassem": "roçagar",
    "roçagasses": "roçagar",
    "roçagaste": "roçagar",
    "roçagastes": "roçagar",
    "roçagava": "roçagar",
    "roçagavam": "roçagar",
    "roçagavas": "roçagar",
    "roçago": "roçagar",
    "roçagou": "roçagar",
    "roçague": "roçagar",
    "roçaguei": "roçagar",
    "roçagueis": "roçagar",
    "roçaguem": "roçagar",
    "roçaguemo": "roçagar",
    "roçaguemos": "roçagar",
    "roçagues": "roçagar",
    "roçagámo": "roçagar",
    "roçagámos": "roçagar",
    "roçagáramo": "roçagar",
    "roçagáramos": "roçagar",
    "roçagáreis": "roçagar",
    "roçagásseis": "roçagar",
    "roçagássemos": "roçagar",
    "roçagávamo": "roçagar",
    "roçagávamos": "roçagar",
    "roçagáveis": "roçagar",
    "roçai": "roçar",
    "roçais": "roçar",
    "roçam": "roçar",
    "roçamentos": "roçamento",
    "roçamo": "roçar",
    "roçamos": "roçar",
    "roçando": "roçar",
    "roçara": "roçar",
    "roçaram": "roçar",
    "roçaras": "roçar",
    "roçarde": "roçar",
    "roçardes": "roçar",
    "roçare": "roçar",
    "roçarei": "roçar",
    "roçareis": "roçar",
    "roçarem": "roçar",
    "roçaremos": "roçar",
    "roçares": "roçar",
    "roçaria": "roçar",
    "roçariam": "roçar",
    "roçarias": "roçar",
    "roçarmo": "roçar",
    "roçarmos": "roçar",
    "roçará": "roçar",
    "roçarás": "roçar",
    "roçarão": "roçar",
    "roçaríamos": "roçar",
    "roçaríeis": "roçar",
    "roças": "roçar",
    "roçasse": "roçar",
    "roçassem": "roçar",
    "roçasses": "roçar",
    "roçaste": "roçar",
    "roçastes": "roçar",
    "roçava": "roçar",
    "roçavam": "roçar",
    "roçavas": "roçar",
    "roço": "roçar",
    "roços": "roço",
    "roçou": "roçar",
    "roçá": "roçar",
    "roçámo": "roçar",
    "roçámos": "roçar",
    "roçáramo": "roçar",
    "roçáramos": "roçar",
    "roçárei": "roçar",
    "roçáreis": "roçar",
    "roçásseis": "roçar",
    "roçássemos": "roçar",
    "roçávamo": "roçar",
    "roçávamos": "roçar",
    "roçávei": "roçar",
    "roçáveis": "roçar",
    "roê": "roer",
    "roêramo": "roer",
    "roêramos": "roer",
    "roêrei": "roer",
    "roêreis": "roer",
    "roêsseis": "roer",
    "roêssemos": "roer",
    "roí": "roer",
    "roía": "roer",
    "roíam": "roer",
    "roíamo": "roer",
    "roíamos": "roer",
    "roías": "roer",
    "roída": "roído",
    "roídas": "roído",
    "roído": "roer",
    "roídos": "roído",
    "roíei": "roer",
    "roíeis": "roer",
    "rua": "ruir",
    "ruaceira": "ruaceiro",
    "ruaceiras": "ruaceiro",
    "ruaceiros": "ruaceiro",
    "ruais": "ruir",
    "ruam": "ruir",
    "ruamo": "ruir",
    "ruamos": "ruir",
    "ruana": "ruano",
    "ruanas": "ruano",
    "ruandesa": "ruandês",
    "ruandesas": "ruandês",
    "ruandeses": "ruandês",
    "ruanos": "ruano",
    "ruantes": "ruante",
    "ruas": "ruir",
    "ruazinha": "rua",
    "ruazinhas": "rua",
    "ruazita": "rua",
    "ruazitas": "rua",
    "rubefacientes": "rubefaciente",
    "rubefacções": "rubefacção",
    "rubeja": "rubejar",
    "rubejada": "rubejar",
    "rubejadas": "rubejar",
    "rubejado": "rubejar",
    "rubejados": "rubejar",
    "rubejai": "rubejar",
    "rubejais": "rubejar",
    "rubejam": "rubejar",
    "rubejamo": "rubejar",
    "rubejamos": "rubejar",
    "rubejando": "rubejar",
    "rubejara": "rubejar",
    "rubejaram": "rubejar",
    "rubejaras": "rubejar",
    "rubejardes": "rubejar",
    "rubejarei": "rubejar",
    "rubejareis": "rubejar",
    "rubejarem": "rubejar",
    "rubejaremos": "rubejar",
    "rubejares": "rubejar",
    "rubejaria": "rubejar",
    "rubejariam": "rubejar",
    "rubejarias": "rubejar",
    "rubejarmo": "rubejar",
    "rubejarmos": "rubejar",
    "rubejará": "rubejar",
    "rubejarás": "rubejar",
    "rubejarão": "rubejar",
    "rubejaríamos": "rubejar",
    "rubejaríeis": "rubejar",
    "rubejas": "rubejar",
    "rubejasse": "rubejar",
    "rubejassem": "rubejar",
    "rubejasses": "rubejar",
    "rubejaste": "rubejar",
    "rubejastes": "rubejar",
    "rubejava": "rubejar",
    "rubejavam": "rubejar",
    "rubejavas": "rubejar",
    "rubeje": "rubejar",
    "rubejei": "rubejar",
    "rubejeis": "rubejar",
    "rubejem": "rubejar",
    "rubejemo": "rubejar",
    "rubejemos": "rubejar",
    "rubejes": "rubejar",
    "rubejo": "rubejar",
    "rubejou": "rubejar",
    "rubejámo": "rubejar",
    "rubejámos": "rubejar",
    "rubejáramo": "rubejar",
    "rubejáramos": "rubejar",
    "rubejáreis": "rubejar",
    "rubejásseis": "rubejar",
    "rubejássemos": "rubejar",
    "rubejávamo": "rubejar",
    "rubejávamos": "rubejar",
    "rubejáveis": "rubejar",
    "rubelites": "rubelite",
    "rubentes": "rubente",
    "rubesce": "rubescer",
    "rubescei": "rubescer",
    "rubesceis": "rubescer",
    "rubescem": "rubescer",
    "rubescemo": "rubescer",
    "rubescemos": "rubescer",
    "rubescendo": "rubescer",
    "rubescentes": "rubescente",
    "rubescera": "rubescer",
    "rubesceram": "rubescer",
    "rubesceras": "rubescer",
    "rubescerdes": "rubescer",
    "rubescerei": "rubescer",
    "rubescereis": "rubescer",
    "rubescerem": "rubescer",
    "rubesceremos": "rubescer",
    "rubesceres": "rubescer",
    "rubesceria": "rubescer",
    "rubesceriam": "rubescer",
    "rubescerias": "rubescer",
    "rubescermo": "rubescer",
    "rubescermos": "rubescer",
    "rubescerá": "rubescer",
    "rubescerás": "rubescer",
    "rubescerão": "rubescer",
    "rubesceríamos": "rubescer",
    "rubesceríeis": "rubescer",
    "rubesces": "rubescer",
    "rubescesse": "rubescer",
    "rubescessem": "rubescer",
    "rubescesses": "rubescer",
    "rubesceste": "rubescer",
    "rubescestes": "rubescer",
    "rubesceu": "rubescer",
    "rubesci": "rubescer",
    "rubescia": "rubescer",
    "rubesciam": "rubescer",
    "rubescias": "rubescer",
    "rubescida": "rubescer",
    "rubescidas": "rubescer",
    "rubescido": "rubescer",
    "rubescidos": "rubescer",
    "rubescências": "rubescência",
    "rubescêramo": "rubescer",
    "rubescêramos": "rubescer",
    "rubescêreis": "rubescer",
    "rubescêsseis": "rubescer",
    "rubescêssemos": "rubescer",
    "rubescíamo": "rubescer",
    "rubescíamos": "rubescer",
    "rubescíeis": "rubescer",
    "rubesça": "rubescer",
    "rubesçais": "rubescer",
    "rubesçam": "rubescer",
    "rubesçamo": "rubescer",
    "rubesçamos": "rubescer",
    "rubesças": "rubescer",
    "rubesço": "rubescer",
    "rubicunda": "rubicundo",
    "rubicundas": "rubicundo",
    "rubicundos": "rubicundo",
    "rubicões": "rubicão",
    "rubifica": "rubificar",
    "rubificada": "rubificar",
    "rubificadas": "rubificar",
    "rubificado": "rubificar",
    "rubificados": "rubificar",
    "rubificai": "rubificar",
    "rubificais": "rubificar",
    "rubificam": "rubificar",
    "rubificamo": "rubificar",
    "rubificamos": "rubificar",
    "rubificando": "rubificar",
    "rubificantes": "rubificante",
    "rubificara": "rubificar",
    "rubificaram": "rubificar",
    "rubificaras": "rubificar",
    "rubificarde": "rubificar",
    "rubificardes": "rubificar",
    "rubificare": "rubificar",
    "rubificarei": "rubificar",
    "rubificareis": "rubificar",
    "rubificarem": "rubificar",
    "rubificaremos": "rubificar",
    "rubificares": "rubificar",
    "rubificaria": "rubificar",
    "rubificariam": "rubificar",
    "rubificarias": "rubificar",
    "rubificarmo": "rubificar",
    "rubificarmos": "rubificar",
    "rubificará": "rubificar",
    "rubificarás": "rubificar",
    "rubificarão": "rubificar",
    "rubificaríamos": "rubificar",
    "rubificaríeis": "rubificar",
    "rubificas": "rubificar",
    "rubificasse": "rubificar",
    "rubificassem": "rubificar",
    "rubificasses": "rubificar",
    "rubificaste": "rubificar",
    "rubificastes": "rubificar",
    "rubificava": "rubificar",
    "rubificavam": "rubificar",
    "rubificavas": "rubificar",
    "rubificações": "rubificação",
    "rubifico": "rubificar",
    "rubificou": "rubificar",
    "rubificá": "rubificar",
    "rubificámo": "rubificar",
    "rubificámos": "rubificar",
    "rubificáramo": "rubificar",
    "rubificáramos": "rubificar",
    "rubificárei": "rubificar",
    "rubificáreis": "rubificar",
    "rubificásseis": "rubificar",
    "rubificássemos": "rubificar",
    "rubificávamo": "rubificar",
    "rubificávamos": "rubificar",
    "rubificávei": "rubificar",
    "rubificáveis": "rubificar",
    "rubifique": "rubificar",
    "rubifiquei": "rubificar",
    "rubifiqueis": "rubificar",
    "rubifiquem": "rubificar",
    "rubifiquemo": "rubificar",
    "rubifiquemos": "rubificar",
    "rubifiques": "rubificar",
    "rubiformes": "rubiforme",
    "rubigens": "rubigem",
    "rubiginosa": "rubiginoso",
    "rubiginosas": "rubiginoso",
    "rubiginosos": "rubiginoso",
    "rubinas": "rubina",
    "rubins": "rubim",
    "rubinéctares": "rubinéctar",
    "rubis": "rubi",
    "rubiácea": "rubiáceo",
    "rubiáceas": "rubiáceo",
    "rubiáceos": "rubiáceo",
    "rublos": "rublo",
    "rubores": "rubor",
    "ruboresce": "ruborescer",
    "ruborescei": "ruborescer",
    "ruboresceis": "ruborescer",
    "ruborescem": "ruborescer",
    "ruborescemo": "ruborescer",
    "ruborescemos": "ruborescer",
    "ruborescendo": "ruborescer",
    "ruborescera": "ruborescer",
    "ruboresceram": "ruborescer",
    "ruboresceras": "ruborescer",
    "ruborescerdes": "ruborescer",
    "ruborescerei": "ruborescer",
    "ruborescereis": "ruborescer",
    "ruborescerem": "ruborescer",
    "ruboresceremos": "ruborescer",
    "ruboresceres": "ruborescer",
    "ruboresceria": "ruborescer",
    "ruboresceriam": "ruborescer",
    "ruborescerias": "ruborescer",
    "ruborescermo": "ruborescer",
    "ruborescermos": "ruborescer",
    "ruborescerá": "ruborescer",
    "ruborescerás": "ruborescer",
    "ruborescerão": "ruborescer",
    "ruboresceríamos": "ruborescer",
    "ruboresceríeis": "ruborescer",
    "ruboresces": "ruborescer",
    "ruborescesse": "ruborescer",
    "ruborescessem": "ruborescer",
    "ruborescesses": "ruborescer",
    "ruboresceste": "ruborescer",
    "ruborescestes": "ruborescer",
    "ruboresceu": "ruborescer",
    "ruboresci": "ruborescer",
    "ruborescia": "ruborescer",
    "ruboresciam": "ruborescer",
    "ruborescias": "ruborescer",
    "ruborescida": "ruborescido",
    "ruborescidas": "ruborescido",
    "ruborescido": "ruborescer",
    "ruborescidos": "ruborescido",
    "ruborescêramo": "ruborescer",
    "ruborescêramos": "ruborescer",
    "ruborescêreis": "ruborescer",
    "ruborescêsseis": "ruborescer",
    "ruborescêssemos": "ruborescer",
    "ruborescíamo": "ruborescer",
    "ruborescíamos": "ruborescer",
    "ruborescíeis": "ruborescer",
    "ruboresça": "ruborescer",
    "ruboresçais": "ruborescer",
    "ruboresçam": "ruborescer",
    "ruboresçamo": "ruborescer",
    "ruboresçamos": "ruborescer",
    "ruboresças": "ruborescer",
    "ruboresço": "ruborescer",
    "ruboriza": "ruborizar",
    "ruborizada": "ruborizar",
    "ruborizadas": "ruborizar",
    "ruborizado": "ruborizar",
    "ruborizados": "ruborizar",
    "ruborizai": "ruborizar",
    "ruborizais": "ruborizar",
    "ruborizam": "ruborizar",
    "ruborizamo": "ruborizar",
    "ruborizamos": "ruborizar",
    "ruborizando": "ruborizar",
    "ruborizara": "ruborizar",
    "ruborizaram": "ruborizar",
    "ruborizaras": "ruborizar",
    "ruborizarde": "ruborizar",
    "ruborizardes": "ruborizar",
    "ruborizare": "ruborizar",
    "ruborizarei": "ruborizar",
    "ruborizareis": "ruborizar",
    "ruborizarem": "ruborizar",
    "ruborizaremos": "ruborizar",
    "ruborizares": "ruborizar",
    "ruborizaria": "ruborizar",
    "ruborizariam": "ruborizar",
    "ruborizarias": "ruborizar",
    "ruborizarmo": "ruborizar",
    "ruborizarmos": "ruborizar",
    "ruborizará": "ruborizar",
    "ruborizarás": "ruborizar",
    "ruborizarão": "ruborizar",
    "ruborizaríamos": "ruborizar",
    "ruborizaríeis": "ruborizar",
    "ruborizas": "ruborizar",
    "ruborizasse": "ruborizar",
    "ruborizassem": "ruborizar",
    "ruborizasses": "ruborizar",
    "ruborizaste": "ruborizar",
    "ruborizastes": "ruborizar",
    "ruborizava": "ruborizar",
    "ruborizavam": "ruborizar",
    "ruborizavas": "ruborizar",
    "ruborizações": "ruborização",
    "ruborize": "ruborizar",
    "ruborizei": "ruborizar",
    "ruborizeis": "ruborizar",
    "ruborizem": "ruborizar",
    "ruborizemo": "ruborizar",
    "ruborizemos": "ruborizar",
    "ruborizes": "ruborizar",
    "ruborizo": "ruborizar",
    "ruborizou": "ruborizar",
    "ruborizá": "ruborizar",
    "ruborizámo": "ruborizar",
    "ruborizámos": "ruborizar",
    "ruborizáramo": "ruborizar",
    "ruborizáramos": "ruborizar",
    "ruborizárei": "ruborizar",
    "ruborizáreis": "ruborizar",
    "ruborizásseis": "ruborizar",
    "ruborizássemos": "ruborizar",
    "ruborizávamo": "ruborizar",
    "ruborizávamos": "ruborizar",
    "ruborizávei": "ruborizar",
    "ruborizáveis": "ruborizar",
    "ruborzinho": "rubor",
    "ruborzinhos": "rubor",
    "ruborzito": "rubor",
    "ruborzitos": "rubor",
    "rubos": "rubo",
    "rubra": "rubro",
    "rubras": "rubro",
    "rubrica": "rubricar",
    "rubricada": "rubricar",
    "rubricadas": "rubricar",
    "rubricado": "rubricar",
    "rubricadora": "rubricador",
    "rubricadoras": "rubricador",
    "rubricadores": "rubricador",
    "rubricados": "rubricar",
    "rubricai": "rubricar",
    "rubricais": "rubricar",
    "rubricam": "rubricar",
    "rubricamo": "rubricar",
    "rubricamos": "rubricar",
    "rubricando": "rubricar",
    "rubricara": "rubricar",
    "rubricaram": "rubricar",
    "rubricaras": "rubricar",
    "rubricarde": "rubricar",
    "rubricardes": "rubricar",
    "rubricare": "rubricar",
    "rubricarei": "rubricar",
    "rubricareis": "rubricar",
    "rubricarem": "rubricar",
    "rubricaremos": "rubricar",
    "rubricares": "rubricar",
    "rubricaria": "rubricar",
    "rubricariam": "rubricar",
    "rubricarias": "rubricar",
    "rubricarmo": "rubricar",
    "rubricarmos": "rubricar",
    "rubricará": "rubricar",
    "rubricarás": "rubricar",
    "rubricarão": "rubricar",
    "rubricaríamos": "rubricar",
    "rubricaríeis": "rubricar",
    "rubricas": "rubricar",
    "rubricasse": "rubricar",
    "rubricassem": "rubricar",
    "rubricasses": "rubricar",
    "rubricaste": "rubricar",
    "rubricastes": "rubricar",
    "rubricaules": "rubricaule",
    "rubricava": "rubricar",
    "rubricavam": "rubricar",
    "rubricavas": "rubricar",
    "rubricistas": "rubricista",
    "rubrico": "rubricar",
    "rubricola": "rubricolo",
    "rubricolas": "rubricolo",
    "rubricolos": "rubricolo",
    "rubricou": "rubricar",
    "rubricá": "rubricar",
    "rubricámo": "rubricar",
    "rubricámos": "rubricar",
    "rubricáramo": "rubricar",
    "rubricáramos": "rubricar",
    "rubricárei": "rubricar",
    "rubricáreis": "rubricar",
    "rubricásseis": "rubricar",
    "rubricássemos": "rubricar",
    "rubricávamo": "rubricar",
    "rubricávamos": "rubricar",
    "rubricávei": "rubricar",
    "rubricáveis": "rubricar",
    "rubricórnea": "rubricórneo",
    "rubricórneas": "rubricórneo",
    "rubricórneos": "rubricórneo",
    "rubriflora": "rubrifloro",
    "rubrifloras": "rubrifloro",
    "rubrifloros": "rubrifloro",
    "rubrigastra": "rubrigastro",
    "rubrigastras": "rubrigastro",
    "rubrigastros": "rubrigastro",
    "rubrique": "rubricar",
    "rubriquei": "rubricar",
    "rubriqueis": "rubricar",
    "rubriquem": "rubricar",
    "rubriquemo": "rubricar",
    "rubriquemos": "rubricar",
    "rubriques": "rubricar",
    "rubrirrostra": "rubrirrostro",
    "rubrirrostras": "rubrirrostro",
    "rubrirrostros": "rubrirrostro",
    "rubros": "rubro",
    "rubrípedes": "rubrípede",
    "rubéolas": "rubéola",
    "rubídios": "rubídio",
    "ruce": "ruçar",
    "rucei": "ruçar",
    "ruceis": "ruçar",
    "rucem": "ruçar",
    "rucemo": "ruçar",
    "rucemos": "ruçar",
    "ruces": "ruçar",
    "rucilha": "rucilho",
    "rucilhas": "rucilho",
    "rucilhos": "rucilho",
    "ruda": "rudo",
    "rudas": "rudo",
    "rudes": "rude",
    "rudezas": "rudeza",
    "rudimentais": "rudimental",
    "rudimentares": "rudimentar",
    "rudimentos": "rudimento",
    "rudistas": "rudista",
    "rudos": "rudo",
    "rudíssima": "rude",
    "rudíssimas": "rude",
    "rudíssimo": "rude",
    "rudíssimos": "rude",
    "rudões": "rudão",
    "rueira": "rueiro",
    "rueiras": "rueiro",
    "rueiros": "rueiro",
    "ruelas": "ruela",
    "ruem": "ruir",
    "rufa": "rufo",
    "rufada": "rufar",
    "rufadas": "rufar",
    "rufadelas": "rufadela",
    "rufado": "rufar",
    "rufadora": "rufador",
    "rufadoras": "rufador",
    "rufadores": "rufador",
    "rufados": "rufar",
    "rufai": "rufar",
    "rufais": "rufar",
    "rufam": "rufar",
    "rufamo": "rufar",
    "rufamos": "rufar",
    "rufando": "rufar",
    "rufara": "rufar",
    "rufaram": "rufar",
    "rufaras": "rufar",
    "rufarde": "rufar",
    "rufardes": "rufar",
    "rufare": "rufar",
    "rufarei": "rufar",
    "rufareis": "rufar",
    "rufarem": "rufar",
    "rufaremos": "rufar",
    "rufares": "rufar",
    "rufaria": "rufar",
    "rufariam": "rufar",
    "rufarias": "rufar",
    "rufarmo": "rufar",
    "rufarmos": "rufar",
    "rufará": "rufar",
    "rufarás": "rufar",
    "rufarão": "rufar",
    "rufaríamos": "rufar",
    "rufaríeis": "rufar",
    "rufas": "rufo",
    "rufasse": "rufar",
    "rufassem": "rufar",
    "rufasses": "rufar",
    "rufaste": "rufar",
    "rufastes": "rufar",
    "rufava": "rufar",
    "rufavam": "rufar",
    "rufavas": "rufar",
    "rufe": "rufar",
    "rufei": "rufar",
    "rufeis": "rufar",
    "rufem": "rufar",
    "rufemo": "rufar",
    "rufemos": "rufar",
    "rufes": "rufar",
    "rufia": "rufiar",
    "rufiada": "rufiar",
    "rufiadas": "rufiar",
    "rufiado": "rufiar",
    "rufiados": "rufiar",
    "rufiai": "rufiar",
    "rufiais": "rufiar",
    "rufiam": "rufiar",
    "rufiamo": "rufiar",
    "rufiamos": "rufiar",
    "rufianazes": "rufianaz",
    "rufiando": "rufiar",
    "rufianismos": "rufianismo",
    "rufiara": "rufiar",
    "rufiaram": "rufiar",
    "rufiaras": "rufiar",
    "rufiardes": "rufiar",
    "rufiarei": "rufiar",
    "rufiareis": "rufiar",
    "rufiarem": "rufiar",
    "rufiaremos": "rufiar",
    "rufiares": "rufiar",
    "rufiaria": "rufiar",
    "rufiariam": "rufiar",
    "rufiarias": "rufiar",
    "rufiarmo": "rufiar",
    "rufiarmos": "rufiar",
    "rufiará": "rufiar",
    "rufiarás": "rufiar",
    "rufiarão": "rufiar",
    "rufiaríamos": "rufiar",
    "rufiaríeis": "rufiar",
    "rufias": "rufiar",
    "rufiasse": "rufiar",
    "rufiassem": "rufiar",
    "rufiasses": "rufiar",
    "rufiaste": "rufiar",
    "rufiastes": "rufiar",
    "rufiava": "rufiar",
    "rufiavam": "rufiar",
    "rufiavas": "rufiar",
    "ruficarpa": "ruficarpo",
    "ruficarpas": "ruficarpo",
    "ruficarpos": "ruficarpo",
    "ruficórnea": "ruficórneo",
    "ruficórneas": "ruficórneo",
    "ruficórneos": "ruficórneo",
    "rufie": "rufiar",
    "rufiei": "rufiar",
    "rufieis": "rufiar",
    "rufiem": "rufiar",
    "rufiemo": "rufiar",
    "rufiemos": "rufiar",
    "rufies": "rufiar",
    "rufigastra": "rufigastro",
    "rufigastras": "rufigastro",
    "rufigastros": "rufigastro",
    "rufinérvea": "rufinérveo",
    "rufinérveas": "rufinérveo",
    "rufinérveos": "rufinérveo",
    "rufio": "rufiar",
    "rufiona": "rufião",
    "rufionas": "rufião",
    "rufiou": "rufiar",
    "rufistas": "rufista",
    "rufitarsa": "rufitarso",
    "rufitarsas": "rufitarso",
    "rufitarsos": "rufitarso",
    "rufiámo": "rufiar",
    "rufiámos": "rufiar",
    "rufiáramo": "rufiar",
    "rufiáramos": "rufiar",
    "rufiáreis": "rufiar",
    "rufiásseis": "rufiar",
    "rufiássemos": "rufiar",
    "rufiávamo": "rufiar",
    "rufiávamos": "rufiar",
    "rufiáveis": "rufiar",
    "rufiões": "rufião",
    "rufla": "ruflar",
    "ruflada": "ruflar",
    "rufladas": "ruflar",
    "ruflado": "ruflar",
    "ruflados": "ruflar",
    "ruflai": "ruflar",
    "ruflais": "ruflar",
    "ruflam": "ruflar",
    "ruflamo": "ruflar",
    "ruflamos": "ruflar",
    "ruflando": "ruflar",
    "ruflara": "ruflar",
    "ruflaram": "ruflar",
    "ruflaras": "ruflar",
    "ruflarde": "ruflar",
    "ruflardes": "ruflar",
    "ruflare": "ruflar",
    "ruflarei": "ruflar",
    "ruflareis": "ruflar",
    "ruflarem": "ruflar",
    "ruflaremos": "ruflar",
    "ruflares": "ruflar",
    "ruflaria": "ruflar",
    "ruflariam": "ruflar",
    "ruflarias": "ruflar",
    "ruflarmo": "ruflar",
    "ruflarmos": "ruflar",
    "ruflará": "ruflar",
    "ruflarás": "ruflar",
    "ruflarão": "ruflar",
    "ruflaríamos": "ruflar",
    "ruflaríeis": "ruflar",
    "ruflas": "ruflar",
    "ruflasse": "ruflar",
    "ruflassem": "ruflar",
    "ruflasses": "ruflar",
    "ruflaste": "ruflar",
    "ruflastes": "ruflar",
    "ruflava": "ruflar",
    "ruflavam": "ruflar",
    "ruflavas": "ruflar",
    "rufle": "ruflar",
    "ruflei": "ruflar",
    "rufleis": "ruflar",
    "ruflem": "ruflar",
    "ruflemo": "ruflar",
    "ruflemos": "ruflar",
    "rufles": "ruflar",
    "ruflo": "ruflar",
    "ruflos": "ruflo",
    "ruflou": "ruflar",
    "ruflá": "ruflar",
    "ruflámo": "ruflar",
    "ruflámos": "ruflar",
    "rufláramo": "ruflar",
    "rufláramos": "ruflar",
    "ruflárei": "ruflar",
    "rufláreis": "ruflar",
    "ruflásseis": "ruflar",
    "ruflássemos": "ruflar",
    "ruflávamo": "ruflar",
    "ruflávamos": "ruflar",
    "ruflávei": "ruflar",
    "rufláveis": "ruflar",
    "rufo": "rufar",
    "rufos": "rufo",
    "rufou": "rufar",
    "rufá": "rufar",
    "rufámo": "rufar",
    "rufámos": "rufar",
    "rufáramo": "rufar",
    "rufáramos": "rufar",
    "rufárei": "rufar",
    "rufáreis": "rufar",
    "rufásseis": "rufar",
    "rufássemos": "rufar",
    "rufávamo": "rufar",
    "rufávamos": "rufar",
    "rufávei": "rufar",
    "rufáveis": "rufar",
    "ruga": "rugar",
    "rugada": "rugar",
    "rugadas": "rugar",
    "rugado": "rugar",
    "rugados": "rugar",
    "rugai": "rugar",
    "rugais": "rugar",
    "rugam": "rugar",
    "rugamo": "rugar",
    "rugamos": "rugar",
    "rugando": "rugar",
    "rugara": "rugar",
    "rugaram": "rugar",
    "rugaras": "rugar",
    "rugarde": "rugar",
    "rugardes": "rugar",
    "rugare": "rugar",
    "rugarei": "rugar",
    "rugareis": "rugar",
    "rugarem": "rugar",
    "rugaremos": "rugar",
    "rugares": "rugar",
    "rugaria": "rugar",
    "rugariam": "rugar",
    "rugarias": "rugar",
    "rugarmo": "rugar",
    "rugarmos": "rugar",
    "rugará": "rugar",
    "rugarás": "rugar",
    "rugarão": "rugar",
    "rugaríamos": "rugar",
    "rugaríeis": "rugar",
    "rugas": "rugar",
    "rugasse": "rugar",
    "rugassem": "rugar",
    "rugasses": "rugar",
    "rugaste": "rugar",
    "rugastes": "rugar",
    "rugava": "rugar",
    "rugavam": "rugar",
    "rugavas": "rugar",
    "ruge": "rugir",
    "rugem": "rugir",
    "ruges": "rugir",
    "rugi": "rugir",
    "rugia": "rugir",
    "rugiam": "rugir",
    "rugias": "rugir",
    "rugida": "rugir",
    "rugidas": "rugir",
    "rugido": "rugir",
    "rugidora": "rugidor",
    "rugidoras": "rugidor",
    "rugidores": "rugidor",
    "rugidos": "rugir",
    "rugientes": "rugiente",
    "rugimo": "rugir",
    "rugimos": "rugir",
    "ruginas": "rugina",
    "rugindo": "rugir",
    "rugira": "rugir",
    "rugiram": "rugir",
    "rugiras": "rugir",
    "rugirdes": "rugir",
    "rugirei": "rugir",
    "rugireis": "rugir",
    "rugirem": "rugir",
    "rugiremos": "rugir",
    "rugires": "rugir",
    "rugiria": "rugir",
    "rugiriam": "rugir",
    "rugirias": "rugir",
    "rugirmo": "rugir",
    "rugirmos": "rugir",
    "rugirá": "rugir",
    "rugirás": "rugir",
    "rugirão": "rugir",
    "rugiríamos": "rugir",
    "rugiríeis": "rugir",
    "rugis": "rugir",
    "rugisse": "rugir",
    "rugissem": "rugir",
    "rugisses": "rugir",
    "rugiste": "rugir",
    "rugistes": "rugir",
    "rugiu": "rugir",
    "rugo": "rugar",
    "rugosa": "rugoso",
    "rugosas": "rugoso",
    "rugosidades": "rugosidade",
    "rugosos": "rugoso",
    "rugou": "rugar",
    "rugue": "rugar",
    "ruguei": "rugar",
    "rugueis": "rugar",
    "ruguem": "rugar",
    "ruguemo": "rugar",
    "ruguemos": "rugar",
    "rugues": "rugar",
    "ruguinha": "ruga",
    "ruguinhas": "ruga",
    "ruguita": "ruga",
    "ruguitas": "ruga",
    "rugá": "rugar",
    "rugámo": "rugar",
    "rugámos": "rugar",
    "rugáramo": "rugar",
    "rugáramos": "rugar",
    "rugárei": "rugar",
    "rugáreis": "rugar",
    "rugásseis": "rugar",
    "rugássemos": "rugar",
    "rugávamo": "rugar",
    "rugávamos": "rugar",
    "rugávei": "rugar",
    "rugáveis": "rugar",
    "rugíamo": "rugir",
    "rugíamos": "rugir",
    "rugíeis": "rugir",
    "rugíramo": "rugir",
    "rugíramos": "rugir",
    "rugíreis": "rugir",
    "rugísseis": "rugir",
    "rugíssemos": "rugir",
    "rui": "ruir",
    "ruibarbos": "ruibarbo",
    "ruida": "ruidar",
    "ruidada": "ruidar",
    "ruidadas": "ruidar",
    "ruidado": "ruidar",
    "ruidados": "ruidar",
    "ruidai": "ruidar",
    "ruidais": "ruidar",
    "ruidam": "ruidar",
    "ruidamo": "ruidar",
    "ruidamos": "ruidar",
    "ruidando": "ruidar",
    "ruidara": "ruidar",
    "ruidaram": "ruidar",
    "ruidaras": "ruidar",
    "ruidardes": "ruidar",
    "ruidarei": "ruidar",
    "ruidareis": "ruidar",
    "ruidarem": "ruidar",
    "ruidaremos": "ruidar",
    "ruidares": "ruidar",
    "ruidaria": "ruidar",
    "ruidariam": "ruidar",
    "ruidarias": "ruidar",
    "ruidarmo": "ruidar",
    "ruidarmos": "ruidar",
    "ruidará": "ruidar",
    "ruidarás": "ruidar",
    "ruidarão": "ruidar",
    "ruidaríamos": "ruidar",
    "ruidaríeis": "ruidar",
    "ruidas": "ruidar",
    "ruidasse": "ruidar",
    "ruidassem": "ruidar",
    "ruidasses": "ruidar",
    "ruidaste": "ruidar",
    "ruidastes": "ruidar",
    "ruidava": "ruidar",
    "ruidavam": "ruidar",
    "ruidavas": "ruidar",
    "ruide": "ruidar",
    "ruidei": "ruidar",
    "ruideis": "ruidar",
    "ruidem": "ruidar",
    "ruidemo": "ruidar",
    "ruidemos": "ruidar",
    "ruides": "ruidar",
    "ruidinho": "ruído",
    "ruidinhos": "ruído",
    "ruidito": "ruído",
    "ruiditos": "ruído",
    "ruido": "ruidar",
    "ruidosa": "ruidoso",
    "ruidosas": "ruidoso",
    "ruidosos": "ruidoso",
    "ruidou": "ruidar",
    "ruidámo": "ruidar",
    "ruidámos": "ruidar",
    "ruidáramo": "ruidar",
    "ruidáramos": "ruidar",
    "ruidáreis": "ruidar",
    "ruidásseis": "ruidar",
    "ruidássemos": "ruidar",
    "ruidávamo": "ruidar",
    "ruidávamos": "ruidar",
    "ruidáveis": "ruidar",
    "ruinarias": "ruinaria",
    "ruindades": "ruindade",
    "ruindo": "ruir",
    "ruinha": "rua",
    "ruinhas": "rua",
    "ruinosa": "ruinoso",
    "ruinosas": "ruinoso",
    "ruinosos": "ruinoso",
    "ruins": "ruim",
    "ruinzinha": "ruim",
    "ruinzinhas": "ruim",
    "ruinzinho": "ruim",
    "ruinzinhos": "ruim",
    "ruinzita": "ruim",
    "ruinzitas": "ruim",
    "ruinzito": "ruim",
    "ruinzitos": "ruim",
    "ruirdes": "ruir",
    "ruirei": "ruir",
    "ruireis": "ruir",
    "ruiremos": "ruir",
    "ruiria": "ruir",
    "ruiriam": "ruir",
    "ruirias": "ruir",
    "ruirmo": "ruir",
    "ruirmos": "ruir",
    "ruirá": "ruir",
    "ruirás": "ruir",
    "ruirão": "ruir",
    "ruiríamos": "ruir",
    "ruiríeis": "ruir",
    "ruis": "ruir",
    "ruita": "rua",
    "ruitas": "rua",
    "ruiu": "ruir",
    "ruiva": "ruivo",
    "ruivacas": "ruivaca",
    "ruivacenta": "ruivacento",
    "ruivacentas": "ruivacento",
    "ruivacentos": "ruivacento",
    "ruivacos": "ruivaco",
    "ruivas": "ruivo",
    "ruivasca": "ruivasco",
    "ruivascas": "ruivasco",
    "ruivascos": "ruivasco",
    "ruivazinha": "ruivo",
    "ruivazinhas": "ruivo",
    "ruivazita": "ruivo",
    "ruivazitas": "ruivo",
    "ruivinha": "ruivo",
    "ruivinhas": "ruivo",
    "ruivinho": "ruivo",
    "ruivinhos": "ruivo",
    "ruivita": "ruivo",
    "ruivitas": "ruivo",
    "ruivito": "ruivo",
    "ruivitos": "ruivo",
    "ruivos": "ruivo",
    "ruivozinho": "ruivo",
    "ruivozinhos": "ruivo",
    "ruivozito": "ruivo",
    "ruivozitos": "ruivo",
    "ruivíssima": "ruivo",
    "ruivíssimas": "ruivo",
    "ruivíssimo": "ruivo",
    "ruivíssimos": "ruivo",
    "ruja": "rugir",
    "rujais": "rugir",
    "rujam": "rugir",
    "rujamo": "rugir",
    "rujamos": "rugir",
    "rujas": "rugir",
    "rujo": "rugir",
    "rulos": "rulo",
    "ruma": "rumar",
    "rumada": "rumar",
    "rumadas": "rumar",
    "rumado": "rumar",
    "rumados": "rumar",
    "rumai": "rumar",
    "rumais": "rumar",
    "rumam": "rumar",
    "rumamo": "rumar",
    "rumamos": "rumar",
    "rumando": "rumar",
    "rumara": "rumar",
    "rumaram": "rumar",
    "rumaras": "rumar",
    "rumarde": "rumar",
    "rumardes": "rumar",
    "rumare": "rumar",
    "rumarei": "rumar",
    "rumareis": "rumar",
    "rumarem": "rumar",
    "rumaremos": "rumar",
    "rumares": "rumar",
    "rumaria": "rumar",
    "rumariam": "rumar",
    "rumarias": "rumar",
    "rumarmo": "rumar",
    "rumarmos": "rumar",
    "rumará": "rumar",
    "rumarás": "rumar",
    "rumarão": "rumar",
    "rumaríamos": "rumar",
    "rumaríeis": "rumar",
    "rumas": "rumar",
    "rumasse": "rumar",
    "rumassem": "rumar",
    "rumasses": "rumar",
    "rumaste": "rumar",
    "rumastes": "rumar",
    "rumava": "rumar",
    "rumavam": "rumar",
    "rumavas": "rumar",
    "rumbas": "rumba",
    "rumbeira": "rumbeiro",
    "rumbeiras": "rumbeiro",
    "rumbeiros": "rumbeiro",
    "rume": "rumar",
    "rumei": "rumar",
    "rumeis": "rumar",
    "rumem": "rumar",
    "rumemo": "rumar",
    "rumemos": "rumar",
    "rumes": "rume",
    "rumina": "ruminar",
    "ruminada": "ruminar",
    "ruminadas": "ruminar",
    "ruminado": "ruminar",
    "ruminadoiros": "ruminadoiro",
    "ruminados": "ruminar",
    "ruminadouros": "ruminadouro",
    "ruminai": "ruminar",
    "ruminais": "ruminar",
    "ruminam": "ruminar",
    "ruminamo": "ruminar",
    "ruminamos": "ruminar",
    "ruminando": "ruminar",
    "ruminantes": "ruminante",
    "ruminara": "ruminar",
    "ruminaram": "ruminar",
    "ruminaras": "ruminar",
    "ruminardes": "ruminar",
    "ruminarei": "ruminar",
    "ruminareis": "ruminar",
    "ruminarem": "ruminar",
    "ruminaremos": "ruminar",
    "ruminares": "ruminar",
    "ruminaria": "ruminar",
    "ruminariam": "ruminar",
    "ruminarias": "ruminar",
    "ruminarmo": "ruminar",
    "ruminarmos": "ruminar",
    "ruminará": "ruminar",
    "ruminarás": "ruminar",
    "ruminarão": "ruminar",
    "ruminaríamos": "ruminar",
    "ruminaríeis": "ruminar",
    "ruminas": "ruminar",
    "ruminasse": "ruminar",
    "ruminassem": "ruminar",
    "ruminasses": "ruminar",
    "ruminaste": "ruminar",
    "ruminastes": "ruminar",
    "ruminava": "ruminar",
    "ruminavam": "ruminar",
    "ruminavas": "ruminar",
    "ruminações": "ruminação",
    "rumine": "ruminar",
    "ruminei": "ruminar",
    "rumineis": "ruminar",
    "ruminem": "ruminar",
    "ruminemo": "ruminar",
    "ruminemos": "ruminar",
    "rumines": "ruminar",
    "rumino": "ruminar",
    "ruminou": "ruminar",
    "ruminámo": "ruminar",
    "ruminámos": "ruminar",
    "rumináramo": "ruminar",
    "rumináramos": "ruminar",
    "rumináreis": "ruminar",
    "ruminásseis": "ruminar",
    "ruminássemos": "ruminar",
    "ruminávamo": "ruminar",
    "ruminávamos": "ruminar",
    "rumináveis": "ruminar",
    "rumo": "rumar",
    "rumoreja": "rumorejar",
    "rumorejada": "rumorejar",
    "rumorejadas": "rumorejar",
    "rumorejado": "rumorejar",
    "rumorejados": "rumorejar",
    "rumorejai": "rumorejar",
    "rumorejais": "rumorejar",
    "rumorejam": "rumorejar",
    "rumorejamo": "rumorejar",
    "rumorejamos": "rumorejar",
    "rumorejando": "rumorejar",
    "rumorejantes": "rumorejante",
    "rumorejara": "rumorejar",
    "rumorejaram": "rumorejar",
    "rumorejaras": "rumorejar",
    "rumorejardes": "rumorejar",
    "rumorejarei": "rumorejar",
    "rumorejareis": "rumorejar",
    "rumorejarem": "rumorejar",
    "rumorejaremos": "rumorejar",
    "rumorejares": "rumorejar",
    "rumorejaria": "rumorejar",
    "rumorejariam": "rumorejar",
    "rumorejarias": "rumorejar",
    "rumorejarmo": "rumorejar",
    "rumorejarmos": "rumorejar",
    "rumorejará": "rumorejar",
    "rumorejarás": "rumorejar",
    "rumorejarão": "rumorejar",
    "rumorejaríamos": "rumorejar",
    "rumorejaríeis": "rumorejar",
    "rumorejas": "rumorejar",
    "rumorejasse": "rumorejar",
    "rumorejassem": "rumorejar",
    "rumorejasses": "rumorejar",
    "rumorejaste": "rumorejar",
    "rumorejastes": "rumorejar",
    "rumorejava": "rumorejar",
    "rumorejavam": "rumorejar",
    "rumorejavas": "rumorejar",
    "rumoreje": "rumorejar",
    "rumorejei": "rumorejar",
    "rumorejeis": "rumorejar",
    "rumorejem": "rumorejar",
    "rumorejemo": "rumorejar",
    "rumorejemos": "rumorejar",
    "rumorejes": "rumorejar",
    "rumorejo": "rumorejar",
    "rumorejos": "rumorejo",
    "rumorejou": "rumorejar",
    "rumorejámo": "rumorejar",
    "rumorejámos": "rumorejar",
    "rumorejáramo": "rumorejar",
    "rumorejáramos": "rumorejar",
    "rumorejáreis": "rumorejar",
    "rumorejásseis": "rumorejar",
    "rumorejássemos": "rumorejar",
    "rumorejávamo": "rumorejar",
    "rumorejávamos": "rumorejar",
    "rumorejáveis": "rumorejar",
    "rumores": "rumor",
    "rumorosa": "rumoroso",
    "rumorosas": "rumoroso",
    "rumorosos": "rumoroso",
    "rumos": "rumo",
    "rumou": "rumar",
    "rumá": "rumar",
    "rumámo": "rumar",
    "rumámos": "rumar",
    "rumáramo": "rumar",
    "rumáramos": "rumar",
    "rumárei": "rumar",
    "rumáreis": "rumar",
    "rumásseis": "rumar",
    "rumássemos": "rumar",
    "rumávamo": "rumar",
    "rumávamos": "rumar",
    "rumávei": "rumar",
    "rumáveis": "rumar",
    "runas": "runa",
    "runografias": "runografia",
    "runográfica": "runográfico",
    "runográficas": "runográfico",
    "runográficos": "runográfico",
    "runruns": "runrum",
    "runs": "rum",
    "runógrafa": "runógrafo",
    "runógrafas": "runógrafo",
    "runógrafos": "runógrafo",
    "runóloga": "runólogo",
    "runólogas": "runólogo",
    "runólogos": "runólogo",
    "ruo": "ruir",
    "rupelianos": "rupeliano",
    "rupestres": "rupestre",
    "rupias": "rupia",
    "ruptilidades": "ruptilidade",
    "rupturas": "ruptura",
    "ruptórios": "ruptório",
    "rupícolas": "rupícola",
    "rurais": "rural",
    "ruralidades": "ruralidade",
    "ruralismos": "ruralismo",
    "ruralistas": "ruralista",
    "ruraliza": "ruralizar",
    "ruralizada": "ruralizar",
    "ruralizadas": "ruralizar",
    "ruralizado": "ruralizar",
    "ruralizados": "ruralizar",
    "ruralizai": "ruralizar",
    "ruralizais": "ruralizar",
    "ruralizam": "ruralizar",
    "ruralizamo": "ruralizar",
    "ruralizamos": "ruralizar",
    "ruralizando": "ruralizar",
    "ruralizara": "ruralizar",
    "ruralizaram": "ruralizar",
    "ruralizaras": "ruralizar",
    "ruralizarde": "ruralizar",
    "ruralizardes": "ruralizar",
    "ruralizare": "ruralizar",
    "ruralizarei": "ruralizar",
    "ruralizareis": "ruralizar",
    "ruralizarem": "ruralizar",
    "ruralizaremos": "ruralizar",
    "ruralizares": "ruralizar",
    "ruralizaria": "ruralizar",
    "ruralizariam": "ruralizar",
    "ruralizarias": "ruralizar",
    "ruralizarmo": "ruralizar",
    "ruralizarmos": "ruralizar",
    "ruralizará": "ruralizar",
    "ruralizarás": "ruralizar",
    "ruralizarão": "ruralizar",
    "ruralizaríamos": "ruralizar",
    "ruralizaríeis": "ruralizar",
    "ruralizas": "ruralizar",
    "ruralizasse": "ruralizar",
    "ruralizassem": "ruralizar",
    "ruralizasses": "ruralizar",
    "ruralizaste": "ruralizar",
    "ruralizastes": "ruralizar",
    "ruralizava": "ruralizar",
    "ruralizavam": "ruralizar",
    "ruralizavas": "ruralizar",
    "ruralize": "ruralizar",
    "ruralizei": "ruralizar",
    "ruralizeis": "ruralizar",
    "ruralizem": "ruralizar",
    "ruralizemo": "ruralizar",
    "ruralizemos": "ruralizar",
    "ruralizes": "ruralizar",
    "ruralizo": "ruralizar",
    "ruralizou": "ruralizar",
    "ruralizá": "ruralizar",
    "ruralizámo": "ruralizar",
    "ruralizámos": "ruralizar",
    "ruralizáramo": "ruralizar",
    "ruralizáramos": "ruralizar",
    "ruralizárei": "ruralizar",
    "ruralizáreis": "ruralizar",
    "ruralizásseis": "ruralizar",
    "ruralizássemos": "ruralizar",
    "ruralizávamo": "ruralizar",
    "ruralizávamos": "ruralizar",
    "ruralizávei": "ruralizar",
    "ruralizáveis": "ruralizável",
    "rurografias": "rurografia",
    "rurícolas": "rurícola",
    "rurígenas": "rurígena",
    "rurógrafa": "rurógrafo",
    "rurógrafas": "rurógrafo",
    "rurógrafos": "rurógrafo",
    "rusga": "rusgar",
    "rusgada": "rusgar",
    "rusgadas": "rusgar",
    "rusgado": "rusgar",
    "rusgados": "rusgar",
    "rusgai": "rusgar",
    "rusgais": "rusgar",
    "rusgam": "rusgar",
    "rusgamo": "rusgar",
    "rusgamos": "rusgar",
    "rusgando": "rusgar",
    "rusgara": "rusgar",
    "rusgaram": "rusgar",
    "rusgaras": "rusgar",
    "rusgardes": "rusgar",
    "rusgarei": "rusgar",
    "rusgareis": "rusgar",
    "rusgarem": "rusgar",
    "rusgaremos": "rusgar",
    "rusgares": "rusgar",
    "rusgaria": "rusgar",
    "rusgariam": "rusgar",
    "rusgarias": "rusgar",
    "rusgarmo": "rusgar",
    "rusgarmos": "rusgar",
    "rusgará": "rusgar",
    "rusgarás": "rusgar",
    "rusgarão": "rusgar",
    "rusgaríamos": "rusgar",
    "rusgaríeis": "rusgar",
    "rusgas": "rusgar",
    "rusgasse": "rusgar",
    "rusgassem": "rusgar",
    "rusgasses": "rusgar",
    "rusgaste": "rusgar",
    "rusgastes": "rusgar",
    "rusgava": "rusgar",
    "rusgavam": "rusgar",
    "rusgavas": "rusgar",
    "rusgo": "rusgar",
    "rusgou": "rusgar",
    "rusgue": "rusgar",
    "rusguei": "rusgar",
    "rusgueis": "rusgar",
    "rusguem": "rusgar",
    "rusguemo": "rusgar",
    "rusguemos": "rusgar",
    "rusgues": "rusgar",
    "rusgámo": "rusgar",
    "rusgámos": "rusgar",
    "rusgáramo": "rusgar",
    "rusgáramos": "rusgar",
    "rusgáreis": "rusgar",
    "rusgásseis": "rusgar",
    "rusgássemos": "rusgar",
    "rusgávamo": "rusgar",
    "rusgávamos": "rusgar",
    "rusgáveis": "rusgar",
    "russa": "russo",
    "russalhadas": "russalhada",
    "russas": "russo",
    "russazinha": "russo",
    "russazinhas": "russo",
    "russazita": "russo",
    "russazitas": "russo",
    "russifica": "russificar",
    "russificada": "russificar",
    "russificadas": "russificar",
    "russificado": "russificar",
    "russificados": "russificar",
    "russificai": "russificar",
    "russificais": "russificar",
    "russificam": "russificar",
    "russificamo": "russificar",
    "russificamos": "russificar",
    "russificando": "russificar",
    "russificara": "russificar",
    "russificaram": "russificar",
    "russificaras": "russificar",
    "russificarde": "russificar",
    "russificardes": "russificar",
    "russificare": "russificar",
    "russificarei": "russificar",
    "russificareis": "russificar",
    "russificarem": "russificar",
    "russificaremos": "russificar",
    "russificares": "russificar",
    "russificaria": "russificar",
    "russificariam": "russificar",
    "russificarias": "russificar",
    "russificarmo": "russificar",
    "russificarmos": "russificar",
    "russificará": "russificar",
    "russificarás": "russificar",
    "russificarão": "russificar",
    "russificaríamos": "russificar",
    "russificaríeis": "russificar",
    "russificas": "russificar",
    "russificasse": "russificar",
    "russificassem": "russificar",
    "russificasses": "russificar",
    "russificaste": "russificar",
    "russificastes": "russificar",
    "russificava": "russificar",
    "russificavam": "russificar",
    "russificavas": "russificar",
    "russificações": "russificação",
    "russifico": "russificar",
    "russificou": "russificar",
    "russificá": "russificar",
    "russificámo": "russificar",
    "russificámos": "russificar",
    "russificáramo": "russificar",
    "russificáramos": "russificar",
    "russificárei": "russificar",
    "russificáreis": "russificar",
    "russificásseis": "russificar",
    "russificássemos": "russificar",
    "russificávamo": "russificar",
    "russificávamos": "russificar",
    "russificávei": "russificar",
    "russificáveis": "russificar",
    "russifique": "russificar",
    "russifiquei": "russificar",
    "russifiqueis": "russificar",
    "russifiquem": "russificar",
    "russifiquemo": "russificar",
    "russifiquemos": "russificar",
    "russifiques": "russificar",
    "russinha": "russo",
    "russinhas": "russo",
    "russinho": "russo",
    "russinhos": "russo",
    "russita": "russo",
    "russitas": "russo",
    "russito": "russo",
    "russitos": "russo",
    "russofilias": "russofilia",
    "russofobias": "russofobia",
    "russos": "russo",
    "russozinho": "russo",
    "russozinhos": "russo",
    "russozito": "russo",
    "russozitos": "russo",
    "russófila": "russófilo",
    "russófilas": "russófilo",
    "russófilos": "russófilo",
    "russófoba": "russófobo",
    "russófobas": "russófobo",
    "russófobos": "russófobo",
    "rustica": "rusticar",
    "rusticada": "rusticar",
    "rusticadas": "rusticar",
    "rusticado": "rusticar",
    "rusticados": "rusticar",
    "rusticais": "rusticar",
    "rusticam": "rusticar",
    "rusticamo": "rusticar",
    "rusticamos": "rusticar",
    "rusticana": "rusticano",
    "rusticanas": "rusticano",
    "rusticando": "rusticar",
    "rusticanos": "rusticano",
    "rusticara": "rusticar",
    "rusticaram": "rusticar",
    "rusticaras": "rusticar",
    "rusticardes": "rusticar",
    "rusticarei": "rusticar",
    "rusticareis": "rusticar",
    "rusticarem": "rusticar",
    "rusticaremos": "rusticar",
    "rusticares": "rusticar",
    "rusticaria": "rusticar",
    "rusticariam": "rusticar",
    "rusticarias": "rusticar",
    "rusticarmo": "rusticar",
    "rusticarmos": "rusticar",
    "rusticará": "rusticar",
    "rusticarás": "rusticar",
    "rusticarão": "rusticar",
    "rusticaríamos": "rusticar",
    "rusticaríeis": "rusticar",
    "rusticas": "rusticar",
    "rusticasse": "rusticar",
    "rusticassem": "rusticar",
    "rusticasses": "rusticar",
    "rusticaste": "rusticar",
    "rusticastes": "rusticar",
    "rusticava": "rusticar",
    "rusticavam": "rusticar",
    "rusticavas": "rusticar",
    "rusticações": "rusticação",
    "rusticidades": "rusticidade",
    "rustico": "rusticar",
    "rusticou": "rusticar",
    "rusticámo": "rusticar",
    "rusticámos": "rusticar",
    "rusticáramo": "rusticar",
    "rusticáramos": "rusticar",
    "rusticáreis": "rusticar",
    "rusticásseis": "rusticar",
    "rusticássemos": "rusticar",
    "rusticávamo": "rusticar",
    "rusticávamos": "rusticar",
    "rusticáveis": "rusticar",
    "rustifica": "rustificar",
    "rustificada": "rustificar",
    "rustificadas": "rustificar",
    "rustificado": "rustificar",
    "rustificados": "rustificar",
    "rustificai": "rustificar",
    "rustificais": "rustificar",
    "rustificam": "rustificar",
    "rustificamo": "rustificar",
    "rustificamos": "rustificar",
    "rustificando": "rustificar",
    "rustificara": "rustificar",
    "rustificaram": "rustificar",
    "rustificaras": "rustificar",
    "rustificarde": "rustificar",
    "rustificardes": "rustificar",
    "rustificare": "rustificar",
    "rustificarei": "rustificar",
    "rustificareis": "rustificar",
    "rustificarem": "rustificar",
    "rustificaremos": "rustificar",
    "rustificares": "rustificar",
    "rustificaria": "rustificar",
    "rustificariam": "rustificar",
    "rustificarias": "rustificar",
    "rustificarmo": "rustificar",
    "rustificarmos": "rustificar",
    "rustificará": "rustificar",
    "rustificarás": "rustificar",
    "rustificarão": "rustificar",
    "rustificaríamos": "rustificar",
    "rustificaríeis": "rustificar",
    "rustificas": "rustificar",
    "rustificasse": "rustificar",
    "rustificassem": "rustificar",
    "rustificasses": "rustificar",
    "rustificaste": "rustificar",
    "rustificastes": "rustificar",
    "rustificava": "rustificar",
    "rustificavam": "rustificar",
    "rustificavas": "rustificar",
    "rustifico": "rustificar",
    "rustificou": "rustificar",
    "rustificá": "rustificar",
    "rustificámo": "rustificar",
    "rustificámos": "rustificar",
    "rustificáramo": "rustificar",
    "rustificáramos": "rustificar",
    "rustificárei": "rustificar",
    "rustificáreis": "rustificar",
    "rustificásseis": "rustificar",
    "rustificássemos": "rustificar",
    "rustificávamo": "rustificar",
    "rustificávamos": "rustificar",
    "rustificávei": "rustificar",
    "rustificáveis": "rustificar",
    "rustifique": "rustificar",
    "rustifiquei": "rustificar",
    "rustifiqueis": "rustificar",
    "rustifiquem": "rustificar",
    "rustifiquemo": "rustificar",
    "rustifiquemos": "rustificar",
    "rustifiques": "rustificar",
    "rustique": "rusticar",
    "rustiquei": "rusticar",
    "rustiqueis": "rusticar",
    "rustiquem": "rusticar",
    "rustiquemos": "rusticar",
    "rustiques": "rusticar",
    "rustiquezas": "rustiqueza",
    "rutabagas": "rutabaga",
    "rutamurárias": "rutamurária",
    "rutherfórdios": "rutherfórdio",
    "rutila": "rutilar",
    "rutilada": "rutilar",
    "rutiladas": "rutilar",
    "rutilado": "rutilar",
    "rutilados": "rutilar",
    "rutilai": "rutilar",
    "rutilais": "rutilar",
    "rutilam": "rutilar",
    "rutilamo": "rutilar",
    "rutilamos": "rutilar",
    "rutilando": "rutilar",
    "rutilantes": "rutilante",
    "rutilara": "rutilar",
    "rutilaram": "rutilar",
    "rutilaras": "rutilar",
    "rutilarde": "rutilar",
    "rutilardes": "rutilar",
    "rutilare": "rutilar",
    "rutilarei": "rutilar",
    "rutilareis": "rutilar",
    "rutilarem": "rutilar",
    "rutilaremos": "rutilar",
    "rutilares": "rutilar",
    "rutilaria": "rutilar",
    "rutilariam": "rutilar",
    "rutilarias": "rutilar",
    "rutilarmo": "rutilar",
    "rutilarmos": "rutilar",
    "rutilará": "rutilar",
    "rutilarás": "rutilar",
    "rutilarão": "rutilar",
    "rutilaríamos": "rutilar",
    "rutilaríeis": "rutilar",
    "rutilas": "rutilar",
    "rutilasse": "rutilar",
    "rutilassem": "rutilar",
    "rutilasses": "rutilar",
    "rutilaste": "rutilar",
    "rutilastes": "rutilar",
    "rutilava": "rutilar",
    "rutilavam": "rutilar",
    "rutilavas": "rutilar",
    "rutilações": "rutilação",
    "rutile": "rutilar",
    "rutilei": "rutilar",
    "rutileis": "rutilar",
    "rutilem": "rutilar",
    "rutilemo": "rutilar",
    "rutilemos": "rutilar",
    "rutiles": "rutilar",
    "rutilo": "rutilar",
    "rutilos": "rutilo",
    "rutilou": "rutilar",
    "rutilá": "rutilar",
    "rutilámo": "rutilar",
    "rutilámos": "rutilar",
    "rutiláramo": "rutilar",
    "rutiláramos": "rutilar",
    "rutilárei": "rutilar",
    "rutiláreis": "rutilar",
    "rutilásseis": "rutilar",
    "rutilássemos": "rutilar",
    "rutilávamo": "rutilar",
    "rutilávamos": "rutilar",
    "rutilávei": "rutilar",
    "rutiláveis": "rutilar",
    "rutilâncias": "rutilância",
    "rutinas": "rutina",
    "rutácea": "rutáceo",
    "rutáceas": "rutáceo",
    "rutáceos": "rutáceo",
    "ruténios": "ruténio",
    "rutílios": "rutílio",
    "ruvinhosa": "ruvinhoso",
    "ruvinhosas": "ruvinhoso",
    "ruvinhosos": "ruvinhoso",
    "ruxaxás": "ruxaxá",
    "ruxoxós": "ruxoxó",
    "ruã": "ruão",
    "ruãos": "ruão",
    "ruãs": "ruão",
    "ruça": "ruço",
    "ruçada": "ruçar",
    "ruçadas": "ruçar",
    "ruçado": "ruçar",
    "ruçados": "ruçar",
    "ruçai": "ruçar",
    "ruçais": "ruçar",
    "ruçam": "ruçar",
    "ruçamo": "ruçar",
    "ruçamos": "ruçar",
    "ruçando": "ruçar",
    "ruçara": "ruçar",
    "ruçaram": "ruçar",
    "ruçaras": "ruçar",
    "ruçarde": "ruçar",
    "ruçardes": "ruçar",
    "ruçare": "ruçar",
    "ruçarei": "ruçar",
    "ruçareis": "ruçar",
    "ruçarem": "ruçar",
    "ruçaremos": "ruçar",
    "ruçares": "ruçar",
    "ruçaria": "ruçar",
    "ruçariam": "ruçar",
    "ruçarias": "ruçar",
    "ruçarmo": "ruçar",
    "ruçarmos": "ruçar",
    "ruçará": "ruçar",
    "ruçarás": "ruçar",
    "ruçarão": "ruçar",
    "ruçaríamos": "ruçar",
    "ruçaríeis": "ruçar",
    "ruças": "ruço",
    "ruçasse": "ruçar",
    "ruçassem": "ruçar",
    "ruçasses": "ruçar",
    "ruçaste": "ruçar",
    "ruçastes": "ruçar",
    "ruçava": "ruçar",
    "ruçavam": "ruçar",
    "ruçavas": "ruçar",
    "ruço": "ruçar",
    "ruços": "ruço",
    "ruçou": "ruçar",
    "ruçá": "ruçar",
    "ruçámo": "ruçar",
    "ruçámos": "ruçar",
    "ruçáramo": "ruçar",
    "ruçáramos": "ruçar",
    "ruçárei": "ruçar",
    "ruçáreis": "ruçar",
    "ruçásseis": "ruçar",
    "ruçássemos": "ruçar",
    "ruçávamo": "ruçar",
    "ruçávamos": "ruçar",
    "ruçávei": "ruçar",
    "ruçáveis": "ruçar",
    "ruí": "ruir",
    "ruía": "ruir",
    "ruíam": "ruir",
    "ruíamo": "ruir",
    "ruíamos": "ruir",
    "ruías": "ruir",
    "ruída": "ruir",
    "ruídas": "ruir",
    "ruído": "ruir",
    "ruídos": "ruir",
    "ruíeis": "ruir",
    "ruímo": "ruir",
    "ruímos": "ruir",
    "ruínas": "ruína",
    "ruíra": "ruir",
    "ruíram": "ruir",
    "ruíramo": "ruir",
    "ruíramos": "ruir",
    "ruíras": "ruir",
    "ruíreis": "ruir",
    "ruírem": "ruir",
    "ruíres": "ruir",
    "ruís": "ruir",
    "ruísse": "ruir",
    "ruísseis": "ruir",
    "ruíssem": "ruir",
    "ruíssemos": "ruir",
    "ruísses": "ruir",
    "ruíste": "ruir",
    "ruístes": "ruir",
    "ruões": "ruão",
    "rv": "r",
    "rábanos": "rábano",
    "rábias": "rábia",
    "rábica": "rábico",
    "rábicas": "rábico",
    "rábicos": "rábico",
    "rábida": "rábido",
    "rábidas": "rábido",
    "rábidos": "rábido",
    "rábitas": "rábita",
    "rábulas": "rábula",
    "rácica": "rácico",
    "rácicas": "rácico",
    "rácicos": "rácico",
    "rácios": "rácio",
    "rádios": "rádio",
    "rádones": "rádon",
    "rádons": "rádon",
    "rádulas": "rádula",
    "ráfias": "ráfia",
    "ráfides": "ráfide",
    "rágada": "rágade",
    "rágadas": "rágade",
    "rágades": "rágade",
    "rálidas": "rálida",
    "rápida": "rápido",
    "rápidas": "rápido",
    "rápidos": "rápido",
    "ráses": "rás",
    "râguebis": "râguebi",
    "râmbolas": "râmbola",
    "râmolas": "râmola",
    "rância": "râncio",
    "râncias": "râncio",
    "râncida": "râncido",
    "râncidas": "râncido",
    "râncidos": "râncido",
    "râncios": "râncio",
    "rânidas": "rânida",
    "rânulas": "rânula",
    "rãs": "rã",
    "rãzinha": "rã",
    "rãzinhas": "rã",
    "rãzita": "rã",
    "rãzitas": "rã",
    "ré": "réu",
    "récipes": "récipe",
    "récitas": "récita",
    "récovas": "récova",
    "rédeas": "rédea",
    "réditos": "rédito",
    "régia": "régio",
    "régias": "régio",
    "régies": "régie",
    "régios": "régio",
    "réguas": "régua",
    "régulos": "régulo",
    "réidas": "réida",
    "réis": "rei",
    "rémiges": "rémige",
    "rémoras": "rémora",
    "rénios": "rénio",
    "réplicas": "réplica",
    "réproba": "réprobo",
    "réprobas": "réprobo",
    "réprobos": "réprobo",
    "répteis": "réptil",
    "réquias": "réquia",
    "réquiens": "réquiem",
    "réquies": "réquie",
    "rés": "réu",
    "réses": "rés",
    "réspices": "réspice",
    "réstias": "réstia",
    "rética": "rético",
    "réticas": "rético",
    "réticos": "rético",
    "réus": "réu",
    "rês": "rê",
    "ríamo": "rir",
    "ríamos": "rir",
    "ríccias": "ríccia",
    "rícinos": "rícino",
    "ríeis": "rir",
    "rígida": "rígido",
    "rígidas": "rígido",
    "rígidos": "rígido",
    "rímeis": "rímel",
    "rímulas": "rímula",
    "rípios": "rípio",
    "ríramo": "rir",
    "ríramos": "rir",
    "ríreis": "rir",
    "ríspida": "ríspido",
    "ríspidas": "ríspido",
    "ríspidos": "ríspido",
    "rísseis": "rir",
    "ríssemos": "rir",
    "rítmica": "rítmico",
    "rítmicas": "rítmico",
    "rítmicos": "rítmico",
    "róberes": "róber",
    "róbures": "róbur",
    "rócios": "rócio",
    "ródica": "ródico",
    "ródicas": "ródico",
    "ródicos": "ródico",
    "ródios": "ródio",
    "rói": "roer",
    "róis": "rol",
    "rópias": "rópia",
    "rórida": "rórido",
    "róridas": "rórido",
    "róridos": "rórido",
    "rós": "ró",
    "róscida": "róscido",
    "róscidas": "róscido",
    "róscidos": "róscido",
    "rósea": "róseo",
    "róseas": "róseo",
    "róseos": "róseo",
    "rótulas": "rótula",
    "rótulos": "rótulo",
    "rômbica": "rômbico",
    "rômbicas": "rômbico",
    "rômbicos": "rômbico",
    "rúbea": "rúbeo",
    "rúbeas": "rúbeo",
    "rúbeos": "rúbeo",
    "rúbida": "rúbido",
    "rúbidas": "rúbido",
    "rúbidos": "rúbido",
    "rúblis": "rúbli",
    "rúfia": "rúfio",
    "rúfias": "rúfio",
    "rúfios": "rúfio",
    "rúmens": "rúmen",
    "rúnica": "rúnico",
    "rúnicas": "rúnico",
    "rúnicos": "rúnico",
    "rúpias": "rúpia",
    "rúptis": "rúptil",
    "rústica": "rústico",
    "rústicas": "rústico",
    "rústicos": "rústico",
    "rútila": "rútilo",
    "rútilas": "rútilo",
    "rútilos": "rútilo",
    "rútula": "rútulo",
    "rútulas": "rútulo",
    "rútulos": "rútulo",
    "sabadeada": "sabadear",
    "sabadeadas": "sabadear",
    "sabadeado": "sabadear",
    "sabadeadora": "sabadeador",
    "sabadeadoras": "sabadeador",
    "sabadeadores": "sabadeador",
    "sabadeados": "sabadear",
    "sabadeai": "sabadear",
    "sabadeais": "sabadear",
    "sabadeamo": "sabadear",
    "sabadeamos": "sabadear",
    "sabadeando": "sabadear",
    "sabadeara": "sabadear",
    "sabadearam": "sabadear",
    "sabadearas": "sabadear",
    "sabadeardes": "sabadear",
    "sabadearei": "sabadear",
    "sabadeareis": "sabadear",
    "sabadearem": "sabadear",
    "sabadearemos": "sabadear",
    "sabadeares": "sabadear",
    "sabadearia": "sabadear",
    "sabadeariam": "sabadear",
    "sabadearias": "sabadear",
    "sabadearmo": "sabadear",
    "sabadearmos": "sabadear",
    "sabadeará": "sabadear",
    "sabadearás": "sabadear",
    "sabadearão": "sabadear",
    "sabadearíamos": "sabadear",
    "sabadearíeis": "sabadear",
    "sabadeasse": "sabadear",
    "sabadeassem": "sabadear",
    "sabadeasses": "sabadear",
    "sabadeaste": "sabadear",
    "sabadeastes": "sabadear",
    "sabadeava": "sabadear",
    "sabadeavam": "sabadear",
    "sabadeavas": "sabadear",
    "sabadeei": "sabadear",
    "sabadeeis": "sabadear",
    "sabadeemo": "sabadear",
    "sabadeemos": "sabadear",
    "sabadeia": "sabadear",
    "sabadeiam": "sabadear",
    "sabadeias": "sabadear",
    "sabadeie": "sabadear",
    "sabadeiem": "sabadear",
    "sabadeies": "sabadear",
    "sabadeio": "sabadear",
    "sabadeou": "sabadear",
    "sabadeámo": "sabadear",
    "sabadeámos": "sabadear",
    "sabadeáramo": "sabadear",
    "sabadeáramos": "sabadear",
    "sabadeáreis": "sabadear",
    "sabadeásseis": "sabadear",
    "sabadeássemos": "sabadear",
    "sabadeávamo": "sabadear",
    "sabadeávamos": "sabadear",
    "sabadeáveis": "sabadear",
    "sabaios": "sabaio",
    "sabais": "sabal",
    "sabaothes": "sabaoth",
    "sabas": "saba",
    "sabates": "sabat",
    "sabatina": "sabatino",
    "sabatinada": "sabatinar",
    "sabatinadas": "sabatinar",
    "sabatinado": "sabatinar",
    "sabatinados": "sabatinar",
    "sabatinai": "sabatinar",
    "sabatinais": "sabatinar",
    "sabatinam": "sabatinar",
    "sabatinamo": "sabatinar",
    "sabatinamos": "sabatinar",
    "sabatinando": "sabatinar",
    "sabatinara": "sabatinar",
    "sabatinaram": "sabatinar",
    "sabatinaras": "sabatinar",
    "sabatinardes": "sabatinar",
    "sabatinarei": "sabatinar",
    "sabatinareis": "sabatinar",
    "sabatinarem": "sabatinar",
    "sabatinaremos": "sabatinar",
    "sabatinares": "sabatinar",
    "sabatinaria": "sabatinar",
    "sabatinariam": "sabatinar",
    "sabatinarias": "sabatinar",
    "sabatinarmo": "sabatinar",
    "sabatinarmos": "sabatinar",
    "sabatinará": "sabatinar",
    "sabatinarás": "sabatinar",
    "sabatinarão": "sabatinar",
    "sabatinaríamos": "sabatinar",
    "sabatinaríeis": "sabatinar",
    "sabatinas": "sabatino",
    "sabatinasse": "sabatinar",
    "sabatinassem": "sabatinar",
    "sabatinasses": "sabatinar",
    "sabatinaste": "sabatinar",
    "sabatinastes": "sabatinar",
    "sabatinava": "sabatinar",
    "sabatinavam": "sabatinar",
    "sabatinavas": "sabatinar",
    "sabatine": "sabatinar",
    "sabatinei": "sabatinar",
    "sabatineira": "sabatineiro",
    "sabatineiras": "sabatineiro",
    "sabatineiros": "sabatineiro",
    "sabatineis": "sabatinar",
    "sabatinem": "sabatinar",
    "sabatinemo": "sabatinar",
    "sabatinemos": "sabatinar",
    "sabatines": "sabatinar",
    "sabatino": "sabatinar",
    "sabatinos": "sabatino",
    "sabatinou": "sabatinar",
    "sabatinámo": "sabatinar",
    "sabatinámos": "sabatinar",
    "sabatináramo": "sabatinar",
    "sabatináramos": "sabatinar",
    "sabatináreis": "sabatinar",
    "sabatinásseis": "sabatinar",
    "sabatinássemos": "sabatinar",
    "sabatinávamo": "sabatinar",
    "sabatinávamos": "sabatinar",
    "sabatináveis": "sabatinar",
    "sabatismos": "sabatismo",
    "sabatistas": "sabatista",
    "sabatiza": "sabatizar",
    "sabatizada": "sabatizar",
    "sabatizadas": "sabatizar",
    "sabatizado": "sabatizar",
    "sabatizados": "sabatizar",
    "sabatizai": "sabatizar",
    "sabatizais": "sabatizar",
    "sabatizam": "sabatizar",
    "sabatizamo": "sabatizar",
    "sabatizamos": "sabatizar",
    "sabatizando": "sabatizar",
    "sabatizara": "sabatizar",
    "sabatizaram": "sabatizar",
    "sabatizaras": "sabatizar",
    "sabatizardes": "sabatizar",
    "sabatizarei": "sabatizar",
    "sabatizareis": "sabatizar",
    "sabatizarem": "sabatizar",
    "sabatizaremos": "sabatizar",
    "sabatizares": "sabatizar",
    "sabatizaria": "sabatizar",
    "sabatizariam": "sabatizar",
    "sabatizarias": "sabatizar",
    "sabatizarmo": "sabatizar",
    "sabatizarmos": "sabatizar",
    "sabatizará": "sabatizar",
    "sabatizarás": "sabatizar",
    "sabatizarão": "sabatizar",
    "sabatizaríamos": "sabatizar",
    "sabatizaríeis": "sabatizar",
    "sabatizas": "sabatizar",
    "sabatizasse": "sabatizar",
    "sabatizassem": "sabatizar",
    "sabatizasses": "sabatizar",
    "sabatizaste": "sabatizar",
    "sabatizastes": "sabatizar",
    "sabatizava": "sabatizar",
    "sabatizavam": "sabatizar",
    "sabatizavas": "sabatizar",
    "sabatize": "sabatizar",
    "sabatizei": "sabatizar",
    "sabatizeis": "sabatizar",
    "sabatizem": "sabatizar",
    "sabatizemo": "sabatizar",
    "sabatizemos": "sabatizar",
    "sabatizes": "sabatizar",
    "sabatizo": "sabatizar",
    "sabatizou": "sabatizar",
    "sabatizámo": "sabatizar",
    "sabatizámos": "sabatizar",
    "sabatizáramo": "sabatizar",
    "sabatizáramos": "sabatizar",
    "sabatizáreis": "sabatizar",
    "sabatizásseis": "sabatizar",
    "sabatizássemos": "sabatizar",
    "sabatizávamo": "sabatizar",
    "sabatizávamos": "sabatizar",
    "sabatizáveis": "sabatizar",
    "sabaísmos": "sabaísmo",
    "sabbaths": "sabbath",
    "sabe": "saber",
    "sabedora": "sabedor",
    "sabedoras": "sabedor",
    "sabedores": "sabedor",
    "sabedorias": "sabedoria",
    "sabei": "saber",
    "sabeia": "sabeu",
    "sabeias": "sabeu",
    "sabeis": "saber",
    "sabela": "sabelo",
    "sabelas": "sabelo",
    "sabelianismos": "sabelianismo",
    "sabelianos": "sabeliano",
    "sabelos": "sabelo",
    "sabem": "saber",
    "sabemo": "saber",
    "sabemos": "saber",
    "sabendo": "saber",
    "sabenças": "sabença",
    "saberde": "saber",
    "saberdes": "saber",
    "sabere": "saber",
    "saberei": "saber",
    "sabereis": "saber",
    "saberem": "saber",
    "saberemos": "saber",
    "saberes": "saber",
    "saberetes": "saberete",
    "saberia": "saber",
    "saberiam": "saber",
    "saberias": "saber",
    "sabermo": "saber",
    "sabermos": "saber",
    "saberá": "saber",
    "saberás": "saber",
    "saberão": "saber",
    "saberíamos": "saber",
    "saberíeis": "saber",
    "sabes": "saber",
    "sabeus": "sabeu",
    "sabeísmos": "sabeísmo",
    "sabeístas": "sabeísta",
    "sabeítas": "sabeíta",
    "sabia": "saber",
    "sabiam": "saber",
    "sabias": "saber",
    "sabicha": "sabichar",
    "sabichada": "sabichar",
    "sabichadas": "sabichar",
    "sabichado": "sabichar",
    "sabichados": "sabichar",
    "sabichai": "sabichar",
    "sabichais": "sabichar",
    "sabicham": "sabichar",
    "sabichamo": "sabichar",
    "sabichamos": "sabichar",
    "sabichando": "sabichar",
    "sabichara": "sabichar",
    "sabicharam": "sabichar",
    "sabicharas": "sabichar",
    "sabicharde": "sabichar",
    "sabichardes": "sabichar",
    "sabichare": "sabichar",
    "sabicharei": "sabichar",
    "sabichareis": "sabichar",
    "sabicharem": "sabichar",
    "sabicharemos": "sabichar",
    "sabichares": "sabichar",
    "sabicharia": "sabichar",
    "sabichariam": "sabichar",
    "sabicharias": "sabichar",
    "sabicharmo": "sabichar",
    "sabicharmos": "sabichar",
    "sabichará": "sabichar",
    "sabicharás": "sabichar",
    "sabicharão": "sabichar",
    "sabicharíamos": "sabichar",
    "sabicharíeis": "sabichar",
    "sabichas": "sabichar",
    "sabichasse": "sabichar",
    "sabichassem": "sabichar",
    "sabichasses": "sabichar",
    "sabichaste": "sabichar",
    "sabichastes": "sabichar",
    "sabichava": "sabichar",
    "sabichavam": "sabichar",
    "sabichavas": "sabichar",
    "sabiche": "sabichar",
    "sabichei": "sabichar",
    "sabicheis": "sabichar",
    "sabichem": "sabichar",
    "sabichemo": "sabichar",
    "sabichemos": "sabichar",
    "sabiches": "sabichar",
    "sabicho": "sabichar",
    "sabichona": "sabichão",
    "sabichonas": "sabichão",
    "sabichonazinha": "sabichão",
    "sabichonazinhas": "sabichão",
    "sabichonazita": "sabichão",
    "sabichonazitas": "sabichão",
    "sabichosa": "sabichoso",
    "sabichosas": "sabichoso",
    "sabichosos": "sabichoso",
    "sabichou": "sabichar",
    "sabichá": "sabichar",
    "sabichámo": "sabichar",
    "sabichámos": "sabichar",
    "sabicháramo": "sabichar",
    "sabicháramos": "sabichar",
    "sabichárei": "sabichar",
    "sabicháreis": "sabichar",
    "sabichásseis": "sabichar",
    "sabichássemos": "sabichar",
    "sabichávamo": "sabichar",
    "sabichávamos": "sabichar",
    "sabichávei": "sabichar",
    "sabicháveis": "sabichar",
    "sabichãozinho": "sabichão",
    "sabichãozito": "sabichão",
    "sabichãs": "sabichã",
    "sabichões": "sabichão",
    "sabichõezinhos": "sabichão",
    "sabichõezitos": "sabichão",
    "sabida": "sabido",
    "sabidas": "sabido",
    "sabido": "saber",
    "sabidos": "sabido",
    "sabidíssima": "sabido",
    "sabidíssimas": "sabido",
    "sabidíssimo": "sabido",
    "sabidíssimos": "sabido",
    "sabina": "sabino",
    "sabinas": "sabino",
    "sabinos": "sabino",
    "sabiáceas": "sabiácea",
    "sabiás": "sabiá",
    "sables": "sable",
    "saboarias": "saboaria",
    "saboeira": "saboeiro",
    "saboeiras": "saboeiro",
    "saboeiros": "saboeiro",
    "sabogas": "saboga",
    "saboiana": "saboiano",
    "saboianas": "saboiano",
    "saboianos": "saboiano",
    "sabonetadas": "sabonetada",
    "saboneteiras": "saboneteira",
    "sabonetes": "sabonete",
    "saboreada": "saborear",
    "saboreadas": "saborear",
    "saboreado": "saborear",
    "saboreados": "saborear",
    "saboreai": "saborear",
    "saboreais": "saborear",
    "saboreamo": "saborear",
    "saboreamos": "saborear",
    "saboreando": "saborear",
    "saboreara": "saborear",
    "saborearam": "saborear",
    "saborearas": "saborear",
    "saborearde": "saborear",
    "saboreardes": "saborear",
    "saboreare": "saborear",
    "saborearei": "saborear",
    "saboreareis": "saborear",
    "saborearem": "saborear",
    "saborearemos": "saborear",
    "saboreares": "saborear",
    "saborearia": "saborear",
    "saboreariam": "saborear",
    "saborearias": "saborear",
    "saborearmo": "saborear",
    "saborearmos": "saborear",
    "saboreará": "saborear",
    "saborearás": "saborear",
    "saborearão": "saborear",
    "saborearíamos": "saborear",
    "saborearíeis": "saborear",
    "saboreasse": "saborear",
    "saboreassem": "saborear",
    "saboreasses": "saborear",
    "saboreaste": "saborear",
    "saboreastes": "saborear",
    "saboreava": "saborear",
    "saboreavam": "saborear",
    "saboreavas": "saborear",
    "saboreei": "saborear",
    "saboreeis": "saborear",
    "saboreemo": "saborear",
    "saboreemos": "saborear",
    "saboreia": "saborear",
    "saboreiam": "saborear",
    "saboreias": "saborear",
    "saboreie": "saborear",
    "saboreiem": "saborear",
    "saboreies": "saborear",
    "saboreio": "saborear",
    "saboreou": "saborear",
    "sabores": "sabor",
    "saboreá": "saborear",
    "saboreámo": "saborear",
    "saboreámos": "saborear",
    "saboreáramo": "saborear",
    "saboreáramos": "saborear",
    "saboreárei": "saborear",
    "saboreáreis": "saborear",
    "saboreásseis": "saborear",
    "saboreássemos": "saborear",
    "saboreávamo": "saborear",
    "saboreávamos": "saborear",
    "saboreávei": "saborear",
    "saboreáveis": "saboreável",
    "saborida": "saborido",
    "saboridas": "saborido",
    "saboridos": "saborido",
    "saborosa": "saboroso",
    "saborosas": "saboroso",
    "saborosos": "saboroso",
    "saborosíssima": "saboroso",
    "saborosíssimas": "saboroso",
    "saborosíssimo": "saboroso",
    "saborosíssimos": "saboroso",
    "saborzinho": "sabor",
    "saborzinhos": "sabor",
    "saborzito": "sabor",
    "saborzitos": "sabor",
    "sabota": "sabotar",
    "sabotada": "sabotar",
    "sabotadas": "sabotar",
    "sabotado": "sabotar",
    "sabotadora": "sabotador",
    "sabotadoras": "sabotador",
    "sabotadores": "sabotador",
    "sabotados": "sabotar",
    "sabotagens": "sabotagem",
    "sabotai": "sabotar",
    "sabotais": "sabotar",
    "sabotam": "sabotar",
    "sabotamo": "sabotar",
    "sabotamos": "sabotar",
    "sabotando": "sabotar",
    "sabotara": "sabotar",
    "sabotaram": "sabotar",
    "sabotaras": "sabotar",
    "sabotarde": "sabotar",
    "sabotardes": "sabotar",
    "sabotare": "sabotar",
    "sabotarei": "sabotar",
    "sabotareis": "sabotar",
    "sabotarem": "sabotar",
    "sabotaremos": "sabotar",
    "sabotares": "sabotar",
    "sabotaria": "sabotar",
    "sabotariam": "sabotar",
    "sabotarias": "sabotar",
    "sabotarmo": "sabotar",
    "sabotarmos": "sabotar",
    "sabotará": "sabotar",
    "sabotarás": "sabotar",
    "sabotarão": "sabotar",
    "sabotaríamos": "sabotar",
    "sabotaríeis": "sabotar",
    "sabotas": "sabotar",
    "sabotasse": "sabotar",
    "sabotassem": "sabotar",
    "sabotasses": "sabotar",
    "sabotaste": "sabotar",
    "sabotastes": "sabotar",
    "sabotava": "sabotar",
    "sabotavam": "sabotar",
    "sabotavas": "sabotar",
    "sabote": "sabotar",
    "sabotei": "sabotar",
    "saboteis": "sabotar",
    "sabotem": "sabotar",
    "sabotemo": "sabotar",
    "sabotemos": "sabotar",
    "sabotes": "sabotar",
    "saboto": "sabotar",
    "sabotou": "sabotar",
    "sabotá": "sabotar",
    "sabotámo": "sabotar",
    "sabotámos": "sabotar",
    "sabotáramo": "sabotar",
    "sabotáramos": "sabotar",
    "sabotárei": "sabotar",
    "sabotáreis": "sabotar",
    "sabotásseis": "sabotar",
    "sabotássemos": "sabotar",
    "sabotávamo": "sabotar",
    "sabotávamos": "sabotar",
    "sabotávei": "sabotar",
    "sabotáveis": "sabotável",
    "sabradas": "sabrada",
    "sabras": "sabra",
    "sabres": "sabre",
    "sabristas": "sabrista",
    "sabugais": "sabugal",
    "sabugos": "sabugo",
    "sabugueiros": "sabugueiro",
    "sabuja": "sabujo",
    "sabujada": "sabujar",
    "sabujadas": "sabujar",
    "sabujado": "sabujar",
    "sabujados": "sabujar",
    "sabujai": "sabujar",
    "sabujais": "sabujar",
    "sabujam": "sabujar",
    "sabujamo": "sabujar",
    "sabujamos": "sabujar",
    "sabujando": "sabujar",
    "sabujara": "sabujar",
    "sabujaram": "sabujar",
    "sabujaras": "sabujar",
    "sabujarde": "sabujar",
    "sabujardes": "sabujar",
    "sabujare": "sabujar",
    "sabujarei": "sabujar",
    "sabujareis": "sabujar",
    "sabujarem": "sabujar",
    "sabujaremos": "sabujar",
    "sabujares": "sabujar",
    "sabujaria": "sabujar",
    "sabujariam": "sabujar",
    "sabujarias": "sabujar",
    "sabujarmo": "sabujar",
    "sabujarmos": "sabujar",
    "sabujará": "sabujar",
    "sabujarás": "sabujar",
    "sabujarão": "sabujar",
    "sabujaríamos": "sabujar",
    "sabujaríeis": "sabujar",
    "sabujas": "sabujo",
    "sabujasse": "sabujar",
    "sabujassem": "sabujar",
    "sabujasses": "sabujar",
    "sabujaste": "sabujar",
    "sabujastes": "sabujar",
    "sabujava": "sabujar",
    "sabujavam": "sabujar",
    "sabujavas": "sabujar",
    "sabuje": "sabujar",
    "sabujei": "sabujar",
    "sabujeis": "sabujar",
    "sabujem": "sabujar",
    "sabujemo": "sabujar",
    "sabujemos": "sabujar",
    "sabujes": "sabujar",
    "sabujices": "sabujice",
    "sabujismos": "sabujismo",
    "sabujo": "sabujar",
    "sabujos": "sabujo",
    "sabujou": "sabujar",
    "sabujá": "sabujar",
    "sabujámo": "sabujar",
    "sabujámos": "sabujar",
    "sabujáramo": "sabujar",
    "sabujáramos": "sabujar",
    "sabujárei": "sabujar",
    "sabujáreis": "sabujar",
    "sabujásseis": "sabujar",
    "sabujássemos": "sabujar",
    "sabujávamo": "sabujar",
    "sabujávamos": "sabujar",
    "sabujávei": "sabujar",
    "sabujáveis": "sabujar",
    "sabulosa": "sabuloso",
    "sabulosas": "sabuloso",
    "sabulosos": "sabuloso",
    "saburra": "saburrar",
    "saburrada": "saburrar",
    "saburradas": "saburrar",
    "saburrado": "saburrar",
    "saburrados": "saburrar",
    "saburrai": "saburrar",
    "saburrais": "saburrar",
    "saburram": "saburrar",
    "saburramo": "saburrar",
    "saburramos": "saburrar",
    "saburrando": "saburrar",
    "saburrara": "saburrar",
    "saburraram": "saburrar",
    "saburraras": "saburrar",
    "saburrarde": "saburrar",
    "saburrardes": "saburrar",
    "saburrare": "saburrar",
    "saburrarei": "saburrar",
    "saburrareis": "saburrar",
    "saburrarem": "saburrar",
    "saburraremos": "saburrar",
    "saburrares": "saburrar",
    "saburraria": "saburrar",
    "saburrariam": "saburrar",
    "saburrarias": "saburrar",
    "saburrarmo": "saburrar",
    "saburrarmos": "saburrar",
    "saburrará": "saburrar",
    "saburrarás": "saburrar",
    "saburrarão": "saburrar",
    "saburraríamos": "saburrar",
    "saburraríeis": "saburrar",
    "saburras": "saburrar",
    "saburrasse": "saburrar",
    "saburrassem": "saburrar",
    "saburrasses": "saburrar",
    "saburraste": "saburrar",
    "saburrastes": "saburrar",
    "saburrava": "saburrar",
    "saburravam": "saburrar",
    "saburravas": "saburrar",
    "saburre": "saburrar",
    "saburrei": "saburrar",
    "saburreis": "saburrar",
    "saburrem": "saburrar",
    "saburremo": "saburrar",
    "saburremos": "saburrar",
    "saburrenta": "saburrento",
    "saburrentas": "saburrento",
    "saburrentos": "saburrento",
    "saburres": "saburrar",
    "saburro": "saburrar",
    "saburrosa": "saburroso",
    "saburrosas": "saburroso",
    "saburrosidades": "saburrosidade",
    "saburrosos": "saburroso",
    "saburrou": "saburrar",
    "saburrá": "saburrar",
    "saburrámo": "saburrar",
    "saburrámos": "saburrar",
    "saburráramo": "saburrar",
    "saburráramos": "saburrar",
    "saburrárei": "saburrar",
    "saburráreis": "saburrar",
    "saburrásseis": "saburrar",
    "saburrássemos": "saburrar",
    "saburrávamo": "saburrar",
    "saburrávamos": "saburrar",
    "saburrávei": "saburrar",
    "saburráveis": "saburrar",
    "sabás": "sabá",
    "sabática": "sabático",
    "sabáticas": "sabático",
    "sabáticos": "sabático",
    "sabélica": "sabélico",
    "sabélicas": "sabélico",
    "sabélicos": "sabélico",
    "sabê": "saber",
    "sabíamo": "saber",
    "sabíamos": "saber",
    "sabíei": "saber",
    "sabíeis": "saber",
    "sabíveis": "sabível",
    "sabóias": "sabóia",
    "sabões": "sabão",
    "saca": "sacar",
    "sacabuxas": "sacabuxa",
    "sacada": "sacar",
    "sacadas": "sacar",
    "sacadelas": "sacadela",
    "sacado": "sacar",
    "sacadora": "sacador",
    "sacadoras": "sacador",
    "sacadores": "sacador",
    "sacados": "sacar",
    "sacadíssima": "sacado",
    "sacadíssimas": "sacado",
    "sacadíssimo": "sacado",
    "sacadíssimos": "sacado",
    "sacai": "sacar",
    "sacais": "sacar",
    "sacalinhas": "sacalinha",
    "sacalões": "sacalão",
    "sacam": "sacar",
    "sacamo": "sacar",
    "sacamos": "sacar",
    "sacanagens": "sacanagem",
    "sacanas": "sacana",
    "sacando": "sacar",
    "sacanices": "sacanice",
    "sacaputos": "sacaputo",
    "sacara": "sacar",
    "sacaram": "sacar",
    "sacaras": "sacar",
    "sacaratos": "sacarato",
    "sacarde": "sacar",
    "sacardes": "sacar",
    "sacare": "sacar",
    "sacarei": "sacar",
    "sacareis": "sacar",
    "sacarem": "sacar",
    "sacaremos": "sacar",
    "sacarena": "sacareno",
    "sacarenas": "sacareno",
    "sacarenos": "sacareno",
    "sacares": "sacar",
    "sacaria": "sacar",
    "sacariam": "sacar",
    "sacarias": "sacaria",
    "sacarifica": "sacarificar",
    "sacarificada": "sacarificar",
    "sacarificadas": "sacarificar",
    "sacarificado": "sacarificar",
    "sacarificados": "sacarificar",
    "sacarificai": "sacarificar",
    "sacarificais": "sacarificar",
    "sacarificam": "sacarificar",
    "sacarificamo": "sacarificar",
    "sacarificamos": "sacarificar",
    "sacarificando": "sacarificar",
    "sacarificantes": "sacarificante",
    "sacarificara": "sacarificar",
    "sacarificaram": "sacarificar",
    "sacarificaras": "sacarificar",
    "sacarificarde": "sacarificar",
    "sacarificardes": "sacarificar",
    "sacarificare": "sacarificar",
    "sacarificarei": "sacarificar",
    "sacarificareis": "sacarificar",
    "sacarificarem": "sacarificar",
    "sacarificaremos": "sacarificar",
    "sacarificares": "sacarificar",
    "sacarificaria": "sacarificar",
    "sacarificariam": "sacarificar",
    "sacarificarias": "sacarificar",
    "sacarificarmo": "sacarificar",
    "sacarificarmos": "sacarificar",
    "sacarificará": "sacarificar",
    "sacarificarás": "sacarificar",
    "sacarificarão": "sacarificar",
    "sacarificaríamos": "sacarificar",
    "sacarificaríeis": "sacarificar",
    "sacarificas": "sacarificar",
    "sacarificasse": "sacarificar",
    "sacarificassem": "sacarificar",
    "sacarificasses": "sacarificar",
    "sacarificaste": "sacarificar",
    "sacarificastes": "sacarificar",
    "sacarificava": "sacarificar",
    "sacarificavam": "sacarificar",
    "sacarificavas": "sacarificar",
    "sacarificações": "sacarificação",
    "sacarifico": "sacarificar",
    "sacarificou": "sacarificar",
    "sacarificá": "sacarificar",
    "sacarificámo": "sacarificar",
    "sacarificámos": "sacarificar",
    "sacarificáramo": "sacarificar",
    "sacarificáramos": "sacarificar",
    "sacarificárei": "sacarificar",
    "sacarificáreis": "sacarificar",
    "sacarificásseis": "sacarificar",
    "sacarificássemos": "sacarificar",
    "sacarificávamo": "sacarificar",
    "sacarificávamos": "sacarificar",
    "sacarificávei": "sacarificar",
    "sacarificáveis": "sacarificável",
    "sacarifique": "sacarificar",
    "sacarifiquei": "sacarificar",
    "sacarifiqueis": "sacarificar",
    "sacarifiquem": "sacarificar",
    "sacarifiquemo": "sacarificar",
    "sacarifiquemos": "sacarificar",
    "sacarifiques": "sacarificar",
    "sacarimetrias": "sacarimetria",
    "sacarina": "sacarino",
    "sacarinas": "sacarino",
    "sacarinos": "sacarino",
    "sacarismos": "sacarismo",
    "sacarmo": "sacar",
    "sacarmos": "sacar",
    "sacarois": "sacarol",
    "sacarologias": "sacarologia",
    "sacarometrias": "sacarometria",
    "sacarosa": "sacaroso",
    "sacarosas": "sacaroso",
    "sacaroses": "sacarose",
    "sacarosos": "sacaroso",
    "sacarrões": "sacarrão",
    "sacará": "sacar",
    "sacarás": "sacar",
    "sacarão": "sacar",
    "sacaríamos": "sacar",
    "sacarídea": "sacarídeo",
    "sacarídeas": "sacarídeo",
    "sacarídeos": "sacarídeo",
    "sacaríeis": "sacar",
    "sacarífera": "sacarífero",
    "sacaríferas": "sacarífero",
    "sacaríferos": "sacarífero",
    "sacarígena": "sacarígeno",
    "sacarígenas": "sacarígeno",
    "sacarígenos": "sacarígeno",
    "sacarímetros": "sacarímetro",
    "sacaríneas": "sacarínea",
    "sacarívora": "sacarívoro",
    "sacarívoras": "sacarívoro",
    "sacarívoros": "sacarívoro",
    "sacaróides": "sacaróide",
    "sacaróleos": "sacaróleo",
    "sacarómetros": "sacarómetro",
    "sacas": "sacar",
    "sacasse": "sacar",
    "sacassem": "sacar",
    "sacasses": "sacar",
    "sacaste": "sacar",
    "sacastes": "sacar",
    "sacateiras": "sacateira",
    "sacava": "sacar",
    "sacavam": "sacar",
    "sacavas": "sacar",
    "sacavenenses": "sacavenense",
    "sacaís": "sacaí",
    "saceliformes": "saceliforme",
    "sacelos": "sacelo",
    "sacerdocracias": "sacerdocracia",
    "sacerdotais": "sacerdotal",
    "sacerdotalismos": "sacerdotalismo",
    "sacerdotes": "sacerdote",
    "sacerdotisa": "sacerdote",
    "sacerdotisas": "sacerdote",
    "sacerdócios": "sacerdócio",
    "sacha": "sachar",
    "sachada": "sachar",
    "sachadas": "sachar",
    "sachadelas": "sachadela",
    "sachado": "sachar",
    "sachadora": "sachador",
    "sachadoras": "sachador",
    "sachadores": "sachador",
    "sachados": "sachar",
    "sachaduras": "sachadura",
    "sachai": "sachar",
    "sachais": "sachar",
    "sacham": "sachar",
    "sachamo": "sachar",
    "sachamos": "sachar",
    "sachando": "sachar",
    "sachara": "sachar",
    "sacharam": "sachar",
    "sacharas": "sachar",
    "sacharde": "sachar",
    "sachardes": "sachar",
    "sachare": "sachar",
    "sacharei": "sachar",
    "sachareis": "sachar",
    "sacharem": "sachar",
    "sacharemos": "sachar",
    "sachares": "sachar",
    "sacharia": "sachar",
    "sachariam": "sachar",
    "sacharias": "sachar",
    "sacharmo": "sachar",
    "sacharmos": "sachar",
    "sachará": "sachar",
    "sacharás": "sachar",
    "sacharão": "sachar",
    "sacharíamos": "sachar",
    "sacharíeis": "sachar",
    "sachas": "sachar",
    "sachasse": "sachar",
    "sachassem": "sachar",
    "sachasses": "sachar",
    "sachaste": "sachar",
    "sachastes": "sachar",
    "sachava": "sachar",
    "sachavam": "sachar",
    "sachavas": "sachar",
    "sache": "sachar",
    "sachei": "sachar",
    "sacheis": "sachar",
    "sachem": "sachar",
    "sachemo": "sachar",
    "sachemos": "sachar",
    "saches": "sachar",
    "sachinho": "sacho",
    "sachinhos": "sacho",
    "sachito": "sacho",
    "sachitos": "sacho",
    "sacho": "sachar",
    "sachola": "sacholar",
    "sacholada": "sacholar",
    "sacholadas": "sacholar",
    "sacholado": "sacholar",
    "sacholados": "sacholar",
    "sacholai": "sacholar",
    "sacholais": "sacholar",
    "sacholam": "sacholar",
    "sacholamo": "sacholar",
    "sacholamos": "sacholar",
    "sacholando": "sacholar",
    "sacholara": "sacholar",
    "sacholaram": "sacholar",
    "sacholaras": "sacholar",
    "sacholarde": "sacholar",
    "sacholardes": "sacholar",
    "sacholare": "sacholar",
    "sacholarei": "sacholar",
    "sacholareis": "sacholar",
    "sacholarem": "sacholar",
    "sacholaremos": "sacholar",
    "sacholares": "sacholar",
    "sacholaria": "sacholar",
    "sacholariam": "sacholar",
    "sacholarias": "sacholar",
    "sacholarmo": "sacholar",
    "sacholarmos": "sacholar",
    "sacholará": "sacholar",
    "sacholarás": "sacholar",
    "sacholarão": "sacholar",
    "sacholaríamos": "sacholar",
    "sacholaríeis": "sacholar",
    "sacholas": "sacholar",
    "sacholasse": "sacholar",
    "sacholassem": "sacholar",
    "sacholasses": "sacholar",
    "sacholaste": "sacholar",
    "sacholastes": "sacholar",
    "sacholava": "sacholar",
    "sacholavam": "sacholar",
    "sacholavas": "sacholar",
    "sachole": "sacholar",
    "sacholei": "sacholar",
    "sacholeis": "sacholar",
    "sacholem": "sacholar",
    "sacholemo": "sacholar",
    "sacholemos": "sacholar",
    "sacholes": "sacholar",
    "sacholo": "sacholar",
    "sacholos": "sacholo",
    "sacholou": "sacholar",
    "sacholá": "sacholar",
    "sacholámo": "sacholar",
    "sacholámos": "sacholar",
    "sacholáramo": "sacholar",
    "sacholáramos": "sacholar",
    "sacholárei": "sacholar",
    "sacholáreis": "sacholar",
    "sacholásseis": "sacholar",
    "sacholássemos": "sacholar",
    "sacholávamo": "sacholar",
    "sacholávamos": "sacholar",
    "sacholávei": "sacholar",
    "sacholáveis": "sacholar",
    "sachos": "sacho",
    "sachou": "sachar",
    "sachá": "sachar",
    "sachámo": "sachar",
    "sachámos": "sachar",
    "sacháramo": "sachar",
    "sacháramos": "sachar",
    "sachárei": "sachar",
    "sacháreis": "sachar",
    "sachásseis": "sachar",
    "sachássemos": "sachar",
    "sachávamo": "sachar",
    "sachávamos": "sachar",
    "sachávei": "sachar",
    "sacháveis": "sachar",
    "sacia": "saciar",
    "saciada": "saciar",
    "saciadas": "saciar",
    "saciado": "saciar",
    "saciados": "saciar",
    "saciai": "saciar",
    "saciais": "saciar",
    "saciam": "saciar",
    "saciamo": "saciar",
    "saciamos": "saciar",
    "saciando": "saciar",
    "saciara": "saciar",
    "saciaram": "saciar",
    "saciaras": "saciar",
    "saciarde": "saciar",
    "saciardes": "saciar",
    "saciare": "saciar",
    "saciarei": "saciar",
    "saciareis": "saciar",
    "saciarem": "saciar",
    "saciaremos": "saciar",
    "saciares": "saciar",
    "saciaria": "saciar",
    "saciariam": "saciar",
    "saciarias": "saciar",
    "saciarmo": "saciar",
    "saciarmos": "saciar",
    "saciará": "saciar",
    "saciarás": "saciar",
    "saciarão": "saciar",
    "saciaríamos": "saciar",
    "saciaríeis": "saciar",
    "sacias": "saciar",
    "saciasse": "saciar",
    "saciassem": "saciar",
    "saciasses": "saciar",
    "saciaste": "saciar",
    "saciastes": "saciar",
    "saciava": "saciar",
    "saciavam": "saciar",
    "saciavas": "saciar",
    "sacie": "saciar",
    "saciedades": "saciedade",
    "saciei": "saciar",
    "sacieis": "saciar",
    "saciem": "saciar",
    "saciemo": "saciar",
    "saciemos": "saciar",
    "sacies": "saciar",
    "saciformes": "saciforme",
    "sacio": "saciar",
    "saciou": "saciar",
    "sacis": "saci",
    "saciá": "saciar",
    "saciámo": "saciar",
    "saciámos": "saciar",
    "saciáramo": "saciar",
    "saciáramos": "saciar",
    "saciárei": "saciar",
    "saciáreis": "saciar",
    "saciásseis": "saciar",
    "saciássemos": "saciar",
    "saciávamo": "saciar",
    "saciávamos": "saciar",
    "saciávei": "saciar",
    "saciáveis": "saciável",
    "saco": "sacar",
    "sacode": "sacudir",
    "sacodem": "sacudir",
    "sacodes": "sacudir",
    "sacolas": "sacola",
    "sacoleja": "sacolejar",
    "sacolejada": "sacolejar",
    "sacolejadas": "sacolejar",
    "sacolejado": "sacolejar",
    "sacolejados": "sacolejar",
    "sacolejai": "sacolejar",
    "sacolejais": "sacolejar",
    "sacolejam": "sacolejar",
    "sacolejamo": "sacolejar",
    "sacolejamos": "sacolejar",
    "sacolejando": "sacolejar",
    "sacolejara": "sacolejar",
    "sacolejaram": "sacolejar",
    "sacolejaras": "sacolejar",
    "sacolejarde": "sacolejar",
    "sacolejardes": "sacolejar",
    "sacolejare": "sacolejar",
    "sacolejarei": "sacolejar",
    "sacolejareis": "sacolejar",
    "sacolejarem": "sacolejar",
    "sacolejaremos": "sacolejar",
    "sacolejares": "sacolejar",
    "sacolejaria": "sacolejar",
    "sacolejariam": "sacolejar",
    "sacolejarias": "sacolejar",
    "sacolejarmo": "sacolejar",
    "sacolejarmos": "sacolejar",
    "sacolejará": "sacolejar",
    "sacolejarás": "sacolejar",
    "sacolejarão": "sacolejar",
    "sacolejaríamos": "sacolejar",
    "sacolejaríeis": "sacolejar",
    "sacolejas": "sacolejar",
    "sacolejasse": "sacolejar",
    "sacolejassem": "sacolejar",
    "sacolejasses": "sacolejar",
    "sacolejaste": "sacolejar",
    "sacolejastes": "sacolejar",
    "sacolejava": "sacolejar",
    "sacolejavam": "sacolejar",
    "sacolejavas": "sacolejar",
    "sacoleje": "sacolejar",
    "sacolejei": "sacolejar",
    "sacolejeis": "sacolejar",
    "sacolejem": "sacolejar",
    "sacolejemo": "sacolejar",
    "sacolejemos": "sacolejar",
    "sacolejes": "sacolejar",
    "sacolejo": "sacolejar",
    "sacolejos": "sacolejo",
    "sacolejou": "sacolejar",
    "sacolejá": "sacolejar",
    "sacolejámo": "sacolejar",
    "sacolejámos": "sacolejar",
    "sacolejáramo": "sacolejar",
    "sacolejáramos": "sacolejar",
    "sacolejárei": "sacolejar",
    "sacolejáreis": "sacolejar",
    "sacolejásseis": "sacolejar",
    "sacolejássemos": "sacolejar",
    "sacolejávamo": "sacolejar",
    "sacolejávamos": "sacolejar",
    "sacolejávei": "sacolejar",
    "sacolejáveis": "sacolejar",
    "sacos": "saco",
    "sacou": "sacar",
    "sacra": "sacro",
    "sacrais": "sacral",
    "sacralgias": "sacralgia",
    "sacralidades": "sacralidade",
    "sacraliza": "sacralizar",
    "sacralizada": "sacralizar",
    "sacralizadas": "sacralizar",
    "sacralizado": "sacralizar",
    "sacralizados": "sacralizar",
    "sacralizai": "sacralizar",
    "sacralizais": "sacralizar",
    "sacralizam": "sacralizar",
    "sacralizamo": "sacralizar",
    "sacralizamos": "sacralizar",
    "sacralizando": "sacralizar",
    "sacralizara": "sacralizar",
    "sacralizaram": "sacralizar",
    "sacralizaras": "sacralizar",
    "sacralizarde": "sacralizar",
    "sacralizardes": "sacralizar",
    "sacralizare": "sacralizar",
    "sacralizarei": "sacralizar",
    "sacralizareis": "sacralizar",
    "sacralizarem": "sacralizar",
    "sacralizaremos": "sacralizar",
    "sacralizares": "sacralizar",
    "sacralizaria": "sacralizar",
    "sacralizariam": "sacralizar",
    "sacralizarias": "sacralizar",
    "sacralizarmo": "sacralizar",
    "sacralizarmos": "sacralizar",
    "sacralizará": "sacralizar",
    "sacralizarás": "sacralizar",
    "sacralizarão": "sacralizar",
    "sacralizaríamos": "sacralizar",
    "sacralizaríeis": "sacralizar",
    "sacralizas": "sacralizar",
    "sacralizasse": "sacralizar",
    "sacralizassem": "sacralizar",
    "sacralizasses": "sacralizar",
    "sacralizaste": "sacralizar",
    "sacralizastes": "sacralizar",
    "sacralizava": "sacralizar",
    "sacralizavam": "sacralizar",
    "sacralizavas": "sacralizar",
    "sacralizações": "sacralização",
    "sacralize": "sacralizar",
    "sacralizei": "sacralizar",
    "sacralizeis": "sacralizar",
    "sacralizem": "sacralizar",
    "sacralizemo": "sacralizar",
    "sacralizemos": "sacralizar",
    "sacralizes": "sacralizar",
    "sacralizo": "sacralizar",
    "sacralizou": "sacralizar",
    "sacralizá": "sacralizar",
    "sacralizámo": "sacralizar",
    "sacralizámos": "sacralizar",
    "sacralizáramo": "sacralizar",
    "sacralizáramos": "sacralizar",
    "sacralizárei": "sacralizar",
    "sacralizáreis": "sacralizar",
    "sacralizásseis": "sacralizar",
    "sacralizássemos": "sacralizar",
    "sacralizávamo": "sacralizar",
    "sacralizávamos": "sacralizar",
    "sacralizávei": "sacralizar",
    "sacralizáveis": "sacralizar",
    "sacramenta": "sacramentar",
    "sacramentada": "sacramentar",
    "sacramentadas": "sacramentar",
    "sacramentado": "sacramentar",
    "sacramentados": "sacramentar",
    "sacramentai": "sacramentar",
    "sacramentais": "sacramentar",
    "sacramentam": "sacramentar",
    "sacramentamo": "sacramentar",
    "sacramentamos": "sacramentar",
    "sacramentando": "sacramentar",
    "sacramentara": "sacramentar",
    "sacramentaram": "sacramentar",
    "sacramentaras": "sacramentar",
    "sacramentarde": "sacramentar",
    "sacramentardes": "sacramentar",
    "sacramentare": "sacramentar",
    "sacramentarei": "sacramentar",
    "sacramentareis": "sacramentar",
    "sacramentarem": "sacramentar",
    "sacramentaremos": "sacramentar",
    "sacramentares": "sacramentar",
    "sacramentaria": "sacramentar",
    "sacramentariam": "sacramentar",
    "sacramentarias": "sacramentar",
    "sacramentarmo": "sacramentar",
    "sacramentarmos": "sacramentar",
    "sacramentará": "sacramentar",
    "sacramentarás": "sacramentar",
    "sacramentarão": "sacramentar",
    "sacramentaríamos": "sacramentar",
    "sacramentaríeis": "sacramentar",
    "sacramentas": "sacramentar",
    "sacramentasse": "sacramentar",
    "sacramentassem": "sacramentar",
    "sacramentasses": "sacramentar",
    "sacramentaste": "sacramentar",
    "sacramentastes": "sacramentar",
    "sacramentava": "sacramentar",
    "sacramentavam": "sacramentar",
    "sacramentavas": "sacramentar",
    "sacramente": "sacramentar",
    "sacramentei": "sacramentar",
    "sacramenteis": "sacramentar",
    "sacramentem": "sacramentar",
    "sacramentemo": "sacramentar",
    "sacramentemos": "sacramentar",
    "sacramentes": "sacramentar",
    "sacramento": "sacramentar",
    "sacramentos": "sacramento",
    "sacramentou": "sacramentar",
    "sacramentá": "sacramentar",
    "sacramentámo": "sacramentar",
    "sacramentámos": "sacramentar",
    "sacramentáramo": "sacramentar",
    "sacramentáramos": "sacramentar",
    "sacramentárei": "sacramentar",
    "sacramentáreis": "sacramentar",
    "sacramentários": "sacramentário",
    "sacramentásseis": "sacramentar",
    "sacramentássemos": "sacramentar",
    "sacramentávamo": "sacramentar",
    "sacramentávamos": "sacramentar",
    "sacramentávei": "sacramentar",
    "sacramentáveis": "sacramentar",
    "sacras": "sacro",
    "sacratíssima": "sagrado",
    "sacratíssimas": "sagrado",
    "sacratíssimo": "sagrado",
    "sacratíssimos": "sagrado",
    "sacrifica": "sacrificar",
    "sacrificada": "sacrificar",
    "sacrificadas": "sacrificar",
    "sacrificado": "sacrificar",
    "sacrificadora": "sacrificador",
    "sacrificadoras": "sacrificador",
    "sacrificadores": "sacrificador",
    "sacrificados": "sacrificar",
    "sacrificadíssima": "sacrificado",
    "sacrificadíssimas": "sacrificado",
    "sacrificadíssimo": "sacrificado",
    "sacrificadíssimos": "sacrificado",
    "sacrificai": "sacrificar",
    "sacrificais": "sacrificar",
    "sacrificam": "sacrificar",
    "sacrificamo": "sacrificar",
    "sacrificamos": "sacrificar",
    "sacrificando": "sacrificar",
    "sacrificantes": "sacrificante",
    "sacrificara": "sacrificar",
    "sacrificaram": "sacrificar",
    "sacrificaras": "sacrificar",
    "sacrificarde": "sacrificar",
    "sacrificardes": "sacrificar",
    "sacrificare": "sacrificar",
    "sacrificarei": "sacrificar",
    "sacrificareis": "sacrificar",
    "sacrificarem": "sacrificar",
    "sacrificaremos": "sacrificar",
    "sacrificares": "sacrificar",
    "sacrificaria": "sacrificar",
    "sacrificariam": "sacrificar",
    "sacrificarias": "sacrificar",
    "sacrificarmo": "sacrificar",
    "sacrificarmos": "sacrificar",
    "sacrificará": "sacrificar",
    "sacrificarás": "sacrificar",
    "sacrificarão": "sacrificar",
    "sacrificaríamos": "sacrificar",
    "sacrificaríeis": "sacrificar",
    "sacrificas": "sacrificar",
    "sacrificasse": "sacrificar",
    "sacrificassem": "sacrificar",
    "sacrificasses": "sacrificar",
    "sacrificaste": "sacrificar",
    "sacrificastes": "sacrificar",
    "sacrificativa": "sacrificativo",
    "sacrificativas": "sacrificativo",
    "sacrificativos": "sacrificativo",
    "sacrificatória": "sacrificatório",
    "sacrificatórias": "sacrificatório",
    "sacrificatórios": "sacrificatório",
    "sacrificava": "sacrificar",
    "sacrificavam": "sacrificar",
    "sacrificavas": "sacrificar",
    "sacrificiais": "sacrificial",
    "sacrifico": "sacrificar",
    "sacrificou": "sacrificar",
    "sacrificá": "sacrificar",
    "sacrificámo": "sacrificar",
    "sacrificámos": "sacrificar",
    "sacrificáramo": "sacrificar",
    "sacrificáramos": "sacrificar",
    "sacrificárei": "sacrificar",
    "sacrificáreis": "sacrificar",
    "sacrificásseis": "sacrificar",
    "sacrificássemos": "sacrificar",
    "sacrificávamo": "sacrificar",
    "sacrificávamos": "sacrificar",
    "sacrificávei": "sacrificar",
    "sacrificáveis": "sacrificável",
    "sacrifique": "sacrificar",
    "sacrifiquei": "sacrificar",
    "sacrifiqueis": "sacrificar",
    "sacrifiquem": "sacrificar",
    "sacrifiquemo": "sacrificar",
    "sacrifiquemos": "sacrificar",
    "sacrifiques": "sacrificar",
    "sacrifícios": "sacrifício",
    "sacrifículos": "sacrifículo",
    "sacrileginha": "sacrílego",
    "sacrileginhas": "sacrílego",
    "sacrileginho": "sacrílego",
    "sacrileginhos": "sacrílego",
    "sacrilegita": "sacrílego",
    "sacrilegitas": "sacrílego",
    "sacrilegito": "sacrílego",
    "sacrilegitos": "sacrílego",
    "sacrilégios": "sacrilégio",
    "sacrilíaca": "sacrilíaco",
    "sacrilíacas": "sacrilíaco",
    "sacrilíacos": "sacrilíaco",
    "sacripantas": "sacripanta",
    "sacripantes": "sacripante",
    "sacrismochos": "sacrismocho",
    "sacristanias": "sacristania",
    "sacristas": "sacrista",
    "sacristias": "sacristia",
    "sacristãs": "sacristã",
    "sacristões": "sacristão",
    "sacrociática": "sacrociático",
    "sacrociáticas": "sacrociático",
    "sacrociáticos": "sacrociático",
    "sacrococcígea": "sacrococcígeo",
    "sacrococcígeas": "sacrococcígeo",
    "sacrococcígeos": "sacrococcígeo",
    "sacrocoxalgias": "sacrocoxalgia",
    "sacrofemorais": "sacrofemoral",
    "sacrolombares": "sacrolombar",
    "sacrorraquidiana": "sacrorraquidiano",
    "sacrorraquidianas": "sacrorraquidiano",
    "sacrorraquidianos": "sacrorraquidiano",
    "sacros": "sacro",
    "sacrossanta": "sacrossanto",
    "sacrossantas": "sacrossanto",
    "sacrossantos": "sacrossanto",
    "sacrários": "sacrário",
    "sacrífera": "sacrífero",
    "sacríferas": "sacrífero",
    "sacríferos": "sacrífero",
    "sacrífica": "sacrífico",
    "sacríficas": "sacrífico",
    "sacríficos": "sacrífico",
    "sacrílega": "sacrílego",
    "sacrílegas": "sacrílego",
    "sacrílegos": "sacrílego",
    "sacuda": "sacudir",
    "sacudais": "sacudir",
    "sacudam": "sacudir",
    "sacudamo": "sacudir",
    "sacudamos": "sacudir",
    "sacudas": "sacudir",
    "sacudi": "sacudir",
    "sacudia": "sacudir",
    "sacudiam": "sacudir",
    "sacudias": "sacudir",
    "sacudida": "sacudir",
    "sacudidas": "sacudir",
    "sacudidelas": "sacudidela",
    "sacudido": "sacudir",
    "sacudidora": "sacudidor",
    "sacudidoras": "sacudidor",
    "sacudidores": "sacudidor",
    "sacudidos": "sacudir",
    "sacudiduras": "sacudidura",
    "sacudidíssima": "sacudido",
    "sacudidíssimas": "sacudido",
    "sacudidíssimo": "sacudido",
    "sacudidíssimos": "sacudido",
    "sacudimentos": "sacudimento",
    "sacudimo": "sacudir",
    "sacudimos": "sacudir",
    "sacudindo": "sacudir",
    "sacudira": "sacudir",
    "sacudiram": "sacudir",
    "sacudiras": "sacudir",
    "sacudirde": "sacudir",
    "sacudirdes": "sacudir",
    "sacudire": "sacudir",
    "sacudirei": "sacudir",
    "sacudireis": "sacudir",
    "sacudirem": "sacudir",
    "sacudiremos": "sacudir",
    "sacudires": "sacudir",
    "sacudiria": "sacudir",
    "sacudiriam": "sacudir",
    "sacudirias": "sacudir",
    "sacudirmo": "sacudir",
    "sacudirmos": "sacudir",
    "sacudirá": "sacudir",
    "sacudirás": "sacudir",
    "sacudirão": "sacudir",
    "sacudiríamos": "sacudir",
    "sacudiríeis": "sacudir",
    "sacudis": "sacudir",
    "sacudisse": "sacudir",
    "sacudissem": "sacudir",
    "sacudisses": "sacudir",
    "sacudiste": "sacudir",
    "sacudistes": "sacudir",
    "sacudiu": "sacudir",
    "sacudo": "sacudir",
    "sacudíamo": "sacudir",
    "sacudíamos": "sacudir",
    "sacudíei": "sacudir",
    "sacudíeis": "sacudir",
    "sacudíramo": "sacudir",
    "sacudíramos": "sacudir",
    "sacudírei": "sacudir",
    "sacudíreis": "sacudir",
    "sacudísseis": "sacudir",
    "sacudíssemos": "sacudir",
    "saculares": "sacular",
    "saculiformes": "saculiforme",
    "sacá": "sacar",
    "sacámo": "sacar",
    "sacámos": "sacar",
    "sacáramo": "sacar",
    "sacáramos": "sacar",
    "sacárei": "sacar",
    "sacáreis": "sacar",
    "sacáridos": "sacárido",
    "sacários": "sacário",
    "sacásseis": "sacar",
    "sacássemos": "sacar",
    "sacávamo": "sacar",
    "sacávamos": "sacar",
    "sacávei": "sacar",
    "sacáveis": "sacar",
    "sacífera": "sacífero",
    "sacíferas": "sacífero",
    "sacíferos": "sacífero",
    "sacófora": "sacóforo",
    "sacóforas": "sacóforo",
    "sacóforos": "sacóforo",
    "sacões": "sacão",
    "sadia": "sadio",
    "sadias": "sadio",
    "sadina": "sadino",
    "sadinas": "sadino",
    "sadinos": "sadino",
    "sadios": "sadio",
    "sadismos": "sadismo",
    "sadistas": "sadista",
    "sadomasochismos": "sadomasochismo",
    "sadomasoquismos": "sadomasoquismo",
    "sadomasoquistas": "sadomasoquista",
    "sadrás": "sadrá",
    "saduceus": "saduceu",
    "saduceísmos": "saduceísmo",
    "saducia": "saduceu",
    "saducias": "saduceu",
    "saducéia": "saduceu",
    "saducéias": "saduceu",
    "saem": "sair",
    "safa": "safo",
    "safada": "safar",
    "safadas": "safar",
    "safadezas": "safadeza",
    "safadices": "safadice",
    "safadismos": "safadismo",
    "safado": "safar",
    "safados": "safar",
    "safadíssima": "safado",
    "safadíssimas": "safado",
    "safadíssimo": "safado",
    "safadíssimos": "safado",
    "safai": "safar",
    "safais": "safar",
    "safam": "safar",
    "safamo": "safar",
    "safamos": "safar",
    "safando": "safar",
    "safanões": "safanão",
    "safara": "safar",
    "safaram": "safar",
    "safaras": "safar",
    "safardanas": "safardana",
    "safarde": "safar",
    "safardes": "safar",
    "safare": "safar",
    "safarei": "safar",
    "safareis": "safar",
    "safarem": "safar",
    "safaremos": "safar",
    "safares": "safar",
    "safaria": "safario",
    "safariam": "safar",
    "safarias": "safario",
    "safarios": "safario",
    "safarmo": "safar",
    "safarmos": "safar",
    "safará": "safar",
    "safarás": "safar",
    "safarão": "safar",
    "safaríamos": "safar",
    "safaríeis": "safar",
    "safas": "safo",
    "safasse": "safar",
    "safassem": "safar",
    "safasses": "safar",
    "safaste": "safar",
    "safastes": "safar",
    "safatas": "safata",
    "safava": "safar",
    "safavam": "safar",
    "safavas": "safar",
    "safe": "safar",
    "safei": "safar",
    "safeis": "safar",
    "safem": "safar",
    "safemo": "safar",
    "safemos": "safar",
    "safenas": "safena",
    "safes": "safar",
    "safios": "safio",
    "safiras": "safira",
    "safirinas": "safirina",
    "safismos": "safismo",
    "safistas": "safista",
    "safo": "safar",
    "saforis": "saforil",
    "safos": "safo",
    "safou": "safar",
    "safradeiras": "safradeira",
    "safras": "safra",
    "safreiras": "safreira",
    "safá": "safar",
    "safámo": "safar",
    "safámos": "safar",
    "safáramo": "safar",
    "safáramos": "safar",
    "safárei": "safar",
    "safáreis": "safar",
    "safáris": "safári",
    "safásseis": "safar",
    "safássemos": "safar",
    "safávamo": "safar",
    "safávamos": "safar",
    "safávei": "safar",
    "safáveis": "safar",
    "sagacidades": "sagacidade",
    "saganhas": "saganha",
    "saganhos": "saganho",
    "sagapejos": "sagapejo",
    "sagapenos": "sagapeno",
    "sagas": "saga",
    "sagazes": "sagaz",
    "sagenites": "sagenite",
    "sages": "sage",
    "sagezas": "sageza",
    "sagitada": "sagitado",
    "sagitadas": "sagitado",
    "sagitados": "sagitado",
    "sagitais": "sagital",
    "sagitariana": "sagitariano",
    "sagitarianas": "sagitariano",
    "sagitarianos": "sagitariano",
    "sagitária": "sagitário",
    "sagitárias": "sagitário",
    "sagitários": "sagitário",
    "sagitífera": "sagitífero",
    "sagitíferas": "sagitífero",
    "sagitíferos": "sagitífero",
    "sagos": "sago",
    "sagra": "sagrar",
    "sagrada": "sagrar",
    "sagradas": "sagrar",
    "sagrado": "sagrar",
    "sagradora": "sagrador",
    "sagradoras": "sagrador",
    "sagradores": "sagrador",
    "sagrados": "sagrar",
    "sagrai": "sagrar",
    "sagrais": "sagrar",
    "sagram": "sagrar",
    "sagramo": "sagrar",
    "sagramos": "sagrar",
    "sagrando": "sagrar",
    "sagrantes": "sagrante",
    "sagrara": "sagrar",
    "sagraram": "sagrar",
    "sagraras": "sagrar",
    "sagrarde": "sagrar",
    "sagrardes": "sagrar",
    "sagrare": "sagrar",
    "sagrarei": "sagrar",
    "sagrareis": "sagrar",
    "sagrarem": "sagrar",
    "sagraremos": "sagrar",
    "sagrares": "sagrar",
    "sagraria": "sagrar",
    "sagrariam": "sagrar",
    "sagrarias": "sagrar",
    "sagrarmo": "sagrar",
    "sagrarmos": "sagrar",
    "sagrará": "sagrar",
    "sagrarás": "sagrar",
    "sagrarão": "sagrar",
    "sagraríamos": "sagrar",
    "sagraríeis": "sagrar",
    "sagras": "sagrar",
    "sagrasse": "sagrar",
    "sagrassem": "sagrar",
    "sagrasses": "sagrar",
    "sagraste": "sagrar",
    "sagrastes": "sagrar",
    "sagrava": "sagrar",
    "sagravam": "sagrar",
    "sagravas": "sagrar",
    "sagrações": "sagração",
    "sagre": "sagrar",
    "sagrei": "sagrar",
    "sagreis": "sagrar",
    "sagrem": "sagrar",
    "sagremo": "sagrar",
    "sagremos": "sagrar",
    "sagres": "sagre",
    "sagro": "sagrar",
    "sagros": "sagro",
    "sagrou": "sagrar",
    "sagrá": "sagrar",
    "sagrámo": "sagrar",
    "sagrámos": "sagrar",
    "sagráramo": "sagrar",
    "sagráramos": "sagrar",
    "sagrárei": "sagrar",
    "sagráreis": "sagrar",
    "sagrásseis": "sagrar",
    "sagrássemos": "sagrar",
    "sagrávamo": "sagrar",
    "sagrávamos": "sagrar",
    "sagrávei": "sagrar",
    "sagráveis": "sagrar",
    "saguais": "sagual",
    "saguates": "saguate",
    "sagueiros": "sagueiro",
    "saguins": "saguim",
    "saguis": "sagui",
    "saguns": "sagum",
    "saguntina": "saguntino",
    "saguntinas": "saguntino",
    "saguntinos": "saguntino",
    "sagus": "sagu",
    "saguões": "saguão",
    "sai": "sair",
    "saia": "sair",
    "saiaguesa": "saiaguês",
    "saiaguesas": "saiaguês",
    "saiagueses": "saiaguês",
    "saiais": "sair",
    "saiam": "sair",
    "saiamo": "sair",
    "saiamos": "sair",
    "saias": "sair",
    "saiba": "saber",
    "saibais": "saber",
    "saibam": "saber",
    "saibamo": "saber",
    "saibamos": "saber",
    "saibas": "saber",
    "saibei": "saber",
    "saibos": "saibo",
    "saibra": "saibrar",
    "saibrada": "saibrar",
    "saibradas": "saibrar",
    "saibrado": "saibrar",
    "saibrados": "saibrar",
    "saibrai": "saibrar",
    "saibrais": "saibrar",
    "saibram": "saibrar",
    "saibramentos": "saibramento",
    "saibramo": "saibrar",
    "saibramos": "saibrar",
    "saibrando": "saibrar",
    "saibrara": "saibrar",
    "saibraram": "saibrar",
    "saibraras": "saibrar",
    "saibrarde": "saibrar",
    "saibrardes": "saibrar",
    "saibrare": "saibrar",
    "saibrarei": "saibrar",
    "saibrareis": "saibrar",
    "saibrarem": "saibrar",
    "saibraremos": "saibrar",
    "saibrares": "saibrar",
    "saibraria": "saibrar",
    "saibrariam": "saibrar",
    "saibrarias": "saibrar",
    "saibrarmo": "saibrar",
    "saibrarmos": "saibrar",
    "saibrará": "saibrar",
    "saibrarás": "saibrar",
    "saibrarão": "saibrar",
    "saibraríamos": "saibrar",
    "saibraríeis": "saibrar",
    "saibras": "saibrar",
    "saibrasse": "saibrar",
    "saibrassem": "saibrar",
    "saibrasses": "saibrar",
    "saibraste": "saibrar",
    "saibrastes": "saibrar",
    "saibrava": "saibrar",
    "saibravam": "saibrar",
    "saibravas": "saibrar",
    "saibre": "saibrar",
    "saibrei": "saibrar",
    "saibreiras": "saibreira",
    "saibreis": "saibrar",
    "saibrem": "saibrar",
    "saibremo": "saibrar",
    "saibremos": "saibrar",
    "saibres": "saibrar",
    "saibro": "saibrar",
    "saibros": "saibro",
    "saibrosa": "saibroso",
    "saibrosas": "saibroso",
    "saibrosos": "saibroso",
    "saibrou": "saibrar",
    "saibrá": "saibrar",
    "saibrámo": "saibrar",
    "saibrámos": "saibrar",
    "saibráramo": "saibrar",
    "saibráramos": "saibrar",
    "saibrárei": "saibrar",
    "saibráreis": "saibrar",
    "saibrásseis": "saibrar",
    "saibrássemos": "saibrar",
    "saibrávamo": "saibrar",
    "saibrávamos": "saibrar",
    "saibrávei": "saibrar",
    "saibráveis": "saibrar",
    "saibrões": "saibrão",
    "saidoiros": "saidoiro",
    "saidouros": "saidouro",
    "saietas": "saieta",
    "saigas": "saiga",
    "saimeis": "saimel",
    "saimentos": "saimento",
    "saimiris": "saimiri",
    "saimões": "saimão",
    "saindo": "sair",
    "sainetes": "sainete",
    "sainha": "saia",
    "sainhas": "saia",
    "saintes": "sainte",
    "saio": "sair",
    "saios": "saio",
    "saiotes": "saiote",
    "sairdes": "sair",
    "sairei": "sair",
    "saireis": "sair",
    "sairemos": "sair",
    "sairia": "sair",
    "sairiam": "sair",
    "sairias": "sair",
    "sairmo": "sair",
    "sairmos": "sair",
    "sairá": "sair",
    "sairás": "sair",
    "sairão": "sair",
    "sairíamos": "sair",
    "sairíeis": "sair",
    "sais": "sal",
    "saita": "saia",
    "saitas": "saia",
    "saiu": "sair",
    "saiões": "saião",
    "sakmarianos": "sakmariano",
    "salabórdias": "salabórdia",
    "salaciana": "salaciano",
    "salacianas": "salaciano",
    "salacianos": "salaciano",
    "salacidades": "salacidade",
    "saladas": "salada",
    "saladeiras": "saladeira",
    "saladeiros": "saladeiro",
    "saladinha": "salada",
    "saladinhas": "salada",
    "saladita": "salada",
    "saladitas": "salada",
    "salafrária": "salafrário",
    "salafrárias": "salafrário",
    "salafrários": "salafrário",
    "salalés": "salalé",
    "salamaleques": "salamaleque",
    "salamandras": "salamandra",
    "salamanquenses": "salamanquense",
    "salamanquina": "salamanquino",
    "salamanquinas": "salamanquino",
    "salamanquinos": "salamanquino",
    "salamantas": "salamanta",
    "salames": "salame",
    "salamurda": "salamurdo",
    "salamurdas": "salamurdo",
    "salamurdos": "salamurdo",
    "salamântegas": "salamântega",
    "salamântigas": "salamântiga",
    "salanganas": "salangana",
    "salaria": "salariar",
    "salariada": "salariar",
    "salariadas": "salariar",
    "salariado": "salariar",
    "salariados": "salariar",
    "salariai": "salariar",
    "salariais": "salariar",
    "salariam": "salariar",
    "salariamo": "salariar",
    "salariamos": "salariar",
    "salariando": "salariar",
    "salariara": "salariar",
    "salariaram": "salariar",
    "salariaras": "salariar",
    "salariarde": "salariar",
    "salariardes": "salariar",
    "salariare": "salariar",
    "salariarei": "salariar",
    "salariareis": "salariar",
    "salariarem": "salariar",
    "salariaremos": "salariar",
    "salariares": "salariar",
    "salariaria": "salariar",
    "salariariam": "salariar",
    "salariarias": "salariar",
    "salariarmo": "salariar",
    "salariarmos": "salariar",
    "salariará": "salariar",
    "salariarás": "salariar",
    "salariarão": "salariar",
    "salariaríamos": "salariar",
    "salariaríeis": "salariar",
    "salarias": "salariar",
    "salariasse": "salariar",
    "salariassem": "salariar",
    "salariasses": "salariar",
    "salariaste": "salariar",
    "salariastes": "salariar",
    "salariatos": "salariato",
    "salariava": "salariar",
    "salariavam": "salariar",
    "salariavas": "salariar",
    "salarie": "salariar",
    "salariei": "salariar",
    "salarieis": "salariar",
    "salariem": "salariar",
    "salariemo": "salariar",
    "salariemos": "salariar",
    "salaries": "salariar",
    "salario": "salariar",
    "salariou": "salariar",
    "salariá": "salariar",
    "salariámo": "salariar",
    "salariámos": "salariar",
    "salariáramo": "salariar",
    "salariáramos": "salariar",
    "salariárei": "salariar",
    "salariáreis": "salariar",
    "salariásseis": "salariar",
    "salariássemos": "salariar",
    "salariávamo": "salariar",
    "salariávamos": "salariar",
    "salariávei": "salariar",
    "salariáveis": "salariar",
    "salas": "sala",
    "salazarenta": "salazarento",
    "salazarentas": "salazarento",
    "salazarentos": "salazarento",
    "salazarismos": "salazarismo",
    "salazaristas": "salazarista",
    "salazes": "salaz",
    "salbandas": "salbanda",
    "salchichas": "salchicha",
    "salda": "saldar",
    "saldada": "saldar",
    "saldadas": "saldar",
    "saldado": "saldar",
    "saldados": "saldar",
    "saldai": "saldar",
    "saldais": "saldar",
    "saldam": "saldar",
    "saldamo": "saldar",
    "saldamos": "saldar",
    "saldando": "saldar",
    "saldanhistas": "saldanhista",
    "saldara": "saldar",
    "saldaram": "saldar",
    "saldaras": "saldar",
    "saldarde": "saldar",
    "saldardes": "saldar",
    "saldare": "saldar",
    "saldarei": "saldar",
    "saldareis": "saldar",
    "saldarem": "saldar",
    "saldaremos": "saldar",
    "saldares": "saldar",
    "saldaria": "saldar",
    "saldariam": "saldar",
    "saldarias": "saldar",
    "saldarmo": "saldar",
    "saldarmos": "saldar",
    "saldará": "saldar",
    "saldarás": "saldar",
    "saldarão": "saldar",
    "saldaríamos": "saldar",
    "saldaríeis": "saldar",
    "saldas": "saldar",
    "saldasse": "saldar",
    "saldassem": "saldar",
    "saldasses": "saldar",
    "saldaste": "saldar",
    "saldastes": "saldar",
    "saldava": "saldar",
    "saldavam": "saldar",
    "saldavas": "saldar",
    "salde": "saldar",
    "saldei": "saldar",
    "saldeis": "saldar",
    "saldem": "saldar",
    "saldemo": "saldar",
    "saldemos": "saldar",
    "saldes": "saldar",
    "saldo": "saldar",
    "saldos": "saldo",
    "saldou": "saldar",
    "saldunes": "saldune",
    "saldá": "saldar",
    "saldámo": "saldar",
    "saldámos": "saldar",
    "saldáramo": "saldar",
    "saldáramos": "saldar",
    "saldárei": "saldar",
    "saldáreis": "saldar",
    "saldásseis": "saldar",
    "saldássemos": "saldar",
    "saldávamo": "saldar",
    "saldávamos": "saldar",
    "saldávei": "saldar",
    "saldáveis": "saldar",
    "saleiras": "saleira",
    "saleiros": "saleiro",
    "salemas": "salema",
    "salepeiras": "salepeira",
    "salepos": "salepo",
    "salernitana": "salernitano",
    "salernitanas": "salernitano",
    "salernitanos": "salernitano",
    "saleros": "salero",
    "salesiana": "salesiano",
    "salesianas": "salesiano",
    "salesianos": "salesiano",
    "saletas": "saleta",
    "salga": "salgar",
    "salgada": "salgar",
    "salgadas": "salgar",
    "salgadeiras": "salgadeira",
    "salgadia": "salgadio",
    "salgadias": "salgadio",
    "salgadinha": "salgado",
    "salgadinhas": "salgado",
    "salgadinho": "salgado",
    "salgadinhos": "salgado",
    "salgadios": "salgadio",
    "salgadita": "salgado",
    "salgaditas": "salgado",
    "salgadito": "salgado",
    "salgaditos": "salgado",
    "salgadiça": "salgadiço",
    "salgadiças": "salgadiço",
    "salgadiços": "salgadiço",
    "salgado": "salgar",
    "salgados": "salgar",
    "salgaduras": "salgadura",
    "salgadíssima": "salgado",
    "salgadíssimas": "salgado",
    "salgadíssimo": "salgado",
    "salgadíssimos": "salgado",
    "salgai": "salgar",
    "salgais": "salgar",
    "salgalhadas": "salgalhada",
    "salgam": "salgar",
    "salgamo": "salgar",
    "salgamos": "salgar",
    "salgando": "salgar",
    "salgara": "salgar",
    "salgaram": "salgar",
    "salgaras": "salgar",
    "salgarde": "salgar",
    "salgardes": "salgar",
    "salgare": "salgar",
    "salgarei": "salgar",
    "salgareis": "salgar",
    "salgarem": "salgar",
    "salgaremos": "salgar",
    "salgares": "salgar",
    "salgaria": "salgar",
    "salgariam": "salgar",
    "salgarias": "salgar",
    "salgarmo": "salgar",
    "salgarmos": "salgar",
    "salgará": "salgar",
    "salgarás": "salgar",
    "salgarão": "salgar",
    "salgaríamos": "salgar",
    "salgaríeis": "salgar",
    "salgas": "salgar",
    "salgasse": "salgar",
    "salgassem": "salgar",
    "salgasses": "salgar",
    "salgaste": "salgar",
    "salgastes": "salgar",
    "salgava": "salgar",
    "salgavam": "salgar",
    "salgavas": "salgar",
    "salgações": "salgação",
    "salgo": "salgar",
    "salgou": "salgar",
    "salgue": "salgar",
    "salguei": "salgar",
    "salgueirais": "salgueiral",
    "salgueiras": "salgueira",
    "salgueirinhas": "salgueirinha",
    "salgueiros": "salgueiro",
    "salgueis": "salgar",
    "salguem": "salgar",
    "salguemo": "salgar",
    "salguemos": "salgar",
    "salgues": "salgar",
    "salgá": "salgar",
    "salgámo": "salgar",
    "salgámos": "salgar",
    "salgáramo": "salgar",
    "salgáramos": "salgar",
    "salgárei": "salgar",
    "salgáreis": "salgar",
    "salgásseis": "salgar",
    "salgássemos": "salgar",
    "salgávamo": "salgar",
    "salgávamos": "salgar",
    "salgávei": "salgar",
    "salgáveis": "salgar",
    "salicilatos": "salicilato",
    "salicilinas": "salicilina",
    "salicultora": "salicultor",
    "salicultoras": "salicultor",
    "salicultores": "salicultor",
    "saliculturas": "salicultura",
    "salicáceas": "salicácea",
    "salicílica": "salicílico",
    "salicílicas": "salicílico",
    "salicílicos": "salicílico",
    "salicívora": "salicívoro",
    "salicívoras": "salicívoro",
    "salicívoros": "salicívoro",
    "salienta": "salientar",
    "salientada": "salientar",
    "salientadas": "salientar",
    "salientado": "salientar",
    "salientados": "salientar",
    "salientai": "salientar",
    "salientais": "salientar",
    "salientam": "salientar",
    "salientamo": "salientar",
    "salientamos": "salientar",
    "salientando": "salientar",
    "salientara": "salientar",
    "salientaram": "salientar",
    "salientaras": "salientar",
    "salientarde": "salientar",
    "salientardes": "salientar",
    "salientare": "salientar",
    "salientarei": "salientar",
    "salientareis": "salientar",
    "salientarem": "salientar",
    "salientaremos": "salientar",
    "salientares": "salientar",
    "salientaria": "salientar",
    "salientariam": "salientar",
    "salientarias": "salientar",
    "salientarmo": "salientar",
    "salientarmos": "salientar",
    "salientará": "salientar",
    "salientarás": "salientar",
    "salientarão": "salientar",
    "salientaríamos": "salientar",
    "salientaríeis": "salientar",
    "salientas": "salientar",
    "salientasse": "salientar",
    "salientassem": "salientar",
    "salientasses": "salientar",
    "salientaste": "salientar",
    "salientastes": "salientar",
    "salientava": "salientar",
    "salientavam": "salientar",
    "salientavas": "salientar",
    "saliente": "salientar",
    "salientei": "salientar",
    "salienteis": "salientar",
    "salientem": "salientar",
    "salientemo": "salientar",
    "salientemos": "salientar",
    "salientes": "saliente",
    "saliento": "salientar",
    "salientou": "salientar",
    "salientá": "salientar",
    "salientámo": "salientar",
    "salientámos": "salientar",
    "salientáramo": "salientar",
    "salientáramos": "salientar",
    "salientárei": "salientar",
    "salientáreis": "salientar",
    "salientásseis": "salientar",
    "salientássemos": "salientar",
    "salientávamo": "salientar",
    "salientávamos": "salientar",
    "salientávei": "salientar",
    "salientáveis": "salientar",
    "salifica": "salificar",
    "salificada": "salificar",
    "salificadas": "salificar",
    "salificado": "salificar",
    "salificados": "salificar",
    "salificai": "salificar",
    "salificais": "salificar",
    "salificam": "salificar",
    "salificamo": "salificar",
    "salificamos": "salificar",
    "salificando": "salificar",
    "salificara": "salificar",
    "salificaram": "salificar",
    "salificaras": "salificar",
    "salificarde": "salificar",
    "salificardes": "salificar",
    "salificare": "salificar",
    "salificarei": "salificar",
    "salificareis": "salificar",
    "salificarem": "salificar",
    "salificaremos": "salificar",
    "salificares": "salificar",
    "salificaria": "salificar",
    "salificariam": "salificar",
    "salificarias": "salificar",
    "salificarmo": "salificar",
    "salificarmos": "salificar",
    "salificará": "salificar",
    "salificarás": "salificar",
    "salificarão": "salificar",
    "salificaríamos": "salificar",
    "salificaríeis": "salificar",
    "salificas": "salificar",
    "salificasse": "salificar",
    "salificassem": "salificar",
    "salificasses": "salificar",
    "salificaste": "salificar",
    "salificastes": "salificar",
    "salificava": "salificar",
    "salificavam": "salificar",
    "salificavas": "salificar",
    "salificações": "salificação",
    "salifico": "salificar",
    "salificou": "salificar",
    "salificá": "salificar",
    "salificámo": "salificar",
    "salificámos": "salificar",
    "salificáramo": "salificar",
    "salificáramos": "salificar",
    "salificárei": "salificar",
    "salificáreis": "salificar",
    "salificásseis": "salificar",
    "salificássemos": "salificar",
    "salificávamo": "salificar",
    "salificávamos": "salificar",
    "salificávei": "salificar",
    "salificáveis": "salificável",
    "salifique": "salificar",
    "salifiquei": "salificar",
    "salifiqueis": "salificar",
    "salifiquem": "salificar",
    "salifiquemo": "salificar",
    "salifiquemos": "salificar",
    "salifiques": "salificar",
    "salimancias": "salimancia",
    "salimantes": "salimante",
    "salina": "salino",
    "salinada": "salinar",
    "salinadas": "salinar",
    "salinado": "salinar",
    "salinados": "salinar",
    "salinagens": "salinagem",
    "salinai": "salinar",
    "salinais": "salinar",
    "salinam": "salinar",
    "salinamo": "salinar",
    "salinamos": "salinar",
    "salinando": "salinar",
    "salinara": "salinar",
    "salinaram": "salinar",
    "salinaras": "salinar",
    "salinarde": "salinar",
    "salinardes": "salinar",
    "salinare": "salinar",
    "salinarei": "salinar",
    "salinareis": "salinar",
    "salinarem": "salinar",
    "salinaremos": "salinar",
    "salinares": "salinar",
    "salinaria": "salinar",
    "salinariam": "salinar",
    "salinarias": "salinar",
    "salinarmo": "salinar",
    "salinarmos": "salinar",
    "salinará": "salinar",
    "salinarás": "salinar",
    "salinarão": "salinar",
    "salinaríamos": "salinar",
    "salinaríeis": "salinar",
    "salinas": "salino",
    "salinasse": "salinar",
    "salinassem": "salinar",
    "salinasses": "salinar",
    "salinaste": "salinar",
    "salinastes": "salinar",
    "salinava": "salinar",
    "salinavam": "salinar",
    "salinavas": "salinar",
    "salinações": "salinação",
    "saline": "salinar",
    "salinei": "salinar",
    "salineira": "salineiro",
    "salineiras": "salineiro",
    "salineiros": "salineiro",
    "salineis": "salinar",
    "salinem": "salinar",
    "salinemo": "salinar",
    "salinemos": "salinar",
    "salines": "salinar",
    "salinha": "sala",
    "salinhas": "sala",
    "salinidades": "salinidade",
    "salinizações": "salinização",
    "salino": "salinar",
    "salinos": "salino",
    "salinou": "salinar",
    "saliná": "salinar",
    "salinámo": "salinar",
    "salinámos": "salinar",
    "salináramo": "salinar",
    "salináramos": "salinar",
    "salinárei": "salinar",
    "salináreis": "salinar",
    "salinásseis": "salinar",
    "salinássemos": "salinar",
    "salinávamo": "salinar",
    "salinávamos": "salinar",
    "salinávei": "salinar",
    "salináveis": "salinável",
    "salinómetros": "salinómetro",
    "salita": "sala",
    "salitas": "sala",
    "salitra": "salitrar",
    "salitrada": "salitrar",
    "salitradas": "salitrar",
    "salitrado": "salitrar",
    "salitrados": "salitrar",
    "salitrai": "salitrar",
    "salitrais": "salitrar",
    "salitram": "salitrar",
    "salitramo": "salitrar",
    "salitramos": "salitrar",
    "salitrando": "salitrar",
    "salitrara": "salitrar",
    "salitraram": "salitrar",
    "salitraras": "salitrar",
    "salitrarde": "salitrar",
    "salitrardes": "salitrar",
    "salitrare": "salitrar",
    "salitrarei": "salitrar",
    "salitrareis": "salitrar",
    "salitrarem": "salitrar",
    "salitraremos": "salitrar",
    "salitrares": "salitrar",
    "salitraria": "salitrar",
    "salitrariam": "salitrar",
    "salitrarias": "salitraria",
    "salitrarmo": "salitrar",
    "salitrarmos": "salitrar",
    "salitrará": "salitrar",
    "salitrarás": "salitrar",
    "salitrarão": "salitrar",
    "salitraríamos": "salitrar",
    "salitraríeis": "salitrar",
    "salitras": "salitrar",
    "salitrasse": "salitrar",
    "salitrassem": "salitrar",
    "salitrasses": "salitrar",
    "salitraste": "salitrar",
    "salitrastes": "salitrar",
    "salitrava": "salitrar",
    "salitravam": "salitrar",
    "salitravas": "salitrar",
    "salitrações": "salitração",
    "salitre": "salitrar",
    "salitrei": "salitrar",
    "salitreira": "salitreiro",
    "salitreiras": "salitreiro",
    "salitreiros": "salitreiro",
    "salitreis": "salitrar",
    "salitrem": "salitrar",
    "salitremo": "salitrar",
    "salitremos": "salitrar",
    "salitres": "salitre",
    "salitriza": "salitrizar",
    "salitrizada": "salitrizar",
    "salitrizadas": "salitrizar",
    "salitrizado": "salitrizar",
    "salitrizados": "salitrizar",
    "salitrizai": "salitrizar",
    "salitrizais": "salitrizar",
    "salitrizam": "salitrizar",
    "salitrizamo": "salitrizar",
    "salitrizamos": "salitrizar",
    "salitrizando": "salitrizar",
    "salitrizara": "salitrizar",
    "salitrizaram": "salitrizar",
    "salitrizaras": "salitrizar",
    "salitrizarde": "salitrizar",
    "salitrizardes": "salitrizar",
    "salitrizare": "salitrizar",
    "salitrizarei": "salitrizar",
    "salitrizareis": "salitrizar",
    "salitrizarem": "salitrizar",
    "salitrizaremos": "salitrizar",
    "salitrizares": "salitrizar",
    "salitrizaria": "salitrizar",
    "salitrizariam": "salitrizar",
    "salitrizarias": "salitrizar",
    "salitrizarmo": "salitrizar",
    "salitrizarmos": "salitrizar",
    "salitrizará": "salitrizar",
    "salitrizarás": "salitrizar",
    "salitrizarão": "salitrizar",
    "salitrizaríamos": "salitrizar",
    "salitrizaríeis": "salitrizar",
    "salitrizas": "salitrizar",
    "salitrizasse": "salitrizar",
    "salitrizassem": "salitrizar",
    "salitrizasses": "salitrizar",
    "salitrizaste": "salitrizar",
    "salitrizastes": "salitrizar",
    "salitrizava": "salitrizar",
    "salitrizavam": "salitrizar",
    "salitrizavas": "salitrizar",
    "salitrizações": "salitrização",
    "salitrize": "salitrizar",
    "salitrizei": "salitrizar",
    "salitrizeis": "salitrizar",
    "salitrizem": "salitrizar",
    "salitrizemo": "salitrizar",
    "salitrizemos": "salitrizar",
    "salitrizes": "salitrizar",
    "salitrizo": "salitrizar",
    "salitrizou": "salitrizar",
    "salitrizá": "salitrizar",
    "salitrizámo": "salitrizar",
    "salitrizámos": "salitrizar",
    "salitrizáramo": "salitrizar",
    "salitrizáramos": "salitrizar",
    "salitrizárei": "salitrizar",
    "salitrizáreis": "salitrizar",
    "salitrizásseis": "salitrizar",
    "salitrizássemos": "salitrizar",
    "salitrizávamo": "salitrizar",
    "salitrizávamos": "salitrizar",
    "salitrizávei": "salitrizar",
    "salitrizáveis": "salitrizar",
    "salitro": "salitrar",
    "salitrosa": "salitroso",
    "salitrosas": "salitroso",
    "salitrosos": "salitroso",
    "salitrou": "salitrar",
    "salitrá": "salitrar",
    "salitrámo": "salitrar",
    "salitrámos": "salitrar",
    "salitráramo": "salitrar",
    "salitráramos": "salitrar",
    "salitrárei": "salitrar",
    "salitráreis": "salitrar",
    "salitrásseis": "salitrar",
    "salitrássemos": "salitrar",
    "salitrávamo": "salitrar",
    "salitrávamos": "salitrar",
    "salitrávei": "salitrar",
    "salitráveis": "salitrar",
    "saliva": "salivar",
    "salivada": "salivar",
    "salivadas": "salivar",
    "salivado": "salivar",
    "salivados": "salivar",
    "salivai": "salivar",
    "salivais": "salivar",
    "salivam": "salivar",
    "salivamo": "salivar",
    "salivamos": "salivar",
    "salivando": "salivar",
    "salivantes": "salivante",
    "salivara": "salivar",
    "salivaram": "salivar",
    "salivaras": "salivar",
    "salivardes": "salivar",
    "salivarei": "salivar",
    "salivareis": "salivar",
    "salivarem": "salivar",
    "salivaremos": "salivar",
    "salivares": "salivar",
    "salivaria": "salivar",
    "salivariam": "salivar",
    "salivarias": "salivar",
    "salivarmo": "salivar",
    "salivarmos": "salivar",
    "salivará": "salivar",
    "salivarás": "salivar",
    "salivarão": "salivar",
    "salivaríamos": "salivar",
    "salivaríeis": "salivar",
    "salivas": "salivar",
    "salivasse": "salivar",
    "salivassem": "salivar",
    "salivasses": "salivar",
    "salivaste": "salivar",
    "salivastes": "salivar",
    "salivava": "salivar",
    "salivavam": "salivar",
    "salivavas": "salivar",
    "salivações": "salivação",
    "salive": "salivar",
    "salivei": "salivar",
    "saliveis": "salivar",
    "salivem": "salivar",
    "salivemo": "salivar",
    "salivemos": "salivar",
    "salives": "salivar",
    "salivo": "salivar",
    "salivosa": "salivoso",
    "salivosas": "salivoso",
    "salivosos": "salivoso",
    "salivou": "salivar",
    "salivámo": "salivar",
    "salivámos": "salivar",
    "saliváramo": "salivar",
    "saliváramos": "salivar",
    "saliváreis": "salivar",
    "salivásseis": "salivar",
    "salivássemos": "salivar",
    "salivávamo": "salivar",
    "salivávamos": "salivar",
    "saliváveis": "salivar",
    "saliências": "saliência",
    "salmanticenses": "salmanticense",
    "salmantina": "salmantino",
    "salmantinas": "salmantino",
    "salmantinos": "salmantino",
    "salmeada": "salmear",
    "salmeadas": "salmear",
    "salmeado": "salmear",
    "salmeados": "salmear",
    "salmeai": "salmear",
    "salmeais": "salmear",
    "salmeamo": "salmear",
    "salmeamos": "salmear",
    "salmeando": "salmear",
    "salmeara": "salmear",
    "salmearam": "salmear",
    "salmearas": "salmear",
    "salmeardes": "salmear",
    "salmearei": "salmear",
    "salmeareis": "salmear",
    "salmearem": "salmear",
    "salmearemos": "salmear",
    "salmeares": "salmear",
    "salmearia": "salmear",
    "salmeariam": "salmear",
    "salmearias": "salmear",
    "salmearmo": "salmear",
    "salmearmos": "salmear",
    "salmeará": "salmear",
    "salmearás": "salmear",
    "salmearão": "salmear",
    "salmearíamos": "salmear",
    "salmearíeis": "salmear",
    "salmeasse": "salmear",
    "salmeassem": "salmear",
    "salmeasses": "salmear",
    "salmeaste": "salmear",
    "salmeastes": "salmear",
    "salmeava": "salmear",
    "salmeavam": "salmear",
    "salmeavas": "salmear",
    "salmeei": "salmear",
    "salmeeis": "salmear",
    "salmeemo": "salmear",
    "salmeemos": "salmear",
    "salmeia": "salmear",
    "salmeiam": "salmear",
    "salmeias": "salmear",
    "salmeie": "salmear",
    "salmeiem": "salmear",
    "salmeies": "salmear",
    "salmeio": "salmear",
    "salmeja": "salmejar",
    "salmejada": "salmejar",
    "salmejadas": "salmejar",
    "salmejado": "salmejar",
    "salmejados": "salmejar",
    "salmejai": "salmejar",
    "salmejais": "salmejar",
    "salmejam": "salmejar",
    "salmejamo": "salmejar",
    "salmejamos": "salmejar",
    "salmejando": "salmejar",
    "salmejara": "salmejar",
    "salmejaram": "salmejar",
    "salmejaras": "salmejar",
    "salmejardes": "salmejar",
    "salmejarei": "salmejar",
    "salmejareis": "salmejar",
    "salmejarem": "salmejar",
    "salmejaremos": "salmejar",
    "salmejares": "salmejar",
    "salmejaria": "salmejar",
    "salmejariam": "salmejar",
    "salmejarias": "salmejar",
    "salmejarmo": "salmejar",
    "salmejarmos": "salmejar",
    "salmejará": "salmejar",
    "salmejarás": "salmejar",
    "salmejarão": "salmejar",
    "salmejaríamos": "salmejar",
    "salmejaríeis": "salmejar",
    "salmejas": "salmejar",
    "salmejasse": "salmejar",
    "salmejassem": "salmejar",
    "salmejasses": "salmejar",
    "salmejaste": "salmejar",
    "salmejastes": "salmejar",
    "salmejava": "salmejar",
    "salmejavam": "salmejar",
    "salmejavas": "salmejar",
    "salmeje": "salmejar",
    "salmejei": "salmejar",
    "salmejeis": "salmejar",
    "salmejem": "salmejar",
    "salmejemo": "salmejar",
    "salmejemos": "salmejar",
    "salmejes": "salmejar",
    "salmejo": "salmejar",
    "salmejou": "salmejar",
    "salmejámo": "salmejar",
    "salmejámos": "salmejar",
    "salmejáramo": "salmejar",
    "salmejáramos": "salmejar",
    "salmejáreis": "salmejar",
    "salmejásseis": "salmejar",
    "salmejássemos": "salmejar",
    "salmejávamo": "salmejar",
    "salmejávamos": "salmejar",
    "salmejáveis": "salmejar",
    "salmeou": "salmear",
    "salmeámo": "salmear",
    "salmeámos": "salmear",
    "salmeáramo": "salmear",
    "salmeáramos": "salmear",
    "salmeáreis": "salmear",
    "salmeásseis": "salmear",
    "salmeássemos": "salmear",
    "salmeávamo": "salmear",
    "salmeávamos": "salmear",
    "salmeáveis": "salmear",
    "salmistas": "salmista",
    "salmodia": "salmodiar",
    "salmodiada": "salmodiar",
    "salmodiadas": "salmodiar",
    "salmodiado": "salmodiar",
    "salmodiados": "salmodiar",
    "salmodiai": "salmodiar",
    "salmodiais": "salmodiar",
    "salmodiam": "salmodiar",
    "salmodiamo": "salmodiar",
    "salmodiamos": "salmodiar",
    "salmodiando": "salmodiar",
    "salmodiara": "salmodiar",
    "salmodiaram": "salmodiar",
    "salmodiaras": "salmodiar",
    "salmodiardes": "salmodiar",
    "salmodiarei": "salmodiar",
    "salmodiareis": "salmodiar",
    "salmodiarem": "salmodiar",
    "salmodiaremos": "salmodiar",
    "salmodiares": "salmodiar",
    "salmodiaria": "salmodiar",
    "salmodiariam": "salmodiar",
    "salmodiarias": "salmodiar",
    "salmodiarmo": "salmodiar",
    "salmodiarmos": "salmodiar",
    "salmodiará": "salmodiar",
    "salmodiarás": "salmodiar",
    "salmodiarão": "salmodiar",
    "salmodiaríamos": "salmodiar",
    "salmodiaríeis": "salmodiar",
    "salmodias": "salmodiar",
    "salmodiasse": "salmodiar",
    "salmodiassem": "salmodiar",
    "salmodiasses": "salmodiar",
    "salmodiaste": "salmodiar",
    "salmodiastes": "salmodiar",
    "salmodiava": "salmodiar",
    "salmodiavam": "salmodiar",
    "salmodiavas": "salmodiar",
    "salmodie": "salmodiar",
    "salmodiei": "salmodiar",
    "salmodieis": "salmodiar",
    "salmodiem": "salmodiar",
    "salmodiemo": "salmodiar",
    "salmodiemos": "salmodiar",
    "salmodies": "salmodiar",
    "salmodio": "salmodiar",
    "salmodiou": "salmodiar",
    "salmodiámo": "salmodiar",
    "salmodiámos": "salmodiar",
    "salmodiáramo": "salmodiar",
    "salmodiáramos": "salmodiar",
    "salmodiáreis": "salmodiar",
    "salmodiásseis": "salmodiar",
    "salmodiássemos": "salmodiar",
    "salmodiávamo": "salmodiar",
    "salmodiávamos": "salmodiar",
    "salmodiáveis": "salmodiar",
    "salmoeiras": "salmoeira",
    "salmoeiros": "salmoeiro",
    "salmoira": "salmoirar",
    "salmoirada": "salmoirar",
    "salmoiradas": "salmoirar",
    "salmoirado": "salmoirar",
    "salmoirados": "salmoirar",
    "salmoirai": "salmoirar",
    "salmoirais": "salmoirar",
    "salmoiram": "salmoirar",
    "salmoiramo": "salmoirar",
    "salmoiramos": "salmoirar",
    "salmoirando": "salmoirar",
    "salmoirara": "salmoirar",
    "salmoiraram": "salmoirar",
    "salmoiraras": "salmoirar",
    "salmoirarde": "salmoirar",
    "salmoirardes": "salmoirar",
    "salmoirare": "salmoirar",
    "salmoirarei": "salmoirar",
    "salmoirareis": "salmoirar",
    "salmoirarem": "salmoirar",
    "salmoiraremos": "salmoirar",
    "salmoirares": "salmoirar",
    "salmoiraria": "salmoirar",
    "salmoirariam": "salmoirar",
    "salmoirarias": "salmoirar",
    "salmoirarmo": "salmoirar",
    "salmoirarmos": "salmoirar",
    "salmoirará": "salmoirar",
    "salmoirarás": "salmoirar",
    "salmoirarão": "salmoirar",
    "salmoiraríamos": "salmoirar",
    "salmoiraríeis": "salmoirar",
    "salmoiras": "salmoirar",
    "salmoirasse": "salmoirar",
    "salmoirassem": "salmoirar",
    "salmoirasses": "salmoirar",
    "salmoiraste": "salmoirar",
    "salmoirastes": "salmoirar",
    "salmoirava": "salmoirar",
    "salmoiravam": "salmoirar",
    "salmoiravas": "salmoirar",
    "salmoire": "salmoirar",
    "salmoirei": "salmoirar",
    "salmoireis": "salmoirar",
    "salmoirem": "salmoirar",
    "salmoiremo": "salmoirar",
    "salmoiremos": "salmoirar",
    "salmoires": "salmoirar",
    "salmoiro": "salmoirar",
    "salmoirou": "salmoirar",
    "salmoirá": "salmoirar",
    "salmoirámo": "salmoirar",
    "salmoirámos": "salmoirar",
    "salmoiráramo": "salmoirar",
    "salmoiráramos": "salmoirar",
    "salmoirárei": "salmoirar",
    "salmoiráreis": "salmoirar",
    "salmoirásseis": "salmoirar",
    "salmoirássemos": "salmoirar",
    "salmoirávamo": "salmoirar",
    "salmoirávamos": "salmoirar",
    "salmoirávei": "salmoirar",
    "salmoiráveis": "salmoirar",
    "salmonada": "salmonado",
    "salmonadas": "salmonado",
    "salmonados": "salmonado",
    "salmoneja": "salmonejo",
    "salmonejas": "salmonejo",
    "salmonejos": "salmonejo",
    "salmonelas": "salmonela",
    "salmonetes": "salmonete",
    "salmoniculturas": "salmonicultura",
    "salmonídea": "salmonídeo",
    "salmonídeas": "salmonídeo",
    "salmonídeos": "salmonídeo",
    "salmos": "salmo",
    "salmoura": "salmourar",
    "salmourada": "salmourar",
    "salmouradas": "salmourar",
    "salmourado": "salmourar",
    "salmourados": "salmourar",
    "salmourai": "salmourar",
    "salmourais": "salmourar",
    "salmouram": "salmourar",
    "salmouramo": "salmourar",
    "salmouramos": "salmourar",
    "salmourando": "salmourar",
    "salmourara": "salmourar",
    "salmouraram": "salmourar",
    "salmouraras": "salmourar",
    "salmourarde": "salmourar",
    "salmourardes": "salmourar",
    "salmourare": "salmourar",
    "salmourarei": "salmourar",
    "salmourareis": "salmourar",
    "salmourarem": "salmourar",
    "salmouraremos": "salmourar",
    "salmourares": "salmourar",
    "salmouraria": "salmourar",
    "salmourariam": "salmourar",
    "salmourarias": "salmourar",
    "salmourarmo": "salmourar",
    "salmourarmos": "salmourar",
    "salmourará": "salmourar",
    "salmourarás": "salmourar",
    "salmourarão": "salmourar",
    "salmouraríamos": "salmourar",
    "salmouraríeis": "salmourar",
    "salmouras": "salmourar",
    "salmourasse": "salmourar",
    "salmourassem": "salmourar",
    "salmourasses": "salmourar",
    "salmouraste": "salmourar",
    "salmourastes": "salmourar",
    "salmourava": "salmourar",
    "salmouravam": "salmourar",
    "salmouravas": "salmourar",
    "salmoure": "salmourar",
    "salmourei": "salmourar",
    "salmoureis": "salmourar",
    "salmourem": "salmourar",
    "salmouremo": "salmourar",
    "salmouremos": "salmourar",
    "salmoures": "salmourar",
    "salmouro": "salmourar",
    "salmourou": "salmourar",
    "salmourá": "salmourar",
    "salmourámo": "salmourar",
    "salmourámos": "salmourar",
    "salmouráramo": "salmourar",
    "salmouráramos": "salmourar",
    "salmourárei": "salmourar",
    "salmouráreis": "salmourar",
    "salmourásseis": "salmourar",
    "salmourássemos": "salmourar",
    "salmourávamo": "salmourar",
    "salmourávamos": "salmourar",
    "salmourávei": "salmourar",
    "salmouráveis": "salmourar",
    "salmónidas": "salmónida",
    "salmões": "salmão",
    "salobra": "salobro",
    "salobras": "salobro",
    "salobres": "salobre",
    "salobros": "salobro",
    "saloia": "saloio",
    "saloiadas": "saloiada",
    "saloias": "saloio",
    "saloiices": "saloiice",
    "saloios": "saloio",
    "saloiíssima": "saloio",
    "saloiíssimas": "saloio",
    "saloiíssimo": "saloio",
    "saloiíssimos": "saloio",
    "salomónica": "salomónico",
    "salomónicas": "salomónico",
    "salomónicos": "salomónico",
    "salonicenses": "salonicense",
    "salopianos": "salopiano",
    "salpas": "salpa",
    "salpica": "salpicar",
    "salpicada": "salpicar",
    "salpicadas": "salpicar",
    "salpicado": "salpicar",
    "salpicadora": "salpicador",
    "salpicadoras": "salpicador",
    "salpicadores": "salpicador",
    "salpicados": "salpicar",
    "salpicaduras": "salpicadura",
    "salpicadíssima": "salpicado",
    "salpicadíssimas": "salpicado",
    "salpicadíssimo": "salpicado",
    "salpicadíssimos": "salpicado",
    "salpicai": "salpicar",
    "salpicais": "salpicar",
    "salpicam": "salpicar",
    "salpicamo": "salpicar",
    "salpicamos": "salpicar",
    "salpicando": "salpicar",
    "salpicara": "salpicar",
    "salpicaram": "salpicar",
    "salpicaras": "salpicar",
    "salpicarde": "salpicar",
    "salpicardes": "salpicar",
    "salpicare": "salpicar",
    "salpicarei": "salpicar",
    "salpicareis": "salpicar",
    "salpicarem": "salpicar",
    "salpicaremos": "salpicar",
    "salpicares": "salpicar",
    "salpicaria": "salpicar",
    "salpicariam": "salpicar",
    "salpicarias": "salpicar",
    "salpicarmo": "salpicar",
    "salpicarmos": "salpicar",
    "salpicará": "salpicar",
    "salpicarás": "salpicar",
    "salpicarão": "salpicar",
    "salpicaríamos": "salpicar",
    "salpicaríeis": "salpicar",
    "salpicas": "salpicar",
    "salpicasse": "salpicar",
    "salpicassem": "salpicar",
    "salpicasses": "salpicar",
    "salpicaste": "salpicar",
    "salpicastes": "salpicar",
    "salpicava": "salpicar",
    "salpicavam": "salpicar",
    "salpicavas": "salpicar",
    "salpico": "salpicar",
    "salpicos": "salpico",
    "salpicou": "salpicar",
    "salpicá": "salpicar",
    "salpicámo": "salpicar",
    "salpicámos": "salpicar",
    "salpicáramo": "salpicar",
    "salpicáramos": "salpicar",
    "salpicárei": "salpicar",
    "salpicáreis": "salpicar",
    "salpicásseis": "salpicar",
    "salpicássemos": "salpicar",
    "salpicávamo": "salpicar",
    "salpicávamos": "salpicar",
    "salpicávei": "salpicar",
    "salpicáveis": "salpicar",
    "salpicões": "salpicão",
    "salpimenta": "salpimentar",
    "salpimentada": "salpimentar",
    "salpimentadas": "salpimentar",
    "salpimentado": "salpimentar",
    "salpimentados": "salpimentar",
    "salpimentai": "salpimentar",
    "salpimentais": "salpimentar",
    "salpimentam": "salpimentar",
    "salpimentamo": "salpimentar",
    "salpimentamos": "salpimentar",
    "salpimentando": "salpimentar",
    "salpimentara": "salpimentar",
    "salpimentaram": "salpimentar",
    "salpimentaras": "salpimentar",
    "salpimentarde": "salpimentar",
    "salpimentardes": "salpimentar",
    "salpimentare": "salpimentar",
    "salpimentarei": "salpimentar",
    "salpimentareis": "salpimentar",
    "salpimentarem": "salpimentar",
    "salpimentaremos": "salpimentar",
    "salpimentares": "salpimentar",
    "salpimentaria": "salpimentar",
    "salpimentariam": "salpimentar",
    "salpimentarias": "salpimentar",
    "salpimentarmo": "salpimentar",
    "salpimentarmos": "salpimentar",
    "salpimentará": "salpimentar",
    "salpimentarás": "salpimentar",
    "salpimentarão": "salpimentar",
    "salpimentaríamos": "salpimentar",
    "salpimentaríeis": "salpimentar",
    "salpimentas": "salpimentar",
    "salpimentasse": "salpimentar",
    "salpimentassem": "salpimentar",
    "salpimentasses": "salpimentar",
    "salpimentaste": "salpimentar",
    "salpimentastes": "salpimentar",
    "salpimentava": "salpimentar",
    "salpimentavam": "salpimentar",
    "salpimentavas": "salpimentar",
    "salpimente": "salpimentar",
    "salpimentei": "salpimentar",
    "salpimenteis": "salpimentar",
    "salpimentem": "salpimentar",
    "salpimentemo": "salpimentar",
    "salpimentemos": "salpimentar",
    "salpimentes": "salpimentar",
    "salpimento": "salpimentar",
    "salpimentou": "salpimentar",
    "salpimentá": "salpimentar",
    "salpimentámo": "salpimentar",
    "salpimentámos": "salpimentar",
    "salpimentáramo": "salpimentar",
    "salpimentáramos": "salpimentar",
    "salpimentárei": "salpimentar",
    "salpimentáreis": "salpimentar",
    "salpimentásseis": "salpimentar",
    "salpimentássemos": "salpimentar",
    "salpimentávamo": "salpimentar",
    "salpimentávamos": "salpimentar",
    "salpimentávei": "salpimentar",
    "salpimentáveis": "salpimentar",
    "salpingectomias": "salpingectomia",
    "salpinges": "salpinge",
    "salpingites": "salpingite",
    "salpingocieses": "salpingociese",
    "salpique": "salpicar",
    "salpiquei": "salpicar",
    "salpiqueis": "salpicar",
    "salpiquem": "salpicar",
    "salpiquemo": "salpicar",
    "salpiquemos": "salpicar",
    "salpiques": "salpicar",
    "salpores": "salpor",
    "salpresa": "salpreso",
    "salpresada": "salpresar",
    "salpresadas": "salpresar",
    "salpresado": "salpresar",
    "salpresados": "salpresar",
    "salpresai": "salpresar",
    "salpresais": "salpresar",
    "salpresam": "salpresar",
    "salpresamo": "salpresar",
    "salpresamos": "salpresar",
    "salpresando": "salpresar",
    "salpresara": "salpresar",
    "salpresaram": "salpresar",
    "salpresaras": "salpresar",
    "salpresarde": "salpresar",
    "salpresardes": "salpresar",
    "salpresare": "salpresar",
    "salpresarei": "salpresar",
    "salpresareis": "salpresar",
    "salpresarem": "salpresar",
    "salpresaremos": "salpresar",
    "salpresares": "salpresar",
    "salpresaria": "salpresar",
    "salpresariam": "salpresar",
    "salpresarias": "salpresar",
    "salpresarmo": "salpresar",
    "salpresarmos": "salpresar",
    "salpresará": "salpresar",
    "salpresarás": "salpresar",
    "salpresarão": "salpresar",
    "salpresaríamos": "salpresar",
    "salpresaríeis": "salpresar",
    "salpresas": "salpreso",
    "salpresasse": "salpresar",
    "salpresassem": "salpresar",
    "salpresasses": "salpresar",
    "salpresaste": "salpresar",
    "salpresastes": "salpresar",
    "salpresava": "salpresar",
    "salpresavam": "salpresar",
    "salpresavas": "salpresar",
    "salprese": "salpresar",
    "salpresei": "salpresar",
    "salpreseis": "salpresar",
    "salpresem": "salpresar",
    "salpresemo": "salpresar",
    "salpresemos": "salpresar",
    "salpreses": "salpresar",
    "salpreso": "salpresar",
    "salpresos": "salpreso",
    "salpresou": "salpresar",
    "salpresá": "salpresar",
    "salpresámo": "salpresar",
    "salpresámos": "salpresar",
    "salpresáramo": "salpresar",
    "salpresáramos": "salpresar",
    "salpresárei": "salpresar",
    "salpresáreis": "salpresar",
    "salpresásseis": "salpresar",
    "salpresássemos": "salpresar",
    "salpresávamo": "salpresar",
    "salpresávamos": "salpresar",
    "salpresávei": "salpresar",
    "salpresáveis": "salpresar",
    "salpícolas": "salpícola",
    "salpídeos": "salpídeo",
    "salsa": "salso",
    "salsadas": "salsada",
    "salsaparrilhas": "salsaparrilha",
    "salsas": "salso",
    "salseiradas": "salseirada",
    "salseiras": "salseira",
    "salseiros": "salseiro",
    "salsicharias": "salsicharia",
    "salsichas": "salsicha",
    "salsicheira": "salsicheiro",
    "salsicheiras": "salsicheiro",
    "salsicheiros": "salsicheiro",
    "salsichões": "salsichão",
    "salsifrés": "salsifré",
    "salsos": "salso",
    "salsugens": "salsugem",
    "salsuginosa": "salsuginoso",
    "salsuginosas": "salsuginoso",
    "salsuginosos": "salsuginoso",
    "salta": "saltar",
    "saltada": "saltar",
    "saltadas": "saltar",
    "saltado": "saltar",
    "saltadoiros": "saltadoiro",
    "saltadora": "saltador",
    "saltadoras": "saltador",
    "saltadorazinha": "saltador",
    "saltadorazinhas": "saltador",
    "saltadorazita": "saltador",
    "saltadorazitas": "saltador",
    "saltadores": "saltador",
    "saltadorzinho": "saltador",
    "saltadorzinhos": "saltador",
    "saltadorzito": "saltador",
    "saltadorzitos": "saltador",
    "saltados": "saltar",
    "saltadouros": "saltadouro",
    "saltai": "saltar",
    "saltais": "saltar",
    "saltam": "saltar",
    "saltamo": "saltar",
    "saltamos": "saltar",
    "saltando": "saltar",
    "saltantes": "saltante",
    "saltara": "saltar",
    "saltaram": "saltar",
    "saltaras": "saltar",
    "saltarde": "saltar",
    "saltardes": "saltar",
    "saltare": "saltar",
    "saltarei": "saltar",
    "saltareis": "saltar",
    "saltarela": "saltarelo",
    "saltarelas": "saltarelo",
    "saltarelos": "saltarelo",
    "saltarem": "saltar",
    "saltaremos": "saltar",
    "saltares": "saltar",
    "saltaria": "saltar",
    "saltariam": "saltar",
    "saltarias": "saltar",
    "saltarica": "saltaricar",
    "saltaricada": "saltaricar",
    "saltaricadas": "saltaricar",
    "saltaricado": "saltaricar",
    "saltaricados": "saltaricar",
    "saltaricais": "saltaricar",
    "saltaricam": "saltaricar",
    "saltaricamo": "saltaricar",
    "saltaricamos": "saltaricar",
    "saltaricando": "saltaricar",
    "saltaricara": "saltaricar",
    "saltaricaram": "saltaricar",
    "saltaricaras": "saltaricar",
    "saltaricardes": "saltaricar",
    "saltaricarei": "saltaricar",
    "saltaricareis": "saltaricar",
    "saltaricarem": "saltaricar",
    "saltaricaremos": "saltaricar",
    "saltaricares": "saltaricar",
    "saltaricaria": "saltaricar",
    "saltaricariam": "saltaricar",
    "saltaricarias": "saltaricar",
    "saltaricarmo": "saltaricar",
    "saltaricarmos": "saltaricar",
    "saltaricará": "saltaricar",
    "saltaricarás": "saltaricar",
    "saltaricarão": "saltaricar",
    "saltaricaríamos": "saltaricar",
    "saltaricaríeis": "saltaricar",
    "saltaricas": "saltaricar",
    "saltaricasse": "saltaricar",
    "saltaricassem": "saltaricar",
    "saltaricasses": "saltaricar",
    "saltaricaste": "saltaricar",
    "saltaricastes": "saltaricar",
    "saltaricava": "saltaricar",
    "saltaricavam": "saltaricar",
    "saltaricavas": "saltaricar",
    "saltarico": "saltaricar",
    "saltaricou": "saltaricar",
    "saltaricámo": "saltaricar",
    "saltaricámos": "saltaricar",
    "saltaricáramo": "saltaricar",
    "saltaricáramos": "saltaricar",
    "saltaricáreis": "saltaricar",
    "saltaricásseis": "saltaricar",
    "saltaricássemos": "saltaricar",
    "saltaricávamo": "saltaricar",
    "saltaricávamos": "saltaricar",
    "saltaricáveis": "saltaricar",
    "saltarilha": "saltarilho",
    "saltarilhada": "saltarilhar",
    "saltarilhadas": "saltarilhar",
    "saltarilhado": "saltarilhar",
    "saltarilhados": "saltarilhar",
    "saltarilhai": "saltarilhar",
    "saltarilhais": "saltarilhar",
    "saltarilham": "saltarilhar",
    "saltarilhamo": "saltarilhar",
    "saltarilhamos": "saltarilhar",
    "saltarilhando": "saltarilhar",
    "saltarilhara": "saltarilhar",
    "saltarilharam": "saltarilhar",
    "saltarilharas": "saltarilhar",
    "saltarilhardes": "saltarilhar",
    "saltarilharei": "saltarilhar",
    "saltarilhareis": "saltarilhar",
    "saltarilharem": "saltarilhar",
    "saltarilharemos": "saltarilhar",
    "saltarilhares": "saltarilhar",
    "saltarilharia": "saltarilhar",
    "saltarilhariam": "saltarilhar",
    "saltarilharias": "saltarilhar",
    "saltarilharmo": "saltarilhar",
    "saltarilharmos": "saltarilhar",
    "saltarilhará": "saltarilhar",
    "saltarilharás": "saltarilhar",
    "saltarilharão": "saltarilhar",
    "saltarilharíamos": "saltarilhar",
    "saltarilharíeis": "saltarilhar",
    "saltarilhas": "saltarilho",
    "saltarilhasse": "saltarilhar",
    "saltarilhassem": "saltarilhar",
    "saltarilhasses": "saltarilhar",
    "saltarilhaste": "saltarilhar",
    "saltarilhastes": "saltarilhar",
    "saltarilhava": "saltarilhar",
    "saltarilhavam": "saltarilhar",
    "saltarilhavas": "saltarilhar",
    "saltarilhe": "saltarilhar",
    "saltarilhei": "saltarilhar",
    "saltarilheis": "saltarilhar",
    "saltarilhem": "saltarilhar",
    "saltarilhemo": "saltarilhar",
    "saltarilhemos": "saltarilhar",
    "saltarilhes": "saltarilhar",
    "saltarilho": "saltarilhar",
    "saltarilhos": "saltarilho",
    "saltarilhou": "saltarilhar",
    "saltarilhámo": "saltarilhar",
    "saltarilhámos": "saltarilhar",
    "saltarilháramo": "saltarilhar",
    "saltarilháramos": "saltarilhar",
    "saltarilháreis": "saltarilhar",
    "saltarilhásseis": "saltarilhar",
    "saltarilhássemos": "saltarilhar",
    "saltarilhávamo": "saltarilhar",
    "saltarilhávamos": "saltarilhar",
    "saltarilháveis": "saltarilhar",
    "saltarinha": "saltarinhar",
    "saltarinhada": "saltarinhar",
    "saltarinhadas": "saltarinhar",
    "saltarinhado": "saltarinhar",
    "saltarinhados": "saltarinhar",
    "saltarinhai": "saltarinhar",
    "saltarinhais": "saltarinhar",
    "saltarinham": "saltarinhar",
    "saltarinhamo": "saltarinhar",
    "saltarinhamos": "saltarinhar",
    "saltarinhando": "saltarinhar",
    "saltarinhara": "saltarinhar",
    "saltarinharam": "saltarinhar",
    "saltarinharas": "saltarinhar",
    "saltarinhardes": "saltarinhar",
    "saltarinharei": "saltarinhar",
    "saltarinhareis": "saltarinhar",
    "saltarinharem": "saltarinhar",
    "saltarinharemos": "saltarinhar",
    "saltarinhares": "saltarinhar",
    "saltarinharia": "saltarinhar",
    "saltarinhariam": "saltarinhar",
    "saltarinharias": "saltarinhar",
    "saltarinharmo": "saltarinhar",
    "saltarinharmos": "saltarinhar",
    "saltarinhará": "saltarinhar",
    "saltarinharás": "saltarinhar",
    "saltarinharão": "saltarinhar",
    "saltarinharíamos": "saltarinhar",
    "saltarinharíeis": "saltarinhar",
    "saltarinhas": "saltarinhar",
    "saltarinhasse": "saltarinhar",
    "saltarinhassem": "saltarinhar",
    "saltarinhasses": "saltarinhar",
    "saltarinhaste": "saltarinhar",
    "saltarinhastes": "saltarinhar",
    "saltarinhava": "saltarinhar",
    "saltarinhavam": "saltarinhar",
    "saltarinhavas": "saltarinhar",
    "saltarinhe": "saltarinhar",
    "saltarinhei": "saltarinhar",
    "saltarinheis": "saltarinhar",
    "saltarinhem": "saltarinhar",
    "saltarinhemo": "saltarinhar",
    "saltarinhemos": "saltarinhar",
    "saltarinhes": "saltarinhar",
    "saltarinho": "saltarinhar",
    "saltarinhou": "saltarinhar",
    "saltarinhámo": "saltarinhar",
    "saltarinhámos": "saltarinhar",
    "saltarinháramo": "saltarinhar",
    "saltarinháramos": "saltarinhar",
    "saltarinháreis": "saltarinhar",
    "saltarinhásseis": "saltarinhar",
    "saltarinhássemos": "saltarinhar",
    "saltarinhávamo": "saltarinhar",
    "saltarinhávamos": "saltarinhar",
    "saltarinháveis": "saltarinhar",
    "saltarique": "saltaricar",
    "saltariquei": "saltaricar",
    "saltariqueis": "saltaricar",
    "saltariquem": "saltaricar",
    "saltariquemos": "saltaricar",
    "saltariques": "saltaricar",
    "saltarmo": "saltar",
    "saltarmos": "saltar",
    "saltará": "saltar",
    "saltarás": "saltar",
    "saltarão": "saltar",
    "saltaríamos": "saltar",
    "saltaríeis": "saltar",
    "saltas": "saltar",
    "saltasse": "saltar",
    "saltassem": "saltar",
    "saltasses": "saltar",
    "saltaste": "saltar",
    "saltastes": "saltar",
    "saltatrice": "saltador",
    "saltatrices": "saltador",
    "saltatricezinha": "saltador",
    "saltatricezinhas": "saltador",
    "saltatricezita": "saltador",
    "saltatricezitas": "saltador",
    "saltatriz": "saltador",
    "saltatrizes": "saltador",
    "saltatrizinha": "saltador",
    "saltatrizinhas": "saltador",
    "saltatrizita": "saltador",
    "saltatrizitas": "saltador",
    "saltava": "saltar",
    "saltavam": "saltar",
    "saltavas": "saltar",
    "salte": "saltar",
    "salteada": "saltear",
    "salteadas": "saltear",
    "salteado": "saltear",
    "salteadora": "salteador",
    "salteadoras": "salteador",
    "salteadores": "salteador",
    "salteados": "saltear",
    "salteadíssima": "salteado",
    "salteadíssimas": "salteado",
    "salteadíssimo": "salteado",
    "salteadíssimos": "salteado",
    "salteai": "saltear",
    "salteais": "saltear",
    "salteamentos": "salteamento",
    "salteamo": "saltear",
    "salteamos": "saltear",
    "salteando": "saltear",
    "salteara": "saltear",
    "saltearam": "saltear",
    "saltearas": "saltear",
    "saltearde": "saltear",
    "salteardes": "saltear",
    "salteare": "saltear",
    "saltearei": "saltear",
    "salteareis": "saltear",
    "saltearem": "saltear",
    "saltearemos": "saltear",
    "salteares": "saltear",
    "saltearia": "saltear",
    "salteariam": "saltear",
    "saltearias": "saltear",
    "saltearmo": "saltear",
    "saltearmos": "saltear",
    "salteará": "saltear",
    "saltearás": "saltear",
    "saltearão": "saltear",
    "saltearíamos": "saltear",
    "saltearíeis": "saltear",
    "salteasse": "saltear",
    "salteassem": "saltear",
    "salteasses": "saltear",
    "salteaste": "saltear",
    "salteastes": "saltear",
    "salteava": "saltear",
    "salteavam": "saltear",
    "salteavas": "saltear",
    "salteei": "saltear",
    "salteeis": "saltear",
    "salteemo": "saltear",
    "salteemos": "saltear",
    "saltei": "saltar",
    "salteia": "saltear",
    "salteiam": "saltear",
    "salteias": "saltear",
    "salteie": "saltear",
    "salteiem": "saltear",
    "salteies": "saltear",
    "salteio": "saltear",
    "salteios": "salteio",
    "salteira": "salteiro",
    "salteiras": "salteiro",
    "salteiros": "salteiro",
    "salteis": "saltar",
    "saltem": "saltar",
    "saltemo": "saltar",
    "saltemos": "saltar",
    "salteou": "saltear",
    "salteres": "salter",
    "salteristas": "salterista",
    "saltes": "saltar",
    "salteá": "saltear",
    "salteámo": "saltear",
    "salteámos": "saltear",
    "salteáramo": "saltear",
    "salteáramos": "saltear",
    "salteárei": "saltear",
    "salteáreis": "saltear",
    "salteásseis": "saltear",
    "salteássemos": "saltear",
    "salteávamo": "saltear",
    "salteávamos": "saltear",
    "salteávei": "saltear",
    "salteáveis": "saltear",
    "saltimbanca": "saltimbanco",
    "saltimbancas": "saltimbanco",
    "saltimbancos": "saltimbanco",
    "saltimbarcas": "saltimbarca",
    "saltinho": "salto",
    "saltinhos": "salto",
    "saltinvões": "saltinvão",
    "saltita": "saltitar",
    "saltitada": "saltitar",
    "saltitadas": "saltitar",
    "saltitado": "saltitar",
    "saltitados": "saltitar",
    "saltitai": "saltitar",
    "saltitais": "saltitar",
    "saltitam": "saltitar",
    "saltitamo": "saltitar",
    "saltitamos": "saltitar",
    "saltitando": "saltitar",
    "saltitantes": "saltitante",
    "saltitara": "saltitar",
    "saltitaram": "saltitar",
    "saltitaras": "saltitar",
    "saltitardes": "saltitar",
    "saltitarei": "saltitar",
    "saltitareis": "saltitar",
    "saltitarem": "saltitar",
    "saltitaremos": "saltitar",
    "saltitares": "saltitar",
    "saltitaria": "saltitar",
    "saltitariam": "saltitar",
    "saltitarias": "saltitar",
    "saltitarmo": "saltitar",
    "saltitarmos": "saltitar",
    "saltitará": "saltitar",
    "saltitarás": "saltitar",
    "saltitarão": "saltitar",
    "saltitaríamos": "saltitar",
    "saltitaríeis": "saltitar",
    "saltitas": "saltitar",
    "saltitasse": "saltitar",
    "saltitassem": "saltitar",
    "saltitasses": "saltitar",
    "saltitaste": "saltitar",
    "saltitastes": "saltitar",
    "saltitava": "saltitar",
    "saltitavam": "saltitar",
    "saltitavas": "saltitar",
    "saltite": "saltitar",
    "saltitei": "saltitar",
    "saltiteis": "saltitar",
    "saltitem": "saltitar",
    "saltitemo": "saltitar",
    "saltitemos": "saltitar",
    "saltites": "saltitar",
    "saltito": "salto",
    "saltitos": "salto",
    "saltitou": "saltitar",
    "saltitámo": "saltitar",
    "saltitámos": "saltitar",
    "saltitáramo": "saltitar",
    "saltitáramos": "saltitar",
    "saltitáreis": "saltitar",
    "saltitásseis": "saltitar",
    "saltitássemos": "saltitar",
    "saltitávamo": "saltitar",
    "saltitávamos": "saltitar",
    "saltitáveis": "saltitar",
    "salto": "saltar",
    "saltona": "saltão",
    "saltonas": "saltão",
    "saltos": "salto",
    "saltou": "saltar",
    "saltá": "saltar",
    "saltámo": "saltar",
    "saltámos": "saltar",
    "saltáramo": "saltar",
    "saltáramos": "saltar",
    "saltárei": "saltar",
    "saltáreis": "saltar",
    "saltásseis": "saltar",
    "saltássemos": "saltar",
    "saltávamo": "saltar",
    "saltávamos": "saltar",
    "saltávei": "saltar",
    "saltáveis": "saltável",
    "saltérios": "saltério",
    "saltígrada": "saltígrado",
    "saltígradas": "saltígrado",
    "saltígrados": "saltígrado",
    "saltões": "saltão",
    "salubradora": "salubrador",
    "salubradoras": "salubrador",
    "salubradores": "salubrador",
    "salubres": "salubre",
    "salubridades": "salubridade",
    "salubrifica": "salubrificar",
    "salubrificada": "salubrificar",
    "salubrificadas": "salubrificar",
    "salubrificado": "salubrificar",
    "salubrificados": "salubrificar",
    "salubrificai": "salubrificar",
    "salubrificais": "salubrificar",
    "salubrificam": "salubrificar",
    "salubrificamo": "salubrificar",
    "salubrificamos": "salubrificar",
    "salubrificando": "salubrificar",
    "salubrificara": "salubrificar",
    "salubrificaram": "salubrificar",
    "salubrificaras": "salubrificar",
    "salubrificarde": "salubrificar",
    "salubrificardes": "salubrificar",
    "salubrificare": "salubrificar",
    "salubrificarei": "salubrificar",
    "salubrificareis": "salubrificar",
    "salubrificarem": "salubrificar",
    "salubrificaremos": "salubrificar",
    "salubrificares": "salubrificar",
    "salubrificaria": "salubrificar",
    "salubrificariam": "salubrificar",
    "salubrificarias": "salubrificar",
    "salubrificarmo": "salubrificar",
    "salubrificarmos": "salubrificar",
    "salubrificará": "salubrificar",
    "salubrificarás": "salubrificar",
    "salubrificarão": "salubrificar",
    "salubrificaríamos": "salubrificar",
    "salubrificaríeis": "salubrificar",
    "salubrificas": "salubrificar",
    "salubrificasse": "salubrificar",
    "salubrificassem": "salubrificar",
    "salubrificasses": "salubrificar",
    "salubrificaste": "salubrificar",
    "salubrificastes": "salubrificar",
    "salubrificava": "salubrificar",
    "salubrificavam": "salubrificar",
    "salubrificavas": "salubrificar",
    "salubrificações": "salubrificação",
    "salubrifico": "salubrificar",
    "salubrificou": "salubrificar",
    "salubrificá": "salubrificar",
    "salubrificámo": "salubrificar",
    "salubrificámos": "salubrificar",
    "salubrificáramo": "salubrificar",
    "salubrificáramos": "salubrificar",
    "salubrificárei": "salubrificar",
    "salubrificáreis": "salubrificar",
    "salubrificásseis": "salubrificar",
    "salubrificássemos": "salubrificar",
    "salubrificávamo": "salubrificar",
    "salubrificávamos": "salubrificar",
    "salubrificávei": "salubrificar",
    "salubrificáveis": "salubrificar",
    "salubrifique": "salubrificar",
    "salubrifiquei": "salubrificar",
    "salubrifiqueis": "salubrificar",
    "salubrifiquem": "salubrificar",
    "salubrifiquemo": "salubrificar",
    "salubrifiquemos": "salubrificar",
    "salubrifiques": "salubrificar",
    "salubriza": "salubrizar",
    "salubrizada": "salubrizar",
    "salubrizadas": "salubrizar",
    "salubrizado": "salubrizar",
    "salubrizados": "salubrizar",
    "salubrizai": "salubrizar",
    "salubrizais": "salubrizar",
    "salubrizam": "salubrizar",
    "salubrizamo": "salubrizar",
    "salubrizamos": "salubrizar",
    "salubrizando": "salubrizar",
    "salubrizara": "salubrizar",
    "salubrizaram": "salubrizar",
    "salubrizaras": "salubrizar",
    "salubrizarde": "salubrizar",
    "salubrizardes": "salubrizar",
    "salubrizare": "salubrizar",
    "salubrizarei": "salubrizar",
    "salubrizareis": "salubrizar",
    "salubrizarem": "salubrizar",
    "salubrizaremos": "salubrizar",
    "salubrizares": "salubrizar",
    "salubrizaria": "salubrizar",
    "salubrizariam": "salubrizar",
    "salubrizarias": "salubrizar",
    "salubrizarmo": "salubrizar",
    "salubrizarmos": "salubrizar",
    "salubrizará": "salubrizar",
    "salubrizarás": "salubrizar",
    "salubrizarão": "salubrizar",
    "salubrizaríamos": "salubrizar",
    "salubrizaríeis": "salubrizar",
    "salubrizas": "salubrizar",
    "salubrizasse": "salubrizar",
    "salubrizassem": "salubrizar",
    "salubrizasses": "salubrizar",
    "salubrizaste": "salubrizar",
    "salubrizastes": "salubrizar",
    "salubrizava": "salubrizar",
    "salubrizavam": "salubrizar",
    "salubrizavas": "salubrizar",
    "salubrize": "salubrizar",
    "salubrizei": "salubrizar",
    "salubrizeis": "salubrizar",
    "salubrizem": "salubrizar",
    "salubrizemo": "salubrizar",
    "salubrizemos": "salubrizar",
    "salubrizes": "salubrizar",
    "salubrizo": "salubrizar",
    "salubrizou": "salubrizar",
    "salubrizá": "salubrizar",
    "salubrizámo": "salubrizar",
    "salubrizámos": "salubrizar",
    "salubrizáramo": "salubrizar",
    "salubrizáramos": "salubrizar",
    "salubrizárei": "salubrizar",
    "salubrizáreis": "salubrizar",
    "salubrizásseis": "salubrizar",
    "salubrizássemos": "salubrizar",
    "salubrizávamo": "salubrizar",
    "salubrizávamos": "salubrizar",
    "salubrizávei": "salubrizar",
    "salubrizáveis": "salubrizar",
    "saluda": "saludar",
    "saludada": "saludar",
    "saludadas": "saludar",
    "saludado": "saludar",
    "saludados": "saludar",
    "saludai": "saludar",
    "saludais": "saludar",
    "saludam": "saludar",
    "saludamo": "saludar",
    "saludamos": "saludar",
    "saludando": "saludar",
    "saludara": "saludar",
    "saludaram": "saludar",
    "saludaras": "saludar",
    "saludarde": "saludar",
    "saludardes": "saludar",
    "saludare": "saludar",
    "saludarei": "saludar",
    "saludareis": "saludar",
    "saludarem": "saludar",
    "saludaremos": "saludar",
    "saludares": "saludar",
    "saludaria": "saludar",
    "saludariam": "saludar",
    "saludarias": "saludar",
    "saludarmo": "saludar",
    "saludarmos": "saludar",
    "saludará": "saludar",
    "saludarás": "saludar",
    "saludarão": "saludar",
    "saludaríamos": "saludar",
    "saludaríeis": "saludar",
    "saludas": "saludar",
    "saludasse": "saludar",
    "saludassem": "saludar",
    "saludasses": "saludar",
    "saludaste": "saludar",
    "saludastes": "saludar",
    "saludava": "saludar",
    "saludavam": "saludar",
    "saludavas": "saludar",
    "salude": "saludar",
    "saludei": "saludar",
    "saludeis": "saludar",
    "saludem": "saludar",
    "saludemo": "saludar",
    "saludemos": "saludar",
    "saludes": "saludar",
    "saludo": "saludar",
    "saludou": "saludar",
    "saludá": "saludar",
    "saludámo": "saludar",
    "saludámos": "saludar",
    "saludáramo": "saludar",
    "saludáramos": "saludar",
    "saludárei": "saludar",
    "saludáreis": "saludar",
    "saludásseis": "saludar",
    "saludássemos": "saludar",
    "saludávamo": "saludar",
    "saludávamos": "saludar",
    "saludávei": "saludar",
    "saludáveis": "saludar",
    "salugas": "saluga",
    "salutares": "salutar",
    "salutífera": "salutífero",
    "salutíferas": "salutífero",
    "salutíferos": "salutífero",
    "saluços": "saluço",
    "salva": "salvo",
    "salvada": "salvar",
    "salvadas": "salvar",
    "salvado": "salvar",
    "salvadora": "salvador",
    "salvadoras": "salvador",
    "salvadorenha": "salvadorenho",
    "salvadorenhas": "salvadorenho",
    "salvadorenhos": "salvadorenho",
    "salvadores": "salvador",
    "salvados": "salvar",
    "salvagens": "salvagem",
    "salvaguarda": "salvaguardar",
    "salvaguardada": "salvaguardar",
    "salvaguardadas": "salvaguardar",
    "salvaguardado": "salvaguardar",
    "salvaguardados": "salvaguardar",
    "salvaguardai": "salvaguardar",
    "salvaguardais": "salvaguardar",
    "salvaguardam": "salvaguardar",
    "salvaguardamo": "salvaguardar",
    "salvaguardamos": "salvaguardar",
    "salvaguardando": "salvaguardar",
    "salvaguardara": "salvaguardar",
    "salvaguardaram": "salvaguardar",
    "salvaguardaras": "salvaguardar",
    "salvaguardarde": "salvaguardar",
    "salvaguardardes": "salvaguardar",
    "salvaguardare": "salvaguardar",
    "salvaguardarei": "salvaguardar",
    "salvaguardareis": "salvaguardar",
    "salvaguardarem": "salvaguardar",
    "salvaguardaremos": "salvaguardar",
    "salvaguardares": "salvaguardar",
    "salvaguardaria": "salvaguardar",
    "salvaguardariam": "salvaguardar",
    "salvaguardarias": "salvaguardar",
    "salvaguardarmo": "salvaguardar",
    "salvaguardarmos": "salvaguardar",
    "salvaguardará": "salvaguardar",
    "salvaguardarás": "salvaguardar",
    "salvaguardarão": "salvaguardar",
    "salvaguardaríamos": "salvaguardar",
    "salvaguardaríeis": "salvaguardar",
    "salvaguardas": "salvaguardar",
    "salvaguardasse": "salvaguardar",
    "salvaguardassem": "salvaguardar",
    "salvaguardasses": "salvaguardar",
    "salvaguardaste": "salvaguardar",
    "salvaguardastes": "salvaguardar",
    "salvaguardava": "salvaguardar",
    "salvaguardavam": "salvaguardar",
    "salvaguardavas": "salvaguardar",
    "salvaguarde": "salvaguardar",
    "salvaguardei": "salvaguardar",
    "salvaguardeis": "salvaguardar",
    "salvaguardem": "salvaguardar",
    "salvaguardemo": "salvaguardar",
    "salvaguardemos": "salvaguardar",
    "salvaguardes": "salvaguardar",
    "salvaguardo": "salvaguardar",
    "salvaguardou": "salvaguardar",
    "salvaguardá": "salvaguardar",
    "salvaguardámo": "salvaguardar",
    "salvaguardámos": "salvaguardar",
    "salvaguardáramo": "salvaguardar",
    "salvaguardáramos": "salvaguardar",
    "salvaguardárei": "salvaguardar",
    "salvaguardáreis": "salvaguardar",
    "salvaguardásseis": "salvaguardar",
    "salvaguardássemos": "salvaguardar",
    "salvaguardávamo": "salvaguardar",
    "salvaguardávamos": "salvaguardar",
    "salvaguardávei": "salvaguardar",
    "salvaguardáveis": "salvaguardar",
    "salvai": "salvar",
    "salvais": "salvar",
    "salvam": "salvar",
    "salvamentos": "salvamento",
    "salvamo": "salvar",
    "salvamos": "salvar",
    "salvando": "salvar",
    "salvantes": "salvante",
    "salvara": "salvar",
    "salvaram": "salvar",
    "salvaras": "salvar",
    "salvarde": "salvar",
    "salvardes": "salvar",
    "salvare": "salvar",
    "salvarei": "salvar",
    "salvareis": "salvar",
    "salvarem": "salvar",
    "salvaremos": "salvar",
    "salvares": "salvar",
    "salvaria": "salvar",
    "salvariam": "salvar",
    "salvarias": "salvar",
    "salvarmo": "salvar",
    "salvarmos": "salvar",
    "salvará": "salvar",
    "salvarás": "salvar",
    "salvarão": "salvar",
    "salvaríamos": "salvar",
    "salvaríeis": "salvar",
    "salvas": "salvo",
    "salvasse": "salvar",
    "salvassem": "salvar",
    "salvasses": "salvar",
    "salvaste": "salvar",
    "salvastes": "salvar",
    "salvatela": "salvatelo",
    "salvatelas": "salvatelo",
    "salvatelos": "salvatelo",
    "salvaterriana": "salvaterriano",
    "salvaterrianas": "salvaterriano",
    "salvaterrianos": "salvaterriano",
    "salvatoriana": "salvatoriano",
    "salvatorianas": "salvatoriano",
    "salvatorianos": "salvatoriano",
    "salvatérios": "salvatério",
    "salvava": "salvar",
    "salvavam": "salvar",
    "salvavas": "salvar",
    "salvações": "salvação",
    "salve": "salvar",
    "salvei": "salvar",
    "salveis": "salvar",
    "salvem": "salvar",
    "salvemo": "salvar",
    "salvemos": "salvar",
    "salves": "salvar",
    "salvetas": "salveta",
    "salviniáceas": "salviniácea",
    "salvo": "salvar",
    "salvos": "salvo",
    "salvou": "salvar",
    "salvá": "salvar",
    "salvádegos": "salvádego",
    "salvámo": "salvar",
    "salvámos": "salvar",
    "salváramo": "salvar",
    "salváramos": "salvar",
    "salvárei": "salvar",
    "salváreis": "salvar",
    "salvásseis": "salvar",
    "salvássemos": "salvar",
    "salvávamo": "salvar",
    "salvávamos": "salvar",
    "salvávei": "salvar",
    "salváveis": "salvável",
    "salvínias": "salvínia",
    "salácias": "salácia",
    "salários": "salário",
    "salés": "salé",
    "salésias": "salésia",
    "salícolas": "salícola",
    "salífera": "salífero",
    "salíferas": "salífero",
    "salíferos": "salífero",
    "salóis": "salol",
    "salões": "salão",
    "samagaios": "samagaio",
    "samaritana": "samaritano",
    "samaritanas": "samaritano",
    "samaritanos": "samaritano",
    "samaritas": "samarita",
    "samarras": "samarra",
    "samarreira": "samarreiro",
    "samarreiras": "samarreiro",
    "samarreiros": "samarreiro",
    "samarsquites": "samarsquite",
    "samarídeos": "samarídeo",
    "samas": "sama",
    "samatras": "samatra",
    "samba": "sambar",
    "sambacuins": "sambacuim",
    "sambada": "sambar",
    "sambadas": "sambar",
    "sambado": "sambar",
    "sambadora": "sambador",
    "sambadoras": "sambador",
    "sambadores": "sambador",
    "sambados": "sambar",
    "sambai": "sambar",
    "sambais": "sambar",
    "sambam": "sambar",
    "sambamo": "sambar",
    "sambamos": "sambar",
    "sambando": "sambar",
    "sambaquis": "sambaqui",
    "sambara": "sambar",
    "sambaram": "sambar",
    "sambaras": "sambar",
    "sambarca": "sambarcar",
    "sambarcada": "sambarcar",
    "sambarcadas": "sambarcar",
    "sambarcado": "sambarcar",
    "sambarcados": "sambarcar",
    "sambarcai": "sambarcar",
    "sambarcais": "sambarcar",
    "sambarcam": "sambarcar",
    "sambarcamo": "sambarcar",
    "sambarcamos": "sambarcar",
    "sambarcando": "sambarcar",
    "sambarcara": "sambarcar",
    "sambarcaram": "sambarcar",
    "sambarcaras": "sambarcar",
    "sambarcarde": "sambarcar",
    "sambarcardes": "sambarcar",
    "sambarcare": "sambarcar",
    "sambarcarei": "sambarcar",
    "sambarcareis": "sambarcar",
    "sambarcarem": "sambarcar",
    "sambarcaremos": "sambarcar",
    "sambarcares": "sambarcar",
    "sambarcaria": "sambarcar",
    "sambarcariam": "sambarcar",
    "sambarcarias": "sambarcar",
    "sambarcarmo": "sambarcar",
    "sambarcarmos": "sambarcar",
    "sambarcará": "sambarcar",
    "sambarcarás": "sambarcar",
    "sambarcarão": "sambarcar",
    "sambarcaríamos": "sambarcar",
    "sambarcaríeis": "sambarcar",
    "sambarcas": "sambarcar",
    "sambarcasse": "sambarcar",
    "sambarcassem": "sambarcar",
    "sambarcasses": "sambarcar",
    "sambarcaste": "sambarcar",
    "sambarcastes": "sambarcar",
    "sambarcava": "sambarcar",
    "sambarcavam": "sambarcar",
    "sambarcavas": "sambarcar",
    "sambarco": "sambarcar",
    "sambarcou": "sambarcar",
    "sambarcá": "sambarcar",
    "sambarcámo": "sambarcar",
    "sambarcámos": "sambarcar",
    "sambarcáramo": "sambarcar",
    "sambarcáramos": "sambarcar",
    "sambarcárei": "sambarcar",
    "sambarcáreis": "sambarcar",
    "sambarcásseis": "sambarcar",
    "sambarcássemos": "sambarcar",
    "sambarcávamo": "sambarcar",
    "sambarcávamos": "sambarcar",
    "sambarcávei": "sambarcar",
    "sambarcáveis": "sambarcar",
    "sambardes": "sambar",
    "sambarei": "sambar",
    "sambareis": "sambar",
    "sambarem": "sambar",
    "sambaremos": "sambar",
    "sambares": "sambar",
    "sambaria": "sambar",
    "sambariam": "sambar",
    "sambarias": "sambar",
    "sambarmo": "sambar",
    "sambarmos": "sambar",
    "sambarque": "sambarcar",
    "sambarquei": "sambarcar",
    "sambarqueis": "sambarcar",
    "sambarquem": "sambarcar",
    "sambarquemo": "sambarcar",
    "sambarquemos": "sambarcar",
    "sambarques": "sambarcar",
    "sambará": "sambar",
    "sambarás": "sambar",
    "sambarão": "sambar",
    "sambaríamos": "sambar",
    "sambaríeis": "sambar",
    "sambas": "sambar",
    "sambasse": "sambar",
    "sambassem": "sambar",
    "sambasses": "sambar",
    "sambaste": "sambar",
    "sambastes": "sambar",
    "sambava": "sambar",
    "sambavam": "sambar",
    "sambavas": "sambar",
    "sambe": "sambar",
    "sambei": "sambar",
    "sambeira": "sambeiro",
    "sambeiras": "sambeiro",
    "sambeiros": "sambeiro",
    "sambeis": "sambar",
    "sambem": "sambar",
    "sambemo": "sambar",
    "sambemos": "sambar",
    "sambenita": "sambenitar",
    "sambenitada": "sambenitar",
    "sambenitadas": "sambenitar",
    "sambenitado": "sambenitar",
    "sambenitados": "sambenitar",
    "sambenitai": "sambenitar",
    "sambenitais": "sambenitar",
    "sambenitam": "sambenitar",
    "sambenitamo": "sambenitar",
    "sambenitamos": "sambenitar",
    "sambenitando": "sambenitar",
    "sambenitara": "sambenitar",
    "sambenitaram": "sambenitar",
    "sambenitaras": "sambenitar",
    "sambenitarde": "sambenitar",
    "sambenitardes": "sambenitar",
    "sambenitare": "sambenitar",
    "sambenitarei": "sambenitar",
    "sambenitareis": "sambenitar",
    "sambenitarem": "sambenitar",
    "sambenitaremos": "sambenitar",
    "sambenitares": "sambenitar",
    "sambenitaria": "sambenitar",
    "sambenitariam": "sambenitar",
    "sambenitarias": "sambenitar",
    "sambenitarmo": "sambenitar",
    "sambenitarmos": "sambenitar",
    "sambenitará": "sambenitar",
    "sambenitarás": "sambenitar",
    "sambenitarão": "sambenitar",
    "sambenitaríamos": "sambenitar",
    "sambenitaríeis": "sambenitar",
    "sambenitas": "sambenitar",
    "sambenitasse": "sambenitar",
    "sambenitassem": "sambenitar",
    "sambenitasses": "sambenitar",
    "sambenitaste": "sambenitar",
    "sambenitastes": "sambenitar",
    "sambenitava": "sambenitar",
    "sambenitavam": "sambenitar",
    "sambenitavas": "sambenitar",
    "sambenite": "sambenitar",
    "sambenitei": "sambenitar",
    "sambeniteis": "sambenitar",
    "sambenitem": "sambenitar",
    "sambenitemo": "sambenitar",
    "sambenitemos": "sambenitar",
    "sambenites": "sambenitar",
    "sambenito": "sambenitar",
    "sambenitos": "sambenito",
    "sambenitou": "sambenitar",
    "sambenitá": "sambenitar",
    "sambenitámo": "sambenitar",
    "sambenitámos": "sambenitar",
    "sambenitáramo": "sambenitar",
    "sambenitáramos": "sambenitar",
    "sambenitárei": "sambenitar",
    "sambenitáreis": "sambenitar",
    "sambenitásseis": "sambenitar",
    "sambenitássemos": "sambenitar",
    "sambenitávamo": "sambenitar",
    "sambenitávamos": "sambenitar",
    "sambenitávei": "sambenitar",
    "sambenitáveis": "sambenitar",
    "sambes": "sambar",
    "sambia": "sambiar",
    "sambiada": "sambiar",
    "sambiadas": "sambiar",
    "sambiado": "sambiar",
    "sambiados": "sambiar",
    "sambiai": "sambiar",
    "sambiais": "sambiar",
    "sambiam": "sambiar",
    "sambiamo": "sambiar",
    "sambiamos": "sambiar",
    "sambiando": "sambiar",
    "sambiara": "sambiar",
    "sambiaram": "sambiar",
    "sambiaras": "sambiar",
    "sambiarde": "sambiar",
    "sambiardes": "sambiar",
    "sambiare": "sambiar",
    "sambiarei": "sambiar",
    "sambiareis": "sambiar",
    "sambiarem": "sambiar",
    "sambiaremos": "sambiar",
    "sambiares": "sambiar",
    "sambiaria": "sambiar",
    "sambiariam": "sambiar",
    "sambiarias": "sambiar",
    "sambiarmo": "sambiar",
    "sambiarmos": "sambiar",
    "sambiará": "sambiar",
    "sambiarás": "sambiar",
    "sambiarão": "sambiar",
    "sambiaríamos": "sambiar",
    "sambiaríeis": "sambiar",
    "sambias": "sambiar",
    "sambiasse": "sambiar",
    "sambiassem": "sambiar",
    "sambiasses": "sambiar",
    "sambiaste": "sambiar",
    "sambiastes": "sambiar",
    "sambiava": "sambiar",
    "sambiavam": "sambiar",
    "sambiavas": "sambiar",
    "sambie": "sambiar",
    "sambiei": "sambiar",
    "sambieis": "sambiar",
    "sambiem": "sambiar",
    "sambiemo": "sambiar",
    "sambiemos": "sambiar",
    "sambies": "sambiar",
    "sambio": "sambiar",
    "sambiou": "sambiar",
    "sambistas": "sambista",
    "sambiá": "sambiar",
    "sambiámo": "sambiar",
    "sambiámos": "sambiar",
    "sambiáramo": "sambiar",
    "sambiáramos": "sambiar",
    "sambiárei": "sambiar",
    "sambiáreis": "sambiar",
    "sambiásseis": "sambiar",
    "sambiássemos": "sambiar",
    "sambiávamo": "sambiar",
    "sambiávamos": "sambiar",
    "sambiávei": "sambiar",
    "sambiáveis": "sambiar",
    "sambla": "samblar",
    "samblada": "samblar",
    "sambladas": "samblar",
    "samblado": "samblar",
    "samblados": "samblar",
    "samblai": "samblar",
    "samblais": "samblar",
    "samblam": "samblar",
    "samblamo": "samblar",
    "samblamos": "samblar",
    "samblando": "samblar",
    "samblara": "samblar",
    "samblaram": "samblar",
    "samblaras": "samblar",
    "samblarde": "samblar",
    "samblardes": "samblar",
    "samblare": "samblar",
    "samblarei": "samblar",
    "samblareis": "samblar",
    "samblarem": "samblar",
    "samblaremos": "samblar",
    "samblares": "samblar",
    "samblaria": "samblar",
    "samblariam": "samblar",
    "samblarias": "samblar",
    "samblarmo": "samblar",
    "samblarmos": "samblar",
    "samblará": "samblar",
    "samblarás": "samblar",
    "samblarão": "samblar",
    "samblaríamos": "samblar",
    "samblaríeis": "samblar",
    "samblas": "samblar",
    "samblasse": "samblar",
    "samblassem": "samblar",
    "samblasses": "samblar",
    "samblaste": "samblar",
    "samblastes": "samblar",
    "samblava": "samblar",
    "samblavam": "samblar",
    "samblavas": "samblar",
    "samble": "samblar",
    "samblei": "samblar",
    "sambleis": "samblar",
    "samblem": "samblar",
    "samblemo": "samblar",
    "samblemos": "samblar",
    "sambles": "samblar",
    "samblo": "samblar",
    "samblou": "samblar",
    "samblá": "samblar",
    "samblámo": "samblar",
    "samblámos": "samblar",
    "sambláramo": "samblar",
    "sambláramos": "samblar",
    "samblárei": "samblar",
    "sambláreis": "samblar",
    "samblásseis": "samblar",
    "samblássemos": "samblar",
    "samblávamo": "samblar",
    "samblávamos": "samblar",
    "samblávei": "samblar",
    "sambláveis": "samblar",
    "sambo": "sambar",
    "sambos": "sambo",
    "sambou": "sambar",
    "sambucas": "sambuca",
    "sambucinas": "sambucina",
    "sambucos": "sambuco",
    "sambucístrias": "sambucístria",
    "sambámo": "sambar",
    "sambámos": "sambar",
    "sambáramo": "sambar",
    "sambáramos": "sambar",
    "sambáreis": "sambar",
    "sambásseis": "sambar",
    "sambássemos": "sambar",
    "sambávamo": "sambar",
    "sambávamos": "sambar",
    "sambáveis": "sambar",
    "sambódromos": "sambódromo",
    "sambúceas": "sambúcea",
    "sambúcinas": "sambúcina",
    "samelos": "samelo",
    "samiana": "samiano",
    "samianas": "samiano",
    "samianos": "samiano",
    "samicas": "samica",
    "samiséns": "samisém",
    "samnitas": "samnita",
    "samocos": "samoco",
    "samoiedos": "samoiedo",
    "samorana": "samorano",
    "samoranas": "samorano",
    "samoranos": "samorano",
    "samorenses": "samorense",
    "samorins": "samorim",
    "samos": "samo",
    "samoucos": "samouco",
    "samovares": "samovar",
    "sampanas": "sampana",
    "sampaístas": "sampaísta",
    "samurais": "samurai",
    "samádis": "samádi",
    "samários": "samário",
    "sana": "sanar",
    "sanada": "sanar",
    "sanadas": "sanar",
    "sanado": "sanar",
    "sanadora": "sanador",
    "sanadoras": "sanador",
    "sanadores": "sanador",
    "sanados": "sanar",
    "sanai": "sanar",
    "sanais": "sanar",
    "sanalas": "sanala",
    "sanam": "sanar",
    "sanamo": "sanar",
    "sanamos": "sanar",
    "sanamundas": "sanamunda",
    "sanando": "sanar",
    "sanara": "sanar",
    "sanaram": "sanar",
    "sanaras": "sanar",
    "sanarde": "sanar",
    "sanardes": "sanar",
    "sanare": "sanar",
    "sanarei": "sanar",
    "sanareis": "sanar",
    "sanarem": "sanar",
    "sanaremos": "sanar",
    "sanares": "sanar",
    "sanaria": "sanar",
    "sanariam": "sanar",
    "sanarias": "sanar",
    "sanarmo": "sanar",
    "sanarmos": "sanar",
    "sanará": "sanar",
    "sanarás": "sanar",
    "sanarão": "sanar",
    "sanaríamos": "sanar",
    "sanaríeis": "sanar",
    "sanas": "sanar",
    "sanasse": "sanar",
    "sanassem": "sanar",
    "sanasses": "sanar",
    "sanaste": "sanar",
    "sanastes": "sanar",
    "sanativa": "sanativo",
    "sanativas": "sanativo",
    "sanativos": "sanativo",
    "sanatoriza": "sanatorizar",
    "sanatorizada": "sanatorizar",
    "sanatorizadas": "sanatorizar",
    "sanatorizado": "sanatorizar",
    "sanatorizados": "sanatorizar",
    "sanatorizai": "sanatorizar",
    "sanatorizais": "sanatorizar",
    "sanatorizam": "sanatorizar",
    "sanatorizamo": "sanatorizar",
    "sanatorizamos": "sanatorizar",
    "sanatorizando": "sanatorizar",
    "sanatorizara": "sanatorizar",
    "sanatorizaram": "sanatorizar",
    "sanatorizaras": "sanatorizar",
    "sanatorizarde": "sanatorizar",
    "sanatorizardes": "sanatorizar",
    "sanatorizare": "sanatorizar",
    "sanatorizarei": "sanatorizar",
    "sanatorizareis": "sanatorizar",
    "sanatorizarem": "sanatorizar",
    "sanatorizaremos": "sanatorizar",
    "sanatorizares": "sanatorizar",
    "sanatorizaria": "sanatorizar",
    "sanatorizariam": "sanatorizar",
    "sanatorizarias": "sanatorizar",
    "sanatorizarmo": "sanatorizar",
    "sanatorizarmos": "sanatorizar",
    "sanatorizará": "sanatorizar",
    "sanatorizarás": "sanatorizar",
    "sanatorizarão": "sanatorizar",
    "sanatorizaríamos": "sanatorizar",
    "sanatorizaríeis": "sanatorizar",
    "sanatorizas": "sanatorizar",
    "sanatorizasse": "sanatorizar",
    "sanatorizassem": "sanatorizar",
    "sanatorizasses": "sanatorizar",
    "sanatorizaste": "sanatorizar",
    "sanatorizastes": "sanatorizar",
    "sanatorizava": "sanatorizar",
    "sanatorizavam": "sanatorizar",
    "sanatorizavas": "sanatorizar",
    "sanatorize": "sanatorizar",
    "sanatorizei": "sanatorizar",
    "sanatorizeis": "sanatorizar",
    "sanatorizem": "sanatorizar",
    "sanatorizemo": "sanatorizar",
    "sanatorizemos": "sanatorizar",
    "sanatorizes": "sanatorizar",
    "sanatorizo": "sanatorizar",
    "sanatorizou": "sanatorizar",
    "sanatorizá": "sanatorizar",
    "sanatorizámo": "sanatorizar",
    "sanatorizámos": "sanatorizar",
    "sanatorizáramo": "sanatorizar",
    "sanatorizáramos": "sanatorizar",
    "sanatorizárei": "sanatorizar",
    "sanatorizáreis": "sanatorizar",
    "sanatorizásseis": "sanatorizar",
    "sanatorizássemos": "sanatorizar",
    "sanatorizávamo": "sanatorizar",
    "sanatorizávamos": "sanatorizar",
    "sanatorizávei": "sanatorizar",
    "sanatorizáveis": "sanatorizar",
    "sanatórios": "sanatório",
    "sanava": "sanar",
    "sanavam": "sanar",
    "sanavas": "sanar",
    "sanações": "sanação",
    "sancadilhas": "sancadilha",
    "sancas": "sanca",
    "sanciona": "sancionar",
    "sancionada": "sancionar",
    "sancionadas": "sancionar",
    "sancionado": "sancionar",
    "sancionadora": "sancionador",
    "sancionadoras": "sancionador",
    "sancionadores": "sancionador",
    "sancionados": "sancionar",
    "sancionai": "sancionar",
    "sancionais": "sancionar",
    "sancionam": "sancionar",
    "sancionamo": "sancionar",
    "sancionamos": "sancionar",
    "sancionando": "sancionar",
    "sancionara": "sancionar",
    "sancionaram": "sancionar",
    "sancionaras": "sancionar",
    "sancionarde": "sancionar",
    "sancionardes": "sancionar",
    "sancionare": "sancionar",
    "sancionarei": "sancionar",
    "sancionareis": "sancionar",
    "sancionarem": "sancionar",
    "sancionaremos": "sancionar",
    "sancionares": "sancionar",
    "sancionaria": "sancionar",
    "sancionariam": "sancionar",
    "sancionarias": "sancionar",
    "sancionarmo": "sancionar",
    "sancionarmos": "sancionar",
    "sancionará": "sancionar",
    "sancionarás": "sancionar",
    "sancionarão": "sancionar",
    "sancionaríamos": "sancionar",
    "sancionaríeis": "sancionar",
    "sancionas": "sancionar",
    "sancionasse": "sancionar",
    "sancionassem": "sancionar",
    "sancionasses": "sancionar",
    "sancionaste": "sancionar",
    "sancionastes": "sancionar",
    "sancionatória": "sancionatório",
    "sancionatórias": "sancionatório",
    "sancionatórios": "sancionatório",
    "sancionava": "sancionar",
    "sancionavam": "sancionar",
    "sancionavas": "sancionar",
    "sancione": "sancionar",
    "sancionei": "sancionar",
    "sancioneis": "sancionar",
    "sancionem": "sancionar",
    "sancionemo": "sancionar",
    "sancionemos": "sancionar",
    "sanciones": "sancionar",
    "sanciono": "sancionar",
    "sancionou": "sancionar",
    "sancioná": "sancionar",
    "sancionámo": "sancionar",
    "sancionámos": "sancionar",
    "sancionáramo": "sancionar",
    "sancionáramos": "sancionar",
    "sancionárei": "sancionar",
    "sancionáreis": "sancionar",
    "sancionásseis": "sancionar",
    "sancionássemos": "sancionar",
    "sancionávamo": "sancionar",
    "sancionávamos": "sancionar",
    "sancionávei": "sancionar",
    "sancionáveis": "sancionável",
    "sancos": "sanco",
    "sandalina": "sandalino",
    "sandalinas": "sandalino",
    "sandalinos": "sandalino",
    "sandarás": "sandará",
    "sandeia": "sandeu",
    "sandeias": "sandeu",
    "sandeja": "sandejar",
    "sandejada": "sandejar",
    "sandejadas": "sandejar",
    "sandejado": "sandejar",
    "sandejados": "sandejar",
    "sandejai": "sandejar",
    "sandejais": "sandejar",
    "sandejam": "sandejar",
    "sandejamo": "sandejar",
    "sandejamos": "sandejar",
    "sandejando": "sandejar",
    "sandejara": "sandejar",
    "sandejaram": "sandejar",
    "sandejaras": "sandejar",
    "sandejardes": "sandejar",
    "sandejarei": "sandejar",
    "sandejareis": "sandejar",
    "sandejarem": "sandejar",
    "sandejaremos": "sandejar",
    "sandejares": "sandejar",
    "sandejaria": "sandejar",
    "sandejariam": "sandejar",
    "sandejarias": "sandejar",
    "sandejarmo": "sandejar",
    "sandejarmos": "sandejar",
    "sandejará": "sandejar",
    "sandejarás": "sandejar",
    "sandejarão": "sandejar",
    "sandejaríamos": "sandejar",
    "sandejaríeis": "sandejar",
    "sandejas": "sandejar",
    "sandejasse": "sandejar",
    "sandejassem": "sandejar",
    "sandejasses": "sandejar",
    "sandejaste": "sandejar",
    "sandejastes": "sandejar",
    "sandejava": "sandejar",
    "sandejavam": "sandejar",
    "sandejavas": "sandejar",
    "sandeje": "sandejar",
    "sandejei": "sandejar",
    "sandejeis": "sandejar",
    "sandejem": "sandejar",
    "sandejemo": "sandejar",
    "sandejemos": "sandejar",
    "sandejes": "sandejar",
    "sandejo": "sandejar",
    "sandejou": "sandejar",
    "sandejámo": "sandejar",
    "sandejámos": "sandejar",
    "sandejáramo": "sandejar",
    "sandejáramos": "sandejar",
    "sandejáreis": "sandejar",
    "sandejásseis": "sandejar",
    "sandejássemos": "sandejar",
    "sandejávamo": "sandejar",
    "sandejávamos": "sandejar",
    "sandejáveis": "sandejar",
    "sanderlingos": "sanderlingo",
    "sandes": "sande",
    "sandeus": "sandeu",
    "sandezinha": "sande",
    "sandezinhas": "sande",
    "sandezita": "sande",
    "sandezitas": "sande",
    "sandia": "sandio",
    "sandias": "sandio",
    "sandices": "sandice",
    "sandinistas": "sandinista",
    "sandins": "sandim",
    "sandios": "sandio",
    "sandizes": "sandiz",
    "sanduicha": "sanduichar",
    "sanduichada": "sanduichar",
    "sanduichadas": "sanduichar",
    "sanduichado": "sanduichar",
    "sanduichados": "sanduichar",
    "sanduichai": "sanduichar",
    "sanduichais": "sanduichar",
    "sanduicham": "sanduichar",
    "sanduichamo": "sanduichar",
    "sanduichamos": "sanduichar",
    "sanduichando": "sanduichar",
    "sanduichara": "sanduichar",
    "sanduicharam": "sanduichar",
    "sanduicharas": "sanduichar",
    "sanduicharde": "sanduichar",
    "sanduichardes": "sanduichar",
    "sanduichare": "sanduichar",
    "sanduicharei": "sanduichar",
    "sanduichareis": "sanduichar",
    "sanduicharem": "sanduichar",
    "sanduicharemos": "sanduichar",
    "sanduichares": "sanduichar",
    "sanduicharia": "sanduichar",
    "sanduichariam": "sanduichar",
    "sanduicharias": "sanduichar",
    "sanduicharmo": "sanduichar",
    "sanduicharmos": "sanduichar",
    "sanduichará": "sanduichar",
    "sanduicharás": "sanduichar",
    "sanduicharão": "sanduichar",
    "sanduicharíamos": "sanduichar",
    "sanduicharíeis": "sanduichar",
    "sanduichas": "sanduichar",
    "sanduichasse": "sanduichar",
    "sanduichassem": "sanduichar",
    "sanduichasses": "sanduichar",
    "sanduichaste": "sanduichar",
    "sanduichastes": "sanduichar",
    "sanduichava": "sanduichar",
    "sanduichavam": "sanduichar",
    "sanduichavas": "sanduichar",
    "sanduiche": "sanduichar",
    "sanduichei": "sanduichar",
    "sanduicheiras": "sanduicheira",
    "sanduicheis": "sanduichar",
    "sanduichem": "sanduichar",
    "sanduichemo": "sanduichar",
    "sanduichemos": "sanduichar",
    "sanduiches": "sanduichar",
    "sanduicho": "sanduichar",
    "sanduichou": "sanduichar",
    "sanduichá": "sanduichar",
    "sanduichámo": "sanduichar",
    "sanduichámos": "sanduichar",
    "sanduicháramo": "sanduichar",
    "sanduicháramos": "sanduichar",
    "sanduichárei": "sanduichar",
    "sanduicháreis": "sanduichar",
    "sanduichásseis": "sanduichar",
    "sanduichássemos": "sanduichar",
    "sanduichávamo": "sanduichar",
    "sanduichávamos": "sanduichar",
    "sanduichávei": "sanduichar",
    "sanduicháveis": "sanduichar",
    "sanduíches": "sanduíche",
    "sandwichs": "sandwich",
    "sandálias": "sandália",
    "sandáracas": "sandáraca",
    "sane": "sanar",
    "saneada": "sanear",
    "saneadas": "sanear",
    "saneado": "sanear",
    "saneadora": "saneador",
    "saneadoras": "saneador",
    "saneadores": "saneador",
    "saneados": "sanear",
    "saneai": "sanear",
    "saneais": "sanear",
    "saneamentos": "saneamento",
    "saneamo": "sanear",
    "saneamos": "sanear",
    "saneando": "sanear",
    "saneara": "sanear",
    "sanearam": "sanear",
    "sanearas": "sanear",
    "sanearde": "sanear",
    "saneardes": "sanear",
    "saneare": "sanear",
    "sanearei": "sanear",
    "saneareis": "sanear",
    "sanearem": "sanear",
    "sanearemos": "sanear",
    "saneares": "sanear",
    "sanearia": "sanear",
    "saneariam": "sanear",
    "sanearias": "sanear",
    "sanearmo": "sanear",
    "sanearmos": "sanear",
    "saneará": "sanear",
    "sanearás": "sanear",
    "sanearão": "sanear",
    "sanearíamos": "sanear",
    "sanearíeis": "sanear",
    "saneasse": "sanear",
    "saneassem": "sanear",
    "saneasses": "sanear",
    "saneaste": "sanear",
    "saneastes": "sanear",
    "saneava": "sanear",
    "saneavam": "sanear",
    "saneavas": "sanear",
    "sanedrins": "sanedrim",
    "saneei": "sanear",
    "saneeis": "sanear",
    "saneemo": "sanear",
    "saneemos": "sanear",
    "sanefas": "sanefa",
    "sanei": "sanar",
    "saneia": "sanear",
    "saneiam": "sanear",
    "saneias": "sanear",
    "saneie": "sanear",
    "saneiem": "sanear",
    "saneies": "sanear",
    "saneio": "sanear",
    "saneis": "sanar",
    "sanem": "sanar",
    "sanemo": "sanar",
    "sanemos": "sanar",
    "saneou": "sanear",
    "sanes": "sanar",
    "saneá": "sanear",
    "saneámo": "sanear",
    "saneámos": "sanear",
    "saneáramo": "sanear",
    "saneáramos": "sanear",
    "saneárei": "sanear",
    "saneáreis": "sanear",
    "saneásseis": "sanear",
    "saneássemos": "sanear",
    "saneávamo": "sanear",
    "saneávamos": "sanear",
    "saneávei": "sanear",
    "saneáveis": "saneável",
    "sanfenos": "sanfeno",
    "sanfona": "sanfonar",
    "sanfonada": "sanfonar",
    "sanfonadas": "sanfonar",
    "sanfonado": "sanfonar",
    "sanfonados": "sanfonar",
    "sanfonai": "sanfonar",
    "sanfonais": "sanfonar",
    "sanfonam": "sanfonar",
    "sanfonamo": "sanfonar",
    "sanfonamos": "sanfonar",
    "sanfonando": "sanfonar",
    "sanfonara": "sanfonar",
    "sanfonaram": "sanfonar",
    "sanfonaras": "sanfonar",
    "sanfonardes": "sanfonar",
    "sanfonarei": "sanfonar",
    "sanfonareis": "sanfonar",
    "sanfonarem": "sanfonar",
    "sanfonaremos": "sanfonar",
    "sanfonares": "sanfonar",
    "sanfonaria": "sanfonar",
    "sanfonariam": "sanfonar",
    "sanfonarias": "sanfonar",
    "sanfonarmo": "sanfonar",
    "sanfonarmos": "sanfonar",
    "sanfonará": "sanfonar",
    "sanfonarás": "sanfonar",
    "sanfonarão": "sanfonar",
    "sanfonaríamos": "sanfonar",
    "sanfonaríeis": "sanfonar",
    "sanfonas": "sanfonar",
    "sanfonasse": "sanfonar",
    "sanfonassem": "sanfonar",
    "sanfonasses": "sanfonar",
    "sanfonaste": "sanfonar",
    "sanfonastes": "sanfonar",
    "sanfonava": "sanfonar",
    "sanfonavam": "sanfonar",
    "sanfonavas": "sanfonar",
    "sanfone": "sanfonar",
    "sanfonei": "sanfonar",
    "sanfoneira": "sanfoneiro",
    "sanfoneiras": "sanfoneiro",
    "sanfoneiros": "sanfoneiro",
    "sanfoneis": "sanfonar",
    "sanfonem": "sanfonar",
    "sanfonemo": "sanfonar",
    "sanfonemos": "sanfonar",
    "sanfones": "sanfonar",
    "sanfonhas": "sanfonha",
    "sanfonina": "sanfoninar",
    "sanfoninada": "sanfoninar",
    "sanfoninadas": "sanfoninar",
    "sanfoninado": "sanfoninar",
    "sanfoninados": "sanfoninar",
    "sanfoninai": "sanfoninar",
    "sanfoninais": "sanfoninar",
    "sanfoninam": "sanfoninar",
    "sanfoninamo": "sanfoninar",
    "sanfoninamos": "sanfoninar",
    "sanfoninando": "sanfoninar",
    "sanfoninara": "sanfoninar",
    "sanfoninaram": "sanfoninar",
    "sanfoninaras": "sanfoninar",
    "sanfoninardes": "sanfoninar",
    "sanfoninarei": "sanfoninar",
    "sanfoninareis": "sanfoninar",
    "sanfoninarem": "sanfoninar",
    "sanfoninaremos": "sanfoninar",
    "sanfoninares": "sanfoninar",
    "sanfoninaria": "sanfoninar",
    "sanfoninariam": "sanfoninar",
    "sanfoninarias": "sanfoninar",
    "sanfoninarmo": "sanfoninar",
    "sanfoninarmos": "sanfoninar",
    "sanfoninará": "sanfoninar",
    "sanfoninarás": "sanfoninar",
    "sanfoninarão": "sanfoninar",
    "sanfoninaríamos": "sanfoninar",
    "sanfoninaríeis": "sanfoninar",
    "sanfoninas": "sanfoninar",
    "sanfoninasse": "sanfoninar",
    "sanfoninassem": "sanfoninar",
    "sanfoninasses": "sanfoninar",
    "sanfoninaste": "sanfoninar",
    "sanfoninastes": "sanfoninar",
    "sanfoninava": "sanfoninar",
    "sanfoninavam": "sanfoninar",
    "sanfoninavas": "sanfoninar",
    "sanfonine": "sanfoninar",
    "sanfoninei": "sanfoninar",
    "sanfonineira": "sanfonineiro",
    "sanfonineiras": "sanfonineiro",
    "sanfonineiros": "sanfonineiro",
    "sanfonineis": "sanfoninar",
    "sanfoninem": "sanfoninar",
    "sanfoninemo": "sanfoninar",
    "sanfoninemos": "sanfoninar",
    "sanfonines": "sanfoninar",
    "sanfoninheira": "sanfoninheiro",
    "sanfoninheiras": "sanfoninheiro",
    "sanfoninheiros": "sanfoninheiro",
    "sanfonino": "sanfoninar",
    "sanfoninou": "sanfoninar",
    "sanfoninámo": "sanfoninar",
    "sanfoninámos": "sanfoninar",
    "sanfonináramo": "sanfoninar",
    "sanfonináramos": "sanfoninar",
    "sanfonináreis": "sanfoninar",
    "sanfoninásseis": "sanfoninar",
    "sanfoninássemos": "sanfoninar",
    "sanfoninávamo": "sanfoninar",
    "sanfoninávamos": "sanfoninar",
    "sanfonináveis": "sanfoninar",
    "sanfono": "sanfonar",
    "sanfonou": "sanfonar",
    "sanfonámo": "sanfonar",
    "sanfonámos": "sanfonar",
    "sanfonáramo": "sanfonar",
    "sanfonáramos": "sanfonar",
    "sanfonáreis": "sanfonar",
    "sanfonásseis": "sanfonar",
    "sanfonássemos": "sanfonar",
    "sanfonávamo": "sanfonar",
    "sanfonávamos": "sanfonar",
    "sanfonáveis": "sanfonar",
    "sangachos": "sangacho",
    "sangada": "sangado",
    "sangadas": "sangado",
    "sangados": "sangado",
    "sangalhos": "sangalho",
    "sangas": "sanga",
    "sangra": "sangrar",
    "sangrada": "sangrar",
    "sangradas": "sangrar",
    "sangradeiras": "sangradeira",
    "sangrado": "sangrar",
    "sangradoiros": "sangradoiro",
    "sangradora": "sangrador",
    "sangradoras": "sangrador",
    "sangradores": "sangrador",
    "sangrados": "sangrar",
    "sangradouros": "sangradouro",
    "sangraduras": "sangradura",
    "sangrai": "sangrar",
    "sangrais": "sangrar",
    "sangram": "sangrar",
    "sangramo": "sangrar",
    "sangramos": "sangrar",
    "sangrando": "sangrar",
    "sangrantes": "sangrante",
    "sangrara": "sangrar",
    "sangraram": "sangrar",
    "sangraras": "sangrar",
    "sangrarde": "sangrar",
    "sangrardes": "sangrar",
    "sangrare": "sangrar",
    "sangrarei": "sangrar",
    "sangrareis": "sangrar",
    "sangrarem": "sangrar",
    "sangraremos": "sangrar",
    "sangrares": "sangrar",
    "sangraria": "sangrar",
    "sangrariam": "sangrar",
    "sangrarias": "sangrar",
    "sangrarmo": "sangrar",
    "sangrarmos": "sangrar",
    "sangrará": "sangrar",
    "sangrarás": "sangrar",
    "sangrarão": "sangrar",
    "sangraríamos": "sangrar",
    "sangraríeis": "sangrar",
    "sangras": "sangrar",
    "sangrasse": "sangrar",
    "sangrassem": "sangrar",
    "sangrasses": "sangrar",
    "sangraste": "sangrar",
    "sangrastes": "sangrar",
    "sangrava": "sangrar",
    "sangravam": "sangrar",
    "sangravas": "sangrar",
    "sangre": "sangrar",
    "sangrei": "sangrar",
    "sangreis": "sangrar",
    "sangrem": "sangrar",
    "sangremo": "sangrar",
    "sangremos": "sangrar",
    "sangrenta": "sangrento",
    "sangrentas": "sangrento",
    "sangrentos": "sangrento",
    "sangres": "sangrar",
    "sangrias": "sangria",
    "sangro": "sangrar",
    "sangrou": "sangrar",
    "sangrá": "sangrar",
    "sangrámo": "sangrar",
    "sangrámos": "sangrar",
    "sangráramo": "sangrar",
    "sangráramos": "sangrar",
    "sangrárei": "sangrar",
    "sangráreis": "sangrar",
    "sangrásseis": "sangrar",
    "sangrássemos": "sangrar",
    "sangrávamo": "sangrar",
    "sangrávamos": "sangrar",
    "sangrávei": "sangrar",
    "sangráveis": "sangrar",
    "sanguechuvas": "sanguechuva",
    "sangueiras": "sangueira",
    "sanguenta": "sanguento",
    "sanguentada": "sanguentado",
    "sanguentadas": "sanguentado",
    "sanguentados": "sanguentado",
    "sanguentas": "sanguento",
    "sanguentos": "sanguento",
    "sangues": "sangue",
    "sanguessugas": "sanguessuga",
    "sanguifica": "sanguificar",
    "sanguificada": "sanguificar",
    "sanguificadas": "sanguificar",
    "sanguificado": "sanguificar",
    "sanguificados": "sanguificar",
    "sanguificai": "sanguificar",
    "sanguificais": "sanguificar",
    "sanguificam": "sanguificar",
    "sanguificamo": "sanguificar",
    "sanguificamos": "sanguificar",
    "sanguificando": "sanguificar",
    "sanguificara": "sanguificar",
    "sanguificaram": "sanguificar",
    "sanguificaras": "sanguificar",
    "sanguificarde": "sanguificar",
    "sanguificardes": "sanguificar",
    "sanguificare": "sanguificar",
    "sanguificarei": "sanguificar",
    "sanguificareis": "sanguificar",
    "sanguificarem": "sanguificar",
    "sanguificaremos": "sanguificar",
    "sanguificares": "sanguificar",
    "sanguificaria": "sanguificar",
    "sanguificariam": "sanguificar",
    "sanguificarias": "sanguificar",
    "sanguificarmo": "sanguificar",
    "sanguificarmos": "sanguificar",
    "sanguificará": "sanguificar",
    "sanguificarás": "sanguificar",
    "sanguificarão": "sanguificar",
    "sanguificaríamos": "sanguificar",
    "sanguificaríeis": "sanguificar",
    "sanguificas": "sanguificar",
    "sanguificasse": "sanguificar",
    "sanguificassem": "sanguificar",
    "sanguificasses": "sanguificar",
    "sanguificaste": "sanguificar",
    "sanguificastes": "sanguificar",
    "sanguificativa": "sanguificativo",
    "sanguificativas": "sanguificativo",
    "sanguificativos": "sanguificativo",
    "sanguificava": "sanguificar",
    "sanguificavam": "sanguificar",
    "sanguificavas": "sanguificar",
    "sanguificações": "sanguificação",
    "sanguifico": "sanguificar",
    "sanguificou": "sanguificar",
    "sanguificá": "sanguificar",
    "sanguificámo": "sanguificar",
    "sanguificámos": "sanguificar",
    "sanguificáramo": "sanguificar",
    "sanguificáramos": "sanguificar",
    "sanguificárei": "sanguificar",
    "sanguificáreis": "sanguificar",
    "sanguificásseis": "sanguificar",
    "sanguificássemos": "sanguificar",
    "sanguificávamo": "sanguificar",
    "sanguificávamos": "sanguificar",
    "sanguificávei": "sanguificar",
    "sanguificáveis": "sanguificar",
    "sanguifique": "sanguificar",
    "sanguifiquei": "sanguificar",
    "sanguifiqueis": "sanguificar",
    "sanguifiquem": "sanguificar",
    "sanguifiquemo": "sanguificar",
    "sanguifiquemos": "sanguificar",
    "sanguifiques": "sanguificar",
    "sanguina": "sanguino",
    "sanguinas": "sanguino",
    "sanguinações": "sanguinação",
    "sanguinhais": "sanguinhal",
    "sanguinhas": "sanguinha",
    "sanguinheiros": "sanguinheiro",
    "sanguinhos": "sanguinho",
    "sanguinidades": "sanguinidade",
    "sanguinolenta": "sanguinolento",
    "sanguinolentas": "sanguinolento",
    "sanguinolentos": "sanguinolento",
    "sanguinolências": "sanguinolência",
    "sanguinos": "sanguino",
    "sanguinosa": "sanguinoso",
    "sanguinosas": "sanguinoso",
    "sanguinosos": "sanguinoso",
    "sanguinária": "sanguinário",
    "sanguinárias": "sanguinário",
    "sanguinários": "sanguinário",
    "sanguissedenta": "sanguissedento",
    "sanguissedentas": "sanguissedento",
    "sanguissedentos": "sanguissedento",
    "sanguífera": "sanguífero",
    "sanguíferas": "sanguífero",
    "sanguíferos": "sanguífero",
    "sanguífica": "sanguífico",
    "sanguíficas": "sanguífico",
    "sanguíficos": "sanguífico",
    "sanguínea": "sanguíneo",
    "sanguíneas": "sanguíneo",
    "sanguíneos": "sanguíneo",
    "sanguívora": "sanguívoro",
    "sanguívoras": "sanguívoro",
    "sanguívoros": "sanguívoro",
    "sanhas": "sanha",
    "sanheiros": "sanheiro",
    "sanhosa": "sanhoso",
    "sanhosas": "sanhoso",
    "sanhosos": "sanhoso",
    "sanhuda": "sanhudo",
    "sanhudas": "sanhudo",
    "sanhudos": "sanhudo",
    "sanica": "sanicar",
    "sanicada": "sanicar",
    "sanicadas": "sanicar",
    "sanicado": "sanicar",
    "sanicados": "sanicar",
    "sanicai": "sanicar",
    "sanicais": "sanicar",
    "sanicam": "sanicar",
    "sanicamo": "sanicar",
    "sanicamos": "sanicar",
    "sanicando": "sanicar",
    "sanicara": "sanicar",
    "sanicaram": "sanicar",
    "sanicaras": "sanicar",
    "sanicarde": "sanicar",
    "sanicardes": "sanicar",
    "sanicare": "sanicar",
    "sanicarei": "sanicar",
    "sanicareis": "sanicar",
    "sanicarem": "sanicar",
    "sanicaremos": "sanicar",
    "sanicares": "sanicar",
    "sanicaria": "sanicar",
    "sanicariam": "sanicar",
    "sanicarias": "sanicar",
    "sanicarmo": "sanicar",
    "sanicarmos": "sanicar",
    "sanicará": "sanicar",
    "sanicarás": "sanicar",
    "sanicarão": "sanicar",
    "sanicaríamos": "sanicar",
    "sanicaríeis": "sanicar",
    "sanicas": "sanicar",
    "sanicasse": "sanicar",
    "sanicassem": "sanicar",
    "sanicasses": "sanicar",
    "sanicaste": "sanicar",
    "sanicastes": "sanicar",
    "sanicava": "sanicar",
    "sanicavam": "sanicar",
    "sanicavas": "sanicar",
    "sanico": "sanicar",
    "sanicou": "sanicar",
    "sanicá": "sanicar",
    "sanicámo": "sanicar",
    "sanicámos": "sanicar",
    "sanicáramo": "sanicar",
    "sanicáramos": "sanicar",
    "sanicárei": "sanicar",
    "sanicáreis": "sanicar",
    "sanicásseis": "sanicar",
    "sanicássemos": "sanicar",
    "sanicávamo": "sanicar",
    "sanicávamos": "sanicar",
    "sanicávei": "sanicar",
    "sanicáveis": "sanicar",
    "sanidades": "sanidade",
    "sanidinas": "sanidina",
    "sanifica": "sanificar",
    "sanificada": "sanificar",
    "sanificadas": "sanificar",
    "sanificado": "sanificar",
    "sanificadora": "sanificador",
    "sanificadoras": "sanificador",
    "sanificadores": "sanificador",
    "sanificados": "sanificar",
    "sanificai": "sanificar",
    "sanificais": "sanificar",
    "sanificam": "sanificar",
    "sanificamo": "sanificar",
    "sanificamos": "sanificar",
    "sanificando": "sanificar",
    "sanificantes": "sanificante",
    "sanificara": "sanificar",
    "sanificaram": "sanificar",
    "sanificaras": "sanificar",
    "sanificarde": "sanificar",
    "sanificardes": "sanificar",
    "sanificare": "sanificar",
    "sanificarei": "sanificar",
    "sanificareis": "sanificar",
    "sanificarem": "sanificar",
    "sanificaremos": "sanificar",
    "sanificares": "sanificar",
    "sanificaria": "sanificar",
    "sanificariam": "sanificar",
    "sanificarias": "sanificar",
    "sanificarmo": "sanificar",
    "sanificarmos": "sanificar",
    "sanificará": "sanificar",
    "sanificarás": "sanificar",
    "sanificarão": "sanificar",
    "sanificaríamos": "sanificar",
    "sanificaríeis": "sanificar",
    "sanificas": "sanificar",
    "sanificasse": "sanificar",
    "sanificassem": "sanificar",
    "sanificasses": "sanificar",
    "sanificaste": "sanificar",
    "sanificastes": "sanificar",
    "sanificava": "sanificar",
    "sanificavam": "sanificar",
    "sanificavas": "sanificar",
    "sanificações": "sanificação",
    "sanifico": "sanificar",
    "sanificou": "sanificar",
    "sanificá": "sanificar",
    "sanificámo": "sanificar",
    "sanificámos": "sanificar",
    "sanificáramo": "sanificar",
    "sanificáramos": "sanificar",
    "sanificárei": "sanificar",
    "sanificáreis": "sanificar",
    "sanificásseis": "sanificar",
    "sanificássemos": "sanificar",
    "sanificávamo": "sanificar",
    "sanificávamos": "sanificar",
    "sanificávei": "sanificar",
    "sanificáveis": "sanificar",
    "sanifique": "sanificar",
    "sanifiquei": "sanificar",
    "sanifiqueis": "sanificar",
    "sanifiquem": "sanificar",
    "sanifiquemo": "sanificar",
    "sanifiquemos": "sanificar",
    "sanifiques": "sanificar",
    "saniosa": "sanioso",
    "saniosas": "sanioso",
    "saniosos": "sanioso",
    "sanique": "sanicar",
    "saniquei": "sanicar",
    "saniqueis": "sanicar",
    "saniquem": "sanicar",
    "saniquemo": "sanicar",
    "saniquemos": "sanicar",
    "saniques": "sanicar",
    "saniscas": "sanisca",
    "sanitas": "sanita",
    "sanitária": "sanitário",
    "sanitárias": "sanitário",
    "sanitários": "sanitário",
    "sanja": "sanjar",
    "sanjada": "sanjar",
    "sanjadas": "sanjar",
    "sanjado": "sanjar",
    "sanjados": "sanjar",
    "sanjai": "sanjar",
    "sanjais": "sanjar",
    "sanjam": "sanjar",
    "sanjamo": "sanjar",
    "sanjamos": "sanjar",
    "sanjando": "sanjar",
    "sanjara": "sanjar",
    "sanjaram": "sanjar",
    "sanjaras": "sanjar",
    "sanjarde": "sanjar",
    "sanjardes": "sanjar",
    "sanjare": "sanjar",
    "sanjarei": "sanjar",
    "sanjareis": "sanjar",
    "sanjarem": "sanjar",
    "sanjaremos": "sanjar",
    "sanjares": "sanjar",
    "sanjaria": "sanjar",
    "sanjariam": "sanjar",
    "sanjarias": "sanjar",
    "sanjarmo": "sanjar",
    "sanjarmos": "sanjar",
    "sanjará": "sanjar",
    "sanjarás": "sanjar",
    "sanjarão": "sanjar",
    "sanjaríamos": "sanjar",
    "sanjaríeis": "sanjar",
    "sanjas": "sanjar",
    "sanjasse": "sanjar",
    "sanjassem": "sanjar",
    "sanjasses": "sanjar",
    "sanjaste": "sanjar",
    "sanjastes": "sanjar",
    "sanjava": "sanjar",
    "sanjavam": "sanjar",
    "sanjavas": "sanjar",
    "sanje": "sanjar",
    "sanjei": "sanjar",
    "sanjeis": "sanjar",
    "sanjem": "sanjar",
    "sanjemo": "sanjar",
    "sanjemos": "sanjar",
    "sanjes": "sanjar",
    "sanjo": "sanjar",
    "sanjoanina": "sanjoanino",
    "sanjoaninas": "sanjoanino",
    "sanjoaninos": "sanjoanino",
    "sanjoeiros": "sanjoeiro",
    "sanjou": "sanjar",
    "sanjá": "sanjar",
    "sanjámo": "sanjar",
    "sanjámos": "sanjar",
    "sanjáramo": "sanjar",
    "sanjáramos": "sanjar",
    "sanjárei": "sanjar",
    "sanjáreis": "sanjar",
    "sanjásseis": "sanjar",
    "sanjássemos": "sanjar",
    "sanjávamo": "sanjar",
    "sanjávamos": "sanjar",
    "sanjávei": "sanjar",
    "sanjáveis": "sanjar",
    "sano": "sanar",
    "sanoisianos": "sanoisiano",
    "sanonas": "sanona",
    "sanou": "sanar",
    "sanquita": "sanquitar",
    "sanquitada": "sanquitar",
    "sanquitadas": "sanquitar",
    "sanquitado": "sanquitar",
    "sanquitados": "sanquitar",
    "sanquitai": "sanquitar",
    "sanquitais": "sanquitar",
    "sanquitam": "sanquitar",
    "sanquitamo": "sanquitar",
    "sanquitamos": "sanquitar",
    "sanquitando": "sanquitar",
    "sanquitara": "sanquitar",
    "sanquitaram": "sanquitar",
    "sanquitaras": "sanquitar",
    "sanquitarde": "sanquitar",
    "sanquitardes": "sanquitar",
    "sanquitare": "sanquitar",
    "sanquitarei": "sanquitar",
    "sanquitareis": "sanquitar",
    "sanquitarem": "sanquitar",
    "sanquitaremos": "sanquitar",
    "sanquitares": "sanquitar",
    "sanquitaria": "sanquitar",
    "sanquitariam": "sanquitar",
    "sanquitarias": "sanquitar",
    "sanquitarmo": "sanquitar",
    "sanquitarmos": "sanquitar",
    "sanquitará": "sanquitar",
    "sanquitarás": "sanquitar",
    "sanquitarão": "sanquitar",
    "sanquitaríamos": "sanquitar",
    "sanquitaríeis": "sanquitar",
    "sanquitas": "sanquitar",
    "sanquitasse": "sanquitar",
    "sanquitassem": "sanquitar",
    "sanquitasses": "sanquitar",
    "sanquitaste": "sanquitar",
    "sanquitastes": "sanquitar",
    "sanquitava": "sanquitar",
    "sanquitavam": "sanquitar",
    "sanquitavas": "sanquitar",
    "sanquite": "sanquitar",
    "sanquitei": "sanquitar",
    "sanquiteis": "sanquitar",
    "sanquitem": "sanquitar",
    "sanquitemo": "sanquitar",
    "sanquitemos": "sanquitar",
    "sanquites": "sanquitar",
    "sanquito": "sanquitar",
    "sanquitou": "sanquitar",
    "sanquitá": "sanquitar",
    "sanquitámo": "sanquitar",
    "sanquitámos": "sanquitar",
    "sanquitáramo": "sanquitar",
    "sanquitáramos": "sanquitar",
    "sanquitárei": "sanquitar",
    "sanquitáreis": "sanquitar",
    "sanquitásseis": "sanquitar",
    "sanquitássemos": "sanquitar",
    "sanquitávamo": "sanquitar",
    "sanquitávamos": "sanquitar",
    "sanquitávei": "sanquitar",
    "sanquitáveis": "sanquitar",
    "sansadorninha": "sansadorninho",
    "sansadorninhas": "sansadorninho",
    "sansadorninhos": "sansadorninho",
    "sansadurninha": "sansadurninho",
    "sansadurninhas": "sansadurninho",
    "sansadurninhos": "sansadurninho",
    "sansas": "sansa",
    "sanscritismos": "sanscritismo",
    "sanscritistas": "sanscritista",
    "sanscritologias": "sanscritologia",
    "sanscritologistas": "sanscritologista",
    "sanscritóloga": "sanscritólogo",
    "sanscritólogas": "sanscritólogo",
    "sanscritólogos": "sanscritólogo",
    "sanscrítica": "sanscrítico",
    "sanscríticas": "sanscrítico",
    "sanscríticos": "sanscrítico",
    "sanseis": "sansei",
    "sansões": "sansão",
    "santa": "santo",
    "santalinas": "santalina",
    "santalácea": "santaláceo",
    "santaláceas": "santaláceo",
    "santaláceos": "santaláceo",
    "santanas": "santana",
    "santanistas": "santanista",
    "santantoninha": "santantoninho",
    "santantoninhas": "santantoninho",
    "santantoninhos": "santantoninho",
    "santanária": "santanário",
    "santanárias": "santanário",
    "santanários": "santanário",
    "santarena": "santareno",
    "santarenas": "santareno",
    "santarenos": "santareno",
    "santarias": "santaria",
    "santarrona": "santarrão",
    "santarronas": "santarrão",
    "santarrões": "santarrão",
    "santas": "santo",
    "santeira": "santeiro",
    "santeiras": "santeiro",
    "santeiros": "santeiro",
    "santelmos": "santelmo",
    "santelos": "santelo",
    "santiagos": "santiago",
    "santiaguesa": "santiaguês",
    "santiaguesas": "santiaguês",
    "santiagueses": "santiaguês",
    "santiaméns": "santiamém",
    "santicos": "santico",
    "santidades": "santidade",
    "santifica": "santificar",
    "santificada": "santificar",
    "santificadas": "santificar",
    "santificado": "santificar",
    "santificadora": "santificador",
    "santificadoras": "santificador",
    "santificadores": "santificador",
    "santificados": "santificar",
    "santificai": "santificar",
    "santificais": "santificar",
    "santificam": "santificar",
    "santificamo": "santificar",
    "santificamos": "santificar",
    "santificando": "santificar",
    "santificantes": "santificante",
    "santificara": "santificar",
    "santificaram": "santificar",
    "santificaras": "santificar",
    "santificarde": "santificar",
    "santificardes": "santificar",
    "santificare": "santificar",
    "santificarei": "santificar",
    "santificareis": "santificar",
    "santificarem": "santificar",
    "santificaremos": "santificar",
    "santificares": "santificar",
    "santificaria": "santificar",
    "santificariam": "santificar",
    "santificarias": "santificar",
    "santificarmo": "santificar",
    "santificarmos": "santificar",
    "santificará": "santificar",
    "santificarás": "santificar",
    "santificarão": "santificar",
    "santificaríamos": "santificar",
    "santificaríeis": "santificar",
    "santificas": "santificar",
    "santificasse": "santificar",
    "santificassem": "santificar",
    "santificasses": "santificar",
    "santificaste": "santificar",
    "santificastes": "santificar",
    "santificava": "santificar",
    "santificavam": "santificar",
    "santificavas": "santificar",
    "santificações": "santificação",
    "santifico": "santificar",
    "santificou": "santificar",
    "santificá": "santificar",
    "santificámo": "santificar",
    "santificámos": "santificar",
    "santificáramo": "santificar",
    "santificáramos": "santificar",
    "santificárei": "santificar",
    "santificáreis": "santificar",
    "santificásseis": "santificar",
    "santificássemos": "santificar",
    "santificávamo": "santificar",
    "santificávamos": "santificar",
    "santificávei": "santificar",
    "santificáveis": "santificável",
    "santifique": "santificar",
    "santifiquei": "santificar",
    "santifiqueis": "santificar",
    "santifiquem": "santificar",
    "santifiquemo": "santificar",
    "santifiquemos": "santificar",
    "santifiques": "santificar",
    "santiga": "santigar",
    "santigada": "santigar",
    "santigadas": "santigar",
    "santigado": "santigar",
    "santigados": "santigar",
    "santigai": "santigar",
    "santigais": "santigar",
    "santigam": "santigar",
    "santigamo": "santigar",
    "santigamos": "santigar",
    "santigando": "santigar",
    "santigara": "santigar",
    "santigaram": "santigar",
    "santigaras": "santigar",
    "santigarde": "santigar",
    "santigardes": "santigar",
    "santigare": "santigar",
    "santigarei": "santigar",
    "santigareis": "santigar",
    "santigarem": "santigar",
    "santigaremos": "santigar",
    "santigares": "santigar",
    "santigaria": "santigar",
    "santigariam": "santigar",
    "santigarias": "santigar",
    "santigarmo": "santigar",
    "santigarmos": "santigar",
    "santigará": "santigar",
    "santigarás": "santigar",
    "santigarão": "santigar",
    "santigaríamos": "santigar",
    "santigaríeis": "santigar",
    "santigas": "santigar",
    "santigasse": "santigar",
    "santigassem": "santigar",
    "santigasses": "santigar",
    "santigaste": "santigar",
    "santigastes": "santigar",
    "santigava": "santigar",
    "santigavam": "santigar",
    "santigavas": "santigar",
    "santigo": "santigar",
    "santigou": "santigar",
    "santigue": "santigar",
    "santiguei": "santigar",
    "santigueis": "santigar",
    "santiguem": "santigar",
    "santiguemo": "santigar",
    "santiguemos": "santigar",
    "santigues": "santigar",
    "santigá": "santigar",
    "santigámo": "santigar",
    "santigámos": "santigar",
    "santigáramo": "santigar",
    "santigáramos": "santigar",
    "santigárei": "santigar",
    "santigáreis": "santigar",
    "santigásseis": "santigar",
    "santigássemos": "santigar",
    "santigávamo": "santigar",
    "santigávamos": "santigar",
    "santigávei": "santigar",
    "santigáveis": "santigar",
    "santilona": "santilão",
    "santilonas": "santilão",
    "santilões": "santilão",
    "santimoniais": "santimonial",
    "santimónias": "santimónia",
    "santinha": "santo",
    "santinhas": "santo",
    "santinho": "santo",
    "santinhos": "santo",
    "santistas": "santista",
    "santita": "santo",
    "santitas": "santo",
    "santito": "santo",
    "santitos": "santo",
    "santiámens": "santiámen",
    "santolas": "santola",
    "santolinas": "santolina",
    "santonianos": "santoniano",
    "santonicas": "santonica",
    "santonicos": "santonico",
    "santoninas": "santonina",
    "santorais": "santoral",
    "santores": "santor",
    "santoros": "santoro",
    "santos": "santo",
    "santuários": "santuário",
    "santíssima": "santo",
    "santíssimas": "santo",
    "santíssimo": "santo",
    "santíssimos": "santo",
    "santórios": "santório",
    "santóruns": "santórum",
    "sanzalas": "sanzala",
    "saná": "sanar",
    "sanámo": "sanar",
    "sanámos": "sanar",
    "sanáramo": "sanar",
    "sanáramos": "sanar",
    "sanárei": "sanar",
    "sanáreis": "sanar",
    "sanásseis": "sanar",
    "sanássemos": "sanar",
    "sanávamo": "sanar",
    "sanávamos": "sanar",
    "sanávei": "sanar",
    "sanáveis": "sanável",
    "sanções": "sanção",
    "sanédrios": "sanédrio",
    "sanículas": "sanícula",
    "saníssima": "são",
    "saníssimas": "são",
    "saníssimo": "são",
    "saníssimos": "são",
    "sapa": "sapo",
    "sapada": "sapar",
    "sapadas": "sapar",
    "sapado": "sapar",
    "sapadora": "sapador",
    "sapadoras": "sapador",
    "sapadores": "sapador",
    "sapados": "sapar",
    "sapai": "sapar",
    "sapais": "sapar",
    "sapam": "sapar",
    "sapamo": "sapar",
    "sapamos": "sapar",
    "sapando": "sapar",
    "sapara": "sapar",
    "saparam": "sapar",
    "saparas": "sapar",
    "sapardes": "sapar",
    "saparei": "sapar",
    "sapareis": "sapar",
    "saparem": "sapar",
    "saparemos": "sapar",
    "sapares": "sapar",
    "saparia": "sapar",
    "sapariam": "sapar",
    "saparias": "sapar",
    "saparmo": "sapar",
    "saparmos": "sapar",
    "sapará": "sapar",
    "saparás": "sapar",
    "saparão": "sapar",
    "saparíamos": "sapar",
    "saparíeis": "sapar",
    "sapas": "sapo",
    "sapasse": "sapar",
    "sapassem": "sapar",
    "sapasses": "sapar",
    "sapaste": "sapar",
    "sapastes": "sapar",
    "sapatadas": "sapatada",
    "sapatarias": "sapataria",
    "sapatas": "sapata",
    "sapateada": "sapatear",
    "sapateadas": "sapatear",
    "sapateado": "sapatear",
    "sapateados": "sapatear",
    "sapateai": "sapatear",
    "sapateais": "sapatear",
    "sapateamo": "sapatear",
    "sapateamos": "sapatear",
    "sapateando": "sapatear",
    "sapateara": "sapatear",
    "sapatearam": "sapatear",
    "sapatearas": "sapatear",
    "sapateardes": "sapatear",
    "sapatearei": "sapatear",
    "sapateareis": "sapatear",
    "sapatearem": "sapatear",
    "sapatearemos": "sapatear",
    "sapateares": "sapatear",
    "sapatearia": "sapatear",
    "sapateariam": "sapatear",
    "sapatearias": "sapatear",
    "sapatearmo": "sapatear",
    "sapatearmos": "sapatear",
    "sapateará": "sapatear",
    "sapatearás": "sapatear",
    "sapatearão": "sapatear",
    "sapatearíamos": "sapatear",
    "sapatearíeis": "sapatear",
    "sapateasse": "sapatear",
    "sapateassem": "sapatear",
    "sapateasses": "sapatear",
    "sapateaste": "sapatear",
    "sapateastes": "sapatear",
    "sapateava": "sapatear",
    "sapateavam": "sapatear",
    "sapateavas": "sapatear",
    "sapateei": "sapatear",
    "sapateeis": "sapatear",
    "sapateemo": "sapatear",
    "sapateemos": "sapatear",
    "sapateia": "sapatear",
    "sapateiam": "sapatear",
    "sapateias": "sapatear",
    "sapateie": "sapatear",
    "sapateiem": "sapatear",
    "sapateies": "sapatear",
    "sapateio": "sapatear",
    "sapateira": "sapateiro",
    "sapateirais": "sapateiral",
    "sapateiras": "sapateiro",
    "sapateiros": "sapateiro",
    "sapateou": "sapatear",
    "sapatetas": "sapateta",
    "sapateámo": "sapatear",
    "sapateámos": "sapatear",
    "sapateáramo": "sapatear",
    "sapateáramos": "sapatear",
    "sapateáreis": "sapatear",
    "sapateásseis": "sapatear",
    "sapateássemos": "sapatear",
    "sapateávamo": "sapatear",
    "sapateávamos": "sapatear",
    "sapateáveis": "sapatear",
    "sapatilhas": "sapatilha",
    "sapatilhos": "sapatilho",
    "sapatinho": "sapato",
    "sapatinhos": "sapato",
    "sapatito": "sapato",
    "sapatitos": "sapato",
    "sapatiões": "sapatião",
    "sapatolas": "sapatola",
    "sapatorras": "sapatorra",
    "sapatorros": "sapatorro",
    "sapatos": "sapato",
    "sapatão": "sapato",
    "sapatões": "sapato",
    "sapava": "sapar",
    "sapavam": "sapar",
    "sapavas": "sapar",
    "sape": "sapar",
    "sapeca": "sapecar",
    "sapecada": "sapecar",
    "sapecadas": "sapecar",
    "sapecado": "sapecar",
    "sapecados": "sapecar",
    "sapecai": "sapecar",
    "sapecais": "sapecar",
    "sapecam": "sapecar",
    "sapecamo": "sapecar",
    "sapecamos": "sapecar",
    "sapecando": "sapecar",
    "sapecara": "sapecar",
    "sapecaram": "sapecar",
    "sapecaras": "sapecar",
    "sapecarde": "sapecar",
    "sapecardes": "sapecar",
    "sapecare": "sapecar",
    "sapecarei": "sapecar",
    "sapecareis": "sapecar",
    "sapecarem": "sapecar",
    "sapecaremos": "sapecar",
    "sapecares": "sapecar",
    "sapecaria": "sapecar",
    "sapecariam": "sapecar",
    "sapecarias": "sapecar",
    "sapecarmo": "sapecar",
    "sapecarmos": "sapecar",
    "sapecará": "sapecar",
    "sapecarás": "sapecar",
    "sapecarão": "sapecar",
    "sapecaríamos": "sapecar",
    "sapecaríeis": "sapecar",
    "sapecas": "sapecar",
    "sapecasse": "sapecar",
    "sapecassem": "sapecar",
    "sapecasses": "sapecar",
    "sapecaste": "sapecar",
    "sapecastes": "sapecar",
    "sapecava": "sapecar",
    "sapecavam": "sapecar",
    "sapecavas": "sapecar",
    "sapeco": "sapecar",
    "sapecou": "sapecar",
    "sapecá": "sapecar",
    "sapecámo": "sapecar",
    "sapecámos": "sapecar",
    "sapecáramo": "sapecar",
    "sapecáramos": "sapecar",
    "sapecárei": "sapecar",
    "sapecáreis": "sapecar",
    "sapecásseis": "sapecar",
    "sapecássemos": "sapecar",
    "sapecávamo": "sapecar",
    "sapecávamos": "sapecar",
    "sapecávei": "sapecar",
    "sapecáveis": "sapecar",
    "sapei": "sapar",
    "sapeiras": "sapeira",
    "sapeiros": "sapeiro",
    "sapeis": "sapar",
    "sapeja": "sapejar",
    "sapejada": "sapejar",
    "sapejadas": "sapejar",
    "sapejado": "sapejar",
    "sapejados": "sapejar",
    "sapejai": "sapejar",
    "sapejais": "sapejar",
    "sapejam": "sapejar",
    "sapejamo": "sapejar",
    "sapejamos": "sapejar",
    "sapejando": "sapejar",
    "sapejara": "sapejar",
    "sapejaram": "sapejar",
    "sapejaras": "sapejar",
    "sapejardes": "sapejar",
    "sapejarei": "sapejar",
    "sapejareis": "sapejar",
    "sapejarem": "sapejar",
    "sapejaremos": "sapejar",
    "sapejares": "sapejar",
    "sapejaria": "sapejar",
    "sapejariam": "sapejar",
    "sapejarias": "sapejar",
    "sapejarmo": "sapejar",
    "sapejarmos": "sapejar",
    "sapejará": "sapejar",
    "sapejarás": "sapejar",
    "sapejarão": "sapejar",
    "sapejaríamos": "sapejar",
    "sapejaríeis": "sapejar",
    "sapejas": "sapejar",
    "sapejasse": "sapejar",
    "sapejassem": "sapejar",
    "sapejasses": "sapejar",
    "sapejaste": "sapejar",
    "sapejastes": "sapejar",
    "sapejava": "sapejar",
    "sapejavam": "sapejar",
    "sapejavas": "sapejar",
    "sapeje": "sapejar",
    "sapejei": "sapejar",
    "sapejeis": "sapejar",
    "sapejem": "sapejar",
    "sapejemo": "sapejar",
    "sapejemos": "sapejar",
    "sapejes": "sapejar",
    "sapejo": "sapejar",
    "sapejou": "sapejar",
    "sapejámo": "sapejar",
    "sapejámos": "sapejar",
    "sapejáramo": "sapejar",
    "sapejáramos": "sapejar",
    "sapejáreis": "sapejar",
    "sapejásseis": "sapejar",
    "sapejássemos": "sapejar",
    "sapejávamo": "sapejar",
    "sapejávamos": "sapejar",
    "sapejáveis": "sapejar",
    "sapem": "sapar",
    "sapemo": "sapar",
    "sapemos": "sapar",
    "sapenos": "sapeno",
    "sapeque": "sapecar",
    "sapequei": "sapecar",
    "sapequeis": "sapecar",
    "sapequem": "sapecar",
    "sapequemo": "sapecar",
    "sapequemos": "sapecar",
    "sapeques": "sapecar",
    "sapes": "sapar",
    "sapezais": "sapezal",
    "sapezeiros": "sapezeiro",
    "sapienciais": "sapiencial",
    "sapientes": "sapiente",
    "sapindácea": "sapindáceo",
    "sapindáceas": "sapindáceo",
    "sapindáceos": "sapindáceo",
    "sapinha": "sapo",
    "sapinhas": "sapo",
    "sapinho": "sapo",
    "sapinhos": "sapo",
    "sapirangas": "sapiranga",
    "sapirocas": "sapiroca",
    "sapiroquenta": "sapiroquento",
    "sapiroquentas": "sapiroquento",
    "sapiroquentos": "sapiroquento",
    "sapita": "sapo",
    "sapitas": "sapo",
    "sapito": "sapo",
    "sapitos": "sapo",
    "sapiências": "sapiência",
    "sapo": "sapar",
    "sapoila": "sapoilo",
    "sapoilas": "sapoilo",
    "sapoilos": "sapoilo",
    "sapoléus": "sapoléu",
    "saponifica": "saponificar",
    "saponificada": "saponificar",
    "saponificadas": "saponificar",
    "saponificado": "saponificar",
    "saponificados": "saponificar",
    "saponificai": "saponificar",
    "saponificais": "saponificar",
    "saponificam": "saponificar",
    "saponificamo": "saponificar",
    "saponificamos": "saponificar",
    "saponificando": "saponificar",
    "saponificara": "saponificar",
    "saponificaram": "saponificar",
    "saponificaras": "saponificar",
    "saponificarde": "saponificar",
    "saponificardes": "saponificar",
    "saponificare": "saponificar",
    "saponificarei": "saponificar",
    "saponificareis": "saponificar",
    "saponificarem": "saponificar",
    "saponificaremos": "saponificar",
    "saponificares": "saponificar",
    "saponificaria": "saponificar",
    "saponificariam": "saponificar",
    "saponificarias": "saponificar",
    "saponificarmo": "saponificar",
    "saponificarmos": "saponificar",
    "saponificará": "saponificar",
    "saponificarás": "saponificar",
    "saponificarão": "saponificar",
    "saponificaríamos": "saponificar",
    "saponificaríeis": "saponificar",
    "saponificas": "saponificar",
    "saponificasse": "saponificar",
    "saponificassem": "saponificar",
    "saponificasses": "saponificar",
    "saponificaste": "saponificar",
    "saponificastes": "saponificar",
    "saponificava": "saponificar",
    "saponificavam": "saponificar",
    "saponificavas": "saponificar",
    "saponificações": "saponificação",
    "saponifico": "saponificar",
    "saponificou": "saponificar",
    "saponificá": "saponificar",
    "saponificámo": "saponificar",
    "saponificámos": "saponificar",
    "saponificáramo": "saponificar",
    "saponificáramos": "saponificar",
    "saponificárei": "saponificar",
    "saponificáreis": "saponificar",
    "saponificásseis": "saponificar",
    "saponificássemos": "saponificar",
    "saponificávamo": "saponificar",
    "saponificávamos": "saponificar",
    "saponificávei": "saponificar",
    "saponificáveis": "saponificável",
    "saponifique": "saponificar",
    "saponifiquei": "saponificar",
    "saponifiqueis": "saponificar",
    "saponifiquem": "saponificar",
    "saponifiquemo": "saponificar",
    "saponifiquemos": "saponificar",
    "saponifiques": "saponificar",
    "saponiformes": "saponiforme",
    "saponinas": "saponina",
    "saponites": "saponite",
    "saponácea": "saponáceo",
    "saponáceas": "saponáceo",
    "saponáceos": "saponáceo",
    "saponárias": "saponária",
    "saponários": "saponário",
    "sapopemas": "sapopema",
    "saporífera": "saporífero",
    "saporíferas": "saporífero",
    "saporíferos": "saporífero",
    "sapos": "sapo",
    "sapotas": "sapota",
    "sapotilhas": "sapotilha",
    "sapotis": "sapoti",
    "sapotizeiros": "sapotizeiro",
    "sapotácea": "sapotáceo",
    "sapotáceas": "sapotáceo",
    "sapotáceos": "sapotáceo",
    "sapou": "sapar",
    "saprema": "sapremar",
    "sapremada": "sapremar",
    "sapremadas": "sapremar",
    "sapremado": "sapremar",
    "sapremados": "sapremar",
    "sapremai": "sapremar",
    "sapremais": "sapremar",
    "sapremam": "sapremar",
    "sapremamo": "sapremar",
    "sapremamos": "sapremar",
    "sapremando": "sapremar",
    "sapremara": "sapremar",
    "sapremaram": "sapremar",
    "sapremaras": "sapremar",
    "sapremarde": "sapremar",
    "sapremardes": "sapremar",
    "sapremare": "sapremar",
    "sapremarei": "sapremar",
    "sapremareis": "sapremar",
    "sapremarem": "sapremar",
    "sapremaremos": "sapremar",
    "sapremares": "sapremar",
    "sapremaria": "sapremar",
    "sapremariam": "sapremar",
    "sapremarias": "sapremar",
    "sapremarmo": "sapremar",
    "sapremarmos": "sapremar",
    "sapremará": "sapremar",
    "sapremarás": "sapremar",
    "sapremarão": "sapremar",
    "sapremaríamos": "sapremar",
    "sapremaríeis": "sapremar",
    "sapremas": "sapremar",
    "sapremasse": "sapremar",
    "sapremassem": "sapremar",
    "sapremasses": "sapremar",
    "sapremaste": "sapremar",
    "sapremastes": "sapremar",
    "sapremava": "sapremar",
    "sapremavam": "sapremar",
    "sapremavas": "sapremar",
    "sapreme": "sapremar",
    "sapremei": "sapremar",
    "sapremeis": "sapremar",
    "sapremem": "sapremar",
    "saprememo": "sapremar",
    "saprememos": "sapremar",
    "sapremes": "sapremar",
    "sapremias": "sapremia",
    "sapremo": "sapremar",
    "sapremou": "sapremar",
    "sapremá": "sapremar",
    "sapremámo": "sapremar",
    "sapremámos": "sapremar",
    "sapremáramo": "sapremar",
    "sapremáramos": "sapremar",
    "sapremárei": "sapremar",
    "sapremáreis": "sapremar",
    "sapremásseis": "sapremar",
    "sapremássemos": "sapremar",
    "sapremávamo": "sapremar",
    "sapremávamos": "sapremar",
    "sapremávei": "sapremar",
    "sapremáveis": "sapremar",
    "saprobioses": "saprobiose",
    "saprocolas": "saprocola",
    "saprofitias": "saprofitia",
    "saprofitismos": "saprofitismo",
    "saprogéneres": "saprogénere",
    "saprogénica": "saprogénico",
    "saprogénicas": "saprogénico",
    "saprogénicos": "saprogénico",
    "saprolegniáceas": "saprolegniácea",
    "sapropeis": "sapropel",
    "sapropelites": "sapropelite",
    "saproxilóbia": "saproxilóbio",
    "saproxilóbias": "saproxilóbio",
    "saproxilóbios": "saproxilóbio",
    "saprozóica": "saprozóico",
    "saprozóicas": "saprozóico",
    "saprozóicos": "saprozóico",
    "saprófaga": "saprófago",
    "saprófagas": "saprófago",
    "saprófagos": "saprófago",
    "saprófila": "saprófilo",
    "saprófilas": "saprófilo",
    "saprófilos": "saprófilo",
    "saprófita": "saprófito",
    "saprófitas": "saprófito",
    "saprófitos": "saprófito",
    "sapucaias": "sapucaia",
    "sapucaieiras": "sapucaieira",
    "sapuda": "sapudo",
    "sapudas": "sapudo",
    "sapudos": "sapudo",
    "sapuléus": "sapuléu",
    "sapámo": "sapar",
    "sapámos": "sapar",
    "sapáramo": "sapar",
    "sapáramos": "sapar",
    "sapáreis": "sapar",
    "sapásseis": "sapar",
    "sapássemos": "sapar",
    "sapávamo": "sapar",
    "sapávamos": "sapar",
    "sapáveis": "sapar",
    "sapés": "sapé",
    "sapónases": "sapónase",
    "saquaremas": "saquarema",
    "saque": "sacar",
    "saqueada": "saquear",
    "saqueadas": "saquear",
    "saqueado": "saquear",
    "saqueadora": "saqueador",
    "saqueadoras": "saqueador",
    "saqueadores": "saqueador",
    "saqueados": "saquear",
    "saqueai": "saquear",
    "saqueais": "saquear",
    "saqueamo": "saquear",
    "saqueamos": "saquear",
    "saqueando": "saquear",
    "saqueara": "saquear",
    "saquearam": "saquear",
    "saquearas": "saquear",
    "saquearde": "saquear",
    "saqueardes": "saquear",
    "saqueare": "saquear",
    "saquearei": "saquear",
    "saqueareis": "saquear",
    "saquearem": "saquear",
    "saquearemos": "saquear",
    "saqueares": "saquear",
    "saquearia": "saquear",
    "saqueariam": "saquear",
    "saquearias": "saquear",
    "saquearmo": "saquear",
    "saquearmos": "saquear",
    "saqueará": "saquear",
    "saquearás": "saquear",
    "saquearão": "saquear",
    "saquearíamos": "saquear",
    "saquearíeis": "saquear",
    "saqueasse": "saquear",
    "saqueassem": "saquear",
    "saqueasses": "saquear",
    "saqueaste": "saquear",
    "saqueastes": "saquear",
    "saqueava": "saquear",
    "saqueavam": "saquear",
    "saqueavas": "saquear",
    "saqueei": "saquear",
    "saqueeis": "saquear",
    "saqueemo": "saquear",
    "saqueemos": "saquear",
    "saquei": "sacar",
    "saqueia": "saquear",
    "saqueiam": "saquear",
    "saqueias": "saquear",
    "saqueie": "saquear",
    "saqueiem": "saquear",
    "saqueies": "saquear",
    "saqueio": "saquear",
    "saqueios": "saqueio",
    "saqueira": "saqueiro",
    "saqueiras": "saqueiro",
    "saqueiros": "saqueiro",
    "saqueis": "sacar",
    "saquem": "sacar",
    "saquemo": "sacar",
    "saquemos": "sacar",
    "saqueou": "saquear",
    "saques": "saque",
    "saquetes": "saquete",
    "saqueá": "saquear",
    "saqueámo": "saquear",
    "saqueámos": "saquear",
    "saqueáramo": "saquear",
    "saqueáramos": "saquear",
    "saqueárei": "saquear",
    "saqueáreis": "saquear",
    "saqueásseis": "saquear",
    "saqueássemos": "saquear",
    "saqueávamo": "saquear",
    "saqueávamos": "saquear",
    "saqueávei": "saquear",
    "saqueáveis": "saqueável",
    "saquiadas": "saquiada",
    "saquiformes": "saquiforme",
    "saquilhões": "saquilhão",
    "saquinha": "saca",
    "saquinhas": "saca",
    "saquinho": "saco",
    "saquinhos": "saco",
    "saquins": "saquim",
    "saquita": "saca",
    "saquitas": "saca",
    "saquiteis": "saquitel",
    "saquito": "saco",
    "saquitos": "saco",
    "saquitéus": "saquitéu",
    "saquês": "saquê",
    "sara": "sarar",
    "sarabandas": "sarabanda",
    "sarabandeada": "sarabandear",
    "sarabandeadas": "sarabandear",
    "sarabandeado": "sarabandear",
    "sarabandeados": "sarabandear",
    "sarabandeai": "sarabandear",
    "sarabandeais": "sarabandear",
    "sarabandeamo": "sarabandear",
    "sarabandeamos": "sarabandear",
    "sarabandeando": "sarabandear",
    "sarabandeara": "sarabandear",
    "sarabandearam": "sarabandear",
    "sarabandearas": "sarabandear",
    "sarabandeardes": "sarabandear",
    "sarabandearei": "sarabandear",
    "sarabandeareis": "sarabandear",
    "sarabandearem": "sarabandear",
    "sarabandearemos": "sarabandear",
    "sarabandeares": "sarabandear",
    "sarabandearia": "sarabandear",
    "sarabandeariam": "sarabandear",
    "sarabandearias": "sarabandear",
    "sarabandearmo": "sarabandear",
    "sarabandearmos": "sarabandear",
    "sarabandeará": "sarabandear",
    "sarabandearás": "sarabandear",
    "sarabandearão": "sarabandear",
    "sarabandearíamos": "sarabandear",
    "sarabandearíeis": "sarabandear",
    "sarabandeasse": "sarabandear",
    "sarabandeassem": "sarabandear",
    "sarabandeasses": "sarabandear",
    "sarabandeaste": "sarabandear",
    "sarabandeastes": "sarabandear",
    "sarabandeava": "sarabandear",
    "sarabandeavam": "sarabandear",
    "sarabandeavas": "sarabandear",
    "sarabandeei": "sarabandear",
    "sarabandeeis": "sarabandear",
    "sarabandeemo": "sarabandear",
    "sarabandeemos": "sarabandear",
    "sarabandeia": "sarabandear",
    "sarabandeiam": "sarabandear",
    "sarabandeias": "sarabandear",
    "sarabandeie": "sarabandear",
    "sarabandeiem": "sarabandear",
    "sarabandeies": "sarabandear",
    "sarabandeio": "sarabandear",
    "sarabandeou": "sarabandear",
    "sarabandeámo": "sarabandear",
    "sarabandeámos": "sarabandear",
    "sarabandeáramo": "sarabandear",
    "sarabandeáramos": "sarabandear",
    "sarabandeáreis": "sarabandear",
    "sarabandeásseis": "sarabandear",
    "sarabandeássemos": "sarabandear",
    "sarabandeávamo": "sarabandear",
    "sarabandeávamos": "sarabandear",
    "sarabandeáveis": "sarabandear",
    "sarabatanas": "sarabatana",
    "sarabulhas": "sarabulha",
    "sarabulhenta": "sarabulhento",
    "sarabulhentas": "sarabulhento",
    "sarabulhentos": "sarabulhento",
    "sarabulhos": "sarabulho",
    "sarabulhosa": "sarabulhoso",
    "sarabulhosas": "sarabulhoso",
    "sarabulhosos": "sarabulhoso",
    "saracoteada": "saracotear",
    "saracoteadas": "saracotear",
    "saracoteado": "saracotear",
    "saracoteadora": "saracoteador",
    "saracoteadoras": "saracoteador",
    "saracoteadores": "saracoteador",
    "saracoteados": "saracotear",
    "saracoteai": "saracotear",
    "saracoteais": "saracotear",
    "saracoteamentos": "saracoteamento",
    "saracoteamo": "saracotear",
    "saracoteamos": "saracotear",
    "saracoteando": "saracotear",
    "saracoteara": "saracotear",
    "saracotearam": "saracotear",
    "saracotearas": "saracotear",
    "saracotearde": "saracotear",
    "saracoteardes": "saracotear",
    "saracoteare": "saracotear",
    "saracotearei": "saracotear",
    "saracoteareis": "saracotear",
    "saracotearem": "saracotear",
    "saracotearemos": "saracotear",
    "saracoteares": "saracotear",
    "saracotearia": "saracotear",
    "saracoteariam": "saracotear",
    "saracotearias": "saracotear",
    "saracotearmo": "saracotear",
    "saracotearmos": "saracotear",
    "saracoteará": "saracotear",
    "saracotearás": "saracotear",
    "saracotearão": "saracotear",
    "saracotearíamos": "saracotear",
    "saracotearíeis": "saracotear",
    "saracoteasse": "saracotear",
    "saracoteassem": "saracotear",
    "saracoteasses": "saracotear",
    "saracoteaste": "saracotear",
    "saracoteastes": "saracotear",
    "saracoteava": "saracotear",
    "saracoteavam": "saracotear",
    "saracoteavas": "saracotear",
    "saracoteei": "saracotear",
    "saracoteeis": "saracotear",
    "saracoteemo": "saracotear",
    "saracoteemos": "saracotear",
    "saracoteia": "saracotear",
    "saracoteiam": "saracotear",
    "saracoteias": "saracotear",
    "saracoteie": "saracotear",
    "saracoteiem": "saracotear",
    "saracoteies": "saracotear",
    "saracoteio": "saracotear",
    "saracoteios": "saracoteio",
    "saracoteou": "saracotear",
    "saracotes": "saracote",
    "saracoteá": "saracotear",
    "saracoteámo": "saracotear",
    "saracoteámos": "saracotear",
    "saracoteáramo": "saracotear",
    "saracoteáramos": "saracotear",
    "saracoteárei": "saracotear",
    "saracoteáreis": "saracotear",
    "saracoteásseis": "saracotear",
    "saracoteássemos": "saracotear",
    "saracoteávamo": "saracotear",
    "saracoteávamos": "saracotear",
    "saracoteávei": "saracotear",
    "saracoteáveis": "saracotear",
    "saracuras": "saracura",
    "saracás": "saracá",
    "sarada": "sarar",
    "saradas": "sarar",
    "sarado": "sarar",
    "sarados": "sarar",
    "saragoçana": "saragoçano",
    "saragoçanas": "saragoçano",
    "saragoçanos": "saragoçano",
    "saragoças": "saragoça",
    "sarai": "sarar",
    "sarais": "sarar",
    "saraiva": "saraivar",
    "saraivada": "saraivar",
    "saraivadas": "saraivar",
    "saraivado": "saraivar",
    "saraivados": "saraivar",
    "saraivai": "saraivar",
    "saraivais": "saraivar",
    "saraivam": "saraivar",
    "saraivamo": "saraivar",
    "saraivamos": "saraivar",
    "saraivando": "saraivar",
    "saraivara": "saraivar",
    "saraivaram": "saraivar",
    "saraivaras": "saraivar",
    "saraivardes": "saraivar",
    "saraivarei": "saraivar",
    "saraivareis": "saraivar",
    "saraivarem": "saraivar",
    "saraivaremos": "saraivar",
    "saraivares": "saraivar",
    "saraivaria": "saraivar",
    "saraivariam": "saraivar",
    "saraivarias": "saraivar",
    "saraivarmo": "saraivar",
    "saraivarmos": "saraivar",
    "saraivará": "saraivar",
    "saraivarás": "saraivar",
    "saraivarão": "saraivar",
    "saraivaríamos": "saraivar",
    "saraivaríeis": "saraivar",
    "saraivas": "saraivar",
    "saraivasse": "saraivar",
    "saraivassem": "saraivar",
    "saraivasses": "saraivar",
    "saraivaste": "saraivar",
    "saraivastes": "saraivar",
    "saraivava": "saraivar",
    "saraivavam": "saraivar",
    "saraivavas": "saraivar",
    "saraive": "saraivar",
    "saraivei": "saraivar",
    "saraiveiros": "saraiveiro",
    "saraiveis": "saraivar",
    "saraivem": "saraivar",
    "saraivemo": "saraivar",
    "saraivemos": "saraivar",
    "saraives": "saraivar",
    "saraiviscos": "saraivisco",
    "saraivo": "saraivar",
    "saraivou": "saraivar",
    "saraivámo": "saraivar",
    "saraivámos": "saraivar",
    "saraiváramo": "saraivar",
    "saraiváramos": "saraivar",
    "saraiváreis": "saraivar",
    "saraivásseis": "saraivar",
    "saraivássemos": "saraivar",
    "saraivávamo": "saraivar",
    "saraivávamos": "saraivar",
    "saraiváveis": "saraivar",
    "saram": "sarar",
    "saramagantas": "saramaganta",
    "saramagos": "saramago",
    "sarambas": "saramba",
    "sarambeques": "sarambeque",
    "saramburas": "sarambura",
    "saramelas": "saramela",
    "saramenheiras": "saramenheira",
    "saramenheiros": "saramenheiro",
    "saramenhos": "saramenho",
    "saramo": "sarar",
    "saramonas": "saramona",
    "saramos": "sarar",
    "sarampelos": "sarampelo",
    "sarampiformes": "sarampiforme",
    "sarampos": "sarampo",
    "saramposa": "saramposo",
    "saramposas": "saramposo",
    "saramposos": "saramposo",
    "sarampões": "sarampão",
    "saramátulos": "saramátulo",
    "saramântigas": "saramântiga",
    "sarandagens": "sarandagem",
    "sarandas": "saranda",
    "sarandeada": "sarandear",
    "sarandeadas": "sarandear",
    "sarandeado": "sarandear",
    "sarandeados": "sarandear",
    "sarandeai": "sarandear",
    "sarandeais": "sarandear",
    "sarandeamo": "sarandear",
    "sarandeamos": "sarandear",
    "sarandeando": "sarandear",
    "sarandeara": "sarandear",
    "sarandearam": "sarandear",
    "sarandearas": "sarandear",
    "sarandeardes": "sarandear",
    "sarandearei": "sarandear",
    "sarandeareis": "sarandear",
    "sarandearem": "sarandear",
    "sarandearemos": "sarandear",
    "sarandeares": "sarandear",
    "sarandearia": "sarandear",
    "sarandeariam": "sarandear",
    "sarandearias": "sarandear",
    "sarandearmo": "sarandear",
    "sarandearmos": "sarandear",
    "sarandeará": "sarandear",
    "sarandearás": "sarandear",
    "sarandearão": "sarandear",
    "sarandearíamos": "sarandear",
    "sarandearíeis": "sarandear",
    "sarandeasse": "sarandear",
    "sarandeassem": "sarandear",
    "sarandeasses": "sarandear",
    "sarandeaste": "sarandear",
    "sarandeastes": "sarandear",
    "sarandeava": "sarandear",
    "sarandeavam": "sarandear",
    "sarandeavas": "sarandear",
    "sarandeei": "sarandear",
    "sarandeeis": "sarandear",
    "sarandeemo": "sarandear",
    "sarandeemos": "sarandear",
    "sarandeia": "sarandear",
    "sarandeiam": "sarandear",
    "sarandeias": "sarandear",
    "sarandeie": "sarandear",
    "sarandeiem": "sarandear",
    "sarandeies": "sarandear",
    "sarandeio": "sarandear",
    "sarandeou": "sarandear",
    "sarandeámo": "sarandear",
    "sarandeámos": "sarandear",
    "sarandeáramo": "sarandear",
    "sarandeáramos": "sarandear",
    "sarandeáreis": "sarandear",
    "sarandeásseis": "sarandear",
    "sarandeássemos": "sarandear",
    "sarandeávamo": "sarandear",
    "sarandeávamos": "sarandear",
    "sarandeáveis": "sarandear",
    "sarandilha": "sarandilhar",
    "sarandilhada": "sarandilhar",
    "sarandilhadas": "sarandilhar",
    "sarandilhado": "sarandilhar",
    "sarandilhados": "sarandilhar",
    "sarandilhai": "sarandilhar",
    "sarandilhais": "sarandilhar",
    "sarandilham": "sarandilhar",
    "sarandilhamo": "sarandilhar",
    "sarandilhamos": "sarandilhar",
    "sarandilhando": "sarandilhar",
    "sarandilhara": "sarandilhar",
    "sarandilharam": "sarandilhar",
    "sarandilharas": "sarandilhar",
    "sarandilhardes": "sarandilhar",
    "sarandilharei": "sarandilhar",
    "sarandilhareis": "sarandilhar",
    "sarandilharem": "sarandilhar",
    "sarandilharemos": "sarandilhar",
    "sarandilhares": "sarandilhar",
    "sarandilharia": "sarandilhar",
    "sarandilhariam": "sarandilhar",
    "sarandilharias": "sarandilhar",
    "sarandilharmo": "sarandilhar",
    "sarandilharmos": "sarandilhar",
    "sarandilhará": "sarandilhar",
    "sarandilharás": "sarandilhar",
    "sarandilharão": "sarandilhar",
    "sarandilharíamos": "sarandilhar",
    "sarandilharíeis": "sarandilhar",
    "sarandilhas": "sarandilhar",
    "sarandilhasse": "sarandilhar",
    "sarandilhassem": "sarandilhar",
    "sarandilhasses": "sarandilhar",
    "sarandilhaste": "sarandilhar",
    "sarandilhastes": "sarandilhar",
    "sarandilhava": "sarandilhar",
    "sarandilhavam": "sarandilhar",
    "sarandilhavas": "sarandilhar",
    "sarandilhe": "sarandilhar",
    "sarandilhei": "sarandilhar",
    "sarandilheis": "sarandilhar",
    "sarandilhem": "sarandilhar",
    "sarandilhemo": "sarandilhar",
    "sarandilhemos": "sarandilhar",
    "sarandilhes": "sarandilhar",
    "sarandilho": "sarandilhar",
    "sarandilhou": "sarandilhar",
    "sarandilhámo": "sarandilhar",
    "sarandilhámos": "sarandilhar",
    "sarandilháramo": "sarandilhar",
    "sarandilháramos": "sarandilhar",
    "sarandilháreis": "sarandilhar",
    "sarandilhásseis": "sarandilhar",
    "sarandilhássemos": "sarandilhar",
    "sarandilhávamo": "sarandilhar",
    "sarandilhávamos": "sarandilhar",
    "sarandilháveis": "sarandilhar",
    "sarando": "sarar",
    "sarangangas": "saranganga",
    "sarapanta": "sarapantar",
    "sarapantada": "sarapantar",
    "sarapantadas": "sarapantar",
    "sarapantado": "sarapantar",
    "sarapantados": "sarapantar",
    "sarapantai": "sarapantar",
    "sarapantais": "sarapantar",
    "sarapantam": "sarapantar",
    "sarapantamo": "sarapantar",
    "sarapantamos": "sarapantar",
    "sarapantando": "sarapantar",
    "sarapantara": "sarapantar",
    "sarapantaram": "sarapantar",
    "sarapantaras": "sarapantar",
    "sarapantarde": "sarapantar",
    "sarapantardes": "sarapantar",
    "sarapantare": "sarapantar",
    "sarapantarei": "sarapantar",
    "sarapantareis": "sarapantar",
    "sarapantarem": "sarapantar",
    "sarapantaremos": "sarapantar",
    "sarapantares": "sarapantar",
    "sarapantaria": "sarapantar",
    "sarapantariam": "sarapantar",
    "sarapantarias": "sarapantar",
    "sarapantarmo": "sarapantar",
    "sarapantarmos": "sarapantar",
    "sarapantará": "sarapantar",
    "sarapantarás": "sarapantar",
    "sarapantarão": "sarapantar",
    "sarapantaríamos": "sarapantar",
    "sarapantaríeis": "sarapantar",
    "sarapantas": "sarapantar",
    "sarapantasse": "sarapantar",
    "sarapantassem": "sarapantar",
    "sarapantasses": "sarapantar",
    "sarapantaste": "sarapantar",
    "sarapantastes": "sarapantar",
    "sarapantava": "sarapantar",
    "sarapantavam": "sarapantar",
    "sarapantavas": "sarapantar",
    "sarapante": "sarapantar",
    "sarapantei": "sarapantar",
    "sarapanteis": "sarapantar",
    "sarapantem": "sarapantar",
    "sarapantemo": "sarapantar",
    "sarapantemos": "sarapantar",
    "sarapantes": "sarapantar",
    "sarapanto": "sarapantar",
    "sarapantona": "sarapantão",
    "sarapantonas": "sarapantão",
    "sarapantou": "sarapantar",
    "sarapantá": "sarapantar",
    "sarapantámo": "sarapantar",
    "sarapantámos": "sarapantar",
    "sarapantáramo": "sarapantar",
    "sarapantáramos": "sarapantar",
    "sarapantárei": "sarapantar",
    "sarapantáreis": "sarapantar",
    "sarapantásseis": "sarapantar",
    "sarapantássemos": "sarapantar",
    "sarapantávamo": "sarapantar",
    "sarapantávamos": "sarapantar",
    "sarapantávei": "sarapantar",
    "sarapantáveis": "sarapantar",
    "sarapantões": "sarapantão",
    "sarapanéis": "sarapanel",
    "sarapatéis": "sarapatel",
    "sarapicos": "sarapico",
    "sarapinta": "sarapintar",
    "sarapintada": "sarapintar",
    "sarapintadas": "sarapintar",
    "sarapintadelas": "sarapintadela",
    "sarapintado": "sarapintar",
    "sarapintados": "sarapintar",
    "sarapintai": "sarapintar",
    "sarapintais": "sarapintar",
    "sarapintam": "sarapintar",
    "sarapintamo": "sarapintar",
    "sarapintamos": "sarapintar",
    "sarapintando": "sarapintar",
    "sarapintara": "sarapintar",
    "sarapintaram": "sarapintar",
    "sarapintaras": "sarapintar",
    "sarapintarde": "sarapintar",
    "sarapintardes": "sarapintar",
    "sarapintare": "sarapintar",
    "sarapintarei": "sarapintar",
    "sarapintareis": "sarapintar",
    "sarapintarem": "sarapintar",
    "sarapintaremos": "sarapintar",
    "sarapintares": "sarapintar",
    "sarapintaria": "sarapintar",
    "sarapintariam": "sarapintar",
    "sarapintarias": "sarapintar",
    "sarapintarmo": "sarapintar",
    "sarapintarmos": "sarapintar",
    "sarapintará": "sarapintar",
    "sarapintarás": "sarapintar",
    "sarapintarão": "sarapintar",
    "sarapintaríamos": "sarapintar",
    "sarapintaríeis": "sarapintar",
    "sarapintas": "sarapintar",
    "sarapintasse": "sarapintar",
    "sarapintassem": "sarapintar",
    "sarapintasses": "sarapintar",
    "sarapintaste": "sarapintar",
    "sarapintastes": "sarapintar",
    "sarapintava": "sarapintar",
    "sarapintavam": "sarapintar",
    "sarapintavas": "sarapintar",
    "sarapinte": "sarapintar",
    "sarapintei": "sarapintar",
    "sarapinteis": "sarapintar",
    "sarapintem": "sarapintar",
    "sarapintemo": "sarapintar",
    "sarapintemos": "sarapintar",
    "sarapintes": "sarapintar",
    "sarapinto": "sarapintar",
    "sarapintou": "sarapintar",
    "sarapintá": "sarapintar",
    "sarapintámo": "sarapintar",
    "sarapintámos": "sarapintar",
    "sarapintáramo": "sarapintar",
    "sarapintáramos": "sarapintar",
    "sarapintárei": "sarapintar",
    "sarapintáreis": "sarapintar",
    "sarapintásseis": "sarapintar",
    "sarapintássemos": "sarapintar",
    "sarapintávamo": "sarapintar",
    "sarapintávamos": "sarapintar",
    "sarapintávei": "sarapintar",
    "sarapintáveis": "sarapintar",
    "sarara": "sarar",
    "sararam": "sarar",
    "sararas": "sarar",
    "sararde": "sarar",
    "sarardes": "sarar",
    "sarare": "sarar",
    "sararei": "sarar",
    "sarareis": "sarar",
    "sararem": "sarar",
    "sararemos": "sarar",
    "sarares": "sarar",
    "sararia": "sarar",
    "sarariam": "sarar",
    "sararias": "sarar",
    "sararmo": "sarar",
    "sararmos": "sarar",
    "sarará": "sarar",
    "sararás": "sarará",
    "sararão": "sarar",
    "sararíamos": "sarar",
    "sararíeis": "sarar",
    "saras": "sarar",
    "sarasse": "sarar",
    "sarassem": "sarar",
    "sarasses": "sarar",
    "saraste": "sarar",
    "sarastes": "sarar",
    "saraus": "sarau",
    "sarava": "sarar",
    "saravam": "sarar",
    "saravas": "sarar",
    "saraças": "saraça",
    "sarcasmos": "sarcasmo",
    "sarcastas": "sarcasta",
    "sarcitas": "sarcita",
    "sarcites": "sarcite",
    "sarcocarpos": "sarcocarpo",
    "sarcoceles": "sarcocele",
    "sarcocárpica": "sarcocárpico",
    "sarcocárpicas": "sarcocárpico",
    "sarcocárpicos": "sarcocárpico",
    "sarcocárpios": "sarcocárpio",
    "sarcodermas": "sarcoderma",
    "sarcofagias": "sarcofagia",
    "sarcofilos": "sarcofilo",
    "sarcoidoses": "sarcoidose",
    "sarcolemas": "sarcolema",
    "sarcologias": "sarcologia",
    "sarcomas": "sarcoma",
    "sarcomatosa": "sarcomatoso",
    "sarcomatosas": "sarcomatoso",
    "sarcomatoses": "sarcomatose",
    "sarcomatosos": "sarcomatoso",
    "sarcomática": "sarcomático",
    "sarcomáticas": "sarcomático",
    "sarcomáticos": "sarcomático",
    "sarcoplasmas": "sarcoplasma",
    "sarcoses": "sarcose",
    "sarcosperma": "sarcospermo",
    "sarcospermas": "sarcospermo",
    "sarcospermos": "sarcospermo",
    "sarcástica": "sarcástico",
    "sarcásticas": "sarcástico",
    "sarcásticos": "sarcástico",
    "sarcódios": "sarcódio",
    "sarcófaga": "sarcófago",
    "sarcófagas": "sarcófago",
    "sarcófagos": "sarcófago",
    "sarcóides": "sarcóide",
    "sarcólitos": "sarcólito",
    "sarcótica": "sarcótico",
    "sarcóticas": "sarcótico",
    "sarcóticos": "sarcótico",
    "sarda": "sardo",
    "sardanapalesca": "sardanapalesco",
    "sardanapalescas": "sardanapalesco",
    "sardanapalescos": "sardanapalesco",
    "sardanapalos": "sardanapalo",
    "sardanas": "sardana",
    "sardaniscas": "sardanisca",
    "sardanitas": "sardanita",
    "sardas": "sardo",
    "sardenha": "sardenho",
    "sardenhas": "sardenho",
    "sardenhos": "sardenho",
    "sardenta": "sardento",
    "sardentas": "sardento",
    "sardentos": "sardento",
    "sardinhadas": "sardinhada",
    "sardinhas": "sardinha",
    "sardinheira": "sardinheiro",
    "sardinheiras": "sardinheiro",
    "sardinheiros": "sardinheiro",
    "sardoeiras": "sardoeira",
    "sardoniscas": "sardonisca",
    "sardonismos": "sardonismo",
    "sardos": "sardo",
    "sardosa": "sardoso",
    "sardosas": "sardoso",
    "sardosos": "sardoso",
    "sardónia": "sardónio",
    "sardónias": "sardónio",
    "sardónica": "sardónico",
    "sardónicas": "sardónico",
    "sardónicos": "sardónico",
    "sardónios": "sardónio",
    "sardónoos": "sardónoo",
    "sardões": "sardão",
    "sare": "sarar",
    "sarei": "sarar",
    "sareis": "sarar",
    "sarem": "sarar",
    "saremo": "sarar",
    "saremos": "sarar",
    "sarenses": "sarense",
    "sares": "sarar",
    "sargaceira": "sargaceiro",
    "sargaceiras": "sargaceiro",
    "sargaceiros": "sargaceiro",
    "sargacinhas": "sargacinha",
    "sargas": "sarga",
    "sargaçais": "sargaçal",
    "sargaças": "sargaça",
    "sargaços": "sargaço",
    "sargenta": "sargento",
    "sargentas": "sargento",
    "sargenteada": "sargentear",
    "sargenteadas": "sargentear",
    "sargenteado": "sargentear",
    "sargenteados": "sargentear",
    "sargenteai": "sargentear",
    "sargenteais": "sargentear",
    "sargenteamo": "sargentear",
    "sargenteamos": "sargentear",
    "sargenteando": "sargentear",
    "sargenteara": "sargentear",
    "sargentearam": "sargentear",
    "sargentearas": "sargentear",
    "sargenteardes": "sargentear",
    "sargentearei": "sargentear",
    "sargenteareis": "sargentear",
    "sargentearem": "sargentear",
    "sargentearemos": "sargentear",
    "sargenteares": "sargentear",
    "sargentearia": "sargentear",
    "sargenteariam": "sargentear",
    "sargentearias": "sargentear",
    "sargentearmo": "sargentear",
    "sargentearmos": "sargentear",
    "sargenteará": "sargentear",
    "sargentearás": "sargentear",
    "sargentearão": "sargentear",
    "sargentearíamos": "sargentear",
    "sargentearíeis": "sargentear",
    "sargenteasse": "sargentear",
    "sargenteassem": "sargentear",
    "sargenteasses": "sargentear",
    "sargenteaste": "sargentear",
    "sargenteastes": "sargentear",
    "sargenteava": "sargentear",
    "sargenteavam": "sargentear",
    "sargenteavas": "sargentear",
    "sargenteei": "sargentear",
    "sargenteeis": "sargentear",
    "sargenteemo": "sargentear",
    "sargenteemos": "sargentear",
    "sargenteia": "sargentear",
    "sargenteiam": "sargentear",
    "sargenteias": "sargentear",
    "sargenteie": "sargentear",
    "sargenteiem": "sargentear",
    "sargenteies": "sargentear",
    "sargenteio": "sargentear",
    "sargenteou": "sargentear",
    "sargentes": "sargente",
    "sargenteámo": "sargentear",
    "sargenteámos": "sargentear",
    "sargenteáramo": "sargentear",
    "sargenteáramos": "sargentear",
    "sargenteáreis": "sargentear",
    "sargenteásseis": "sargentear",
    "sargenteássemos": "sargentear",
    "sargenteávamo": "sargentear",
    "sargenteávamos": "sargentear",
    "sargenteáveis": "sargentear",
    "sargentos": "sargento",
    "sargolas": "sargola",
    "sargos": "sargo",
    "sarguetas": "sargueta",
    "sariana": "sariano",
    "sarianas": "sariano",
    "sarianos": "sariano",
    "saribandas": "saribanda",
    "sariemas": "sariema",
    "sarigueiras": "sarigueira",
    "sarilha": "sarilhar",
    "sarilhada": "sarilhar",
    "sarilhadas": "sarilhar",
    "sarilhado": "sarilhar",
    "sarilhados": "sarilhar",
    "sarilhai": "sarilhar",
    "sarilhais": "sarilhar",
    "sarilham": "sarilhar",
    "sarilhamo": "sarilhar",
    "sarilhamos": "sarilhar",
    "sarilhando": "sarilhar",
    "sarilhara": "sarilhar",
    "sarilharam": "sarilhar",
    "sarilharas": "sarilhar",
    "sarilharde": "sarilhar",
    "sarilhardes": "sarilhar",
    "sarilhare": "sarilhar",
    "sarilharei": "sarilhar",
    "sarilhareis": "sarilhar",
    "sarilharem": "sarilhar",
    "sarilharemos": "sarilhar",
    "sarilhares": "sarilhar",
    "sarilharia": "sarilhar",
    "sarilhariam": "sarilhar",
    "sarilharias": "sarilhar",
    "sarilharmo": "sarilhar",
    "sarilharmos": "sarilhar",
    "sarilhará": "sarilhar",
    "sarilharás": "sarilhar",
    "sarilharão": "sarilhar",
    "sarilharíamos": "sarilhar",
    "sarilharíeis": "sarilhar",
    "sarilhas": "sarilhar",
    "sarilhasse": "sarilhar",
    "sarilhassem": "sarilhar",
    "sarilhasses": "sarilhar",
    "sarilhaste": "sarilhar",
    "sarilhastes": "sarilhar",
    "sarilhava": "sarilhar",
    "sarilhavam": "sarilhar",
    "sarilhavas": "sarilhar",
    "sarilhe": "sarilhar",
    "sarilhei": "sarilhar",
    "sarilheis": "sarilhar",
    "sarilhem": "sarilhar",
    "sarilhemo": "sarilhar",
    "sarilhemos": "sarilhar",
    "sarilhes": "sarilhar",
    "sarilho": "sarilhar",
    "sarilhos": "sarilho",
    "sarilhou": "sarilhar",
    "sarilhá": "sarilhar",
    "sarilhámo": "sarilhar",
    "sarilhámos": "sarilhar",
    "sarilháramo": "sarilhar",
    "sarilháramos": "sarilhar",
    "sarilhárei": "sarilhar",
    "sarilháreis": "sarilhar",
    "sarilhásseis": "sarilhar",
    "sarilhássemos": "sarilhar",
    "sarilhávamo": "sarilhar",
    "sarilhávamos": "sarilhar",
    "sarilhávei": "sarilhar",
    "sarilháveis": "sarilhar",
    "sarins": "sarin",
    "saris": "sari",
    "sarja": "sarjar",
    "sarjada": "sarjar",
    "sarjadas": "sarjar",
    "sarjadeira": "sarjador",
    "sarjadeiras": "sarjador",
    "sarjado": "sarjar",
    "sarjadora": "sarjador",
    "sarjadoras": "sarjador",
    "sarjadores": "sarjador",
    "sarjados": "sarjar",
    "sarjaduras": "sarjadura",
    "sarjai": "sarjar",
    "sarjais": "sarjar",
    "sarjam": "sarjar",
    "sarjamo": "sarjar",
    "sarjamos": "sarjar",
    "sarjando": "sarjar",
    "sarjara": "sarjar",
    "sarjaram": "sarjar",
    "sarjaras": "sarjar",
    "sarjarde": "sarjar",
    "sarjardes": "sarjar",
    "sarjare": "sarjar",
    "sarjarei": "sarjar",
    "sarjareis": "sarjar",
    "sarjarem": "sarjar",
    "sarjaremos": "sarjar",
    "sarjares": "sarjar",
    "sarjaria": "sarjar",
    "sarjariam": "sarjar",
    "sarjarias": "sarjar",
    "sarjarmo": "sarjar",
    "sarjarmos": "sarjar",
    "sarjará": "sarjar",
    "sarjarás": "sarjar",
    "sarjarão": "sarjar",
    "sarjaríamos": "sarjar",
    "sarjaríeis": "sarjar",
    "sarjas": "sarjar",
    "sarjasse": "sarjar",
    "sarjassem": "sarjar",
    "sarjasses": "sarjar",
    "sarjaste": "sarjar",
    "sarjastes": "sarjar",
    "sarjava": "sarjar",
    "sarjavam": "sarjar",
    "sarjavas": "sarjar",
    "sarjações": "sarjação",
    "sarje": "sarjar",
    "sarjei": "sarjar",
    "sarjeis": "sarjar",
    "sarjem": "sarjar",
    "sarjemo": "sarjar",
    "sarjemos": "sarjar",
    "sarjes": "sarjar",
    "sarjetas": "sarjeta",
    "sarjo": "sarjar",
    "sarjou": "sarjar",
    "sarjá": "sarjar",
    "sarjámo": "sarjar",
    "sarjámos": "sarjar",
    "sarjáramo": "sarjar",
    "sarjáramos": "sarjar",
    "sarjárei": "sarjar",
    "sarjáreis": "sarjar",
    "sarjásseis": "sarjar",
    "sarjássemos": "sarjar",
    "sarjávamo": "sarjar",
    "sarjávamos": "sarjar",
    "sarjávei": "sarjar",
    "sarjáveis": "sarjar",
    "sarjéis": "sarjel",
    "sarjões": "sarjão",
    "sarmacianos": "sarmaciano",
    "sarmentos": "sarmento",
    "sarmentosa": "sarmentoso",
    "sarmentosas": "sarmentoso",
    "sarmentosos": "sarmentoso",
    "sarmentácea": "sarmentáceo",
    "sarmentáceas": "sarmentáceo",
    "sarmentáceos": "sarmentáceo",
    "sarmentícia": "sarmentício",
    "sarmentícias": "sarmentício",
    "sarmentícios": "sarmentício",
    "sarmentífera": "sarmentífero",
    "sarmentíferas": "sarmentífero",
    "sarmentíferos": "sarmentífero",
    "sarmática": "sarmático",
    "sarmáticas": "sarmático",
    "sarmáticos": "sarmático",
    "sarmões": "sarmão",
    "sarna": "sarnir",
    "sarnais": "sarnir",
    "sarnam": "sarnir",
    "sarnamo": "sarnir",
    "sarnamos": "sarnir",
    "sarnas": "sarnir",
    "sarne": "sarnir",
    "sarnem": "sarnir",
    "sarnenta": "sarnento",
    "sarnentas": "sarnento",
    "sarnentos": "sarnento",
    "sarnes": "sarnir",
    "sarni": "sarnir",
    "sarnia": "sarnir",
    "sarniam": "sarnir",
    "sarnias": "sarnir",
    "sarnida": "sarnir",
    "sarnidas": "sarnir",
    "sarnido": "sarnir",
    "sarnidos": "sarnir",
    "sarnimo": "sarnir",
    "sarnimos": "sarnir",
    "sarnindo": "sarnir",
    "sarnira": "sarnir",
    "sarniram": "sarnir",
    "sarniras": "sarnir",
    "sarnirde": "sarnir",
    "sarnirdes": "sarnir",
    "sarnire": "sarnir",
    "sarnirei": "sarnir",
    "sarnireis": "sarnir",
    "sarnirem": "sarnir",
    "sarniremos": "sarnir",
    "sarnires": "sarnir",
    "sarniria": "sarnir",
    "sarniriam": "sarnir",
    "sarnirias": "sarnir",
    "sarnirmo": "sarnir",
    "sarnirmos": "sarnir",
    "sarnirá": "sarnir",
    "sarnirás": "sarnir",
    "sarnirão": "sarnir",
    "sarniríamos": "sarnir",
    "sarniríeis": "sarnir",
    "sarnis": "sarnir",
    "sarnisse": "sarnir",
    "sarnissem": "sarnir",
    "sarnisses": "sarnir",
    "sarniste": "sarnir",
    "sarnistes": "sarnir",
    "sarniu": "sarnir",
    "sarno": "sarnir",
    "sarnosa": "sarnoso",
    "sarnosas": "sarnoso",
    "sarnosos": "sarnoso",
    "sarníamo": "sarnir",
    "sarníamos": "sarnir",
    "sarníei": "sarnir",
    "sarníeis": "sarnir",
    "sarníramo": "sarnir",
    "sarníramos": "sarnir",
    "sarnírei": "sarnir",
    "sarníreis": "sarnir",
    "sarnísseis": "sarnir",
    "sarníssemos": "sarnir",
    "sarnões": "sarnão",
    "saro": "sarar",
    "sarou": "sarar",
    "sarpa": "sarpar",
    "sarpada": "sarpar",
    "sarpadas": "sarpar",
    "sarpado": "sarpar",
    "sarpados": "sarpar",
    "sarpai": "sarpar",
    "sarpais": "sarpar",
    "sarpam": "sarpar",
    "sarpamo": "sarpar",
    "sarpamos": "sarpar",
    "sarpando": "sarpar",
    "sarpara": "sarpar",
    "sarparam": "sarpar",
    "sarparas": "sarpar",
    "sarpardes": "sarpar",
    "sarparei": "sarpar",
    "sarpareis": "sarpar",
    "sarparem": "sarpar",
    "sarparemos": "sarpar",
    "sarpares": "sarpar",
    "sarparia": "sarpar",
    "sarpariam": "sarpar",
    "sarparias": "sarpar",
    "sarparmo": "sarpar",
    "sarparmos": "sarpar",
    "sarpará": "sarpar",
    "sarparás": "sarpar",
    "sarparão": "sarpar",
    "sarparíamos": "sarpar",
    "sarparíeis": "sarpar",
    "sarpas": "sarpar",
    "sarpasse": "sarpar",
    "sarpassem": "sarpar",
    "sarpasses": "sarpar",
    "sarpaste": "sarpar",
    "sarpastes": "sarpar",
    "sarpava": "sarpar",
    "sarpavam": "sarpar",
    "sarpavas": "sarpar",
    "sarpe": "sarpar",
    "sarpei": "sarpar",
    "sarpeis": "sarpar",
    "sarpem": "sarpar",
    "sarpemo": "sarpar",
    "sarpemos": "sarpar",
    "sarpes": "sarpar",
    "sarpo": "sarpar",
    "sarpou": "sarpar",
    "sarpámo": "sarpar",
    "sarpámos": "sarpar",
    "sarpáramo": "sarpar",
    "sarpáramos": "sarpar",
    "sarpáreis": "sarpar",
    "sarpásseis": "sarpar",
    "sarpássemos": "sarpar",
    "sarpávamo": "sarpar",
    "sarpávamos": "sarpar",
    "sarpáveis": "sarpar",
    "sarrabalhos": "sarrabalho",
    "sarrabisca": "sarrabiscar",
    "sarrabiscada": "sarrabiscar",
    "sarrabiscadas": "sarrabiscar",
    "sarrabiscado": "sarrabiscar",
    "sarrabiscados": "sarrabiscar",
    "sarrabiscai": "sarrabiscar",
    "sarrabiscais": "sarrabiscar",
    "sarrabiscam": "sarrabiscar",
    "sarrabiscamo": "sarrabiscar",
    "sarrabiscamos": "sarrabiscar",
    "sarrabiscando": "sarrabiscar",
    "sarrabiscara": "sarrabiscar",
    "sarrabiscaram": "sarrabiscar",
    "sarrabiscaras": "sarrabiscar",
    "sarrabiscarde": "sarrabiscar",
    "sarrabiscardes": "sarrabiscar",
    "sarrabiscare": "sarrabiscar",
    "sarrabiscarei": "sarrabiscar",
    "sarrabiscareis": "sarrabiscar",
    "sarrabiscarem": "sarrabiscar",
    "sarrabiscaremos": "sarrabiscar",
    "sarrabiscares": "sarrabiscar",
    "sarrabiscaria": "sarrabiscar",
    "sarrabiscariam": "sarrabiscar",
    "sarrabiscarias": "sarrabiscar",
    "sarrabiscarmo": "sarrabiscar",
    "sarrabiscarmos": "sarrabiscar",
    "sarrabiscará": "sarrabiscar",
    "sarrabiscarás": "sarrabiscar",
    "sarrabiscarão": "sarrabiscar",
    "sarrabiscaríamos": "sarrabiscar",
    "sarrabiscaríeis": "sarrabiscar",
    "sarrabiscas": "sarrabiscar",
    "sarrabiscasse": "sarrabiscar",
    "sarrabiscassem": "sarrabiscar",
    "sarrabiscasses": "sarrabiscar",
    "sarrabiscaste": "sarrabiscar",
    "sarrabiscastes": "sarrabiscar",
    "sarrabiscava": "sarrabiscar",
    "sarrabiscavam": "sarrabiscar",
    "sarrabiscavas": "sarrabiscar",
    "sarrabisco": "sarrabiscar",
    "sarrabiscos": "sarrabisco",
    "sarrabiscou": "sarrabiscar",
    "sarrabiscá": "sarrabiscar",
    "sarrabiscámo": "sarrabiscar",
    "sarrabiscámos": "sarrabiscar",
    "sarrabiscáramo": "sarrabiscar",
    "sarrabiscáramos": "sarrabiscar",
    "sarrabiscárei": "sarrabiscar",
    "sarrabiscáreis": "sarrabiscar",
    "sarrabiscásseis": "sarrabiscar",
    "sarrabiscássemos": "sarrabiscar",
    "sarrabiscávamo": "sarrabiscar",
    "sarrabiscávamos": "sarrabiscar",
    "sarrabiscávei": "sarrabiscar",
    "sarrabiscáveis": "sarrabiscar",
    "sarrabisque": "sarrabiscar",
    "sarrabisquei": "sarrabiscar",
    "sarrabisqueis": "sarrabiscar",
    "sarrabisquem": "sarrabiscar",
    "sarrabisquemo": "sarrabiscar",
    "sarrabisquemos": "sarrabiscar",
    "sarrabisques": "sarrabiscar",
    "sarrabulhadas": "sarrabulhada",
    "sarrabulhenta": "sarrabulhento",
    "sarrabulhentas": "sarrabulhento",
    "sarrabulhentos": "sarrabulhento",
    "sarrabulhos": "sarrabulho",
    "sarracena": "sarraceno",
    "sarracenas": "sarraceno",
    "sarracenazinha": "sarraceno",
    "sarracenazinhas": "sarraceno",
    "sarracenazita": "sarraceno",
    "sarracenazitas": "sarraceno",
    "sarraceniáceas": "sarraceniácea",
    "sarracenos": "sarraceno",
    "sarracenozinho": "sarraceno",
    "sarracenozinhos": "sarraceno",
    "sarracenozito": "sarraceno",
    "sarracenozitos": "sarraceno",
    "sarrafa": "sarrafar",
    "sarraface": "sarrafaçar",
    "sarrafacei": "sarrafaçar",
    "sarrafaceis": "sarrafaçar",
    "sarrafacem": "sarrafaçar",
    "sarrafacemo": "sarrafaçar",
    "sarrafacemos": "sarrafaçar",
    "sarrafaces": "sarrafaçar",
    "sarrafada": "sarrafar",
    "sarrafadas": "sarrafar",
    "sarrafado": "sarrafar",
    "sarrafados": "sarrafar",
    "sarrafai": "sarrafar",
    "sarrafais": "sarrafar",
    "sarrafam": "sarrafar",
    "sarrafamo": "sarrafar",
    "sarrafamos": "sarrafar",
    "sarrafando": "sarrafar",
    "sarrafara": "sarrafar",
    "sarrafaram": "sarrafar",
    "sarrafaras": "sarrafar",
    "sarrafardes": "sarrafar",
    "sarrafarei": "sarrafar",
    "sarrafareis": "sarrafar",
    "sarrafarem": "sarrafar",
    "sarrafaremos": "sarrafar",
    "sarrafares": "sarrafar",
    "sarrafaria": "sarrafar",
    "sarrafariam": "sarrafar",
    "sarrafarias": "sarrafar",
    "sarrafarmo": "sarrafar",
    "sarrafarmos": "sarrafar",
    "sarrafará": "sarrafar",
    "sarrafarás": "sarrafar",
    "sarrafarão": "sarrafar",
    "sarrafaríamos": "sarrafar",
    "sarrafaríeis": "sarrafar",
    "sarrafas": "sarrafar",
    "sarrafasse": "sarrafar",
    "sarrafassem": "sarrafar",
    "sarrafasses": "sarrafar",
    "sarrafaste": "sarrafar",
    "sarrafastes": "sarrafar",
    "sarrafava": "sarrafar",
    "sarrafavam": "sarrafar",
    "sarrafavas": "sarrafar",
    "sarrafaça": "sarrafaçar",
    "sarrafaçada": "sarrafaçar",
    "sarrafaçadas": "sarrafaçar",
    "sarrafaçado": "sarrafaçar",
    "sarrafaçadora": "sarrafaçador",
    "sarrafaçadoras": "sarrafaçador",
    "sarrafaçadores": "sarrafaçador",
    "sarrafaçados": "sarrafaçar",
    "sarrafaçaduras": "sarrafaçadura",
    "sarrafaçai": "sarrafaçar",
    "sarrafaçais": "sarrafaçar",
    "sarrafaçam": "sarrafaçar",
    "sarrafaçamo": "sarrafaçar",
    "sarrafaçamos": "sarrafaçar",
    "sarrafaçanas": "sarrafaçana",
    "sarrafaçando": "sarrafaçar",
    "sarrafaçara": "sarrafaçar",
    "sarrafaçaram": "sarrafaçar",
    "sarrafaçaras": "sarrafaçar",
    "sarrafaçardes": "sarrafaçar",
    "sarrafaçarei": "sarrafaçar",
    "sarrafaçareis": "sarrafaçar",
    "sarrafaçarem": "sarrafaçar",
    "sarrafaçaremos": "sarrafaçar",
    "sarrafaçares": "sarrafaçar",
    "sarrafaçaria": "sarrafaçar",
    "sarrafaçariam": "sarrafaçar",
    "sarrafaçarias": "sarrafaçar",
    "sarrafaçarmo": "sarrafaçar",
    "sarrafaçarmos": "sarrafaçar",
    "sarrafaçará": "sarrafaçar",
    "sarrafaçarás": "sarrafaçar",
    "sarrafaçarão": "sarrafaçar",
    "sarrafaçaríamos": "sarrafaçar",
    "sarrafaçaríeis": "sarrafaçar",
    "sarrafaças": "sarrafaçar",
    "sarrafaçasse": "sarrafaçar",
    "sarrafaçassem": "sarrafaçar",
    "sarrafaçasses": "sarrafaçar",
    "sarrafaçaste": "sarrafaçar",
    "sarrafaçastes": "sarrafaçar",
    "sarrafaçava": "sarrafaçar",
    "sarrafaçavam": "sarrafaçar",
    "sarrafaçavas": "sarrafaçar",
    "sarrafaço": "sarrafaçar",
    "sarrafaçou": "sarrafaçar",
    "sarrafaçámo": "sarrafaçar",
    "sarrafaçámos": "sarrafaçar",
    "sarrafaçáramo": "sarrafaçar",
    "sarrafaçáramos": "sarrafaçar",
    "sarrafaçáreis": "sarrafaçar",
    "sarrafaçásseis": "sarrafaçar",
    "sarrafaçássemos": "sarrafaçar",
    "sarrafaçávamo": "sarrafaçar",
    "sarrafaçávamos": "sarrafaçar",
    "sarrafaçáveis": "sarrafaçar",
    "sarrafe": "sarrafar",
    "sarrafeada": "sarrafear",
    "sarrafeadas": "sarrafear",
    "sarrafeado": "sarrafear",
    "sarrafeados": "sarrafear",
    "sarrafeai": "sarrafear",
    "sarrafeais": "sarrafear",
    "sarrafeamo": "sarrafear",
    "sarrafeamos": "sarrafear",
    "sarrafeando": "sarrafear",
    "sarrafeara": "sarrafear",
    "sarrafearam": "sarrafear",
    "sarrafearas": "sarrafear",
    "sarrafearde": "sarrafear",
    "sarrafeardes": "sarrafear",
    "sarrafeare": "sarrafear",
    "sarrafearei": "sarrafear",
    "sarrafeareis": "sarrafear",
    "sarrafearem": "sarrafear",
    "sarrafearemos": "sarrafear",
    "sarrafeares": "sarrafear",
    "sarrafearia": "sarrafear",
    "sarrafeariam": "sarrafear",
    "sarrafearias": "sarrafear",
    "sarrafearmo": "sarrafear",
    "sarrafearmos": "sarrafear",
    "sarrafeará": "sarrafear",
    "sarrafearás": "sarrafear",
    "sarrafearão": "sarrafear",
    "sarrafearíamos": "sarrafear",
    "sarrafearíeis": "sarrafear",
    "sarrafeasse": "sarrafear",
    "sarrafeassem": "sarrafear",
    "sarrafeasses": "sarrafear",
    "sarrafeaste": "sarrafear",
    "sarrafeastes": "sarrafear",
    "sarrafeava": "sarrafear",
    "sarrafeavam": "sarrafear",
    "sarrafeavas": "sarrafear",
    "sarrafeei": "sarrafear",
    "sarrafeeis": "sarrafear",
    "sarrafeemo": "sarrafear",
    "sarrafeemos": "sarrafear",
    "sarrafei": "sarrafar",
    "sarrafeia": "sarrafear",
    "sarrafeiam": "sarrafear",
    "sarrafeias": "sarrafear",
    "sarrafeie": "sarrafear",
    "sarrafeiem": "sarrafear",
    "sarrafeies": "sarrafear",
    "sarrafeio": "sarrafear",
    "sarrafeis": "sarrafar",
    "sarrafem": "sarrafar",
    "sarrafemo": "sarrafar",
    "sarrafemos": "sarrafar",
    "sarrafeou": "sarrafear",
    "sarrafes": "sarrafar",
    "sarrafeá": "sarrafear",
    "sarrafeámo": "sarrafear",
    "sarrafeámos": "sarrafear",
    "sarrafeáramo": "sarrafear",
    "sarrafeáramos": "sarrafear",
    "sarrafeárei": "sarrafear",
    "sarrafeáreis": "sarrafear",
    "sarrafeásseis": "sarrafear",
    "sarrafeássemos": "sarrafear",
    "sarrafeávamo": "sarrafear",
    "sarrafeávamos": "sarrafear",
    "sarrafeávei": "sarrafear",
    "sarrafeáveis": "sarrafear",
    "sarrafo": "sarrafar",
    "sarrafos": "sarrafo",
    "sarrafou": "sarrafar",
    "sarrafuscas": "sarrafusca",
    "sarrafámo": "sarrafar",
    "sarrafámos": "sarrafar",
    "sarrafáramo": "sarrafar",
    "sarrafáramos": "sarrafar",
    "sarrafáreis": "sarrafar",
    "sarrafásseis": "sarrafar",
    "sarrafássemos": "sarrafar",
    "sarrafávamo": "sarrafar",
    "sarrafávamos": "sarrafar",
    "sarrafáveis": "sarrafar",
    "sarrajões": "sarrajão",
    "sarranhos": "sarranho",
    "sarrazina": "sarrazinar",
    "sarrazinada": "sarrazinar",
    "sarrazinadas": "sarrazinar",
    "sarrazinado": "sarrazinar",
    "sarrazinados": "sarrazinar",
    "sarrazinai": "sarrazinar",
    "sarrazinais": "sarrazinar",
    "sarrazinam": "sarrazinar",
    "sarrazinamo": "sarrazinar",
    "sarrazinamos": "sarrazinar",
    "sarrazinando": "sarrazinar",
    "sarrazinara": "sarrazinar",
    "sarrazinaram": "sarrazinar",
    "sarrazinaras": "sarrazinar",
    "sarrazinarde": "sarrazinar",
    "sarrazinardes": "sarrazinar",
    "sarrazinare": "sarrazinar",
    "sarrazinarei": "sarrazinar",
    "sarrazinareis": "sarrazinar",
    "sarrazinarem": "sarrazinar",
    "sarrazinaremos": "sarrazinar",
    "sarrazinares": "sarrazinar",
    "sarrazinaria": "sarrazinar",
    "sarrazinariam": "sarrazinar",
    "sarrazinarias": "sarrazinar",
    "sarrazinarmo": "sarrazinar",
    "sarrazinarmos": "sarrazinar",
    "sarrazinará": "sarrazinar",
    "sarrazinarás": "sarrazinar",
    "sarrazinarão": "sarrazinar",
    "sarrazinaríamos": "sarrazinar",
    "sarrazinaríeis": "sarrazinar",
    "sarrazinas": "sarrazinar",
    "sarrazinasse": "sarrazinar",
    "sarrazinassem": "sarrazinar",
    "sarrazinasses": "sarrazinar",
    "sarrazinaste": "sarrazinar",
    "sarrazinastes": "sarrazinar",
    "sarrazinava": "sarrazinar",
    "sarrazinavam": "sarrazinar",
    "sarrazinavas": "sarrazinar",
    "sarrazine": "sarrazinar",
    "sarrazinei": "sarrazinar",
    "sarrazineis": "sarrazinar",
    "sarrazinem": "sarrazinar",
    "sarrazinemo": "sarrazinar",
    "sarrazinemos": "sarrazinar",
    "sarrazines": "sarrazinar",
    "sarrazino": "sarrazinar",
    "sarrazinou": "sarrazinar",
    "sarraziná": "sarrazinar",
    "sarrazinámo": "sarrazinar",
    "sarrazinámos": "sarrazinar",
    "sarrazináramo": "sarrazinar",
    "sarrazináramos": "sarrazinar",
    "sarrazinárei": "sarrazinar",
    "sarrazináreis": "sarrazinar",
    "sarrazinásseis": "sarrazinar",
    "sarrazinássemos": "sarrazinar",
    "sarrazinávamo": "sarrazinar",
    "sarrazinávamos": "sarrazinar",
    "sarrazinávei": "sarrazinar",
    "sarrazináveis": "sarrazinar",
    "sarreira": "sarreiro",
    "sarreiras": "sarreiro",
    "sarreiros": "sarreiro",
    "sarrenta": "sarrento",
    "sarrentas": "sarrento",
    "sarrentos": "sarrento",
    "sarrida": "sarrido",
    "sarridas": "sarrido",
    "sarridos": "sarrido",
    "sarroncas": "sarronca",
    "sarros": "sarro",
    "sarrrafões": "sarrrafão",
    "sarrões": "sarrão",
    "sarsórios": "sarsório",
    "sartais": "sartal",
    "sartas": "sarta",
    "sartrianos": "sartriano",
    "sartãs": "sartã",
    "sartória": "sartório",
    "sartórias": "sartório",
    "sartórios": "sartório",
    "sarugas": "saruga",
    "saruês": "saruê",
    "sará": "sarar",
    "sarámo": "sarar",
    "sarámos": "sarar",
    "saráramo": "sarar",
    "saráramos": "sarar",
    "sarárei": "sarar",
    "saráreis": "sarar",
    "sarás": "sará",
    "sarásseis": "sarar",
    "sarássemos": "sarar",
    "sarávamo": "sarar",
    "sarávamos": "sarar",
    "sarávei": "sarar",
    "saráveis": "sarável",
    "sarçais": "sarçal",
    "sarçaparrilhas": "sarçaparrilha",
    "sarças": "sarça",
    "sarçosa": "sarçoso",
    "sarçosas": "sarçoso",
    "sarçosos": "sarçoso",
    "sarópodes": "sarópode",
    "sassa": "sassar",
    "sassada": "sassar",
    "sassadas": "sassar",
    "sassado": "sassar",
    "sassados": "sassar",
    "sassafráss": "sassafrás",
    "sassai": "sassar",
    "sassais": "sassar",
    "sassam": "sassar",
    "sassamo": "sassar",
    "sassamos": "sassar",
    "sassando": "sassar",
    "sassara": "sassar",
    "sassaram": "sassar",
    "sassaras": "sassar",
    "sassarde": "sassar",
    "sassardes": "sassar",
    "sassare": "sassar",
    "sassarei": "sassar",
    "sassareis": "sassar",
    "sassarem": "sassar",
    "sassaremos": "sassar",
    "sassares": "sassar",
    "sassaria": "sassar",
    "sassariam": "sassar",
    "sassarias": "sassar",
    "sassarica": "sassaricar",
    "sassaricada": "sassaricar",
    "sassaricadas": "sassaricar",
    "sassaricado": "sassaricar",
    "sassaricados": "sassaricar",
    "sassaricais": "sassaricar",
    "sassaricam": "sassaricar",
    "sassaricamo": "sassaricar",
    "sassaricamos": "sassaricar",
    "sassaricando": "sassaricar",
    "sassaricara": "sassaricar",
    "sassaricaram": "sassaricar",
    "sassaricaras": "sassaricar",
    "sassaricardes": "sassaricar",
    "sassaricarei": "sassaricar",
    "sassaricareis": "sassaricar",
    "sassaricarem": "sassaricar",
    "sassaricaremos": "sassaricar",
    "sassaricares": "sassaricar",
    "sassaricaria": "sassaricar",
    "sassaricariam": "sassaricar",
    "sassaricarias": "sassaricar",
    "sassaricarmo": "sassaricar",
    "sassaricarmos": "sassaricar",
    "sassaricará": "sassaricar",
    "sassaricarás": "sassaricar",
    "sassaricarão": "sassaricar",
    "sassaricaríamos": "sassaricar",
    "sassaricaríeis": "sassaricar",
    "sassaricas": "sassaricar",
    "sassaricasse": "sassaricar",
    "sassaricassem": "sassaricar",
    "sassaricasses": "sassaricar",
    "sassaricaste": "sassaricar",
    "sassaricastes": "sassaricar",
    "sassaricava": "sassaricar",
    "sassaricavam": "sassaricar",
    "sassaricavas": "sassaricar",
    "sassarico": "sassaricar",
    "sassaricou": "sassaricar",
    "sassaricámo": "sassaricar",
    "sassaricámos": "sassaricar",
    "sassaricáramo": "sassaricar",
    "sassaricáramos": "sassaricar",
    "sassaricáreis": "sassaricar",
    "sassaricásseis": "sassaricar",
    "sassaricássemos": "sassaricar",
    "sassaricávamo": "sassaricar",
    "sassaricávamos": "sassaricar",
    "sassaricáveis": "sassaricar",
    "sassarique": "sassaricar",
    "sassariquei": "sassaricar",
    "sassariqueis": "sassaricar",
    "sassariquem": "sassaricar",
    "sassariquemos": "sassaricar",
    "sassariques": "sassaricar",
    "sassarmo": "sassar",
    "sassarmos": "sassar",
    "sassará": "sassar",
    "sassarás": "sassar",
    "sassarão": "sassar",
    "sassaríamos": "sassar",
    "sassaríeis": "sassar",
    "sassas": "sassar",
    "sassasse": "sassar",
    "sassassem": "sassar",
    "sassasses": "sassar",
    "sassaste": "sassar",
    "sassastes": "sassar",
    "sassava": "sassar",
    "sassavam": "sassar",
    "sassavas": "sassar",
    "sasse": "sassar",
    "sassei": "sassar",
    "sasseis": "sassar",
    "sassem": "sassar",
    "sassemo": "sassar",
    "sassemos": "sassar",
    "sasses": "sassar",
    "sasso": "sassar",
    "sassou": "sassar",
    "sassá": "sassar",
    "sassámo": "sassar",
    "sassámos": "sassar",
    "sassáramo": "sassar",
    "sassáramos": "sassar",
    "sassárei": "sassar",
    "sassáreis": "sassar",
    "sassásseis": "sassar",
    "sassássemos": "sassar",
    "sassávamo": "sassar",
    "sassávamos": "sassar",
    "sassávei": "sassar",
    "sassáveis": "sassar",
    "satanismos": "satanismo",
    "satanistas": "satanista",
    "sataniza": "satanizar",
    "satanizada": "satanizar",
    "satanizadas": "satanizar",
    "satanizado": "satanizar",
    "satanizados": "satanizar",
    "satanizai": "satanizar",
    "satanizais": "satanizar",
    "satanizam": "satanizar",
    "satanizamo": "satanizar",
    "satanizamos": "satanizar",
    "satanizando": "satanizar",
    "satanizara": "satanizar",
    "satanizaram": "satanizar",
    "satanizaras": "satanizar",
    "satanizarde": "satanizar",
    "satanizardes": "satanizar",
    "satanizare": "satanizar",
    "satanizarei": "satanizar",
    "satanizareis": "satanizar",
    "satanizarem": "satanizar",
    "satanizaremos": "satanizar",
    "satanizares": "satanizar",
    "satanizaria": "satanizar",
    "satanizariam": "satanizar",
    "satanizarias": "satanizar",
    "satanizarmo": "satanizar",
    "satanizarmos": "satanizar",
    "satanizará": "satanizar",
    "satanizarás": "satanizar",
    "satanizarão": "satanizar",
    "satanizaríamos": "satanizar",
    "satanizaríeis": "satanizar",
    "satanizas": "satanizar",
    "satanizasse": "satanizar",
    "satanizassem": "satanizar",
    "satanizasses": "satanizar",
    "satanizaste": "satanizar",
    "satanizastes": "satanizar",
    "satanizava": "satanizar",
    "satanizavam": "satanizar",
    "satanizavas": "satanizar",
    "satanize": "satanizar",
    "satanizei": "satanizar",
    "satanizeis": "satanizar",
    "satanizem": "satanizar",
    "satanizemo": "satanizar",
    "satanizemos": "satanizar",
    "satanizes": "satanizar",
    "satanizo": "satanizar",
    "satanizou": "satanizar",
    "satanizá": "satanizar",
    "satanizámo": "satanizar",
    "satanizámos": "satanizar",
    "satanizáramo": "satanizar",
    "satanizáramos": "satanizar",
    "satanizárei": "satanizar",
    "satanizáreis": "satanizar",
    "satanizásseis": "satanizar",
    "satanizássemos": "satanizar",
    "satanizávamo": "satanizar",
    "satanizávamos": "satanizar",
    "satanizávei": "satanizar",
    "satanizáveis": "satanizar",
    "satanáss": "satanás",
    "satelismos": "satelismo",
    "satelitizações": "satelitização",
    "satilhas": "satilha",
    "satiristas": "satirista",
    "satiriza": "satirizar",
    "satirizada": "satirizar",
    "satirizadas": "satirizar",
    "satirizado": "satirizar",
    "satirizados": "satirizar",
    "satirizai": "satirizar",
    "satirizais": "satirizar",
    "satirizam": "satirizar",
    "satirizamo": "satirizar",
    "satirizamos": "satirizar",
    "satirizando": "satirizar",
    "satirizara": "satirizar",
    "satirizaram": "satirizar",
    "satirizaras": "satirizar",
    "satirizarde": "satirizar",
    "satirizardes": "satirizar",
    "satirizare": "satirizar",
    "satirizarei": "satirizar",
    "satirizareis": "satirizar",
    "satirizarem": "satirizar",
    "satirizaremos": "satirizar",
    "satirizares": "satirizar",
    "satirizaria": "satirizar",
    "satirizariam": "satirizar",
    "satirizarias": "satirizar",
    "satirizarmo": "satirizar",
    "satirizarmos": "satirizar",
    "satirizará": "satirizar",
    "satirizarás": "satirizar",
    "satirizarão": "satirizar",
    "satirizaríamos": "satirizar",
    "satirizaríeis": "satirizar",
    "satirizas": "satirizar",
    "satirizasse": "satirizar",
    "satirizassem": "satirizar",
    "satirizasses": "satirizar",
    "satirizaste": "satirizar",
    "satirizastes": "satirizar",
    "satirizava": "satirizar",
    "satirizavam": "satirizar",
    "satirizavas": "satirizar",
    "satirize": "satirizar",
    "satirizei": "satirizar",
    "satirizeis": "satirizar",
    "satirizem": "satirizar",
    "satirizemo": "satirizar",
    "satirizemos": "satirizar",
    "satirizes": "satirizar",
    "satirizo": "satirizar",
    "satirizou": "satirizar",
    "satirizá": "satirizar",
    "satirizámo": "satirizar",
    "satirizámos": "satirizar",
    "satirizáramo": "satirizar",
    "satirizáramos": "satirizar",
    "satirizárei": "satirizar",
    "satirizáreis": "satirizar",
    "satirizásseis": "satirizar",
    "satirizássemos": "satirizar",
    "satirizávamo": "satirizar",
    "satirizávamos": "satirizar",
    "satirizávei": "satirizar",
    "satirizáveis": "satirizar",
    "satiriões": "satirião",
    "satiromanias": "satiromania",
    "satiríases": "satiríase",
    "satisda": "satisdar",
    "satisdada": "satisdar",
    "satisdadas": "satisdar",
    "satisdado": "satisdar",
    "satisdados": "satisdar",
    "satisdai": "satisdar",
    "satisdais": "satisdar",
    "satisdam": "satisdar",
    "satisdamo": "satisdar",
    "satisdamos": "satisdar",
    "satisdando": "satisdar",
    "satisdara": "satisdar",
    "satisdaram": "satisdar",
    "satisdaras": "satisdar",
    "satisdardes": "satisdar",
    "satisdarei": "satisdar",
    "satisdareis": "satisdar",
    "satisdarem": "satisdar",
    "satisdaremos": "satisdar",
    "satisdares": "satisdar",
    "satisdaria": "satisdar",
    "satisdariam": "satisdar",
    "satisdarias": "satisdar",
    "satisdarmo": "satisdar",
    "satisdarmos": "satisdar",
    "satisdará": "satisdar",
    "satisdarás": "satisdar",
    "satisdarão": "satisdar",
    "satisdaríamos": "satisdar",
    "satisdaríeis": "satisdar",
    "satisdas": "satisdar",
    "satisdasse": "satisdar",
    "satisdassem": "satisdar",
    "satisdasses": "satisdar",
    "satisdaste": "satisdar",
    "satisdastes": "satisdar",
    "satisdava": "satisdar",
    "satisdavam": "satisdar",
    "satisdavas": "satisdar",
    "satisdações": "satisdação",
    "satisde": "satisdar",
    "satisdei": "satisdar",
    "satisdeis": "satisdar",
    "satisdem": "satisdar",
    "satisdemo": "satisdar",
    "satisdemos": "satisdar",
    "satisdes": "satisdar",
    "satisdo": "satisdar",
    "satisdou": "satisdar",
    "satisdámo": "satisdar",
    "satisdámos": "satisdar",
    "satisdáramo": "satisdar",
    "satisdáramos": "satisdar",
    "satisdáreis": "satisdar",
    "satisdásseis": "satisdar",
    "satisdássemos": "satisdar",
    "satisdávamo": "satisdar",
    "satisdávamos": "satisdar",
    "satisdáveis": "satisdar",
    "satisfarei": "satisfazer",
    "satisfareis": "satisfazer",
    "satisfaremos": "satisfazer",
    "satisfaria": "satisfazer",
    "satisfariam": "satisfazer",
    "satisfarias": "satisfazer",
    "satisfará": "satisfazer",
    "satisfarás": "satisfazer",
    "satisfarão": "satisfazer",
    "satisfaríamos": "satisfazer",
    "satisfaríeis": "satisfazer",
    "satisfatória": "satisfatório",
    "satisfatórias": "satisfatório",
    "satisfatórios": "satisfatório",
    "satisfaz": "satisfazer",
    "satisfaze": "satisfazer",
    "satisfazei": "satisfazer",
    "satisfazeis": "satisfazer",
    "satisfazem": "satisfazer",
    "satisfazemo": "satisfazer",
    "satisfazemos": "satisfazer",
    "satisfazendo": "satisfazer",
    "satisfazerde": "satisfazer",
    "satisfazerdes": "satisfazer",
    "satisfazere": "satisfazer",
    "satisfazerem": "satisfazer",
    "satisfazeres": "satisfazer",
    "satisfazermo": "satisfazer",
    "satisfazermos": "satisfazer",
    "satisfazes": "satisfazer",
    "satisfazia": "satisfazer",
    "satisfaziam": "satisfazer",
    "satisfazias": "satisfazer",
    "satisfazê": "satisfazer",
    "satisfazíamo": "satisfazer",
    "satisfazíamos": "satisfazer",
    "satisfazíei": "satisfazer",
    "satisfazíeis": "satisfazer",
    "satisfazíveis": "satisfazível",
    "satisfaça": "satisfazer",
    "satisfaçais": "satisfazer",
    "satisfaçam": "satisfazer",
    "satisfaçamo": "satisfazer",
    "satisfaçamos": "satisfazer",
    "satisfaças": "satisfazer",
    "satisfaço": "satisfazer",
    "satisfações": "satisfação",
    "satisfeita": "satisfeito",
    "satisfeitas": "satisfeito",
    "satisfeito": "satisfazer",
    "satisfeitos": "satisfeito",
    "satisfeitíssima": "satisfeito",
    "satisfeitíssimas": "satisfeito",
    "satisfeitíssimo": "satisfeito",
    "satisfeitíssimos": "satisfeito",
    "satisfez": "satisfazer",
    "satisfi": "satisfazer",
    "satisfiz": "satisfazer",
    "satisfizemo": "satisfazer",
    "satisfizemos": "satisfazer",
    "satisfizer": "satisfazer",
    "satisfizera": "satisfazer",
    "satisfizeram": "satisfazer",
    "satisfizeras": "satisfazer",
    "satisfizerdes": "satisfazer",
    "satisfizerem": "satisfazer",
    "satisfizeres": "satisfazer",
    "satisfizermos": "satisfazer",
    "satisfizesse": "satisfazer",
    "satisfizessem": "satisfazer",
    "satisfizesses": "satisfazer",
    "satisfizeste": "satisfazer",
    "satisfizestes": "satisfazer",
    "satisfizéramo": "satisfazer",
    "satisfizéramos": "satisfazer",
    "satisfizérei": "satisfazer",
    "satisfizéreis": "satisfazer",
    "satisfizésseis": "satisfazer",
    "satisfizéssemos": "satisfazer",
    "satisfá": "satisfazer",
    "satisfê": "satisfazer",
    "sativus": "sativu",
    "satrapeada": "satrapear",
    "satrapeadas": "satrapear",
    "satrapeado": "satrapear",
    "satrapeados": "satrapear",
    "satrapeai": "satrapear",
    "satrapeais": "satrapear",
    "satrapeamo": "satrapear",
    "satrapeamos": "satrapear",
    "satrapeando": "satrapear",
    "satrapeara": "satrapear",
    "satrapearam": "satrapear",
    "satrapearas": "satrapear",
    "satrapeardes": "satrapear",
    "satrapearei": "satrapear",
    "satrapeareis": "satrapear",
    "satrapearem": "satrapear",
    "satrapearemos": "satrapear",
    "satrapeares": "satrapear",
    "satrapearia": "satrapear",
    "satrapeariam": "satrapear",
    "satrapearias": "satrapear",
    "satrapearmo": "satrapear",
    "satrapearmos": "satrapear",
    "satrapeará": "satrapear",
    "satrapearás": "satrapear",
    "satrapearão": "satrapear",
    "satrapearíamos": "satrapear",
    "satrapearíeis": "satrapear",
    "satrapeasse": "satrapear",
    "satrapeassem": "satrapear",
    "satrapeasses": "satrapear",
    "satrapeaste": "satrapear",
    "satrapeastes": "satrapear",
    "satrapeava": "satrapear",
    "satrapeavam": "satrapear",
    "satrapeavas": "satrapear",
    "satrapeei": "satrapear",
    "satrapeeis": "satrapear",
    "satrapeemo": "satrapear",
    "satrapeemos": "satrapear",
    "satrapeia": "satrapear",
    "satrapeiam": "satrapear",
    "satrapeias": "satrapear",
    "satrapeie": "satrapear",
    "satrapeiem": "satrapear",
    "satrapeies": "satrapear",
    "satrapeio": "satrapear",
    "satrapeou": "satrapear",
    "satrapeámo": "satrapear",
    "satrapeámos": "satrapear",
    "satrapeáramo": "satrapear",
    "satrapeáramos": "satrapear",
    "satrapeáreis": "satrapear",
    "satrapeásseis": "satrapear",
    "satrapeássemos": "satrapear",
    "satrapeávamo": "satrapear",
    "satrapeávamos": "satrapear",
    "satrapeáveis": "satrapear",
    "satrapias": "satrapia",
    "satrapismos": "satrapismo",
    "satura": "saturar",
    "saturabilidades": "saturabilidade",
    "saturada": "saturar",
    "saturadas": "saturar",
    "saturado": "saturar",
    "saturadora": "saturador",
    "saturadoras": "saturador",
    "saturadores": "saturador",
    "saturados": "saturar",
    "saturadíssima": "saturado",
    "saturadíssimas": "saturado",
    "saturadíssimo": "saturado",
    "saturadíssimos": "saturado",
    "saturagens": "saturagem",
    "saturai": "saturar",
    "saturais": "saturar",
    "saturam": "saturar",
    "saturamo": "saturar",
    "saturamos": "saturar",
    "saturando": "saturar",
    "saturantes": "saturante",
    "saturara": "saturar",
    "saturaram": "saturar",
    "saturaras": "saturar",
    "saturarde": "saturar",
    "saturardes": "saturar",
    "saturare": "saturar",
    "saturarei": "saturar",
    "saturareis": "saturar",
    "saturarem": "saturar",
    "saturaremos": "saturar",
    "saturares": "saturar",
    "saturaria": "saturar",
    "saturariam": "saturar",
    "saturarias": "saturar",
    "saturarmo": "saturar",
    "saturarmos": "saturar",
    "saturará": "saturar",
    "saturarás": "saturar",
    "saturarão": "saturar",
    "saturaríamos": "saturar",
    "saturaríeis": "saturar",
    "saturas": "saturar",
    "saturasse": "saturar",
    "saturassem": "saturar",
    "saturasses": "saturar",
    "saturaste": "saturar",
    "saturastes": "saturar",
    "saturava": "saturar",
    "saturavam": "saturar",
    "saturavas": "saturar",
    "saturações": "saturação",
    "sature": "saturar",
    "saturei": "saturar",
    "satureis": "saturar",
    "saturem": "saturar",
    "saturemo": "saturar",
    "saturemos": "saturar",
    "satures": "saturar",
    "saturnais": "saturnal",
    "saturniana": "saturniano",
    "saturnianas": "saturniano",
    "saturnianos": "saturniano",
    "saturnina": "saturnino",
    "saturninas": "saturnino",
    "saturninos": "saturnino",
    "saturnismos": "saturnismo",
    "saturnos": "saturno",
    "saturo": "saturar",
    "saturou": "saturar",
    "saturá": "saturar",
    "saturámo": "saturar",
    "saturámos": "saturar",
    "saturáramo": "saturar",
    "saturáramos": "saturar",
    "saturárei": "saturar",
    "saturáreis": "saturar",
    "saturásseis": "saturar",
    "saturássemos": "saturar",
    "saturávamo": "saturar",
    "saturávamos": "saturar",
    "saturávei": "saturar",
    "saturáveis": "saturável",
    "satânica": "satânico",
    "satânicas": "satânico",
    "satânicos": "satânico",
    "satãs": "satã",
    "satélites": "satélite",
    "satírica": "satírico",
    "satíricas": "satírico",
    "satíricos": "satírico",
    "satírios": "satírio",
    "satúrnia": "satúrnio",
    "satúrnias": "satúrnio",
    "satúrnios": "satúrnio",
    "saudada": "saudar",
    "saudadas": "saudar",
    "saudades": "saudade",
    "saudado": "saudar",
    "saudadora": "saudador",
    "saudadoras": "saudador",
    "saudadores": "saudador",
    "saudados": "saudar",
    "saudai": "saudar",
    "saudais": "saudar",
    "saudamo": "saudar",
    "saudamos": "saudar",
    "saudando": "saudar",
    "saudantes": "saudante",
    "saudara": "saudar",
    "saudaram": "saudar",
    "saudaras": "saudar",
    "saudarde": "saudar",
    "saudardes": "saudar",
    "saudare": "saudar",
    "saudarei": "saudar",
    "saudareis": "saudar",
    "saudarem": "saudar",
    "saudaremos": "saudar",
    "saudares": "saudar",
    "saudaria": "saudar",
    "saudariam": "saudar",
    "saudarias": "saudar",
    "saudarmo": "saudar",
    "saudarmos": "saudar",
    "saudará": "saudar",
    "saudarás": "saudar",
    "saudarão": "saudar",
    "saudaríamos": "saudar",
    "saudaríeis": "saudar",
    "saudasse": "saudar",
    "saudassem": "saudar",
    "saudasses": "saudar",
    "saudaste": "saudar",
    "saudastes": "saudar",
    "saudava": "saudar",
    "saudavam": "saudar",
    "saudavas": "saudar",
    "saudações": "saudação",
    "saudei": "saudar",
    "saudeis": "saudar",
    "saudemo": "saudar",
    "saudemos": "saudar",
    "saudinha": "saúde",
    "saudinhas": "saúde",
    "saudita": "saúde",
    "sauditas": "saudita",
    "saudosa": "saudoso",
    "saudosas": "saudoso",
    "saudosismos": "saudosismo",
    "saudosistas": "saudosista",
    "saudosos": "saudoso",
    "saudosíssima": "saudoso",
    "saudosíssimas": "saudoso",
    "saudosíssimo": "saudoso",
    "saudosíssimos": "saudoso",
    "saudou": "saudar",
    "saudá": "saudar",
    "saudámo": "saudar",
    "saudámos": "saudar",
    "saudáramo": "saudar",
    "saudáramos": "saudar",
    "saudárei": "saudar",
    "saudáreis": "saudar",
    "saudásseis": "saudar",
    "saudássemos": "saudar",
    "saudávamo": "saudar",
    "saudávamos": "saudar",
    "saudávei": "saudar",
    "saudáveis": "saudável",
    "saunas": "sauna",
    "sauripélvicos": "sauripélvico",
    "saurisquianos": "saurisquiano",
    "saurites": "saurite",
    "saurografias": "saurografia",
    "sauromorfa": "sauromorfo",
    "sauromorfas": "sauromorfo",
    "sauromorfos": "sauromorfo",
    "sauropterígios": "sauropterígio",
    "saururídeas": "saururídea",
    "saurófaga": "saurófago",
    "saurófagas": "saurófago",
    "saurófagos": "saurófago",
    "saurópodes": "saurópode",
    "saussurites": "saussurite",
    "sautores": "sautor",
    "sauvais": "sauval",
    "savacus": "savacu",
    "savanas": "savana",
    "savarins": "savarim",
    "saveira": "saveiro",
    "saveiras": "saveiro",
    "saveirinhos": "saveirinho",
    "saveiristas": "saveirista",
    "saveiros": "saveiro",
    "savelhas": "savelha",
    "savicas": "savica",
    "saxes": "sax",
    "saxifragácea": "saxifragáceo",
    "saxifragáceas": "saxifragáceo",
    "saxifragáceos": "saxifragáceo",
    "saxofones": "saxofone",
    "saxofonistas": "saxofonista",
    "saxona": "saxão",
    "saxonas": "saxão",
    "saxonazinha": "saxão",
    "saxonazinhas": "saxão",
    "saxonazita": "saxão",
    "saxonazitas": "saxão",
    "saxonianos": "saxoniano",
    "saxosa": "saxoso",
    "saxosas": "saxoso",
    "saxosos": "saxoso",
    "saxotrombas": "saxotromba",
    "saxotrompas": "saxotrompa",
    "saxotrompistas": "saxotrompista",
    "saxáveis": "saxável",
    "saxãozinho": "saxão",
    "saxãozito": "saxão",
    "saxícolas": "saxícola",
    "saxífraga": "saxífrago",
    "saxífragas": "saxífrago",
    "saxífragos": "saxífrago",
    "saxónia": "saxónio",
    "saxónias": "saxónio",
    "saxónica": "saxónico",
    "saxónicas": "saxónico",
    "saxónicos": "saxónico",
    "saxónios": "saxónio",
    "saxões": "saxão",
    "saxõezinhos": "saxão",
    "saxõezitos": "saxão",
    "sazeiros": "sazeiro",
    "sazoa": "sazoar",
    "sazoada": "sazoar",
    "sazoadas": "sazoar",
    "sazoado": "sazoar",
    "sazoados": "sazoar",
    "sazoai": "sazoar",
    "sazoais": "sazoar",
    "sazoam": "sazoar",
    "sazoamentos": "sazoamento",
    "sazoamo": "sazoar",
    "sazoamos": "sazoar",
    "sazoando": "sazoar",
    "sazoara": "sazoar",
    "sazoaram": "sazoar",
    "sazoaras": "sazoar",
    "sazoarde": "sazoar",
    "sazoardes": "sazoar",
    "sazoare": "sazoar",
    "sazoarei": "sazoar",
    "sazoareis": "sazoar",
    "sazoarem": "sazoar",
    "sazoaremos": "sazoar",
    "sazoares": "sazoar",
    "sazoaria": "sazoar",
    "sazoariam": "sazoar",
    "sazoarias": "sazoar",
    "sazoarmo": "sazoar",
    "sazoarmos": "sazoar",
    "sazoará": "sazoar",
    "sazoarás": "sazoar",
    "sazoarão": "sazoar",
    "sazoaríamos": "sazoar",
    "sazoaríeis": "sazoar",
    "sazoas": "sazoar",
    "sazoasse": "sazoar",
    "sazoassem": "sazoar",
    "sazoasses": "sazoar",
    "sazoaste": "sazoar",
    "sazoastes": "sazoar",
    "sazoava": "sazoar",
    "sazoavam": "sazoar",
    "sazoavas": "sazoar",
    "sazoe": "sazoar",
    "sazoei": "sazoar",
    "sazoeis": "sazoar",
    "sazoem": "sazoar",
    "sazoemo": "sazoar",
    "sazoemos": "sazoar",
    "sazoes": "sazoar",
    "sazona": "sazonar",
    "sazonada": "sazonar",
    "sazonadas": "sazonar",
    "sazonado": "sazonar",
    "sazonadora": "sazonador",
    "sazonadoras": "sazonador",
    "sazonadores": "sazonador",
    "sazonados": "sazonar",
    "sazonai": "sazonar",
    "sazonais": "sazonar",
    "sazonalidades": "sazonalidade",
    "sazonam": "sazonar",
    "sazonamentos": "sazonamento",
    "sazonamo": "sazonar",
    "sazonamos": "sazonar",
    "sazonando": "sazonar",
    "sazonara": "sazonar",
    "sazonaram": "sazonar",
    "sazonaras": "sazonar",
    "sazonarde": "sazonar",
    "sazonardes": "sazonar",
    "sazonare": "sazonar",
    "sazonarei": "sazonar",
    "sazonareis": "sazonar",
    "sazonarem": "sazonar",
    "sazonaremos": "sazonar",
    "sazonares": "sazonar",
    "sazonaria": "sazonar",
    "sazonariam": "sazonar",
    "sazonarias": "sazonar",
    "sazonarmo": "sazonar",
    "sazonarmos": "sazonar",
    "sazonará": "sazonar",
    "sazonarás": "sazonar",
    "sazonarão": "sazonar",
    "sazonaríamos": "sazonar",
    "sazonaríeis": "sazonar",
    "sazonas": "sazonar",
    "sazonasse": "sazonar",
    "sazonassem": "sazonar",
    "sazonasses": "sazonar",
    "sazonaste": "sazonar",
    "sazonastes": "sazonar",
    "sazonava": "sazonar",
    "sazonavam": "sazonar",
    "sazonavas": "sazonar",
    "sazonações": "sazonação",
    "sazone": "sazonar",
    "sazonei": "sazonar",
    "sazoneis": "sazonar",
    "sazonem": "sazonar",
    "sazonemo": "sazonar",
    "sazonemos": "sazonar",
    "sazones": "sazonar",
    "sazono": "sazonar",
    "sazonou": "sazonar",
    "sazoná": "sazonar",
    "sazonámo": "sazonar",
    "sazonámos": "sazonar",
    "sazonáramo": "sazonar",
    "sazonáramos": "sazonar",
    "sazonárei": "sazonar",
    "sazonáreis": "sazonar",
    "sazonásseis": "sazonar",
    "sazonássemos": "sazonar",
    "sazonávamo": "sazonar",
    "sazonávamos": "sazonar",
    "sazonávei": "sazonar",
    "sazonáveis": "sazonável",
    "sazoo": "sazoar",
    "sazoou": "sazoar",
    "sazos": "sazo",
    "sazoá": "sazoar",
    "sazoámo": "sazoar",
    "sazoámos": "sazoar",
    "sazoáramo": "sazoar",
    "sazoáramos": "sazoar",
    "sazoárei": "sazoar",
    "sazoáreis": "sazoar",
    "sazoásseis": "sazoar",
    "sazoássemos": "sazoar",
    "sazoávamo": "sazoar",
    "sazoávamos": "sazoar",
    "sazoávei": "sazoar",
    "sazoáveis": "sazoar",
    "sazus": "sazu",
    "sazões": "sazão",
    "saí": "sair",
    "saía": "sair",
    "saíam": "sair",
    "saíamo": "sair",
    "saíamos": "sair",
    "saías": "sair",
    "saída": "sair",
    "saídas": "sair",
    "saído": "sair",
    "saídos": "sair",
    "saíeis": "sair",
    "saímo": "sair",
    "saímos": "sair",
    "saíra": "sair",
    "saíram": "sair",
    "saíramo": "sair",
    "saíramos": "sair",
    "saíras": "sair",
    "saíreis": "sair",
    "saírem": "sair",
    "saíres": "sair",
    "saís": "sair",
    "saísse": "sair",
    "saísseis": "sair",
    "saíssem": "sair",
    "saíssemos": "sair",
    "saísses": "sair",
    "saíste": "sair",
    "saístes": "sair",
    "saúcos": "saúco",
    "saúda": "saudar",
    "saúdam": "saudar",
    "saúdas": "saudar",
    "saúde": "saudar",
    "saúdem": "saudar",
    "saúdes": "saúde",
    "saúdo": "saudar",
    "saúnas": "saúna",
    "saúvas": "saúva",
    "scaneres": "scaner",
    "scanneres": "scanner",
    "scheelites": "scheelite",
    "scooters": "scooter",
    "scores": "score",
    "searas": "seara",
    "seareira": "seareiro",
    "seareiras": "seareiro",
    "seareiros": "seareiro",
    "sebadas": "sebada",
    "sebas": "seba",
    "sebastianina": "sebastianino",
    "sebastianinas": "sebastianino",
    "sebastianinos": "sebastianino",
    "sebastianismos": "sebastianismo",
    "sebastianistas": "sebastianista",
    "sebastianopolitana": "sebastianopolitano",
    "sebastianopolitanas": "sebastianopolitano",
    "sebastianopolitanos": "sebastianopolitano",
    "sebastiões": "sebastião",
    "sebastos": "sebasto",
    "sebastros": "sebastro",
    "sebeira": "sebeiro",
    "sebeiras": "sebeiro",
    "sebeiros": "sebeiro",
    "sebenta": "sebento",
    "sebentarias": "sebentaria",
    "sebentas": "sebento",
    "sebentazinha": "sebento",
    "sebentazinhas": "sebento",
    "sebentazita": "sebento",
    "sebentazitas": "sebento",
    "sebenteira": "sebenteiro",
    "sebenteiras": "sebenteiro",
    "sebenteiros": "sebenteiro",
    "sebentices": "sebentice",
    "sebentinha": "sebento",
    "sebentinhas": "sebento",
    "sebentinho": "sebento",
    "sebentinhos": "sebento",
    "sebentita": "sebento",
    "sebentitas": "sebento",
    "sebentito": "sebento",
    "sebentitos": "sebento",
    "sebentos": "sebento",
    "sebentozinho": "sebento",
    "sebentozinhos": "sebento",
    "sebentozito": "sebento",
    "sebentozitos": "sebento",
    "sebentíssima": "sebento",
    "sebentíssimas": "sebento",
    "sebentíssimo": "sebento",
    "sebentíssimos": "sebento",
    "sebes": "sebe",
    "sebestas": "sebesta",
    "sebesteiras": "sebesteira",
    "sebesteiros": "sebesteiro",
    "sebinas": "sebina",
    "sebinho": "sebo",
    "sebinhos": "sebo",
    "sebinos": "sebino",
    "sebipiras": "sebipira",
    "sebito": "sebo",
    "sebitos": "sebo",
    "seborreias": "seborreia",
    "seborreica": "seborreico",
    "seborreicas": "seborreico",
    "seborreicos": "seborreico",
    "sebos": "sebo",
    "sebosa": "seboso",
    "sebosas": "seboso",
    "sebosos": "seboso",
    "sebácea": "sebáceo",
    "sebáceas": "sebáceo",
    "sebáceos": "sebáceo",
    "sebácica": "sebácico",
    "sebácicas": "sebácico",
    "sebácicos": "sebácico",
    "sebástica": "sebástico",
    "sebásticas": "sebástico",
    "sebásticos": "sebástico",
    "seca": "seco",
    "secada": "secar",
    "secadais": "secadal",
    "secadas": "secar",
    "secadeira": "secador",
    "secadeiras": "secador",
    "secadios": "secadio",
    "secado": "secar",
    "secadoiros": "secadoiro",
    "secadora": "secador",
    "secadoras": "secador",
    "secadores": "secador",
    "secados": "secar",
    "secadouros": "secadouro",
    "secagens": "secagem",
    "secai": "secar",
    "secais": "secar",
    "secam": "secar",
    "secamo": "secar",
    "secamos": "secar",
    "secando": "secar",
    "secantes": "secante",
    "secara": "secar",
    "secaram": "secar",
    "secaras": "secar",
    "secarde": "secar",
    "secardes": "secar",
    "secare": "secar",
    "secarei": "secar",
    "secareis": "secar",
    "secarem": "secar",
    "secaremos": "secar",
    "secares": "secar",
    "secaria": "secar",
    "secariam": "secar",
    "secarias": "secar",
    "secarmo": "secar",
    "secarmos": "secar",
    "secarona": "secarão",
    "secaronas": "secarão",
    "secará": "secar",
    "secarás": "secar",
    "secarão": "secar",
    "secaríamos": "secar",
    "secaríeis": "secar",
    "secarões": "secarão",
    "secas": "seco",
    "secasse": "secar",
    "secassem": "secar",
    "secasses": "secar",
    "secaste": "secar",
    "secastes": "secar",
    "secativa": "secativo",
    "secativas": "secativo",
    "secativos": "secativo",
    "secaturas": "secatura",
    "secatória": "secatório",
    "secatórias": "secatório",
    "secatórios": "secatório",
    "secava": "secar",
    "secavam": "secar",
    "secavas": "secar",
    "secações": "secação",
    "secciona": "seccionar",
    "seccionada": "seccionar",
    "seccionadas": "seccionar",
    "seccionado": "seccionar",
    "seccionados": "seccionar",
    "seccionai": "seccionar",
    "seccionais": "seccionar",
    "seccionam": "seccionar",
    "seccionamentos": "seccionamento",
    "seccionamo": "seccionar",
    "seccionamos": "seccionar",
    "seccionando": "seccionar",
    "seccionara": "seccionar",
    "seccionaram": "seccionar",
    "seccionaras": "seccionar",
    "seccionarde": "seccionar",
    "seccionardes": "seccionar",
    "seccionare": "seccionar",
    "seccionarei": "seccionar",
    "seccionareis": "seccionar",
    "seccionarem": "seccionar",
    "seccionaremos": "seccionar",
    "seccionares": "seccionar",
    "seccionaria": "seccionar",
    "seccionariam": "seccionar",
    "seccionarias": "seccionar",
    "seccionarmo": "seccionar",
    "seccionarmos": "seccionar",
    "seccionará": "seccionar",
    "seccionarás": "seccionar",
    "seccionarão": "seccionar",
    "seccionaríamos": "seccionar",
    "seccionaríeis": "seccionar",
    "seccionas": "seccionar",
    "seccionasse": "seccionar",
    "seccionassem": "seccionar",
    "seccionasses": "seccionar",
    "seccionaste": "seccionar",
    "seccionastes": "seccionar",
    "seccionava": "seccionar",
    "seccionavam": "seccionar",
    "seccionavas": "seccionar",
    "seccione": "seccionar",
    "seccionei": "seccionar",
    "seccioneis": "seccionar",
    "seccionem": "seccionar",
    "seccionemo": "seccionar",
    "seccionemos": "seccionar",
    "secciones": "seccionar",
    "secciono": "seccionar",
    "seccionou": "seccionar",
    "seccioná": "seccionar",
    "seccionámo": "seccionar",
    "seccionámos": "seccionar",
    "seccionáramo": "seccionar",
    "seccionáramos": "seccionar",
    "seccionárei": "seccionar",
    "seccionáreis": "seccionar",
    "seccionásseis": "seccionar",
    "seccionássemos": "seccionar",
    "seccionávamo": "seccionar",
    "seccionávamos": "seccionar",
    "seccionávei": "seccionar",
    "seccionáveis": "seccionável",
    "secernentes": "secernente",
    "secessos": "secesso",
    "secessões": "secessão",
    "sechuanas": "sechuana",
    "secia": "seciar",
    "seciada": "seciar",
    "seciadas": "seciar",
    "seciado": "seciar",
    "seciados": "seciar",
    "seciai": "seciar",
    "seciais": "seciar",
    "seciam": "seciar",
    "seciamo": "seciar",
    "seciamos": "seciar",
    "seciando": "seciar",
    "seciara": "seciar",
    "seciaram": "seciar",
    "seciaras": "seciar",
    "seciardes": "seciar",
    "seciarei": "seciar",
    "seciareis": "seciar",
    "seciarem": "seciar",
    "seciaremos": "seciar",
    "seciares": "seciar",
    "seciaria": "seciar",
    "seciariam": "seciar",
    "seciarias": "seciar",
    "seciarmo": "seciar",
    "seciarmos": "seciar",
    "seciará": "seciar",
    "seciarás": "seciar",
    "seciarão": "seciar",
    "seciaríamos": "seciar",
    "seciaríeis": "seciar",
    "secias": "seciar",
    "seciasse": "seciar",
    "seciassem": "seciar",
    "seciasses": "seciar",
    "seciaste": "seciar",
    "seciastes": "seciar",
    "seciava": "seciar",
    "seciavam": "seciar",
    "seciavas": "seciar",
    "secie": "seciar",
    "seciei": "seciar",
    "secieis": "seciar",
    "seciem": "seciar",
    "seciemo": "seciar",
    "seciemos": "seciar",
    "secies": "seciar",
    "secio": "seciar",
    "seciou": "seciar",
    "seciámo": "seciar",
    "seciámos": "seciar",
    "seciáramo": "seciar",
    "seciáramos": "seciar",
    "seciáreis": "seciar",
    "seciásseis": "seciar",
    "seciássemos": "seciar",
    "seciávamo": "seciar",
    "seciávamos": "seciar",
    "seciáveis": "seciar",
    "seco": "secar",
    "secos": "seco",
    "secou": "secar",
    "secreta": "secreto",
    "secretaria": "secretariar",
    "secretariada": "secretariar",
    "secretariadas": "secretariar",
    "secretariado": "secretariar",
    "secretariados": "secretariar",
    "secretariai": "secretariar",
    "secretariais": "secretariar",
    "secretariam": "secretariar",
    "secretariamo": "secretariar",
    "secretariamos": "secretariar",
    "secretariando": "secretariar",
    "secretariara": "secretariar",
    "secretariaram": "secretariar",
    "secretariaras": "secretariar",
    "secretariarde": "secretariar",
    "secretariardes": "secretariar",
    "secretariare": "secretariar",
    "secretariarei": "secretariar",
    "secretariareis": "secretariar",
    "secretariarem": "secretariar",
    "secretariaremos": "secretariar",
    "secretariares": "secretariar",
    "secretariaria": "secretariar",
    "secretariariam": "secretariar",
    "secretariarias": "secretariar",
    "secretariarmo": "secretariar",
    "secretariarmos": "secretariar",
    "secretariará": "secretariar",
    "secretariarás": "secretariar",
    "secretariarão": "secretariar",
    "secretariaríamos": "secretariar",
    "secretariaríeis": "secretariar",
    "secretarias": "secretariar",
    "secretariasse": "secretariar",
    "secretariassem": "secretariar",
    "secretariasses": "secretariar",
    "secretariaste": "secretariar",
    "secretariastes": "secretariar",
    "secretariava": "secretariar",
    "secretariavam": "secretariar",
    "secretariavas": "secretariar",
    "secretariazinha": "secretário",
    "secretariazinhas": "secretário",
    "secretariazita": "secretário",
    "secretariazitas": "secretário",
    "secretarie": "secretariar",
    "secretariei": "secretariar",
    "secretarieis": "secretariar",
    "secretariem": "secretariar",
    "secretariemo": "secretariar",
    "secretariemos": "secretariar",
    "secretaries": "secretariar",
    "secretario": "secretariar",
    "secretariou": "secretariar",
    "secretariozinho": "secretário",
    "secretariozinhos": "secretário",
    "secretariozito": "secretário",
    "secretariozitos": "secretário",
    "secretariá": "secretariar",
    "secretariámo": "secretariar",
    "secretariámos": "secretariar",
    "secretariáramo": "secretariar",
    "secretariáramos": "secretariar",
    "secretariárei": "secretariar",
    "secretariáreis": "secretariar",
    "secretariásseis": "secretariar",
    "secretariássemos": "secretariar",
    "secretariávamo": "secretariar",
    "secretariávamos": "secretariar",
    "secretariávei": "secretariar",
    "secretariáveis": "secretariar",
    "secretas": "secreto",
    "secretazinha": "secreto",
    "secretazinhas": "secreto",
    "secretazita": "secreto",
    "secretazitas": "secreto",
    "secretismos": "secretismo",
    "secretora": "secretor",
    "secretoras": "secretor",
    "secretores": "secretor",
    "secretos": "secreto",
    "secretozinho": "secreto",
    "secretozinhos": "secreto",
    "secretozito": "secreto",
    "secretozitos": "secreto",
    "secretária": "secretário",
    "secretárias": "secretário",
    "secretários": "secretário",
    "secretícia": "secretício",
    "secretícias": "secretício",
    "secretícios": "secretício",
    "secretíssima": "secreto",
    "secretíssimas": "secreto",
    "secretíssimo": "secreto",
    "secretíssimos": "secreto",
    "secretória": "secretório",
    "secretórias": "secretório",
    "secretórios": "secretório",
    "secreções": "secreção",
    "sectantes": "sectante",
    "sectarismos": "sectarismo",
    "sectaristas": "sectarista",
    "sectores": "sector",
    "sectoriais": "sectorial",
    "sectoriza": "sectorizar",
    "sectorizada": "sectorizar",
    "sectorizadas": "sectorizar",
    "sectorizado": "sectorizar",
    "sectorizados": "sectorizar",
    "sectorizai": "sectorizar",
    "sectorizais": "sectorizar",
    "sectorizam": "sectorizar",
    "sectorizamo": "sectorizar",
    "sectorizamos": "sectorizar",
    "sectorizando": "sectorizar",
    "sectorizara": "sectorizar",
    "sectorizaram": "sectorizar",
    "sectorizaras": "sectorizar",
    "sectorizarde": "sectorizar",
    "sectorizardes": "sectorizar",
    "sectorizare": "sectorizar",
    "sectorizarei": "sectorizar",
    "sectorizareis": "sectorizar",
    "sectorizarem": "sectorizar",
    "sectorizaremos": "sectorizar",
    "sectorizares": "sectorizar",
    "sectorizaria": "sectorizar",
    "sectorizariam": "sectorizar",
    "sectorizarias": "sectorizar",
    "sectorizarmo": "sectorizar",
    "sectorizarmos": "sectorizar",
    "sectorizará": "sectorizar",
    "sectorizarás": "sectorizar",
    "sectorizarão": "sectorizar",
    "sectorizaríamos": "sectorizar",
    "sectorizaríeis": "sectorizar",
    "sectorizas": "sectorizar",
    "sectorizasse": "sectorizar",
    "sectorizassem": "sectorizar",
    "sectorizasses": "sectorizar",
    "sectorizaste": "sectorizar",
    "sectorizastes": "sectorizar",
    "sectorizava": "sectorizar",
    "sectorizavam": "sectorizar",
    "sectorizavas": "sectorizar",
    "sectorizações": "sectorização",
    "sectorize": "sectorizar",
    "sectorizei": "sectorizar",
    "sectorizeis": "sectorizar",
    "sectorizem": "sectorizar",
    "sectorizemo": "sectorizar",
    "sectorizemos": "sectorizar",
    "sectorizes": "sectorizar",
    "sectorizo": "sectorizar",
    "sectorizou": "sectorizar",
    "sectorizá": "sectorizar",
    "sectorizámo": "sectorizar",
    "sectorizámos": "sectorizar",
    "sectorizáramo": "sectorizar",
    "sectorizáramos": "sectorizar",
    "sectorizárei": "sectorizar",
    "sectorizáreis": "sectorizar",
    "sectorizásseis": "sectorizar",
    "sectorizássemos": "sectorizar",
    "sectorizávamo": "sectorizar",
    "sectorizávamos": "sectorizar",
    "sectorizávei": "sectorizar",
    "sectorizáveis": "sectorizar",
    "secturas": "sectura",
    "sectária": "sectário",
    "sectárias": "sectário",
    "sectários": "sectário",
    "sectória": "sectório",
    "sectórias": "sectório",
    "sectórios": "sectório",
    "seculara": "secular",
    "secularas": "secular",
    "seculares": "secular",
    "secularidades": "secularidade",
    "secularismos": "secularismo",
    "secularistas": "secularista",
    "seculariza": "secularizar",
    "secularizada": "secularizar",
    "secularizadas": "secularizar",
    "secularizado": "secularizar",
    "secularizados": "secularizar",
    "secularizai": "secularizar",
    "secularizais": "secularizar",
    "secularizam": "secularizar",
    "secularizamo": "secularizar",
    "secularizamos": "secularizar",
    "secularizando": "secularizar",
    "secularizara": "secularizar",
    "secularizaram": "secularizar",
    "secularizaras": "secularizar",
    "secularizarde": "secularizar",
    "secularizardes": "secularizar",
    "secularizare": "secularizar",
    "secularizarei": "secularizar",
    "secularizareis": "secularizar",
    "secularizarem": "secularizar",
    "secularizaremos": "secularizar",
    "secularizares": "secularizar",
    "secularizaria": "secularizar",
    "secularizariam": "secularizar",
    "secularizarias": "secularizar",
    "secularizarmo": "secularizar",
    "secularizarmos": "secularizar",
    "secularizará": "secularizar",
    "secularizarás": "secularizar",
    "secularizarão": "secularizar",
    "secularizaríamos": "secularizar",
    "secularizaríeis": "secularizar",
    "secularizas": "secularizar",
    "secularizasse": "secularizar",
    "secularizassem": "secularizar",
    "secularizasses": "secularizar",
    "secularizaste": "secularizar",
    "secularizastes": "secularizar",
    "secularizava": "secularizar",
    "secularizavam": "secularizar",
    "secularizavas": "secularizar",
    "secularizações": "secularização",
    "secularize": "secularizar",
    "secularizei": "secularizar",
    "secularizeis": "secularizar",
    "secularizem": "secularizar",
    "secularizemo": "secularizar",
    "secularizemos": "secularizar",
    "secularizes": "secularizar",
    "secularizo": "secularizar",
    "secularizou": "secularizar",
    "secularizá": "secularizar",
    "secularizámo": "secularizar",
    "secularizámos": "secularizar",
    "secularizáramo": "secularizar",
    "secularizáramos": "secularizar",
    "secularizárei": "secularizar",
    "secularizáreis": "secularizar",
    "secularizásseis": "secularizar",
    "secularizássemos": "secularizar",
    "secularizávamo": "secularizar",
    "secularizávamos": "secularizar",
    "secularizávei": "secularizar",
    "secularizáveis": "secularizável",
    "seculos": "seculo",
    "secunda": "secundar",
    "secundada": "secundar",
    "secundadas": "secundar",
    "secundado": "secundar",
    "secundados": "secundar",
    "secundai": "secundar",
    "secundais": "secundar",
    "secundam": "secundar",
    "secundamo": "secundar",
    "secundamos": "secundar",
    "secundando": "secundar",
    "secundanos": "secundano",
    "secundara": "secundar",
    "secundaram": "secundar",
    "secundaras": "secundar",
    "secundarde": "secundar",
    "secundardes": "secundar",
    "secundare": "secundar",
    "secundarei": "secundar",
    "secundareis": "secundar",
    "secundarem": "secundar",
    "secundaremos": "secundar",
    "secundares": "secundar",
    "secundaria": "secundar",
    "secundariam": "secundar",
    "secundarias": "secundar",
    "secundarmo": "secundar",
    "secundarmos": "secundar",
    "secundará": "secundar",
    "secundarás": "secundar",
    "secundarão": "secundar",
    "secundaríamos": "secundar",
    "secundaríeis": "secundar",
    "secundaríssima": "secundário",
    "secundaríssimas": "secundário",
    "secundaríssimo": "secundário",
    "secundaríssimos": "secundário",
    "secundas": "secundar",
    "secundasse": "secundar",
    "secundassem": "secundar",
    "secundasses": "secundar",
    "secundaste": "secundar",
    "secundastes": "secundar",
    "secundava": "secundar",
    "secundavam": "secundar",
    "secundavas": "secundar",
    "secunde": "secundar",
    "secundei": "secundar",
    "secundeiras": "secundeira",
    "secundeis": "secundar",
    "secundem": "secundar",
    "secundemo": "secundar",
    "secundemos": "secundar",
    "secundes": "secundar",
    "secundinas": "secundina",
    "secundo": "secundar",
    "secundogénita": "secundogénito",
    "secundogénitas": "secundogénito",
    "secundogénitos": "secundogénito",
    "secundou": "secundar",
    "secundá": "secundar",
    "secundámo": "secundar",
    "secundámos": "secundar",
    "secundáramo": "secundar",
    "secundáramos": "secundar",
    "secundárei": "secundar",
    "secundáreis": "secundar",
    "secundária": "secundário",
    "secundárias": "secundário",
    "secundários": "secundário",
    "secundásseis": "secundar",
    "secundássemos": "secundar",
    "secundávamo": "secundar",
    "secundávamos": "secundar",
    "secundávei": "secundar",
    "secundáveis": "secundável",
    "secundípara": "secundíparo",
    "secundíparas": "secundíparo",
    "secundíparos": "secundíparo",
    "securas": "secura",
    "secures": "secure",
    "securiformes": "securiforme",
    "secá": "secar",
    "secámo": "secar",
    "secámos": "secar",
    "secáramo": "secar",
    "secáramos": "secar",
    "secárei": "secar",
    "secáreis": "secar",
    "secásseis": "secar",
    "secássemos": "secar",
    "secávamo": "secar",
    "secávamos": "secar",
    "secávei": "secar",
    "secáveis": "secar",
    "secâncias": "secância",
    "secções": "secção",
    "seda": "sedar",
    "sedaceira": "sedaceiro",
    "sedaceiras": "sedaceiro",
    "sedaceiros": "sedaceiro",
    "sedada": "sedar",
    "sedadas": "sedar",
    "sedado": "sedar",
    "sedados": "sedar",
    "sedai": "sedar",
    "sedais": "sedar",
    "sedalhas": "sedalha",
    "sedalinas": "sedalina",
    "sedam": "sedar",
    "sedamo": "sedar",
    "sedamos": "sedar",
    "sedando": "sedar",
    "sedantes": "sedante",
    "sedara": "sedar",
    "sedaram": "sedar",
    "sedaras": "sedar",
    "sedarde": "sedar",
    "sedardes": "sedar",
    "sedare": "sedar",
    "sedarei": "sedar",
    "sedareis": "sedar",
    "sedarem": "sedar",
    "sedaremos": "sedar",
    "sedares": "sedar",
    "sedaria": "sedar",
    "sedariam": "sedar",
    "sedarias": "sedar",
    "sedarmo": "sedar",
    "sedarmos": "sedar",
    "sedará": "sedar",
    "sedarás": "sedar",
    "sedarão": "sedar",
    "sedaríamos": "sedar",
    "sedaríeis": "sedar",
    "sedas": "sedar",
    "sedasse": "sedar",
    "sedassem": "sedar",
    "sedasses": "sedar",
    "sedaste": "sedar",
    "sedastes": "sedar",
    "sedativa": "sedativo",
    "sedativas": "sedativo",
    "sedativos": "sedativo",
    "sedava": "sedar",
    "sedavam": "sedar",
    "sedavas": "sedar",
    "sedaços": "sedaço",
    "sedações": "sedação",
    "sede": "ser",
    "sedeada": "sedear",
    "sedeadas": "sedear",
    "sedeado": "sedear",
    "sedeados": "sedear",
    "sedeai": "sedear",
    "sedeais": "sedear",
    "sedeamo": "sedear",
    "sedeamos": "sedear",
    "sedeando": "sedear",
    "sedeara": "sedear",
    "sedearam": "sedear",
    "sedearas": "sedear",
    "sedearde": "sedear",
    "sedeardes": "sedear",
    "sedeare": "sedear",
    "sedearei": "sedear",
    "sedeareis": "sedear",
    "sedearem": "sedear",
    "sedearemos": "sedear",
    "sedeares": "sedear",
    "sedearia": "sedear",
    "sedeariam": "sedear",
    "sedearias": "sedear",
    "sedearmo": "sedear",
    "sedearmos": "sedear",
    "sedeará": "sedear",
    "sedearás": "sedear",
    "sedearão": "sedear",
    "sedearíamos": "sedear",
    "sedearíeis": "sedear",
    "sedeasse": "sedear",
    "sedeassem": "sedear",
    "sedeasses": "sedear",
    "sedeaste": "sedear",
    "sedeastes": "sedear",
    "sedeava": "sedear",
    "sedeavam": "sedear",
    "sedeavas": "sedear",
    "sedeei": "sedear",
    "sedeeis": "sedear",
    "sedeemo": "sedear",
    "sedeemos": "sedear",
    "sedei": "sedar",
    "sedeia": "sedear",
    "sedeiam": "sedear",
    "sedeias": "sedear",
    "sedeie": "sedear",
    "sedeiem": "sedear",
    "sedeies": "sedear",
    "sedeio": "sedear",
    "sedeiros": "sedeiro",
    "sedeis": "sedar",
    "sedelas": "sedela",
    "sedem": "sedar",
    "sedemo": "sedar",
    "sedemos": "sedar",
    "sedenhos": "sedenho",
    "sedenta": "sedento",
    "sedentariazinha": "sedentário",
    "sedentariazinhas": "sedentário",
    "sedentariazita": "sedentário",
    "sedentariazitas": "sedentário",
    "sedentariedades": "sedentariedade",
    "sedentariozinho": "sedentário",
    "sedentariozinhos": "sedentário",
    "sedentariozito": "sedentário",
    "sedentariozitos": "sedentário",
    "sedentarismos": "sedentarismo",
    "sedentariza": "sedentarizar",
    "sedentarizada": "sedentarizar",
    "sedentarizadas": "sedentarizar",
    "sedentarizado": "sedentarizar",
    "sedentarizados": "sedentarizar",
    "sedentarizai": "sedentarizar",
    "sedentarizais": "sedentarizar",
    "sedentarizam": "sedentarizar",
    "sedentarizamo": "sedentarizar",
    "sedentarizamos": "sedentarizar",
    "sedentarizando": "sedentarizar",
    "sedentarizara": "sedentarizar",
    "sedentarizaram": "sedentarizar",
    "sedentarizaras": "sedentarizar",
    "sedentarizardes": "sedentarizar",
    "sedentarizarei": "sedentarizar",
    "sedentarizareis": "sedentarizar",
    "sedentarizarem": "sedentarizar",
    "sedentarizaremos": "sedentarizar",
    "sedentarizares": "sedentarizar",
    "sedentarizaria": "sedentarizar",
    "sedentarizariam": "sedentarizar",
    "sedentarizarias": "sedentarizar",
    "sedentarizarmo": "sedentarizar",
    "sedentarizarmos": "sedentarizar",
    "sedentarizará": "sedentarizar",
    "sedentarizarás": "sedentarizar",
    "sedentarizarão": "sedentarizar",
    "sedentarizaríamos": "sedentarizar",
    "sedentarizaríeis": "sedentarizar",
    "sedentarizas": "sedentarizar",
    "sedentarizasse": "sedentarizar",
    "sedentarizassem": "sedentarizar",
    "sedentarizasses": "sedentarizar",
    "sedentarizaste": "sedentarizar",
    "sedentarizastes": "sedentarizar",
    "sedentarizava": "sedentarizar",
    "sedentarizavam": "sedentarizar",
    "sedentarizavas": "sedentarizar",
    "sedentarizações": "sedentarização",
    "sedentarize": "sedentarizar",
    "sedentarizei": "sedentarizar",
    "sedentarizeis": "sedentarizar",
    "sedentarizem": "sedentarizar",
    "sedentarizemo": "sedentarizar",
    "sedentarizemos": "sedentarizar",
    "sedentarizes": "sedentarizar",
    "sedentarizo": "sedentarizar",
    "sedentarizou": "sedentarizar",
    "sedentarizámo": "sedentarizar",
    "sedentarizámos": "sedentarizar",
    "sedentarizáramo": "sedentarizar",
    "sedentarizáramos": "sedentarizar",
    "sedentarizáreis": "sedentarizar",
    "sedentarizásseis": "sedentarizar",
    "sedentarizássemos": "sedentarizar",
    "sedentarizávamo": "sedentarizar",
    "sedentarizávamos": "sedentarizar",
    "sedentarizáveis": "sedentarizável",
    "sedentas": "sedento",
    "sedentes": "sedente",
    "sedentos": "sedento",
    "sedentária": "sedentário",
    "sedentárias": "sedentário",
    "sedentários": "sedentário",
    "sedeou": "sedear",
    "sedes": "sede",
    "sedeá": "sedear",
    "sedeámo": "sedear",
    "sedeámos": "sedear",
    "sedeáramo": "sedear",
    "sedeáramos": "sedear",
    "sedeárei": "sedear",
    "sedeáreis": "sedear",
    "sedeásseis": "sedear",
    "sedeássemos": "sedear",
    "sedeávamo": "sedear",
    "sedeávamos": "sedear",
    "sedeávei": "sedear",
    "sedeáveis": "sedear",
    "sedeúda": "sedeúdo",
    "sedeúdas": "sedeúdo",
    "sedeúdos": "sedeúdo",
    "sedia": "sediar",
    "sediada": "sediar",
    "sediadas": "sediar",
    "sediado": "sediar",
    "sediados": "sediar",
    "sediai": "sediar",
    "sediais": "sediar",
    "sediam": "sediar",
    "sediamo": "sediar",
    "sediamos": "sediar",
    "sediando": "sediar",
    "sediara": "sediar",
    "sediaram": "sediar",
    "sediaras": "sediar",
    "sediarde": "sediar",
    "sediardes": "sediar",
    "sediare": "sediar",
    "sediarei": "sediar",
    "sediareis": "sediar",
    "sediarem": "sediar",
    "sediaremos": "sediar",
    "sediares": "sediar",
    "sediaria": "sediar",
    "sediariam": "sediar",
    "sediarias": "sediar",
    "sediarmo": "sediar",
    "sediarmos": "sediar",
    "sediará": "sediar",
    "sediarás": "sediar",
    "sediarão": "sediar",
    "sediaríamos": "sediar",
    "sediaríeis": "sediar",
    "sedias": "sediar",
    "sediasse": "sediar",
    "sediassem": "sediar",
    "sediasses": "sediar",
    "sediaste": "sediar",
    "sediastes": "sediar",
    "sediava": "sediar",
    "sediavam": "sediar",
    "sediavas": "sediar",
    "sediciosa": "sedicioso",
    "sediciosas": "sedicioso",
    "sediciosos": "sedicioso",
    "sedie": "sediar",
    "sediei": "sediar",
    "sedieis": "sediar",
    "sedielas": "sediela",
    "sediem": "sediar",
    "sediemo": "sediar",
    "sediemos": "sediar",
    "sedies": "sediar",
    "sedilúvios": "sedilúvio",
    "sedimenta": "sedimentar",
    "sedimentada": "sedimentar",
    "sedimentadas": "sedimentar",
    "sedimentado": "sedimentar",
    "sedimentadores": "sedimentador",
    "sedimentados": "sedimentar",
    "sedimentai": "sedimentar",
    "sedimentais": "sedimentar",
    "sedimentam": "sedimentar",
    "sedimentamo": "sedimentar",
    "sedimentamos": "sedimentar",
    "sedimentando": "sedimentar",
    "sedimentara": "sedimentar",
    "sedimentaram": "sedimentar",
    "sedimentaras": "sedimentar",
    "sedimentardes": "sedimentar",
    "sedimentarei": "sedimentar",
    "sedimentareis": "sedimentar",
    "sedimentarem": "sedimentar",
    "sedimentaremos": "sedimentar",
    "sedimentares": "sedimentar",
    "sedimentaria": "sedimentar",
    "sedimentariam": "sedimentar",
    "sedimentarias": "sedimentar",
    "sedimentarmo": "sedimentar",
    "sedimentarmos": "sedimentar",
    "sedimentará": "sedimentar",
    "sedimentarás": "sedimentar",
    "sedimentarão": "sedimentar",
    "sedimentaríamos": "sedimentar",
    "sedimentaríeis": "sedimentar",
    "sedimentas": "sedimentar",
    "sedimentasse": "sedimentar",
    "sedimentassem": "sedimentar",
    "sedimentasses": "sedimentar",
    "sedimentaste": "sedimentar",
    "sedimentastes": "sedimentar",
    "sedimentava": "sedimentar",
    "sedimentavam": "sedimentar",
    "sedimentavas": "sedimentar",
    "sedimentações": "sedimentação",
    "sedimente": "sedimentar",
    "sedimentei": "sedimentar",
    "sedimenteis": "sedimentar",
    "sedimentem": "sedimentar",
    "sedimentemo": "sedimentar",
    "sedimentemos": "sedimentar",
    "sedimentes": "sedimentar",
    "sedimento": "sedimentar",
    "sedimentologias": "sedimentologia",
    "sedimentometrias": "sedimentometria",
    "sedimentos": "sedimento",
    "sedimentosa": "sedimentoso",
    "sedimentosas": "sedimentoso",
    "sedimentosos": "sedimentoso",
    "sedimentou": "sedimentar",
    "sedimentámo": "sedimentar",
    "sedimentámos": "sedimentar",
    "sedimentáramo": "sedimentar",
    "sedimentáramos": "sedimentar",
    "sedimentáreis": "sedimentar",
    "sedimentária": "sedimentário",
    "sedimentárias": "sedimentário",
    "sedimentários": "sedimentário",
    "sedimentásseis": "sedimentar",
    "sedimentássemos": "sedimentar",
    "sedimentávamo": "sedimentar",
    "sedimentávamos": "sedimentar",
    "sedimentáveis": "sedimentar",
    "sedinha": "sede",
    "sedinhas": "sede",
    "sedio": "sediar",
    "sediou": "sediar",
    "sedita": "sede",
    "seditas": "sede",
    "sediá": "sediar",
    "sediámo": "sediar",
    "sediámos": "sediar",
    "sediáramo": "sediar",
    "sediáramos": "sediar",
    "sediárei": "sediar",
    "sediáreis": "sediar",
    "sediásseis": "sediar",
    "sediássemos": "sediar",
    "sediávamo": "sediar",
    "sediávamos": "sediar",
    "sediávei": "sediar",
    "sediáveis": "sediar",
    "sedições": "sedição",
    "sedo": "sedar",
    "sedonhos": "sedonho",
    "sedosa": "sedoso",
    "sedosas": "sedoso",
    "sedosos": "sedoso",
    "sedosíssima": "sedoso",
    "sedosíssimas": "sedoso",
    "sedosíssimo": "sedoso",
    "sedosíssimos": "sedoso",
    "sedou": "sedar",
    "sedutora": "sedutor",
    "sedutoras": "sedutor",
    "sedutores": "sedutor",
    "seduz": "seduzir",
    "seduza": "seduzir",
    "seduzais": "seduzir",
    "seduzam": "seduzir",
    "seduzamo": "seduzir",
    "seduzamos": "seduzir",
    "seduzas": "seduzir",
    "seduze": "seduzir",
    "seduzem": "seduzir",
    "seduzes": "seduzir",
    "seduzi": "seduzir",
    "seduzia": "seduzir",
    "seduziam": "seduzir",
    "seduzias": "seduzir",
    "seduzida": "seduzir",
    "seduzidas": "seduzir",
    "seduzido": "seduzir",
    "seduzidos": "seduzir",
    "seduzimo": "seduzir",
    "seduzimos": "seduzir",
    "seduzindo": "seduzir",
    "seduzira": "seduzir",
    "seduziram": "seduzir",
    "seduziras": "seduzir",
    "seduzirde": "seduzir",
    "seduzirdes": "seduzir",
    "seduzire": "seduzir",
    "seduzirei": "seduzir",
    "seduzireis": "seduzir",
    "seduzirem": "seduzir",
    "seduziremos": "seduzir",
    "seduzires": "seduzir",
    "seduziria": "seduzir",
    "seduziriam": "seduzir",
    "seduzirias": "seduzir",
    "seduzirmo": "seduzir",
    "seduzirmos": "seduzir",
    "seduzirá": "seduzir",
    "seduzirás": "seduzir",
    "seduzirão": "seduzir",
    "seduziríamos": "seduzir",
    "seduziríeis": "seduzir",
    "seduzis": "seduzir",
    "seduzisse": "seduzir",
    "seduzissem": "seduzir",
    "seduzisses": "seduzir",
    "seduziste": "seduzir",
    "seduzistes": "seduzir",
    "seduziu": "seduzir",
    "seduzo": "seduzir",
    "seduzíamo": "seduzir",
    "seduzíamos": "seduzir",
    "seduzíei": "seduzir",
    "seduzíeis": "seduzir",
    "seduzíramo": "seduzir",
    "seduzíramos": "seduzir",
    "seduzírei": "seduzir",
    "seduzíreis": "seduzir",
    "seduzísseis": "seduzir",
    "seduzíssemos": "seduzir",
    "seduzíveis": "seduzível",
    "seduções": "sedução",
    "sedá": "sedar",
    "sedámo": "sedar",
    "sedámos": "sedar",
    "sedáramo": "sedar",
    "sedáramos": "sedar",
    "sedárei": "sedar",
    "sedáreis": "sedar",
    "sedásseis": "sedar",
    "sedássemos": "sedar",
    "sedávamo": "sedar",
    "sedávamos": "sedar",
    "sedávei": "sedar",
    "sedáveis": "sedar",
    "sedãs": "sedã",
    "sedígera": "sedígero",
    "sedígeras": "sedígero",
    "sedígeros": "sedígero",
    "sefardins": "sefardim",
    "sefarditas": "sefardita",
    "sefias": "sefia",
    "sega": "segar",
    "segada": "segar",
    "segadas": "segar",
    "segadeira": "segador",
    "segadeiras": "segador",
    "segado": "segar",
    "segadoira": "segadoiro",
    "segadoiras": "segadoiro",
    "segadoiros": "segadoiro",
    "segadora": "segador",
    "segadoras": "segador",
    "segadores": "segador",
    "segados": "segar",
    "segadoura": "segadouro",
    "segadouras": "segadouro",
    "segadouros": "segadouro",
    "segaduras": "segadura",
    "segai": "segar",
    "segais": "segar",
    "segam": "segar",
    "segamo": "segar",
    "segamos": "segar",
    "segando": "segar",
    "segara": "segar",
    "segaram": "segar",
    "segaras": "segar",
    "segarde": "segar",
    "segardes": "segar",
    "segare": "segar",
    "segarei": "segar",
    "segareis": "segar",
    "segarem": "segar",
    "segaremos": "segar",
    "segares": "segar",
    "segaria": "segar",
    "segariam": "segar",
    "segarias": "segar",
    "segarmo": "segar",
    "segarmos": "segar",
    "segará": "segar",
    "segarás": "segar",
    "segarão": "segar",
    "segaríamos": "segar",
    "segaríeis": "segar",
    "segas": "segar",
    "segasse": "segar",
    "segassem": "segar",
    "segasses": "segar",
    "segaste": "segar",
    "segastes": "segar",
    "segava": "segar",
    "segavam": "segar",
    "segavas": "segar",
    "segeira": "segeiro",
    "segeiras": "segeiro",
    "segeiros": "segeiro",
    "seges": "sege",
    "segetais": "segetal",
    "segmenta": "segmentar",
    "segmentada": "segmentar",
    "segmentadas": "segmentar",
    "segmentado": "segmentar",
    "segmentados": "segmentar",
    "segmentai": "segmentar",
    "segmentais": "segmentar",
    "segmentam": "segmentar",
    "segmentamo": "segmentar",
    "segmentamos": "segmentar",
    "segmentando": "segmentar",
    "segmentara": "segmentar",
    "segmentaram": "segmentar",
    "segmentaras": "segmentar",
    "segmentarde": "segmentar",
    "segmentardes": "segmentar",
    "segmentare": "segmentar",
    "segmentarei": "segmentar",
    "segmentareis": "segmentar",
    "segmentarem": "segmentar",
    "segmentaremos": "segmentar",
    "segmentares": "segmentar",
    "segmentaria": "segmentar",
    "segmentariam": "segmentar",
    "segmentarias": "segmentar",
    "segmentarmo": "segmentar",
    "segmentarmos": "segmentar",
    "segmentará": "segmentar",
    "segmentarás": "segmentar",
    "segmentarão": "segmentar",
    "segmentaríamos": "segmentar",
    "segmentaríeis": "segmentar",
    "segmentas": "segmentar",
    "segmentasse": "segmentar",
    "segmentassem": "segmentar",
    "segmentasses": "segmentar",
    "segmentaste": "segmentar",
    "segmentastes": "segmentar",
    "segmentava": "segmentar",
    "segmentavam": "segmentar",
    "segmentavas": "segmentar",
    "segmentações": "segmentação",
    "segmente": "segmentar",
    "segmentei": "segmentar",
    "segmenteis": "segmentar",
    "segmentem": "segmentar",
    "segmentemo": "segmentar",
    "segmentemos": "segmentar",
    "segmentes": "segmentar",
    "segmento": "segmentar",
    "segmentos": "segmento",
    "segmentou": "segmentar",
    "segmentá": "segmentar",
    "segmentámo": "segmentar",
    "segmentámos": "segmentar",
    "segmentáramo": "segmentar",
    "segmentáramos": "segmentar",
    "segmentárei": "segmentar",
    "segmentáreis": "segmentar",
    "segmentária": "segmentário",
    "segmentárias": "segmentário",
    "segmentários": "segmentário",
    "segmentásseis": "segmentar",
    "segmentássemos": "segmentar",
    "segmentávamo": "segmentar",
    "segmentávamos": "segmentar",
    "segmentávei": "segmentar",
    "segmentáveis": "segmentável",
    "segnícias": "segnícia",
    "segnícies": "segnície",
    "sego": "segar",
    "segou": "segar",
    "segreda": "segredar",
    "segredada": "segredar",
    "segredadas": "segredar",
    "segredado": "segredar",
    "segredados": "segredar",
    "segredai": "segredar",
    "segredais": "segredar",
    "segredam": "segredar",
    "segredamo": "segredar",
    "segredamos": "segredar",
    "segredando": "segredar",
    "segredara": "segredar",
    "segredaram": "segredar",
    "segredaras": "segredar",
    "segredarde": "segredar",
    "segredardes": "segredar",
    "segredare": "segredar",
    "segredarei": "segredar",
    "segredareis": "segredar",
    "segredarem": "segredar",
    "segredaremos": "segredar",
    "segredares": "segredar",
    "segredaria": "segredar",
    "segredariam": "segredar",
    "segredarias": "segredar",
    "segredarmo": "segredar",
    "segredarmos": "segredar",
    "segredará": "segredar",
    "segredarás": "segredar",
    "segredarão": "segredar",
    "segredaríamos": "segredar",
    "segredaríeis": "segredar",
    "segredas": "segredar",
    "segredasse": "segredar",
    "segredassem": "segredar",
    "segredasses": "segredar",
    "segredaste": "segredar",
    "segredastes": "segredar",
    "segredava": "segredar",
    "segredavam": "segredar",
    "segredavas": "segredar",
    "segrede": "segredar",
    "segredei": "segredar",
    "segredeira": "segredeiro",
    "segredeiras": "segredeiro",
    "segredeiros": "segredeiro",
    "segredeis": "segredar",
    "segredem": "segredar",
    "segredemo": "segredar",
    "segredemos": "segredar",
    "segredes": "segredar",
    "segredinho": "segredo",
    "segredinhos": "segredo",
    "segredistas": "segredista",
    "segredito": "segredo",
    "segreditos": "segredo",
    "segredo": "segredar",
    "segredos": "segredo",
    "segredou": "segredar",
    "segredá": "segredar",
    "segredámo": "segredar",
    "segredámos": "segredar",
    "segredáramo": "segredar",
    "segredáramos": "segredar",
    "segredárei": "segredar",
    "segredáreis": "segredar",
    "segredásseis": "segredar",
    "segredássemos": "segredar",
    "segredávamo": "segredar",
    "segredávamos": "segredar",
    "segredávei": "segredar",
    "segredáveis": "segredar",
    "segrega": "segregar",
    "segregacionismos": "segregacionismo",
    "segregacionistas": "segregacionista",
    "segregada": "segregar",
    "segregadas": "segregar",
    "segregado": "segregar",
    "segregadora": "segregador",
    "segregadoras": "segregador",
    "segregadores": "segregador",
    "segregados": "segregar",
    "segregai": "segregar",
    "segregais": "segregar",
    "segregam": "segregar",
    "segregamo": "segregar",
    "segregamos": "segregar",
    "segregando": "segregar",
    "segregara": "segregar",
    "segregaram": "segregar",
    "segregaras": "segregar",
    "segregarde": "segregar",
    "segregardes": "segregar",
    "segregare": "segregar",
    "segregarei": "segregar",
    "segregareis": "segregar",
    "segregarem": "segregar",
    "segregaremos": "segregar",
    "segregares": "segregar",
    "segregaria": "segregar",
    "segregariam": "segregar",
    "segregarias": "segregar",
    "segregarmo": "segregar",
    "segregarmos": "segregar",
    "segregará": "segregar",
    "segregarás": "segregar",
    "segregarão": "segregar",
    "segregaríamos": "segregar",
    "segregaríeis": "segregar",
    "segregas": "segregar",
    "segregasse": "segregar",
    "segregassem": "segregar",
    "segregasses": "segregar",
    "segregaste": "segregar",
    "segregastes": "segregar",
    "segregativa": "segregativo",
    "segregativas": "segregativo",
    "segregativos": "segregativo",
    "segregatícia": "segregatício",
    "segregatícias": "segregatício",
    "segregatícios": "segregatício",
    "segregava": "segregar",
    "segregavam": "segregar",
    "segregavas": "segregar",
    "segregações": "segregação",
    "segrego": "segregar",
    "segregou": "segregar",
    "segregue": "segregar",
    "segreguei": "segregar",
    "segregueis": "segregar",
    "segreguem": "segregar",
    "segreguemo": "segregar",
    "segreguemos": "segregar",
    "segregues": "segregar",
    "segregá": "segregar",
    "segregámo": "segregar",
    "segregámos": "segregar",
    "segregáramo": "segregar",
    "segregáramos": "segregar",
    "segregárei": "segregar",
    "segregáreis": "segregar",
    "segregásseis": "segregar",
    "segregássemos": "segregar",
    "segregávamo": "segregar",
    "segregávamos": "segregar",
    "segregávei": "segregar",
    "segregáveis": "segregar",
    "segreis": "segrel",
    "segue": "seguir",
    "seguei": "segar",
    "segueis": "segar",
    "seguem": "seguir",
    "seguemo": "segar",
    "seguemos": "segar",
    "segues": "seguir",
    "segui": "seguir",
    "seguia": "seguir",
    "seguiam": "seguir",
    "seguias": "seguir",
    "seguida": "seguir",
    "seguidas": "seguir",
    "seguidilhas": "seguidilha",
    "seguidilheira": "seguidilheiro",
    "seguidilheiras": "seguidilheiro",
    "seguidilheiros": "seguidilheiro",
    "seguido": "seguir",
    "seguidora": "seguidor",
    "seguidoras": "seguidor",
    "seguidores": "seguidor",
    "seguidos": "seguir",
    "seguidíssima": "seguido",
    "seguidíssimas": "seguido",
    "seguidíssimo": "seguido",
    "seguidíssimos": "seguido",
    "seguimentos": "seguimento",
    "seguimo": "seguir",
    "seguimos": "seguir",
    "seguindo": "seguir",
    "seguintes": "seguinte",
    "seguira": "seguir",
    "seguiram": "seguir",
    "seguiras": "seguir",
    "seguirde": "seguir",
    "seguirdes": "seguir",
    "seguire": "seguir",
    "seguirei": "seguir",
    "seguireis": "seguir",
    "seguirem": "seguir",
    "seguiremos": "seguir",
    "seguires": "seguir",
    "seguiria": "seguir",
    "seguiriam": "seguir",
    "seguirias": "seguir",
    "seguirmo": "seguir",
    "seguirmos": "seguir",
    "seguirá": "seguir",
    "seguirás": "seguir",
    "seguirão": "seguir",
    "seguiríamos": "seguir",
    "seguiríeis": "seguir",
    "seguis": "seguir",
    "seguisse": "seguir",
    "seguissem": "seguir",
    "seguisses": "seguir",
    "seguiste": "seguir",
    "seguistes": "seguir",
    "seguiu": "seguir",
    "segunda": "segundo",
    "segundada": "segundar",
    "segundadas": "segundar",
    "segundado": "segundar",
    "segundados": "segundar",
    "segundai": "segundar",
    "segundais": "segundar",
    "segundam": "segundar",
    "segundamo": "segundar",
    "segundamos": "segundar",
    "segundando": "segundar",
    "segundanistas": "segundanista",
    "segundara": "segundar",
    "segundaram": "segundar",
    "segundaras": "segundar",
    "segundarde": "segundar",
    "segundardes": "segundar",
    "segundare": "segundar",
    "segundarei": "segundar",
    "segundareis": "segundar",
    "segundarem": "segundar",
    "segundaremos": "segundar",
    "segundares": "segundar",
    "segundaria": "segundar",
    "segundariam": "segundar",
    "segundarias": "segundar",
    "segundarmo": "segundar",
    "segundarmos": "segundar",
    "segundará": "segundar",
    "segundarás": "segundar",
    "segundarão": "segundar",
    "segundaríamos": "segundar",
    "segundaríeis": "segundar",
    "segundas": "segundo",
    "segundasse": "segundar",
    "segundassem": "segundar",
    "segundasses": "segundar",
    "segundaste": "segundar",
    "segundastes": "segundar",
    "segundava": "segundar",
    "segundavam": "segundar",
    "segundavas": "segundar",
    "segunde": "segundar",
    "segundei": "segundar",
    "segundeiras": "segundeira",
    "segundeis": "segundar",
    "segundem": "segundar",
    "segundemo": "segundar",
    "segundemos": "segundar",
    "segundes": "segundar",
    "segundinho": "segundo",
    "segundinhos": "segundo",
    "segundito": "segundo",
    "segunditos": "segundo",
    "segundo": "segundar",
    "segundogenituras": "segundogenitura",
    "segundogénita": "segundogénito",
    "segundogénitas": "segundogénito",
    "segundogénitos": "segundogénito",
    "segundos": "segundo",
    "segundou": "segundar",
    "segundá": "segundar",
    "segundámo": "segundar",
    "segundámos": "segundar",
    "segundáramo": "segundar",
    "segundáramos": "segundar",
    "segundárei": "segundar",
    "segundáreis": "segundar",
    "segundásseis": "segundar",
    "segundássemos": "segundar",
    "segundávamo": "segundar",
    "segundávamos": "segundar",
    "segundávei": "segundar",
    "segundáveis": "segundar",
    "segura": "seguro",
    "segurada": "segurar",
    "seguradas": "segurar",
    "segurado": "segurar",
    "seguradora": "segurador",
    "seguradoras": "seguradora",
    "seguradores": "segurador",
    "segurados": "segurar",
    "segurai": "segurar",
    "segurais": "segurar",
    "seguram": "segurar",
    "seguramo": "segurar",
    "seguramos": "segurar",
    "segurando": "segurar",
    "seguranças": "segurança",
    "segurara": "segurar",
    "seguraram": "segurar",
    "seguraras": "segurar",
    "segurarde": "segurar",
    "segurardes": "segurar",
    "segurare": "segurar",
    "segurarei": "segurar",
    "segurareis": "segurar",
    "segurarem": "segurar",
    "seguraremos": "segurar",
    "segurares": "segurar",
    "seguraria": "segurar",
    "segurariam": "segurar",
    "segurarias": "segurar",
    "segurarmo": "segurar",
    "segurarmos": "segurar",
    "segurará": "segurar",
    "segurarás": "segurar",
    "segurarão": "segurar",
    "seguraríamos": "segurar",
    "seguraríeis": "segurar",
    "seguras": "seguro",
    "segurasse": "segurar",
    "segurassem": "segurar",
    "segurasses": "segurar",
    "seguraste": "segurar",
    "segurastes": "segurar",
    "segurava": "segurar",
    "seguravam": "segurar",
    "seguravas": "segurar",
    "segurações": "seguração",
    "segure": "segurar",
    "segurei": "segurar",
    "segureis": "segurar",
    "segurelhas": "segurelha",
    "segurem": "segurar",
    "seguremo": "segurar",
    "seguremos": "segurar",
    "segures": "segure",
    "seguridades": "seguridade",
    "seguro": "segurar",
    "seguros": "seguro",
    "segurou": "segurar",
    "segurá": "segurar",
    "segurámo": "segurar",
    "segurámos": "segurar",
    "seguráramo": "segurar",
    "seguráramos": "segurar",
    "segurárei": "segurar",
    "seguráreis": "segurar",
    "segurásseis": "segurar",
    "segurássemos": "segurar",
    "segurávamo": "segurar",
    "segurávamos": "segurar",
    "segurávei": "segurar",
    "seguráveis": "segurar",
    "segurávona": "segurável",
    "segurávonas": "segurável",
    "segurávões": "segurável",
    "seguríssima": "seguro",
    "seguríssimas": "seguro",
    "seguríssimo": "seguro",
    "seguríssimos": "seguro",
    "seguíamo": "seguir",
    "seguíamos": "seguir",
    "seguíei": "seguir",
    "seguíeis": "seguir",
    "seguíramo": "seguir",
    "seguíramos": "seguir",
    "seguírei": "seguir",
    "seguíreis": "seguir",
    "seguísseis": "seguir",
    "seguíssemos": "seguir",
    "segá": "segar",
    "segámo": "segar",
    "segámos": "segar",
    "segáramo": "segar",
    "segáramos": "segar",
    "segárei": "segar",
    "segáreis": "segar",
    "segásseis": "segar",
    "segássemos": "segar",
    "segávamo": "segar",
    "segávamos": "segar",
    "segávei": "segar",
    "segáveis": "segar",
    "segões": "segão",
    "sei": "saber",
    "seiceiros": "seiceiro",
    "seices": "seice",
    "seichelenses": "seichelense",
    "seimas": "seima",
    "seios": "seio",
    "seiozinho": "seio",
    "seiozinhos": "seio",
    "seiozito": "seio",
    "seiozitos": "seio",
    "seiras": "seira",
    "seirões": "seirão",
    "seiscentas": "seiscentos",
    "seiscentismos": "seiscentismo",
    "seiscentistas": "seiscentista",
    "seiscentésima": "seiscentésimo",
    "seiscentésimas": "seiscentésimo",
    "seiscentésimos": "seiscentésimo",
    "seitas": "seita",
    "seitoiras": "seitoira",
    "seitoris": "seitoril",
    "seitouras": "seitoura",
    "seivas": "seiva",
    "seivosa": "seivoso",
    "seivosas": "seivoso",
    "seivosos": "seivoso",
    "seixagais": "seixagal",
    "seixais": "seixal",
    "seixas": "seixa",
    "seixebras": "seixebra",
    "seixoeiras": "seixoeira",
    "seixos": "seixo",
    "seixosa": "seixoso",
    "seixosas": "seixoso",
    "seixosos": "seixoso",
    "seiçais": "seiçal",
    "seiças": "seiça",
    "seja": "ser",
    "sejais": "ser",
    "sejam": "ser",
    "sejamo": "ser",
    "sejamos": "ser",
    "sejas": "ser",
    "sela": "selar",
    "selada": "selar",
    "seladas": "selar",
    "selado": "selar",
    "seladoiros": "seladoiro",
    "seladora": "selador",
    "seladoras": "selador",
    "seladores": "selador",
    "selados": "selar",
    "seladouros": "seladouro",
    "seladuras": "seladura",
    "seladíssima": "selado",
    "seladíssimas": "selado",
    "seladíssimo": "selado",
    "seladíssimos": "selado",
    "selagens": "selagem",
    "selaginelas": "selaginela",
    "selagineláceas": "selaginelácea",
    "selagotes": "selagote",
    "selagões": "selagão",
    "selai": "selar",
    "selais": "selar",
    "selam": "selar",
    "selamo": "selar",
    "selamos": "selar",
    "selando": "selar",
    "selara": "selar",
    "selaram": "selar",
    "selaras": "selar",
    "selarde": "selar",
    "selardes": "selar",
    "selare": "selar",
    "selarei": "selar",
    "selareis": "selar",
    "selarem": "selar",
    "selaremos": "selar",
    "selares": "selar",
    "selaria": "selar",
    "selariam": "selar",
    "selarias": "selaria",
    "selarmo": "selar",
    "selarmos": "selar",
    "selará": "selar",
    "selarás": "selar",
    "selarão": "selar",
    "selaríamos": "selar",
    "selaríeis": "selar",
    "selas": "selar",
    "selasse": "selar",
    "selassem": "selar",
    "selasses": "selar",
    "selaste": "selar",
    "selastes": "selar",
    "selava": "selar",
    "selavam": "selar",
    "selavas": "selar",
    "sele": "selar",
    "selecciona": "seleccionar",
    "seleccionada": "seleccionar",
    "seleccionadas": "seleccionar",
    "seleccionado": "seleccionar",
    "seleccionadora": "seleccionador",
    "seleccionadoras": "seleccionador",
    "seleccionadores": "seleccionador",
    "seleccionados": "seleccionar",
    "seleccionai": "seleccionar",
    "seleccionais": "seleccionar",
    "seleccionam": "seleccionar",
    "seleccionamentos": "seleccionamento",
    "seleccionamo": "seleccionar",
    "seleccionamos": "seleccionar",
    "seleccionando": "seleccionar",
    "seleccionara": "seleccionar",
    "seleccionaram": "seleccionar",
    "seleccionaras": "seleccionar",
    "seleccionarde": "seleccionar",
    "seleccionardes": "seleccionar",
    "seleccionare": "seleccionar",
    "seleccionarei": "seleccionar",
    "seleccionareis": "seleccionar",
    "seleccionarem": "seleccionar",
    "seleccionaremos": "seleccionar",
    "seleccionares": "seleccionar",
    "seleccionaria": "seleccionar",
    "seleccionariam": "seleccionar",
    "seleccionarias": "seleccionar",
    "seleccionarmo": "seleccionar",
    "seleccionarmos": "seleccionar",
    "seleccionará": "seleccionar",
    "seleccionarás": "seleccionar",
    "seleccionarão": "seleccionar",
    "seleccionaríamos": "seleccionar",
    "seleccionaríeis": "seleccionar",
    "seleccionas": "seleccionar",
    "seleccionasse": "seleccionar",
    "seleccionassem": "seleccionar",
    "seleccionasses": "seleccionar",
    "seleccionaste": "seleccionar",
    "seleccionastes": "seleccionar",
    "seleccionava": "seleccionar",
    "seleccionavam": "seleccionar",
    "seleccionavas": "seleccionar",
    "seleccione": "seleccionar",
    "seleccionei": "seleccionar",
    "seleccioneis": "seleccionar",
    "seleccionem": "seleccionar",
    "seleccionemo": "seleccionar",
    "seleccionemos": "seleccionar",
    "selecciones": "seleccionar",
    "seleccionismos": "seleccionismo",
    "selecciono": "seleccionar",
    "seleccionou": "seleccionar",
    "seleccioná": "seleccionar",
    "seleccionámo": "seleccionar",
    "seleccionámos": "seleccionar",
    "seleccionáramo": "seleccionar",
    "seleccionáramos": "seleccionar",
    "seleccionárei": "seleccionar",
    "seleccionáreis": "seleccionar",
    "seleccionásseis": "seleccionar",
    "seleccionássemos": "seleccionar",
    "seleccionávamo": "seleccionar",
    "seleccionávamos": "seleccionar",
    "seleccionávei": "seleccionar",
    "seleccionáveis": "seleccionar",
    "selecta": "selecto",
    "selectada": "selectar",
    "selectadas": "selectar",
    "selectado": "selectar",
    "selectados": "selectar",
    "selectai": "selectar",
    "selectais": "selectar",
    "selectam": "selectar",
    "selectamo": "selectar",
    "selectamos": "selectar",
    "selectando": "selectar",
    "selectara": "selectar",
    "selectaram": "selectar",
    "selectaras": "selectar",
    "selectarde": "selectar",
    "selectardes": "selectar",
    "selectare": "selectar",
    "selectarei": "selectar",
    "selectareis": "selectar",
    "selectarem": "selectar",
    "selectaremos": "selectar",
    "selectares": "selectar",
    "selectaria": "selectar",
    "selectariam": "selectar",
    "selectarias": "selectar",
    "selectarmo": "selectar",
    "selectarmos": "selectar",
    "selectará": "selectar",
    "selectarás": "selectar",
    "selectarão": "selectar",
    "selectaríamos": "selectar",
    "selectaríeis": "selectar",
    "selectas": "selecto",
    "selectasse": "selectar",
    "selectassem": "selectar",
    "selectasses": "selectar",
    "selectaste": "selectar",
    "selectastes": "selectar",
    "selectava": "selectar",
    "selectavam": "selectar",
    "selectavas": "selectar",
    "selecte": "selectar",
    "selectei": "selectar",
    "selecteis": "selectar",
    "selectem": "selectar",
    "selectemo": "selectar",
    "selectemos": "selectar",
    "selectes": "selectar",
    "selectiva": "selectivo",
    "selectivas": "selectivo",
    "selectividades": "selectividade",
    "selectivos": "selectivo",
    "selecto": "selectar",
    "selectora": "selector",
    "selectoras": "selector",
    "selectores": "selector",
    "selectos": "selecto",
    "selectou": "selectar",
    "selectá": "selectar",
    "selectámo": "selectar",
    "selectámos": "selectar",
    "selectáramo": "selectar",
    "selectáramos": "selectar",
    "selectárei": "selectar",
    "selectáreis": "selectar",
    "selectásseis": "selectar",
    "selectássemos": "selectar",
    "selectávamo": "selectar",
    "selectávamos": "selectar",
    "selectávei": "selectar",
    "selectáveis": "selectar",
    "selecções": "selecção",
    "selei": "selar",
    "seleiros": "seleiro",
    "seleis": "selar",
    "selem": "selar",
    "selemo": "selar",
    "selemos": "selar",
    "selenatos": "selenato",
    "seleniosa": "selenioso",
    "seleniosas": "selenioso",
    "seleniosos": "selenioso",
    "selenitas": "selenita",
    "selenites": "selenite",
    "selenitosa": "selenitoso",
    "selenitosas": "selenitoso",
    "selenitosos": "selenitoso",
    "selenodontes": "selenodonte",
    "selenografias": "selenografia",
    "selenográfica": "selenográfico",
    "selenográficas": "selenográfico",
    "selenográficos": "selenográfico",
    "selenologias": "selenologia",
    "selenoses": "selenose",
    "selenífera": "selenífero",
    "seleníferas": "selenífero",
    "seleníferos": "selenífero",
    "selenógrafos": "selenógrafo",
    "selenólogos": "selenólogo",
    "selenóstatos": "selenóstato",
    "seles": "selar",
    "selhas": "selha",
    "selindras": "selindra",
    "selinho": "selo",
    "selinhos": "selo",
    "selins": "selim",
    "selito": "selo",
    "selitos": "selo",
    "selo": "selar",
    "selos": "selo",
    "selotes": "selote",
    "selou": "selar",
    "selvagens": "selvagem",
    "selvagenzinha": "selvagem",
    "selvagenzinhas": "selvagem",
    "selvagenzinho": "selvagem",
    "selvagenzinhos": "selvagem",
    "selvagenzita": "selvagem",
    "selvagenzitas": "selvagem",
    "selvagenzito": "selvagem",
    "selvagenzitos": "selvagem",
    "selvagerias": "selvageria",
    "selvagina": "selvagino",
    "selvaginas": "selvagino",
    "selvaginos": "selvagino",
    "selvagismos": "selvagismo",
    "selvagínea": "selvagíneo",
    "selvagíneas": "selvagíneo",
    "selvagíneos": "selvagíneo",
    "selvajarias": "selvajaria",
    "selvas": "selva",
    "selvosa": "selvoso",
    "selvosas": "selvoso",
    "selvosos": "selvoso",
    "selvática": "selvático",
    "selváticas": "selvático",
    "selváticos": "selvático",
    "selvícolas": "selvícola",
    "selá": "selar",
    "selámo": "selar",
    "selámos": "selar",
    "seláquia": "seláquio",
    "seláquias": "seláquio",
    "seláquios": "seláquio",
    "seláramo": "selar",
    "seláramos": "selar",
    "selárei": "selar",
    "seláreis": "selar",
    "selásseis": "selar",
    "selássemos": "selar",
    "selávamo": "selar",
    "selávamos": "selar",
    "selávei": "selar",
    "seláveis": "selar",
    "selénica": "selénico",
    "selénicas": "selénico",
    "selénicos": "selénico",
    "selénios": "selénio",
    "selêucidas": "selêucida",
    "semafórica": "semafórico",
    "semafóricas": "semafórico",
    "semafóricos": "semafórico",
    "semanadas": "semanada",
    "semanais": "semanal",
    "semanas": "semana",
    "semaninha": "semana",
    "semaninhas": "semana",
    "semanita": "semana",
    "semanitas": "semana",
    "semantemas": "semantema",
    "semanticistas": "semanticista",
    "semanária": "semanário",
    "semanárias": "semanário",
    "semanários": "semanário",
    "semasiologias": "semasiologia",
    "semasiológica": "semasiológico",
    "semasiológicas": "semasiológico",
    "semasiológicos": "semasiológico",
    "sematologias": "sematologia",
    "sematológica": "sematológico",
    "sematológicas": "sematológico",
    "sematológicos": "sematológico",
    "sembas": "semba",
    "semblantes": "semblante",
    "semeada": "semear",
    "semeadas": "semear",
    "semeado": "semear",
    "semeadoira": "semeadoiro",
    "semeadoiras": "semeadoiro",
    "semeadoiros": "semeadoiro",
    "semeadora": "semeador",
    "semeadoras": "semeador",
    "semeadores": "semeador",
    "semeados": "semear",
    "semeadoura": "semeadouro",
    "semeadouras": "semeadouro",
    "semeadouros": "semeadouro",
    "semeaduras": "semeadura",
    "semeai": "semear",
    "semeais": "semear",
    "semeamo": "semear",
    "semeamos": "semear",
    "semeando": "semear",
    "semeara": "semear",
    "semearam": "semear",
    "semearas": "semear",
    "semeardes": "semear",
    "semearei": "semear",
    "semeareis": "semear",
    "semearem": "semear",
    "semearemos": "semear",
    "semeares": "semear",
    "semearia": "semear",
    "semeariam": "semear",
    "semearias": "semear",
    "semearmo": "semear",
    "semearmos": "semear",
    "semeará": "semear",
    "semearás": "semear",
    "semearão": "semear",
    "semearíamos": "semear",
    "semearíeis": "semear",
    "semeasse": "semear",
    "semeassem": "semear",
    "semeasses": "semear",
    "semeaste": "semear",
    "semeastes": "semear",
    "semeava": "semear",
    "semeavam": "semear",
    "semeavas": "semear",
    "semeações": "semeação",
    "semeei": "semear",
    "semeeis": "semear",
    "semeemo": "semear",
    "semeemos": "semear",
    "semeia": "semear",
    "semeiam": "semear",
    "semeias": "semear",
    "semeie": "semear",
    "semeiem": "semear",
    "semeies": "semear",
    "semeio": "semear",
    "semelha": "semelhar",
    "semelhada": "semelhar",
    "semelhadas": "semelhar",
    "semelhado": "semelhar",
    "semelhados": "semelhar",
    "semelhai": "semelhar",
    "semelhais": "semelhar",
    "semelham": "semelhar",
    "semelhamo": "semelhar",
    "semelhamos": "semelhar",
    "semelhando": "semelhar",
    "semelhantes": "semelhante",
    "semelhantezinha": "semelhante",
    "semelhantezinhas": "semelhante",
    "semelhantezinho": "semelhante",
    "semelhantezinhos": "semelhante",
    "semelhantezita": "semelhante",
    "semelhantezitas": "semelhante",
    "semelhantezito": "semelhante",
    "semelhantezitos": "semelhante",
    "semelhanças": "semelhança",
    "semelhara": "semelhar",
    "semelharam": "semelhar",
    "semelharas": "semelhar",
    "semelharde": "semelhar",
    "semelhardes": "semelhar",
    "semelhare": "semelhar",
    "semelharei": "semelhar",
    "semelhareis": "semelhar",
    "semelharem": "semelhar",
    "semelharemos": "semelhar",
    "semelhares": "semelhar",
    "semelharia": "semelhar",
    "semelhariam": "semelhar",
    "semelharias": "semelhar",
    "semelharmo": "semelhar",
    "semelharmos": "semelhar",
    "semelhará": "semelhar",
    "semelharás": "semelhar",
    "semelharão": "semelhar",
    "semelharíamos": "semelhar",
    "semelharíeis": "semelhar",
    "semelhas": "semelhar",
    "semelhasse": "semelhar",
    "semelhassem": "semelhar",
    "semelhasses": "semelhar",
    "semelhaste": "semelhar",
    "semelhastes": "semelhar",
    "semelhava": "semelhar",
    "semelhavam": "semelhar",
    "semelhavas": "semelhar",
    "semelhe": "semelhar",
    "semelhei": "semelhar",
    "semelheis": "semelhar",
    "semelhem": "semelhar",
    "semelhemo": "semelhar",
    "semelhemos": "semelhar",
    "semelhes": "semelhar",
    "semelho": "semelhar",
    "semelhou": "semelhar",
    "semelhá": "semelhar",
    "semelhámo": "semelhar",
    "semelhámos": "semelhar",
    "semelháramo": "semelhar",
    "semelháramos": "semelhar",
    "semelhárei": "semelhar",
    "semelháreis": "semelhar",
    "semelhásseis": "semelhar",
    "semelhássemos": "semelhar",
    "semelhávamo": "semelhar",
    "semelhávamos": "semelhar",
    "semelhávei": "semelhar",
    "semelháveis": "semelhável",
    "sementa": "sementar",
    "sementada": "sementar",
    "sementadas": "sementar",
    "sementado": "sementar",
    "sementados": "sementar",
    "sementai": "sementar",
    "sementais": "sementar",
    "sementalhas": "sementalha",
    "sementam": "sementar",
    "sementamo": "sementar",
    "sementamos": "sementar",
    "sementando": "sementar",
    "sementara": "sementar",
    "sementaram": "sementar",
    "sementaras": "sementar",
    "sementarde": "sementar",
    "sementardes": "sementar",
    "sementare": "sementar",
    "sementarei": "sementar",
    "sementareis": "sementar",
    "sementarem": "sementar",
    "sementaremos": "sementar",
    "sementares": "sementar",
    "sementaria": "sementar",
    "sementariam": "sementar",
    "sementarias": "sementar",
    "sementarmo": "sementar",
    "sementarmos": "sementar",
    "sementará": "sementar",
    "sementarás": "sementar",
    "sementarão": "sementar",
    "sementaríamos": "sementar",
    "sementaríeis": "sementar",
    "sementas": "sementar",
    "sementasse": "sementar",
    "sementassem": "sementar",
    "sementasses": "sementar",
    "sementaste": "sementar",
    "sementastes": "sementar",
    "sementava": "sementar",
    "sementavam": "sementar",
    "sementavas": "sementar",
    "semente": "sementar",
    "sementei": "sementar",
    "sementeira": "sementeiro",
    "sementeiras": "sementeiro",
    "sementeiros": "sementeiro",
    "sementeis": "sementar",
    "sementem": "sementar",
    "sementemo": "sementar",
    "sementemos": "sementar",
    "sementes": "semente",
    "sementilhas": "sementilha",
    "sementinha": "semente",
    "sementinhas": "semente",
    "sementios": "sementio",
    "sementita": "semente",
    "sementitas": "semente",
    "semento": "sementar",
    "sementou": "sementar",
    "sementá": "sementar",
    "sementámo": "sementar",
    "sementámos": "sementar",
    "sementáramo": "sementar",
    "sementáramos": "sementar",
    "sementárei": "sementar",
    "sementáreis": "sementar",
    "sementásseis": "sementar",
    "sementássemos": "sementar",
    "sementávamo": "sementar",
    "sementávamos": "sementar",
    "sementávei": "sementar",
    "sementáveis": "sementar",
    "semeou": "semear",
    "semestrais": "semestral",
    "semestralidades": "semestralidade",
    "semestreira": "semestreiro",
    "semestreiras": "semestreiro",
    "semestreiros": "semestreiro",
    "semestres": "semestre",
    "semeámo": "semear",
    "semeámos": "semear",
    "semeáramo": "semear",
    "semeáramos": "semear",
    "semeáreis": "semear",
    "semeásseis": "semear",
    "semeássemos": "semear",
    "semeávamo": "semear",
    "semeávamos": "semear",
    "semeáveis": "semeável",
    "semeóforos": "semeóforo",
    "semiaberta": "semiaberto",
    "semiabertas": "semiaberto",
    "semiabertos": "semiaberto",
    "semiacerba": "semiacerbo",
    "semiacerbas": "semiacerbo",
    "semiacerbos": "semiacerbo",
    "semialmas": "semialma",
    "semianalfabetica": "semianalfabetico",
    "semianalfabeticas": "semianalfabetico",
    "semianalfabeticos": "semianalfabetico",
    "semianuais": "semianual",
    "semianulares": "semianular",
    "semibreves": "semibreve",
    "semibárbara": "semibárbaro",
    "semibárbaras": "semibárbaro",
    "semibárbaros": "semibárbaro",
    "semicadáveis": "semicadável",
    "semicapra": "semicapro",
    "semicapras": "semicapro",
    "semicapros": "semicapro",
    "semicerra": "semicerrar",
    "semicerrada": "semicerrar",
    "semicerradas": "semicerrar",
    "semicerrado": "semicerrar",
    "semicerrados": "semicerrar",
    "semicerrai": "semicerrar",
    "semicerrais": "semicerrar",
    "semicerram": "semicerrar",
    "semicerramo": "semicerrar",
    "semicerramos": "semicerrar",
    "semicerrando": "semicerrar",
    "semicerrara": "semicerrar",
    "semicerraram": "semicerrar",
    "semicerraras": "semicerrar",
    "semicerrarde": "semicerrar",
    "semicerrardes": "semicerrar",
    "semicerrare": "semicerrar",
    "semicerrarei": "semicerrar",
    "semicerrareis": "semicerrar",
    "semicerrarem": "semicerrar",
    "semicerraremos": "semicerrar",
    "semicerrares": "semicerrar",
    "semicerraria": "semicerrar",
    "semicerrariam": "semicerrar",
    "semicerrarias": "semicerrar",
    "semicerrarmo": "semicerrar",
    "semicerrarmos": "semicerrar",
    "semicerrará": "semicerrar",
    "semicerrarás": "semicerrar",
    "semicerrarão": "semicerrar",
    "semicerraríamos": "semicerrar",
    "semicerraríeis": "semicerrar",
    "semicerras": "semicerrar",
    "semicerrasse": "semicerrar",
    "semicerrassem": "semicerrar",
    "semicerrasses": "semicerrar",
    "semicerraste": "semicerrar",
    "semicerrastes": "semicerrar",
    "semicerrava": "semicerrar",
    "semicerravam": "semicerrar",
    "semicerravas": "semicerrar",
    "semicerre": "semicerrar",
    "semicerrei": "semicerrar",
    "semicerreis": "semicerrar",
    "semicerrem": "semicerrar",
    "semicerremo": "semicerrar",
    "semicerremos": "semicerrar",
    "semicerres": "semicerrar",
    "semicerro": "semicerrar",
    "semicerrou": "semicerrar",
    "semicerrá": "semicerrar",
    "semicerrámo": "semicerrar",
    "semicerrámos": "semicerrar",
    "semicerráramo": "semicerrar",
    "semicerráramos": "semicerrar",
    "semicerrárei": "semicerrar",
    "semicerráreis": "semicerrar",
    "semicerrásseis": "semicerrar",
    "semicerrássemos": "semicerrar",
    "semicerrávamo": "semicerrar",
    "semicerrávamos": "semicerrar",
    "semicerrávei": "semicerrar",
    "semicerráveis": "semicerrar",
    "semichas": "semicha",
    "semicilindros": "semicilindro",
    "semicilíndrica": "semicilíndrico",
    "semicilíndricas": "semicilíndrico",
    "semicilíndricos": "semicilíndrico",
    "semicirculares": "semicircular",
    "semicircunferências": "semicircunferência",
    "semicivilizada": "semicivilizado",
    "semicivilizadas": "semicivilizado",
    "semicivilizados": "semicivilizado",
    "semiclandestina": "semiclandestino",
    "semiclandestinas": "semiclandestino",
    "semiclandestinos": "semiclandestino",
    "semiclausuras": "semiclausura",
    "semicolcheias": "semicolcheia",
    "semicondutora": "semicondutor",
    "semicondutoras": "semicondutor",
    "semicondutores": "semicondutor",
    "semiconscientes": "semiconsciente",
    "semiconsoantes": "semiconsoante",
    "semicírculos": "semicírculo",
    "semicúpios": "semicúpio",
    "semidefunta": "semidefunto",
    "semidefuntas": "semidefunto",
    "semidefuntos": "semidefunto",
    "semideiros": "semideiro",
    "semidesnatada": "semidesnatado",
    "semidesnatadas": "semidesnatado",
    "semidesnatados": "semidesnatado",
    "semidestruídos": "semidestruído",
    "semidesértica": "semidesértico",
    "semidesérticas": "semidesértico",
    "semidesérticos": "semidesértico",
    "semideusa": "semideus",
    "semideusas": "semideus",
    "semideuses": "semideus",
    "semiditongos": "semiditongo",
    "semidivina": "semidivino",
    "semidivinas": "semidivino",
    "semidivindades": "semidivindade",
    "semidivinos": "semidivino",
    "semidiáfana": "semidiáfano",
    "semidiáfanas": "semidiáfano",
    "semidiáfanos": "semidiáfano",
    "semidobrada": "semidobrado",
    "semidobradas": "semidobrado",
    "semidobrados": "semidobrado",
    "semidoida": "semidoido",
    "semidoidas": "semidoido",
    "semidoidazinha": "semidoido",
    "semidoidazinhas": "semidoido",
    "semidoidazita": "semidoido",
    "semidoidazitas": "semidoido",
    "semidoidinha": "semidoido",
    "semidoidinhas": "semidoido",
    "semidoidinho": "semidoido",
    "semidoidinhos": "semidoido",
    "semidoidita": "semidoido",
    "semidoiditas": "semidoido",
    "semidoidito": "semidoido",
    "semidoiditos": "semidoido",
    "semidoidos": "semidoido",
    "semidoidozinho": "semidoido",
    "semidoidozinhos": "semidoido",
    "semidoidozito": "semidoido",
    "semidoidozitos": "semidoido",
    "semieixos": "semieixo",
    "semienfastiada": "semienfastiado",
    "semienfastiadas": "semienfastiado",
    "semienfastiados": "semienfastiado",
    "semienterrada": "semienterrado",
    "semienterradas": "semienterrado",
    "semienterrados": "semienterrado",
    "semierudita": "semierudito",
    "semieruditas": "semierudito",
    "semieruditos": "semierudito",
    "semiesferas": "semiesfera",
    "semiesferóides": "semiesferóide",
    "semiesférica": "semiesférico",
    "semiesféricas": "semiesférico",
    "semiesféricos": "semiesférico",
    "semifabulosa": "semifabuloso",
    "semifabulosas": "semifabuloso",
    "semifabulosos": "semifabuloso",
    "semifendida": "semifendido",
    "semifendidas": "semifendido",
    "semifendidos": "semifendido",
    "semifinais": "semifinal",
    "semifinalistas": "semifinalista",
    "semifluida": "semifluido",
    "semifluidas": "semifluido",
    "semifluidos": "semifluido",
    "semiforçada": "semiforçado",
    "semiforçadas": "semiforçado",
    "semiforçados": "semiforçado",
    "semifusas": "semifusa",
    "semigasta": "semigasto",
    "semigastas": "semigasto",
    "semigastos": "semigasto",
    "semigótica": "semigótico",
    "semigóticas": "semigótico",
    "semigóticos": "semigótico",
    "semilouca": "semilouco",
    "semiloucas": "semilouco",
    "semiloucos": "semilouco",
    "semilunares": "semilunar",
    "semilunações": "semilunação",
    "semilunática": "semilunático",
    "semilunáticas": "semilunático",
    "semilunáticos": "semilunático",
    "semilíquida": "semilíquido",
    "semilíquidas": "semilíquido",
    "semilíquidos": "semilíquido",
    "semilúnia": "semilúnio",
    "semilúnias": "semilúnio",
    "semilúnios": "semilúnio",
    "semimetais": "semimetal",
    "semimilionária": "semimilionário",
    "semimilionárias": "semimilionário",
    "semimilionários": "semimilionário",
    "semimorta": "semimorto",
    "semimortas": "semimorto",
    "semimortos": "semimorto",
    "seminais": "seminal",
    "seminaristas": "seminarista",
    "seminarística": "seminarístico",
    "seminarísticas": "seminarístico",
    "seminarísticos": "seminarístico",
    "seminações": "seminação",
    "seminua": "seminu",
    "seminuas": "seminu",
    "seminuazinha": "seminu",
    "seminuazinhas": "seminu",
    "seminuazita": "seminu",
    "seminuazitas": "seminu",
    "seminudezes": "seminudez",
    "seminuinha": "seminu",
    "seminuinhas": "seminu",
    "seminuinho": "seminu",
    "seminuinhos": "seminu",
    "seminuita": "seminu",
    "seminuitas": "seminu",
    "seminuito": "seminu",
    "seminuitos": "seminu",
    "seminus": "seminu",
    "seminuzinha": "seminu",
    "seminuzinhas": "seminu",
    "seminuzinho": "seminu",
    "seminuzinhos": "seminu",
    "seminuzita": "seminu",
    "seminuzitas": "seminu",
    "seminuzito": "seminu",
    "seminuzitos": "seminu",
    "seminários": "seminário",
    "seminífera": "seminífero",
    "seminíferas": "seminífero",
    "seminíferos": "seminífero",
    "seminípara": "seminíparo",
    "seminíparas": "seminíparo",
    "seminíparos": "seminíparo",
    "seminós": "seminó",
    "semioficiais": "semioficial",
    "semioficiosa": "semioficioso",
    "semioficiosas": "semioficioso",
    "semioficiosos": "semioficioso",
    "semiografias": "semiografia",
    "semiologias": "semiologia",
    "semiológica": "semiológico",
    "semiológicas": "semiológico",
    "semiológicos": "semiológico",
    "semiparentes": "semiparente",
    "semipedais": "semipedal",
    "semipenetrações": "semipenetração",
    "semiperiférica": "semiperiférico",
    "semiperiféricas": "semiperiférico",
    "semiperiféricos": "semiperiférico",
    "semipermeáveis": "semipermeável",
    "semiplanos": "semiplano",
    "semiplena": "semipleno",
    "semiplenas": "semipleno",
    "semiplenos": "semipleno",
    "semiprofissionais": "semiprofissional",
    "semiprofissionalismos": "semiprofissionalismo",
    "semiprovas": "semiprova",
    "semiputa": "semiputo",
    "semiputas": "semiputo",
    "semiputos": "semiputo",
    "semipúbrica": "semipúbrico",
    "semipúbricas": "semipúbrico",
    "semipúbricos": "semipúbrico",
    "semipútrica": "semipútrico",
    "semipútricas": "semipútrico",
    "semipútricos": "semipútrico",
    "semiscarúnfia": "semiscarúnfio",
    "semiscarúnfias": "semiscarúnfio",
    "semiscarúnfios": "semiscarúnfio",
    "semitas": "semita",
    "semiternária": "semiternário",
    "semiternárias": "semiternário",
    "semiternários": "semiternário",
    "semiterçãs": "semiterçã",
    "semitismos": "semitismo",
    "semitistas": "semitista",
    "semitonada": "semitonado",
    "semitonadas": "semitonado",
    "semitonados": "semitonado",
    "semitons": "semitom",
    "semitotais": "semitotal",
    "semitransparentes": "semitransparente",
    "semitónica": "semitónico",
    "semitónicas": "semitónico",
    "semitónicos": "semitónico",
    "semiusta": "semiusto",
    "semiustas": "semiusto",
    "semiustos": "semiusto",
    "semivazia": "semivazio",
    "semivazias": "semivazio",
    "semivazios": "semivazio",
    "semiviva": "semivivo",
    "semivivais": "semiviver",
    "semivivam": "semiviver",
    "semivivamo": "semiviver",
    "semivivamos": "semiviver",
    "semivivas": "semivivo",
    "semivive": "semiviver",
    "semivivei": "semiviver",
    "semiviveis": "semiviver",
    "semivivem": "semiviver",
    "semivivemo": "semiviver",
    "semivivemos": "semiviver",
    "semivivendo": "semiviver",
    "semivivera": "semiviver",
    "semiviveram": "semiviver",
    "semiviveras": "semiviver",
    "semiviverdes": "semiviver",
    "semiviverei": "semiviver",
    "semivivereis": "semiviver",
    "semiviverem": "semiviver",
    "semiviveremos": "semiviver",
    "semiviveres": "semiviver",
    "semiviveria": "semiviver",
    "semiviveriam": "semiviver",
    "semiviverias": "semiviver",
    "semivivermo": "semiviver",
    "semivivermos": "semiviver",
    "semiviverá": "semiviver",
    "semiviverás": "semiviver",
    "semiviverão": "semiviver",
    "semiviveríamos": "semiviver",
    "semiviveríeis": "semiviver",
    "semivives": "semiviver",
    "semivivesse": "semiviver",
    "semivivessem": "semiviver",
    "semivivesses": "semiviver",
    "semiviveste": "semiviver",
    "semivivestes": "semiviver",
    "semiviveu": "semiviver",
    "semivivi": "semiviver",
    "semivivia": "semiviver",
    "semiviviam": "semiviver",
    "semivivias": "semiviver",
    "semivivida": "semiviver",
    "semivividas": "semiviver",
    "semivivido": "semiviver",
    "semivividos": "semiviver",
    "semivivo": "semiviver",
    "semivivos": "semivivo",
    "semivivêramo": "semiviver",
    "semivivêramos": "semiviver",
    "semivivêreis": "semiviver",
    "semivivêsseis": "semiviver",
    "semivivêssemos": "semiviver",
    "semivivíamo": "semiviver",
    "semivivíamos": "semiviver",
    "semivivíeis": "semiviver",
    "semivogais": "semivogal",
    "semivítrea": "semivítreo",
    "semivítreas": "semivítreo",
    "semivítreos": "semivítreo",
    "semiânimes": "semiânime",
    "semiótica": "semiótico",
    "semióticas": "semiótico",
    "semióticos": "semiótico",
    "semnopitecídeos": "semnopitecídeo",
    "semnopitécidas": "semnopitécida",
    "semodagens": "semodagem",
    "semolinas": "semolina",
    "semostra": "semostrar",
    "semostrada": "semostrar",
    "semostradas": "semostrar",
    "semostradeiras": "semostradeira",
    "semostrado": "semostrar",
    "semostradora": "semostrador",
    "semostradoras": "semostrador",
    "semostradores": "semostrador",
    "semostrados": "semostrar",
    "semostrai": "semostrar",
    "semostrais": "semostrar",
    "semostram": "semostrar",
    "semostramo": "semostrar",
    "semostramos": "semostrar",
    "semostrando": "semostrar",
    "semostrara": "semostrar",
    "semostraram": "semostrar",
    "semostraras": "semostrar",
    "semostrarde": "semostrar",
    "semostrardes": "semostrar",
    "semostrare": "semostrar",
    "semostrarei": "semostrar",
    "semostrareis": "semostrar",
    "semostrarem": "semostrar",
    "semostraremos": "semostrar",
    "semostrares": "semostrar",
    "semostraria": "semostrar",
    "semostrariam": "semostrar",
    "semostrarias": "semostrar",
    "semostrarmo": "semostrar",
    "semostrarmos": "semostrar",
    "semostrará": "semostrar",
    "semostrarás": "semostrar",
    "semostrarão": "semostrar",
    "semostraríamos": "semostrar",
    "semostraríeis": "semostrar",
    "semostras": "semostrar",
    "semostrasse": "semostrar",
    "semostrassem": "semostrar",
    "semostrasses": "semostrar",
    "semostraste": "semostrar",
    "semostrastes": "semostrar",
    "semostrava": "semostrar",
    "semostravam": "semostrar",
    "semostravas": "semostrar",
    "semostrações": "semostração",
    "semostre": "semostrar",
    "semostrei": "semostrar",
    "semostreis": "semostrar",
    "semostrem": "semostrar",
    "semostremo": "semostrar",
    "semostremos": "semostrar",
    "semostres": "semostrar",
    "semostro": "semostrar",
    "semostrou": "semostrar",
    "semostrá": "semostrar",
    "semostrámo": "semostrar",
    "semostrámos": "semostrar",
    "semostráramo": "semostrar",
    "semostráramos": "semostrar",
    "semostrárei": "semostrar",
    "semostráreis": "semostrar",
    "semostrásseis": "semostrar",
    "semostrássemos": "semostrar",
    "semostrávamo": "semostrar",
    "semostrávamos": "semostrar",
    "semostrávei": "semostrar",
    "semostráveis": "semostrar",
    "semota": "semoto",
    "semotas": "semoto",
    "semotos": "semoto",
    "semoventes": "semovente",
    "sempiterna": "sempiterno",
    "sempiternas": "sempiterno",
    "sempiternidades": "sempiternidade",
    "sempiternos": "sempiterno",
    "semáforos": "semáforo",
    "semântica": "semântico",
    "semânticas": "semântico",
    "semânticos": "semântico",
    "semífera": "semífero",
    "semíferas": "semífero",
    "semíferos": "semífero",
    "semínimas": "semínima",
    "semínulas": "semínula",
    "semínulos": "semínulo",
    "semítica": "semítico",
    "semíticas": "semítico",
    "semíticos": "semítico",
    "semítonos": "semítono",
    "semíviros": "semíviro",
    "senadora": "senador",
    "senadoras": "senador",
    "senadores": "senador",
    "senadorias": "senadoria",
    "senados": "senado",
    "senais": "senal",
    "senas": "sena",
    "senatoriais": "senatorial",
    "senatorias": "senatoria",
    "senatriz": "senador",
    "senatrizes": "senador",
    "senatória": "senatório",
    "senatórias": "senatório",
    "senatórios": "senatório",
    "sencelos": "sencelo",
    "sencenadas": "sencenada",
    "sencenos": "senceno",
    "sencientes": "senciente",
    "sendas": "senda",
    "sendeira": "sendeiro",
    "sendeiradas": "sendeirada",
    "sendeiras": "sendeiro",
    "sendeirices": "sendeirice",
    "sendeiros": "sendeiro",
    "sendinesa": "sendinês",
    "sendinesas": "sendinês",
    "sendineses": "sendinês",
    "sendo": "ser",
    "senecta": "senecto",
    "senectas": "senecto",
    "senectos": "senecto",
    "senectudes": "senectude",
    "senegalenses": "senegalense",
    "senegalesa": "senegalês",
    "senegalesas": "senegalês",
    "senegalesca": "senegalesco",
    "senegalescas": "senegalesco",
    "senegalescos": "senegalesco",
    "senegaleses": "senegalês",
    "senegalis": "senegali",
    "senenses": "senense",
    "senes": "sene",
    "senescais": "senescal",
    "senescalias": "senescalia",
    "senescentes": "senescente",
    "senescências": "senescência",
    "senfilistas": "senfilista",
    "senga": "sengar",
    "sengada": "sengar",
    "sengadas": "sengar",
    "sengado": "sengar",
    "sengados": "sengar",
    "sengai": "sengar",
    "sengais": "sengar",
    "sengam": "sengar",
    "sengamo": "sengar",
    "sengamos": "sengar",
    "sengando": "sengar",
    "sengara": "sengar",
    "sengaram": "sengar",
    "sengaras": "sengar",
    "sengarde": "sengar",
    "sengardes": "sengar",
    "sengare": "sengar",
    "sengarei": "sengar",
    "sengareis": "sengar",
    "sengarem": "sengar",
    "sengaremos": "sengar",
    "sengares": "sengar",
    "sengaria": "sengar",
    "sengariam": "sengar",
    "sengarias": "sengar",
    "sengarmo": "sengar",
    "sengarmos": "sengar",
    "sengará": "sengar",
    "sengarás": "sengar",
    "sengarão": "sengar",
    "sengaríamos": "sengar",
    "sengaríeis": "sengar",
    "sengas": "sengar",
    "sengasse": "sengar",
    "sengassem": "sengar",
    "sengasses": "sengar",
    "sengaste": "sengar",
    "sengastes": "sengar",
    "sengava": "sengar",
    "sengavam": "sengar",
    "sengavas": "sengar",
    "sengo": "sengar",
    "sengou": "sengar",
    "sengue": "sengar",
    "senguei": "sengar",
    "sengueis": "sengar",
    "senguem": "sengar",
    "senguemo": "sengar",
    "senguemos": "sengar",
    "sengues": "sengar",
    "sengá": "sengar",
    "sengámo": "sengar",
    "sengámos": "sengar",
    "sengáramo": "sengar",
    "sengáramos": "sengar",
    "sengárei": "sengar",
    "sengáreis": "sengar",
    "sengásseis": "sengar",
    "sengássemos": "sengar",
    "sengávamo": "sengar",
    "sengávamos": "sengar",
    "sengávei": "sengar",
    "sengáveis": "sengar",
    "senhas": "senha",
    "senhazinha": "senha",
    "senhazinhas": "senha",
    "senhazita": "senha",
    "senhazitas": "senha",
    "senhinha": "senha",
    "senhinhas": "senha",
    "senhita": "senha",
    "senhitas": "senha",
    "senhora": "senhor",
    "senhoramas": "senhorama",
    "senhoras": "senhor",
    "senhoraça": "senhoraço",
    "senhoraças": "senhoraço",
    "senhoraços": "senhoraço",
    "senhoreada": "senhorear",
    "senhoreadas": "senhorear",
    "senhoreado": "senhorear",
    "senhoreadora": "senhoreador",
    "senhoreadoras": "senhoreador",
    "senhoreadores": "senhoreador",
    "senhoreados": "senhorear",
    "senhoreai": "senhorear",
    "senhoreais": "senhorear",
    "senhoreamo": "senhorear",
    "senhoreamos": "senhorear",
    "senhoreando": "senhorear",
    "senhoreara": "senhorear",
    "senhorearam": "senhorear",
    "senhorearas": "senhorear",
    "senhorearde": "senhorear",
    "senhoreardes": "senhorear",
    "senhoreare": "senhorear",
    "senhorearei": "senhorear",
    "senhoreareis": "senhorear",
    "senhorearem": "senhorear",
    "senhorearemos": "senhorear",
    "senhoreares": "senhorear",
    "senhorearia": "senhorear",
    "senhoreariam": "senhorear",
    "senhorearias": "senhorear",
    "senhorearmo": "senhorear",
    "senhorearmos": "senhorear",
    "senhoreará": "senhorear",
    "senhorearás": "senhorear",
    "senhorearão": "senhorear",
    "senhorearíamos": "senhorear",
    "senhorearíeis": "senhorear",
    "senhoreasse": "senhorear",
    "senhoreassem": "senhorear",
    "senhoreasses": "senhorear",
    "senhoreaste": "senhorear",
    "senhoreastes": "senhorear",
    "senhoreava": "senhorear",
    "senhoreavam": "senhorear",
    "senhoreavas": "senhorear",
    "senhoreei": "senhorear",
    "senhoreeis": "senhorear",
    "senhoreemo": "senhorear",
    "senhoreemos": "senhorear",
    "senhoreia": "senhorear",
    "senhoreiam": "senhorear",
    "senhoreias": "senhorear",
    "senhoreie": "senhorear",
    "senhoreiem": "senhorear",
    "senhoreies": "senhorear",
    "senhoreio": "senhorear",
    "senhoreou": "senhorear",
    "senhores": "senhor",
    "senhoreá": "senhorear",
    "senhoreámo": "senhorear",
    "senhoreámos": "senhorear",
    "senhoreáramo": "senhorear",
    "senhoreáramos": "senhorear",
    "senhoreárei": "senhorear",
    "senhoreáreis": "senhorear",
    "senhoreásseis": "senhorear",
    "senhoreássemos": "senhorear",
    "senhoreávamo": "senhorear",
    "senhoreávamos": "senhorear",
    "senhoreávei": "senhorear",
    "senhoreáveis": "senhorear",
    "senhoria": "senhorio",
    "senhoriagens": "senhoriagem",
    "senhoriais": "senhorial",
    "senhorias": "senhorio",
    "senhorilidades": "senhorilidade",
    "senhorinha": "senhor",
    "senhorinhas": "senhor",
    "senhorinho": "senhor",
    "senhorinhos": "senhor",
    "senhorios": "senhorio",
    "senhoris": "senhoril",
    "senhorita": "senhor",
    "senhoritas": "senhor",
    "senhorito": "senhor",
    "senhoritos": "senhor",
    "senhos": "senho",
    "senilidades": "senilidade",
    "seniliza": "senilizar",
    "senilizada": "senilizar",
    "senilizadas": "senilizar",
    "senilizado": "senilizar",
    "senilizados": "senilizar",
    "senilizai": "senilizar",
    "senilizais": "senilizar",
    "senilizam": "senilizar",
    "senilizamo": "senilizar",
    "senilizamos": "senilizar",
    "senilizando": "senilizar",
    "senilizara": "senilizar",
    "senilizaram": "senilizar",
    "senilizaras": "senilizar",
    "senilizardes": "senilizar",
    "senilizarei": "senilizar",
    "senilizareis": "senilizar",
    "senilizarem": "senilizar",
    "senilizaremos": "senilizar",
    "senilizares": "senilizar",
    "senilizaria": "senilizar",
    "senilizariam": "senilizar",
    "senilizarias": "senilizar",
    "senilizarmo": "senilizar",
    "senilizarmos": "senilizar",
    "senilizará": "senilizar",
    "senilizarás": "senilizar",
    "senilizarão": "senilizar",
    "senilizaríamos": "senilizar",
    "senilizaríeis": "senilizar",
    "senilizas": "senilizar",
    "senilizasse": "senilizar",
    "senilizassem": "senilizar",
    "senilizasses": "senilizar",
    "senilizaste": "senilizar",
    "senilizastes": "senilizar",
    "senilizava": "senilizar",
    "senilizavam": "senilizar",
    "senilizavas": "senilizar",
    "senilizações": "senilização",
    "senilize": "senilizar",
    "senilizei": "senilizar",
    "senilizeis": "senilizar",
    "senilizem": "senilizar",
    "senilizemo": "senilizar",
    "senilizemos": "senilizar",
    "senilizes": "senilizar",
    "senilizo": "senilizar",
    "senilizou": "senilizar",
    "senilizámo": "senilizar",
    "senilizámos": "senilizar",
    "senilizáramo": "senilizar",
    "senilizáramos": "senilizar",
    "senilizáreis": "senilizar",
    "senilizásseis": "senilizar",
    "senilizássemos": "senilizar",
    "senilizávamo": "senilizar",
    "senilizávamos": "senilizar",
    "senilizáveis": "senilizar",
    "seniores": "sénior",
    "senis": "senil",
    "senisgas": "senisga",
    "senismos": "senismo",
    "senografias": "senografia",
    "senoites": "senoite",
    "senos": "seno",
    "senoutes": "senoute",
    "senradas": "senrada",
    "senradelas": "senradela",
    "senras": "senra",
    "sensabores": "sensabor",
    "sensaborias": "sensaboria",
    "sensaboriza": "sensaborizar",
    "sensaborizada": "sensaborizar",
    "sensaborizadas": "sensaborizar",
    "sensaborizado": "sensaborizar",
    "sensaborizados": "sensaborizar",
    "sensaborizai": "sensaborizar",
    "sensaborizais": "sensaborizar",
    "sensaborizam": "sensaborizar",
    "sensaborizamo": "sensaborizar",
    "sensaborizamos": "sensaborizar",
    "sensaborizando": "sensaborizar",
    "sensaborizara": "sensaborizar",
    "sensaborizaram": "sensaborizar",
    "sensaborizaras": "sensaborizar",
    "sensaborizarde": "sensaborizar",
    "sensaborizardes": "sensaborizar",
    "sensaborizare": "sensaborizar",
    "sensaborizarei": "sensaborizar",
    "sensaborizareis": "sensaborizar",
    "sensaborizarem": "sensaborizar",
    "sensaborizaremos": "sensaborizar",
    "sensaborizares": "sensaborizar",
    "sensaborizaria": "sensaborizar",
    "sensaborizariam": "sensaborizar",
    "sensaborizarias": "sensaborizar",
    "sensaborizarmo": "sensaborizar",
    "sensaborizarmos": "sensaborizar",
    "sensaborizará": "sensaborizar",
    "sensaborizarás": "sensaborizar",
    "sensaborizarão": "sensaborizar",
    "sensaborizaríamos": "sensaborizar",
    "sensaborizaríeis": "sensaborizar",
    "sensaborizas": "sensaborizar",
    "sensaborizasse": "sensaborizar",
    "sensaborizassem": "sensaborizar",
    "sensaborizasses": "sensaborizar",
    "sensaborizaste": "sensaborizar",
    "sensaborizastes": "sensaborizar",
    "sensaborizava": "sensaborizar",
    "sensaborizavam": "sensaborizar",
    "sensaborizavas": "sensaborizar",
    "sensaborize": "sensaborizar",
    "sensaborizei": "sensaborizar",
    "sensaborizeis": "sensaborizar",
    "sensaborizem": "sensaborizar",
    "sensaborizemo": "sensaborizar",
    "sensaborizemos": "sensaborizar",
    "sensaborizes": "sensaborizar",
    "sensaborizo": "sensaborizar",
    "sensaborizou": "sensaborizar",
    "sensaborizá": "sensaborizar",
    "sensaborizámo": "sensaborizar",
    "sensaborizámos": "sensaborizar",
    "sensaborizáramo": "sensaborizar",
    "sensaborizáramos": "sensaborizar",
    "sensaborizárei": "sensaborizar",
    "sensaborizáreis": "sensaborizar",
    "sensaborizásseis": "sensaborizar",
    "sensaborizássemos": "sensaborizar",
    "sensaborizávamo": "sensaborizar",
    "sensaborizávamos": "sensaborizar",
    "sensaborizávei": "sensaborizar",
    "sensaborizáveis": "sensaborizar",
    "sensaborona": "sensaborão",
    "sensaboronas": "sensaborão",
    "sensaborões": "sensaborão",
    "sensacionais": "sensacional",
    "sensacionalismos": "sensacionalismo",
    "sensacionalistas": "sensacionalista",
    "sensacionismos": "sensacionismo",
    "sensata": "sensato",
    "sensatas": "sensato",
    "sensatos": "sensato",
    "sensatíssima": "sensato",
    "sensatíssimas": "sensato",
    "sensatíssimo": "sensato",
    "sensatíssimos": "sensato",
    "sensações": "sensação",
    "sensibilidades": "sensibilidade",
    "sensibiliza": "sensibilizar",
    "sensibilizada": "sensibilizar",
    "sensibilizadas": "sensibilizar",
    "sensibilizado": "sensibilizar",
    "sensibilizadora": "sensibilizador",
    "sensibilizadoras": "sensibilizador",
    "sensibilizadores": "sensibilizador",
    "sensibilizados": "sensibilizar",
    "sensibilizai": "sensibilizar",
    "sensibilizais": "sensibilizar",
    "sensibilizam": "sensibilizar",
    "sensibilizamo": "sensibilizar",
    "sensibilizamos": "sensibilizar",
    "sensibilizando": "sensibilizar",
    "sensibilizantes": "sensibilizante",
    "sensibilizara": "sensibilizar",
    "sensibilizaram": "sensibilizar",
    "sensibilizaras": "sensibilizar",
    "sensibilizarde": "sensibilizar",
    "sensibilizardes": "sensibilizar",
    "sensibilizare": "sensibilizar",
    "sensibilizarei": "sensibilizar",
    "sensibilizareis": "sensibilizar",
    "sensibilizarem": "sensibilizar",
    "sensibilizaremos": "sensibilizar",
    "sensibilizares": "sensibilizar",
    "sensibilizaria": "sensibilizar",
    "sensibilizariam": "sensibilizar",
    "sensibilizarias": "sensibilizar",
    "sensibilizarmo": "sensibilizar",
    "sensibilizarmos": "sensibilizar",
    "sensibilizará": "sensibilizar",
    "sensibilizarás": "sensibilizar",
    "sensibilizarão": "sensibilizar",
    "sensibilizaríamos": "sensibilizar",
    "sensibilizaríeis": "sensibilizar",
    "sensibilizas": "sensibilizar",
    "sensibilizasse": "sensibilizar",
    "sensibilizassem": "sensibilizar",
    "sensibilizasses": "sensibilizar",
    "sensibilizaste": "sensibilizar",
    "sensibilizastes": "sensibilizar",
    "sensibilizava": "sensibilizar",
    "sensibilizavam": "sensibilizar",
    "sensibilizavas": "sensibilizar",
    "sensibilizações": "sensibilização",
    "sensibilize": "sensibilizar",
    "sensibilizei": "sensibilizar",
    "sensibilizeis": "sensibilizar",
    "sensibilizem": "sensibilizar",
    "sensibilizemo": "sensibilizar",
    "sensibilizemos": "sensibilizar",
    "sensibilizes": "sensibilizar",
    "sensibilizo": "sensibilizar",
    "sensibilizou": "sensibilizar",
    "sensibilizá": "sensibilizar",
    "sensibilizámo": "sensibilizar",
    "sensibilizámos": "sensibilizar",
    "sensibilizáramo": "sensibilizar",
    "sensibilizáramos": "sensibilizar",
    "sensibilizárei": "sensibilizar",
    "sensibilizáreis": "sensibilizar",
    "sensibilizásseis": "sensibilizar",
    "sensibilizássemos": "sensibilizar",
    "sensibilizávamo": "sensibilizar",
    "sensibilizávamos": "sensibilizar",
    "sensibilizávei": "sensibilizar",
    "sensibilizáveis": "sensibilizável",
    "sensibilíssima": "sensível",
    "sensibilíssimas": "sensível",
    "sensibilíssimo": "sensível",
    "sensibilíssimos": "sensível",
    "sensifica": "sensificar",
    "sensificada": "sensificar",
    "sensificadas": "sensificar",
    "sensificado": "sensificar",
    "sensificados": "sensificar",
    "sensificai": "sensificar",
    "sensificais": "sensificar",
    "sensificam": "sensificar",
    "sensificamo": "sensificar",
    "sensificamos": "sensificar",
    "sensificando": "sensificar",
    "sensificara": "sensificar",
    "sensificaram": "sensificar",
    "sensificaras": "sensificar",
    "sensificarde": "sensificar",
    "sensificardes": "sensificar",
    "sensificare": "sensificar",
    "sensificarei": "sensificar",
    "sensificareis": "sensificar",
    "sensificarem": "sensificar",
    "sensificaremos": "sensificar",
    "sensificares": "sensificar",
    "sensificaria": "sensificar",
    "sensificariam": "sensificar",
    "sensificarias": "sensificar",
    "sensificarmo": "sensificar",
    "sensificarmos": "sensificar",
    "sensificará": "sensificar",
    "sensificarás": "sensificar",
    "sensificarão": "sensificar",
    "sensificaríamos": "sensificar",
    "sensificaríeis": "sensificar",
    "sensificas": "sensificar",
    "sensificasse": "sensificar",
    "sensificassem": "sensificar",
    "sensificasses": "sensificar",
    "sensificaste": "sensificar",
    "sensificastes": "sensificar",
    "sensificava": "sensificar",
    "sensificavam": "sensificar",
    "sensificavas": "sensificar",
    "sensifico": "sensificar",
    "sensificou": "sensificar",
    "sensificá": "sensificar",
    "sensificámo": "sensificar",
    "sensificámos": "sensificar",
    "sensificáramo": "sensificar",
    "sensificáramos": "sensificar",
    "sensificárei": "sensificar",
    "sensificáreis": "sensificar",
    "sensificásseis": "sensificar",
    "sensificássemos": "sensificar",
    "sensificávamo": "sensificar",
    "sensificávamos": "sensificar",
    "sensificávei": "sensificar",
    "sensificáveis": "sensificar",
    "sensifique": "sensificar",
    "sensifiquei": "sensificar",
    "sensifiqueis": "sensificar",
    "sensifiquem": "sensificar",
    "sensifiquemo": "sensificar",
    "sensifiquemos": "sensificar",
    "sensifiques": "sensificar",
    "sensilas": "sensila",
    "sensistas": "sensista",
    "sensitiva": "sensitivo",
    "sensitivas": "sensitivo",
    "sensitivos": "sensitivo",
    "sensitometrias": "sensitometria",
    "sensiva": "sensivo",
    "sensivas": "sensivo",
    "sensivos": "sensivo",
    "sensores": "sensor",
    "sensoriais": "sensorial",
    "sensorimetrias": "sensorimetria",
    "sensos": "senso",
    "sensuais": "sensual",
    "sensualidades": "sensualidade",
    "sensualismos": "sensualismo",
    "sensualistas": "sensualista",
    "sensualiza": "sensualizar",
    "sensualizada": "sensualizar",
    "sensualizadas": "sensualizar",
    "sensualizado": "sensualizar",
    "sensualizados": "sensualizar",
    "sensualizai": "sensualizar",
    "sensualizais": "sensualizar",
    "sensualizam": "sensualizar",
    "sensualizamo": "sensualizar",
    "sensualizamos": "sensualizar",
    "sensualizando": "sensualizar",
    "sensualizara": "sensualizar",
    "sensualizaram": "sensualizar",
    "sensualizaras": "sensualizar",
    "sensualizarde": "sensualizar",
    "sensualizardes": "sensualizar",
    "sensualizare": "sensualizar",
    "sensualizarei": "sensualizar",
    "sensualizareis": "sensualizar",
    "sensualizarem": "sensualizar",
    "sensualizaremos": "sensualizar",
    "sensualizares": "sensualizar",
    "sensualizaria": "sensualizar",
    "sensualizariam": "sensualizar",
    "sensualizarias": "sensualizar",
    "sensualizarmo": "sensualizar",
    "sensualizarmos": "sensualizar",
    "sensualizará": "sensualizar",
    "sensualizarás": "sensualizar",
    "sensualizarão": "sensualizar",
    "sensualizaríamos": "sensualizar",
    "sensualizaríeis": "sensualizar",
    "sensualizas": "sensualizar",
    "sensualizasse": "sensualizar",
    "sensualizassem": "sensualizar",
    "sensualizasses": "sensualizar",
    "sensualizaste": "sensualizar",
    "sensualizastes": "sensualizar",
    "sensualizava": "sensualizar",
    "sensualizavam": "sensualizar",
    "sensualizavas": "sensualizar",
    "sensualizações": "sensualização",
    "sensualize": "sensualizar",
    "sensualizei": "sensualizar",
    "sensualizeis": "sensualizar",
    "sensualizem": "sensualizar",
    "sensualizemo": "sensualizar",
    "sensualizemos": "sensualizar",
    "sensualizes": "sensualizar",
    "sensualizo": "sensualizar",
    "sensualizou": "sensualizar",
    "sensualizá": "sensualizar",
    "sensualizámo": "sensualizar",
    "sensualizámos": "sensualizar",
    "sensualizáramo": "sensualizar",
    "sensualizáramos": "sensualizar",
    "sensualizárei": "sensualizar",
    "sensualizáreis": "sensualizar",
    "sensualizásseis": "sensualizar",
    "sensualizássemos": "sensualizar",
    "sensualizávamo": "sensualizar",
    "sensualizávamos": "sensualizar",
    "sensualizávei": "sensualizar",
    "sensualizáveis": "sensualizar",
    "sensíveis": "sensível",
    "sensória": "sensório",
    "sensórias": "sensório",
    "sensórios": "sensório",
    "senta": "sentar",
    "sentada": "sentar",
    "sentadas": "sentar",
    "sentadinha": "sentado",
    "sentadinhas": "sentado",
    "sentadinho": "sentado",
    "sentadinhos": "sentado",
    "sentadita": "sentado",
    "sentaditas": "sentado",
    "sentadito": "sentado",
    "sentaditos": "sentado",
    "sentado": "sentar",
    "sentados": "sentar",
    "sentai": "sentar",
    "sentais": "sentar",
    "sentam": "sentar",
    "sentamo": "sentar",
    "sentamos": "sentar",
    "sentando": "sentar",
    "sentara": "sentar",
    "sentaram": "sentar",
    "sentaras": "sentar",
    "sentarde": "sentar",
    "sentardes": "sentar",
    "sentare": "sentar",
    "sentarei": "sentar",
    "sentareis": "sentar",
    "sentarem": "sentar",
    "sentaremos": "sentar",
    "sentares": "sentar",
    "sentaria": "sentar",
    "sentariam": "sentar",
    "sentarias": "sentar",
    "sentarmo": "sentar",
    "sentarmos": "sentar",
    "sentará": "sentar",
    "sentarás": "sentar",
    "sentarão": "sentar",
    "sentaríamos": "sentar",
    "sentaríeis": "sentar",
    "sentas": "sentar",
    "sentasse": "sentar",
    "sentassem": "sentar",
    "sentasses": "sentar",
    "sentaste": "sentar",
    "sentastes": "sentar",
    "sentava": "sentar",
    "sentavam": "sentar",
    "sentavas": "sentar",
    "sente": "sentir",
    "sentei": "sentar",
    "senteis": "sentar",
    "sentem": "sentir",
    "sentemo": "sentar",
    "sentemos": "sentar",
    "sentencia": "sentenciar",
    "sentenciada": "sentenciar",
    "sentenciadas": "sentenciar",
    "sentenciado": "sentenciar",
    "sentenciadora": "sentenciador",
    "sentenciadoras": "sentenciador",
    "sentenciadores": "sentenciador",
    "sentenciados": "sentenciar",
    "sentenciai": "sentenciar",
    "sentenciais": "sentenciar",
    "sentenciam": "sentenciar",
    "sentenciamo": "sentenciar",
    "sentenciamos": "sentenciar",
    "sentenciando": "sentenciar",
    "sentenciara": "sentenciar",
    "sentenciaram": "sentenciar",
    "sentenciaras": "sentenciar",
    "sentenciarde": "sentenciar",
    "sentenciardes": "sentenciar",
    "sentenciare": "sentenciar",
    "sentenciarei": "sentenciar",
    "sentenciareis": "sentenciar",
    "sentenciarem": "sentenciar",
    "sentenciaremos": "sentenciar",
    "sentenciares": "sentenciar",
    "sentenciaria": "sentenciar",
    "sentenciariam": "sentenciar",
    "sentenciarias": "sentenciar",
    "sentenciarmo": "sentenciar",
    "sentenciarmos": "sentenciar",
    "sentenciará": "sentenciar",
    "sentenciarás": "sentenciar",
    "sentenciarão": "sentenciar",
    "sentenciaríamos": "sentenciar",
    "sentenciaríeis": "sentenciar",
    "sentencias": "sentenciar",
    "sentenciasse": "sentenciar",
    "sentenciassem": "sentenciar",
    "sentenciasses": "sentenciar",
    "sentenciaste": "sentenciar",
    "sentenciastes": "sentenciar",
    "sentenciava": "sentenciar",
    "sentenciavam": "sentenciar",
    "sentenciavas": "sentenciar",
    "sentencie": "sentenciar",
    "sentenciei": "sentenciar",
    "sentencieis": "sentenciar",
    "sentenciem": "sentenciar",
    "sentenciemo": "sentenciar",
    "sentenciemos": "sentenciar",
    "sentencies": "sentenciar",
    "sentencio": "sentenciar",
    "sentenciosa": "sentencioso",
    "sentenciosas": "sentencioso",
    "sentenciosos": "sentencioso",
    "sentenciou": "sentenciar",
    "sentenciá": "sentenciar",
    "sentenciámo": "sentenciar",
    "sentenciámos": "sentenciar",
    "sentenciáramo": "sentenciar",
    "sentenciáramos": "sentenciar",
    "sentenciárei": "sentenciar",
    "sentenciáreis": "sentenciar",
    "sentenciásseis": "sentenciar",
    "sentenciássemos": "sentenciar",
    "sentenciávamo": "sentenciar",
    "sentenciávamos": "sentenciar",
    "sentenciávei": "sentenciar",
    "sentenciáveis": "sentenciar",
    "sentenciúnculas": "sentenciúncula",
    "sentenças": "sentença",
    "sentes": "sentir",
    "senti": "sentir",
    "sentia": "sentir",
    "sentiam": "sentir",
    "sentias": "sentir",
    "sentida": "sentir",
    "sentidas": "sentir",
    "sentido": "sentir",
    "sentidos": "sentir",
    "sentidíssima": "sentido",
    "sentidíssimas": "sentido",
    "sentidíssimo": "sentido",
    "sentidíssimos": "sentido",
    "sentimentais": "sentimental",
    "sentimentalidades": "sentimentalidade",
    "sentimentalismos": "sentimentalismo",
    "sentimentalistas": "sentimentalista",
    "sentimentaliza": "sentimentalizar",
    "sentimentalizada": "sentimentalizar",
    "sentimentalizadas": "sentimentalizar",
    "sentimentalizado": "sentimentalizar",
    "sentimentalizados": "sentimentalizar",
    "sentimentalizai": "sentimentalizar",
    "sentimentalizais": "sentimentalizar",
    "sentimentalizam": "sentimentalizar",
    "sentimentalizamo": "sentimentalizar",
    "sentimentalizamos": "sentimentalizar",
    "sentimentalizando": "sentimentalizar",
    "sentimentalizara": "sentimentalizar",
    "sentimentalizaram": "sentimentalizar",
    "sentimentalizaras": "sentimentalizar",
    "sentimentalizarde": "sentimentalizar",
    "sentimentalizardes": "sentimentalizar",
    "sentimentalizare": "sentimentalizar",
    "sentimentalizarei": "sentimentalizar",
    "sentimentalizareis": "sentimentalizar",
    "sentimentalizarem": "sentimentalizar",
    "sentimentalizaremos": "sentimentalizar",
    "sentimentalizares": "sentimentalizar",
    "sentimentalizaria": "sentimentalizar",
    "sentimentalizariam": "sentimentalizar",
    "sentimentalizarias": "sentimentalizar",
    "sentimentalizarmo": "sentimentalizar",
    "sentimentalizarmos": "sentimentalizar",
    "sentimentalizará": "sentimentalizar",
    "sentimentalizarás": "sentimentalizar",
    "sentimentalizarão": "sentimentalizar",
    "sentimentalizaríamos": "sentimentalizar",
    "sentimentalizaríeis": "sentimentalizar",
    "sentimentalizas": "sentimentalizar",
    "sentimentalizasse": "sentimentalizar",
    "sentimentalizassem": "sentimentalizar",
    "sentimentalizasses": "sentimentalizar",
    "sentimentalizaste": "sentimentalizar",
    "sentimentalizastes": "sentimentalizar",
    "sentimentalizava": "sentimentalizar",
    "sentimentalizavam": "sentimentalizar",
    "sentimentalizavas": "sentimentalizar",
    "sentimentalize": "sentimentalizar",
    "sentimentalizei": "sentimentalizar",
    "sentimentalizeis": "sentimentalizar",
    "sentimentalizem": "sentimentalizar",
    "sentimentalizemo": "sentimentalizar",
    "sentimentalizemos": "sentimentalizar",
    "sentimentalizes": "sentimentalizar",
    "sentimentalizo": "sentimentalizar",
    "sentimentalizou": "sentimentalizar",
    "sentimentalizá": "sentimentalizar",
    "sentimentalizámo": "sentimentalizar",
    "sentimentalizámos": "sentimentalizar",
    "sentimentalizáramo": "sentimentalizar",
    "sentimentalizáramos": "sentimentalizar",
    "sentimentalizárei": "sentimentalizar",
    "sentimentalizáreis": "sentimentalizar",
    "sentimentalizásseis": "sentimentalizar",
    "sentimentalizássemos": "sentimentalizar",
    "sentimentalizávamo": "sentimentalizar",
    "sentimentalizávamos": "sentimentalizar",
    "sentimentalizávei": "sentimentalizar",
    "sentimentalizáveis": "sentimentalizar",
    "sentimentalona": "sentimentalão",
    "sentimentalonas": "sentimentalão",
    "sentimentalões": "sentimentalão",
    "sentimentos": "sentimento",
    "sentimo": "sentir",
    "sentimos": "sentir",
    "sentinas": "sentina",
    "sentindo": "sentir",
    "sentinelas": "sentinela",
    "sentira": "sentir",
    "sentiram": "sentir",
    "sentiras": "sentir",
    "sentirde": "sentir",
    "sentirdes": "sentir",
    "sentire": "sentir",
    "sentirei": "sentir",
    "sentireis": "sentir",
    "sentirem": "sentir",
    "sentiremos": "sentir",
    "sentires": "sentir",
    "sentiria": "sentir",
    "sentiriam": "sentir",
    "sentirias": "sentir",
    "sentirmo": "sentir",
    "sentirmos": "sentir",
    "sentirá": "sentir",
    "sentirás": "sentir",
    "sentirão": "sentir",
    "sentiríamos": "sentir",
    "sentiríeis": "sentir",
    "sentis": "sentir",
    "sentisse": "sentir",
    "sentissem": "sentir",
    "sentisses": "sentir",
    "sentiste": "sentir",
    "sentistes": "sentir",
    "sentiu": "sentir",
    "sento": "sentar",
    "sentou": "sentar",
    "sentá": "sentar",
    "sentámo": "sentar",
    "sentámos": "sentar",
    "sentáramo": "sentar",
    "sentáramos": "sentar",
    "sentárei": "sentar",
    "sentáreis": "sentar",
    "sentásseis": "sentar",
    "sentássemos": "sentar",
    "sentávamo": "sentar",
    "sentávamos": "sentar",
    "sentávei": "sentar",
    "sentáveis": "sentar",
    "sentíamo": "sentir",
    "sentíamos": "sentir",
    "sentíei": "sentir",
    "sentíeis": "sentir",
    "sentíramo": "sentir",
    "sentíramos": "sentir",
    "sentírei": "sentir",
    "sentíreis": "sentir",
    "sentísseis": "sentir",
    "sentíssemos": "sentir",
    "senzalas": "senzala",
    "senáculos": "senáculo",
    "senária": "senário",
    "senárias": "senário",
    "senários": "senário",
    "senões": "senão",
    "sepalóides": "sepalóide",
    "separa": "separar",
    "separabilidades": "separabilidade",
    "separada": "separar",
    "separadas": "separar",
    "separado": "separar",
    "separadora": "separador",
    "separadoras": "separador",
    "separadores": "separador",
    "separados": "separar",
    "separadíssima": "separado",
    "separadíssimas": "separado",
    "separadíssimo": "separado",
    "separadíssimos": "separado",
    "separai": "separar",
    "separais": "separar",
    "separam": "separar",
    "separamo": "separar",
    "separamos": "separar",
    "separando": "separar",
    "separara": "separar",
    "separaram": "separar",
    "separaras": "separar",
    "separarde": "separar",
    "separardes": "separar",
    "separare": "separar",
    "separarei": "separar",
    "separareis": "separar",
    "separarem": "separar",
    "separaremos": "separar",
    "separares": "separar",
    "separaria": "separar",
    "separariam": "separar",
    "separarias": "separar",
    "separarmo": "separar",
    "separarmos": "separar",
    "separará": "separar",
    "separarás": "separar",
    "separarão": "separar",
    "separaríamos": "separar",
    "separaríeis": "separar",
    "separas": "separar",
    "separasse": "separar",
    "separassem": "separar",
    "separasses": "separar",
    "separaste": "separar",
    "separastes": "separar",
    "separatas": "separata",
    "separatismos": "separatismo",
    "separatistas": "separatista",
    "separatistazinha": "separatista",
    "separatistazinhas": "separatista",
    "separatistazinho": "separatista",
    "separatistazinhos": "separatista",
    "separatistazita": "separatista",
    "separatistazitas": "separatista",
    "separatistazito": "separatista",
    "separatistazitos": "separatista",
    "separativa": "separativo",
    "separativas": "separativo",
    "separativos": "separativo",
    "separatrizes": "separatriz",
    "separatória": "separatório",
    "separatórias": "separatório",
    "separatórios": "separatório",
    "separava": "separar",
    "separavam": "separar",
    "separavas": "separar",
    "separações": "separação",
    "separe": "separar",
    "separei": "separar",
    "separeis": "separar",
    "separem": "separar",
    "separemo": "separar",
    "separemos": "separar",
    "separes": "separar",
    "separo": "separar",
    "separou": "separar",
    "separá": "separar",
    "separámo": "separar",
    "separámos": "separar",
    "separáramo": "separar",
    "separáramos": "separar",
    "separárei": "separar",
    "separáreis": "separar",
    "separásseis": "separar",
    "separássemos": "separar",
    "separávamo": "separar",
    "separávamos": "separar",
    "separávei": "separar",
    "separáveis": "separável",
    "sepiolites": "sepiolite",
    "sepses": "sepse",
    "sepsias": "sepsia",
    "sepsinas": "sepsina",
    "septada": "septado",
    "septadas": "septado",
    "septados": "septado",
    "septena": "septeno",
    "septenais": "septenal",
    "septenas": "septeno",
    "septenatos": "septenato",
    "septeniais": "septenial",
    "septenos": "septeno",
    "septenvirados": "septenvirado",
    "septenvirais": "septenviral",
    "septenviratos": "septenvirato",
    "septenária": "septenário",
    "septenárias": "septenário",
    "septenários": "septenário",
    "septetos": "septeto",
    "septicemias": "septicemia",
    "septicidades": "septicidade",
    "septicidas": "septicida",
    "septicoles": "septicole",
    "septicolores": "septicolor",
    "septicordes": "septicorde",
    "septicémica": "septicémico",
    "septicémicas": "septicémico",
    "septicémicos": "septicémico",
    "septiformes": "septiforme",
    "septifólia": "septifólio",
    "septifólias": "septifólio",
    "septifólios": "septifólio",
    "septiliões": "septilião",
    "septimestres": "septimestre",
    "septiminos": "septimino",
    "septingentésima": "septingentésimo",
    "septingentésimas": "septingentésimo",
    "septingentésimos": "septingentésimo",
    "septissílaba": "septissílabo",
    "septissílabas": "septissílabo",
    "septissílabos": "septissílabo",
    "septometrias": "septometria",
    "septos": "septo",
    "septuagenariazinha": "septuagenário",
    "septuagenariazinhas": "septuagenário",
    "septuagenariazita": "septuagenário",
    "septuagenariazitas": "septuagenário",
    "septuagenariozinho": "septuagenário",
    "septuagenariozinhos": "septuagenário",
    "septuagenariozito": "septuagenário",
    "septuagenariozitos": "septuagenário",
    "septuagenária": "septuagenário",
    "septuagenárias": "septuagenário",
    "septuagenários": "septuagenário",
    "septuagésima": "septuagésimo",
    "septuagésimas": "septuagésimo",
    "septuagésimos": "septuagésimo",
    "septupletas": "septupleta",
    "septuplica": "septuplicar",
    "septuplicada": "septuplicar",
    "septuplicadas": "septuplicar",
    "septuplicado": "septuplicar",
    "septuplicados": "septuplicar",
    "septuplicai": "septuplicar",
    "septuplicais": "septuplicar",
    "septuplicam": "septuplicar",
    "septuplicamo": "septuplicar",
    "septuplicamos": "septuplicar",
    "septuplicando": "septuplicar",
    "septuplicara": "septuplicar",
    "septuplicaram": "septuplicar",
    "septuplicaras": "septuplicar",
    "septuplicarde": "septuplicar",
    "septuplicardes": "septuplicar",
    "septuplicare": "septuplicar",
    "septuplicarei": "septuplicar",
    "septuplicareis": "septuplicar",
    "septuplicarem": "septuplicar",
    "septuplicaremos": "septuplicar",
    "septuplicares": "septuplicar",
    "septuplicaria": "septuplicar",
    "septuplicariam": "septuplicar",
    "septuplicarias": "septuplicar",
    "septuplicarmo": "septuplicar",
    "septuplicarmos": "septuplicar",
    "septuplicará": "septuplicar",
    "septuplicarás": "septuplicar",
    "septuplicarão": "septuplicar",
    "septuplicaríamos": "septuplicar",
    "septuplicaríeis": "septuplicar",
    "septuplicas": "septuplicar",
    "septuplicasse": "septuplicar",
    "septuplicassem": "septuplicar",
    "septuplicasses": "septuplicar",
    "septuplicaste": "septuplicar",
    "septuplicastes": "septuplicar",
    "septuplicava": "septuplicar",
    "septuplicavam": "septuplicar",
    "septuplicavas": "septuplicar",
    "septuplico": "septuplicar",
    "septuplicou": "septuplicar",
    "septuplicá": "septuplicar",
    "septuplicámo": "septuplicar",
    "septuplicámos": "septuplicar",
    "septuplicáramo": "septuplicar",
    "septuplicáramos": "septuplicar",
    "septuplicárei": "septuplicar",
    "septuplicáreis": "septuplicar",
    "septuplicásseis": "septuplicar",
    "septuplicássemos": "septuplicar",
    "septuplicávamo": "septuplicar",
    "septuplicávamos": "septuplicar",
    "septuplicávei": "septuplicar",
    "septuplicáveis": "septuplicável",
    "septuplique": "septuplicar",
    "septupliquei": "septuplicar",
    "septupliqueis": "septuplicar",
    "septupliquem": "septuplicar",
    "septupliquemo": "septuplicar",
    "septupliquemos": "septuplicar",
    "septupliques": "septuplicar",
    "septusses": "septusse",
    "septénios": "septénio",
    "septêmplices": "septêmplice",
    "septênflua": "septênfluo",
    "septênfluas": "septênfluo",
    "septênfluos": "septênfluo",
    "septênviros": "septênviro",
    "septífera": "septífero",
    "septíferas": "septífero",
    "septíferos": "septífero",
    "septífraga": "septífrago",
    "septífragas": "septífrago",
    "septífragos": "septífrago",
    "septímanos": "septímano",
    "septíssona": "septíssono",
    "septíssonas": "septíssono",
    "septíssonos": "septíssono",
    "septívoca": "septívoco",
    "septívocas": "septívoco",
    "septívocos": "septívoco",
    "septómetros": "septómetro",
    "sepulcrais": "sepulcral",
    "sepulcrologias": "sepulcrologia",
    "sepulcros": "sepulcro",
    "sepulcrários": "sepulcrário",
    "sepulta": "sepulto",
    "sepultada": "sepultar",
    "sepultadas": "sepultar",
    "sepultado": "sepultar",
    "sepultadora": "sepultador",
    "sepultadoras": "sepultador",
    "sepultadores": "sepultador",
    "sepultados": "sepultar",
    "sepultai": "sepultar",
    "sepultais": "sepultar",
    "sepultam": "sepultar",
    "sepultamentos": "sepultamento",
    "sepultamo": "sepultar",
    "sepultamos": "sepultar",
    "sepultando": "sepultar",
    "sepultantes": "sepultante",
    "sepultara": "sepultar",
    "sepultaram": "sepultar",
    "sepultaras": "sepultar",
    "sepultarde": "sepultar",
    "sepultardes": "sepultar",
    "sepultare": "sepultar",
    "sepultarei": "sepultar",
    "sepultareis": "sepultar",
    "sepultarem": "sepultar",
    "sepultaremos": "sepultar",
    "sepultares": "sepultar",
    "sepultaria": "sepultar",
    "sepultariam": "sepultar",
    "sepultarias": "sepultar",
    "sepultarmo": "sepultar",
    "sepultarmos": "sepultar",
    "sepultará": "sepultar",
    "sepultarás": "sepultar",
    "sepultarão": "sepultar",
    "sepultaríamos": "sepultar",
    "sepultaríeis": "sepultar",
    "sepultas": "sepulto",
    "sepultasse": "sepultar",
    "sepultassem": "sepultar",
    "sepultasses": "sepultar",
    "sepultaste": "sepultar",
    "sepultastes": "sepultar",
    "sepultava": "sepultar",
    "sepultavam": "sepultar",
    "sepultavas": "sepultar",
    "sepulte": "sepultar",
    "sepultei": "sepultar",
    "sepulteis": "sepultar",
    "sepultem": "sepultar",
    "sepultemo": "sepultar",
    "sepultemos": "sepultar",
    "sepultes": "sepultar",
    "sepulto": "sepultar",
    "sepultos": "sepulto",
    "sepultou": "sepultar",
    "sepulturas": "sepultura",
    "sepultureira": "sepultureiro",
    "sepultureiras": "sepultureiro",
    "sepultureiros": "sepultureiro",
    "sepultá": "sepultar",
    "sepultámo": "sepultar",
    "sepultámos": "sepultar",
    "sepultáramo": "sepultar",
    "sepultáramos": "sepultar",
    "sepultárei": "sepultar",
    "sepultáreis": "sepultar",
    "sepultásseis": "sepultar",
    "sepultássemos": "sepultar",
    "sepultávamo": "sepultar",
    "sepultávamos": "sepultar",
    "sepultávei": "sepultar",
    "sepultáveis": "sepultar",
    "sepícolas": "sepícola",
    "sequanianos": "sequaniano",
    "sequazes": "sequaz",
    "seque": "secar",
    "sequei": "secar",
    "sequeira": "sequeiro",
    "sequeiras": "sequeiro",
    "sequeiros": "sequeiro",
    "sequeis": "secar",
    "sequelas": "sequela",
    "sequem": "secar",
    "sequemo": "secar",
    "sequemos": "secar",
    "sequenciais": "sequencial",
    "sequentes": "sequente",
    "seques": "secar",
    "sequestra": "sequestrar",
    "sequestrada": "sequestrar",
    "sequestradas": "sequestrar",
    "sequestrado": "sequestrar",
    "sequestradora": "sequestrador",
    "sequestradoras": "sequestrador",
    "sequestradores": "sequestrador",
    "sequestrados": "sequestrar",
    "sequestrai": "sequestrar",
    "sequestrais": "sequestrar",
    "sequestram": "sequestrar",
    "sequestramo": "sequestrar",
    "sequestramos": "sequestrar",
    "sequestrando": "sequestrar",
    "sequestrara": "sequestrar",
    "sequestraram": "sequestrar",
    "sequestraras": "sequestrar",
    "sequestrarde": "sequestrar",
    "sequestrardes": "sequestrar",
    "sequestrare": "sequestrar",
    "sequestrarei": "sequestrar",
    "sequestrareis": "sequestrar",
    "sequestrarem": "sequestrar",
    "sequestraremos": "sequestrar",
    "sequestrares": "sequestrar",
    "sequestraria": "sequestrar",
    "sequestrariam": "sequestrar",
    "sequestrarias": "sequestrar",
    "sequestrarmo": "sequestrar",
    "sequestrarmos": "sequestrar",
    "sequestrará": "sequestrar",
    "sequestrarás": "sequestrar",
    "sequestrarão": "sequestrar",
    "sequestraríamos": "sequestrar",
    "sequestraríeis": "sequestrar",
    "sequestras": "sequestrar",
    "sequestrasse": "sequestrar",
    "sequestrassem": "sequestrar",
    "sequestrasses": "sequestrar",
    "sequestraste": "sequestrar",
    "sequestrastes": "sequestrar",
    "sequestrava": "sequestrar",
    "sequestravam": "sequestrar",
    "sequestravas": "sequestrar",
    "sequestrações": "sequestração",
    "sequestre": "sequestrar",
    "sequestrei": "sequestrar",
    "sequestreis": "sequestrar",
    "sequestrem": "sequestrar",
    "sequestremo": "sequestrar",
    "sequestremos": "sequestrar",
    "sequestres": "sequestrar",
    "sequestro": "sequestrar",
    "sequestros": "sequestro",
    "sequestrou": "sequestrar",
    "sequestrá": "sequestrar",
    "sequestrámo": "sequestrar",
    "sequestrámos": "sequestrar",
    "sequestráramo": "sequestrar",
    "sequestráramos": "sequestrar",
    "sequestrárei": "sequestrar",
    "sequestráreis": "sequestrar",
    "sequestrásseis": "sequestrar",
    "sequestrássemos": "sequestrar",
    "sequestrávamo": "sequestrar",
    "sequestrávamos": "sequestrar",
    "sequestrávei": "sequestrar",
    "sequestráveis": "sequestrável",
    "sequidões": "sequidão",
    "sequilhos": "sequilho",
    "sequinha": "seco",
    "sequinhas": "seco",
    "sequinho": "seco",
    "sequinhos": "seco",
    "sequiosa": "sequioso",
    "sequiosas": "sequioso",
    "sequiosos": "sequioso",
    "sequiosíssima": "sequioso",
    "sequiosíssimas": "sequioso",
    "sequiosíssimo": "sequioso",
    "sequiosíssimos": "sequioso",
    "sequistas": "sequista",
    "sequita": "seco",
    "sequitas": "seco",
    "sequito": "seco",
    "sequitos": "seco",
    "sequências": "sequência",
    "sequíssima": "seco",
    "sequíssimas": "seco",
    "sequíssimo": "seco",
    "sequíssimos": "seco",
    "sequóias": "sequóia",
    "seradiça": "seradiço",
    "seradiças": "seradiço",
    "seradiços": "seradiço",
    "serafanados": "serafanado",
    "serafinas": "serafina",
    "serafins": "serafim",
    "serais": "seral",
    "seramanga": "seramangar",
    "seramangada": "seramangar",
    "seramangadas": "seramangar",
    "seramangado": "seramangar",
    "seramangados": "seramangar",
    "seramangai": "seramangar",
    "seramangais": "seramangar",
    "seramangam": "seramangar",
    "seramangamo": "seramangar",
    "seramangamos": "seramangar",
    "seramangando": "seramangar",
    "seramangara": "seramangar",
    "seramangaram": "seramangar",
    "seramangaras": "seramangar",
    "seramangardes": "seramangar",
    "seramangarei": "seramangar",
    "seramangareis": "seramangar",
    "seramangarem": "seramangar",
    "seramangaremos": "seramangar",
    "seramangares": "seramangar",
    "seramangaria": "seramangar",
    "seramangariam": "seramangar",
    "seramangarias": "seramangar",
    "seramangarmo": "seramangar",
    "seramangarmos": "seramangar",
    "seramangará": "seramangar",
    "seramangarás": "seramangar",
    "seramangarão": "seramangar",
    "seramangaríamos": "seramangar",
    "seramangaríeis": "seramangar",
    "seramangas": "seramangar",
    "seramangasse": "seramangar",
    "seramangassem": "seramangar",
    "seramangasses": "seramangar",
    "seramangaste": "seramangar",
    "seramangastes": "seramangar",
    "seramangava": "seramangar",
    "seramangavam": "seramangar",
    "seramangavas": "seramangar",
    "seramango": "seramangar",
    "seramangou": "seramangar",
    "seramangue": "seramangar",
    "seramanguei": "seramangar",
    "seramangueis": "seramangar",
    "seramanguem": "seramangar",
    "seramanguemo": "seramangar",
    "seramanguemos": "seramangar",
    "seramangues": "seramangar",
    "seramangámo": "seramangar",
    "seramangámos": "seramangar",
    "seramangáramo": "seramangar",
    "seramangáramos": "seramangar",
    "seramangáreis": "seramangar",
    "seramangásseis": "seramangar",
    "seramangássemos": "seramangar",
    "seramangávamo": "seramangar",
    "seramangávamos": "seramangar",
    "seramangáveis": "seramangar",
    "seranda": "serandar",
    "serandada": "serandar",
    "serandadas": "serandar",
    "serandado": "serandar",
    "serandados": "serandar",
    "serandai": "serandar",
    "serandais": "serandar",
    "serandam": "serandar",
    "serandamo": "serandar",
    "serandamos": "serandar",
    "serandando": "serandar",
    "serandara": "serandar",
    "serandaram": "serandar",
    "serandaras": "serandar",
    "serandardes": "serandar",
    "serandarei": "serandar",
    "serandareis": "serandar",
    "serandarem": "serandar",
    "serandaremos": "serandar",
    "serandares": "serandar",
    "serandaria": "serandar",
    "serandariam": "serandar",
    "serandarias": "serandar",
    "serandarmo": "serandar",
    "serandarmos": "serandar",
    "serandará": "serandar",
    "serandarás": "serandar",
    "serandarão": "serandar",
    "serandaríamos": "serandar",
    "serandaríeis": "serandar",
    "serandas": "serandar",
    "serandasse": "serandar",
    "serandassem": "serandar",
    "serandasses": "serandar",
    "serandaste": "serandar",
    "serandastes": "serandar",
    "serandava": "serandar",
    "serandavam": "serandar",
    "serandavas": "serandar",
    "serande": "serandar",
    "serandei": "serandar",
    "serandeiroa": "serandeiroo",
    "serandeiroas": "serandeiroo",
    "serandeiroos": "serandeiroo",
    "serandeis": "serandar",
    "serandem": "serandar",
    "serandemo": "serandar",
    "serandemos": "serandar",
    "serandes": "serandar",
    "serando": "serandar",
    "serandou": "serandar",
    "serandámo": "serandar",
    "serandámos": "serandar",
    "serandáramo": "serandar",
    "serandáramos": "serandar",
    "serandáreis": "serandar",
    "serandásseis": "serandar",
    "serandássemos": "serandar",
    "serandávamo": "serandar",
    "serandávamos": "serandar",
    "serandáveis": "serandar",
    "seranza": "seranzar",
    "seranzada": "seranzar",
    "seranzadas": "seranzar",
    "seranzado": "seranzar",
    "seranzados": "seranzar",
    "seranzai": "seranzar",
    "seranzais": "seranzar",
    "seranzam": "seranzar",
    "seranzamo": "seranzar",
    "seranzamos": "seranzar",
    "seranzando": "seranzar",
    "seranzara": "seranzar",
    "seranzaram": "seranzar",
    "seranzaras": "seranzar",
    "seranzarde": "seranzar",
    "seranzardes": "seranzar",
    "seranzare": "seranzar",
    "seranzarei": "seranzar",
    "seranzareis": "seranzar",
    "seranzarem": "seranzar",
    "seranzaremos": "seranzar",
    "seranzares": "seranzar",
    "seranzaria": "seranzar",
    "seranzariam": "seranzar",
    "seranzarias": "seranzar",
    "seranzarmo": "seranzar",
    "seranzarmos": "seranzar",
    "seranzará": "seranzar",
    "seranzarás": "seranzar",
    "seranzarão": "seranzar",
    "seranzaríamos": "seranzar",
    "seranzaríeis": "seranzar",
    "seranzas": "seranzar",
    "seranzasse": "seranzar",
    "seranzassem": "seranzar",
    "seranzasses": "seranzar",
    "seranzaste": "seranzar",
    "seranzastes": "seranzar",
    "seranzava": "seranzar",
    "seranzavam": "seranzar",
    "seranzavas": "seranzar",
    "seranze": "seranzar",
    "seranzei": "seranzar",
    "seranzeis": "seranzar",
    "seranzem": "seranzar",
    "seranzemo": "seranzar",
    "seranzemos": "seranzar",
    "seranzes": "seranzar",
    "seranzo": "seranzar",
    "seranzou": "seranzar",
    "seranzá": "seranzar",
    "seranzámo": "seranzar",
    "seranzámos": "seranzar",
    "seranzáramo": "seranzar",
    "seranzáramos": "seranzar",
    "seranzárei": "seranzar",
    "seranzáreis": "seranzar",
    "seranzásseis": "seranzar",
    "seranzássemos": "seranzar",
    "seranzávamo": "seranzar",
    "seranzávamos": "seranzar",
    "seranzávei": "seranzar",
    "seranzáveis": "seranzar",
    "serapilheiras": "serapilheira",
    "serasmões": "serasmão",
    "serde": "ser",
    "serdes": "ser",
    "sere": "ser",
    "serei": "ser",
    "sereias": "sereia",
    "sereis": "ser",
    "serelepes": "serelepe",
    "serem": "ser",
    "seremos": "ser",
    "serena": "sereno",
    "serenada": "serenar",
    "serenadas": "serenar",
    "serenado": "serenar",
    "serenados": "serenar",
    "serenagens": "serenagem",
    "serenai": "serenar",
    "serenais": "serenar",
    "serenam": "serenar",
    "serenamo": "serenar",
    "serenamos": "serenar",
    "serenando": "serenar",
    "serenara": "serenar",
    "serenaram": "serenar",
    "serenaras": "serenar",
    "serenarde": "serenar",
    "serenardes": "serenar",
    "serenare": "serenar",
    "serenarei": "serenar",
    "serenareis": "serenar",
    "serenarem": "serenar",
    "serenaremos": "serenar",
    "serenares": "serenar",
    "serenaria": "serenar",
    "serenariam": "serenar",
    "serenarias": "serenar",
    "serenarmo": "serenar",
    "serenarmos": "serenar",
    "serenará": "serenar",
    "serenarás": "serenar",
    "serenarão": "serenar",
    "serenaríamos": "serenar",
    "serenaríeis": "serenar",
    "serenas": "sereno",
    "serenasse": "serenar",
    "serenassem": "serenar",
    "serenasses": "serenar",
    "serenaste": "serenar",
    "serenastes": "serenar",
    "serenatas": "serenata",
    "serenateira": "serenateiro",
    "serenateiras": "serenateiro",
    "serenateiros": "serenateiro",
    "serenava": "serenar",
    "serenavam": "serenar",
    "serenavas": "serenar",
    "serenazinha": "sereno",
    "serenazinhas": "sereno",
    "serenazita": "sereno",
    "serenazitas": "sereno",
    "serene": "serenar",
    "serenei": "serenar",
    "sereneis": "serenar",
    "serenem": "serenar",
    "serenemo": "serenar",
    "serenemos": "serenar",
    "serenes": "serenar",
    "serenidades": "serenidade",
    "sereninha": "sereno",
    "sereninhas": "sereno",
    "sereninho": "sereno",
    "sereninhos": "sereno",
    "serenins": "serenim",
    "serenita": "sereno",
    "serenitas": "sereno",
    "serenito": "sereno",
    "serenitos": "sereno",
    "sereno": "serenar",
    "serenos": "sereno",
    "serenou": "serenar",
    "serenozinho": "sereno",
    "serenozinhos": "sereno",
    "serenozito": "sereno",
    "serenozitos": "sereno",
    "serená": "serenar",
    "serenámo": "serenar",
    "serenámos": "serenar",
    "serenáramo": "serenar",
    "serenáramos": "serenar",
    "serenárei": "serenar",
    "serenáreis": "serenar",
    "serenásseis": "serenar",
    "serenássemos": "serenar",
    "serenávamo": "serenar",
    "serenávamos": "serenar",
    "serenávei": "serenar",
    "serenáveis": "serenar",
    "sereníssima": "sereno",
    "sereníssimas": "sereno",
    "sereníssimo": "sereno",
    "sereníssimos": "sereno",
    "seres": "ser",
    "seresmas": "seresma",
    "seresmos": "seresmo",
    "serezinos": "serezino",
    "sergetas": "sergeta",
    "sergipana": "sergipano",
    "sergipanas": "sergipano",
    "sergipanos": "sergipano",
    "serguilhas": "serguilha",
    "seria": "seriar",
    "seriada": "seriar",
    "seriadas": "seriar",
    "seriado": "seriar",
    "seriados": "seriar",
    "seriai": "seriar",
    "seriais": "seriar",
    "seriam": "seriar",
    "seriamas": "seriama",
    "seriamo": "seriar",
    "seriamos": "seriar",
    "seriando": "seriar",
    "seriara": "seriar",
    "seriaram": "seriar",
    "seriaras": "seriar",
    "seriarde": "seriar",
    "seriardes": "seriar",
    "seriare": "seriar",
    "seriarei": "seriar",
    "seriareis": "seriar",
    "seriarem": "seriar",
    "seriaremos": "seriar",
    "seriares": "seriar",
    "seriaria": "seriar",
    "seriariam": "seriar",
    "seriarias": "seriar",
    "seriarmo": "seriar",
    "seriarmos": "seriar",
    "seriará": "seriar",
    "seriarás": "seriar",
    "seriarão": "seriar",
    "seriaríamos": "seriar",
    "seriaríeis": "seriar",
    "serias": "seriar",
    "seriasse": "seriar",
    "seriassem": "seriar",
    "seriasses": "seriar",
    "seriaste": "seriar",
    "seriastes": "seriar",
    "seriava": "seriar",
    "seriavam": "seriar",
    "seriavas": "seriar",
    "seriazinha": "sério",
    "seriazinhas": "sério",
    "seriazita": "sério",
    "seriazitas": "sério",
    "seriações": "seriação",
    "sericaias": "sericaia",
    "sericicultora": "sericicultor",
    "sericicultoras": "sericicultor",
    "sericicultores": "sericicultor",
    "sericiculturas": "sericicultura",
    "sericinas": "sericina",
    "sericites": "sericite",
    "sericultora": "sericultor",
    "sericultoras": "sericultor",
    "sericultores": "sericultor",
    "sericulturas": "sericultura",
    "sericícolas": "sericícola",
    "sericífera": "sericífero",
    "sericíferas": "sericífero",
    "sericíferos": "sericífero",
    "sericígena": "sericígeno",
    "sericígenas": "sericígeno",
    "sericígenos": "sericígeno",
    "sericímetros": "sericímetro",
    "sericógena": "sericógeno",
    "sericógenas": "sericógeno",
    "sericógenos": "sericógeno",
    "serie": "seriar",
    "seriedades": "seriedade",
    "seriei": "seriar",
    "serieis": "seriar",
    "seriem": "seriar",
    "seriemas": "seriema",
    "seriemo": "seriar",
    "seriemos": "seriar",
    "series": "seriar",
    "serifas": "serifa",
    "serigaita": "serigaitar",
    "serigaitada": "serigaitar",
    "serigaitadas": "serigaitar",
    "serigaitado": "serigaitar",
    "serigaitados": "serigaitar",
    "serigaitai": "serigaitar",
    "serigaitais": "serigaitar",
    "serigaitam": "serigaitar",
    "serigaitamo": "serigaitar",
    "serigaitamos": "serigaitar",
    "serigaitando": "serigaitar",
    "serigaitara": "serigaitar",
    "serigaitaram": "serigaitar",
    "serigaitaras": "serigaitar",
    "serigaitardes": "serigaitar",
    "serigaitarei": "serigaitar",
    "serigaitareis": "serigaitar",
    "serigaitarem": "serigaitar",
    "serigaitaremos": "serigaitar",
    "serigaitares": "serigaitar",
    "serigaitaria": "serigaitar",
    "serigaitariam": "serigaitar",
    "serigaitarias": "serigaitar",
    "serigaitarmo": "serigaitar",
    "serigaitarmos": "serigaitar",
    "serigaitará": "serigaitar",
    "serigaitarás": "serigaitar",
    "serigaitarão": "serigaitar",
    "serigaitaríamos": "serigaitar",
    "serigaitaríeis": "serigaitar",
    "serigaitas": "serigaitar",
    "serigaitasse": "serigaitar",
    "serigaitassem": "serigaitar",
    "serigaitasses": "serigaitar",
    "serigaitaste": "serigaitar",
    "serigaitastes": "serigaitar",
    "serigaitava": "serigaitar",
    "serigaitavam": "serigaitar",
    "serigaitavas": "serigaitar",
    "serigaite": "serigaitar",
    "serigaitei": "serigaitar",
    "serigaiteis": "serigaitar",
    "serigaitem": "serigaitar",
    "serigaitemo": "serigaitar",
    "serigaitemos": "serigaitar",
    "serigaites": "serigaitar",
    "serigaito": "serigaitar",
    "serigaitou": "serigaitar",
    "serigaitámo": "serigaitar",
    "serigaitámos": "serigaitar",
    "serigaitáramo": "serigaitar",
    "serigaitáramos": "serigaitar",
    "serigaitáreis": "serigaitar",
    "serigaitásseis": "serigaitar",
    "serigaitássemos": "serigaitar",
    "serigaitávamo": "serigaitar",
    "serigaitávamos": "serigaitar",
    "serigaitáveis": "serigaitar",
    "serigarias": "serigaria",
    "serigrafa": "serigrafo",
    "serigrafas": "serigrafo",
    "serigrafias": "serigrafia",
    "serigrafistas": "serigrafista",
    "serigrafos": "serigrafo",
    "serigueiros": "serigueiro",
    "seriguilhas": "seriguilha",
    "serijos": "serijo",
    "serinas": "serina",
    "serinetas": "serineta",
    "serinfolhas": "serinfolha",
    "seringa": "seringar",
    "seringada": "seringar",
    "seringadas": "seringar",
    "seringadelas": "seringadela",
    "seringado": "seringar",
    "seringadora": "seringador",
    "seringadoras": "seringador",
    "seringadores": "seringador",
    "seringados": "seringar",
    "seringai": "seringar",
    "seringais": "seringar",
    "seringalistas": "seringalista",
    "seringam": "seringar",
    "seringamo": "seringar",
    "seringamos": "seringar",
    "seringando": "seringar",
    "seringara": "seringar",
    "seringaram": "seringar",
    "seringaras": "seringar",
    "seringarde": "seringar",
    "seringardes": "seringar",
    "seringare": "seringar",
    "seringarei": "seringar",
    "seringareis": "seringar",
    "seringarem": "seringar",
    "seringaremos": "seringar",
    "seringares": "seringar",
    "seringaria": "seringar",
    "seringariam": "seringar",
    "seringarias": "seringar",
    "seringarmo": "seringar",
    "seringarmos": "seringar",
    "seringará": "seringar",
    "seringarás": "seringar",
    "seringarão": "seringar",
    "seringaríamos": "seringar",
    "seringaríeis": "seringar",
    "seringas": "seringar",
    "seringasse": "seringar",
    "seringassem": "seringar",
    "seringasses": "seringar",
    "seringaste": "seringar",
    "seringastes": "seringar",
    "seringatória": "seringatório",
    "seringatórias": "seringatório",
    "seringatórios": "seringatório",
    "seringava": "seringar",
    "seringavam": "seringar",
    "seringavas": "seringar",
    "seringações": "seringação",
    "seringo": "seringar",
    "seringona": "seringão",
    "seringonas": "seringão",
    "seringou": "seringar",
    "seringue": "seringar",
    "seringuei": "seringar",
    "seringueira": "seringueiro",
    "seringueiras": "seringueiro",
    "seringueiros": "seringueiro",
    "seringueis": "seringar",
    "seringuem": "seringar",
    "seringuemo": "seringar",
    "seringuemos": "seringar",
    "seringues": "seringar",
    "seringá": "seringar",
    "seringámo": "seringar",
    "seringámos": "seringar",
    "seringáramo": "seringar",
    "seringáramos": "seringar",
    "seringárei": "seringar",
    "seringáreis": "seringar",
    "seringásseis": "seringar",
    "seringássemos": "seringar",
    "seringávamo": "seringar",
    "seringávamos": "seringar",
    "seringávei": "seringar",
    "seringáveis": "seringar",
    "seringões": "seringão",
    "serinos": "serino",
    "serio": "seriar",
    "seriou": "seriar",
    "seriozinho": "sério",
    "seriozinhos": "sério",
    "seriozito": "sério",
    "seriozitos": "sério",
    "seriá": "seriar",
    "seriámo": "seriar",
    "seriámos": "seriar",
    "seriáramo": "seriar",
    "seriáramos": "seriar",
    "seriárei": "seriar",
    "seriáreis": "seriar",
    "seriária": "seriário",
    "seriárias": "seriário",
    "seriários": "seriário",
    "seriásseis": "seriar",
    "seriássemos": "seriar",
    "seriávamo": "seriar",
    "seriávamos": "seriar",
    "seriávei": "seriar",
    "seriáveis": "seriar",
    "seriíssima": "sério",
    "seriíssimas": "sério",
    "seriíssimo": "sério",
    "seriíssimos": "sério",
    "sermo": "ser",
    "sermoas": "sermoa",
    "sermona": "sermonar",
    "sermonada": "sermonar",
    "sermonadas": "sermonar",
    "sermonado": "sermonar",
    "sermonados": "sermonar",
    "sermonai": "sermonar",
    "sermonais": "sermonar",
    "sermonam": "sermonar",
    "sermonamo": "sermonar",
    "sermonamos": "sermonar",
    "sermonando": "sermonar",
    "sermonara": "sermonar",
    "sermonaram": "sermonar",
    "sermonaras": "sermonar",
    "sermonarde": "sermonar",
    "sermonardes": "sermonar",
    "sermonare": "sermonar",
    "sermonarei": "sermonar",
    "sermonareis": "sermonar",
    "sermonarem": "sermonar",
    "sermonaremos": "sermonar",
    "sermonares": "sermonar",
    "sermonaria": "sermonar",
    "sermonariam": "sermonar",
    "sermonarias": "sermonar",
    "sermonarmo": "sermonar",
    "sermonarmos": "sermonar",
    "sermonará": "sermonar",
    "sermonarás": "sermonar",
    "sermonarão": "sermonar",
    "sermonaríamos": "sermonar",
    "sermonaríeis": "sermonar",
    "sermonas": "sermonar",
    "sermonasse": "sermonar",
    "sermonassem": "sermonar",
    "sermonasses": "sermonar",
    "sermonaste": "sermonar",
    "sermonastes": "sermonar",
    "sermonava": "sermonar",
    "sermonavam": "sermonar",
    "sermonavas": "sermonar",
    "sermone": "sermonar",
    "sermoneada": "sermonear",
    "sermoneadas": "sermonear",
    "sermoneado": "sermonear",
    "sermoneados": "sermonear",
    "sermoneai": "sermonear",
    "sermoneais": "sermonear",
    "sermoneamo": "sermonear",
    "sermoneamos": "sermonear",
    "sermoneando": "sermonear",
    "sermoneara": "sermonear",
    "sermonearam": "sermonear",
    "sermonearas": "sermonear",
    "sermoneardes": "sermonear",
    "sermonearei": "sermonear",
    "sermoneareis": "sermonear",
    "sermonearem": "sermonear",
    "sermonearemos": "sermonear",
    "sermoneares": "sermonear",
    "sermonearia": "sermonear",
    "sermoneariam": "sermonear",
    "sermonearias": "sermonear",
    "sermonearmo": "sermonear",
    "sermonearmos": "sermonear",
    "sermoneará": "sermonear",
    "sermonearás": "sermonear",
    "sermonearão": "sermonear",
    "sermonearíamos": "sermonear",
    "sermonearíeis": "sermonear",
    "sermoneasse": "sermonear",
    "sermoneassem": "sermonear",
    "sermoneasses": "sermonear",
    "sermoneaste": "sermonear",
    "sermoneastes": "sermonear",
    "sermoneava": "sermonear",
    "sermoneavam": "sermonear",
    "sermoneavas": "sermonear",
    "sermoneei": "sermonear",
    "sermoneeis": "sermonear",
    "sermoneemo": "sermonear",
    "sermoneemos": "sermonear",
    "sermonei": "sermonar",
    "sermoneia": "sermonear",
    "sermoneiam": "sermonear",
    "sermoneias": "sermonear",
    "sermoneie": "sermonear",
    "sermoneiem": "sermonear",
    "sermoneies": "sermonear",
    "sermoneio": "sermonear",
    "sermoneis": "sermonar",
    "sermonem": "sermonar",
    "sermonemo": "sermonar",
    "sermonemos": "sermonar",
    "sermoneou": "sermonear",
    "sermones": "sermonar",
    "sermoneámo": "sermonear",
    "sermoneámos": "sermonear",
    "sermoneáramo": "sermonear",
    "sermoneáramos": "sermonear",
    "sermoneáreis": "sermonear",
    "sermoneásseis": "sermonear",
    "sermoneássemos": "sermonear",
    "sermoneávamo": "sermonear",
    "sermoneávamos": "sermonear",
    "sermoneáveis": "sermonear",
    "sermono": "sermonar",
    "sermonou": "sermonar",
    "sermoná": "sermonar",
    "sermonámo": "sermonar",
    "sermonámos": "sermonar",
    "sermonáramo": "sermonar",
    "sermonáramos": "sermonar",
    "sermonárei": "sermonar",
    "sermonáreis": "sermonar",
    "sermonários": "sermonário",
    "sermonásseis": "sermonar",
    "sermonássemos": "sermonar",
    "sermonávamo": "sermonar",
    "sermonávamos": "sermonar",
    "sermonávei": "sermonar",
    "sermonáveis": "sermonar",
    "sermos": "ser",
    "sermões": "sermão",
    "seroa": "seroar",
    "seroada": "seroar",
    "seroadas": "seroar",
    "seroado": "seroar",
    "seroados": "seroar",
    "seroai": "seroar",
    "seroais": "seroar",
    "seroam": "seroar",
    "seroamo": "seroar",
    "seroamos": "seroar",
    "seroando": "seroar",
    "seroantes": "seroante",
    "seroara": "seroar",
    "seroaram": "seroar",
    "seroaras": "seroar",
    "seroardes": "seroar",
    "seroarei": "seroar",
    "seroareis": "seroar",
    "seroarem": "seroar",
    "seroaremos": "seroar",
    "seroares": "seroar",
    "seroaria": "seroar",
    "seroariam": "seroar",
    "seroarias": "seroar",
    "seroarmo": "seroar",
    "seroarmos": "seroar",
    "seroará": "seroar",
    "seroarás": "seroar",
    "seroarão": "seroar",
    "seroaríamos": "seroar",
    "seroaríeis": "seroar",
    "seroas": "seroar",
    "seroasse": "seroar",
    "seroassem": "seroar",
    "seroasses": "seroar",
    "seroaste": "seroar",
    "seroastes": "seroar",
    "seroava": "seroar",
    "seroavam": "seroar",
    "seroavas": "seroar",
    "seroe": "seroar",
    "seroei": "seroar",
    "seroeira": "seroeiro",
    "seroeiras": "seroeiro",
    "seroeiros": "seroeiro",
    "seroeis": "seroar",
    "seroem": "seroar",
    "seroemo": "seroar",
    "seroemos": "seroar",
    "seroes": "seroar",
    "serologias": "serologia",
    "serologistas": "serologista",
    "serológica": "serológico",
    "serológicas": "serológico",
    "serológicos": "serológico",
    "seronegativa": "seronegativo",
    "seronegativas": "seronegativo",
    "seronegativos": "seronegativo",
    "seroo": "seroar",
    "seroou": "seroar",
    "seropositiva": "seropositivo",
    "seropositivas": "seropositivo",
    "seropositividades": "seropositividade",
    "seropositivos": "seropositivo",
    "serosa": "seroso",
    "serosas": "seroso",
    "serosidades": "serosidade",
    "serosos": "seroso",
    "seroterapias": "seroterapia",
    "seroterápica": "seroterápico",
    "seroterápicas": "seroterápico",
    "seroterápicos": "seroterápico",
    "serotoninas": "serotonina",
    "seroámo": "seroar",
    "seroámos": "seroar",
    "seroáramo": "seroar",
    "seroáramos": "seroar",
    "seroáreis": "seroar",
    "seroásseis": "seroar",
    "seroássemos": "seroar",
    "seroávamo": "seroar",
    "seroávamos": "seroar",
    "seroáveis": "seroar",
    "serpeada": "serpear",
    "serpeadas": "serpear",
    "serpeado": "serpear",
    "serpeados": "serpear",
    "serpeai": "serpear",
    "serpeais": "serpear",
    "serpeamo": "serpear",
    "serpeamos": "serpear",
    "serpeando": "serpear",
    "serpeantes": "serpeante",
    "serpeara": "serpear",
    "serpearam": "serpear",
    "serpearas": "serpear",
    "serpeardes": "serpear",
    "serpearei": "serpear",
    "serpeareis": "serpear",
    "serpearem": "serpear",
    "serpearemos": "serpear",
    "serpeares": "serpear",
    "serpearia": "serpear",
    "serpeariam": "serpear",
    "serpearias": "serpear",
    "serpearmo": "serpear",
    "serpearmos": "serpear",
    "serpeará": "serpear",
    "serpearás": "serpear",
    "serpearão": "serpear",
    "serpearíamos": "serpear",
    "serpearíeis": "serpear",
    "serpeasse": "serpear",
    "serpeassem": "serpear",
    "serpeasses": "serpear",
    "serpeaste": "serpear",
    "serpeastes": "serpear",
    "serpeava": "serpear",
    "serpeavam": "serpear",
    "serpeavas": "serpear",
    "serpeei": "serpear",
    "serpeeis": "serpear",
    "serpeemo": "serpear",
    "serpeemos": "serpear",
    "serpeia": "serpear",
    "serpeiam": "serpear",
    "serpeias": "serpear",
    "serpeie": "serpear",
    "serpeiem": "serpear",
    "serpeies": "serpear",
    "serpeio": "serpear",
    "serpeja": "serpejar",
    "serpejada": "serpejar",
    "serpejadas": "serpejar",
    "serpejado": "serpejar",
    "serpejados": "serpejar",
    "serpejai": "serpejar",
    "serpejais": "serpejar",
    "serpejam": "serpejar",
    "serpejamo": "serpejar",
    "serpejamos": "serpejar",
    "serpejando": "serpejar",
    "serpejantes": "serpejante",
    "serpejara": "serpejar",
    "serpejaram": "serpejar",
    "serpejaras": "serpejar",
    "serpejardes": "serpejar",
    "serpejarei": "serpejar",
    "serpejareis": "serpejar",
    "serpejarem": "serpejar",
    "serpejaremos": "serpejar",
    "serpejares": "serpejar",
    "serpejaria": "serpejar",
    "serpejariam": "serpejar",
    "serpejarias": "serpejar",
    "serpejarmo": "serpejar",
    "serpejarmos": "serpejar",
    "serpejará": "serpejar",
    "serpejarás": "serpejar",
    "serpejarão": "serpejar",
    "serpejaríamos": "serpejar",
    "serpejaríeis": "serpejar",
    "serpejas": "serpejar",
    "serpejasse": "serpejar",
    "serpejassem": "serpejar",
    "serpejasses": "serpejar",
    "serpejaste": "serpejar",
    "serpejastes": "serpejar",
    "serpejava": "serpejar",
    "serpejavam": "serpejar",
    "serpejavas": "serpejar",
    "serpeje": "serpejar",
    "serpejei": "serpejar",
    "serpejeis": "serpejar",
    "serpejem": "serpejar",
    "serpejemo": "serpejar",
    "serpejemos": "serpejar",
    "serpejes": "serpejar",
    "serpejo": "serpejar",
    "serpejou": "serpejar",
    "serpejámo": "serpejar",
    "serpejámos": "serpejar",
    "serpejáramo": "serpejar",
    "serpejáramos": "serpejar",
    "serpejáreis": "serpejar",
    "serpejásseis": "serpejar",
    "serpejássemos": "serpejar",
    "serpejávamo": "serpejar",
    "serpejávamos": "serpejar",
    "serpejáveis": "serpejar",
    "serpenta": "serpentar",
    "serpentada": "serpentar",
    "serpentadas": "serpentar",
    "serpentado": "serpentar",
    "serpentados": "serpentar",
    "serpentai": "serpentar",
    "serpentais": "serpentar",
    "serpentam": "serpentar",
    "serpentamo": "serpentar",
    "serpentamos": "serpentar",
    "serpentando": "serpentar",
    "serpentara": "serpentar",
    "serpentaram": "serpentar",
    "serpentaras": "serpentar",
    "serpentardes": "serpentar",
    "serpentarei": "serpentar",
    "serpentareis": "serpentar",
    "serpentarem": "serpentar",
    "serpentaremos": "serpentar",
    "serpentares": "serpentar",
    "serpentaria": "serpentar",
    "serpentariam": "serpentar",
    "serpentarias": "serpentar",
    "serpentarmo": "serpentar",
    "serpentarmos": "serpentar",
    "serpentará": "serpentar",
    "serpentarás": "serpentar",
    "serpentarão": "serpentar",
    "serpentaríamos": "serpentar",
    "serpentaríeis": "serpentar",
    "serpentas": "serpentar",
    "serpentasse": "serpentar",
    "serpentassem": "serpentar",
    "serpentasses": "serpentar",
    "serpentaste": "serpentar",
    "serpentastes": "serpentar",
    "serpentava": "serpentar",
    "serpentavam": "serpentar",
    "serpentavas": "serpentar",
    "serpente": "serpentar",
    "serpenteada": "serpentear",
    "serpenteadas": "serpentear",
    "serpenteado": "serpentear",
    "serpenteados": "serpentear",
    "serpenteai": "serpentear",
    "serpenteais": "serpentear",
    "serpenteamo": "serpentear",
    "serpenteamos": "serpentear",
    "serpenteando": "serpentear",
    "serpenteantes": "serpenteante",
    "serpenteara": "serpentear",
    "serpentearam": "serpentear",
    "serpentearas": "serpentear",
    "serpenteardes": "serpentear",
    "serpentearei": "serpentear",
    "serpenteareis": "serpentear",
    "serpentearem": "serpentear",
    "serpentearemos": "serpentear",
    "serpenteares": "serpentear",
    "serpentearia": "serpentear",
    "serpenteariam": "serpentear",
    "serpentearias": "serpentear",
    "serpentearmo": "serpentear",
    "serpentearmos": "serpentear",
    "serpenteará": "serpentear",
    "serpentearás": "serpentear",
    "serpentearão": "serpentear",
    "serpentearíamos": "serpentear",
    "serpentearíeis": "serpentear",
    "serpenteasse": "serpentear",
    "serpenteassem": "serpentear",
    "serpenteasses": "serpentear",
    "serpenteaste": "serpentear",
    "serpenteastes": "serpentear",
    "serpenteava": "serpentear",
    "serpenteavam": "serpentear",
    "serpenteavas": "serpentear",
    "serpenteei": "serpentear",
    "serpenteeis": "serpentear",
    "serpenteemo": "serpentear",
    "serpenteemos": "serpentear",
    "serpentei": "serpentar",
    "serpenteia": "serpentear",
    "serpenteiam": "serpentear",
    "serpenteias": "serpentear",
    "serpenteie": "serpentear",
    "serpenteiem": "serpentear",
    "serpenteies": "serpentear",
    "serpenteio": "serpentear",
    "serpenteis": "serpentar",
    "serpentem": "serpentar",
    "serpentemo": "serpentar",
    "serpentemos": "serpentar",
    "serpenteou": "serpentear",
    "serpentes": "serpente",
    "serpenteámo": "serpentear",
    "serpenteámos": "serpentear",
    "serpenteáramo": "serpentear",
    "serpenteáramos": "serpentear",
    "serpenteáreis": "serpentear",
    "serpenteásseis": "serpentear",
    "serpenteássemos": "serpentear",
    "serpenteávamo": "serpentear",
    "serpenteávamos": "serpentear",
    "serpenteáveis": "serpentear",
    "serpenticidas": "serpenticida",
    "serpentiformes": "serpentiforme",
    "serpentina": "serpentino",
    "serpentinas": "serpentino",
    "serpentinites": "serpentinite",
    "serpentinos": "serpentino",
    "serpentinosa": "serpentinoso",
    "serpentinosas": "serpentinoso",
    "serpentinosos": "serpentinoso",
    "serpento": "serpentar",
    "serpentou": "serpentar",
    "serpentámo": "serpentar",
    "serpentámos": "serpentar",
    "serpentáramo": "serpentar",
    "serpentáramos": "serpentar",
    "serpentáreis": "serpentar",
    "serpentárias": "serpentária",
    "serpentários": "serpentário",
    "serpentásseis": "serpentar",
    "serpentássemos": "serpentar",
    "serpentávamo": "serpentar",
    "serpentávamos": "serpentar",
    "serpentáveis": "serpentar",
    "serpentífera": "serpentífero",
    "serpentíferas": "serpentífero",
    "serpentíferos": "serpentífero",
    "serpentígena": "serpentígeno",
    "serpentígenas": "serpentígeno",
    "serpentígenos": "serpentígeno",
    "serpentões": "serpentão",
    "serpeou": "serpear",
    "serpes": "serpe",
    "serpetes": "serpete",
    "serpeámo": "serpear",
    "serpeámos": "serpear",
    "serpeáramo": "serpear",
    "serpeáramos": "serpear",
    "serpeáreis": "serpear",
    "serpeásseis": "serpear",
    "serpeássemos": "serpear",
    "serpeávamo": "serpear",
    "serpeávamos": "serpear",
    "serpeáveis": "serpear",
    "serpilhos": "serpilho",
    "serpis": "serpil",
    "serpóis": "serpol",
    "serpões": "serpão",
    "serra": "serrar",
    "serrabulhos": "serrabulho",
    "serrada": "serrar",
    "serradas": "serrar",
    "serradelas": "serradela",
    "serrado": "serrar",
    "serradora": "serrador",
    "serradoras": "serrador",
    "serradores": "serrador",
    "serrados": "serrar",
    "serraduras": "serradura",
    "serragens": "serragem",
    "serrai": "serrar",
    "serrais": "serrar",
    "serralha": "serralhar",
    "serralhada": "serralhar",
    "serralhadas": "serralhar",
    "serralhado": "serralhar",
    "serralhados": "serralhar",
    "serralhai": "serralhar",
    "serralhais": "serralhar",
    "serralham": "serralhar",
    "serralhamo": "serralhar",
    "serralhamos": "serralhar",
    "serralhando": "serralhar",
    "serralhara": "serralhar",
    "serralharam": "serralhar",
    "serralharas": "serralhar",
    "serralharde": "serralhar",
    "serralhardes": "serralhar",
    "serralhare": "serralhar",
    "serralharei": "serralhar",
    "serralhareis": "serralhar",
    "serralharem": "serralhar",
    "serralharemos": "serralhar",
    "serralhares": "serralhar",
    "serralharia": "serralhar",
    "serralhariam": "serralhar",
    "serralharias": "serralharia",
    "serralharmo": "serralhar",
    "serralharmos": "serralhar",
    "serralhará": "serralhar",
    "serralharás": "serralhar",
    "serralharão": "serralhar",
    "serralharíamos": "serralhar",
    "serralharíeis": "serralhar",
    "serralhas": "serralhar",
    "serralhasse": "serralhar",
    "serralhassem": "serralhar",
    "serralhasses": "serralhar",
    "serralhaste": "serralhar",
    "serralhastes": "serralhar",
    "serralhava": "serralhar",
    "serralhavam": "serralhar",
    "serralhavas": "serralhar",
    "serralhe": "serralhar",
    "serralhei": "serralhar",
    "serralheira": "serralheiro",
    "serralheiras": "serralheiro",
    "serralheiros": "serralheiro",
    "serralheis": "serralhar",
    "serralhem": "serralhar",
    "serralhemo": "serralhar",
    "serralhemos": "serralhar",
    "serralhes": "serralhar",
    "serralho": "serralhar",
    "serralhos": "serralho",
    "serralhou": "serralhar",
    "serralhá": "serralhar",
    "serralhámo": "serralhar",
    "serralhámos": "serralhar",
    "serralháramo": "serralhar",
    "serralháramos": "serralhar",
    "serralhárei": "serralhar",
    "serralháreis": "serralhar",
    "serralhásseis": "serralhar",
    "serralhássemos": "serralhar",
    "serralhávamo": "serralhar",
    "serralhávamos": "serralhar",
    "serralhávei": "serralhar",
    "serralháveis": "serralhar",
    "serram": "serrar",
    "serramentos": "serramento",
    "serramo": "serrar",
    "serramos": "serrar",
    "serrana": "serrano",
    "serranas": "serrano",
    "serrando": "serrar",
    "serranias": "serrania",
    "serranices": "serranice",
    "serranilhas": "serranilha",
    "serranos": "serrano",
    "serranídeos": "serranídeo",
    "serrara": "serrar",
    "serraram": "serrar",
    "serraras": "serrar",
    "serrarde": "serrar",
    "serrardes": "serrar",
    "serrare": "serrar",
    "serrarei": "serrar",
    "serrareis": "serrar",
    "serrarem": "serrar",
    "serraremos": "serrar",
    "serrares": "serrar",
    "serraria": "serrar",
    "serrariam": "serrar",
    "serrarias": "serraria",
    "serrarmo": "serrar",
    "serrarmos": "serrar",
    "serrará": "serrar",
    "serrarás": "serrar",
    "serrarão": "serrar",
    "serraríamos": "serrar",
    "serraríeis": "serrar",
    "serras": "serrar",
    "serrasse": "serrar",
    "serrassem": "serrar",
    "serrasses": "serrar",
    "serraste": "serrar",
    "serrastes": "serrar",
    "serrava": "serrar",
    "serravam": "serrar",
    "serravas": "serrar",
    "serrazina": "serrazinar",
    "serrazinada": "serrazinar",
    "serrazinadas": "serrazinar",
    "serrazinado": "serrazinar",
    "serrazinados": "serrazinar",
    "serrazinai": "serrazinar",
    "serrazinais": "serrazinar",
    "serrazinam": "serrazinar",
    "serrazinamo": "serrazinar",
    "serrazinamos": "serrazinar",
    "serrazinando": "serrazinar",
    "serrazinara": "serrazinar",
    "serrazinaram": "serrazinar",
    "serrazinaras": "serrazinar",
    "serrazinarde": "serrazinar",
    "serrazinardes": "serrazinar",
    "serrazinare": "serrazinar",
    "serrazinarei": "serrazinar",
    "serrazinareis": "serrazinar",
    "serrazinarem": "serrazinar",
    "serrazinaremos": "serrazinar",
    "serrazinares": "serrazinar",
    "serrazinaria": "serrazinar",
    "serrazinariam": "serrazinar",
    "serrazinarias": "serrazinar",
    "serrazinarmo": "serrazinar",
    "serrazinarmos": "serrazinar",
    "serrazinará": "serrazinar",
    "serrazinarás": "serrazinar",
    "serrazinarão": "serrazinar",
    "serrazinaríamos": "serrazinar",
    "serrazinaríeis": "serrazinar",
    "serrazinas": "serrazinar",
    "serrazinasse": "serrazinar",
    "serrazinassem": "serrazinar",
    "serrazinasses": "serrazinar",
    "serrazinaste": "serrazinar",
    "serrazinastes": "serrazinar",
    "serrazinava": "serrazinar",
    "serrazinavam": "serrazinar",
    "serrazinavas": "serrazinar",
    "serrazine": "serrazinar",
    "serrazinei": "serrazinar",
    "serrazineis": "serrazinar",
    "serrazinem": "serrazinar",
    "serrazinemo": "serrazinar",
    "serrazinemos": "serrazinar",
    "serrazines": "serrazinar",
    "serrazino": "serrazinar",
    "serrazinou": "serrazinar",
    "serraziná": "serrazinar",
    "serrazinámo": "serrazinar",
    "serrazinámos": "serrazinar",
    "serrazináramo": "serrazinar",
    "serrazináramos": "serrazinar",
    "serrazinárei": "serrazinar",
    "serrazináreis": "serrazinar",
    "serrazinásseis": "serrazinar",
    "serrazinássemos": "serrazinar",
    "serrazinávamo": "serrazinar",
    "serrazinávamos": "serrazinar",
    "serrazinávei": "serrazinar",
    "serrazináveis": "serrazinar",
    "serrações": "serração",
    "serre": "serrar",
    "serreada": "serrear",
    "serreadas": "serrear",
    "serreado": "serrear",
    "serreados": "serrear",
    "serreai": "serrear",
    "serreais": "serrear",
    "serreamo": "serrear",
    "serreamos": "serrear",
    "serreando": "serrear",
    "serreara": "serrear",
    "serrearam": "serrear",
    "serrearas": "serrear",
    "serrearde": "serrear",
    "serreardes": "serrear",
    "serreare": "serrear",
    "serrearei": "serrear",
    "serreareis": "serrear",
    "serrearem": "serrear",
    "serrearemos": "serrear",
    "serreares": "serrear",
    "serrearia": "serrear",
    "serreariam": "serrear",
    "serrearias": "serrear",
    "serrearmo": "serrear",
    "serrearmos": "serrear",
    "serreará": "serrear",
    "serrearás": "serrear",
    "serrearão": "serrear",
    "serrearíamos": "serrear",
    "serrearíeis": "serrear",
    "serreasse": "serrear",
    "serreassem": "serrear",
    "serreasses": "serrear",
    "serreaste": "serrear",
    "serreastes": "serrear",
    "serreava": "serrear",
    "serreavam": "serrear",
    "serreavas": "serrear",
    "serreei": "serrear",
    "serreeis": "serrear",
    "serreemo": "serrear",
    "serreemos": "serrear",
    "serrei": "serrar",
    "serreia": "serrear",
    "serreiam": "serrear",
    "serreias": "serrear",
    "serreie": "serrear",
    "serreiem": "serrear",
    "serreies": "serrear",
    "serreio": "serrear",
    "serreis": "serrar",
    "serrem": "serrar",
    "serremo": "serrar",
    "serremos": "serrar",
    "serrenha": "serrenho",
    "serrenhas": "serrenho",
    "serrenhos": "serrenho",
    "serreou": "serrear",
    "serres": "serrar",
    "serretas": "serreta",
    "serreá": "serrear",
    "serreámo": "serrear",
    "serreámos": "serrear",
    "serreáramo": "serrear",
    "serreáramos": "serrear",
    "serreárei": "serrear",
    "serreáreis": "serrear",
    "serreásseis": "serrear",
    "serreássemos": "serrear",
    "serreávamo": "serrear",
    "serreávamos": "serrear",
    "serreávei": "serrear",
    "serreáveis": "serrear",
    "serricórnea": "serricórneo",
    "serricórneas": "serricórneo",
    "serricórneos": "serricórneo",
    "serridentada": "serridentado",
    "serridentadas": "serridentado",
    "serridentados": "serridentado",
    "serridêntea": "serridênteo",
    "serridênteas": "serridênteo",
    "serridênteos": "serridênteo",
    "serrilha": "serrilhar",
    "serrilhada": "serrilhar",
    "serrilhadas": "serrilhar",
    "serrilhado": "serrilhar",
    "serrilhadores": "serrilhador",
    "serrilhados": "serrilhar",
    "serrilhai": "serrilhar",
    "serrilhais": "serrilhar",
    "serrilham": "serrilhar",
    "serrilhamo": "serrilhar",
    "serrilhamos": "serrilhar",
    "serrilhando": "serrilhar",
    "serrilhara": "serrilhar",
    "serrilharam": "serrilhar",
    "serrilharas": "serrilhar",
    "serrilharde": "serrilhar",
    "serrilhardes": "serrilhar",
    "serrilhare": "serrilhar",
    "serrilharei": "serrilhar",
    "serrilhareis": "serrilhar",
    "serrilharem": "serrilhar",
    "serrilharemos": "serrilhar",
    "serrilhares": "serrilhar",
    "serrilharia": "serrilhar",
    "serrilhariam": "serrilhar",
    "serrilharias": "serrilhar",
    "serrilharmo": "serrilhar",
    "serrilharmos": "serrilhar",
    "serrilhará": "serrilhar",
    "serrilharás": "serrilhar",
    "serrilharão": "serrilhar",
    "serrilharíamos": "serrilhar",
    "serrilharíeis": "serrilhar",
    "serrilhas": "serrilhar",
    "serrilhasse": "serrilhar",
    "serrilhassem": "serrilhar",
    "serrilhasses": "serrilhar",
    "serrilhaste": "serrilhar",
    "serrilhastes": "serrilhar",
    "serrilhava": "serrilhar",
    "serrilhavam": "serrilhar",
    "serrilhavas": "serrilhar",
    "serrilhe": "serrilhar",
    "serrilhei": "serrilhar",
    "serrilheis": "serrilhar",
    "serrilhem": "serrilhar",
    "serrilhemo": "serrilhar",
    "serrilhemos": "serrilhar",
    "serrilhes": "serrilhar",
    "serrilho": "serrilhar",
    "serrilhos": "serrilho",
    "serrilhou": "serrilhar",
    "serrilhá": "serrilhar",
    "serrilhámo": "serrilhar",
    "serrilhámos": "serrilhar",
    "serrilháramo": "serrilhar",
    "serrilháramos": "serrilhar",
    "serrilhárei": "serrilhar",
    "serrilháreis": "serrilhar",
    "serrilhásseis": "serrilhar",
    "serrilhássemos": "serrilhar",
    "serrilhávamo": "serrilhar",
    "serrilhávamos": "serrilhar",
    "serrilhávei": "serrilhar",
    "serrilháveis": "serrilhar",
    "serrina": "serrino",
    "serrinas": "serrino",
    "serrinos": "serrino",
    "serrins": "serrim",
    "serrirrostra": "serrirrostro",
    "serrirrostras": "serrirrostro",
    "serrirrostros": "serrirrostro",
    "serris": "serril",
    "serro": "serrar",
    "serrobecos": "serrobeco",
    "serros": "serro",
    "serrota": "serrotar",
    "serrotada": "serrotar",
    "serrotadas": "serrotar",
    "serrotado": "serrotar",
    "serrotados": "serrotar",
    "serrotagens": "serrotagem",
    "serrotai": "serrotar",
    "serrotais": "serrotar",
    "serrotam": "serrotar",
    "serrotamo": "serrotar",
    "serrotamos": "serrotar",
    "serrotando": "serrotar",
    "serrotara": "serrotar",
    "serrotaram": "serrotar",
    "serrotaras": "serrotar",
    "serrotarde": "serrotar",
    "serrotardes": "serrotar",
    "serrotare": "serrotar",
    "serrotarei": "serrotar",
    "serrotareis": "serrotar",
    "serrotarem": "serrotar",
    "serrotaremos": "serrotar",
    "serrotares": "serrotar",
    "serrotaria": "serrotar",
    "serrotariam": "serrotar",
    "serrotarias": "serrotar",
    "serrotarmo": "serrotar",
    "serrotarmos": "serrotar",
    "serrotará": "serrotar",
    "serrotarás": "serrotar",
    "serrotarão": "serrotar",
    "serrotaríamos": "serrotar",
    "serrotaríeis": "serrotar",
    "serrotas": "serrotar",
    "serrotasse": "serrotar",
    "serrotassem": "serrotar",
    "serrotasses": "serrotar",
    "serrotaste": "serrotar",
    "serrotastes": "serrotar",
    "serrotava": "serrotar",
    "serrotavam": "serrotar",
    "serrotavas": "serrotar",
    "serrote": "serrotar",
    "serrotei": "serrotar",
    "serroteis": "serrotar",
    "serrotem": "serrotar",
    "serrotemo": "serrotar",
    "serrotemos": "serrotar",
    "serrotes": "serrote",
    "serroto": "serrotar",
    "serrotou": "serrotar",
    "serrotá": "serrotar",
    "serrotámo": "serrotar",
    "serrotámos": "serrotar",
    "serrotáramo": "serrotar",
    "serrotáramos": "serrotar",
    "serrotárei": "serrotar",
    "serrotáreis": "serrotar",
    "serrotásseis": "serrotar",
    "serrotássemos": "serrotar",
    "serrotávamo": "serrotar",
    "serrotávamos": "serrotar",
    "serrotávei": "serrotar",
    "serrotáveis": "serrotar",
    "serrou": "serrar",
    "serrá": "serrar",
    "serrámo": "serrar",
    "serrámos": "serrar",
    "serráramo": "serrar",
    "serráramos": "serrar",
    "serrárei": "serrar",
    "serráreis": "serrar",
    "serrásseis": "serrar",
    "serrássemos": "serrar",
    "serrátis": "serrátil",
    "serrávamo": "serrar",
    "serrávamos": "serrar",
    "serrávei": "serrar",
    "serráveis": "serrar",
    "serrânidas": "serrânida",
    "serrã": "serrão",
    "serrães": "serrão",
    "serrãos": "serrão",
    "serrãs": "serrão",
    "serrípedes": "serrípede",
    "serrões": "serrão",
    "sertainha": "sertainho",
    "sertainhas": "sertainho",
    "sertainhos": "sertainho",
    "sertaneja": "sertanejo",
    "sertanejas": "sertanejo",
    "sertanejos": "sertanejo",
    "sertanistas": "sertanista",
    "sertelas": "sertela",
    "sertelhas": "sertelha",
    "sertãs": "sertã",
    "sertões": "sertão",
    "serubunas": "serubuna",
    "serutingas": "serutinga",
    "serva": "servo",
    "servas": "servo",
    "servazinha": "servo",
    "servazinhas": "servo",
    "servazita": "servo",
    "servazitas": "servo",
    "serve": "servir",
    "servem": "servir",
    "serventes": "servente",
    "serventias": "serventia",
    "serventuária": "serventuário",
    "serventuárias": "serventuário",
    "serventuários": "serventuário",
    "serves": "servir",
    "servi": "servir",
    "servia": "servir",
    "serviam": "servir",
    "servias": "servir",
    "serviazinha": "sérvio",
    "serviazinhas": "sérvio",
    "serviazita": "sérvio",
    "serviazitas": "sérvio",
    "servicinho": "serviço",
    "servicinhos": "serviço",
    "servicito": "serviço",
    "servicitos": "serviço",
    "servida": "servir",
    "servidas": "servir",
    "servidiça": "servidiço",
    "servidiças": "servidiço",
    "servidiços": "servidiço",
    "servido": "servir",
    "servidora": "servidor",
    "servidoras": "servidor",
    "servidores": "servidor",
    "servidos": "servir",
    "servidíssima": "servido",
    "servidíssimas": "servido",
    "servidíssimo": "servido",
    "servidíssimos": "servido",
    "servidões": "servidão",
    "servientes": "serviente",
    "servilhas": "servilha",
    "servilheiros": "servilheiro",
    "servilhetas": "servilheta",
    "servilismos": "servilismo",
    "serviliza": "servilizar",
    "servilizada": "servilizar",
    "servilizadas": "servilizar",
    "servilizado": "servilizar",
    "servilizados": "servilizar",
    "servilizai": "servilizar",
    "servilizais": "servilizar",
    "servilizam": "servilizar",
    "servilizamo": "servilizar",
    "servilizamos": "servilizar",
    "servilizando": "servilizar",
    "servilizara": "servilizar",
    "servilizaram": "servilizar",
    "servilizaras": "servilizar",
    "servilizarde": "servilizar",
    "servilizardes": "servilizar",
    "servilizare": "servilizar",
    "servilizarei": "servilizar",
    "servilizareis": "servilizar",
    "servilizarem": "servilizar",
    "servilizaremos": "servilizar",
    "servilizares": "servilizar",
    "servilizaria": "servilizar",
    "servilizariam": "servilizar",
    "servilizarias": "servilizar",
    "servilizarmo": "servilizar",
    "servilizarmos": "servilizar",
    "servilizará": "servilizar",
    "servilizarás": "servilizar",
    "servilizarão": "servilizar",
    "servilizaríamos": "servilizar",
    "servilizaríeis": "servilizar",
    "servilizas": "servilizar",
    "servilizasse": "servilizar",
    "servilizassem": "servilizar",
    "servilizasses": "servilizar",
    "servilizaste": "servilizar",
    "servilizastes": "servilizar",
    "servilizava": "servilizar",
    "servilizavam": "servilizar",
    "servilizavas": "servilizar",
    "servilize": "servilizar",
    "servilizei": "servilizar",
    "servilizeis": "servilizar",
    "servilizem": "servilizar",
    "servilizemo": "servilizar",
    "servilizemos": "servilizar",
    "servilizes": "servilizar",
    "servilizo": "servilizar",
    "servilizou": "servilizar",
    "servilizá": "servilizar",
    "servilizámo": "servilizar",
    "servilizámos": "servilizar",
    "servilizáramo": "servilizar",
    "servilizáramos": "servilizar",
    "servilizárei": "servilizar",
    "servilizáreis": "servilizar",
    "servilizásseis": "servilizar",
    "servilizássemos": "servilizar",
    "servilizávamo": "servilizar",
    "servilizávamos": "servilizar",
    "servilizávei": "servilizar",
    "servilizáveis": "servilizar",
    "servilona": "servilão",
    "servilonas": "servilão",
    "servilões": "servilão",
    "servimo": "servir",
    "servimos": "servir",
    "servindo": "servir",
    "serviolas": "serviola",
    "serviozinho": "sérvio",
    "serviozinhos": "sérvio",
    "serviozito": "sérvio",
    "serviozitos": "sérvio",
    "servira": "servir",
    "serviram": "servir",
    "serviras": "servir",
    "servirde": "servir",
    "servirdes": "servir",
    "servire": "servir",
    "servirei": "servir",
    "servireis": "servir",
    "servirem": "servir",
    "serviremos": "servir",
    "servires": "servir",
    "serviria": "servir",
    "serviriam": "servir",
    "servirias": "servir",
    "servirmo": "servir",
    "servirmos": "servir",
    "servirá": "servir",
    "servirás": "servir",
    "servirão": "servir",
    "serviríamos": "servir",
    "serviríeis": "servir",
    "servis": "servir",
    "servisse": "servir",
    "servissem": "servir",
    "servisses": "servir",
    "serviste": "servir",
    "servistes": "servir",
    "servitas": "servita",
    "serviu": "servir",
    "serviçais": "serviçal",
    "serviçaizinhas": "serviçal",
    "serviçaizinhos": "serviçal",
    "serviçaizitas": "serviçal",
    "serviçaizitos": "serviçal",
    "serviçalzinha": "serviçal",
    "serviçalzinho": "serviçal",
    "serviçalzita": "serviçal",
    "serviçalzito": "serviçal",
    "serviços": "serviço",
    "servições": "servição",
    "servocomandos": "servocomando",
    "servofreios": "servofreio",
    "servomecanismos": "servomecanismo",
    "servomotores": "servomotor",
    "servos": "servo",
    "servossistemas": "servossistema",
    "servozinho": "servo",
    "servozinhos": "servo",
    "servozito": "servo",
    "servozitos": "servo",
    "servências": "servência",
    "servíamo": "servir",
    "servíamos": "servir",
    "servíei": "servir",
    "servíeis": "servir",
    "servíramo": "servir",
    "servíramos": "servir",
    "servírei": "servir",
    "servíreis": "servir",
    "servísseis": "servir",
    "servíssemos": "servir",
    "servíveis": "servível",
    "serzetas": "serzeta",
    "serzetes": "serzete",
    "serzinos": "serzino",
    "será": "ser",
    "seráfica": "seráfico",
    "seráficas": "seráfico",
    "seráficos": "seráfico",
    "serás": "ser",
    "serão": "ser",
    "seríamos": "ser",
    "serícea": "seríceo",
    "seríceas": "seríceo",
    "seríceos": "seríceo",
    "seríeis": "ser",
    "serôdia": "serôdio",
    "serôdias": "serôdio",
    "serôdios": "serôdio",
    "serões": "serão",
    "sesamóides": "sesamóide",
    "sesga": "sesgo",
    "sesgas": "sesgo",
    "sesgos": "sesgo",
    "sesimbroa": "sesimbrão",
    "sesimbroas": "sesimbrão",
    "sesimbrões": "sesimbrão",
    "sesma": "sesmar",
    "sesmada": "sesmar",
    "sesmadas": "sesmar",
    "sesmado": "sesmar",
    "sesmados": "sesmar",
    "sesmai": "sesmar",
    "sesmais": "sesmar",
    "sesmam": "sesmar",
    "sesmamo": "sesmar",
    "sesmamos": "sesmar",
    "sesmando": "sesmar",
    "sesmara": "sesmar",
    "sesmaram": "sesmar",
    "sesmaras": "sesmar",
    "sesmarde": "sesmar",
    "sesmardes": "sesmar",
    "sesmare": "sesmar",
    "sesmarei": "sesmar",
    "sesmareis": "sesmar",
    "sesmarem": "sesmar",
    "sesmaremos": "sesmar",
    "sesmares": "sesmar",
    "sesmaria": "sesmar",
    "sesmariam": "sesmar",
    "sesmarias": "sesmaria",
    "sesmarmo": "sesmar",
    "sesmarmos": "sesmar",
    "sesmará": "sesmar",
    "sesmarás": "sesmar",
    "sesmarão": "sesmar",
    "sesmaríamos": "sesmar",
    "sesmaríeis": "sesmar",
    "sesmas": "sesmar",
    "sesmasse": "sesmar",
    "sesmassem": "sesmar",
    "sesmasses": "sesmar",
    "sesmaste": "sesmar",
    "sesmastes": "sesmar",
    "sesmava": "sesmar",
    "sesmavam": "sesmar",
    "sesmavas": "sesmar",
    "sesme": "sesmar",
    "sesmei": "sesmar",
    "sesmeira": "sesmeiro",
    "sesmeiras": "sesmeiro",
    "sesmeiros": "sesmeiro",
    "sesmeis": "sesmar",
    "sesmem": "sesmar",
    "sesmemo": "sesmar",
    "sesmemos": "sesmar",
    "sesmes": "sesmar",
    "sesmo": "sesmar",
    "sesmos": "sesmo",
    "sesmou": "sesmar",
    "sesmá": "sesmar",
    "sesmámo": "sesmar",
    "sesmámos": "sesmar",
    "sesmáramo": "sesmar",
    "sesmáramos": "sesmar",
    "sesmárei": "sesmar",
    "sesmáreis": "sesmar",
    "sesmásseis": "sesmar",
    "sesmássemos": "sesmar",
    "sesmávamo": "sesmar",
    "sesmávamos": "sesmar",
    "sesmávei": "sesmar",
    "sesmáveis": "sesmar",
    "sesquipedais": "sesquipedal",
    "sesquitércia": "sesquitércio",
    "sesquitércias": "sesquitércio",
    "sesquitércios": "sesquitércio",
    "sesquiáltera": "sesquiáltero",
    "sesquiálteras": "sesquiáltero",
    "sesquiálteros": "sesquiáltero",
    "sesquióxidos": "sesquióxido",
    "sessa": "sessar",
    "sessada": "sessar",
    "sessadas": "sessar",
    "sessado": "sessar",
    "sessados": "sessar",
    "sessai": "sessar",
    "sessais": "sessar",
    "sessam": "sessar",
    "sessamentos": "sessamento",
    "sessamo": "sessar",
    "sessamos": "sessar",
    "sessando": "sessar",
    "sessara": "sessar",
    "sessaram": "sessar",
    "sessaras": "sessar",
    "sessarde": "sessar",
    "sessardes": "sessar",
    "sessare": "sessar",
    "sessarei": "sessar",
    "sessareis": "sessar",
    "sessarem": "sessar",
    "sessaremos": "sessar",
    "sessares": "sessar",
    "sessaria": "sessar",
    "sessariam": "sessar",
    "sessarias": "sessar",
    "sessarmo": "sessar",
    "sessarmos": "sessar",
    "sessará": "sessar",
    "sessarás": "sessar",
    "sessarão": "sessar",
    "sessaríamos": "sessar",
    "sessaríeis": "sessar",
    "sessas": "sessar",
    "sessasse": "sessar",
    "sessassem": "sessar",
    "sessasses": "sessar",
    "sessaste": "sessar",
    "sessastes": "sessar",
    "sessava": "sessar",
    "sessavam": "sessar",
    "sessavas": "sessar",
    "sessações": "sessação",
    "sesse": "sessar",
    "sessei": "sessar",
    "sesseis": "sessar",
    "sessem": "sessar",
    "sessemo": "sessar",
    "sessemos": "sessar",
    "sessentona": "sessentão",
    "sessentonas": "sessentão",
    "sessentões": "sessentão",
    "sesses": "sessar",
    "sessilfólia": "sessilfólio",
    "sessilfólias": "sessilfólio",
    "sessilfólios": "sessilfólio",
    "sessiliflora": "sessilifloro",
    "sessilifloras": "sessilifloro",
    "sessilifloros": "sessilifloro",
    "sessilifoliada": "sessilifoliado",
    "sessilifoliadas": "sessilifoliado",
    "sessilifoliados": "sessilifoliado",
    "sesso": "sessar",
    "sessos": "sesso",
    "sessou": "sessar",
    "sessá": "sessar",
    "sessámo": "sessar",
    "sessámos": "sessar",
    "sessáramo": "sessar",
    "sessáramos": "sessar",
    "sessárei": "sessar",
    "sessáreis": "sessar",
    "sessásseis": "sessar",
    "sessássemos": "sessar",
    "sessávamo": "sessar",
    "sessávamos": "sessar",
    "sessávei": "sessar",
    "sessáveis": "sessar",
    "sessões": "sessão",
    "sestas": "sesta",
    "sesteada": "sestear",
    "sesteadas": "sestear",
    "sesteado": "sestear",
    "sesteados": "sestear",
    "sesteai": "sestear",
    "sesteais": "sestear",
    "sesteamo": "sestear",
    "sesteamos": "sestear",
    "sesteando": "sestear",
    "sesteara": "sestear",
    "sestearam": "sestear",
    "sestearas": "sestear",
    "sestearde": "sestear",
    "sesteardes": "sestear",
    "sesteare": "sestear",
    "sestearei": "sestear",
    "sesteareis": "sestear",
    "sestearem": "sestear",
    "sestearemos": "sestear",
    "sesteares": "sestear",
    "sestearia": "sestear",
    "sesteariam": "sestear",
    "sestearias": "sestear",
    "sestearmo": "sestear",
    "sestearmos": "sestear",
    "sesteará": "sestear",
    "sestearás": "sestear",
    "sestearão": "sestear",
    "sestearíamos": "sestear",
    "sestearíeis": "sestear",
    "sesteasse": "sestear",
    "sesteassem": "sestear",
    "sesteasses": "sestear",
    "sesteaste": "sestear",
    "sesteastes": "sestear",
    "sesteava": "sestear",
    "sesteavam": "sestear",
    "sesteavas": "sestear",
    "sesteei": "sestear",
    "sesteeis": "sestear",
    "sesteemo": "sestear",
    "sesteemos": "sestear",
    "sesteia": "sestear",
    "sesteiam": "sestear",
    "sesteias": "sestear",
    "sesteie": "sestear",
    "sesteiem": "sestear",
    "sesteies": "sestear",
    "sesteio": "sestear",
    "sesteiros": "sesteiro",
    "sesteou": "sestear",
    "sesteá": "sestear",
    "sesteámo": "sestear",
    "sesteámos": "sestear",
    "sesteáramo": "sestear",
    "sesteáramos": "sestear",
    "sesteárei": "sestear",
    "sesteáreis": "sestear",
    "sesteásseis": "sestear",
    "sesteássemos": "sestear",
    "sesteávamo": "sestear",
    "sesteávamos": "sestear",
    "sesteávei": "sestear",
    "sesteáveis": "sestear",
    "sestra": "sestro",
    "sestras": "sestro",
    "sestros": "sestro",
    "sestrosa": "sestroso",
    "sestrosas": "sestroso",
    "sestrosos": "sestroso",
    "sestércios": "sestércio",
    "sesuda": "sesudo",
    "sesudas": "sesudo",
    "sesudos": "sesudo",
    "sesuviáceas": "sesuviácea",
    "setadas": "setada",
    "setas": "seta",
    "seteada": "setear",
    "seteadas": "setear",
    "seteado": "setear",
    "seteados": "setear",
    "seteai": "setear",
    "seteais": "setear",
    "seteamo": "setear",
    "seteamos": "setear",
    "seteando": "setear",
    "seteara": "setear",
    "setearam": "setear",
    "setearas": "setear",
    "setearde": "setear",
    "seteardes": "setear",
    "seteare": "setear",
    "setearei": "setear",
    "seteareis": "setear",
    "setearem": "setear",
    "setearemos": "setear",
    "seteares": "setear",
    "setearia": "setear",
    "seteariam": "setear",
    "setearias": "setear",
    "setearmo": "setear",
    "setearmos": "setear",
    "seteará": "setear",
    "setearás": "setear",
    "setearão": "setear",
    "setearíamos": "setear",
    "setearíeis": "setear",
    "seteasse": "setear",
    "seteassem": "setear",
    "seteasses": "setear",
    "seteaste": "setear",
    "seteastes": "setear",
    "seteava": "setear",
    "seteavam": "setear",
    "seteavas": "setear",
    "setecentas": "setecentos",
    "setecentenária": "setecentenário",
    "setecentenárias": "setecentenário",
    "setecentenários": "setecentenário",
    "setecentismos": "setecentismo",
    "setecentistas": "setecentista",
    "seteei": "setear",
    "seteeis": "setear",
    "seteemo": "setear",
    "seteemos": "setear",
    "seteia": "setear",
    "seteiam": "setear",
    "seteias": "setear",
    "seteie": "setear",
    "seteiem": "setear",
    "seteies": "setear",
    "seteio": "setear",
    "seteira": "seteiro",
    "seteiras": "seteiro",
    "seteirazinha": "seteiro",
    "seteirazinhas": "seteiro",
    "seteirazita": "seteiro",
    "seteirazitas": "seteiro",
    "seteiros": "seteiro",
    "seteirozinho": "seteiro",
    "seteirozinhos": "seteiro",
    "seteirozito": "seteiro",
    "seteirozitos": "seteiro",
    "setembradas": "setembrada",
    "setembrina": "setembrino",
    "setembrinas": "setembrino",
    "setembrinos": "setembrino",
    "setembrismos": "setembrismo",
    "setembristas": "setembrista",
    "setenada": "setenado",
    "setenadas": "setenado",
    "setenados": "setenado",
    "setentrionais": "setentrional",
    "seteou": "setear",
    "seteá": "setear",
    "seteámo": "setear",
    "seteámos": "setear",
    "seteáramo": "setear",
    "seteáramos": "setear",
    "seteárei": "setear",
    "seteáreis": "setear",
    "seteásseis": "setear",
    "seteássemos": "setear",
    "seteávamo": "setear",
    "seteávamos": "setear",
    "seteávei": "setear",
    "seteáveis": "setear",
    "setiais": "setial",
    "setias": "setia",
    "seticórnea": "seticórneo",
    "seticórneas": "seticórneo",
    "seticórneos": "seticórneo",
    "setiflora": "setifloro",
    "setifloras": "setifloro",
    "setifloros": "setifloro",
    "setiformes": "setiforme",
    "setilhas": "setilha",
    "setimanistas": "setimanista",
    "setinha": "seta",
    "setinhas": "seta",
    "setita": "seta",
    "setitas": "seta",
    "setoiras": "setoira",
    "setouras": "setoura",
    "sets": "set",
    "setubalenses": "setubalense",
    "setácea": "setáceo",
    "setáceas": "setáceo",
    "setáceos": "setáceo",
    "seténios": "seténio",
    "setífera": "setífero",
    "setíferas": "setífero",
    "setíferos": "setífero",
    "setígera": "setígero",
    "setígeras": "setígero",
    "setígeros": "setígero",
    "setúbais": "setúbal",
    "seus": "seu",
    "seva": "sevo",
    "sevada": "sevar",
    "sevadas": "sevar",
    "sevadeiras": "sevadeira",
    "sevado": "sevar",
    "sevados": "sevar",
    "sevai": "sevar",
    "sevais": "sevar",
    "sevam": "sevar",
    "sevamo": "sevar",
    "sevamos": "sevar",
    "sevandija": "sevandijar",
    "sevandijada": "sevandijar",
    "sevandijadas": "sevandijar",
    "sevandijado": "sevandijar",
    "sevandijados": "sevandijar",
    "sevandijai": "sevandijar",
    "sevandijais": "sevandijar",
    "sevandijam": "sevandijar",
    "sevandijamo": "sevandijar",
    "sevandijamos": "sevandijar",
    "sevandijando": "sevandijar",
    "sevandijara": "sevandijar",
    "sevandijaram": "sevandijar",
    "sevandijaras": "sevandijar",
    "sevandijarde": "sevandijar",
    "sevandijardes": "sevandijar",
    "sevandijare": "sevandijar",
    "sevandijarei": "sevandijar",
    "sevandijareis": "sevandijar",
    "sevandijarem": "sevandijar",
    "sevandijaremos": "sevandijar",
    "sevandijares": "sevandijar",
    "sevandijaria": "sevandijar",
    "sevandijariam": "sevandijar",
    "sevandijarias": "sevandijaria",
    "sevandijarmo": "sevandijar",
    "sevandijarmos": "sevandijar",
    "sevandijará": "sevandijar",
    "sevandijarás": "sevandijar",
    "sevandijarão": "sevandijar",
    "sevandijaríamos": "sevandijar",
    "sevandijaríeis": "sevandijar",
    "sevandijas": "sevandijar",
    "sevandijasse": "sevandijar",
    "sevandijassem": "sevandijar",
    "sevandijasses": "sevandijar",
    "sevandijaste": "sevandijar",
    "sevandijastes": "sevandijar",
    "sevandijava": "sevandijar",
    "sevandijavam": "sevandijar",
    "sevandijavas": "sevandijar",
    "sevandije": "sevandijar",
    "sevandijei": "sevandijar",
    "sevandijeis": "sevandijar",
    "sevandijem": "sevandijar",
    "sevandijemo": "sevandijar",
    "sevandijemos": "sevandijar",
    "sevandijes": "sevandijar",
    "sevandijo": "sevandijar",
    "sevandijou": "sevandijar",
    "sevandijá": "sevandijar",
    "sevandijámo": "sevandijar",
    "sevandijámos": "sevandijar",
    "sevandijáramo": "sevandijar",
    "sevandijáramos": "sevandijar",
    "sevandijárei": "sevandijar",
    "sevandijáreis": "sevandijar",
    "sevandijásseis": "sevandijar",
    "sevandijássemos": "sevandijar",
    "sevandijávamo": "sevandijar",
    "sevandijávamos": "sevandijar",
    "sevandijávei": "sevandijar",
    "sevandijáveis": "sevandijar",
    "sevando": "sevar",
    "sevara": "sevar",
    "sevaram": "sevar",
    "sevaras": "sevar",
    "sevarde": "sevar",
    "sevardes": "sevar",
    "sevare": "sevar",
    "sevarei": "sevar",
    "sevareis": "sevar",
    "sevarem": "sevar",
    "sevaremos": "sevar",
    "sevares": "sevar",
    "sevaria": "sevar",
    "sevariam": "sevar",
    "sevarias": "sevar",
    "sevarmo": "sevar",
    "sevarmos": "sevar",
    "sevará": "sevar",
    "sevarás": "sevar",
    "sevarão": "sevar",
    "sevaríamos": "sevar",
    "sevaríeis": "sevar",
    "sevas": "sevo",
    "sevasse": "sevar",
    "sevassem": "sevar",
    "sevasses": "sevar",
    "sevaste": "sevar",
    "sevastes": "sevar",
    "sevava": "sevar",
    "sevavam": "sevar",
    "sevavas": "sevar",
    "seve": "sevar",
    "sevei": "sevar",
    "seveis": "sevar",
    "sevem": "sevar",
    "sevemo": "sevar",
    "sevemos": "sevar",
    "severa": "severo",
    "severas": "severo",
    "severidades": "severidade",
    "severinos": "severino",
    "severites": "severite",
    "severiza": "severizar",
    "severizada": "severizar",
    "severizadas": "severizar",
    "severizado": "severizar",
    "severizados": "severizar",
    "severizai": "severizar",
    "severizais": "severizar",
    "severizam": "severizar",
    "severizamo": "severizar",
    "severizamos": "severizar",
    "severizando": "severizar",
    "severizara": "severizar",
    "severizaram": "severizar",
    "severizaras": "severizar",
    "severizarde": "severizar",
    "severizardes": "severizar",
    "severizare": "severizar",
    "severizarei": "severizar",
    "severizareis": "severizar",
    "severizarem": "severizar",
    "severizaremos": "severizar",
    "severizares": "severizar",
    "severizaria": "severizar",
    "severizariam": "severizar",
    "severizarias": "severizar",
    "severizarmo": "severizar",
    "severizarmos": "severizar",
    "severizará": "severizar",
    "severizarás": "severizar",
    "severizarão": "severizar",
    "severizaríamos": "severizar",
    "severizaríeis": "severizar",
    "severizas": "severizar",
    "severizasse": "severizar",
    "severizassem": "severizar",
    "severizasses": "severizar",
    "severizaste": "severizar",
    "severizastes": "severizar",
    "severizava": "severizar",
    "severizavam": "severizar",
    "severizavas": "severizar",
    "severize": "severizar",
    "severizei": "severizar",
    "severizeis": "severizar",
    "severizem": "severizar",
    "severizemo": "severizar",
    "severizemos": "severizar",
    "severizes": "severizar",
    "severizo": "severizar",
    "severizou": "severizar",
    "severizá": "severizar",
    "severizámo": "severizar",
    "severizámos": "severizar",
    "severizáramo": "severizar",
    "severizáramos": "severizar",
    "severizárei": "severizar",
    "severizáreis": "severizar",
    "severizásseis": "severizar",
    "severizássemos": "severizar",
    "severizávamo": "severizar",
    "severizávamos": "severizar",
    "severizávei": "severizar",
    "severizáveis": "severizar",
    "severos": "severo",
    "severíssima": "severo",
    "severíssimas": "severo",
    "severíssimo": "severo",
    "severíssimos": "severo",
    "seves": "sevar",
    "sevicia": "seviciar",
    "seviciada": "seviciar",
    "seviciadas": "seviciar",
    "seviciado": "seviciar",
    "seviciados": "seviciar",
    "seviciai": "seviciar",
    "seviciais": "seviciar",
    "seviciam": "seviciar",
    "seviciamo": "seviciar",
    "seviciamos": "seviciar",
    "seviciando": "seviciar",
    "seviciara": "seviciar",
    "seviciaram": "seviciar",
    "seviciaras": "seviciar",
    "seviciarde": "seviciar",
    "seviciardes": "seviciar",
    "seviciare": "seviciar",
    "seviciarei": "seviciar",
    "seviciareis": "seviciar",
    "seviciarem": "seviciar",
    "seviciaremos": "seviciar",
    "seviciares": "seviciar",
    "seviciaria": "seviciar",
    "seviciariam": "seviciar",
    "seviciarias": "seviciar",
    "seviciarmo": "seviciar",
    "seviciarmos": "seviciar",
    "seviciará": "seviciar",
    "seviciarás": "seviciar",
    "seviciarão": "seviciar",
    "seviciaríamos": "seviciar",
    "seviciaríeis": "seviciar",
    "sevicias": "seviciar",
    "seviciasse": "seviciar",
    "seviciassem": "seviciar",
    "seviciasses": "seviciar",
    "seviciaste": "seviciar",
    "seviciastes": "seviciar",
    "seviciava": "seviciar",
    "seviciavam": "seviciar",
    "seviciavas": "seviciar",
    "sevicie": "seviciar",
    "seviciei": "seviciar",
    "sevicieis": "seviciar",
    "seviciem": "seviciar",
    "seviciemo": "seviciar",
    "seviciemos": "seviciar",
    "sevicies": "seviciar",
    "sevicio": "seviciar",
    "seviciou": "seviciar",
    "seviciá": "seviciar",
    "seviciámo": "seviciar",
    "seviciámos": "seviciar",
    "seviciáramo": "seviciar",
    "seviciáramos": "seviciar",
    "seviciárei": "seviciar",
    "seviciáreis": "seviciar",
    "seviciásseis": "seviciar",
    "seviciássemos": "seviciar",
    "seviciávamo": "seviciar",
    "seviciávamos": "seviciar",
    "seviciávei": "seviciar",
    "seviciáveis": "seviciar",
    "sevilhana": "sevilhano",
    "sevilhanas": "sevilhano",
    "sevilhanazinha": "sevilhano",
    "sevilhanazinhas": "sevilhano",
    "sevilhanazita": "sevilhano",
    "sevilhanazitas": "sevilhano",
    "sevilhanos": "sevilhano",
    "sevilhanozinho": "sevilhano",
    "sevilhanozinhos": "sevilhano",
    "sevilhanozito": "sevilhano",
    "sevilhanozitos": "sevilhano",
    "sevo": "sevar",
    "sevos": "sevo",
    "sevou": "sevar",
    "sevress": "sevres",
    "sevá": "sevar",
    "sevámo": "sevar",
    "sevámos": "sevar",
    "seváramo": "sevar",
    "seváramos": "sevar",
    "sevárei": "sevar",
    "seváreis": "sevar",
    "sevásseis": "sevar",
    "sevássemos": "sevar",
    "sevávamo": "sevar",
    "sevávamos": "sevar",
    "sevávei": "sevar",
    "seváveis": "sevar",
    "sevícias": "sevícia",
    "sexagenariazinha": "sexagenário",
    "sexagenariazinhas": "sexagenário",
    "sexagenariazita": "sexagenário",
    "sexagenariazitas": "sexagenário",
    "sexagenariozinho": "sexagenário",
    "sexagenariozinhos": "sexagenário",
    "sexagenariozito": "sexagenário",
    "sexagenariozitos": "sexagenário",
    "sexagenária": "sexagenário",
    "sexagenárias": "sexagenário",
    "sexagenários": "sexagenário",
    "sexagesimais": "sexagesimal",
    "sexagésima": "sexagésimo",
    "sexagésimais": "sexagésimal",
    "sexagésimas": "sexagésimo",
    "sexagésimos": "sexagésimo",
    "sexangulada": "sexangulado",
    "sexanguladas": "sexangulado",
    "sexangulados": "sexangulado",
    "sexangulares": "sexangular",
    "sexcentésima": "sexcentésimo",
    "sexcentésimas": "sexcentésimo",
    "sexcentésimos": "sexcentésimo",
    "sexdigitada": "sexdigitado",
    "sexdigitadas": "sexdigitado",
    "sexdigitados": "sexdigitado",
    "sexdigitais": "sexdigital",
    "sexdigitismos": "sexdigitismo",
    "sexdigitária": "sexdigitário",
    "sexdigitárias": "sexdigitário",
    "sexdigitários": "sexdigitário",
    "sexenais": "sexenal",
    "sexies": "sexy",
    "sexiparidades": "sexiparidade",
    "sexismos": "sexismo",
    "sexistas": "sexista",
    "sexoduções": "sexodução",
    "sexofobias": "sexofobia",
    "sexologias": "sexologia",
    "sexologistas": "sexologista",
    "sexos": "sexo",
    "sexta": "sexto",
    "sextanistas": "sextanista",
    "sextantes": "sextante",
    "sextas": "sexto",
    "sextava": "sextavar",
    "sextavada": "sextavar",
    "sextavadas": "sextavar",
    "sextavado": "sextavar",
    "sextavados": "sextavar",
    "sextavai": "sextavar",
    "sextavais": "sextavar",
    "sextavam": "sextavar",
    "sextavamo": "sextavar",
    "sextavamos": "sextavar",
    "sextavando": "sextavar",
    "sextavara": "sextavar",
    "sextavaram": "sextavar",
    "sextavaras": "sextavar",
    "sextavarde": "sextavar",
    "sextavardes": "sextavar",
    "sextavare": "sextavar",
    "sextavarei": "sextavar",
    "sextavareis": "sextavar",
    "sextavarem": "sextavar",
    "sextavaremos": "sextavar",
    "sextavares": "sextavar",
    "sextavaria": "sextavar",
    "sextavariam": "sextavar",
    "sextavarias": "sextavar",
    "sextavarmo": "sextavar",
    "sextavarmos": "sextavar",
    "sextavará": "sextavar",
    "sextavarás": "sextavar",
    "sextavarão": "sextavar",
    "sextavaríamos": "sextavar",
    "sextavaríeis": "sextavar",
    "sextavas": "sextavar",
    "sextavasse": "sextavar",
    "sextavassem": "sextavar",
    "sextavasses": "sextavar",
    "sextavaste": "sextavar",
    "sextavastes": "sextavar",
    "sextavava": "sextavar",
    "sextavavam": "sextavar",
    "sextavavas": "sextavar",
    "sextave": "sextavar",
    "sextavei": "sextavar",
    "sextaveis": "sextavar",
    "sextavem": "sextavar",
    "sextavemo": "sextavar",
    "sextavemos": "sextavar",
    "sextaves": "sextavar",
    "sextavo": "sextavar",
    "sextavou": "sextavar",
    "sextavá": "sextavar",
    "sextavámo": "sextavar",
    "sextavámos": "sextavar",
    "sextaváramo": "sextavar",
    "sextaváramos": "sextavar",
    "sextavárei": "sextavar",
    "sextaváreis": "sextavar",
    "sextavásseis": "sextavar",
    "sextavássemos": "sextavar",
    "sextavávamo": "sextavar",
    "sextavávamos": "sextavar",
    "sextavávei": "sextavar",
    "sextaváveis": "sextavar",
    "sextetos": "sexteto",
    "sextilhas": "sextilha",
    "sextiliões": "sextilião",
    "sextinas": "sextina",
    "sextos": "sexto",
    "sextupletas": "sextupleta",
    "sextuplica": "sextuplicar",
    "sextuplicada": "sextuplicar",
    "sextuplicadas": "sextuplicar",
    "sextuplicado": "sextuplicar",
    "sextuplicados": "sextuplicar",
    "sextuplicai": "sextuplicar",
    "sextuplicais": "sextuplicar",
    "sextuplicam": "sextuplicar",
    "sextuplicamo": "sextuplicar",
    "sextuplicamos": "sextuplicar",
    "sextuplicando": "sextuplicar",
    "sextuplicara": "sextuplicar",
    "sextuplicaram": "sextuplicar",
    "sextuplicaras": "sextuplicar",
    "sextuplicarde": "sextuplicar",
    "sextuplicardes": "sextuplicar",
    "sextuplicare": "sextuplicar",
    "sextuplicarei": "sextuplicar",
    "sextuplicareis": "sextuplicar",
    "sextuplicarem": "sextuplicar",
    "sextuplicaremos": "sextuplicar",
    "sextuplicares": "sextuplicar",
    "sextuplicaria": "sextuplicar",
    "sextuplicariam": "sextuplicar",
    "sextuplicarias": "sextuplicar",
    "sextuplicarmo": "sextuplicar",
    "sextuplicarmos": "sextuplicar",
    "sextuplicará": "sextuplicar",
    "sextuplicarás": "sextuplicar",
    "sextuplicarão": "sextuplicar",
    "sextuplicaríamos": "sextuplicar",
    "sextuplicaríeis": "sextuplicar",
    "sextuplicas": "sextuplicar",
    "sextuplicasse": "sextuplicar",
    "sextuplicassem": "sextuplicar",
    "sextuplicasses": "sextuplicar",
    "sextuplicaste": "sextuplicar",
    "sextuplicastes": "sextuplicar",
    "sextuplicava": "sextuplicar",
    "sextuplicavam": "sextuplicar",
    "sextuplicavas": "sextuplicar",
    "sextuplicações": "sextuplicação",
    "sextuplico": "sextuplicar",
    "sextuplicou": "sextuplicar",
    "sextuplicá": "sextuplicar",
    "sextuplicámo": "sextuplicar",
    "sextuplicámos": "sextuplicar",
    "sextuplicáramo": "sextuplicar",
    "sextuplicáramos": "sextuplicar",
    "sextuplicárei": "sextuplicar",
    "sextuplicáreis": "sextuplicar",
    "sextuplicásseis": "sextuplicar",
    "sextuplicássemos": "sextuplicar",
    "sextuplicávamo": "sextuplicar",
    "sextuplicávamos": "sextuplicar",
    "sextuplicávei": "sextuplicar",
    "sextuplicáveis": "sextuplicável",
    "sextuplique": "sextuplicar",
    "sextupliquei": "sextuplicar",
    "sextupliqueis": "sextuplicar",
    "sextupliquem": "sextuplicar",
    "sextupliquemo": "sextuplicar",
    "sextupliquemos": "sextuplicar",
    "sextupliques": "sextuplicar",
    "sexturas": "sextura",
    "sextários": "sextário",
    "sexuada": "sexuado",
    "sexuadas": "sexuado",
    "sexuados": "sexuado",
    "sexuadíssima": "sexuado",
    "sexuadíssimas": "sexuado",
    "sexuadíssimo": "sexuado",
    "sexuadíssimos": "sexuado",
    "sexuais": "sexual",
    "sexualidades": "sexualidade",
    "sexualismos": "sexualismo",
    "sexualistas": "sexualista",
    "sexualiza": "sexualizar",
    "sexualizada": "sexualizar",
    "sexualizadas": "sexualizar",
    "sexualizado": "sexualizar",
    "sexualizados": "sexualizar",
    "sexualizai": "sexualizar",
    "sexualizais": "sexualizar",
    "sexualizam": "sexualizar",
    "sexualizamo": "sexualizar",
    "sexualizamos": "sexualizar",
    "sexualizando": "sexualizar",
    "sexualizara": "sexualizar",
    "sexualizaram": "sexualizar",
    "sexualizaras": "sexualizar",
    "sexualizarde": "sexualizar",
    "sexualizardes": "sexualizar",
    "sexualizare": "sexualizar",
    "sexualizarei": "sexualizar",
    "sexualizareis": "sexualizar",
    "sexualizarem": "sexualizar",
    "sexualizaremos": "sexualizar",
    "sexualizares": "sexualizar",
    "sexualizaria": "sexualizar",
    "sexualizariam": "sexualizar",
    "sexualizarias": "sexualizar",
    "sexualizarmo": "sexualizar",
    "sexualizarmos": "sexualizar",
    "sexualizará": "sexualizar",
    "sexualizarás": "sexualizar",
    "sexualizarão": "sexualizar",
    "sexualizaríamos": "sexualizar",
    "sexualizaríeis": "sexualizar",
    "sexualizas": "sexualizar",
    "sexualizasse": "sexualizar",
    "sexualizassem": "sexualizar",
    "sexualizasses": "sexualizar",
    "sexualizaste": "sexualizar",
    "sexualizastes": "sexualizar",
    "sexualizava": "sexualizar",
    "sexualizavam": "sexualizar",
    "sexualizavas": "sexualizar",
    "sexualize": "sexualizar",
    "sexualizei": "sexualizar",
    "sexualizeis": "sexualizar",
    "sexualizem": "sexualizar",
    "sexualizemo": "sexualizar",
    "sexualizemos": "sexualizar",
    "sexualizes": "sexualizar",
    "sexualizo": "sexualizar",
    "sexualizou": "sexualizar",
    "sexualizá": "sexualizar",
    "sexualizámo": "sexualizar",
    "sexualizámos": "sexualizar",
    "sexualizáramo": "sexualizar",
    "sexualizáramos": "sexualizar",
    "sexualizárei": "sexualizar",
    "sexualizáreis": "sexualizar",
    "sexualizásseis": "sexualizar",
    "sexualizássemos": "sexualizar",
    "sexualizávamo": "sexualizar",
    "sexualizávamos": "sexualizar",
    "sexualizávei": "sexualizar",
    "sexualizáveis": "sexualizar",
    "sexângula": "sexângulo",
    "sexângulas": "sexângulo",
    "sexângulos": "sexângulo",
    "sexénios": "sexénio",
    "sexóloga": "sexólogo",
    "sexólogas": "sexólogo",
    "sexólogos": "sexólogo",
    "sezoa": "sezoar",
    "sezoada": "sezoar",
    "sezoadas": "sezoar",
    "sezoado": "sezoar",
    "sezoados": "sezoar",
    "sezoai": "sezoar",
    "sezoais": "sezoar",
    "sezoam": "sezoar",
    "sezoamo": "sezoar",
    "sezoamos": "sezoar",
    "sezoando": "sezoar",
    "sezoara": "sezoar",
    "sezoaram": "sezoar",
    "sezoaras": "sezoar",
    "sezoardes": "sezoar",
    "sezoarei": "sezoar",
    "sezoareis": "sezoar",
    "sezoarem": "sezoar",
    "sezoaremos": "sezoar",
    "sezoares": "sezoar",
    "sezoaria": "sezoar",
    "sezoariam": "sezoar",
    "sezoarias": "sezoar",
    "sezoarmo": "sezoar",
    "sezoarmos": "sezoar",
    "sezoará": "sezoar",
    "sezoarás": "sezoar",
    "sezoarão": "sezoar",
    "sezoaríamos": "sezoar",
    "sezoaríeis": "sezoar",
    "sezoas": "sezoar",
    "sezoasse": "sezoar",
    "sezoassem": "sezoar",
    "sezoasses": "sezoar",
    "sezoaste": "sezoar",
    "sezoastes": "sezoar",
    "sezoava": "sezoar",
    "sezoavam": "sezoar",
    "sezoavas": "sezoar",
    "sezoe": "sezoar",
    "sezoei": "sezoar",
    "sezoeis": "sezoar",
    "sezoem": "sezoar",
    "sezoemo": "sezoar",
    "sezoemos": "sezoar",
    "sezoes": "sezoar",
    "sezonada": "sezonado",
    "sezonadas": "sezonado",
    "sezonados": "sezonado",
    "sezonais": "sezonal",
    "sezonismos": "sezonismo",
    "sezonologias": "sezonologia",
    "sezonologistas": "sezonologista",
    "sezonática": "sezonático",
    "sezonáticas": "sezonático",
    "sezonáticos": "sezonático",
    "sezonígena": "sezonígeno",
    "sezonígenas": "sezonígeno",
    "sezonígenos": "sezonígeno",
    "sezoo": "sezoar",
    "sezoou": "sezoar",
    "sezoámo": "sezoar",
    "sezoámos": "sezoar",
    "sezoáramo": "sezoar",
    "sezoáramos": "sezoar",
    "sezoáreis": "sezoar",
    "sezoásseis": "sezoar",
    "sezoássemos": "sezoar",
    "sezoávamo": "sezoar",
    "sezoávamos": "sezoar",
    "sezoáveis": "sezoar",
    "sezónica": "sezónico",
    "sezónicas": "sezónico",
    "sezónicos": "sezónico",
    "sezões": "sezão",
    "shabats": "shabat",
    "shakespeariana": "shakespeariano",
    "shakespearianas": "shakespeariano",
    "shakespearianos": "shakespeariano",
    "shakesperiana": "shakesperiano",
    "shakesperianas": "shakesperiano",
    "shakesperianos": "shakesperiano",
    "shares": "share",
    "shenquinites": "shenquinite",
    "sherries": "sherry",
    "shirts": "shirt",
    "shonquinites": "shonquinite",
    "shoppings": "shopping",
    "shorts": "short",
    "shotes": "shot",
    "shows": "show",
    "shunta": "shuntar",
    "shuntada": "shuntar",
    "shuntadas": "shuntar",
    "shuntado": "shuntar",
    "shuntados": "shuntar",
    "shuntai": "shuntar",
    "shuntais": "shuntar",
    "shuntam": "shuntar",
    "shuntamo": "shuntar",
    "shuntamos": "shuntar",
    "shuntando": "shuntar",
    "shuntara": "shuntar",
    "shuntaram": "shuntar",
    "shuntaras": "shuntar",
    "shuntarde": "shuntar",
    "shuntardes": "shuntar",
    "shuntare": "shuntar",
    "shuntarei": "shuntar",
    "shuntareis": "shuntar",
    "shuntarem": "shuntar",
    "shuntaremos": "shuntar",
    "shuntares": "shuntar",
    "shuntaria": "shuntar",
    "shuntariam": "shuntar",
    "shuntarias": "shuntar",
    "shuntarmo": "shuntar",
    "shuntarmos": "shuntar",
    "shuntará": "shuntar",
    "shuntarás": "shuntar",
    "shuntarão": "shuntar",
    "shuntaríamos": "shuntar",
    "shuntaríeis": "shuntar",
    "shuntas": "shuntar",
    "shuntasse": "shuntar",
    "shuntassem": "shuntar",
    "shuntasses": "shuntar",
    "shuntaste": "shuntar",
    "shuntastes": "shuntar",
    "shuntava": "shuntar",
    "shuntavam": "shuntar",
    "shuntavas": "shuntar",
    "shunte": "shuntar",
    "shuntei": "shuntar",
    "shunteis": "shuntar",
    "shuntem": "shuntar",
    "shuntemo": "shuntar",
    "shuntemos": "shuntar",
    "shuntes": "shuntar",
    "shunto": "shuntar",
    "shuntou": "shuntar",
    "shuntá": "shuntar",
    "shuntámo": "shuntar",
    "shuntámos": "shuntar",
    "shuntáramo": "shuntar",
    "shuntáramos": "shuntar",
    "shuntárei": "shuntar",
    "shuntáreis": "shuntar",
    "shuntásseis": "shuntar",
    "shuntássemos": "shuntar",
    "shuntávamo": "shuntar",
    "shuntávamos": "shuntar",
    "shuntávei": "shuntar",
    "shuntáveis": "shuntar",
    "sia": "siar",
    "siada": "siar",
    "siadas": "siar",
    "siado": "siar",
    "siados": "siar",
    "siai": "siar",
    "siais": "siar",
    "sialadenites": "sialadenite",
    "sialagoga": "sialagogo",
    "sialagogas": "sialagogo",
    "sialagogos": "sialagogo",
    "sialismos": "sialismo",
    "sialofagias": "sialofagia",
    "sialologias": "sialologia",
    "sialológica": "sialológico",
    "sialológicas": "sialológico",
    "sialológicos": "sialológico",
    "sialorreias": "sialorreia",
    "siam": "siar",
    "siames": "siame",
    "siamesa": "siamês",
    "siamesas": "siamês",
    "siameses": "siamês",
    "siamises": "siamise",
    "siamo": "siar",
    "siamos": "siar",
    "siando": "siar",
    "siara": "siar",
    "siaram": "siar",
    "siaras": "siar",
    "siardes": "siar",
    "siarei": "siar",
    "siareis": "siar",
    "siarem": "siar",
    "siaremos": "siar",
    "siares": "siar",
    "siaria": "siar",
    "siariam": "siar",
    "siarias": "siar",
    "siarmo": "siar",
    "siarmos": "siar",
    "siará": "siar",
    "siarás": "siar",
    "siarão": "siar",
    "siaríamos": "siar",
    "siaríeis": "siar",
    "sias": "siar",
    "siasse": "siar",
    "siassem": "siar",
    "siasses": "siar",
    "siaste": "siar",
    "siastes": "siar",
    "siava": "siar",
    "siavam": "siar",
    "siavas": "siar",
    "sibanas": "sibana",
    "sibares": "sibar",
    "sibarismos": "sibarismo",
    "sibaristas": "sibarista",
    "sibarita": "sibaritar",
    "sibaritada": "sibaritar",
    "sibaritadas": "sibaritar",
    "sibaritado": "sibaritar",
    "sibaritados": "sibaritar",
    "sibaritai": "sibaritar",
    "sibaritais": "sibaritar",
    "sibaritam": "sibaritar",
    "sibaritamo": "sibaritar",
    "sibaritamos": "sibaritar",
    "sibaritando": "sibaritar",
    "sibaritara": "sibaritar",
    "sibaritaram": "sibaritar",
    "sibaritaras": "sibaritar",
    "sibaritardes": "sibaritar",
    "sibaritarei": "sibaritar",
    "sibaritareis": "sibaritar",
    "sibaritarem": "sibaritar",
    "sibaritaremos": "sibaritar",
    "sibaritares": "sibaritar",
    "sibaritaria": "sibaritar",
    "sibaritariam": "sibaritar",
    "sibaritarias": "sibaritar",
    "sibaritarmo": "sibaritar",
    "sibaritarmos": "sibaritar",
    "sibaritará": "sibaritar",
    "sibaritarás": "sibaritar",
    "sibaritarão": "sibaritar",
    "sibaritaríamos": "sibaritar",
    "sibaritaríeis": "sibaritar",
    "sibaritas": "sibaritar",
    "sibaritasse": "sibaritar",
    "sibaritassem": "sibaritar",
    "sibaritasses": "sibaritar",
    "sibaritaste": "sibaritar",
    "sibaritastes": "sibaritar",
    "sibaritava": "sibaritar",
    "sibaritavam": "sibaritar",
    "sibaritavas": "sibaritar",
    "sibarite": "sibaritar",
    "sibaritei": "sibaritar",
    "sibariteis": "sibaritar",
    "sibaritem": "sibaritar",
    "sibaritemo": "sibaritar",
    "sibaritemos": "sibaritar",
    "sibarites": "sibaritar",
    "sibaritismos": "sibaritismo",
    "sibarito": "sibaritar",
    "sibaritou": "sibaritar",
    "sibaritámo": "sibaritar",
    "sibaritámos": "sibaritar",
    "sibaritáramo": "sibaritar",
    "sibaritáramos": "sibaritar",
    "sibaritáreis": "sibaritar",
    "sibaritásseis": "sibaritar",
    "sibaritássemos": "sibaritar",
    "sibaritávamo": "sibaritar",
    "sibaritávamos": "sibaritar",
    "sibaritáveis": "sibaritar",
    "sibarítica": "sibarítico",
    "sibaríticas": "sibarítico",
    "sibaríticos": "sibarítico",
    "sibas": "siba",
    "siberiana": "siberiano",
    "siberianas": "siberiano",
    "siberianos": "siberiano",
    "sibila": "sibilar",
    "sibilada": "sibilar",
    "sibiladas": "sibilar",
    "sibilado": "sibilar",
    "sibilados": "sibilar",
    "sibilai": "sibilar",
    "sibilais": "sibilar",
    "sibilam": "sibilar",
    "sibilamo": "sibilar",
    "sibilamos": "sibilar",
    "sibilando": "sibilar",
    "sibilantes": "sibilante",
    "sibilantiza": "sibilantizar",
    "sibilantizada": "sibilantizar",
    "sibilantizadas": "sibilantizar",
    "sibilantizado": "sibilantizar",
    "sibilantizados": "sibilantizar",
    "sibilantizai": "sibilantizar",
    "sibilantizais": "sibilantizar",
    "sibilantizam": "sibilantizar",
    "sibilantizamo": "sibilantizar",
    "sibilantizamos": "sibilantizar",
    "sibilantizando": "sibilantizar",
    "sibilantizara": "sibilantizar",
    "sibilantizaram": "sibilantizar",
    "sibilantizaras": "sibilantizar",
    "sibilantizarde": "sibilantizar",
    "sibilantizardes": "sibilantizar",
    "sibilantizare": "sibilantizar",
    "sibilantizarei": "sibilantizar",
    "sibilantizareis": "sibilantizar",
    "sibilantizarem": "sibilantizar",
    "sibilantizaremos": "sibilantizar",
    "sibilantizares": "sibilantizar",
    "sibilantizaria": "sibilantizar",
    "sibilantizariam": "sibilantizar",
    "sibilantizarias": "sibilantizar",
    "sibilantizarmo": "sibilantizar",
    "sibilantizarmos": "sibilantizar",
    "sibilantizará": "sibilantizar",
    "sibilantizarás": "sibilantizar",
    "sibilantizarão": "sibilantizar",
    "sibilantizaríamos": "sibilantizar",
    "sibilantizaríeis": "sibilantizar",
    "sibilantizas": "sibilantizar",
    "sibilantizasse": "sibilantizar",
    "sibilantizassem": "sibilantizar",
    "sibilantizasses": "sibilantizar",
    "sibilantizaste": "sibilantizar",
    "sibilantizastes": "sibilantizar",
    "sibilantizava": "sibilantizar",
    "sibilantizavam": "sibilantizar",
    "sibilantizavas": "sibilantizar",
    "sibilantize": "sibilantizar",
    "sibilantizei": "sibilantizar",
    "sibilantizeis": "sibilantizar",
    "sibilantizem": "sibilantizar",
    "sibilantizemo": "sibilantizar",
    "sibilantizemos": "sibilantizar",
    "sibilantizes": "sibilantizar",
    "sibilantizo": "sibilantizar",
    "sibilantizou": "sibilantizar",
    "sibilantizá": "sibilantizar",
    "sibilantizámo": "sibilantizar",
    "sibilantizámos": "sibilantizar",
    "sibilantizáramo": "sibilantizar",
    "sibilantizáramos": "sibilantizar",
    "sibilantizárei": "sibilantizar",
    "sibilantizáreis": "sibilantizar",
    "sibilantizásseis": "sibilantizar",
    "sibilantizássemos": "sibilantizar",
    "sibilantizávamo": "sibilantizar",
    "sibilantizávamos": "sibilantizar",
    "sibilantizávei": "sibilantizar",
    "sibilantizáveis": "sibilantizar",
    "sibilara": "sibilar",
    "sibilaram": "sibilar",
    "sibilaras": "sibilar",
    "sibilardes": "sibilar",
    "sibilarei": "sibilar",
    "sibilareis": "sibilar",
    "sibilarem": "sibilar",
    "sibilaremos": "sibilar",
    "sibilares": "sibilar",
    "sibilaria": "sibilar",
    "sibilariam": "sibilar",
    "sibilarias": "sibilar",
    "sibilarmo": "sibilar",
    "sibilarmos": "sibilar",
    "sibilará": "sibilar",
    "sibilarás": "sibilar",
    "sibilarão": "sibilar",
    "sibilaríamos": "sibilar",
    "sibilaríeis": "sibilar",
    "sibilas": "sibilar",
    "sibilasse": "sibilar",
    "sibilassem": "sibilar",
    "sibilasses": "sibilar",
    "sibilaste": "sibilar",
    "sibilastes": "sibilar",
    "sibilava": "sibilar",
    "sibilavam": "sibilar",
    "sibilavas": "sibilar",
    "sibilações": "sibilação",
    "sibile": "sibilar",
    "sibilei": "sibilar",
    "sibileis": "sibilar",
    "sibilem": "sibilar",
    "sibilemo": "sibilar",
    "sibilemos": "sibilar",
    "sibiles": "sibilar",
    "sibilina": "sibilino",
    "sibilinas": "sibilino",
    "sibilinos": "sibilino",
    "sibilismos": "sibilismo",
    "sibilistas": "sibilista",
    "sibilo": "sibilar",
    "sibilos": "sibilo",
    "sibilou": "sibilar",
    "sibilámo": "sibilar",
    "sibilámos": "sibilar",
    "sibiláramo": "sibilar",
    "sibiláramos": "sibilar",
    "sibiláreis": "sibilar",
    "sibilásseis": "sibilar",
    "sibilássemos": "sibilar",
    "sibilávamo": "sibilar",
    "sibilávamos": "sibilar",
    "sibiláveis": "sibilar",
    "sibilâncias": "sibilância",
    "sibilítica": "sibilítico",
    "sibilíticas": "sibilítico",
    "sibilíticos": "sibilítico",
    "sibérias": "sibéria",
    "sicambros": "sicambro",
    "sicandras": "sicandra",
    "sicariatos": "sicariato",
    "sicas": "sica",
    "sicativa": "sicativo",
    "sicativas": "sicativo",
    "sicatividades": "sicatividade",
    "sicativos": "sicativo",
    "siciliana": "siciliano",
    "sicilianas": "siciliano",
    "sicilianos": "siciliano",
    "sicilienses": "siciliense",
    "siciliotas": "siciliota",
    "sicites": "sicite",
    "siclos": "siclo",
    "sicofantas": "sicofanta",
    "sicofantismos": "sicofantismo",
    "sicomancias": "sicomancia",
    "sicomantes": "sicomante",
    "sicomas": "sicoma",
    "sicons": "sicon",
    "sicoses": "sicose",
    "sicranos": "sicrano",
    "sicários": "sicário",
    "sicófaga": "sicófago",
    "sicófagas": "sicófago",
    "sicófagos": "sicófago",
    "sicómoros": "sicómoro",
    "sicónias": "sicónia",
    "sida": "ser",
    "sidas": "sida",
    "sidera": "siderar",
    "siderada": "siderar",
    "sideradas": "siderar",
    "siderado": "siderar",
    "siderados": "siderar",
    "siderai": "siderar",
    "siderais": "siderar",
    "sideralidades": "sideralidade",
    "sideram": "siderar",
    "sideramo": "siderar",
    "sideramos": "siderar",
    "siderando": "siderar",
    "siderara": "siderar",
    "sideraram": "siderar",
    "sideraras": "siderar",
    "siderarde": "siderar",
    "siderardes": "siderar",
    "siderare": "siderar",
    "siderarei": "siderar",
    "siderareis": "siderar",
    "siderarem": "siderar",
    "sideraremos": "siderar",
    "siderares": "siderar",
    "sideraria": "siderar",
    "siderariam": "siderar",
    "siderarias": "siderar",
    "siderarmo": "siderar",
    "siderarmos": "siderar",
    "siderará": "siderar",
    "siderarás": "siderar",
    "siderarão": "siderar",
    "sideraríamos": "siderar",
    "sideraríeis": "siderar",
    "sideras": "siderar",
    "siderasse": "siderar",
    "siderassem": "siderar",
    "siderasses": "siderar",
    "sideraste": "siderar",
    "siderastes": "siderar",
    "siderava": "siderar",
    "sideravam": "siderar",
    "sideravas": "siderar",
    "siderações": "sideração",
    "sidere": "siderar",
    "siderei": "siderar",
    "sidereis": "siderar",
    "siderem": "siderar",
    "sideremo": "siderar",
    "sideremos": "siderar",
    "sideres": "siderar",
    "siderismos": "siderismo",
    "siderites": "siderite",
    "sideritinas": "sideritina",
    "sideritos": "siderito",
    "sidero": "siderar",
    "siderolítica": "siderolítico",
    "siderolíticas": "siderolítico",
    "siderolíticos": "siderolítico",
    "sideromancias": "sideromancia",
    "sideromantes": "sideromante",
    "sideroses": "siderose",
    "siderosferas": "siderosfera",
    "siderotecnias": "siderotecnia",
    "siderotécnica": "siderotécnico",
    "siderotécnicas": "siderotécnico",
    "siderotécnicos": "siderotécnico",
    "siderou": "siderar",
    "siderurgias": "siderurgia",
    "siderá": "siderar",
    "siderámo": "siderar",
    "siderámos": "siderar",
    "sideráramo": "siderar",
    "sideráramos": "siderar",
    "siderárei": "siderar",
    "sideráreis": "siderar",
    "siderásseis": "siderar",
    "siderássemos": "siderar",
    "siderávamo": "siderar",
    "siderávamos": "siderar",
    "siderávei": "siderar",
    "sideráveis": "siderar",
    "siderólitos": "siderólito",
    "siderósios": "siderósio",
    "sideróstatos": "sideróstato",
    "siderúrgica": "siderúrgico",
    "siderúrgicas": "siderúrgico",
    "siderúrgicos": "siderúrgico",
    "sido": "ser",
    "sidonismos": "sidonismo",
    "sidonistas": "sidonista",
    "sidos": "ser",
    "sidras": "sidra",
    "sidérea": "sidéreo",
    "sidéreas": "sidéreo",
    "sidéreos": "sidéreo",
    "sidérica": "sidérico",
    "sidéricas": "sidérico",
    "sidéricos": "sidérico",
    "sidónia": "sidónio",
    "sidónias": "sidónio",
    "sidónios": "sidónio",
    "sie": "siar",
    "siegenianos": "siegeniano",
    "siei": "siar",
    "sieis": "siar",
    "siem": "siar",
    "siemo": "siar",
    "siemos": "siar",
    "sienites": "sienite",
    "sies": "siar",
    "sifiligrafias": "sifiligrafia",
    "sifiligrafistas": "sifiligrafista",
    "sifilistas": "sifilista",
    "sifilizações": "sifilização",
    "sifilografias": "sifilografia",
    "sifilologias": "sifilologia",
    "sifilologistas": "sifilologista",
    "sifilomas": "sifiloma",
    "sifiloterapias": "sifiloterapia",
    "sifiloterápica": "sifiloterápico",
    "sifiloterápicas": "sifiloterápico",
    "sifiloterápicos": "sifiloterápico",
    "sifilígrafos": "sifilígrafo",
    "sifilítica": "sifilítico",
    "sifilíticas": "sifilítico",
    "sifilíticos": "sifilítico",
    "sifilógrafos": "sifilógrafo",
    "sifilóloga": "sifilólogo",
    "sifilólogas": "sifilólogo",
    "sifilólogos": "sifilólogo",
    "sifla": "siflar",
    "siflada": "siflar",
    "sifladas": "siflar",
    "siflado": "siflar",
    "siflados": "siflar",
    "siflai": "siflar",
    "siflais": "siflar",
    "siflam": "siflar",
    "siflamo": "siflar",
    "siflamos": "siflar",
    "siflando": "siflar",
    "siflara": "siflar",
    "siflaram": "siflar",
    "siflaras": "siflar",
    "siflarde": "siflar",
    "siflardes": "siflar",
    "siflare": "siflar",
    "siflarei": "siflar",
    "siflareis": "siflar",
    "siflarem": "siflar",
    "siflaremos": "siflar",
    "siflares": "siflar",
    "siflaria": "siflar",
    "siflariam": "siflar",
    "siflarias": "siflar",
    "siflarmo": "siflar",
    "siflarmos": "siflar",
    "siflará": "siflar",
    "siflarás": "siflar",
    "siflarão": "siflar",
    "siflaríamos": "siflar",
    "siflaríeis": "siflar",
    "siflas": "siflar",
    "siflasse": "siflar",
    "siflassem": "siflar",
    "siflasses": "siflar",
    "siflaste": "siflar",
    "siflastes": "siflar",
    "siflava": "siflar",
    "siflavam": "siflar",
    "siflavas": "siflar",
    "sifle": "siflar",
    "siflei": "siflar",
    "sifleis": "siflar",
    "siflem": "siflar",
    "siflemo": "siflar",
    "siflemos": "siflar",
    "sifles": "siflar",
    "siflo": "siflar",
    "siflou": "siflar",
    "siflá": "siflar",
    "siflámo": "siflar",
    "siflámos": "siflar",
    "sifláramo": "siflar",
    "sifláramos": "siflar",
    "siflárei": "siflar",
    "sifláreis": "siflar",
    "siflásseis": "siflar",
    "siflássemos": "siflar",
    "siflávamo": "siflar",
    "siflávamos": "siflar",
    "siflávei": "siflar",
    "sifláveis": "siflar",
    "sifonada": "sifonado",
    "sifonadas": "sifonado",
    "sifonados": "sifonado",
    "sifonóides": "sifonóide",
    "sifílides": "sifílide",
    "sifões": "sifão",
    "siga": "seguir",
    "sigais": "seguir",
    "sigam": "seguir",
    "sigamo": "seguir",
    "sigamos": "seguir",
    "sigas": "seguir",
    "sigila": "sigilar",
    "sigilada": "sigilar",
    "sigiladas": "sigilar",
    "sigilado": "sigilar",
    "sigilados": "sigilar",
    "sigilai": "sigilar",
    "sigilais": "sigilar",
    "sigilam": "sigilar",
    "sigilamo": "sigilar",
    "sigilamos": "sigilar",
    "sigilando": "sigilar",
    "sigilara": "sigilar",
    "sigilaram": "sigilar",
    "sigilaras": "sigilar",
    "sigilarde": "sigilar",
    "sigilardes": "sigilar",
    "sigilare": "sigilar",
    "sigilarei": "sigilar",
    "sigilareis": "sigilar",
    "sigilarem": "sigilar",
    "sigilaremos": "sigilar",
    "sigilares": "sigilar",
    "sigilaria": "sigilar",
    "sigilariam": "sigilar",
    "sigilarias": "sigilar",
    "sigilariáceas": "sigilariácea",
    "sigilarmo": "sigilar",
    "sigilarmos": "sigilar",
    "sigilará": "sigilar",
    "sigilarás": "sigilar",
    "sigilarão": "sigilar",
    "sigilaríamos": "sigilar",
    "sigilaríeis": "sigilar",
    "sigilas": "sigilar",
    "sigilasse": "sigilar",
    "sigilassem": "sigilar",
    "sigilasses": "sigilar",
    "sigilaste": "sigilar",
    "sigilastes": "sigilar",
    "sigilava": "sigilar",
    "sigilavam": "sigilar",
    "sigilavas": "sigilar",
    "sigilações": "sigilação",
    "sigile": "sigilar",
    "sigilei": "sigilar",
    "sigileis": "sigilar",
    "sigilem": "sigilar",
    "sigilemo": "sigilar",
    "sigilemos": "sigilar",
    "sigiles": "sigilar",
    "sigilismos": "sigilismo",
    "sigilistas": "sigilista",
    "sigilo": "sigilar",
    "sigilografias": "sigilografia",
    "sigilos": "sigilo",
    "sigilosa": "sigiloso",
    "sigilosas": "sigiloso",
    "sigilosos": "sigiloso",
    "sigilou": "sigilar",
    "sigilá": "sigilar",
    "sigilámo": "sigilar",
    "sigilámos": "sigilar",
    "sigiláramo": "sigilar",
    "sigiláramos": "sigilar",
    "sigilárei": "sigilar",
    "sigiláreis": "sigilar",
    "sigilárias": "sigilária",
    "sigilásseis": "sigilar",
    "sigilássemos": "sigilar",
    "sigilávamo": "sigilar",
    "sigilávamos": "sigilar",
    "sigilávei": "sigilar",
    "sigiláveis": "sigilar",
    "siglas": "sigla",
    "siglações": "siglação",
    "siglemas": "siglema",
    "sigmas": "sigma",
    "sigmatismos": "sigmatismo",
    "sigmoidites": "sigmoidite",
    "sigmoidostomias": "sigmoidostomia",
    "sigmática": "sigmático",
    "sigmáticas": "sigmático",
    "sigmáticos": "sigmático",
    "sigmóidea": "sigmóideo",
    "sigmóideas": "sigmóideo",
    "sigmóideos": "sigmóideo",
    "sigmóides": "sigmóide",
    "signas": "signa",
    "signatariazinha": "signatário",
    "signatariazinhas": "signatário",
    "signatariazita": "signatário",
    "signatariazitas": "signatário",
    "signatariozinho": "signatário",
    "signatariozinhos": "signatário",
    "signatariozito": "signatário",
    "signatariozitos": "signatário",
    "signatária": "signatário",
    "signatárias": "signatário",
    "signatários": "signatário",
    "significa": "significar",
    "significada": "significar",
    "significadas": "significar",
    "significado": "significar",
    "significadora": "significador",
    "significadoras": "significador",
    "significadores": "significador",
    "significados": "significar",
    "significai": "significar",
    "significais": "significar",
    "significam": "significar",
    "significamo": "significar",
    "significamos": "significar",
    "significando": "significar",
    "significantes": "significante",
    "significara": "significar",
    "significaram": "significar",
    "significaras": "significar",
    "significarde": "significar",
    "significardes": "significar",
    "significare": "significar",
    "significarei": "significar",
    "significareis": "significar",
    "significarem": "significar",
    "significaremos": "significar",
    "significares": "significar",
    "significaria": "significar",
    "significariam": "significar",
    "significarias": "significar",
    "significarmo": "significar",
    "significarmos": "significar",
    "significará": "significar",
    "significarás": "significar",
    "significarão": "significar",
    "significaríamos": "significar",
    "significaríeis": "significar",
    "significas": "significar",
    "significasse": "significar",
    "significassem": "significar",
    "significasses": "significar",
    "significaste": "significar",
    "significastes": "significar",
    "significativa": "significativo",
    "significativas": "significativo",
    "significativos": "significativo",
    "significava": "significar",
    "significavam": "significar",
    "significavas": "significar",
    "significações": "significação",
    "significo": "significar",
    "significou": "significar",
    "significá": "significar",
    "significámo": "significar",
    "significámos": "significar",
    "significáramo": "significar",
    "significáramos": "significar",
    "significárei": "significar",
    "significáreis": "significar",
    "significásseis": "significar",
    "significássemos": "significar",
    "significávamo": "significar",
    "significávamos": "significar",
    "significávei": "significar",
    "significáveis": "significar",
    "signifique": "significar",
    "signifiquei": "significar",
    "signifiqueis": "significar",
    "signifiquem": "significar",
    "signifiquemo": "significar",
    "signifiquemos": "significar",
    "signifiques": "significar",
    "signografias": "signografia",
    "signos": "signo",
    "signíferos": "signífero",
    "sigo": "seguir",
    "silaba": "silabar",
    "silabada": "silabar",
    "silabadas": "silabar",
    "silabado": "silabar",
    "silabados": "silabar",
    "silabai": "silabar",
    "silabais": "silabar",
    "silabam": "silabar",
    "silabamo": "silabar",
    "silabamos": "silabar",
    "silabando": "silabar",
    "silabara": "silabar",
    "silabaram": "silabar",
    "silabaras": "silabar",
    "silabarde": "silabar",
    "silabardes": "silabar",
    "silabare": "silabar",
    "silabarei": "silabar",
    "silabareis": "silabar",
    "silabarem": "silabar",
    "silabaremos": "silabar",
    "silabares": "silabar",
    "silabaria": "silabar",
    "silabariam": "silabar",
    "silabarias": "silabar",
    "silabarmo": "silabar",
    "silabarmos": "silabar",
    "silabará": "silabar",
    "silabarás": "silabar",
    "silabarão": "silabar",
    "silabaríamos": "silabar",
    "silabaríeis": "silabar",
    "silabas": "silabar",
    "silabasse": "silabar",
    "silabassem": "silabar",
    "silabasses": "silabar",
    "silabaste": "silabar",
    "silabastes": "silabar",
    "silabava": "silabar",
    "silabavam": "silabar",
    "silabavas": "silabar",
    "silabações": "silabação",
    "silabe": "silabar",
    "silabei": "silabar",
    "silabeis": "silabar",
    "silabem": "silabar",
    "silabemo": "silabar",
    "silabemos": "silabar",
    "silabes": "silabar",
    "silabismos": "silabismo",
    "silabo": "silabar",
    "silabogramas": "silabograma",
    "silabou": "silabar",
    "silabá": "silabar",
    "silabámo": "silabar",
    "silabámos": "silabar",
    "silabáramo": "silabar",
    "silabáramos": "silabar",
    "silabárei": "silabar",
    "silabáreis": "silabar",
    "silabários": "silabário",
    "silabásseis": "silabar",
    "silabássemos": "silabar",
    "silabávamo": "silabar",
    "silabávamos": "silabar",
    "silabávei": "silabar",
    "silabáveis": "silabar",
    "silagens": "silagem",
    "silanos": "silano",
    "silculosa": "silculoso",
    "silculosas": "silculoso",
    "silculosos": "silculoso",
    "silencia": "silenciar",
    "silenciada": "silenciar",
    "silenciadas": "silenciar",
    "silenciado": "silenciar",
    "silenciadora": "silenciador",
    "silenciadoras": "silenciador",
    "silenciadores": "silenciador",
    "silenciados": "silenciar",
    "silenciai": "silenciar",
    "silenciais": "silenciar",
    "silenciam": "silenciar",
    "silenciamo": "silenciar",
    "silenciamos": "silenciar",
    "silenciando": "silenciar",
    "silenciara": "silenciar",
    "silenciaram": "silenciar",
    "silenciaras": "silenciar",
    "silenciarde": "silenciar",
    "silenciardes": "silenciar",
    "silenciare": "silenciar",
    "silenciarei": "silenciar",
    "silenciareis": "silenciar",
    "silenciarem": "silenciar",
    "silenciaremos": "silenciar",
    "silenciares": "silenciar",
    "silenciaria": "silenciar",
    "silenciariam": "silenciar",
    "silenciarias": "silenciar",
    "silenciarmo": "silenciar",
    "silenciarmos": "silenciar",
    "silenciará": "silenciar",
    "silenciarás": "silenciar",
    "silenciarão": "silenciar",
    "silenciaríamos": "silenciar",
    "silenciaríeis": "silenciar",
    "silencias": "silenciar",
    "silenciasse": "silenciar",
    "silenciassem": "silenciar",
    "silenciasses": "silenciar",
    "silenciaste": "silenciar",
    "silenciastes": "silenciar",
    "silenciava": "silenciar",
    "silenciavam": "silenciar",
    "silenciavas": "silenciar",
    "silencie": "silenciar",
    "silenciei": "silenciar",
    "silencieis": "silenciar",
    "silenciem": "silenciar",
    "silenciemo": "silenciar",
    "silenciemos": "silenciar",
    "silencies": "silenciar",
    "silencio": "silenciar",
    "silenciosa": "silencioso",
    "silenciosas": "silencioso",
    "silenciosos": "silencioso",
    "silenciou": "silenciar",
    "silenciá": "silenciar",
    "silenciámo": "silenciar",
    "silenciámos": "silenciar",
    "silenciáramo": "silenciar",
    "silenciáramos": "silenciar",
    "silenciárei": "silenciar",
    "silenciáreis": "silenciar",
    "silenciários": "silenciário",
    "silenciásseis": "silenciar",
    "silenciássemos": "silenciar",
    "silenciávamo": "silenciar",
    "silenciávamos": "silenciar",
    "silenciávei": "silenciar",
    "silenciáveis": "silenciável",
    "silenos": "sileno",
    "silentes": "silente",
    "silenáceas": "silenácea",
    "silepses": "silepse",
    "silesiana": "silesiano",
    "silesianas": "silesiano",
    "silesianos": "silesiano",
    "silfos": "silfo",
    "silfídica": "silfídico",
    "silfídicas": "silfídico",
    "silfídicos": "silfídico",
    "silhadoiros": "silhadoiro",
    "silhadouros": "silhadouro",
    "silhais": "silhal",
    "silhares": "silhar",
    "silharias": "silharia",
    "silhas": "silha",
    "silhuetas": "silhueta",
    "silhões": "silhão",
    "silicatada": "silicatado",
    "silicatadas": "silicatado",
    "silicatados": "silicatado",
    "silicatos": "silicato",
    "silicificações": "silicificação",
    "siliciosa": "silicioso",
    "siliciosas": "silicioso",
    "siliciosos": "silicioso",
    "siliciozinho": "silício",
    "siliciozinhos": "silício",
    "siliciozito": "silício",
    "siliciozitos": "silício",
    "silicoflagelados": "silicoflagelado",
    "silicones": "silicone",
    "silicoses": "silicose",
    "siliculiformes": "siliculiforme",
    "silicícolas": "silicícola",
    "silicífera": "silicífero",
    "silicíferas": "silicífero",
    "silicíferos": "silicífero",
    "siliginária": "siliginário",
    "siliginárias": "siliginário",
    "siliginários": "siliginário",
    "siligos": "siligo",
    "silimanites": "silimanite",
    "silindras": "silindra",
    "siliquiformes": "siliquiforme",
    "siliquosa": "siliquoso",
    "siliquosas": "siliquoso",
    "siliquosos": "siliquoso",
    "silogeus": "silogeu",
    "silogismos": "silogismo",
    "silogiza": "silogizar",
    "silogizada": "silogizar",
    "silogizadas": "silogizar",
    "silogizado": "silogizar",
    "silogizados": "silogizar",
    "silogizai": "silogizar",
    "silogizais": "silogizar",
    "silogizam": "silogizar",
    "silogizamo": "silogizar",
    "silogizamos": "silogizar",
    "silogizando": "silogizar",
    "silogizara": "silogizar",
    "silogizaram": "silogizar",
    "silogizaras": "silogizar",
    "silogizarde": "silogizar",
    "silogizardes": "silogizar",
    "silogizare": "silogizar",
    "silogizarei": "silogizar",
    "silogizareis": "silogizar",
    "silogizarem": "silogizar",
    "silogizaremos": "silogizar",
    "silogizares": "silogizar",
    "silogizaria": "silogizar",
    "silogizariam": "silogizar",
    "silogizarias": "silogizar",
    "silogizarmo": "silogizar",
    "silogizarmos": "silogizar",
    "silogizará": "silogizar",
    "silogizarás": "silogizar",
    "silogizarão": "silogizar",
    "silogizaríamos": "silogizar",
    "silogizaríeis": "silogizar",
    "silogizas": "silogizar",
    "silogizasse": "silogizar",
    "silogizassem": "silogizar",
    "silogizasses": "silogizar",
    "silogizaste": "silogizar",
    "silogizastes": "silogizar",
    "silogizava": "silogizar",
    "silogizavam": "silogizar",
    "silogizavas": "silogizar",
    "silogize": "silogizar",
    "silogizei": "silogizar",
    "silogizeis": "silogizar",
    "silogizem": "silogizar",
    "silogizemo": "silogizar",
    "silogizemos": "silogizar",
    "silogizes": "silogizar",
    "silogizo": "silogizar",
    "silogizou": "silogizar",
    "silogizá": "silogizar",
    "silogizámo": "silogizar",
    "silogizámos": "silogizar",
    "silogizáramo": "silogizar",
    "silogizáramos": "silogizar",
    "silogizárei": "silogizar",
    "silogizáreis": "silogizar",
    "silogizásseis": "silogizar",
    "silogizássemos": "silogizar",
    "silogizávamo": "silogizar",
    "silogizávamos": "silogizar",
    "silogizávei": "silogizar",
    "silogizáveis": "silogizar",
    "silogística": "silogístico",
    "silogísticas": "silogístico",
    "silogísticos": "silogístico",
    "silos": "silo",
    "siltes": "silte",
    "siltitos": "siltito",
    "siluriana": "siluriano",
    "silurianas": "siluriano",
    "silurianos": "siluriano",
    "silurídeos": "silurídeo",
    "silva": "silvar",
    "silvada": "silvar",
    "silvadas": "silvar",
    "silvado": "silvar",
    "silvados": "silvar",
    "silvai": "silvar",
    "silvais": "silvar",
    "silvam": "silvar",
    "silvamo": "silvar",
    "silvamos": "silvar",
    "silvana": "silvano",
    "silvanas": "silvano",
    "silvando": "silvar",
    "silvandras": "silvandra",
    "silvanos": "silvano",
    "silvanta": "silvante",
    "silvantas": "silvante",
    "silvantes": "silvante",
    "silvara": "silvar",
    "silvaram": "silvar",
    "silvaras": "silvar",
    "silvardes": "silvar",
    "silvarei": "silvar",
    "silvareis": "silvar",
    "silvarem": "silvar",
    "silvaremos": "silvar",
    "silvares": "silvar",
    "silvaria": "silvar",
    "silvariam": "silvar",
    "silvarias": "silvar",
    "silvarmo": "silvar",
    "silvarmos": "silvar",
    "silvará": "silvar",
    "silvarás": "silvar",
    "silvarão": "silvar",
    "silvaríamos": "silvar",
    "silvaríeis": "silvar",
    "silvas": "silvar",
    "silvasse": "silvar",
    "silvassem": "silvar",
    "silvasses": "silvar",
    "silvaste": "silvar",
    "silvastes": "silvar",
    "silvava": "silvar",
    "silvavam": "silvar",
    "silvavas": "silvar",
    "silve": "silvar",
    "silvedos": "silvedo",
    "silvei": "silvar",
    "silveira": "silveiro",
    "silveirais": "silveiral",
    "silveiras": "silveiro",
    "silveiros": "silveiro",
    "silveis": "silvar",
    "silvem": "silvar",
    "silvemo": "silvar",
    "silvemos": "silvar",
    "silves": "silvar",
    "silvestres": "silvestre",
    "silviana": "silviano",
    "silvianas": "silviano",
    "silvianos": "silviano",
    "silvicultora": "silvicultor",
    "silvicultoras": "silvicultor",
    "silvicultores": "silvicultor",
    "silviculturas": "silvicultura",
    "silvienses": "silviense",
    "silvinas": "silvina",
    "silvites": "silvite",
    "silviídeos": "silviídeo",
    "silvo": "silvar",
    "silvos": "silvo",
    "silvosa": "silvoso",
    "silvosas": "silvoso",
    "silvosos": "silvoso",
    "silvou": "silvar",
    "silvámo": "silvar",
    "silvámos": "silvar",
    "silváramo": "silvar",
    "silváramos": "silvar",
    "silváreis": "silvar",
    "silvásseis": "silvar",
    "silvássemos": "silvar",
    "silvática": "silvático",
    "silváticas": "silvático",
    "silváticos": "silvático",
    "silvávamo": "silvar",
    "silvávamos": "silvar",
    "silváveis": "silvar",
    "silvícolas": "silvícola",
    "silvíidas": "silvíida",
    "silvões": "silvão",
    "silábica": "silábico",
    "silábicas": "silábico",
    "silábicos": "silábico",
    "siléptica": "siléptico",
    "silépticas": "siléptico",
    "silépticos": "siléptico",
    "silêncios": "silêncio",
    "silícica": "silícico",
    "silícicas": "silícico",
    "silícicos": "silícico",
    "silícios": "silício",
    "silículas": "silícula",
    "silúrica": "silúrico",
    "silúricas": "silúrico",
    "silúricos": "silúrico",
    "silúridas": "silúrida",
    "simarubáceas": "simarubácea",
    "simas": "sima",
    "simbiontes": "simbionte",
    "simbioses": "simbiose",
    "simbiotas": "simbiota",
    "simbiótica": "simbiótico",
    "simbióticas": "simbiótico",
    "simbióticos": "simbiótico",
    "simbolismos": "simbolismo",
    "simbolistas": "simbolista",
    "simboliza": "simbolizar",
    "simbolizada": "simbolizar",
    "simbolizadas": "simbolizar",
    "simbolizado": "simbolizar",
    "simbolizadora": "simbolizador",
    "simbolizadoras": "simbolizador",
    "simbolizadores": "simbolizador",
    "simbolizados": "simbolizar",
    "simbolizai": "simbolizar",
    "simbolizais": "simbolizar",
    "simbolizam": "simbolizar",
    "simbolizamo": "simbolizar",
    "simbolizamos": "simbolizar",
    "simbolizando": "simbolizar",
    "simbolizantes": "simbolizante",
    "simbolizara": "simbolizar",
    "simbolizaram": "simbolizar",
    "simbolizaras": "simbolizar",
    "simbolizarde": "simbolizar",
    "simbolizardes": "simbolizar",
    "simbolizare": "simbolizar",
    "simbolizarei": "simbolizar",
    "simbolizareis": "simbolizar",
    "simbolizarem": "simbolizar",
    "simbolizaremos": "simbolizar",
    "simbolizares": "simbolizar",
    "simbolizaria": "simbolizar",
    "simbolizariam": "simbolizar",
    "simbolizarias": "simbolizar",
    "simbolizarmo": "simbolizar",
    "simbolizarmos": "simbolizar",
    "simbolizará": "simbolizar",
    "simbolizarás": "simbolizar",
    "simbolizarão": "simbolizar",
    "simbolizaríamos": "simbolizar",
    "simbolizaríeis": "simbolizar",
    "simbolizas": "simbolizar",
    "simbolizasse": "simbolizar",
    "simbolizassem": "simbolizar",
    "simbolizasses": "simbolizar",
    "simbolizaste": "simbolizar",
    "simbolizastes": "simbolizar",
    "simbolizava": "simbolizar",
    "simbolizavam": "simbolizar",
    "simbolizavas": "simbolizar",
    "simbolizações": "simbolização",
    "simbolize": "simbolizar",
    "simbolizei": "simbolizar",
    "simbolizeis": "simbolizar",
    "simbolizem": "simbolizar",
    "simbolizemo": "simbolizar",
    "simbolizemos": "simbolizar",
    "simbolizes": "simbolizar",
    "simbolizo": "simbolizar",
    "simbolizou": "simbolizar",
    "simbolizá": "simbolizar",
    "simbolizámo": "simbolizar",
    "simbolizámos": "simbolizar",
    "simbolizáramo": "simbolizar",
    "simbolizáramos": "simbolizar",
    "simbolizárei": "simbolizar",
    "simbolizáreis": "simbolizar",
    "simbolizásseis": "simbolizar",
    "simbolizássemos": "simbolizar",
    "simbolizávamo": "simbolizar",
    "simbolizávamos": "simbolizar",
    "simbolizávei": "simbolizar",
    "simbolizáveis": "simbolizável",
    "simbologias": "simbologia",
    "simbolologias": "simbolologia",
    "simbolológica": "simbolológico",
    "simbolológicas": "simbolológico",
    "simbolológicos": "simbolológico",
    "simbolística": "simbolístico",
    "simbolísticas": "simbolístico",
    "simbolísticos": "simbolístico",
    "simbológica": "simbológico",
    "simbológicas": "simbológico",
    "simbológicos": "simbológico",
    "simbólica": "simbólico",
    "simbólicas": "simbólico",
    "simbólicos": "simbólico",
    "simetrias": "simetria",
    "simetriza": "simetrizar",
    "simetrizada": "simetrizar",
    "simetrizadas": "simetrizar",
    "simetrizado": "simetrizar",
    "simetrizados": "simetrizar",
    "simetrizai": "simetrizar",
    "simetrizais": "simetrizar",
    "simetrizam": "simetrizar",
    "simetrizamo": "simetrizar",
    "simetrizamos": "simetrizar",
    "simetrizando": "simetrizar",
    "simetrizara": "simetrizar",
    "simetrizaram": "simetrizar",
    "simetrizaras": "simetrizar",
    "simetrizarde": "simetrizar",
    "simetrizardes": "simetrizar",
    "simetrizare": "simetrizar",
    "simetrizarei": "simetrizar",
    "simetrizareis": "simetrizar",
    "simetrizarem": "simetrizar",
    "simetrizaremos": "simetrizar",
    "simetrizares": "simetrizar",
    "simetrizaria": "simetrizar",
    "simetrizariam": "simetrizar",
    "simetrizarias": "simetrizar",
    "simetrizarmo": "simetrizar",
    "simetrizarmos": "simetrizar",
    "simetrizará": "simetrizar",
    "simetrizarás": "simetrizar",
    "simetrizarão": "simetrizar",
    "simetrizaríamos": "simetrizar",
    "simetrizaríeis": "simetrizar",
    "simetrizas": "simetrizar",
    "simetrizasse": "simetrizar",
    "simetrizassem": "simetrizar",
    "simetrizasses": "simetrizar",
    "simetrizaste": "simetrizar",
    "simetrizastes": "simetrizar",
    "simetrizava": "simetrizar",
    "simetrizavam": "simetrizar",
    "simetrizavas": "simetrizar",
    "simetrizações": "simetrização",
    "simetrize": "simetrizar",
    "simetrizei": "simetrizar",
    "simetrizeis": "simetrizar",
    "simetrizem": "simetrizar",
    "simetrizemo": "simetrizar",
    "simetrizemos": "simetrizar",
    "simetrizes": "simetrizar",
    "simetrizo": "simetrizar",
    "simetrizou": "simetrizar",
    "simetrizá": "simetrizar",
    "simetrizámo": "simetrizar",
    "simetrizámos": "simetrizar",
    "simetrizáramo": "simetrizar",
    "simetrizáramos": "simetrizar",
    "simetrizárei": "simetrizar",
    "simetrizáreis": "simetrizar",
    "simetrizásseis": "simetrizar",
    "simetrizássemos": "simetrizar",
    "simetrizávamo": "simetrizar",
    "simetrizávamos": "simetrizar",
    "simetrizávei": "simetrizar",
    "simetrizáveis": "simetrizar",
    "simiana": "simiano",
    "simianas": "simiano",
    "simianismos": "simianismo",
    "simianos": "simiano",
    "simiesca": "simiesco",
    "simiescas": "simiesco",
    "simiescos": "simiesco",
    "similares": "similar",
    "similaridades": "similaridade",
    "similitudes": "similitude",
    "similitudinária": "similitudinário",
    "similitudinárias": "similitudinário",
    "similitudinários": "similitudinário",
    "simiologias": "simiologia",
    "simiídeos": "simiídeo",
    "simoniana": "simoniano",
    "simonianas": "simoniano",
    "simonianos": "simoniano",
    "simonias": "simonia",
    "simontes": "simonte",
    "simoníaca": "simoníaco",
    "simoníacas": "simoníaco",
    "simoníacos": "simoníaco",
    "simpalhona": "simpalhão",
    "simpalhonas": "simpalhão",
    "simpalhões": "simpalhão",
    "simpatalgias": "simpatalgia",
    "simpatectomias": "simpatectomia",
    "simpatias": "simpatia",
    "simpaticectomias": "simpaticectomia",
    "simpaticotonias": "simpaticotonia",
    "simpaticíssima": "simpático",
    "simpaticíssimas": "simpático",
    "simpaticíssimo": "simpático",
    "simpaticíssimos": "simpático",
    "simpatinas": "simpatina",
    "simpatiquíssima": "simpático",
    "simpatiquíssimas": "simpático",
    "simpatiquíssimo": "simpático",
    "simpatiquíssimos": "simpático",
    "simpatiza": "simpatizar",
    "simpatizada": "simpatizar",
    "simpatizadas": "simpatizar",
    "simpatizado": "simpatizar",
    "simpatizados": "simpatizar",
    "simpatizai": "simpatizar",
    "simpatizais": "simpatizar",
    "simpatizam": "simpatizar",
    "simpatizamo": "simpatizar",
    "simpatizamos": "simpatizar",
    "simpatizando": "simpatizar",
    "simpatizantes": "simpatizante",
    "simpatizara": "simpatizar",
    "simpatizaram": "simpatizar",
    "simpatizaras": "simpatizar",
    "simpatizardes": "simpatizar",
    "simpatizarei": "simpatizar",
    "simpatizareis": "simpatizar",
    "simpatizarem": "simpatizar",
    "simpatizaremos": "simpatizar",
    "simpatizares": "simpatizar",
    "simpatizaria": "simpatizar",
    "simpatizariam": "simpatizar",
    "simpatizarias": "simpatizar",
    "simpatizarmo": "simpatizar",
    "simpatizarmos": "simpatizar",
    "simpatizará": "simpatizar",
    "simpatizarás": "simpatizar",
    "simpatizarão": "simpatizar",
    "simpatizaríamos": "simpatizar",
    "simpatizaríeis": "simpatizar",
    "simpatizas": "simpatizar",
    "simpatizasse": "simpatizar",
    "simpatizassem": "simpatizar",
    "simpatizasses": "simpatizar",
    "simpatizaste": "simpatizar",
    "simpatizastes": "simpatizar",
    "simpatizava": "simpatizar",
    "simpatizavam": "simpatizar",
    "simpatizavas": "simpatizar",
    "simpatize": "simpatizar",
    "simpatizei": "simpatizar",
    "simpatizeis": "simpatizar",
    "simpatizem": "simpatizar",
    "simpatizemo": "simpatizar",
    "simpatizemos": "simpatizar",
    "simpatizes": "simpatizar",
    "simpatizo": "simpatizar",
    "simpatizou": "simpatizar",
    "simpatizámo": "simpatizar",
    "simpatizámos": "simpatizar",
    "simpatizáramo": "simpatizar",
    "simpatizáramos": "simpatizar",
    "simpatizáreis": "simpatizar",
    "simpatizásseis": "simpatizar",
    "simpatizássemos": "simpatizar",
    "simpatizávamo": "simpatizar",
    "simpatizávamos": "simpatizar",
    "simpatizáveis": "simpatizar",
    "simpatrias": "simpatria",
    "simplacheirona": "simplacheirão",
    "simplacheironas": "simplacheirão",
    "simplacheirões": "simplacheirão",
    "simplezas": "simpleza",
    "simplicidades": "simplicidade",
    "simplicistas": "simplicista",
    "simplicíssima": "simples",
    "simplicíssimas": "simples",
    "simplicíssimo": "simples",
    "simplicíssimos": "simples",
    "simplifica": "simplificar",
    "simplificacionistas": "simplificacionista",
    "simplificada": "simplificar",
    "simplificadas": "simplificar",
    "simplificado": "simplificar",
    "simplificadora": "simplificador",
    "simplificadoras": "simplificador",
    "simplificadores": "simplificador",
    "simplificados": "simplificar",
    "simplificai": "simplificar",
    "simplificais": "simplificar",
    "simplificam": "simplificar",
    "simplificamo": "simplificar",
    "simplificamos": "simplificar",
    "simplificando": "simplificar",
    "simplificara": "simplificar",
    "simplificaram": "simplificar",
    "simplificaras": "simplificar",
    "simplificarde": "simplificar",
    "simplificardes": "simplificar",
    "simplificare": "simplificar",
    "simplificarei": "simplificar",
    "simplificareis": "simplificar",
    "simplificarem": "simplificar",
    "simplificaremos": "simplificar",
    "simplificares": "simplificar",
    "simplificaria": "simplificar",
    "simplificariam": "simplificar",
    "simplificarias": "simplificar",
    "simplificarmo": "simplificar",
    "simplificarmos": "simplificar",
    "simplificará": "simplificar",
    "simplificarás": "simplificar",
    "simplificarão": "simplificar",
    "simplificaríamos": "simplificar",
    "simplificaríeis": "simplificar",
    "simplificas": "simplificar",
    "simplificasse": "simplificar",
    "simplificassem": "simplificar",
    "simplificasses": "simplificar",
    "simplificaste": "simplificar",
    "simplificastes": "simplificar",
    "simplificativa": "simplificativo",
    "simplificativas": "simplificativo",
    "simplificativos": "simplificativo",
    "simplificava": "simplificar",
    "simplificavam": "simplificar",
    "simplificavas": "simplificar",
    "simplificações": "simplificação",
    "simplifico": "simplificar",
    "simplificou": "simplificar",
    "simplificá": "simplificar",
    "simplificámo": "simplificar",
    "simplificámos": "simplificar",
    "simplificáramo": "simplificar",
    "simplificáramos": "simplificar",
    "simplificárei": "simplificar",
    "simplificáreis": "simplificar",
    "simplificásseis": "simplificar",
    "simplificássemos": "simplificar",
    "simplificávamo": "simplificar",
    "simplificávamos": "simplificar",
    "simplificávei": "simplificar",
    "simplificáveis": "simplificável",
    "simplifique": "simplificar",
    "simplifiquei": "simplificar",
    "simplifiqueis": "simplificar",
    "simplifiquem": "simplificar",
    "simplifiquemo": "simplificar",
    "simplifiquemos": "simplificar",
    "simplifiques": "simplificar",
    "simplismos": "simplismo",
    "simplistas": "simplista",
    "simplistazinha": "simplista",
    "simplistazinhas": "simplista",
    "simplistazinho": "simplista",
    "simplistazinhos": "simplista",
    "simplistazita": "simplista",
    "simplistazitas": "simplista",
    "simplistazito": "simplista",
    "simplistazitos": "simplista",
    "simploriazinha": "simplório",
    "simploriazinhas": "simplório",
    "simploriazita": "simplório",
    "simploriazitas": "simplório",
    "simploriedades": "simploriedade",
    "simploriozinho": "simplório",
    "simploriozinhos": "simplório",
    "simploriozito": "simplório",
    "simploriozitos": "simplório",
    "simpléctica": "simpléctico",
    "simplécticas": "simpléctico",
    "simplécticos": "simpléctico",
    "simplérrima": "simples",
    "simplérrimas": "simples",
    "simplérrimo": "simples",
    "simplérrimos": "simples",
    "simplíssima": "simples",
    "simplíssimas": "simples",
    "simplíssimo": "simples",
    "simplíssimos": "simples",
    "simplória": "simplório",
    "simplórias": "simplório",
    "simplórios": "simplório",
    "simpodiais": "simpodial",
    "simposiarcas": "simposiarca",
    "simpática": "simpático",
    "simpáticas": "simpático",
    "simpáticos": "simpático",
    "simpétalas": "simpétala",
    "simpódica": "simpódico",
    "simpódicas": "simpódico",
    "simpódicos": "simpódico",
    "simpódios": "simpódio",
    "simpósios": "simpósio",
    "simula": "simular",
    "simulacros": "simulacro",
    "simulada": "simular",
    "simuladas": "simular",
    "simulado": "simular",
    "simuladora": "simulador",
    "simuladoras": "simulador",
    "simuladores": "simulador",
    "simulados": "simular",
    "simuladíssima": "simulado",
    "simuladíssimas": "simulado",
    "simuladíssimo": "simulado",
    "simuladíssimos": "simulado",
    "simulai": "simular",
    "simulais": "simular",
    "simulam": "simular",
    "simulamentos": "simulamento",
    "simulamo": "simular",
    "simulamos": "simular",
    "simulando": "simular",
    "simulara": "simular",
    "simularam": "simular",
    "simularas": "simular",
    "simularde": "simular",
    "simulardes": "simular",
    "simulare": "simular",
    "simularei": "simular",
    "simulareis": "simular",
    "simularem": "simular",
    "simularemos": "simular",
    "simulares": "simular",
    "simularia": "simular",
    "simulariam": "simular",
    "simularias": "simular",
    "simularmo": "simular",
    "simularmos": "simular",
    "simulará": "simular",
    "simularás": "simular",
    "simularão": "simular",
    "simularíamos": "simular",
    "simularíeis": "simular",
    "simulas": "simular",
    "simulasse": "simular",
    "simulassem": "simular",
    "simulasses": "simular",
    "simulaste": "simular",
    "simulastes": "simular",
    "simulatória": "simulatório",
    "simulatórias": "simulatório",
    "simulatórios": "simulatório",
    "simulava": "simular",
    "simulavam": "simular",
    "simulavas": "simular",
    "simulações": "simulação",
    "simulcadentes": "simulcadente",
    "simulcadências": "simulcadência",
    "simuldesinências": "simuldesinência",
    "simule": "simular",
    "simulei": "simular",
    "simuleis": "simular",
    "simulem": "simular",
    "simulemo": "simular",
    "simulemos": "simular",
    "simules": "simular",
    "simulo": "simular",
    "simulou": "simular",
    "simultaneidades": "simultaneidade",
    "simultânea": "simultâneo",
    "simultâneas": "simultâneo",
    "simultâneos": "simultâneo",
    "simulá": "simular",
    "simulámo": "simular",
    "simulámos": "simular",
    "simuláramo": "simular",
    "simuláramos": "simular",
    "simulárei": "simular",
    "simuláreis": "simular",
    "simulásseis": "simular",
    "simulássemos": "simular",
    "simulávamo": "simular",
    "simulávamos": "simular",
    "simulávei": "simular",
    "simuláveis": "simulável",
    "simuns": "simum",
    "simétrica": "simétrico",
    "simétricas": "simétrico",
    "simétricos": "simétrico",
    "simíidas": "simíida",
    "simílima": "símil",
    "simílimas": "símil",
    "simílimo": "símil",
    "simílimos": "símil",
    "simões": "simão",
    "sina": "sino",
    "sinadelfos": "sinadelfo",
    "sinafias": "sinafia",
    "sinagelástica": "sinagelástico",
    "sinagelásticas": "sinagelástico",
    "sinagelásticos": "sinagelástico",
    "sinagogas": "sinagoga",
    "sinais": "sinal",
    "sinaizinhos": "sinal",
    "sinaizitos": "sinal",
    "sinala": "sinalar",
    "sinalada": "sinalar",
    "sinaladas": "sinalar",
    "sinalado": "sinalar",
    "sinalados": "sinalar",
    "sinalagmática": "sinalagmático",
    "sinalagmáticas": "sinalagmático",
    "sinalagmáticos": "sinalagmático",
    "sinalai": "sinalar",
    "sinalais": "sinalar",
    "sinalam": "sinalar",
    "sinalamo": "sinalar",
    "sinalamos": "sinalar",
    "sinalando": "sinalar",
    "sinalara": "sinalar",
    "sinalaram": "sinalar",
    "sinalaras": "sinalar",
    "sinalarde": "sinalar",
    "sinalardes": "sinalar",
    "sinalare": "sinalar",
    "sinalarei": "sinalar",
    "sinalareis": "sinalar",
    "sinalarem": "sinalar",
    "sinalaremos": "sinalar",
    "sinalares": "sinalar",
    "sinalaria": "sinalar",
    "sinalariam": "sinalar",
    "sinalarias": "sinalar",
    "sinalarmo": "sinalar",
    "sinalarmos": "sinalar",
    "sinalará": "sinalar",
    "sinalarás": "sinalar",
    "sinalarão": "sinalar",
    "sinalaríamos": "sinalar",
    "sinalaríeis": "sinalar",
    "sinalas": "sinalar",
    "sinalasse": "sinalar",
    "sinalassem": "sinalar",
    "sinalasses": "sinalar",
    "sinalaste": "sinalar",
    "sinalastes": "sinalar",
    "sinalava": "sinalar",
    "sinalavam": "sinalar",
    "sinalavas": "sinalar",
    "sinale": "sinalar",
    "sinalefas": "sinalefa",
    "sinalefistas": "sinalefista",
    "sinalei": "sinalar",
    "sinaleira": "sinaleiro",
    "sinaleiras": "sinaleiro",
    "sinaleiros": "sinaleiro",
    "sinaleis": "sinalar",
    "sinalem": "sinalar",
    "sinalemo": "sinalar",
    "sinalemos": "sinalar",
    "sinales": "sinalar",
    "sinalgias": "sinalgia",
    "sinalhadas": "sinalhada",
    "sinaliza": "sinalizar",
    "sinalizada": "sinalizar",
    "sinalizadas": "sinalizar",
    "sinalizado": "sinalizar",
    "sinalizadora": "sinalizador",
    "sinalizadoras": "sinalizador",
    "sinalizadores": "sinalizador",
    "sinalizados": "sinalizar",
    "sinalizai": "sinalizar",
    "sinalizais": "sinalizar",
    "sinalizam": "sinalizar",
    "sinalizamo": "sinalizar",
    "sinalizamos": "sinalizar",
    "sinalizando": "sinalizar",
    "sinalizara": "sinalizar",
    "sinalizaram": "sinalizar",
    "sinalizaras": "sinalizar",
    "sinalizarde": "sinalizar",
    "sinalizardes": "sinalizar",
    "sinalizare": "sinalizar",
    "sinalizarei": "sinalizar",
    "sinalizareis": "sinalizar",
    "sinalizarem": "sinalizar",
    "sinalizaremos": "sinalizar",
    "sinalizares": "sinalizar",
    "sinalizaria": "sinalizar",
    "sinalizariam": "sinalizar",
    "sinalizarias": "sinalizar",
    "sinalizarmo": "sinalizar",
    "sinalizarmos": "sinalizar",
    "sinalizará": "sinalizar",
    "sinalizarás": "sinalizar",
    "sinalizarão": "sinalizar",
    "sinalizaríamos": "sinalizar",
    "sinalizaríeis": "sinalizar",
    "sinalizas": "sinalizar",
    "sinalizasse": "sinalizar",
    "sinalizassem": "sinalizar",
    "sinalizasses": "sinalizar",
    "sinalizaste": "sinalizar",
    "sinalizastes": "sinalizar",
    "sinalizava": "sinalizar",
    "sinalizavam": "sinalizar",
    "sinalizavas": "sinalizar",
    "sinalizações": "sinalização",
    "sinalize": "sinalizar",
    "sinalizei": "sinalizar",
    "sinalizeis": "sinalizar",
    "sinalizem": "sinalizar",
    "sinalizemo": "sinalizar",
    "sinalizemos": "sinalizar",
    "sinalizes": "sinalizar",
    "sinalizo": "sinalizar",
    "sinalizou": "sinalizar",
    "sinalizá": "sinalizar",
    "sinalizámo": "sinalizar",
    "sinalizámos": "sinalizar",
    "sinalizáramo": "sinalizar",
    "sinalizáramos": "sinalizar",
    "sinalizárei": "sinalizar",
    "sinalizáreis": "sinalizar",
    "sinalizásseis": "sinalizar",
    "sinalizássemos": "sinalizar",
    "sinalizávamo": "sinalizar",
    "sinalizávamos": "sinalizar",
    "sinalizávei": "sinalizar",
    "sinalizáveis": "sinalizável",
    "sinalo": "sinalar",
    "sinalou": "sinalar",
    "sinalzinho": "sinal",
    "sinalzito": "sinal",
    "sinalá": "sinalar",
    "sinalámo": "sinalar",
    "sinalámos": "sinalar",
    "sinaláramo": "sinalar",
    "sinaláramos": "sinalar",
    "sinalárei": "sinalar",
    "sinaláreis": "sinalar",
    "sinalásseis": "sinalar",
    "sinalássemos": "sinalar",
    "sinalávamo": "sinalar",
    "sinalávamos": "sinalar",
    "sinalávei": "sinalar",
    "sinaláveis": "sinalar",
    "sinaléticas": "sinalética",
    "sinandrias": "sinandria",
    "sinandros": "sinandro",
    "sinanterias": "sinanteria",
    "sinantias": "sinantia",
    "sinantocarpias": "sinantocarpia",
    "sinantocarpos": "sinantocarpo",
    "sinantropos": "sinantropo",
    "sinantérea": "sinantéreo",
    "sinantéreas": "sinantéreo",
    "sinantéreos": "sinantéreo",
    "sinantérica": "sinantérico",
    "sinantéricas": "sinantérico",
    "sinantéricos": "sinantérico",
    "sinapismos": "sinapismo",
    "sinapiza": "sinapizar",
    "sinapizada": "sinapizar",
    "sinapizadas": "sinapizar",
    "sinapizado": "sinapizar",
    "sinapizados": "sinapizar",
    "sinapizai": "sinapizar",
    "sinapizais": "sinapizar",
    "sinapizam": "sinapizar",
    "sinapizamo": "sinapizar",
    "sinapizamos": "sinapizar",
    "sinapizando": "sinapizar",
    "sinapizara": "sinapizar",
    "sinapizaram": "sinapizar",
    "sinapizaras": "sinapizar",
    "sinapizarde": "sinapizar",
    "sinapizardes": "sinapizar",
    "sinapizare": "sinapizar",
    "sinapizarei": "sinapizar",
    "sinapizareis": "sinapizar",
    "sinapizarem": "sinapizar",
    "sinapizaremos": "sinapizar",
    "sinapizares": "sinapizar",
    "sinapizaria": "sinapizar",
    "sinapizariam": "sinapizar",
    "sinapizarias": "sinapizar",
    "sinapizarmo": "sinapizar",
    "sinapizarmos": "sinapizar",
    "sinapizará": "sinapizar",
    "sinapizarás": "sinapizar",
    "sinapizarão": "sinapizar",
    "sinapizaríamos": "sinapizar",
    "sinapizaríeis": "sinapizar",
    "sinapizas": "sinapizar",
    "sinapizasse": "sinapizar",
    "sinapizassem": "sinapizar",
    "sinapizasses": "sinapizar",
    "sinapizaste": "sinapizar",
    "sinapizastes": "sinapizar",
    "sinapizava": "sinapizar",
    "sinapizavam": "sinapizar",
    "sinapizavas": "sinapizar",
    "sinapizações": "sinapização",
    "sinapize": "sinapizar",
    "sinapizei": "sinapizar",
    "sinapizeis": "sinapizar",
    "sinapizem": "sinapizar",
    "sinapizemo": "sinapizar",
    "sinapizemos": "sinapizar",
    "sinapizes": "sinapizar",
    "sinapizo": "sinapizar",
    "sinapizou": "sinapizar",
    "sinapizá": "sinapizar",
    "sinapizámo": "sinapizar",
    "sinapizámos": "sinapizar",
    "sinapizáramo": "sinapizar",
    "sinapizáramos": "sinapizar",
    "sinapizárei": "sinapizar",
    "sinapizáreis": "sinapizar",
    "sinapizásseis": "sinapizar",
    "sinapizássemos": "sinapizar",
    "sinapizávamo": "sinapizar",
    "sinapizávamos": "sinapizar",
    "sinapizávei": "sinapizar",
    "sinapizáveis": "sinapizar",
    "sinapses": "sinapse",
    "sinaptologias": "sinaptologia",
    "sinartroses": "sinartrose",
    "sinas": "sino",
    "sinaspismos": "sinaspismo",
    "sinaítas": "sinaíta",
    "sincantos": "sincanto",
    "sincarpa": "sincarpo",
    "sincarpada": "sincarpado",
    "sincarpadas": "sincarpado",
    "sincarpados": "sincarpado",
    "sincarpas": "sincarpo",
    "sincarpias": "sincarpia",
    "sincarpos": "sincarpo",
    "sincarídeos": "sincarídeo",
    "sincdactilias": "sincdactilia",
    "sinceirais": "sinceiral",
    "sinceiros": "sinceiro",
    "sinceladas": "sincelada",
    "sincelos": "sincelo",
    "sincenos": "sinceno",
    "sincera": "sincero",
    "sinceras": "sincero",
    "sinceridades": "sinceridade",
    "sinceros": "sincero",
    "sincinesias": "sincinesia",
    "sincipitais": "sincipital",
    "sincipúcios": "sincipúcio",
    "sinclinais": "sinclinal",
    "sinclinórios": "sinclinório",
    "sinclitismos": "sinclitismo",
    "sinclítica": "sinclítico",
    "sinclíticas": "sinclítico",
    "sinclíticos": "sinclítico",
    "sincondroses": "sincondrose",
    "sincondrotomias": "sincondrotomia",
    "sincopa": "sincopar",
    "sincopada": "sincopar",
    "sincopadas": "sincopar",
    "sincopado": "sincopar",
    "sincopados": "sincopar",
    "sincopai": "sincopar",
    "sincopais": "sincopar",
    "sincopam": "sincopar",
    "sincopamo": "sincopar",
    "sincopamos": "sincopar",
    "sincopando": "sincopar",
    "sincopara": "sincopar",
    "sincoparam": "sincopar",
    "sincoparas": "sincopar",
    "sincoparde": "sincopar",
    "sincopardes": "sincopar",
    "sincopare": "sincopar",
    "sincoparei": "sincopar",
    "sincopareis": "sincopar",
    "sincoparem": "sincopar",
    "sincoparemos": "sincopar",
    "sincopares": "sincopar",
    "sincoparia": "sincopar",
    "sincopariam": "sincopar",
    "sincoparias": "sincopar",
    "sincoparmo": "sincopar",
    "sincoparmos": "sincopar",
    "sincopará": "sincopar",
    "sincoparás": "sincopar",
    "sincoparão": "sincopar",
    "sincoparíamos": "sincopar",
    "sincoparíeis": "sincopar",
    "sincopas": "sincopar",
    "sincopasse": "sincopar",
    "sincopassem": "sincopar",
    "sincopasses": "sincopar",
    "sincopaste": "sincopar",
    "sincopastes": "sincopar",
    "sincopava": "sincopar",
    "sincopavam": "sincopar",
    "sincopavas": "sincopar",
    "sincope": "sincopar",
    "sincopei": "sincopar",
    "sincopeis": "sincopar",
    "sincopem": "sincopar",
    "sincopemo": "sincopar",
    "sincopemos": "sincopar",
    "sincopes": "sincopar",
    "sincopo": "sincopar",
    "sincopou": "sincopar",
    "sincopá": "sincopar",
    "sincopámo": "sincopar",
    "sincopámos": "sincopar",
    "sincopáramo": "sincopar",
    "sincopáramos": "sincopar",
    "sincopárei": "sincopar",
    "sincopáreis": "sincopar",
    "sincopásseis": "sincopar",
    "sincopássemos": "sincopar",
    "sincopávamo": "sincopar",
    "sincopávamos": "sincopar",
    "sincopávei": "sincopar",
    "sincopáveis": "sincopável",
    "sincorologias": "sincorologia",
    "sincotiledónea": "sincotiledóneo",
    "sincotiledóneas": "sincotiledóneo",
    "sincotiledóneos": "sincotiledóneo",
    "sincotilias": "sincotilia",
    "sincretismos": "sincretismo",
    "sincretistas": "sincretista",
    "sincrociclotrões": "sincrociclotrão",
    "sincronismos": "sincronismo",
    "sincronistas": "sincronista",
    "sincroniza": "sincronizar",
    "sincronizada": "sincronizar",
    "sincronizadas": "sincronizar",
    "sincronizado": "sincronizar",
    "sincronizados": "sincronizar",
    "sincronizai": "sincronizar",
    "sincronizais": "sincronizar",
    "sincronizam": "sincronizar",
    "sincronizamo": "sincronizar",
    "sincronizamos": "sincronizar",
    "sincronizando": "sincronizar",
    "sincronizara": "sincronizar",
    "sincronizaram": "sincronizar",
    "sincronizaras": "sincronizar",
    "sincronizarde": "sincronizar",
    "sincronizardes": "sincronizar",
    "sincronizare": "sincronizar",
    "sincronizarei": "sincronizar",
    "sincronizareis": "sincronizar",
    "sincronizarem": "sincronizar",
    "sincronizaremos": "sincronizar",
    "sincronizares": "sincronizar",
    "sincronizaria": "sincronizar",
    "sincronizariam": "sincronizar",
    "sincronizarias": "sincronizar",
    "sincronizarmo": "sincronizar",
    "sincronizarmos": "sincronizar",
    "sincronizará": "sincronizar",
    "sincronizarás": "sincronizar",
    "sincronizarão": "sincronizar",
    "sincronizaríamos": "sincronizar",
    "sincronizaríeis": "sincronizar",
    "sincronizas": "sincronizar",
    "sincronizasse": "sincronizar",
    "sincronizassem": "sincronizar",
    "sincronizasses": "sincronizar",
    "sincronizaste": "sincronizar",
    "sincronizastes": "sincronizar",
    "sincronizava": "sincronizar",
    "sincronizavam": "sincronizar",
    "sincronizavas": "sincronizar",
    "sincronizações": "sincronização",
    "sincronize": "sincronizar",
    "sincronizei": "sincronizar",
    "sincronizeis": "sincronizar",
    "sincronizem": "sincronizar",
    "sincronizemo": "sincronizar",
    "sincronizemos": "sincronizar",
    "sincronizes": "sincronizar",
    "sincronizo": "sincronizar",
    "sincronizou": "sincronizar",
    "sincronizá": "sincronizar",
    "sincronizámo": "sincronizar",
    "sincronizámos": "sincronizar",
    "sincronizáramo": "sincronizar",
    "sincronizáramos": "sincronizar",
    "sincronizárei": "sincronizar",
    "sincronizáreis": "sincronizar",
    "sincronizásseis": "sincronizar",
    "sincronizássemos": "sincronizar",
    "sincronizávamo": "sincronizar",
    "sincronizávamos": "sincronizar",
    "sincronizávei": "sincronizar",
    "sincronizáveis": "sincronizável",
    "sincroscópios": "sincroscópio",
    "sincrotrões": "sincrotrão",
    "sincrética": "sincrético",
    "sincréticas": "sincrético",
    "sincréticos": "sincrético",
    "sincrítica": "sincrítico",
    "sincríticas": "sincrítico",
    "sincríticos": "sincrítico",
    "sincrónica": "sincrónico",
    "sincrónicas": "sincrónico",
    "sincrónicos": "sincrónico",
    "sincárpica": "sincárpico",
    "sincárpicas": "sincárpico",
    "sincárpicos": "sincárpico",
    "sincéfala": "sincéfalo",
    "sincéfalas": "sincéfalo",
    "sincéfalos": "sincéfalo",
    "sincícios": "sincício",
    "sindectomias": "sindectomia",
    "sindesmites": "sindesmite",
    "sindesmografias": "sindesmografia",
    "sindesmologias": "sindesmologia",
    "sindesmoses": "sindesmose",
    "sindesmotomias": "sindesmotomia",
    "sindica": "sindicar",
    "sindicada": "sindicar",
    "sindicadas": "sindicar",
    "sindicado": "sindicar",
    "sindicadora": "sindicador",
    "sindicadoras": "sindicador",
    "sindicadores": "sindicador",
    "sindicados": "sindicar",
    "sindicai": "sindicar",
    "sindicais": "sindicar",
    "sindicalismos": "sindicalismo",
    "sindicalistas": "sindicalista",
    "sindicalistazinha": "sindicalista",
    "sindicalistazinhas": "sindicalista",
    "sindicalistazinho": "sindicalista",
    "sindicalistazinhos": "sindicalista",
    "sindicalistazita": "sindicalista",
    "sindicalistazitas": "sindicalista",
    "sindicalistazito": "sindicalista",
    "sindicalistazitos": "sindicalista",
    "sindicaliza": "sindicalizar",
    "sindicalizada": "sindicalizar",
    "sindicalizadas": "sindicalizar",
    "sindicalizado": "sindicalizar",
    "sindicalizados": "sindicalizar",
    "sindicalizai": "sindicalizar",
    "sindicalizais": "sindicalizar",
    "sindicalizam": "sindicalizar",
    "sindicalizamo": "sindicalizar",
    "sindicalizamos": "sindicalizar",
    "sindicalizando": "sindicalizar",
    "sindicalizara": "sindicalizar",
    "sindicalizaram": "sindicalizar",
    "sindicalizaras": "sindicalizar",
    "sindicalizarde": "sindicalizar",
    "sindicalizardes": "sindicalizar",
    "sindicalizare": "sindicalizar",
    "sindicalizarei": "sindicalizar",
    "sindicalizareis": "sindicalizar",
    "sindicalizarem": "sindicalizar",
    "sindicalizaremos": "sindicalizar",
    "sindicalizares": "sindicalizar",
    "sindicalizaria": "sindicalizar",
    "sindicalizariam": "sindicalizar",
    "sindicalizarias": "sindicalizar",
    "sindicalizarmo": "sindicalizar",
    "sindicalizarmos": "sindicalizar",
    "sindicalizará": "sindicalizar",
    "sindicalizarás": "sindicalizar",
    "sindicalizarão": "sindicalizar",
    "sindicalizaríamos": "sindicalizar",
    "sindicalizaríeis": "sindicalizar",
    "sindicalizas": "sindicalizar",
    "sindicalizasse": "sindicalizar",
    "sindicalizassem": "sindicalizar",
    "sindicalizasses": "sindicalizar",
    "sindicalizaste": "sindicalizar",
    "sindicalizastes": "sindicalizar",
    "sindicalizava": "sindicalizar",
    "sindicalizavam": "sindicalizar",
    "sindicalizavas": "sindicalizar",
    "sindicalizações": "sindicalização",
    "sindicalize": "sindicalizar",
    "sindicalizei": "sindicalizar",
    "sindicalizeis": "sindicalizar",
    "sindicalizem": "sindicalizar",
    "sindicalizemo": "sindicalizar",
    "sindicalizemos": "sindicalizar",
    "sindicalizes": "sindicalizar",
    "sindicalizo": "sindicalizar",
    "sindicalizou": "sindicalizar",
    "sindicalizá": "sindicalizar",
    "sindicalizámo": "sindicalizar",
    "sindicalizámos": "sindicalizar",
    "sindicalizáramo": "sindicalizar",
    "sindicalizáramos": "sindicalizar",
    "sindicalizárei": "sindicalizar",
    "sindicalizáreis": "sindicalizar",
    "sindicalizásseis": "sindicalizar",
    "sindicalizássemos": "sindicalizar",
    "sindicalizávamo": "sindicalizar",
    "sindicalizávamos": "sindicalizar",
    "sindicalizávei": "sindicalizar",
    "sindicalizáveis": "sindicalizar",
    "sindicam": "sindicar",
    "sindicamo": "sindicar",
    "sindicamos": "sindicar",
    "sindicando": "sindicar",
    "sindicantes": "sindicante",
    "sindicara": "sindicar",
    "sindicaram": "sindicar",
    "sindicaras": "sindicar",
    "sindicarde": "sindicar",
    "sindicardes": "sindicar",
    "sindicare": "sindicar",
    "sindicarei": "sindicar",
    "sindicareis": "sindicar",
    "sindicarem": "sindicar",
    "sindicaremos": "sindicar",
    "sindicares": "sindicar",
    "sindicaria": "sindicar",
    "sindicariam": "sindicar",
    "sindicarias": "sindicar",
    "sindicarmo": "sindicar",
    "sindicarmos": "sindicar",
    "sindicará": "sindicar",
    "sindicarás": "sindicar",
    "sindicarão": "sindicar",
    "sindicaríamos": "sindicar",
    "sindicaríeis": "sindicar",
    "sindicas": "sindicar",
    "sindicasse": "sindicar",
    "sindicassem": "sindicar",
    "sindicasses": "sindicar",
    "sindicaste": "sindicar",
    "sindicastes": "sindicar",
    "sindicateiros": "sindicateiro",
    "sindicatos": "sindicato",
    "sindicaturas": "sindicatura",
    "sindicatários": "sindicatário",
    "sindicatórios": "sindicatório",
    "sindicava": "sindicar",
    "sindicavam": "sindicar",
    "sindicavas": "sindicar",
    "sindicações": "sindicação",
    "sindico": "sindicar",
    "sindicou": "sindicar",
    "sindicá": "sindicar",
    "sindicámo": "sindicar",
    "sindicámos": "sindicar",
    "sindicáramo": "sindicar",
    "sindicáramos": "sindicar",
    "sindicárei": "sindicar",
    "sindicáreis": "sindicar",
    "sindicásseis": "sindicar",
    "sindicássemos": "sindicar",
    "sindicávamo": "sindicar",
    "sindicávamos": "sindicar",
    "sindicávei": "sindicar",
    "sindicáveis": "sindicar",
    "sindicâncias": "sindicância",
    "sindique": "sindicar",
    "sindiquei": "sindicar",
    "sindiqueis": "sindicar",
    "sindiquem": "sindicar",
    "sindiquemo": "sindicar",
    "sindiquemos": "sindicar",
    "sindiques": "sindicar",
    "sindis": "sindi",
    "sindromais": "sindromal",
    "sindromas": "sindroma",
    "sindromática": "sindromático",
    "sindromáticas": "sindromático",
    "sindromáticos": "sindromático",
    "sindrómica": "sindrómico",
    "sindrómicas": "sindrómico",
    "sindrómicos": "sindrómico",
    "sindáctila": "sindáctilo",
    "sindáctilas": "sindáctilo",
    "sindáctilos": "sindáctilo",
    "sindéctica": "sindéctico",
    "sindécticas": "sindéctico",
    "sindécticos": "sindéctico",
    "sindéreses": "sindérese",
    "sinecologias": "sinecologia",
    "sinecuras": "sinecura",
    "sinecurismos": "sinecurismo",
    "sinecuristas": "sinecurista",
    "sinedrins": "sinedrim",
    "sineira": "sineiro",
    "sineiras": "sineiro",
    "sineirazinha": "sineiro",
    "sineirazinhas": "sineiro",
    "sineirazita": "sineiro",
    "sineirazitas": "sineiro",
    "sineiros": "sineiro",
    "sineirozinho": "sineiro",
    "sineirozinhos": "sineiro",
    "sineirozito": "sineiro",
    "sineirozitos": "sineiro",
    "sinemas": "sinema",
    "sinemurianos": "sinemuriano",
    "sinemática": "sinemático",
    "sinemáticas": "sinemático",
    "sinemáticos": "sinemático",
    "sinentógnatos": "sinentógnato",
    "sinergias": "sinergia",
    "sinergismos": "sinergismo",
    "sinergistas": "sinergista",
    "sinestesias": "sinestesia",
    "sinestra": "sinestro",
    "sinestras": "sinestro",
    "sinestros": "sinestro",
    "sineta": "sinetar",
    "sinetada": "sinetar",
    "sinetadas": "sinetar",
    "sinetado": "sinetar",
    "sinetados": "sinetar",
    "sinetai": "sinetar",
    "sinetais": "sinetar",
    "sinetam": "sinetar",
    "sinetamo": "sinetar",
    "sinetamos": "sinetar",
    "sinetando": "sinetar",
    "sinetara": "sinetar",
    "sinetaram": "sinetar",
    "sinetaras": "sinetar",
    "sinetarde": "sinetar",
    "sinetardes": "sinetar",
    "sinetare": "sinetar",
    "sinetarei": "sinetar",
    "sinetareis": "sinetar",
    "sinetarem": "sinetar",
    "sinetaremos": "sinetar",
    "sinetares": "sinetar",
    "sinetaria": "sinetar",
    "sinetariam": "sinetar",
    "sinetarias": "sinetar",
    "sinetarmo": "sinetar",
    "sinetarmos": "sinetar",
    "sinetará": "sinetar",
    "sinetarás": "sinetar",
    "sinetarão": "sinetar",
    "sinetaríamos": "sinetar",
    "sinetaríeis": "sinetar",
    "sinetas": "sinetar",
    "sinetasse": "sinetar",
    "sinetassem": "sinetar",
    "sinetasses": "sinetar",
    "sinetaste": "sinetar",
    "sinetastes": "sinetar",
    "sinetava": "sinetar",
    "sinetavam": "sinetar",
    "sinetavas": "sinetar",
    "sinete": "sinetar",
    "sinetei": "sinetar",
    "sineteis": "sinetar",
    "sinetem": "sinetar",
    "sinetemo": "sinetar",
    "sinetemos": "sinetar",
    "sinetes": "sinete",
    "sineto": "sinetar",
    "sinetou": "sinetar",
    "sinetá": "sinetar",
    "sinetámo": "sinetar",
    "sinetámos": "sinetar",
    "sinetáramo": "sinetar",
    "sinetáramos": "sinetar",
    "sinetárei": "sinetar",
    "sinetáreis": "sinetar",
    "sinetásseis": "sinetar",
    "sinetássemos": "sinetar",
    "sinetávamo": "sinetar",
    "sinetávamos": "sinetar",
    "sinetávei": "sinetar",
    "sinetáveis": "sinetar",
    "sinfilias": "sinfilia",
    "sinfisiotomias": "sinfisiotomia",
    "sinfonias": "sinfonia",
    "sinfonietas": "sinfonieta",
    "sinfonistas": "sinfonista",
    "sinfoniza": "sinfonizar",
    "sinfonizada": "sinfonizar",
    "sinfonizadas": "sinfonizar",
    "sinfonizado": "sinfonizar",
    "sinfonizados": "sinfonizar",
    "sinfonizai": "sinfonizar",
    "sinfonizais": "sinfonizar",
    "sinfonizam": "sinfonizar",
    "sinfonizamo": "sinfonizar",
    "sinfonizamos": "sinfonizar",
    "sinfonizando": "sinfonizar",
    "sinfonizara": "sinfonizar",
    "sinfonizaram": "sinfonizar",
    "sinfonizaras": "sinfonizar",
    "sinfonizarde": "sinfonizar",
    "sinfonizardes": "sinfonizar",
    "sinfonizare": "sinfonizar",
    "sinfonizarei": "sinfonizar",
    "sinfonizareis": "sinfonizar",
    "sinfonizarem": "sinfonizar",
    "sinfonizaremos": "sinfonizar",
    "sinfonizares": "sinfonizar",
    "sinfonizaria": "sinfonizar",
    "sinfonizariam": "sinfonizar",
    "sinfonizarias": "sinfonizar",
    "sinfonizarmo": "sinfonizar",
    "sinfonizarmos": "sinfonizar",
    "sinfonizará": "sinfonizar",
    "sinfonizarás": "sinfonizar",
    "sinfonizarão": "sinfonizar",
    "sinfonizaríamos": "sinfonizar",
    "sinfonizaríeis": "sinfonizar",
    "sinfonizas": "sinfonizar",
    "sinfonizasse": "sinfonizar",
    "sinfonizassem": "sinfonizar",
    "sinfonizasses": "sinfonizar",
    "sinfonizaste": "sinfonizar",
    "sinfonizastes": "sinfonizar",
    "sinfonizava": "sinfonizar",
    "sinfonizavam": "sinfonizar",
    "sinfonizavas": "sinfonizar",
    "sinfonize": "sinfonizar",
    "sinfonizei": "sinfonizar",
    "sinfonizeis": "sinfonizar",
    "sinfonizem": "sinfonizar",
    "sinfonizemo": "sinfonizar",
    "sinfonizemos": "sinfonizar",
    "sinfonizes": "sinfonizar",
    "sinfonizo": "sinfonizar",
    "sinfonizou": "sinfonizar",
    "sinfonizá": "sinfonizar",
    "sinfonizámo": "sinfonizar",
    "sinfonizámos": "sinfonizar",
    "sinfonizáramo": "sinfonizar",
    "sinfonizáramos": "sinfonizar",
    "sinfonizárei": "sinfonizar",
    "sinfonizáreis": "sinfonizar",
    "sinfonizásseis": "sinfonizar",
    "sinfonizássemos": "sinfonizar",
    "sinfonizávamo": "sinfonizar",
    "sinfonizávamos": "sinfonizar",
    "sinfonizávei": "sinfonizar",
    "sinfonizáveis": "sinfonizar",
    "sinforinas": "sinforina",
    "sinfónica": "sinfónico",
    "sinfónicas": "sinfónico",
    "sinfónicos": "sinfónico",
    "singamias": "singamia",
    "singamídeos": "singamídeo",
    "singela": "singelo",
    "singelas": "singelo",
    "singeleiras": "singeleira",
    "singelezas": "singeleza",
    "singelos": "singelo",
    "singenesias": "singenesia",
    "singenistas": "singenista",
    "singenésica": "singenésico",
    "singenésicas": "singenésico",
    "singenésicos": "singenésico",
    "singenética": "singenético",
    "singenéticas": "singenético",
    "singenéticos": "singenético",
    "singles": "single",
    "singletes": "singlete",
    "singletos": "singleto",
    "singnatídeos": "singnatídeo",
    "singnátidas": "singnátida",
    "singra": "singrar",
    "singrada": "singrar",
    "singradas": "singrar",
    "singradeiros": "singradeiro",
    "singrado": "singrar",
    "singrados": "singrar",
    "singradouros": "singradouro",
    "singraduras": "singradura",
    "singrai": "singrar",
    "singrais": "singrar",
    "singram": "singrar",
    "singramo": "singrar",
    "singramos": "singrar",
    "singrando": "singrar",
    "singrantes": "singrante",
    "singrara": "singrar",
    "singraram": "singrar",
    "singraras": "singrar",
    "singrardes": "singrar",
    "singrarei": "singrar",
    "singrareis": "singrar",
    "singrarem": "singrar",
    "singraremos": "singrar",
    "singrares": "singrar",
    "singraria": "singrar",
    "singrariam": "singrar",
    "singrarias": "singrar",
    "singrarmo": "singrar",
    "singrarmos": "singrar",
    "singrará": "singrar",
    "singrarás": "singrar",
    "singrarão": "singrar",
    "singraríamos": "singrar",
    "singraríeis": "singrar",
    "singras": "singrar",
    "singrasse": "singrar",
    "singrassem": "singrar",
    "singrasses": "singrar",
    "singraste": "singrar",
    "singrastes": "singrar",
    "singrava": "singrar",
    "singravam": "singrar",
    "singravas": "singrar",
    "singre": "singrar",
    "singrei": "singrar",
    "singreis": "singrar",
    "singrem": "singrar",
    "singremo": "singrar",
    "singremos": "singrar",
    "singres": "singrar",
    "singro": "singrar",
    "singrou": "singrar",
    "singrámo": "singrar",
    "singrámos": "singrar",
    "singráramo": "singrar",
    "singráramos": "singrar",
    "singráreis": "singrar",
    "singrásseis": "singrar",
    "singrássemos": "singrar",
    "singrávamo": "singrar",
    "singrávamos": "singrar",
    "singráveis": "singrar",
    "singulares": "singular",
    "singularidades": "singularidade",
    "singulariza": "singularizar",
    "singularizada": "singularizar",
    "singularizadas": "singularizar",
    "singularizado": "singularizar",
    "singularizados": "singularizar",
    "singularizai": "singularizar",
    "singularizais": "singularizar",
    "singularizam": "singularizar",
    "singularizamo": "singularizar",
    "singularizamos": "singularizar",
    "singularizando": "singularizar",
    "singularizara": "singularizar",
    "singularizaram": "singularizar",
    "singularizaras": "singularizar",
    "singularizarde": "singularizar",
    "singularizardes": "singularizar",
    "singularizare": "singularizar",
    "singularizarei": "singularizar",
    "singularizareis": "singularizar",
    "singularizarem": "singularizar",
    "singularizaremos": "singularizar",
    "singularizares": "singularizar",
    "singularizaria": "singularizar",
    "singularizariam": "singularizar",
    "singularizarias": "singularizar",
    "singularizarmo": "singularizar",
    "singularizarmos": "singularizar",
    "singularizará": "singularizar",
    "singularizarás": "singularizar",
    "singularizarão": "singularizar",
    "singularizaríamos": "singularizar",
    "singularizaríeis": "singularizar",
    "singularizas": "singularizar",
    "singularizasse": "singularizar",
    "singularizassem": "singularizar",
    "singularizasses": "singularizar",
    "singularizaste": "singularizar",
    "singularizastes": "singularizar",
    "singularizava": "singularizar",
    "singularizavam": "singularizar",
    "singularizavas": "singularizar",
    "singularize": "singularizar",
    "singularizei": "singularizar",
    "singularizeis": "singularizar",
    "singularizem": "singularizar",
    "singularizemo": "singularizar",
    "singularizemos": "singularizar",
    "singularizes": "singularizar",
    "singularizo": "singularizar",
    "singularizou": "singularizar",
    "singularizá": "singularizar",
    "singularizámo": "singularizar",
    "singularizámos": "singularizar",
    "singularizáramo": "singularizar",
    "singularizáramos": "singularizar",
    "singularizárei": "singularizar",
    "singularizáreis": "singularizar",
    "singularizásseis": "singularizar",
    "singularizássemos": "singularizar",
    "singularizávamo": "singularizar",
    "singularizávamos": "singularizar",
    "singularizávei": "singularizar",
    "singularizáveis": "singularizar",
    "singulars": "singular",
    "singultos": "singulto",
    "singéneses": "singénese",
    "sinhás": "sinhá",
    "sinienses": "siniense",
    "sininho": "sino",
    "sininhos": "sino",
    "sinistra": "sinistro",
    "sinistrada": "sinistrar",
    "sinistradas": "sinistrar",
    "sinistradazinha": "sinistrado",
    "sinistradazinhas": "sinistrado",
    "sinistradazita": "sinistrado",
    "sinistradazitas": "sinistrado",
    "sinistrado": "sinistrar",
    "sinistrados": "sinistrar",
    "sinistradozinho": "sinistrado",
    "sinistradozinhos": "sinistrado",
    "sinistradozito": "sinistrado",
    "sinistradozitos": "sinistrado",
    "sinistrai": "sinistrar",
    "sinistrais": "sinistrar",
    "sinistralidades": "sinistralidade",
    "sinistram": "sinistrar",
    "sinistramo": "sinistrar",
    "sinistramos": "sinistrar",
    "sinistrando": "sinistrar",
    "sinistrara": "sinistrar",
    "sinistraram": "sinistrar",
    "sinistraras": "sinistrar",
    "sinistrardes": "sinistrar",
    "sinistrarei": "sinistrar",
    "sinistrareis": "sinistrar",
    "sinistrarem": "sinistrar",
    "sinistraremos": "sinistrar",
    "sinistrares": "sinistrar",
    "sinistraria": "sinistrar",
    "sinistrariam": "sinistrar",
    "sinistrarias": "sinistrar",
    "sinistrarmo": "sinistrar",
    "sinistrarmos": "sinistrar",
    "sinistrará": "sinistrar",
    "sinistrarás": "sinistrar",
    "sinistrarão": "sinistrar",
    "sinistraríamos": "sinistrar",
    "sinistraríeis": "sinistrar",
    "sinistras": "sinistro",
    "sinistrasse": "sinistrar",
    "sinistrassem": "sinistrar",
    "sinistrasses": "sinistrar",
    "sinistraste": "sinistrar",
    "sinistrastes": "sinistrar",
    "sinistrava": "sinistrar",
    "sinistravam": "sinistrar",
    "sinistravas": "sinistrar",
    "sinistre": "sinistrar",
    "sinistrei": "sinistrar",
    "sinistreis": "sinistrar",
    "sinistrem": "sinistrar",
    "sinistremo": "sinistrar",
    "sinistremos": "sinistrar",
    "sinistres": "sinistrar",
    "sinistrismos": "sinistrismo",
    "sinistro": "sinistrar",
    "sinistrocardias": "sinistrocardia",
    "sinistrorsa": "sinistrorso",
    "sinistrorsas": "sinistrorso",
    "sinistrorsos": "sinistrorso",
    "sinistros": "sinistro",
    "sinistrou": "sinistrar",
    "sinistrámo": "sinistrar",
    "sinistrámos": "sinistrar",
    "sinistráramo": "sinistrar",
    "sinistráramos": "sinistrar",
    "sinistráreis": "sinistrar",
    "sinistrásseis": "sinistrar",
    "sinistrássemos": "sinistrar",
    "sinistrávamo": "sinistrar",
    "sinistrávamos": "sinistrar",
    "sinistráveis": "sinistrar",
    "sinito": "sino",
    "sinitos": "sino",
    "sinizeses": "sinizese",
    "sinodais": "sinodal",
    "sinodática": "sinodático",
    "sinodáticas": "sinodático",
    "sinodáticos": "sinodático",
    "sinologias": "sinologia",
    "sinológica": "sinológico",
    "sinológicas": "sinológico",
    "sinológicos": "sinológico",
    "sinonima": "sinonimar",
    "sinonimada": "sinonimar",
    "sinonimadas": "sinonimar",
    "sinonimado": "sinonimar",
    "sinonimados": "sinonimar",
    "sinonimai": "sinonimar",
    "sinonimais": "sinonimar",
    "sinonimam": "sinonimar",
    "sinonimamo": "sinonimar",
    "sinonimamos": "sinonimar",
    "sinonimando": "sinonimar",
    "sinonimara": "sinonimar",
    "sinonimaram": "sinonimar",
    "sinonimaras": "sinonimar",
    "sinonimarde": "sinonimar",
    "sinonimardes": "sinonimar",
    "sinonimare": "sinonimar",
    "sinonimarei": "sinonimar",
    "sinonimareis": "sinonimar",
    "sinonimarem": "sinonimar",
    "sinonimaremos": "sinonimar",
    "sinonimares": "sinonimar",
    "sinonimaria": "sinonimar",
    "sinonimariam": "sinonimar",
    "sinonimarias": "sinonimar",
    "sinonimarmo": "sinonimar",
    "sinonimarmos": "sinonimar",
    "sinonimará": "sinonimar",
    "sinonimarás": "sinonimar",
    "sinonimarão": "sinonimar",
    "sinonimaríamos": "sinonimar",
    "sinonimaríeis": "sinonimar",
    "sinonimas": "sinonimar",
    "sinonimasse": "sinonimar",
    "sinonimassem": "sinonimar",
    "sinonimasses": "sinonimar",
    "sinonimaste": "sinonimar",
    "sinonimastes": "sinonimar",
    "sinonimava": "sinonimar",
    "sinonimavam": "sinonimar",
    "sinonimavas": "sinonimar",
    "sinonime": "sinonimar",
    "sinonimei": "sinonimar",
    "sinonimeis": "sinonimar",
    "sinonimem": "sinonimar",
    "sinonimemo": "sinonimar",
    "sinonimemos": "sinonimar",
    "sinonimes": "sinonimar",
    "sinonimistas": "sinonimista",
    "sinonimiza": "sinonimizar",
    "sinonimizada": "sinonimizar",
    "sinonimizadas": "sinonimizar",
    "sinonimizado": "sinonimizar",
    "sinonimizados": "sinonimizar",
    "sinonimizai": "sinonimizar",
    "sinonimizais": "sinonimizar",
    "sinonimizam": "sinonimizar",
    "sinonimizamo": "sinonimizar",
    "sinonimizamos": "sinonimizar",
    "sinonimizando": "sinonimizar",
    "sinonimizara": "sinonimizar",
    "sinonimizaram": "sinonimizar",
    "sinonimizaras": "sinonimizar",
    "sinonimizarde": "sinonimizar",
    "sinonimizardes": "sinonimizar",
    "sinonimizare": "sinonimizar",
    "sinonimizarei": "sinonimizar",
    "sinonimizareis": "sinonimizar",
    "sinonimizarem": "sinonimizar",
    "sinonimizaremos": "sinonimizar",
    "sinonimizares": "sinonimizar",
    "sinonimizaria": "sinonimizar",
    "sinonimizariam": "sinonimizar",
    "sinonimizarias": "sinonimizar",
    "sinonimizarmo": "sinonimizar",
    "sinonimizarmos": "sinonimizar",
    "sinonimizará": "sinonimizar",
    "sinonimizarás": "sinonimizar",
    "sinonimizarão": "sinonimizar",
    "sinonimizaríamos": "sinonimizar",
    "sinonimizaríeis": "sinonimizar",
    "sinonimizas": "sinonimizar",
    "sinonimizasse": "sinonimizar",
    "sinonimizassem": "sinonimizar",
    "sinonimizasses": "sinonimizar",
    "sinonimizaste": "sinonimizar",
    "sinonimizastes": "sinonimizar",
    "sinonimizava": "sinonimizar",
    "sinonimizavam": "sinonimizar",
    "sinonimizavas": "sinonimizar",
    "sinonimize": "sinonimizar",
    "sinonimizei": "sinonimizar",
    "sinonimizeis": "sinonimizar",
    "sinonimizem": "sinonimizar",
    "sinonimizemo": "sinonimizar",
    "sinonimizemos": "sinonimizar",
    "sinonimizes": "sinonimizar",
    "sinonimizo": "sinonimizar",
    "sinonimizou": "sinonimizar",
    "sinonimizá": "sinonimizar",
    "sinonimizámo": "sinonimizar",
    "sinonimizámos": "sinonimizar",
    "sinonimizáramo": "sinonimizar",
    "sinonimizáramos": "sinonimizar",
    "sinonimizárei": "sinonimizar",
    "sinonimizáreis": "sinonimizar",
    "sinonimizásseis": "sinonimizar",
    "sinonimizássemos": "sinonimizar",
    "sinonimizávamo": "sinonimizar",
    "sinonimizávamos": "sinonimizar",
    "sinonimizávei": "sinonimizar",
    "sinonimizáveis": "sinonimizar",
    "sinonimo": "sinonimar",
    "sinonimou": "sinonimar",
    "sinonimá": "sinonimar",
    "sinonimámo": "sinonimar",
    "sinonimámos": "sinonimar",
    "sinonimáramo": "sinonimar",
    "sinonimáramos": "sinonimar",
    "sinonimárei": "sinonimar",
    "sinonimáreis": "sinonimar",
    "sinonimásseis": "sinonimar",
    "sinonimássemos": "sinonimar",
    "sinonimávamo": "sinonimar",
    "sinonimávamos": "sinonimar",
    "sinonimávei": "sinonimar",
    "sinonimáveis": "sinonimar",
    "sinonímias": "sinonímia",
    "sinonímica": "sinonímico",
    "sinonímicas": "sinonímico",
    "sinonímicos": "sinonímico",
    "sinoplas": "sinopla",
    "sinoples": "sinople",
    "sinopses": "sinopse",
    "sinopsias": "sinopsia",
    "sinoptiza": "sinoptizar",
    "sinoptizada": "sinoptizar",
    "sinoptizadas": "sinoptizar",
    "sinoptizado": "sinoptizar",
    "sinoptizados": "sinoptizar",
    "sinoptizai": "sinoptizar",
    "sinoptizais": "sinoptizar",
    "sinoptizam": "sinoptizar",
    "sinoptizamo": "sinoptizar",
    "sinoptizamos": "sinoptizar",
    "sinoptizando": "sinoptizar",
    "sinoptizara": "sinoptizar",
    "sinoptizaram": "sinoptizar",
    "sinoptizaras": "sinoptizar",
    "sinoptizarde": "sinoptizar",
    "sinoptizardes": "sinoptizar",
    "sinoptizare": "sinoptizar",
    "sinoptizarei": "sinoptizar",
    "sinoptizareis": "sinoptizar",
    "sinoptizarem": "sinoptizar",
    "sinoptizaremos": "sinoptizar",
    "sinoptizares": "sinoptizar",
    "sinoptizaria": "sinoptizar",
    "sinoptizariam": "sinoptizar",
    "sinoptizarias": "sinoptizar",
    "sinoptizarmo": "sinoptizar",
    "sinoptizarmos": "sinoptizar",
    "sinoptizará": "sinoptizar",
    "sinoptizarás": "sinoptizar",
    "sinoptizarão": "sinoptizar",
    "sinoptizaríamos": "sinoptizar",
    "sinoptizaríeis": "sinoptizar",
    "sinoptizas": "sinoptizar",
    "sinoptizasse": "sinoptizar",
    "sinoptizassem": "sinoptizar",
    "sinoptizasses": "sinoptizar",
    "sinoptizaste": "sinoptizar",
    "sinoptizastes": "sinoptizar",
    "sinoptizava": "sinoptizar",
    "sinoptizavam": "sinoptizar",
    "sinoptizavas": "sinoptizar",
    "sinoptize": "sinoptizar",
    "sinoptizei": "sinoptizar",
    "sinoptizeis": "sinoptizar",
    "sinoptizem": "sinoptizar",
    "sinoptizemo": "sinoptizar",
    "sinoptizemos": "sinoptizar",
    "sinoptizes": "sinoptizar",
    "sinoptizo": "sinoptizar",
    "sinoptizou": "sinoptizar",
    "sinoptizá": "sinoptizar",
    "sinoptizámo": "sinoptizar",
    "sinoptizámos": "sinoptizar",
    "sinoptizáramo": "sinoptizar",
    "sinoptizáramos": "sinoptizar",
    "sinoptizárei": "sinoptizar",
    "sinoptizáreis": "sinoptizar",
    "sinoptizásseis": "sinoptizar",
    "sinoptizássemos": "sinoptizar",
    "sinoptizávamo": "sinoptizar",
    "sinoptizávamos": "sinoptizar",
    "sinoptizávei": "sinoptizar",
    "sinoptizáveis": "sinoptizar",
    "sinos": "sino",
    "sinosteografias": "sinosteografia",
    "sinosteologias": "sinosteologia",
    "sinoviais": "sinovial",
    "sinovites": "sinovite",
    "sins": "sim",
    "sinsépala": "sinsépalo",
    "sinsépalas": "sinsépalo",
    "sinsépalos": "sinsépalo",
    "sinta": "sentir",
    "sintagmarcas": "sintagmarca",
    "sintagmas": "sintagma",
    "sintais": "sentir",
    "sintam": "sentir",
    "sintamo": "sentir",
    "sintamos": "sentir",
    "sintas": "sentir",
    "sintaxes": "sintaxe",
    "sintaxiologias": "sintaxiologia",
    "sintaxiológica": "sintaxiológico",
    "sintaxiológicas": "sintaxiológico",
    "sintaxiológicos": "sintaxiológico",
    "sintemas": "sintema",
    "sintetismos": "sintetismo",
    "sintetiza": "sintetizar",
    "sintetizada": "sintetizar",
    "sintetizadas": "sintetizar",
    "sintetizado": "sintetizar",
    "sintetizadores": "sintetizador",
    "sintetizados": "sintetizar",
    "sintetizai": "sintetizar",
    "sintetizais": "sintetizar",
    "sintetizam": "sintetizar",
    "sintetizamo": "sintetizar",
    "sintetizamos": "sintetizar",
    "sintetizando": "sintetizar",
    "sintetizara": "sintetizar",
    "sintetizaram": "sintetizar",
    "sintetizaras": "sintetizar",
    "sintetizarde": "sintetizar",
    "sintetizardes": "sintetizar",
    "sintetizare": "sintetizar",
    "sintetizarei": "sintetizar",
    "sintetizareis": "sintetizar",
    "sintetizarem": "sintetizar",
    "sintetizaremos": "sintetizar",
    "sintetizares": "sintetizar",
    "sintetizaria": "sintetizar",
    "sintetizariam": "sintetizar",
    "sintetizarias": "sintetizar",
    "sintetizarmo": "sintetizar",
    "sintetizarmos": "sintetizar",
    "sintetizará": "sintetizar",
    "sintetizarás": "sintetizar",
    "sintetizarão": "sintetizar",
    "sintetizaríamos": "sintetizar",
    "sintetizaríeis": "sintetizar",
    "sintetizas": "sintetizar",
    "sintetizasse": "sintetizar",
    "sintetizassem": "sintetizar",
    "sintetizasses": "sintetizar",
    "sintetizaste": "sintetizar",
    "sintetizastes": "sintetizar",
    "sintetizava": "sintetizar",
    "sintetizavam": "sintetizar",
    "sintetizavas": "sintetizar",
    "sintetizações": "sintetização",
    "sintetize": "sintetizar",
    "sintetizei": "sintetizar",
    "sintetizeis": "sintetizar",
    "sintetizem": "sintetizar",
    "sintetizemo": "sintetizar",
    "sintetizemos": "sintetizar",
    "sintetizes": "sintetizar",
    "sintetizo": "sintetizar",
    "sintetizou": "sintetizar",
    "sintetizá": "sintetizar",
    "sintetizámo": "sintetizar",
    "sintetizámos": "sintetizar",
    "sintetizáramo": "sintetizar",
    "sintetizáramos": "sintetizar",
    "sintetizárei": "sintetizar",
    "sintetizáreis": "sintetizar",
    "sintetizásseis": "sintetizar",
    "sintetizássemos": "sintetizar",
    "sintetizávamo": "sintetizar",
    "sintetizávamos": "sintetizar",
    "sintetizávei": "sintetizar",
    "sintetizáveis": "sintetizável",
    "sinto": "sentir",
    "sintomas": "sintoma",
    "sintomatismos": "sintomatismo",
    "sintomatologias": "sintomatologia",
    "sintomatologistas": "sintomatologista",
    "sintomatológica": "sintomatológico",
    "sintomatológicas": "sintomatológico",
    "sintomatológicos": "sintomatológico",
    "sintomias": "sintomia",
    "sintomática": "sintomático",
    "sintomáticas": "sintomático",
    "sintomáticos": "sintomático",
    "sintonias": "sintonia",
    "sintoninas": "sintonina",
    "sintoniza": "sintonizar",
    "sintonizada": "sintonizar",
    "sintonizadas": "sintonizar",
    "sintonizado": "sintonizar",
    "sintonizadores": "sintonizador",
    "sintonizados": "sintonizar",
    "sintonizai": "sintonizar",
    "sintonizais": "sintonizar",
    "sintonizam": "sintonizar",
    "sintonizamo": "sintonizar",
    "sintonizamos": "sintonizar",
    "sintonizando": "sintonizar",
    "sintonizara": "sintonizar",
    "sintonizaram": "sintonizar",
    "sintonizaras": "sintonizar",
    "sintonizarde": "sintonizar",
    "sintonizardes": "sintonizar",
    "sintonizare": "sintonizar",
    "sintonizarei": "sintonizar",
    "sintonizareis": "sintonizar",
    "sintonizarem": "sintonizar",
    "sintonizaremos": "sintonizar",
    "sintonizares": "sintonizar",
    "sintonizaria": "sintonizar",
    "sintonizariam": "sintonizar",
    "sintonizarias": "sintonizar",
    "sintonizarmo": "sintonizar",
    "sintonizarmos": "sintonizar",
    "sintonizará": "sintonizar",
    "sintonizarás": "sintonizar",
    "sintonizarão": "sintonizar",
    "sintonizaríamos": "sintonizar",
    "sintonizaríeis": "sintonizar",
    "sintonizas": "sintonizar",
    "sintonizasse": "sintonizar",
    "sintonizassem": "sintonizar",
    "sintonizasses": "sintonizar",
    "sintonizaste": "sintonizar",
    "sintonizastes": "sintonizar",
    "sintonizava": "sintonizar",
    "sintonizavam": "sintonizar",
    "sintonizavas": "sintonizar",
    "sintonizações": "sintonização",
    "sintonize": "sintonizar",
    "sintonizei": "sintonizar",
    "sintonizeis": "sintonizar",
    "sintonizem": "sintonizar",
    "sintonizemo": "sintonizar",
    "sintonizemos": "sintonizar",
    "sintonizes": "sintonizar",
    "sintonizo": "sintonizar",
    "sintonizou": "sintonizar",
    "sintonizá": "sintonizar",
    "sintonizámo": "sintonizar",
    "sintonizámos": "sintonizar",
    "sintonizáramo": "sintonizar",
    "sintonizáramos": "sintonizar",
    "sintonizárei": "sintonizar",
    "sintonizáreis": "sintonizar",
    "sintonizásseis": "sintonizar",
    "sintonizássemos": "sintonizar",
    "sintonizávamo": "sintonizar",
    "sintonizávamos": "sintonizar",
    "sintonizávei": "sintonizar",
    "sintonizáveis": "sintonizável",
    "sintoísmos": "sintoísmo",
    "sintoístas": "sintoísta",
    "sintratrizes": "sintratriz",
    "sintrenses": "sintrense",
    "sintrofias": "sintrofia",
    "sintros": "sintro",
    "sintrã": "sintrão",
    "sintrãos": "sintrão",
    "sintrãs": "sintrão",
    "sintáctica": "sintáctico",
    "sintácticas": "sintáctico",
    "sintácticos": "sintáctico",
    "sintáxica": "sintáxico",
    "sintáxicas": "sintáxico",
    "sintáxicos": "sintáxico",
    "sintética": "sintético",
    "sintéticas": "sintético",
    "sintéticos": "sintético",
    "sintónica": "sintónico",
    "sintónicas": "sintónico",
    "sintónicos": "sintónico",
    "sinuosa": "sinuoso",
    "sinuosas": "sinuoso",
    "sinuosidades": "sinuosidade",
    "sinuosos": "sinuoso",
    "sinupaliados": "sinupaliado",
    "sinusites": "sinusite",
    "sinusoidais": "sinusoidal",
    "sinusóides": "sinusóide",
    "sinápica": "sinápico",
    "sinápicas": "sinápico",
    "sinápicos": "sinápico",
    "sináptica": "sináptico",
    "sinápticas": "sináptico",
    "sinápticos": "sináptico",
    "sinédoques": "sinédoque",
    "sinédrios": "sinédrio",
    "sinéquias": "sinéquia",
    "sinéreses": "sinérese",
    "sinérgica": "sinérgico",
    "sinérgicas": "sinérgico",
    "sinérgicos": "sinérgico",
    "sinérgides": "sinérgide",
    "sinódica": "sinódico",
    "sinódicas": "sinódico",
    "sinódicos": "sinódico",
    "sinóloga": "sinólogo",
    "sinólogas": "sinólogo",
    "sinólogos": "sinólogo",
    "sinónima": "sinónimo",
    "sinónimas": "sinónimo",
    "sinónimos": "sinónimo",
    "sinóptica": "sinóptico",
    "sinópticas": "sinóptico",
    "sinópticos": "sinóptico",
    "sinóvias": "sinóvia",
    "sinões": "sinão",
    "sio": "siar",
    "siochos": "siocho",
    "sionismos": "sionismo",
    "sionistas": "sionista",
    "sionizações": "sionização",
    "sios": "sio",
    "siou": "siar",
    "sipaios": "sipaio",
    "sipais": "sipai",
    "sipilhos": "sipilho",
    "sira": "siro",
    "siracusana": "siracusano",
    "siracusanas": "siracusano",
    "siracusanos": "siracusano",
    "sirages": "sirage",
    "siras": "siro",
    "sirenas": "sirena",
    "sirenes": "sirene",
    "sirenídeos": "sirenídeo",
    "sires": "sire",
    "sirfídeos": "sirfídeo",
    "sirga": "sirgar",
    "sirgada": "sirgar",
    "sirgadas": "sirgar",
    "sirgado": "sirgar",
    "sirgados": "sirgar",
    "sirgagens": "sirgagem",
    "sirgai": "sirgar",
    "sirgais": "sirgar",
    "sirgam": "sirgar",
    "sirgamo": "sirgar",
    "sirgamos": "sirgar",
    "sirgando": "sirgar",
    "sirgara": "sirgar",
    "sirgaram": "sirgar",
    "sirgaras": "sirgar",
    "sirgarde": "sirgar",
    "sirgardes": "sirgar",
    "sirgare": "sirgar",
    "sirgarei": "sirgar",
    "sirgareis": "sirgar",
    "sirgarem": "sirgar",
    "sirgaremos": "sirgar",
    "sirgares": "sirgar",
    "sirgaria": "sirgar",
    "sirgariam": "sirgar",
    "sirgarias": "sirgaria",
    "sirgarmo": "sirgar",
    "sirgarmos": "sirgar",
    "sirgará": "sirgar",
    "sirgarás": "sirgar",
    "sirgarão": "sirgar",
    "sirgaríamos": "sirgar",
    "sirgaríeis": "sirgar",
    "sirgas": "sirgar",
    "sirgasse": "sirgar",
    "sirgassem": "sirgar",
    "sirgasses": "sirgar",
    "sirgaste": "sirgar",
    "sirgastes": "sirgar",
    "sirgava": "sirgar",
    "sirgavam": "sirgar",
    "sirgavas": "sirgar",
    "sirgideiras": "sirgideira",
    "sirgo": "sirgar",
    "sirgos": "sirgo",
    "sirgou": "sirgar",
    "sirgue": "sirgar",
    "sirguei": "sirgar",
    "sirgueira": "sirgueiro",
    "sirgueiras": "sirgueiro",
    "sirgueiros": "sirgueiro",
    "sirgueis": "sirgar",
    "sirguem": "sirgar",
    "sirguemo": "sirgar",
    "sirguemos": "sirgar",
    "sirgues": "sirgar",
    "sirguilhas": "sirguilha",
    "sirgá": "sirgar",
    "sirgámo": "sirgar",
    "sirgámos": "sirgar",
    "sirgáramo": "sirgar",
    "sirgáramos": "sirgar",
    "sirgárei": "sirgar",
    "sirgáreis": "sirgar",
    "sirgásseis": "sirgar",
    "sirgássemos": "sirgar",
    "sirgávamo": "sirgar",
    "sirgávamos": "sirgar",
    "sirgávei": "sirgar",
    "sirgáveis": "sirgar",
    "siria": "sirio",
    "sirias": "sirio",
    "sirigaitas": "sirigaita",
    "sirigas": "siriga",
    "siringes": "siringe",
    "siringotomias": "siringotomia",
    "sirios": "sirio",
    "sirocos": "siroco",
    "siros": "siro",
    "sirtes": "sirte",
    "sirva": "servir",
    "sirvais": "servir",
    "sirvam": "servir",
    "sirvamo": "servir",
    "sirvamos": "servir",
    "sirvas": "servir",
    "sirventes": "sirvente",
    "sirventeses": "sirventês",
    "sirvo": "servir",
    "sirénica": "sirénico",
    "sirénicas": "sirénico",
    "sirénicos": "sirénico",
    "sirénidas": "sirénida",
    "sirénios": "sirénio",
    "siríaca": "siríaco",
    "siríacas": "siríaco",
    "siríacos": "siríaco",
    "sis": "si",
    "sisa": "sisar",
    "sisada": "sisar",
    "sisadas": "sisar",
    "sisado": "sisar",
    "sisados": "sisar",
    "sisai": "sisar",
    "sisais": "sisar",
    "sisam": "sisar",
    "sisamo": "sisar",
    "sisamos": "sisar",
    "sisando": "sisar",
    "sisara": "sisar",
    "sisaram": "sisar",
    "sisaras": "sisar",
    "sisarde": "sisar",
    "sisardes": "sisar",
    "sisare": "sisar",
    "sisarei": "sisar",
    "sisareis": "sisar",
    "sisarem": "sisar",
    "sisaremos": "sisar",
    "sisares": "sisar",
    "sisaria": "sisar",
    "sisariam": "sisar",
    "sisarias": "sisar",
    "sisarmo": "sisar",
    "sisarmos": "sisar",
    "sisará": "sisar",
    "sisarás": "sisar",
    "sisarão": "sisar",
    "sisaríamos": "sisar",
    "sisaríeis": "sisar",
    "sisas": "sisar",
    "sisasse": "sisar",
    "sisassem": "sisar",
    "sisasses": "sisar",
    "sisaste": "sisar",
    "sisastes": "sisar",
    "sisava": "sisar",
    "sisavam": "sisar",
    "sisavas": "sisar",
    "sise": "sisar",
    "sisei": "sisar",
    "siseiros": "siseiro",
    "siseirões": "siseirão",
    "siseis": "sisar",
    "sisem": "sisar",
    "sisemo": "sisar",
    "sisemos": "sisar",
    "sises": "sisar",
    "sismais": "sismal",
    "sismicidades": "sismicidade",
    "sismografias": "sismografia",
    "sismogramas": "sismograma",
    "sismográfica": "sismográfico",
    "sismográficas": "sismográfico",
    "sismográficos": "sismográfico",
    "sismogénica": "sismogénico",
    "sismogénicas": "sismogénico",
    "sismogénicos": "sismogénico",
    "sismologias": "sismologia",
    "sismologistas": "sismologista",
    "sismológica": "sismológico",
    "sismológicas": "sismológico",
    "sismológicos": "sismológico",
    "sismometrias": "sismometria",
    "sismos": "sismo",
    "sismotectónica": "sismotectónico",
    "sismotectónicas": "sismotectónico",
    "sismotectónicos": "sismotectónico",
    "sismoterapias": "sismoterapia",
    "sismógrafos": "sismógrafo",
    "sismóloga": "sismólogo",
    "sismólogas": "sismólogo",
    "sismólogos": "sismólogo",
    "sismómetros": "sismómetro",
    "siso": "sisar",
    "sisos": "siso",
    "sisou": "sisar",
    "sissomias": "sissomia",
    "sissomos": "sissomo",
    "sissómica": "sissómico",
    "sissómicas": "sissómico",
    "sissómicos": "sissómico",
    "sissós": "sissó",
    "sistemas": "sistema",
    "sistematas": "sistemata",
    "sistematiza": "sistematizar",
    "sistematizada": "sistematizar",
    "sistematizadas": "sistematizar",
    "sistematizado": "sistematizar",
    "sistematizadora": "sistematizador",
    "sistematizadoras": "sistematizador",
    "sistematizadores": "sistematizador",
    "sistematizados": "sistematizar",
    "sistematizai": "sistematizar",
    "sistematizais": "sistematizar",
    "sistematizam": "sistematizar",
    "sistematizamo": "sistematizar",
    "sistematizamos": "sistematizar",
    "sistematizando": "sistematizar",
    "sistematizara": "sistematizar",
    "sistematizaram": "sistematizar",
    "sistematizaras": "sistematizar",
    "sistematizarde": "sistematizar",
    "sistematizardes": "sistematizar",
    "sistematizare": "sistematizar",
    "sistematizarei": "sistematizar",
    "sistematizareis": "sistematizar",
    "sistematizarem": "sistematizar",
    "sistematizaremos": "sistematizar",
    "sistematizares": "sistematizar",
    "sistematizaria": "sistematizar",
    "sistematizariam": "sistematizar",
    "sistematizarias": "sistematizar",
    "sistematizarmo": "sistematizar",
    "sistematizarmos": "sistematizar",
    "sistematizará": "sistematizar",
    "sistematizarás": "sistematizar",
    "sistematizarão": "sistematizar",
    "sistematizaríamos": "sistematizar",
    "sistematizaríeis": "sistematizar",
    "sistematizas": "sistematizar",
    "sistematizasse": "sistematizar",
    "sistematizassem": "sistematizar",
    "sistematizasses": "sistematizar",
    "sistematizaste": "sistematizar",
    "sistematizastes": "sistematizar",
    "sistematizava": "sistematizar",
    "sistematizavam": "sistematizar",
    "sistematizavas": "sistematizar",
    "sistematizações": "sistematização",
    "sistematize": "sistematizar",
    "sistematizei": "sistematizar",
    "sistematizeis": "sistematizar",
    "sistematizem": "sistematizar",
    "sistematizemo": "sistematizar",
    "sistematizemos": "sistematizar",
    "sistematizes": "sistematizar",
    "sistematizo": "sistematizar",
    "sistematizou": "sistematizar",
    "sistematizá": "sistematizar",
    "sistematizámo": "sistematizar",
    "sistematizámos": "sistematizar",
    "sistematizáramo": "sistematizar",
    "sistematizáramos": "sistematizar",
    "sistematizárei": "sistematizar",
    "sistematizáreis": "sistematizar",
    "sistematizásseis": "sistematizar",
    "sistematizássemos": "sistematizar",
    "sistematizávamo": "sistematizar",
    "sistematizávamos": "sistematizar",
    "sistematizávei": "sistematizar",
    "sistematizáveis": "sistematizável",
    "sistematologias": "sistematologia",
    "sistemática": "sistemático",
    "sistemáticas": "sistemático",
    "sistemáticos": "sistemático",
    "sistilos": "sistilo",
    "sistina": "sistino",
    "sistinas": "sistino",
    "sistinos": "sistino",
    "sistolares": "sistolar",
    "sistrada": "sistrado",
    "sistradas": "sistrado",
    "sistrados": "sistrado",
    "sistros": "sistro",
    "sistáltica": "sistáltico",
    "sistálticas": "sistáltico",
    "sistálticos": "sistáltico",
    "sistémica": "sistémico",
    "sistémicas": "sistémico",
    "sistémicos": "sistémico",
    "sistólica": "sistólico",
    "sistólicas": "sistólico",
    "sistólicos": "sistólico",
    "sisuda": "sisudo",
    "sisudas": "sisudo",
    "sisudezas": "sisudeza",
    "sisudos": "sisudo",
    "sisá": "sisar",
    "sisámo": "sisar",
    "sisámos": "sisar",
    "sisáramo": "sisar",
    "sisáramos": "sisar",
    "sisárei": "sisar",
    "sisáreis": "sisar",
    "sisásseis": "sisar",
    "sisássemos": "sisar",
    "sisávamo": "sisar",
    "sisávamos": "sisar",
    "sisávei": "sisar",
    "sisáveis": "sisar",
    "sisórios": "sisório",
    "sisões": "sisão",
    "sita": "sito",
    "sitas": "sito",
    "sites": "site",
    "sitia": "sitiar",
    "sitiada": "sitiar",
    "sitiadas": "sitiar",
    "sitiado": "sitiar",
    "sitiadora": "sitiador",
    "sitiadoras": "sitiador",
    "sitiadores": "sitiador",
    "sitiados": "sitiar",
    "sitiadíssima": "sitiado",
    "sitiadíssimas": "sitiado",
    "sitiadíssimo": "sitiado",
    "sitiadíssimos": "sitiado",
    "sitiai": "sitiar",
    "sitiais": "sitiar",
    "sitiam": "sitiar",
    "sitiamo": "sitiar",
    "sitiamos": "sitiar",
    "sitiando": "sitiar",
    "sitiantes": "sitiante",
    "sitiara": "sitiar",
    "sitiaram": "sitiar",
    "sitiaras": "sitiar",
    "sitiarde": "sitiar",
    "sitiardes": "sitiar",
    "sitiare": "sitiar",
    "sitiarei": "sitiar",
    "sitiareis": "sitiar",
    "sitiarem": "sitiar",
    "sitiaremos": "sitiar",
    "sitiares": "sitiar",
    "sitiaria": "sitiar",
    "sitiariam": "sitiar",
    "sitiarias": "sitiar",
    "sitiarmo": "sitiar",
    "sitiarmos": "sitiar",
    "sitiará": "sitiar",
    "sitiarás": "sitiar",
    "sitiarão": "sitiar",
    "sitiaríamos": "sitiar",
    "sitiaríeis": "sitiar",
    "sitias": "sitiar",
    "sitiasse": "sitiar",
    "sitiassem": "sitiar",
    "sitiasses": "sitiar",
    "sitiaste": "sitiar",
    "sitiastes": "sitiar",
    "sitiava": "sitiar",
    "sitiavam": "sitiar",
    "sitiavas": "sitiar",
    "sitibunda": "sitibundo",
    "sitibundas": "sitibundo",
    "sitibundos": "sitibundo",
    "sitidas": "sitida",
    "sitie": "sitiar",
    "sitiei": "sitiar",
    "sitieis": "sitiar",
    "sitiem": "sitiar",
    "sitiemo": "sitiar",
    "sitiemos": "sitiar",
    "sities": "sitiar",
    "sitio": "sitiar",
    "sitiofobias": "sitiofobia",
    "sitiologias": "sitiologia",
    "sitiomanias": "sitiomania",
    "sitioterapias": "sitioterapia",
    "sitiou": "sitiar",
    "sitiá": "sitiar",
    "sitiámo": "sitiar",
    "sitiámos": "sitiar",
    "sitiáramo": "sitiar",
    "sitiáramos": "sitiar",
    "sitiárei": "sitiar",
    "sitiáreis": "sitiar",
    "sitiásseis": "sitiar",
    "sitiássemos": "sitiar",
    "sitiávamo": "sitiar",
    "sitiávamos": "sitiar",
    "sitiávei": "sitiar",
    "sitiáveis": "sitiar",
    "sitiófoba": "sitiófobo",
    "sitiófobas": "sitiófobo",
    "sitiófobos": "sitiófobo",
    "sitofagias": "sitofagia",
    "sitos": "sito",
    "situa": "situar",
    "situacionismos": "situacionismo",
    "situacionistas": "situacionista",
    "situada": "situar",
    "situadas": "situar",
    "situado": "situar",
    "situados": "situar",
    "situai": "situar",
    "situais": "situar",
    "situam": "situar",
    "situamo": "situar",
    "situamos": "situar",
    "situando": "situar",
    "situara": "situar",
    "situaram": "situar",
    "situaras": "situar",
    "situarde": "situar",
    "situardes": "situar",
    "situare": "situar",
    "situarei": "situar",
    "situareis": "situar",
    "situarem": "situar",
    "situaremos": "situar",
    "situares": "situar",
    "situaria": "situar",
    "situariam": "situar",
    "situarias": "situar",
    "situarmo": "situar",
    "situarmos": "situar",
    "situará": "situar",
    "situarás": "situar",
    "situarão": "situar",
    "situaríamos": "situar",
    "situaríeis": "situar",
    "situas": "situar",
    "situasse": "situar",
    "situassem": "situar",
    "situasses": "situar",
    "situaste": "situar",
    "situastes": "situar",
    "situava": "situar",
    "situavam": "situar",
    "situavas": "situar",
    "situações": "situação",
    "situe": "situar",
    "situei": "situar",
    "situeis": "situar",
    "situem": "situar",
    "situemo": "situar",
    "situemos": "situar",
    "situes": "situar",
    "situo": "situar",
    "situou": "situar",
    "situá": "situar",
    "situámo": "situar",
    "situámos": "situar",
    "situáramo": "situar",
    "situáramos": "situar",
    "situárei": "situar",
    "situáreis": "situar",
    "situásseis": "situar",
    "situássemos": "situar",
    "situávamo": "situar",
    "situávamos": "situar",
    "situávei": "situar",
    "situáveis": "situar",
    "sitídeos": "sitídeo",
    "sitófaga": "sitófago",
    "sitófagas": "sitófago",
    "sitófagos": "sitófago",
    "sitómetros": "sitómetro",
    "sivãs": "sivã",
    "sizeteses": "sizetese",
    "sizígias": "sizígia",
    "sizígios": "sizígio",
    "siámo": "siar",
    "siámos": "siar",
    "siáramo": "siar",
    "siáramos": "siar",
    "siáreis": "siar",
    "siás": "siá",
    "siásseis": "siar",
    "siássemos": "siar",
    "siávamo": "siar",
    "siávamos": "siar",
    "siáveis": "siar",
    "skates": "skate",
    "sketches": "sketch",
    "skidavianos": "skidaviano",
    "skinheads": "skinhead",
    "skis": "ski",
    "slides": "slide",
    "slogans": "slogan",
    "smokings": "smoking",
    "snacks": "snack",
    "snifa": "snifar",
    "snifada": "snifar",
    "snifadas": "snifar",
    "snifado": "snifar",
    "snifados": "snifar",
    "snifai": "snifar",
    "snifais": "snifar",
    "snifam": "snifar",
    "snifamo": "snifar",
    "snifamos": "snifar",
    "snifando": "snifar",
    "snifara": "snifar",
    "snifaram": "snifar",
    "snifaras": "snifar",
    "snifarde": "snifar",
    "snifardes": "snifar",
    "snifare": "snifar",
    "snifarei": "snifar",
    "snifareis": "snifar",
    "snifarem": "snifar",
    "snifaremos": "snifar",
    "snifares": "snifar",
    "snifaria": "snifar",
    "snifariam": "snifar",
    "snifarias": "snifar",
    "snifarmo": "snifar",
    "snifarmos": "snifar",
    "snifará": "snifar",
    "snifarás": "snifar",
    "snifarão": "snifar",
    "snifaríamos": "snifar",
    "snifaríeis": "snifar",
    "snifas": "snifar",
    "snifasse": "snifar",
    "snifassem": "snifar",
    "snifasses": "snifar",
    "snifaste": "snifar",
    "snifastes": "snifar",
    "snifava": "snifar",
    "snifavam": "snifar",
    "snifavas": "snifar",
    "snife": "snifar",
    "snifei": "snifar",
    "snifeis": "snifar",
    "snifem": "snifar",
    "snifemo": "snifar",
    "snifemos": "snifar",
    "snifes": "snifar",
    "snifo": "snifar",
    "snifou": "snifar",
    "snifá": "snifar",
    "snifámo": "snifar",
    "snifámos": "snifar",
    "snifáramo": "snifar",
    "snifáramos": "snifar",
    "snifárei": "snifar",
    "snifáreis": "snifar",
    "snifásseis": "snifar",
    "snifássemos": "snifar",
    "snifávamo": "snifar",
    "snifávamos": "snifar",
    "snifávei": "snifar",
    "snifáveis": "snifar",
    "snobeiras": "snobeira",
    "snobes": "snobe",
    "snobismos": "snobismo",
    "snobs": "snob",
    "snookeres": "snooker",
    "soa": "soer",
    "soabra": "soabrir",
    "soabrais": "soabrir",
    "soabram": "soabrir",
    "soabramo": "soabrir",
    "soabramos": "soabrir",
    "soabras": "soabrir",
    "soabre": "soabrir",
    "soabrem": "soabrir",
    "soabres": "soabrir",
    "soabri": "soabrir",
    "soabria": "soabrir",
    "soabriam": "soabrir",
    "soabrias": "soabrir",
    "soabrida": "soabrir",
    "soabridas": "soabrir",
    "soabrido": "soabrir",
    "soabridos": "soabrir",
    "soabrimo": "soabrir",
    "soabrimos": "soabrir",
    "soabrindo": "soabrir",
    "soabrira": "soabrir",
    "soabriram": "soabrir",
    "soabriras": "soabrir",
    "soabrirde": "soabrir",
    "soabrirdes": "soabrir",
    "soabrire": "soabrir",
    "soabrirei": "soabrir",
    "soabrireis": "soabrir",
    "soabrirem": "soabrir",
    "soabriremos": "soabrir",
    "soabrires": "soabrir",
    "soabriria": "soabrir",
    "soabririam": "soabrir",
    "soabririas": "soabrir",
    "soabrirmo": "soabrir",
    "soabrirmos": "soabrir",
    "soabrirá": "soabrir",
    "soabrirás": "soabrir",
    "soabrirão": "soabrir",
    "soabriríamos": "soabrir",
    "soabriríeis": "soabrir",
    "soabris": "soabrir",
    "soabrisse": "soabrir",
    "soabrissem": "soabrir",
    "soabrisses": "soabrir",
    "soabriste": "soabrir",
    "soabristes": "soabrir",
    "soabriu": "soabrir",
    "soabro": "soabrir",
    "soabríamo": "soabrir",
    "soabríamos": "soabrir",
    "soabríei": "soabrir",
    "soabríeis": "soabrir",
    "soabríramo": "soabrir",
    "soabríramos": "soabrir",
    "soabrírei": "soabrir",
    "soabríreis": "soabrir",
    "soabrísseis": "soabrir",
    "soabríssemos": "soabrir",
    "soada": "soar",
    "soadas": "soar",
    "soado": "soar",
    "soados": "soar",
    "soagens": "soagem",
    "soai": "soar",
    "soais": "soer",
    "soajenses": "soajense",
    "soajensezinha": "soajense",
    "soajensezinhas": "soajense",
    "soajensezinho": "soajense",
    "soajensezinhos": "soajense",
    "soajensezita": "soajense",
    "soajensezitas": "soajense",
    "soajensezito": "soajense",
    "soajensezitos": "soajense",
    "soajos": "soajo",
    "soalha": "soalhar",
    "soalhada": "soalhar",
    "soalhadas": "soalhar",
    "soalhado": "soalhar",
    "soalhados": "soalhar",
    "soalhai": "soalhar",
    "soalhais": "soalhar",
    "soalham": "soalhar",
    "soalhamo": "soalhar",
    "soalhamos": "soalhar",
    "soalhando": "soalhar",
    "soalhara": "soalhar",
    "soalharam": "soalhar",
    "soalharas": "soalhar",
    "soalharde": "soalhar",
    "soalhardes": "soalhar",
    "soalhare": "soalhar",
    "soalharei": "soalhar",
    "soalhareis": "soalhar",
    "soalharem": "soalhar",
    "soalharemos": "soalhar",
    "soalhares": "soalhar",
    "soalharia": "soalhar",
    "soalhariam": "soalhar",
    "soalharias": "soalhar",
    "soalharmo": "soalhar",
    "soalharmos": "soalhar",
    "soalhará": "soalhar",
    "soalharás": "soalhar",
    "soalharão": "soalhar",
    "soalharíamos": "soalhar",
    "soalharíeis": "soalhar",
    "soalhas": "soalhar",
    "soalhasse": "soalhar",
    "soalhassem": "soalhar",
    "soalhasses": "soalhar",
    "soalhaste": "soalhar",
    "soalhastes": "soalhar",
    "soalhava": "soalhar",
    "soalhavam": "soalhar",
    "soalhavas": "soalhar",
    "soalhe": "soalhar",
    "soalhei": "soalhar",
    "soalheira": "soalheiro",
    "soalheiras": "soalheiro",
    "soalheiros": "soalheiro",
    "soalheis": "soalhar",
    "soalhem": "soalhar",
    "soalhemo": "soalhar",
    "soalhemos": "soalhar",
    "soalhes": "soalhar",
    "soalho": "soalhar",
    "soalhos": "soalho",
    "soalhou": "soalhar",
    "soalhá": "soalhar",
    "soalhámo": "soalhar",
    "soalhámos": "soalhar",
    "soalháramo": "soalhar",
    "soalháramos": "soalhar",
    "soalhárei": "soalhar",
    "soalháreis": "soalhar",
    "soalhásseis": "soalhar",
    "soalhássemos": "soalhar",
    "soalhávamo": "soalhar",
    "soalhávamos": "soalhar",
    "soalhávei": "soalhar",
    "soalháveis": "soalhar",
    "soam": "soer",
    "soamo": "soer",
    "soamos": "soer",
    "soando": "soar",
    "soantes": "soante",
    "soara": "soar",
    "soaram": "soar",
    "soaras": "soar",
    "soardes": "soar",
    "soarei": "soar",
    "soareis": "soar",
    "soarem": "soar",
    "soaremos": "soar",
    "soares": "soar",
    "soaria": "soar",
    "soariam": "soar",
    "soarias": "soar",
    "soaristas": "soarista",
    "soarmo": "soar",
    "soarmos": "soar",
    "soará": "soar",
    "soarás": "soar",
    "soarão": "soar",
    "soaríamos": "soar",
    "soaríeis": "soar",
    "soas": "soer",
    "soasse": "soar",
    "soassem": "soar",
    "soasses": "soar",
    "soaste": "soar",
    "soastes": "soar",
    "soava": "soar",
    "soavam": "soar",
    "soavas": "soar",
    "sobacos": "sobaco",
    "sobados": "sobado",
    "sobalce": "sobalçar",
    "sobalcei": "sobalçar",
    "sobalceis": "sobalçar",
    "sobalcem": "sobalçar",
    "sobalcemo": "sobalçar",
    "sobalcemos": "sobalçar",
    "sobalces": "sobalçar",
    "sobalça": "sobalçar",
    "sobalçada": "sobalçar",
    "sobalçadas": "sobalçar",
    "sobalçado": "sobalçar",
    "sobalçados": "sobalçar",
    "sobalçai": "sobalçar",
    "sobalçais": "sobalçar",
    "sobalçam": "sobalçar",
    "sobalçamo": "sobalçar",
    "sobalçamos": "sobalçar",
    "sobalçando": "sobalçar",
    "sobalçara": "sobalçar",
    "sobalçaram": "sobalçar",
    "sobalçaras": "sobalçar",
    "sobalçarde": "sobalçar",
    "sobalçardes": "sobalçar",
    "sobalçare": "sobalçar",
    "sobalçarei": "sobalçar",
    "sobalçareis": "sobalçar",
    "sobalçarem": "sobalçar",
    "sobalçaremos": "sobalçar",
    "sobalçares": "sobalçar",
    "sobalçaria": "sobalçar",
    "sobalçariam": "sobalçar",
    "sobalçarias": "sobalçar",
    "sobalçarmo": "sobalçar",
    "sobalçarmos": "sobalçar",
    "sobalçará": "sobalçar",
    "sobalçarás": "sobalçar",
    "sobalçarão": "sobalçar",
    "sobalçaríamos": "sobalçar",
    "sobalçaríeis": "sobalçar",
    "sobalças": "sobalçar",
    "sobalçasse": "sobalçar",
    "sobalçassem": "sobalçar",
    "sobalçasses": "sobalçar",
    "sobalçaste": "sobalçar",
    "sobalçastes": "sobalçar",
    "sobalçava": "sobalçar",
    "sobalçavam": "sobalçar",
    "sobalçavas": "sobalçar",
    "sobalço": "sobalçar",
    "sobalçou": "sobalçar",
    "sobalçá": "sobalçar",
    "sobalçámo": "sobalçar",
    "sobalçámos": "sobalçar",
    "sobalçáramo": "sobalçar",
    "sobalçáramos": "sobalçar",
    "sobalçárei": "sobalçar",
    "sobalçáreis": "sobalçar",
    "sobalçásseis": "sobalçar",
    "sobalçássemos": "sobalçar",
    "sobalçávamo": "sobalçar",
    "sobalçávamos": "sobalçar",
    "sobalçávei": "sobalçar",
    "sobalçáveis": "sobalçar",
    "sobaqueiros": "sobaqueiro",
    "sobarbadas": "sobarbada",
    "sobarbas": "sobarba",
    "sobas": "soba",
    "sobe": "subir",
    "sobeiras": "sobeira",
    "sobeja": "sobejo",
    "sobejada": "sobejar",
    "sobejadas": "sobejar",
    "sobejado": "sobejar",
    "sobejados": "sobejar",
    "sobejai": "sobejar",
    "sobejais": "sobejar",
    "sobejam": "sobejar",
    "sobejamo": "sobejar",
    "sobejamos": "sobejar",
    "sobejando": "sobejar",
    "sobejara": "sobejar",
    "sobejaram": "sobejar",
    "sobejaras": "sobejar",
    "sobejardes": "sobejar",
    "sobejarei": "sobejar",
    "sobejareis": "sobejar",
    "sobejarem": "sobejar",
    "sobejaremos": "sobejar",
    "sobejares": "sobejar",
    "sobejaria": "sobejar",
    "sobejariam": "sobejar",
    "sobejarias": "sobejar",
    "sobejarmo": "sobejar",
    "sobejarmos": "sobejar",
    "sobejará": "sobejar",
    "sobejarás": "sobejar",
    "sobejarão": "sobejar",
    "sobejaríamos": "sobejar",
    "sobejaríeis": "sobejar",
    "sobejas": "sobejo",
    "sobejasse": "sobejar",
    "sobejassem": "sobejar",
    "sobejasses": "sobejar",
    "sobejaste": "sobejar",
    "sobejastes": "sobejar",
    "sobejava": "sobejar",
    "sobejavam": "sobejar",
    "sobejavas": "sobejar",
    "sobeje": "sobejar",
    "sobejei": "sobejar",
    "sobejeis": "sobejar",
    "sobejem": "sobejar",
    "sobejemo": "sobejar",
    "sobejemos": "sobejar",
    "sobejes": "sobejar",
    "sobejidões": "sobejidão",
    "sobejo": "sobejar",
    "sobejos": "sobejo",
    "sobejou": "sobejar",
    "sobejámo": "sobejar",
    "sobejámos": "sobejar",
    "sobejáramo": "sobejar",
    "sobejáramos": "sobejar",
    "sobejáreis": "sobejar",
    "sobejásseis": "sobejar",
    "sobejássemos": "sobejar",
    "sobejávamo": "sobejar",
    "sobejávamos": "sobejar",
    "sobejáveis": "sobejar",
    "sobem": "subir",
    "soberana": "soberano",
    "soberanas": "soberano",
    "soberanazinha": "soberano",
    "soberanazinhas": "soberano",
    "soberanazita": "soberano",
    "soberanazitas": "soberano",
    "soberanias": "soberania",
    "soberaniza": "soberanizar",
    "soberanizada": "soberanizar",
    "soberanizadas": "soberanizar",
    "soberanizado": "soberanizar",
    "soberanizados": "soberanizar",
    "soberanizai": "soberanizar",
    "soberanizais": "soberanizar",
    "soberanizam": "soberanizar",
    "soberanizamo": "soberanizar",
    "soberanizamos": "soberanizar",
    "soberanizando": "soberanizar",
    "soberanizara": "soberanizar",
    "soberanizaram": "soberanizar",
    "soberanizaras": "soberanizar",
    "soberanizarde": "soberanizar",
    "soberanizardes": "soberanizar",
    "soberanizare": "soberanizar",
    "soberanizarei": "soberanizar",
    "soberanizareis": "soberanizar",
    "soberanizarem": "soberanizar",
    "soberanizaremos": "soberanizar",
    "soberanizares": "soberanizar",
    "soberanizaria": "soberanizar",
    "soberanizariam": "soberanizar",
    "soberanizarias": "soberanizar",
    "soberanizarmo": "soberanizar",
    "soberanizarmos": "soberanizar",
    "soberanizará": "soberanizar",
    "soberanizarás": "soberanizar",
    "soberanizarão": "soberanizar",
    "soberanizaríamos": "soberanizar",
    "soberanizaríeis": "soberanizar",
    "soberanizas": "soberanizar",
    "soberanizasse": "soberanizar",
    "soberanizassem": "soberanizar",
    "soberanizasses": "soberanizar",
    "soberanizaste": "soberanizar",
    "soberanizastes": "soberanizar",
    "soberanizava": "soberanizar",
    "soberanizavam": "soberanizar",
    "soberanizavas": "soberanizar",
    "soberanize": "soberanizar",
    "soberanizei": "soberanizar",
    "soberanizeis": "soberanizar",
    "soberanizem": "soberanizar",
    "soberanizemo": "soberanizar",
    "soberanizemos": "soberanizar",
    "soberanizes": "soberanizar",
    "soberanizo": "soberanizar",
    "soberanizou": "soberanizar",
    "soberanizá": "soberanizar",
    "soberanizámo": "soberanizar",
    "soberanizámos": "soberanizar",
    "soberanizáramo": "soberanizar",
    "soberanizáramos": "soberanizar",
    "soberanizárei": "soberanizar",
    "soberanizáreis": "soberanizar",
    "soberanizásseis": "soberanizar",
    "soberanizássemos": "soberanizar",
    "soberanizávamo": "soberanizar",
    "soberanizávamos": "soberanizar",
    "soberanizávei": "soberanizar",
    "soberanizáveis": "soberanizar",
    "soberanos": "soberano",
    "soberanozinho": "soberano",
    "soberanozinhos": "soberano",
    "soberanozito": "soberano",
    "soberanozitos": "soberano",
    "soberba": "soberbo",
    "soberbas": "soberbo",
    "soberbaça": "soberbaço",
    "soberbaças": "soberbaço",
    "soberbaços": "soberbaço",
    "soberbeta": "soberbete",
    "soberbetas": "soberbete",
    "soberbetes": "soberbete",
    "soberbias": "soberbia",
    "soberbona": "soberbão",
    "soberbonas": "soberbão",
    "soberbos": "soberbo",
    "soberbosa": "soberboso",
    "soberbosas": "soberboso",
    "soberbosos": "soberboso",
    "soberbões": "soberbão",
    "sobernais": "sobernal",
    "sobes": "subir",
    "sobesta": "sobestar",
    "sobestada": "sobestar",
    "sobestadas": "sobestar",
    "sobestado": "sobestar",
    "sobestados": "sobestar",
    "sobestai": "sobestar",
    "sobestais": "sobestar",
    "sobestam": "sobestar",
    "sobestamo": "sobestar",
    "sobestamos": "sobestar",
    "sobestando": "sobestar",
    "sobestara": "sobestar",
    "sobestaram": "sobestar",
    "sobestaras": "sobestar",
    "sobestardes": "sobestar",
    "sobestarei": "sobestar",
    "sobestareis": "sobestar",
    "sobestarem": "sobestar",
    "sobestaremos": "sobestar",
    "sobestares": "sobestar",
    "sobestaria": "sobestar",
    "sobestariam": "sobestar",
    "sobestarias": "sobestar",
    "sobestarmo": "sobestar",
    "sobestarmos": "sobestar",
    "sobestará": "sobestar",
    "sobestarás": "sobestar",
    "sobestarão": "sobestar",
    "sobestaríamos": "sobestar",
    "sobestaríeis": "sobestar",
    "sobestas": "sobestar",
    "sobestasse": "sobestar",
    "sobestassem": "sobestar",
    "sobestasses": "sobestar",
    "sobestaste": "sobestar",
    "sobestastes": "sobestar",
    "sobestava": "sobestar",
    "sobestavam": "sobestar",
    "sobestavas": "sobestar",
    "sobeste": "sobestar",
    "sobestei": "sobestar",
    "sobesteis": "sobestar",
    "sobestem": "sobestar",
    "sobestemo": "sobestar",
    "sobestemos": "sobestar",
    "sobestes": "sobestar",
    "sobesto": "sobestar",
    "sobestou": "sobestar",
    "sobestámo": "sobestar",
    "sobestámos": "sobestar",
    "sobestáramo": "sobestar",
    "sobestáramos": "sobestar",
    "sobestáreis": "sobestar",
    "sobestásseis": "sobestar",
    "sobestássemos": "sobestar",
    "sobestávamo": "sobestar",
    "sobestávamos": "sobestar",
    "sobestáveis": "sobestar",
    "sobgraves": "sobgrave",
    "soborralha": "soborralhar",
    "soborralhada": "soborralhar",
    "soborralhadas": "soborralhar",
    "soborralhado": "soborralhar",
    "soborralhadoiros": "soborralhadoiro",
    "soborralhados": "soborralhar",
    "soborralhadouros": "soborralhadouro",
    "soborralhai": "soborralhar",
    "soborralhais": "soborralhar",
    "soborralham": "soborralhar",
    "soborralhamo": "soborralhar",
    "soborralhamos": "soborralhar",
    "soborralhando": "soborralhar",
    "soborralhara": "soborralhar",
    "soborralharam": "soborralhar",
    "soborralharas": "soborralhar",
    "soborralharde": "soborralhar",
    "soborralhardes": "soborralhar",
    "soborralhare": "soborralhar",
    "soborralharei": "soborralhar",
    "soborralhareis": "soborralhar",
    "soborralharem": "soborralhar",
    "soborralharemos": "soborralhar",
    "soborralhares": "soborralhar",
    "soborralharia": "soborralhar",
    "soborralhariam": "soborralhar",
    "soborralharias": "soborralhar",
    "soborralharmo": "soborralhar",
    "soborralharmos": "soborralhar",
    "soborralhará": "soborralhar",
    "soborralharás": "soborralhar",
    "soborralharão": "soborralhar",
    "soborralharíamos": "soborralhar",
    "soborralharíeis": "soborralhar",
    "soborralhas": "soborralhar",
    "soborralhasse": "soborralhar",
    "soborralhassem": "soborralhar",
    "soborralhasses": "soborralhar",
    "soborralhaste": "soborralhar",
    "soborralhastes": "soborralhar",
    "soborralhava": "soborralhar",
    "soborralhavam": "soborralhar",
    "soborralhavas": "soborralhar",
    "soborralhe": "soborralhar",
    "soborralhei": "soborralhar",
    "soborralheis": "soborralhar",
    "soborralhem": "soborralhar",
    "soborralhemo": "soborralhar",
    "soborralhemos": "soborralhar",
    "soborralhes": "soborralhar",
    "soborralho": "soborralhar",
    "soborralhos": "soborralho",
    "soborralhou": "soborralhar",
    "soborralhá": "soborralhar",
    "soborralhámo": "soborralhar",
    "soborralhámos": "soborralhar",
    "soborralháramo": "soborralhar",
    "soborralháramos": "soborralhar",
    "soborralhárei": "soborralhar",
    "soborralháreis": "soborralhar",
    "soborralhásseis": "soborralhar",
    "soborralhássemos": "soborralhar",
    "soborralhávamo": "soborralhar",
    "soborralhávamos": "soborralhar",
    "soborralhávei": "soborralhar",
    "soborralháveis": "soborralhar",
    "sobpeada": "sobpear",
    "sobpeadas": "sobpear",
    "sobpeado": "sobpear",
    "sobpeados": "sobpear",
    "sobpeai": "sobpear",
    "sobpeais": "sobpear",
    "sobpeamo": "sobpear",
    "sobpeamos": "sobpear",
    "sobpeando": "sobpear",
    "sobpeara": "sobpear",
    "sobpearam": "sobpear",
    "sobpearas": "sobpear",
    "sobpearde": "sobpear",
    "sobpeardes": "sobpear",
    "sobpeare": "sobpear",
    "sobpearei": "sobpear",
    "sobpeareis": "sobpear",
    "sobpearem": "sobpear",
    "sobpearemos": "sobpear",
    "sobpeares": "sobpear",
    "sobpearia": "sobpear",
    "sobpeariam": "sobpear",
    "sobpearias": "sobpear",
    "sobpearmo": "sobpear",
    "sobpearmos": "sobpear",
    "sobpeará": "sobpear",
    "sobpearás": "sobpear",
    "sobpearão": "sobpear",
    "sobpearíamos": "sobpear",
    "sobpearíeis": "sobpear",
    "sobpeasse": "sobpear",
    "sobpeassem": "sobpear",
    "sobpeasses": "sobpear",
    "sobpeaste": "sobpear",
    "sobpeastes": "sobpear",
    "sobpeava": "sobpear",
    "sobpeavam": "sobpear",
    "sobpeavas": "sobpear",
    "sobpeei": "sobpear",
    "sobpeeis": "sobpear",
    "sobpeemo": "sobpear",
    "sobpeemos": "sobpear",
    "sobpeia": "sobpear",
    "sobpeiam": "sobpear",
    "sobpeias": "sobpear",
    "sobpeie": "sobpear",
    "sobpeiem": "sobpear",
    "sobpeies": "sobpear",
    "sobpeio": "sobpear",
    "sobpeou": "sobpear",
    "sobpeá": "sobpear",
    "sobpeámo": "sobpear",
    "sobpeámos": "sobpear",
    "sobpeáramo": "sobpear",
    "sobpeáramos": "sobpear",
    "sobpeárei": "sobpear",
    "sobpeáreis": "sobpear",
    "sobpeásseis": "sobpear",
    "sobpeássemos": "sobpear",
    "sobpeávamo": "sobpear",
    "sobpeávamos": "sobpear",
    "sobpeávei": "sobpear",
    "sobpeáveis": "sobpear",
    "sobpomo": "sobpor",
    "sobpomos": "sobpor",
    "sobponde": "sobpor",
    "sobpondes": "sobpor",
    "sobpondo": "sobpor",
    "sobponha": "sobpor",
    "sobponhais": "sobpor",
    "sobponham": "sobpor",
    "sobponhamo": "sobpor",
    "sobponhamos": "sobpor",
    "sobponhas": "sobpor",
    "sobponho": "sobpor",
    "sobponíveis": "sobponível",
    "sobporde": "sobpor",
    "sobpordes": "sobpor",
    "sobpore": "sobpor",
    "sobporei": "sobpor",
    "sobporeis": "sobpor",
    "sobporem": "sobpor",
    "sobporemos": "sobpor",
    "sobpores": "sobpor",
    "sobporia": "sobpor",
    "sobporiam": "sobpor",
    "sobporias": "sobpor",
    "sobpormo": "sobpor",
    "sobpormos": "sobpor",
    "sobporá": "sobpor",
    "sobporás": "sobpor",
    "sobporão": "sobpor",
    "sobporíamos": "sobpor",
    "sobporíeis": "sobpor",
    "sobposta": "sobpor",
    "sobpostas": "sobpor",
    "sobposto": "sobpor",
    "sobpostos": "sobpor",
    "sobpunha": "sobpor",
    "sobpunham": "sobpor",
    "sobpunhas": "sobpor",
    "sobpus": "sobpor",
    "sobpusemo": "sobpor",
    "sobpusemos": "sobpor",
    "sobpuser": "sobpor",
    "sobpusera": "sobpor",
    "sobpuseram": "sobpor",
    "sobpuseras": "sobpor",
    "sobpuserdes": "sobpor",
    "sobpuserem": "sobpor",
    "sobpuseres": "sobpor",
    "sobpusermos": "sobpor",
    "sobpusesse": "sobpor",
    "sobpusessem": "sobpor",
    "sobpusesses": "sobpor",
    "sobpuseste": "sobpor",
    "sobpusestes": "sobpor",
    "sobpuséramo": "sobpor",
    "sobpuséramos": "sobpor",
    "sobpusérei": "sobpor",
    "sobpuséreis": "sobpor",
    "sobpusésseis": "sobpor",
    "sobpuséssemos": "sobpor",
    "sobpés": "sobpé",
    "sobpô": "sobpor",
    "sobpôs": "sobpor",
    "sobpõe": "sobpor",
    "sobpõem": "sobpor",
    "sobpões": "sobpor",
    "sobpúnhamo": "sobpor",
    "sobpúnhamos": "sobpor",
    "sobpúnhei": "sobpor",
    "sobpúnheis": "sobpor",
    "sobra": "sobrar",
    "sobrace": "sobraçar",
    "sobracei": "sobraçar",
    "sobraceis": "sobraçar",
    "sobracem": "sobraçar",
    "sobracemo": "sobraçar",
    "sobracemos": "sobraçar",
    "sobraces": "sobraçar",
    "sobrada": "sobrar",
    "sobradada": "sobradar",
    "sobradadas": "sobradar",
    "sobradado": "sobradar",
    "sobradados": "sobradar",
    "sobradai": "sobradar",
    "sobradais": "sobradar",
    "sobradam": "sobradar",
    "sobradamo": "sobradar",
    "sobradamos": "sobradar",
    "sobradando": "sobradar",
    "sobradara": "sobradar",
    "sobradaram": "sobradar",
    "sobradaras": "sobradar",
    "sobradarde": "sobradar",
    "sobradardes": "sobradar",
    "sobradare": "sobradar",
    "sobradarei": "sobradar",
    "sobradareis": "sobradar",
    "sobradarem": "sobradar",
    "sobradaremos": "sobradar",
    "sobradares": "sobradar",
    "sobradaria": "sobradar",
    "sobradariam": "sobradar",
    "sobradarias": "sobradar",
    "sobradarmo": "sobradar",
    "sobradarmos": "sobradar",
    "sobradará": "sobradar",
    "sobradarás": "sobradar",
    "sobradarão": "sobradar",
    "sobradaríamos": "sobradar",
    "sobradaríeis": "sobradar",
    "sobradas": "sobrar",
    "sobradasse": "sobradar",
    "sobradassem": "sobradar",
    "sobradasses": "sobradar",
    "sobradaste": "sobradar",
    "sobradastes": "sobradar",
    "sobradava": "sobradar",
    "sobradavam": "sobradar",
    "sobradavas": "sobradar",
    "sobrade": "sobradar",
    "sobradei": "sobradar",
    "sobradeis": "sobradar",
    "sobradem": "sobradar",
    "sobrademo": "sobradar",
    "sobrademos": "sobradar",
    "sobrades": "sobradar",
    "sobrado": "sobrar",
    "sobrados": "sobrar",
    "sobradou": "sobradar",
    "sobradá": "sobradar",
    "sobradámo": "sobradar",
    "sobradámos": "sobradar",
    "sobradáramo": "sobradar",
    "sobradáramos": "sobradar",
    "sobradárei": "sobradar",
    "sobradáreis": "sobradar",
    "sobradásseis": "sobradar",
    "sobradássemos": "sobradar",
    "sobradávamo": "sobradar",
    "sobradávamos": "sobradar",
    "sobradávei": "sobradar",
    "sobradáveis": "sobradar",
    "sobrai": "sobrar",
    "sobrais": "sobrar",
    "sobram": "sobrar",
    "sobramo": "sobrar",
    "sobramos": "sobrar",
    "sobranceada": "sobrancear",
    "sobranceadas": "sobrancear",
    "sobranceado": "sobrancear",
    "sobranceados": "sobrancear",
    "sobranceai": "sobrancear",
    "sobranceais": "sobrancear",
    "sobranceamo": "sobrancear",
    "sobranceamos": "sobrancear",
    "sobranceando": "sobrancear",
    "sobranceara": "sobrancear",
    "sobrancearam": "sobrancear",
    "sobrancearas": "sobrancear",
    "sobranceardes": "sobrancear",
    "sobrancearei": "sobrancear",
    "sobranceareis": "sobrancear",
    "sobrancearem": "sobrancear",
    "sobrancearemos": "sobrancear",
    "sobranceares": "sobrancear",
    "sobrancearia": "sobrancear",
    "sobranceariam": "sobrancear",
    "sobrancearias": "sobrancear",
    "sobrancearmo": "sobrancear",
    "sobrancearmos": "sobrancear",
    "sobranceará": "sobrancear",
    "sobrancearás": "sobrancear",
    "sobrancearão": "sobrancear",
    "sobrancearíamos": "sobrancear",
    "sobrancearíeis": "sobrancear",
    "sobranceasse": "sobrancear",
    "sobranceassem": "sobrancear",
    "sobranceasses": "sobrancear",
    "sobranceaste": "sobrancear",
    "sobranceastes": "sobrancear",
    "sobranceava": "sobrancear",
    "sobranceavam": "sobrancear",
    "sobranceavas": "sobrancear",
    "sobranceei": "sobrancear",
    "sobranceeis": "sobrancear",
    "sobranceemo": "sobrancear",
    "sobranceemos": "sobrancear",
    "sobranceia": "sobrancear",
    "sobranceiam": "sobrancear",
    "sobranceias": "sobrancear",
    "sobranceie": "sobrancear",
    "sobranceiem": "sobrancear",
    "sobranceies": "sobrancear",
    "sobranceio": "sobrancear",
    "sobranceira": "sobranceiro",
    "sobranceiras": "sobranceiro",
    "sobranceiros": "sobranceiro",
    "sobrancelhas": "sobrancelha",
    "sobrancelhuda": "sobrancelhudo",
    "sobrancelhudas": "sobrancelhudo",
    "sobrancelhudos": "sobrancelhudo",
    "sobranceou": "sobrancear",
    "sobrancerias": "sobranceria",
    "sobranceámo": "sobrancear",
    "sobranceámos": "sobrancear",
    "sobranceáramo": "sobrancear",
    "sobranceáramos": "sobrancear",
    "sobranceáreis": "sobrancear",
    "sobranceásseis": "sobrancear",
    "sobranceássemos": "sobrancear",
    "sobranceávamo": "sobrancear",
    "sobranceávamos": "sobrancear",
    "sobranceáveis": "sobrancear",
    "sobrando": "sobrar",
    "sobrantes": "sobrante",
    "sobrançarias": "sobrançaria",
    "sobrara": "sobrar",
    "sobraram": "sobrar",
    "sobraras": "sobrar",
    "sobrardes": "sobrar",
    "sobrarei": "sobrar",
    "sobrareis": "sobrar",
    "sobrarem": "sobrar",
    "sobraremos": "sobrar",
    "sobrares": "sobrar",
    "sobraria": "sobrar",
    "sobrariam": "sobrar",
    "sobrarias": "sobrar",
    "sobrarmo": "sobrar",
    "sobrarmos": "sobrar",
    "sobrará": "sobrar",
    "sobrarás": "sobrar",
    "sobrarão": "sobrar",
    "sobraríamos": "sobrar",
    "sobraríeis": "sobrar",
    "sobras": "sobrar",
    "sobrasa": "sobrasar",
    "sobrasada": "sobrasar",
    "sobrasadas": "sobrasar",
    "sobrasado": "sobrasar",
    "sobrasados": "sobrasar",
    "sobrasai": "sobrasar",
    "sobrasais": "sobrasar",
    "sobrasam": "sobrasar",
    "sobrasamo": "sobrasar",
    "sobrasamos": "sobrasar",
    "sobrasando": "sobrasar",
    "sobrasara": "sobrasar",
    "sobrasaram": "sobrasar",
    "sobrasaras": "sobrasar",
    "sobrasarde": "sobrasar",
    "sobrasardes": "sobrasar",
    "sobrasare": "sobrasar",
    "sobrasarei": "sobrasar",
    "sobrasareis": "sobrasar",
    "sobrasarem": "sobrasar",
    "sobrasaremos": "sobrasar",
    "sobrasares": "sobrasar",
    "sobrasaria": "sobrasar",
    "sobrasariam": "sobrasar",
    "sobrasarias": "sobrasar",
    "sobrasarmo": "sobrasar",
    "sobrasarmos": "sobrasar",
    "sobrasará": "sobrasar",
    "sobrasarás": "sobrasar",
    "sobrasarão": "sobrasar",
    "sobrasaríamos": "sobrasar",
    "sobrasaríeis": "sobrasar",
    "sobrasas": "sobrasar",
    "sobrasasse": "sobrasar",
    "sobrasassem": "sobrasar",
    "sobrasasses": "sobrasar",
    "sobrasaste": "sobrasar",
    "sobrasastes": "sobrasar",
    "sobrasava": "sobrasar",
    "sobrasavam": "sobrasar",
    "sobrasavas": "sobrasar",
    "sobrase": "sobrasar",
    "sobrasei": "sobrasar",
    "sobraseis": "sobrasar",
    "sobrasem": "sobrasar",
    "sobrasemo": "sobrasar",
    "sobrasemos": "sobrasar",
    "sobrases": "sobrasar",
    "sobraso": "sobrasar",
    "sobrasou": "sobrasar",
    "sobrasse": "sobrar",
    "sobrassem": "sobrar",
    "sobrasses": "sobrar",
    "sobraste": "sobrar",
    "sobrastes": "sobrar",
    "sobrasá": "sobrasar",
    "sobrasámo": "sobrasar",
    "sobrasámos": "sobrasar",
    "sobrasáramo": "sobrasar",
    "sobrasáramos": "sobrasar",
    "sobrasárei": "sobrasar",
    "sobrasáreis": "sobrasar",
    "sobrasásseis": "sobrasar",
    "sobrasássemos": "sobrasar",
    "sobrasávamo": "sobrasar",
    "sobrasávamos": "sobrasar",
    "sobrasávei": "sobrasar",
    "sobrasáveis": "sobrasar",
    "sobrava": "sobrar",
    "sobravam": "sobrar",
    "sobravas": "sobrar",
    "sobraça": "sobraçar",
    "sobraçada": "sobraçar",
    "sobraçadas": "sobraçar",
    "sobraçado": "sobraçar",
    "sobraçados": "sobraçar",
    "sobraçai": "sobraçar",
    "sobraçais": "sobraçar",
    "sobraçam": "sobraçar",
    "sobraçamo": "sobraçar",
    "sobraçamos": "sobraçar",
    "sobraçando": "sobraçar",
    "sobraçara": "sobraçar",
    "sobraçaram": "sobraçar",
    "sobraçaras": "sobraçar",
    "sobraçarde": "sobraçar",
    "sobraçardes": "sobraçar",
    "sobraçare": "sobraçar",
    "sobraçarei": "sobraçar",
    "sobraçareis": "sobraçar",
    "sobraçarem": "sobraçar",
    "sobraçaremos": "sobraçar",
    "sobraçares": "sobraçar",
    "sobraçaria": "sobraçar",
    "sobraçariam": "sobraçar",
    "sobraçarias": "sobraçar",
    "sobraçarmo": "sobraçar",
    "sobraçarmos": "sobraçar",
    "sobraçará": "sobraçar",
    "sobraçarás": "sobraçar",
    "sobraçarão": "sobraçar",
    "sobraçaríamos": "sobraçar",
    "sobraçaríeis": "sobraçar",
    "sobraças": "sobraçar",
    "sobraçasse": "sobraçar",
    "sobraçassem": "sobraçar",
    "sobraçasses": "sobraçar",
    "sobraçaste": "sobraçar",
    "sobraçastes": "sobraçar",
    "sobraçava": "sobraçar",
    "sobraçavam": "sobraçar",
    "sobraçavas": "sobraçar",
    "sobraço": "sobraçar",
    "sobraçou": "sobraçar",
    "sobraçá": "sobraçar",
    "sobraçámo": "sobraçar",
    "sobraçámos": "sobraçar",
    "sobraçáramo": "sobraçar",
    "sobraçáramos": "sobraçar",
    "sobraçárei": "sobraçar",
    "sobraçáreis": "sobraçar",
    "sobraçásseis": "sobraçar",
    "sobraçássemos": "sobraçar",
    "sobraçávamo": "sobraçar",
    "sobraçávamos": "sobraçar",
    "sobraçávei": "sobraçar",
    "sobraçáveis": "sobraçar",
    "sobre": "sobrar",
    "sobrea": "sobreir",
    "sobreabastecida": "sobreabastecido",
    "sobreabastecidas": "sobreabastecido",
    "sobreabastecidos": "sobreabastecido",
    "sobreabunda": "sobreabundar",
    "sobreabundada": "sobreabundar",
    "sobreabundadas": "sobreabundar",
    "sobreabundado": "sobreabundar",
    "sobreabundados": "sobreabundar",
    "sobreabundai": "sobreabundar",
    "sobreabundais": "sobreabundar",
    "sobreabundam": "sobreabundar",
    "sobreabundamo": "sobreabundar",
    "sobreabundamos": "sobreabundar",
    "sobreabundando": "sobreabundar",
    "sobreabundara": "sobreabundar",
    "sobreabundaram": "sobreabundar",
    "sobreabundaras": "sobreabundar",
    "sobreabundardes": "sobreabundar",
    "sobreabundarei": "sobreabundar",
    "sobreabundareis": "sobreabundar",
    "sobreabundarem": "sobreabundar",
    "sobreabundaremos": "sobreabundar",
    "sobreabundares": "sobreabundar",
    "sobreabundaria": "sobreabundar",
    "sobreabundariam": "sobreabundar",
    "sobreabundarias": "sobreabundar",
    "sobreabundarmo": "sobreabundar",
    "sobreabundarmos": "sobreabundar",
    "sobreabundará": "sobreabundar",
    "sobreabundarás": "sobreabundar",
    "sobreabundarão": "sobreabundar",
    "sobreabundaríamos": "sobreabundar",
    "sobreabundaríeis": "sobreabundar",
    "sobreabundas": "sobreabundar",
    "sobreabundasse": "sobreabundar",
    "sobreabundassem": "sobreabundar",
    "sobreabundasses": "sobreabundar",
    "sobreabundaste": "sobreabundar",
    "sobreabundastes": "sobreabundar",
    "sobreabundava": "sobreabundar",
    "sobreabundavam": "sobreabundar",
    "sobreabundavas": "sobreabundar",
    "sobreabunde": "sobreabundar",
    "sobreabundei": "sobreabundar",
    "sobreabundeis": "sobreabundar",
    "sobreabundem": "sobreabundar",
    "sobreabundemo": "sobreabundar",
    "sobreabundemos": "sobreabundar",
    "sobreabundes": "sobreabundar",
    "sobreabundo": "sobreabundar",
    "sobreabundou": "sobreabundar",
    "sobreabundámo": "sobreabundar",
    "sobreabundámos": "sobreabundar",
    "sobreabundáramo": "sobreabundar",
    "sobreabundáramos": "sobreabundar",
    "sobreabundáreis": "sobreabundar",
    "sobreabundásseis": "sobreabundar",
    "sobreabundássemos": "sobreabundar",
    "sobreabundávamo": "sobreabundar",
    "sobreabundávamos": "sobreabundar",
    "sobreabundáveis": "sobreabundar",
    "sobreabundâncias": "sobreabundância",
    "sobreagua": "sobreaguar",
    "sobreaguada": "sobreaguar",
    "sobreaguadas": "sobreaguar",
    "sobreaguado": "sobreaguar",
    "sobreaguados": "sobreaguar",
    "sobreaguai": "sobreaguar",
    "sobreaguais": "sobreaguar",
    "sobreaguam": "sobreaguar",
    "sobreaguamo": "sobreaguar",
    "sobreaguamos": "sobreaguar",
    "sobreaguando": "sobreaguar",
    "sobreaguara": "sobreaguar",
    "sobreaguaram": "sobreaguar",
    "sobreaguaras": "sobreaguar",
    "sobreaguarde": "sobreaguar",
    "sobreaguardes": "sobreaguar",
    "sobreaguare": "sobreaguar",
    "sobreaguarei": "sobreaguar",
    "sobreaguareis": "sobreaguar",
    "sobreaguarem": "sobreaguar",
    "sobreaguaremos": "sobreaguar",
    "sobreaguares": "sobreaguar",
    "sobreaguaria": "sobreaguar",
    "sobreaguariam": "sobreaguar",
    "sobreaguarias": "sobreaguar",
    "sobreaguarmo": "sobreaguar",
    "sobreaguarmos": "sobreaguar",
    "sobreaguará": "sobreaguar",
    "sobreaguarás": "sobreaguar",
    "sobreaguarão": "sobreaguar",
    "sobreaguaríamos": "sobreaguar",
    "sobreaguaríeis": "sobreaguar",
    "sobreaguas": "sobreaguar",
    "sobreaguasse": "sobreaguar",
    "sobreaguassem": "sobreaguar",
    "sobreaguasses": "sobreaguar",
    "sobreaguaste": "sobreaguar",
    "sobreaguastes": "sobreaguar",
    "sobreaguava": "sobreaguar",
    "sobreaguavam": "sobreaguar",
    "sobreaguavas": "sobreaguar",
    "sobreaguei": "sobreaguar",
    "sobreagueis": "sobreaguar",
    "sobreaguemo": "sobreaguar",
    "sobreaguemos": "sobreaguar",
    "sobreagues": "sobreaguar",
    "sobreaguo": "sobreaguar",
    "sobreaguou": "sobreaguar",
    "sobreaguá": "sobreaguar",
    "sobreaguámo": "sobreaguar",
    "sobreaguámos": "sobreaguar",
    "sobreaguáramo": "sobreaguar",
    "sobreaguáramos": "sobreaguar",
    "sobreaguárei": "sobreaguar",
    "sobreaguáreis": "sobreaguar",
    "sobreaguásseis": "sobreaguar",
    "sobreaguássemos": "sobreaguar",
    "sobreaguávamo": "sobreaguar",
    "sobreaguávamos": "sobreaguar",
    "sobreaguávei": "sobreaguar",
    "sobreaguáveis": "sobreaguar",
    "sobreagúe": "sobreaguar",
    "sobreagúem": "sobreaguar",
    "sobreagúes": "sobreaguar",
    "sobreais": "sobreir",
    "sobrealcunhas": "sobrealcunha",
    "sobrealimenta": "sobrealimentar",
    "sobrealimentada": "sobrealimentar",
    "sobrealimentadas": "sobrealimentar",
    "sobrealimentado": "sobrealimentar",
    "sobrealimentados": "sobrealimentar",
    "sobrealimentai": "sobrealimentar",
    "sobrealimentais": "sobrealimentar",
    "sobrealimentam": "sobrealimentar",
    "sobrealimentamo": "sobrealimentar",
    "sobrealimentamos": "sobrealimentar",
    "sobrealimentando": "sobrealimentar",
    "sobrealimentara": "sobrealimentar",
    "sobrealimentaram": "sobrealimentar",
    "sobrealimentaras": "sobrealimentar",
    "sobrealimentarde": "sobrealimentar",
    "sobrealimentardes": "sobrealimentar",
    "sobrealimentare": "sobrealimentar",
    "sobrealimentarei": "sobrealimentar",
    "sobrealimentareis": "sobrealimentar",
    "sobrealimentarem": "sobrealimentar",
    "sobrealimentaremos": "sobrealimentar",
    "sobrealimentares": "sobrealimentar",
    "sobrealimentaria": "sobrealimentar",
    "sobrealimentariam": "sobrealimentar",
    "sobrealimentarias": "sobrealimentar",
    "sobrealimentarmo": "sobrealimentar",
    "sobrealimentarmos": "sobrealimentar",
    "sobrealimentará": "sobrealimentar",
    "sobrealimentarás": "sobrealimentar",
    "sobrealimentarão": "sobrealimentar",
    "sobrealimentaríamos": "sobrealimentar",
    "sobrealimentaríeis": "sobrealimentar",
    "sobrealimentas": "sobrealimentar",
    "sobrealimentasse": "sobrealimentar",
    "sobrealimentassem": "sobrealimentar",
    "sobrealimentasses": "sobrealimentar",
    "sobrealimentaste": "sobrealimentar",
    "sobrealimentastes": "sobrealimentar",
    "sobrealimentava": "sobrealimentar",
    "sobrealimentavam": "sobrealimentar",
    "sobrealimentavas": "sobrealimentar",
    "sobrealimentações": "sobrealimentação",
    "sobrealimente": "sobrealimentar",
    "sobrealimentei": "sobrealimentar",
    "sobrealimenteis": "sobrealimentar",
    "sobrealimentem": "sobrealimentar",
    "sobrealimentemo": "sobrealimentar",
    "sobrealimentemos": "sobrealimentar",
    "sobrealimentes": "sobrealimentar",
    "sobrealimento": "sobrealimentar",
    "sobrealimentou": "sobrealimentar",
    "sobrealimentá": "sobrealimentar",
    "sobrealimentámo": "sobrealimentar",
    "sobrealimentámos": "sobrealimentar",
    "sobrealimentáramo": "sobrealimentar",
    "sobrealimentáramos": "sobrealimentar",
    "sobrealimentárei": "sobrealimentar",
    "sobrealimentáreis": "sobrealimentar",
    "sobrealimentásseis": "sobrealimentar",
    "sobrealimentássemos": "sobrealimentar",
    "sobrealimentávamo": "sobrealimentar",
    "sobrealimentávamos": "sobrealimentar",
    "sobrealimentávei": "sobrealimentar",
    "sobrealimentáveis": "sobrealimentar",
    "sobream": "sobreir",
    "sobreamo": "sobreir",
    "sobreamos": "sobreir",
    "sobreancas": "sobreanca",
    "sobreapelidos": "sobreapelido",
    "sobreaquecida": "sobreaquecido",
    "sobreaquecidas": "sobreaquecido",
    "sobreaquecidos": "sobreaquecido",
    "sobreaquecimentos": "sobreaquecimento",
    "sobrearcos": "sobrearco",
    "sobreas": "sobreir",
    "sobreavalia": "sobreavaliar",
    "sobreavaliada": "sobreavaliar",
    "sobreavaliadas": "sobreavaliar",
    "sobreavaliado": "sobreavaliar",
    "sobreavaliados": "sobreavaliar",
    "sobreavaliai": "sobreavaliar",
    "sobreavaliais": "sobreavaliar",
    "sobreavaliam": "sobreavaliar",
    "sobreavaliamo": "sobreavaliar",
    "sobreavaliamos": "sobreavaliar",
    "sobreavaliando": "sobreavaliar",
    "sobreavaliara": "sobreavaliar",
    "sobreavaliaram": "sobreavaliar",
    "sobreavaliaras": "sobreavaliar",
    "sobreavaliarde": "sobreavaliar",
    "sobreavaliardes": "sobreavaliar",
    "sobreavaliare": "sobreavaliar",
    "sobreavaliarei": "sobreavaliar",
    "sobreavaliareis": "sobreavaliar",
    "sobreavaliarem": "sobreavaliar",
    "sobreavaliaremos": "sobreavaliar",
    "sobreavaliares": "sobreavaliar",
    "sobreavaliaria": "sobreavaliar",
    "sobreavaliariam": "sobreavaliar",
    "sobreavaliarias": "sobreavaliar",
    "sobreavaliarmo": "sobreavaliar",
    "sobreavaliarmos": "sobreavaliar",
    "sobreavaliará": "sobreavaliar",
    "sobreavaliarás": "sobreavaliar",
    "sobreavaliarão": "sobreavaliar",
    "sobreavaliaríamos": "sobreavaliar",
    "sobreavaliaríeis": "sobreavaliar",
    "sobreavalias": "sobreavaliar",
    "sobreavaliasse": "sobreavaliar",
    "sobreavaliassem": "sobreavaliar",
    "sobreavaliasses": "sobreavaliar",
    "sobreavaliaste": "sobreavaliar",
    "sobreavaliastes": "sobreavaliar",
    "sobreavaliava": "sobreavaliar",
    "sobreavaliavam": "sobreavaliar",
    "sobreavaliavas": "sobreavaliar",
    "sobreavaliações": "sobreavaliação",
    "sobreavalie": "sobreavaliar",
    "sobreavaliei": "sobreavaliar",
    "sobreavalieis": "sobreavaliar",
    "sobreavaliem": "sobreavaliar",
    "sobreavaliemo": "sobreavaliar",
    "sobreavaliemos": "sobreavaliar",
    "sobreavalies": "sobreavaliar",
    "sobreavalio": "sobreavaliar",
    "sobreavaliou": "sobreavaliar",
    "sobreavaliá": "sobreavaliar",
    "sobreavaliámo": "sobreavaliar",
    "sobreavaliámos": "sobreavaliar",
    "sobreavaliáramo": "sobreavaliar",
    "sobreavaliáramos": "sobreavaliar",
    "sobreavaliárei": "sobreavaliar",
    "sobreavaliáreis": "sobreavaliar",
    "sobreavaliásseis": "sobreavaliar",
    "sobreavaliássemos": "sobreavaliar",
    "sobreavaliávamo": "sobreavaliar",
    "sobreavaliávamos": "sobreavaliar",
    "sobreavaliávei": "sobreavaliar",
    "sobreavaliáveis": "sobreavaliar",
    "sobreavisa": "sobreavisar",
    "sobreavisada": "sobreavisar",
    "sobreavisadas": "sobreavisar",
    "sobreavisado": "sobreavisar",
    "sobreavisados": "sobreavisar",
    "sobreavisai": "sobreavisar",
    "sobreavisais": "sobreavisar",
    "sobreavisam": "sobreavisar",
    "sobreavisamo": "sobreavisar",
    "sobreavisamos": "sobreavisar",
    "sobreavisando": "sobreavisar",
    "sobreavisara": "sobreavisar",
    "sobreavisaram": "sobreavisar",
    "sobreavisaras": "sobreavisar",
    "sobreavisarde": "sobreavisar",
    "sobreavisardes": "sobreavisar",
    "sobreavisare": "sobreavisar",
    "sobreavisarei": "sobreavisar",
    "sobreavisareis": "sobreavisar",
    "sobreavisarem": "sobreavisar",
    "sobreavisaremos": "sobreavisar",
    "sobreavisares": "sobreavisar",
    "sobreavisaria": "sobreavisar",
    "sobreavisariam": "sobreavisar",
    "sobreavisarias": "sobreavisar",
    "sobreavisarmo": "sobreavisar",
    "sobreavisarmos": "sobreavisar",
    "sobreavisará": "sobreavisar",
    "sobreavisarás": "sobreavisar",
    "sobreavisarão": "sobreavisar",
    "sobreavisaríamos": "sobreavisar",
    "sobreavisaríeis": "sobreavisar",
    "sobreavisas": "sobreavisar",
    "sobreavisasse": "sobreavisar",
    "sobreavisassem": "sobreavisar",
    "sobreavisasses": "sobreavisar",
    "sobreavisaste": "sobreavisar",
    "sobreavisastes": "sobreavisar",
    "sobreavisava": "sobreavisar",
    "sobreavisavam": "sobreavisar",
    "sobreavisavas": "sobreavisar",
    "sobreavise": "sobreavisar",
    "sobreavisei": "sobreavisar",
    "sobreaviseis": "sobreavisar",
    "sobreavisem": "sobreavisar",
    "sobreavisemo": "sobreavisar",
    "sobreavisemos": "sobreavisar",
    "sobreavises": "sobreavisar",
    "sobreaviso": "sobreavisar",
    "sobreavisos": "sobreaviso",
    "sobreavisou": "sobreavisar",
    "sobreavisá": "sobreavisar",
    "sobreavisámo": "sobreavisar",
    "sobreavisámos": "sobreavisar",
    "sobreavisáramo": "sobreavisar",
    "sobreavisáramos": "sobreavisar",
    "sobreavisárei": "sobreavisar",
    "sobreavisáreis": "sobreavisar",
    "sobreavisásseis": "sobreavisar",
    "sobreavisássemos": "sobreavisar",
    "sobreavisávamo": "sobreavisar",
    "sobreavisávamos": "sobreavisar",
    "sobreavisávei": "sobreavisar",
    "sobreavisáveis": "sobreavisar",
    "sobreaxilares": "sobreaxilar",
    "sobrebailéus": "sobrebailéu",
    "sobrebainhas": "sobrebainha",
    "sobrebicos": "sobrebico",
    "sobrebojos": "sobrebojo",
    "sobrecabada": "sobrecabado",
    "sobrecabadas": "sobrecabado",
    "sobrecabados": "sobrecabado",
    "sobrecanas": "sobrecana",
    "sobrecapas": "sobrecapa",
    "sobrecargas": "sobrecarga",
    "sobrecarrega": "sobrecarregar",
    "sobrecarregada": "sobrecarregar",
    "sobrecarregadas": "sobrecarregar",
    "sobrecarregado": "sobrecarregar",
    "sobrecarregados": "sobrecarregar",
    "sobrecarregai": "sobrecarregar",
    "sobrecarregais": "sobrecarregar",
    "sobrecarregam": "sobrecarregar",
    "sobrecarregamo": "sobrecarregar",
    "sobrecarregamos": "sobrecarregar",
    "sobrecarregando": "sobrecarregar",
    "sobrecarregara": "sobrecarregar",
    "sobrecarregaram": "sobrecarregar",
    "sobrecarregaras": "sobrecarregar",
    "sobrecarregarde": "sobrecarregar",
    "sobrecarregardes": "sobrecarregar",
    "sobrecarregare": "sobrecarregar",
    "sobrecarregarei": "sobrecarregar",
    "sobrecarregareis": "sobrecarregar",
    "sobrecarregarem": "sobrecarregar",
    "sobrecarregaremos": "sobrecarregar",
    "sobrecarregares": "sobrecarregar",
    "sobrecarregaria": "sobrecarregar",
    "sobrecarregariam": "sobrecarregar",
    "sobrecarregarias": "sobrecarregar",
    "sobrecarregarmo": "sobrecarregar",
    "sobrecarregarmos": "sobrecarregar",
    "sobrecarregará": "sobrecarregar",
    "sobrecarregarás": "sobrecarregar",
    "sobrecarregarão": "sobrecarregar",
    "sobrecarregaríamos": "sobrecarregar",
    "sobrecarregaríeis": "sobrecarregar",
    "sobrecarregas": "sobrecarregar",
    "sobrecarregasse": "sobrecarregar",
    "sobrecarregassem": "sobrecarregar",
    "sobrecarregasses": "sobrecarregar",
    "sobrecarregaste": "sobrecarregar",
    "sobrecarregastes": "sobrecarregar",
    "sobrecarregava": "sobrecarregar",
    "sobrecarregavam": "sobrecarregar",
    "sobrecarregavas": "sobrecarregar",
    "sobrecarrego": "sobrecarregar",
    "sobrecarregou": "sobrecarregar",
    "sobrecarregue": "sobrecarregar",
    "sobrecarreguei": "sobrecarregar",
    "sobrecarregueis": "sobrecarregar",
    "sobrecarreguem": "sobrecarregar",
    "sobrecarreguemo": "sobrecarregar",
    "sobrecarreguemos": "sobrecarregar",
    "sobrecarregues": "sobrecarregar",
    "sobrecarregá": "sobrecarregar",
    "sobrecarregámo": "sobrecarregar",
    "sobrecarregámos": "sobrecarregar",
    "sobrecarregáramo": "sobrecarregar",
    "sobrecarregáramos": "sobrecarregar",
    "sobrecarregárei": "sobrecarregar",
    "sobrecarregáreis": "sobrecarregar",
    "sobrecarregásseis": "sobrecarregar",
    "sobrecarregássemos": "sobrecarregar",
    "sobrecarregávamo": "sobrecarregar",
    "sobrecarregávamos": "sobrecarregar",
    "sobrecarregávei": "sobrecarregar",
    "sobrecarregáveis": "sobrecarregar",
    "sobrecartas": "sobrecarta",
    "sobrecasacas": "sobrecasaca",
    "sobreceias": "sobreceia",
    "sobrecenhos": "sobrecenho",
    "sobrechega": "sobrechegar",
    "sobrechegada": "sobrechegar",
    "sobrechegadas": "sobrechegar",
    "sobrechegado": "sobrechegar",
    "sobrechegados": "sobrechegar",
    "sobrechegai": "sobrechegar",
    "sobrechegais": "sobrechegar",
    "sobrechegam": "sobrechegar",
    "sobrechegamo": "sobrechegar",
    "sobrechegamos": "sobrechegar",
    "sobrechegando": "sobrechegar",
    "sobrechegara": "sobrechegar",
    "sobrechegaram": "sobrechegar",
    "sobrechegaras": "sobrechegar",
    "sobrechegardes": "sobrechegar",
    "sobrechegarei": "sobrechegar",
    "sobrechegareis": "sobrechegar",
    "sobrechegarem": "sobrechegar",
    "sobrechegaremos": "sobrechegar",
    "sobrechegares": "sobrechegar",
    "sobrechegaria": "sobrechegar",
    "sobrechegariam": "sobrechegar",
    "sobrechegarias": "sobrechegar",
    "sobrechegarmo": "sobrechegar",
    "sobrechegarmos": "sobrechegar",
    "sobrechegará": "sobrechegar",
    "sobrechegarás": "sobrechegar",
    "sobrechegarão": "sobrechegar",
    "sobrechegaríamos": "sobrechegar",
    "sobrechegaríeis": "sobrechegar",
    "sobrechegas": "sobrechegar",
    "sobrechegasse": "sobrechegar",
    "sobrechegassem": "sobrechegar",
    "sobrechegasses": "sobrechegar",
    "sobrechegaste": "sobrechegar",
    "sobrechegastes": "sobrechegar",
    "sobrechegava": "sobrechegar",
    "sobrechegavam": "sobrechegar",
    "sobrechegavas": "sobrechegar",
    "sobrechego": "sobrechegar",
    "sobrechegou": "sobrechegar",
    "sobrechegue": "sobrechegar",
    "sobrecheguei": "sobrechegar",
    "sobrechegueis": "sobrechegar",
    "sobrecheguem": "sobrechegar",
    "sobrecheguemo": "sobrechegar",
    "sobrecheguemos": "sobrechegar",
    "sobrechegues": "sobrechegar",
    "sobrechegámo": "sobrechegar",
    "sobrechegámos": "sobrechegar",
    "sobrechegáramo": "sobrechegar",
    "sobrechegáramos": "sobrechegar",
    "sobrechegáreis": "sobrechegar",
    "sobrechegásseis": "sobrechegar",
    "sobrechegássemos": "sobrechegar",
    "sobrechegávamo": "sobrechegar",
    "sobrechegávamos": "sobrechegar",
    "sobrechegáveis": "sobrechegar",
    "sobrecheia": "sobrecheio",
    "sobrecheias": "sobrecheio",
    "sobrecheios": "sobrecheio",
    "sobrecilhas": "sobrecilha",
    "sobreclaustras": "sobreclaustra",
    "sobreclaustros": "sobreclaustro",
    "sobrecobertas": "sobrecoberta",
    "sobrecompensa": "sobrecompensar",
    "sobrecompensada": "sobrecompensar",
    "sobrecompensadas": "sobrecompensar",
    "sobrecompensado": "sobrecompensar",
    "sobrecompensados": "sobrecompensar",
    "sobrecompensai": "sobrecompensar",
    "sobrecompensais": "sobrecompensar",
    "sobrecompensam": "sobrecompensar",
    "sobrecompensamo": "sobrecompensar",
    "sobrecompensamos": "sobrecompensar",
    "sobrecompensando": "sobrecompensar",
    "sobrecompensara": "sobrecompensar",
    "sobrecompensaram": "sobrecompensar",
    "sobrecompensaras": "sobrecompensar",
    "sobrecompensarde": "sobrecompensar",
    "sobrecompensardes": "sobrecompensar",
    "sobrecompensare": "sobrecompensar",
    "sobrecompensarei": "sobrecompensar",
    "sobrecompensareis": "sobrecompensar",
    "sobrecompensarem": "sobrecompensar",
    "sobrecompensaremos": "sobrecompensar",
    "sobrecompensares": "sobrecompensar",
    "sobrecompensaria": "sobrecompensar",
    "sobrecompensariam": "sobrecompensar",
    "sobrecompensarias": "sobrecompensar",
    "sobrecompensarmo": "sobrecompensar",
    "sobrecompensarmos": "sobrecompensar",
    "sobrecompensará": "sobrecompensar",
    "sobrecompensarás": "sobrecompensar",
    "sobrecompensarão": "sobrecompensar",
    "sobrecompensaríamos": "sobrecompensar",
    "sobrecompensaríeis": "sobrecompensar",
    "sobrecompensas": "sobrecompensar",
    "sobrecompensasse": "sobrecompensar",
    "sobrecompensassem": "sobrecompensar",
    "sobrecompensasses": "sobrecompensar",
    "sobrecompensaste": "sobrecompensar",
    "sobrecompensastes": "sobrecompensar",
    "sobrecompensava": "sobrecompensar",
    "sobrecompensavam": "sobrecompensar",
    "sobrecompensavas": "sobrecompensar",
    "sobrecompensações": "sobrecompensação",
    "sobrecompense": "sobrecompensar",
    "sobrecompensei": "sobrecompensar",
    "sobrecompenseis": "sobrecompensar",
    "sobrecompensem": "sobrecompensar",
    "sobrecompensemo": "sobrecompensar",
    "sobrecompensemos": "sobrecompensar",
    "sobrecompenses": "sobrecompensar",
    "sobrecompenso": "sobrecompensar",
    "sobrecompensou": "sobrecompensar",
    "sobrecompensá": "sobrecompensar",
    "sobrecompensámo": "sobrecompensar",
    "sobrecompensámos": "sobrecompensar",
    "sobrecompensáramo": "sobrecompensar",
    "sobrecompensáramos": "sobrecompensar",
    "sobrecompensárei": "sobrecompensar",
    "sobrecompensáreis": "sobrecompensar",
    "sobrecompensásseis": "sobrecompensar",
    "sobrecompensássemos": "sobrecompensar",
    "sobrecompensávamo": "sobrecompensar",
    "sobrecompensávamos": "sobrecompensar",
    "sobrecompensávei": "sobrecompensar",
    "sobrecompensáveis": "sobrecompensar",
    "sobrecomuns": "sobrecomum",
    "sobrecopas": "sobrecopa",
    "sobrecosa": "sobrecoser",
    "sobrecosais": "sobrecoser",
    "sobrecosam": "sobrecoser",
    "sobrecosamo": "sobrecoser",
    "sobrecosamos": "sobrecoser",
    "sobrecosas": "sobrecoser",
    "sobrecose": "sobrecoser",
    "sobrecosei": "sobrecoser",
    "sobrecoseis": "sobrecoser",
    "sobrecosem": "sobrecoser",
    "sobrecosemo": "sobrecoser",
    "sobrecosemos": "sobrecoser",
    "sobrecosendo": "sobrecoser",
    "sobrecosera": "sobrecoser",
    "sobrecoseram": "sobrecoser",
    "sobrecoseras": "sobrecoser",
    "sobrecoserde": "sobrecoser",
    "sobrecoserdes": "sobrecoser",
    "sobrecosere": "sobrecoser",
    "sobrecoserei": "sobrecoser",
    "sobrecosereis": "sobrecoser",
    "sobrecoserem": "sobrecoser",
    "sobrecoseremos": "sobrecoser",
    "sobrecoseres": "sobrecoser",
    "sobrecoseria": "sobrecoser",
    "sobrecoseriam": "sobrecoser",
    "sobrecoserias": "sobrecoser",
    "sobrecosermo": "sobrecoser",
    "sobrecosermos": "sobrecoser",
    "sobrecoserá": "sobrecoser",
    "sobrecoserás": "sobrecoser",
    "sobrecoserão": "sobrecoser",
    "sobrecoseríamos": "sobrecoser",
    "sobrecoseríeis": "sobrecoser",
    "sobrecoses": "sobrecoser",
    "sobrecosesse": "sobrecoser",
    "sobrecosessem": "sobrecoser",
    "sobrecosesses": "sobrecoser",
    "sobrecoseste": "sobrecoser",
    "sobrecosestes": "sobrecoser",
    "sobrecoseu": "sobrecoser",
    "sobrecosi": "sobrecoser",
    "sobrecosia": "sobrecoser",
    "sobrecosiam": "sobrecoser",
    "sobrecosias": "sobrecoser",
    "sobrecosida": "sobrecoser",
    "sobrecosidas": "sobrecoser",
    "sobrecosido": "sobrecoser",
    "sobrecosidos": "sobrecoser",
    "sobrecoso": "sobrecoser",
    "sobrecosturas": "sobrecostura",
    "sobrecosê": "sobrecoser",
    "sobrecosêramo": "sobrecoser",
    "sobrecosêramos": "sobrecoser",
    "sobrecosêrei": "sobrecoser",
    "sobrecosêreis": "sobrecoser",
    "sobrecosêsseis": "sobrecoser",
    "sobrecosêssemos": "sobrecoser",
    "sobrecosíamo": "sobrecoser",
    "sobrecosíamos": "sobrecoser",
    "sobrecosíei": "sobrecoser",
    "sobrecosíeis": "sobrecoser",
    "sobrecurvas": "sobrecurva",
    "sobrecus": "sobrecu",
    "sobrecâmaras": "sobrecâmara",
    "sobrecéus": "sobrecéu",
    "sobredentais": "sobredental",
    "sobredentes": "sobredente",
    "sobredimensionada": "sobredimensionado",
    "sobredimensionadas": "sobredimensionado",
    "sobredimensionados": "sobredimensionado",
    "sobredita": "sobredito",
    "sobreditas": "sobredito",
    "sobreditos": "sobredito",
    "sobredivina": "sobredivino",
    "sobredivinas": "sobredivino",
    "sobredivinos": "sobredivino",
    "sobredoira": "sobredoirar",
    "sobredoirada": "sobredoirar",
    "sobredoiradas": "sobredoirar",
    "sobredoirado": "sobredoirar",
    "sobredoirados": "sobredoirar",
    "sobredoirai": "sobredoirar",
    "sobredoirais": "sobredoirar",
    "sobredoiram": "sobredoirar",
    "sobredoiramo": "sobredoirar",
    "sobredoiramos": "sobredoirar",
    "sobredoirando": "sobredoirar",
    "sobredoirara": "sobredoirar",
    "sobredoiraram": "sobredoirar",
    "sobredoiraras": "sobredoirar",
    "sobredoirarde": "sobredoirar",
    "sobredoirardes": "sobredoirar",
    "sobredoirare": "sobredoirar",
    "sobredoirarei": "sobredoirar",
    "sobredoirareis": "sobredoirar",
    "sobredoirarem": "sobredoirar",
    "sobredoiraremos": "sobredoirar",
    "sobredoirares": "sobredoirar",
    "sobredoiraria": "sobredoirar",
    "sobredoirariam": "sobredoirar",
    "sobredoirarias": "sobredoirar",
    "sobredoirarmo": "sobredoirar",
    "sobredoirarmos": "sobredoirar",
    "sobredoirará": "sobredoirar",
    "sobredoirarás": "sobredoirar",
    "sobredoirarão": "sobredoirar",
    "sobredoiraríamos": "sobredoirar",
    "sobredoiraríeis": "sobredoirar",
    "sobredoiras": "sobredoirar",
    "sobredoirasse": "sobredoirar",
    "sobredoirassem": "sobredoirar",
    "sobredoirasses": "sobredoirar",
    "sobredoiraste": "sobredoirar",
    "sobredoirastes": "sobredoirar",
    "sobredoirava": "sobredoirar",
    "sobredoiravam": "sobredoirar",
    "sobredoiravas": "sobredoirar",
    "sobredoire": "sobredoirar",
    "sobredoirei": "sobredoirar",
    "sobredoireis": "sobredoirar",
    "sobredoirem": "sobredoirar",
    "sobredoiremo": "sobredoirar",
    "sobredoiremos": "sobredoirar",
    "sobredoires": "sobredoirar",
    "sobredoiro": "sobredoirar",
    "sobredoirou": "sobredoirar",
    "sobredoirá": "sobredoirar",
    "sobredoirámo": "sobredoirar",
    "sobredoirámos": "sobredoirar",
    "sobredoiráramo": "sobredoirar",
    "sobredoiráramos": "sobredoirar",
    "sobredoirárei": "sobredoirar",
    "sobredoiráreis": "sobredoirar",
    "sobredoirásseis": "sobredoirar",
    "sobredoirássemos": "sobredoirar",
    "sobredoirávamo": "sobredoirar",
    "sobredoirávamos": "sobredoirar",
    "sobredoirávei": "sobredoirar",
    "sobredoiráveis": "sobredoirar",
    "sobredominantes": "sobredominante",
    "sobredominâncias": "sobredominância",
    "sobredotada": "sobredotado",
    "sobredotadas": "sobredotado",
    "sobredotados": "sobredotado",
    "sobredotações": "sobredotação",
    "sobredoura": "sobredourar",
    "sobredourada": "sobredourar",
    "sobredouradas": "sobredourar",
    "sobredourado": "sobredourar",
    "sobredourados": "sobredourar",
    "sobredourai": "sobredourar",
    "sobredourais": "sobredourar",
    "sobredouram": "sobredourar",
    "sobredouramo": "sobredourar",
    "sobredouramos": "sobredourar",
    "sobredourando": "sobredourar",
    "sobredourara": "sobredourar",
    "sobredouraram": "sobredourar",
    "sobredouraras": "sobredourar",
    "sobredourarde": "sobredourar",
    "sobredourardes": "sobredourar",
    "sobredourare": "sobredourar",
    "sobredourarei": "sobredourar",
    "sobredourareis": "sobredourar",
    "sobredourarem": "sobredourar",
    "sobredouraremos": "sobredourar",
    "sobredourares": "sobredourar",
    "sobredouraria": "sobredourar",
    "sobredourariam": "sobredourar",
    "sobredourarias": "sobredourar",
    "sobredourarmo": "sobredourar",
    "sobredourarmos": "sobredourar",
    "sobredourará": "sobredourar",
    "sobredourarás": "sobredourar",
    "sobredourarão": "sobredourar",
    "sobredouraríamos": "sobredourar",
    "sobredouraríeis": "sobredourar",
    "sobredouras": "sobredourar",
    "sobredourasse": "sobredourar",
    "sobredourassem": "sobredourar",
    "sobredourasses": "sobredourar",
    "sobredouraste": "sobredourar",
    "sobredourastes": "sobredourar",
    "sobredourava": "sobredourar",
    "sobredouravam": "sobredourar",
    "sobredouravas": "sobredourar",
    "sobredoure": "sobredourar",
    "sobredourei": "sobredourar",
    "sobredoureis": "sobredourar",
    "sobredourem": "sobredourar",
    "sobredouremo": "sobredourar",
    "sobredouremos": "sobredourar",
    "sobredoures": "sobredourar",
    "sobredouro": "sobredourar",
    "sobredourou": "sobredourar",
    "sobredourá": "sobredourar",
    "sobredourámo": "sobredourar",
    "sobredourámos": "sobredourar",
    "sobredouráramo": "sobredourar",
    "sobredouráramos": "sobredourar",
    "sobredourárei": "sobredourar",
    "sobredouráreis": "sobredourar",
    "sobredourásseis": "sobredourar",
    "sobredourássemos": "sobredourar",
    "sobredourávamo": "sobredourar",
    "sobredourávamos": "sobredourar",
    "sobredourávei": "sobredourar",
    "sobredouráveis": "sobredourar",
    "sobree": "sobreir",
    "sobreem": "sobreir",
    "sobreeminentes": "sobreeminente",
    "sobreeminências": "sobreeminência",
    "sobreemissões": "sobreemissão",
    "sobreendividamentos": "sobreendividamento",
    "sobreera": "sobresser",
    "sobreeram": "sobresser",
    "sobreeras": "sobresser",
    "sobreerga": "sobreerguer",
    "sobreergais": "sobreerguer",
    "sobreergam": "sobreerguer",
    "sobreergamo": "sobreerguer",
    "sobreergamos": "sobreerguer",
    "sobreergas": "sobreerguer",
    "sobreergo": "sobreerguer",
    "sobreergue": "sobreerguer",
    "sobreerguei": "sobreerguer",
    "sobreergueis": "sobreerguer",
    "sobreerguem": "sobreerguer",
    "sobreerguemo": "sobreerguer",
    "sobreerguemos": "sobreerguer",
    "sobreerguendo": "sobreerguer",
    "sobreerguera": "sobreerguer",
    "sobreergueram": "sobreerguer",
    "sobreergueras": "sobreerguer",
    "sobreerguerde": "sobreerguer",
    "sobreerguerdes": "sobreerguer",
    "sobreerguere": "sobreerguer",
    "sobreerguerei": "sobreerguer",
    "sobreerguereis": "sobreerguer",
    "sobreerguerem": "sobreerguer",
    "sobreergueremos": "sobreerguer",
    "sobreergueres": "sobreerguer",
    "sobreergueria": "sobreerguer",
    "sobreergueriam": "sobreerguer",
    "sobreerguerias": "sobreerguer",
    "sobreerguermo": "sobreerguer",
    "sobreerguermos": "sobreerguer",
    "sobreerguerá": "sobreerguer",
    "sobreerguerás": "sobreerguer",
    "sobreerguerão": "sobreerguer",
    "sobreergueríamos": "sobreerguer",
    "sobreergueríeis": "sobreerguer",
    "sobreergues": "sobreerguer",
    "sobreerguesse": "sobreerguer",
    "sobreerguessem": "sobreerguer",
    "sobreerguesses": "sobreerguer",
    "sobreergueste": "sobreerguer",
    "sobreerguestes": "sobreerguer",
    "sobreergueu": "sobreerguer",
    "sobreergui": "sobreerguer",
    "sobreerguia": "sobreerguer",
    "sobreerguiam": "sobreerguer",
    "sobreerguias": "sobreerguer",
    "sobreerguida": "sobreerguer",
    "sobreerguidas": "sobreerguer",
    "sobreerguido": "sobreerguer",
    "sobreerguidos": "sobreerguer",
    "sobreerguê": "sobreerguer",
    "sobreerguêramo": "sobreerguer",
    "sobreerguêramos": "sobreerguer",
    "sobreerguêrei": "sobreerguer",
    "sobreerguêreis": "sobreerguer",
    "sobreerguêsseis": "sobreerguer",
    "sobreerguêssemos": "sobreerguer",
    "sobreerguíamo": "sobreerguer",
    "sobreerguíamos": "sobreerguer",
    "sobreerguíei": "sobreerguer",
    "sobreerguíeis": "sobreerguer",
    "sobrees": "sobreir",
    "sobreestadias": "sobreestadia",
    "sobreexalta": "sobreexaltar",
    "sobreexaltada": "sobreexaltar",
    "sobreexaltadas": "sobreexaltar",
    "sobreexaltado": "sobreexaltar",
    "sobreexaltados": "sobreexaltar",
    "sobreexaltai": "sobreexaltar",
    "sobreexaltais": "sobreexaltar",
    "sobreexaltam": "sobreexaltar",
    "sobreexaltamo": "sobreexaltar",
    "sobreexaltamos": "sobreexaltar",
    "sobreexaltando": "sobreexaltar",
    "sobreexaltara": "sobreexaltar",
    "sobreexaltaram": "sobreexaltar",
    "sobreexaltaras": "sobreexaltar",
    "sobreexaltarde": "sobreexaltar",
    "sobreexaltardes": "sobreexaltar",
    "sobreexaltare": "sobreexaltar",
    "sobreexaltarei": "sobreexaltar",
    "sobreexaltareis": "sobreexaltar",
    "sobreexaltarem": "sobreexaltar",
    "sobreexaltaremos": "sobreexaltar",
    "sobreexaltares": "sobreexaltar",
    "sobreexaltaria": "sobreexaltar",
    "sobreexaltariam": "sobreexaltar",
    "sobreexaltarias": "sobreexaltar",
    "sobreexaltarmo": "sobreexaltar",
    "sobreexaltarmos": "sobreexaltar",
    "sobreexaltará": "sobreexaltar",
    "sobreexaltarás": "sobreexaltar",
    "sobreexaltarão": "sobreexaltar",
    "sobreexaltaríamos": "sobreexaltar",
    "sobreexaltaríeis": "sobreexaltar",
    "sobreexaltas": "sobreexaltar",
    "sobreexaltasse": "sobreexaltar",
    "sobreexaltassem": "sobreexaltar",
    "sobreexaltasses": "sobreexaltar",
    "sobreexaltaste": "sobreexaltar",
    "sobreexaltastes": "sobreexaltar",
    "sobreexaltava": "sobreexaltar",
    "sobreexaltavam": "sobreexaltar",
    "sobreexaltavas": "sobreexaltar",
    "sobreexaltações": "sobreexaltação",
    "sobreexalte": "sobreexaltar",
    "sobreexaltei": "sobreexaltar",
    "sobreexalteis": "sobreexaltar",
    "sobreexaltem": "sobreexaltar",
    "sobreexaltemo": "sobreexaltar",
    "sobreexaltemos": "sobreexaltar",
    "sobreexaltes": "sobreexaltar",
    "sobreexalto": "sobreexaltar",
    "sobreexaltou": "sobreexaltar",
    "sobreexaltá": "sobreexaltar",
    "sobreexaltámo": "sobreexaltar",
    "sobreexaltámos": "sobreexaltar",
    "sobreexaltáramo": "sobreexaltar",
    "sobreexaltáramos": "sobreexaltar",
    "sobreexaltárei": "sobreexaltar",
    "sobreexaltáreis": "sobreexaltar",
    "sobreexaltásseis": "sobreexaltar",
    "sobreexaltássemos": "sobreexaltar",
    "sobreexaltávamo": "sobreexaltar",
    "sobreexaltávamos": "sobreexaltar",
    "sobreexaltávei": "sobreexaltar",
    "sobreexaltáveis": "sobreexaltar",
    "sobreexceda": "sobreexceder",
    "sobreexcedais": "sobreexceder",
    "sobreexcedam": "sobreexceder",
    "sobreexcedamo": "sobreexceder",
    "sobreexcedamos": "sobreexceder",
    "sobreexcedas": "sobreexceder",
    "sobreexcede": "sobreexceder",
    "sobreexcedei": "sobreexceder",
    "sobreexcedeis": "sobreexceder",
    "sobreexcedem": "sobreexceder",
    "sobreexcedemo": "sobreexceder",
    "sobreexcedemos": "sobreexceder",
    "sobreexcedendo": "sobreexceder",
    "sobreexcedentes": "sobreexcedente",
    "sobreexcedera": "sobreexceder",
    "sobreexcederam": "sobreexceder",
    "sobreexcederas": "sobreexceder",
    "sobreexcederde": "sobreexceder",
    "sobreexcederdes": "sobreexceder",
    "sobreexcedere": "sobreexceder",
    "sobreexcederei": "sobreexceder",
    "sobreexcedereis": "sobreexceder",
    "sobreexcederem": "sobreexceder",
    "sobreexcederemos": "sobreexceder",
    "sobreexcederes": "sobreexceder",
    "sobreexcederia": "sobreexceder",
    "sobreexcederiam": "sobreexceder",
    "sobreexcederias": "sobreexceder",
    "sobreexcedermo": "sobreexceder",
    "sobreexcedermos": "sobreexceder",
    "sobreexcederá": "sobreexceder",
    "sobreexcederás": "sobreexceder",
    "sobreexcederão": "sobreexceder",
    "sobreexcederíamos": "sobreexceder",
    "sobreexcederíeis": "sobreexceder",
    "sobreexcedes": "sobreexceder",
    "sobreexcedesse": "sobreexceder",
    "sobreexcedessem": "sobreexceder",
    "sobreexcedesses": "sobreexceder",
    "sobreexcedeste": "sobreexceder",
    "sobreexcedestes": "sobreexceder",
    "sobreexcedeu": "sobreexceder",
    "sobreexcedi": "sobreexceder",
    "sobreexcedia": "sobreexceder",
    "sobreexcediam": "sobreexceder",
    "sobreexcedias": "sobreexceder",
    "sobreexcedida": "sobreexceder",
    "sobreexcedidas": "sobreexceder",
    "sobreexcedido": "sobreexceder",
    "sobreexcedidos": "sobreexceder",
    "sobreexcedo": "sobreexceder",
    "sobreexcedê": "sobreexceder",
    "sobreexcedêramo": "sobreexceder",
    "sobreexcedêramos": "sobreexceder",
    "sobreexcedêrei": "sobreexceder",
    "sobreexcedêreis": "sobreexceder",
    "sobreexcedêsseis": "sobreexceder",
    "sobreexcedêssemos": "sobreexceder",
    "sobreexcedíamo": "sobreexceder",
    "sobreexcedíamos": "sobreexceder",
    "sobreexcedíei": "sobreexceder",
    "sobreexcedíeis": "sobreexceder",
    "sobreexcelentes": "sobreexcelente",
    "sobreexcelências": "sobreexcelência",
    "sobreexcita": "sobreexcitar",
    "sobreexcitada": "sobreexcitar",
    "sobreexcitadas": "sobreexcitar",
    "sobreexcitado": "sobreexcitar",
    "sobreexcitados": "sobreexcitar",
    "sobreexcitai": "sobreexcitar",
    "sobreexcitais": "sobreexcitar",
    "sobreexcitam": "sobreexcitar",
    "sobreexcitamo": "sobreexcitar",
    "sobreexcitamos": "sobreexcitar",
    "sobreexcitando": "sobreexcitar",
    "sobreexcitara": "sobreexcitar",
    "sobreexcitaram": "sobreexcitar",
    "sobreexcitaras": "sobreexcitar",
    "sobreexcitarde": "sobreexcitar",
    "sobreexcitardes": "sobreexcitar",
    "sobreexcitare": "sobreexcitar",
    "sobreexcitarei": "sobreexcitar",
    "sobreexcitareis": "sobreexcitar",
    "sobreexcitarem": "sobreexcitar",
    "sobreexcitaremos": "sobreexcitar",
    "sobreexcitares": "sobreexcitar",
    "sobreexcitaria": "sobreexcitar",
    "sobreexcitariam": "sobreexcitar",
    "sobreexcitarias": "sobreexcitar",
    "sobreexcitarmo": "sobreexcitar",
    "sobreexcitarmos": "sobreexcitar",
    "sobreexcitará": "sobreexcitar",
    "sobreexcitarás": "sobreexcitar",
    "sobreexcitarão": "sobreexcitar",
    "sobreexcitaríamos": "sobreexcitar",
    "sobreexcitaríeis": "sobreexcitar",
    "sobreexcitas": "sobreexcitar",
    "sobreexcitasse": "sobreexcitar",
    "sobreexcitassem": "sobreexcitar",
    "sobreexcitasses": "sobreexcitar",
    "sobreexcitaste": "sobreexcitar",
    "sobreexcitastes": "sobreexcitar",
    "sobreexcitava": "sobreexcitar",
    "sobreexcitavam": "sobreexcitar",
    "sobreexcitavas": "sobreexcitar",
    "sobreexcitações": "sobreexcitação",
    "sobreexcite": "sobreexcitar",
    "sobreexcitei": "sobreexcitar",
    "sobreexciteis": "sobreexcitar",
    "sobreexcitem": "sobreexcitar",
    "sobreexcitemo": "sobreexcitar",
    "sobreexcitemos": "sobreexcitar",
    "sobreexcites": "sobreexcitar",
    "sobreexcito": "sobreexcitar",
    "sobreexcitou": "sobreexcitar",
    "sobreexcitá": "sobreexcitar",
    "sobreexcitámo": "sobreexcitar",
    "sobreexcitámos": "sobreexcitar",
    "sobreexcitáramo": "sobreexcitar",
    "sobreexcitáramos": "sobreexcitar",
    "sobreexcitárei": "sobreexcitar",
    "sobreexcitáreis": "sobreexcitar",
    "sobreexcitásseis": "sobreexcitar",
    "sobreexcitássemos": "sobreexcitar",
    "sobreexcitávamo": "sobreexcitar",
    "sobreexcitávamos": "sobreexcitar",
    "sobreexcitávei": "sobreexcitar",
    "sobreexcitáveis": "sobreexcitar",
    "sobrefacturações": "sobrefacturação",
    "sobrefoi": "sobresser",
    "sobrefoliácea": "sobrefoliáceo",
    "sobrefoliáceas": "sobrefoliáceo",
    "sobrefoliáceos": "sobrefoliáceo",
    "sobrefomo": "sobresser",
    "sobrefomos": "sobresser",
    "sobrefor": "sobresser",
    "sobrefora": "sobresser",
    "sobreforam": "sobresser",
    "sobreforas": "sobresser",
    "sobrefordes": "sobresser",
    "sobreforem": "sobresser",
    "sobrefores": "sobresser",
    "sobreformos": "sobresser",
    "sobrefosse": "sobresser",
    "sobrefossem": "sobresser",
    "sobrefosses": "sobresser",
    "sobrefoste": "sobresser",
    "sobrefostes": "sobresser",
    "sobrefui": "sobresser",
    "sobrefusões": "sobrefusão",
    "sobrefôramo": "sobresser",
    "sobrefôramos": "sobresser",
    "sobrefôrei": "sobresser",
    "sobrefôreis": "sobresser",
    "sobrefôsseis": "sobresser",
    "sobrefôssemos": "sobresser",
    "sobregatas": "sobregata",
    "sobregatinhas": "sobregatinha",
    "sobregovernos": "sobregoverno",
    "sobregáveas": "sobregávea",
    "sobrei": "sobreir",
    "sobreia": "sobreir",
    "sobreiam": "sobreir",
    "sobreias": "sobreir",
    "sobreida": "sobreir",
    "sobreidas": "sobreir",
    "sobreido": "sobreir",
    "sobreidos": "sobreir",
    "sobreimo": "sobreir",
    "sobreimos": "sobreir",
    "sobreindo": "sobreir",
    "sobreintenda": "sobreintender",
    "sobreintendais": "sobreintender",
    "sobreintendam": "sobreintender",
    "sobreintendamo": "sobreintender",
    "sobreintendamos": "sobreintender",
    "sobreintendas": "sobreintender",
    "sobreintende": "sobreintender",
    "sobreintendei": "sobreintender",
    "sobreintendeis": "sobreintender",
    "sobreintendem": "sobreintender",
    "sobreintendemo": "sobreintender",
    "sobreintendemos": "sobreintender",
    "sobreintendendo": "sobreintender",
    "sobreintendentes": "sobreintendente",
    "sobreintendera": "sobreintender",
    "sobreintenderam": "sobreintender",
    "sobreintenderas": "sobreintender",
    "sobreintenderdes": "sobreintender",
    "sobreintenderei": "sobreintender",
    "sobreintendereis": "sobreintender",
    "sobreintenderem": "sobreintender",
    "sobreintenderemos": "sobreintender",
    "sobreintenderes": "sobreintender",
    "sobreintenderia": "sobreintender",
    "sobreintenderiam": "sobreintender",
    "sobreintenderias": "sobreintender",
    "sobreintendermo": "sobreintender",
    "sobreintendermos": "sobreintender",
    "sobreintenderá": "sobreintender",
    "sobreintenderás": "sobreintender",
    "sobreintenderão": "sobreintender",
    "sobreintenderíamos": "sobreintender",
    "sobreintenderíeis": "sobreintender",
    "sobreintendes": "sobreintender",
    "sobreintendesse": "sobreintender",
    "sobreintendessem": "sobreintender",
    "sobreintendesses": "sobreintender",
    "sobreintendeste": "sobreintender",
    "sobreintendestes": "sobreintender",
    "sobreintendeu": "sobreintender",
    "sobreintendi": "sobreintender",
    "sobreintendia": "sobreintender",
    "sobreintendiam": "sobreintender",
    "sobreintendias": "sobreintender",
    "sobreintendida": "sobreintender",
    "sobreintendidas": "sobreintender",
    "sobreintendido": "sobreintender",
    "sobreintendidos": "sobreintender",
    "sobreintendo": "sobreintender",
    "sobreintendêramo": "sobreintender",
    "sobreintendêramos": "sobreintender",
    "sobreintendêreis": "sobreintender",
    "sobreintendêsseis": "sobreintender",
    "sobreintendêssemos": "sobreintender",
    "sobreintendíamo": "sobreintender",
    "sobreintendíamos": "sobreintender",
    "sobreintendíeis": "sobreintender",
    "sobreintendíveis": "sobreintendível",
    "sobreira": "sobreir",
    "sobreirais": "sobreiral",
    "sobreiram": "sobreir",
    "sobreiras": "sobreira",
    "sobreirdes": "sobreir",
    "sobreirei": "sobreir",
    "sobreireis": "sobreir",
    "sobreirem": "sobreir",
    "sobreiremos": "sobreir",
    "sobreires": "sobreir",
    "sobreiria": "sobreir",
    "sobreiriam": "sobreir",
    "sobreirias": "sobreir",
    "sobreirmo": "sobreir",
    "sobreirmos": "sobreir",
    "sobreiros": "sobreiro",
    "sobreirrita": "sobreirritar",
    "sobreirritada": "sobreirritar",
    "sobreirritadas": "sobreirritar",
    "sobreirritado": "sobreirritar",
    "sobreirritados": "sobreirritar",
    "sobreirritai": "sobreirritar",
    "sobreirritais": "sobreirritar",
    "sobreirritam": "sobreirritar",
    "sobreirritamo": "sobreirritar",
    "sobreirritamos": "sobreirritar",
    "sobreirritando": "sobreirritar",
    "sobreirritara": "sobreirritar",
    "sobreirritaram": "sobreirritar",
    "sobreirritaras": "sobreirritar",
    "sobreirritarde": "sobreirritar",
    "sobreirritardes": "sobreirritar",
    "sobreirritare": "sobreirritar",
    "sobreirritarei": "sobreirritar",
    "sobreirritareis": "sobreirritar",
    "sobreirritarem": "sobreirritar",
    "sobreirritaremos": "sobreirritar",
    "sobreirritares": "sobreirritar",
    "sobreirritaria": "sobreirritar",
    "sobreirritariam": "sobreirritar",
    "sobreirritarias": "sobreirritar",
    "sobreirritarmo": "sobreirritar",
    "sobreirritarmos": "sobreirritar",
    "sobreirritará": "sobreirritar",
    "sobreirritarás": "sobreirritar",
    "sobreirritarão": "sobreirritar",
    "sobreirritaríamos": "sobreirritar",
    "sobreirritaríeis": "sobreirritar",
    "sobreirritas": "sobreirritar",
    "sobreirritasse": "sobreirritar",
    "sobreirritassem": "sobreirritar",
    "sobreirritasses": "sobreirritar",
    "sobreirritaste": "sobreirritar",
    "sobreirritastes": "sobreirritar",
    "sobreirritava": "sobreirritar",
    "sobreirritavam": "sobreirritar",
    "sobreirritavas": "sobreirritar",
    "sobreirrite": "sobreirritar",
    "sobreirritei": "sobreirritar",
    "sobreirriteis": "sobreirritar",
    "sobreirritem": "sobreirritar",
    "sobreirritemo": "sobreirritar",
    "sobreirritemos": "sobreirritar",
    "sobreirrites": "sobreirritar",
    "sobreirrito": "sobreirritar",
    "sobreirritou": "sobreirritar",
    "sobreirritá": "sobreirritar",
    "sobreirritámo": "sobreirritar",
    "sobreirritámos": "sobreirritar",
    "sobreirritáramo": "sobreirritar",
    "sobreirritáramos": "sobreirritar",
    "sobreirritárei": "sobreirritar",
    "sobreirritáreis": "sobreirritar",
    "sobreirritásseis": "sobreirritar",
    "sobreirritássemos": "sobreirritar",
    "sobreirritávamo": "sobreirritar",
    "sobreirritávamos": "sobreirritar",
    "sobreirritávei": "sobreirritar",
    "sobreirritáveis": "sobreirritar",
    "sobreirá": "sobreir",
    "sobreirás": "sobreir",
    "sobreirão": "sobreir",
    "sobreiríamos": "sobreir",
    "sobreiríeis": "sobreir",
    "sobreis": "sobreir",
    "sobreisse": "sobreir",
    "sobreissem": "sobreir",
    "sobreisses": "sobreir",
    "sobreiste": "sobreir",
    "sobreistes": "sobreir",
    "sobreiu": "sobreir",
    "sobrejacentes": "sobrejacente",
    "sobrejecções": "sobrejecção",
    "sobrejoanetes": "sobrejoanete",
    "sobrejoanetinhos": "sobrejoanetinho",
    "sobrelanços": "sobrelanço",
    "sobreleitos": "sobreleito",
    "sobreleva": "sobrelevar",
    "sobrelevada": "sobrelevar",
    "sobrelevadas": "sobrelevar",
    "sobrelevado": "sobrelevar",
    "sobrelevados": "sobrelevar",
    "sobrelevai": "sobrelevar",
    "sobrelevais": "sobrelevar",
    "sobrelevam": "sobrelevar",
    "sobrelevamo": "sobrelevar",
    "sobrelevamos": "sobrelevar",
    "sobrelevando": "sobrelevar",
    "sobrelevantes": "sobrelevante",
    "sobrelevara": "sobrelevar",
    "sobrelevaram": "sobrelevar",
    "sobrelevaras": "sobrelevar",
    "sobrelevarde": "sobrelevar",
    "sobrelevardes": "sobrelevar",
    "sobrelevare": "sobrelevar",
    "sobrelevarei": "sobrelevar",
    "sobrelevareis": "sobrelevar",
    "sobrelevarem": "sobrelevar",
    "sobrelevaremos": "sobrelevar",
    "sobrelevares": "sobrelevar",
    "sobrelevaria": "sobrelevar",
    "sobrelevariam": "sobrelevar",
    "sobrelevarias": "sobrelevar",
    "sobrelevarmo": "sobrelevar",
    "sobrelevarmos": "sobrelevar",
    "sobrelevará": "sobrelevar",
    "sobrelevarás": "sobrelevar",
    "sobrelevarão": "sobrelevar",
    "sobrelevaríamos": "sobrelevar",
    "sobrelevaríeis": "sobrelevar",
    "sobrelevas": "sobrelevar",
    "sobrelevasse": "sobrelevar",
    "sobrelevassem": "sobrelevar",
    "sobrelevasses": "sobrelevar",
    "sobrelevaste": "sobrelevar",
    "sobrelevastes": "sobrelevar",
    "sobrelevava": "sobrelevar",
    "sobrelevavam": "sobrelevar",
    "sobrelevavas": "sobrelevar",
    "sobreleve": "sobrelevar",
    "sobrelevei": "sobrelevar",
    "sobreleveis": "sobrelevar",
    "sobrelevem": "sobrelevar",
    "sobrelevemo": "sobrelevar",
    "sobrelevemos": "sobrelevar",
    "sobreleves": "sobrelevar",
    "sobrelevo": "sobrelevar",
    "sobrelevou": "sobrelevar",
    "sobrelevá": "sobrelevar",
    "sobrelevámo": "sobrelevar",
    "sobrelevámos": "sobrelevar",
    "sobreleváramo": "sobrelevar",
    "sobreleváramos": "sobrelevar",
    "sobrelevárei": "sobrelevar",
    "sobreleváreis": "sobrelevar",
    "sobrelevásseis": "sobrelevar",
    "sobrelevássemos": "sobrelevar",
    "sobrelevávamo": "sobrelevar",
    "sobrelevávamos": "sobrelevar",
    "sobrelevávei": "sobrelevar",
    "sobreleváveis": "sobrelevar",
    "sobreliminares": "sobreliminar",
    "sobrelojas": "sobreloja",
    "sobrelotada": "sobrelotado",
    "sobrelotadas": "sobrelotado",
    "sobrelotados": "sobrelotado",
    "sobrelotações": "sobrelotação",
    "sobreluz": "sobreluzir",
    "sobreluza": "sobreluzir",
    "sobreluzais": "sobreluzir",
    "sobreluzam": "sobreluzir",
    "sobreluzamo": "sobreluzir",
    "sobreluzamos": "sobreluzir",
    "sobreluzas": "sobreluzir",
    "sobreluze": "sobreluzir",
    "sobreluzem": "sobreluzir",
    "sobreluzes": "sobreluzir",
    "sobreluzi": "sobreluzir",
    "sobreluzia": "sobreluzir",
    "sobreluziam": "sobreluzir",
    "sobreluzias": "sobreluzir",
    "sobreluzida": "sobreluzir",
    "sobreluzidas": "sobreluzir",
    "sobreluzido": "sobreluzir",
    "sobreluzidos": "sobreluzir",
    "sobreluzimo": "sobreluzir",
    "sobreluzimos": "sobreluzir",
    "sobreluzindo": "sobreluzir",
    "sobreluzira": "sobreluzir",
    "sobreluziram": "sobreluzir",
    "sobreluziras": "sobreluzir",
    "sobreluzirdes": "sobreluzir",
    "sobreluzirei": "sobreluzir",
    "sobreluzireis": "sobreluzir",
    "sobreluzirem": "sobreluzir",
    "sobreluziremos": "sobreluzir",
    "sobreluzires": "sobreluzir",
    "sobreluziria": "sobreluzir",
    "sobreluziriam": "sobreluzir",
    "sobreluzirias": "sobreluzir",
    "sobreluzirmo": "sobreluzir",
    "sobreluzirmos": "sobreluzir",
    "sobreluzirá": "sobreluzir",
    "sobreluzirás": "sobreluzir",
    "sobreluzirão": "sobreluzir",
    "sobreluziríamos": "sobreluzir",
    "sobreluziríeis": "sobreluzir",
    "sobreluzis": "sobreluzir",
    "sobreluzisse": "sobreluzir",
    "sobreluzissem": "sobreluzir",
    "sobreluzisses": "sobreluzir",
    "sobreluziste": "sobreluzir",
    "sobreluzistes": "sobreluzir",
    "sobreluziu": "sobreluzir",
    "sobreluzo": "sobreluzir",
    "sobreluzíamo": "sobreluzir",
    "sobreluzíamos": "sobreluzir",
    "sobreluzíeis": "sobreluzir",
    "sobreluzíramo": "sobreluzir",
    "sobreluzíramos": "sobreluzir",
    "sobreluzíreis": "sobreluzir",
    "sobreluzísseis": "sobreluzir",
    "sobreluzíssemos": "sobreluzir",
    "sobrelábios": "sobrelábio",
    "sobrem": "sobrar",
    "sobremanhãs": "sobremanhã",
    "sobremaravilha": "sobremaravilhar",
    "sobremaravilhada": "sobremaravilhar",
    "sobremaravilhadas": "sobremaravilhar",
    "sobremaravilhado": "sobremaravilhar",
    "sobremaravilhados": "sobremaravilhar",
    "sobremaravilhai": "sobremaravilhar",
    "sobremaravilhais": "sobremaravilhar",
    "sobremaravilham": "sobremaravilhar",
    "sobremaravilhamo": "sobremaravilhar",
    "sobremaravilhamos": "sobremaravilhar",
    "sobremaravilhando": "sobremaravilhar",
    "sobremaravilhara": "sobremaravilhar",
    "sobremaravilharam": "sobremaravilhar",
    "sobremaravilharas": "sobremaravilhar",
    "sobremaravilharde": "sobremaravilhar",
    "sobremaravilhardes": "sobremaravilhar",
    "sobremaravilhare": "sobremaravilhar",
    "sobremaravilharei": "sobremaravilhar",
    "sobremaravilhareis": "sobremaravilhar",
    "sobremaravilharem": "sobremaravilhar",
    "sobremaravilharemos": "sobremaravilhar",
    "sobremaravilhares": "sobremaravilhar",
    "sobremaravilharia": "sobremaravilhar",
    "sobremaravilhariam": "sobremaravilhar",
    "sobremaravilharias": "sobremaravilhar",
    "sobremaravilharmo": "sobremaravilhar",
    "sobremaravilharmos": "sobremaravilhar",
    "sobremaravilhará": "sobremaravilhar",
    "sobremaravilharás": "sobremaravilhar",
    "sobremaravilharão": "sobremaravilhar",
    "sobremaravilharíamos": "sobremaravilhar",
    "sobremaravilharíeis": "sobremaravilhar",
    "sobremaravilhas": "sobremaravilhar",
    "sobremaravilhasse": "sobremaravilhar",
    "sobremaravilhassem": "sobremaravilhar",
    "sobremaravilhasses": "sobremaravilhar",
    "sobremaravilhaste": "sobremaravilhar",
    "sobremaravilhastes": "sobremaravilhar",
    "sobremaravilhava": "sobremaravilhar",
    "sobremaravilhavam": "sobremaravilhar",
    "sobremaravilhavas": "sobremaravilhar",
    "sobremaravilhe": "sobremaravilhar",
    "sobremaravilhei": "sobremaravilhar",
    "sobremaravilheis": "sobremaravilhar",
    "sobremaravilhem": "sobremaravilhar",
    "sobremaravilhemo": "sobremaravilhar",
    "sobremaravilhemos": "sobremaravilhar",
    "sobremaravilhes": "sobremaravilhar",
    "sobremaravilho": "sobremaravilhar",
    "sobremaravilhou": "sobremaravilhar",
    "sobremaravilhá": "sobremaravilhar",
    "sobremaravilhámo": "sobremaravilhar",
    "sobremaravilhámos": "sobremaravilhar",
    "sobremaravilháramo": "sobremaravilhar",
    "sobremaravilháramos": "sobremaravilhar",
    "sobremaravilhárei": "sobremaravilhar",
    "sobremaravilháreis": "sobremaravilhar",
    "sobremaravilhásseis": "sobremaravilhar",
    "sobremaravilhássemos": "sobremaravilhar",
    "sobremaravilhávamo": "sobremaravilhar",
    "sobremaravilhávamos": "sobremaravilhar",
    "sobremaravilhávei": "sobremaravilhar",
    "sobremaravilháveis": "sobremaravilhar",
    "sobremesas": "sobremesa",
    "sobremo": "sobrar",
    "sobremos": "sobrar",
    "sobremunhoneiras": "sobremunhoneira",
    "sobremãos": "sobremão",
    "sobrenada": "sobrenadar",
    "sobrenadada": "sobrenadar",
    "sobrenadadas": "sobrenadar",
    "sobrenadado": "sobrenadar",
    "sobrenadados": "sobrenadar",
    "sobrenadai": "sobrenadar",
    "sobrenadais": "sobrenadar",
    "sobrenadam": "sobrenadar",
    "sobrenadamo": "sobrenadar",
    "sobrenadamos": "sobrenadar",
    "sobrenadando": "sobrenadar",
    "sobrenadara": "sobrenadar",
    "sobrenadaram": "sobrenadar",
    "sobrenadaras": "sobrenadar",
    "sobrenadardes": "sobrenadar",
    "sobrenadarei": "sobrenadar",
    "sobrenadareis": "sobrenadar",
    "sobrenadarem": "sobrenadar",
    "sobrenadaremos": "sobrenadar",
    "sobrenadares": "sobrenadar",
    "sobrenadaria": "sobrenadar",
    "sobrenadariam": "sobrenadar",
    "sobrenadarias": "sobrenadar",
    "sobrenadarmo": "sobrenadar",
    "sobrenadarmos": "sobrenadar",
    "sobrenadará": "sobrenadar",
    "sobrenadarás": "sobrenadar",
    "sobrenadarão": "sobrenadar",
    "sobrenadaríamos": "sobrenadar",
    "sobrenadaríeis": "sobrenadar",
    "sobrenadas": "sobrenadar",
    "sobrenadasse": "sobrenadar",
    "sobrenadassem": "sobrenadar",
    "sobrenadasses": "sobrenadar",
    "sobrenadaste": "sobrenadar",
    "sobrenadastes": "sobrenadar",
    "sobrenadava": "sobrenadar",
    "sobrenadavam": "sobrenadar",
    "sobrenadavas": "sobrenadar",
    "sobrenade": "sobrenadar",
    "sobrenadei": "sobrenadar",
    "sobrenadeis": "sobrenadar",
    "sobrenadem": "sobrenadar",
    "sobrenademo": "sobrenadar",
    "sobrenademos": "sobrenadar",
    "sobrenades": "sobrenadar",
    "sobrenado": "sobrenadar",
    "sobrenadou": "sobrenadar",
    "sobrenadámo": "sobrenadar",
    "sobrenadámos": "sobrenadar",
    "sobrenadáramo": "sobrenadar",
    "sobrenadáramos": "sobrenadar",
    "sobrenadáreis": "sobrenadar",
    "sobrenadásseis": "sobrenadar",
    "sobrenadássemos": "sobrenadar",
    "sobrenadávamo": "sobrenadar",
    "sobrenadávamos": "sobrenadar",
    "sobrenadáveis": "sobrenadar",
    "sobrenaturais": "sobrenatural",
    "sobrenaturalidades": "sobrenaturalidade",
    "sobrenaturalismos": "sobrenaturalismo",
    "sobrenaturalistas": "sobrenaturalista",
    "sobrenaturaliza": "sobrenaturalizar",
    "sobrenaturalizada": "sobrenaturalizar",
    "sobrenaturalizadas": "sobrenaturalizar",
    "sobrenaturalizado": "sobrenaturalizar",
    "sobrenaturalizados": "sobrenaturalizar",
    "sobrenaturalizai": "sobrenaturalizar",
    "sobrenaturalizais": "sobrenaturalizar",
    "sobrenaturalizam": "sobrenaturalizar",
    "sobrenaturalizamo": "sobrenaturalizar",
    "sobrenaturalizamos": "sobrenaturalizar",
    "sobrenaturalizando": "sobrenaturalizar",
    "sobrenaturalizara": "sobrenaturalizar",
    "sobrenaturalizaram": "sobrenaturalizar",
    "sobrenaturalizaras": "sobrenaturalizar",
    "sobrenaturalizarde": "sobrenaturalizar",
    "sobrenaturalizardes": "sobrenaturalizar",
    "sobrenaturalizare": "sobrenaturalizar",
    "sobrenaturalizarei": "sobrenaturalizar",
    "sobrenaturalizareis": "sobrenaturalizar",
    "sobrenaturalizarem": "sobrenaturalizar",
    "sobrenaturalizaremos": "sobrenaturalizar",
    "sobrenaturalizares": "sobrenaturalizar",
    "sobrenaturalizaria": "sobrenaturalizar",
    "sobrenaturalizariam": "sobrenaturalizar",
    "sobrenaturalizarias": "sobrenaturalizar",
    "sobrenaturalizarmo": "sobrenaturalizar",
    "sobrenaturalizarmos": "sobrenaturalizar",
    "sobrenaturalizará": "sobrenaturalizar",
    "sobrenaturalizarás": "sobrenaturalizar",
    "sobrenaturalizarão": "sobrenaturalizar",
    "sobrenaturalizaríamos": "sobrenaturalizar",
    "sobrenaturalizaríeis": "sobrenaturalizar",
    "sobrenaturalizas": "sobrenaturalizar",
    "sobrenaturalizasse": "sobrenaturalizar",
    "sobrenaturalizassem": "sobrenaturalizar",
    "sobrenaturalizasses": "sobrenaturalizar",
    "sobrenaturalizaste": "sobrenaturalizar",
    "sobrenaturalizastes": "sobrenaturalizar",
    "sobrenaturalizava": "sobrenaturalizar",
    "sobrenaturalizavam": "sobrenaturalizar",
    "sobrenaturalizavas": "sobrenaturalizar",
    "sobrenaturalize": "sobrenaturalizar",
    "sobrenaturalizei": "sobrenaturalizar",
    "sobrenaturalizeis": "sobrenaturalizar",
    "sobrenaturalizem": "sobrenaturalizar",
    "sobrenaturalizemo": "sobrenaturalizar",
    "sobrenaturalizemos": "sobrenaturalizar",
    "sobrenaturalizes": "sobrenaturalizar",
    "sobrenaturalizo": "sobrenaturalizar",
    "sobrenaturalizou": "sobrenaturalizar",
    "sobrenaturalizá": "sobrenaturalizar",
    "sobrenaturalizámo": "sobrenaturalizar",
    "sobrenaturalizámos": "sobrenaturalizar",
    "sobrenaturalizáramo": "sobrenaturalizar",
    "sobrenaturalizáramos": "sobrenaturalizar",
    "sobrenaturalizárei": "sobrenaturalizar",
    "sobrenaturalizáreis": "sobrenaturalizar",
    "sobrenaturalizásseis": "sobrenaturalizar",
    "sobrenaturalizássemos": "sobrenaturalizar",
    "sobrenaturalizávamo": "sobrenaturalizar",
    "sobrenaturalizávamos": "sobrenaturalizar",
    "sobrenaturalizávei": "sobrenaturalizar",
    "sobrenaturalizáveis": "sobrenaturalizar",
    "sobrenomeada": "sobrenomear",
    "sobrenomeadas": "sobrenomear",
    "sobrenomeado": "sobrenomear",
    "sobrenomeados": "sobrenomear",
    "sobrenomeai": "sobrenomear",
    "sobrenomeais": "sobrenomear",
    "sobrenomeamo": "sobrenomear",
    "sobrenomeamos": "sobrenomear",
    "sobrenomeando": "sobrenomear",
    "sobrenomeara": "sobrenomear",
    "sobrenomearam": "sobrenomear",
    "sobrenomearas": "sobrenomear",
    "sobrenomearde": "sobrenomear",
    "sobrenomeardes": "sobrenomear",
    "sobrenomeare": "sobrenomear",
    "sobrenomearei": "sobrenomear",
    "sobrenomeareis": "sobrenomear",
    "sobrenomearem": "sobrenomear",
    "sobrenomearemos": "sobrenomear",
    "sobrenomeares": "sobrenomear",
    "sobrenomearia": "sobrenomear",
    "sobrenomeariam": "sobrenomear",
    "sobrenomearias": "sobrenomear",
    "sobrenomearmo": "sobrenomear",
    "sobrenomearmos": "sobrenomear",
    "sobrenomeará": "sobrenomear",
    "sobrenomearás": "sobrenomear",
    "sobrenomearão": "sobrenomear",
    "sobrenomearíamos": "sobrenomear",
    "sobrenomearíeis": "sobrenomear",
    "sobrenomeasse": "sobrenomear",
    "sobrenomeassem": "sobrenomear",
    "sobrenomeasses": "sobrenomear",
    "sobrenomeaste": "sobrenomear",
    "sobrenomeastes": "sobrenomear",
    "sobrenomeava": "sobrenomear",
    "sobrenomeavam": "sobrenomear",
    "sobrenomeavas": "sobrenomear",
    "sobrenomeei": "sobrenomear",
    "sobrenomeeis": "sobrenomear",
    "sobrenomeemo": "sobrenomear",
    "sobrenomeemos": "sobrenomear",
    "sobrenomeia": "sobrenomear",
    "sobrenomeiam": "sobrenomear",
    "sobrenomeias": "sobrenomear",
    "sobrenomeie": "sobrenomear",
    "sobrenomeiem": "sobrenomear",
    "sobrenomeies": "sobrenomear",
    "sobrenomeio": "sobrenomear",
    "sobrenomeou": "sobrenomear",
    "sobrenomes": "sobrenome",
    "sobrenomeá": "sobrenomear",
    "sobrenomeámo": "sobrenomear",
    "sobrenomeámos": "sobrenomear",
    "sobrenomeáramo": "sobrenomear",
    "sobrenomeáramos": "sobrenomear",
    "sobrenomeárei": "sobrenomear",
    "sobrenomeáreis": "sobrenomear",
    "sobrenomeásseis": "sobrenomear",
    "sobrenomeássemos": "sobrenomear",
    "sobrenomeávamo": "sobrenomear",
    "sobrenomeávamos": "sobrenomear",
    "sobrenomeávei": "sobrenomear",
    "sobrenomeáveis": "sobrenomear",
    "sobrenumeráveis": "sobrenumerável",
    "sobreo": "sobreir",
    "sobreolha": "sobreolhar",
    "sobreolhada": "sobreolhar",
    "sobreolhadas": "sobreolhar",
    "sobreolhado": "sobreolhar",
    "sobreolhados": "sobreolhar",
    "sobreolhai": "sobreolhar",
    "sobreolhais": "sobreolhar",
    "sobreolham": "sobreolhar",
    "sobreolhamo": "sobreolhar",
    "sobreolhamos": "sobreolhar",
    "sobreolhando": "sobreolhar",
    "sobreolhara": "sobreolhar",
    "sobreolharam": "sobreolhar",
    "sobreolharas": "sobreolhar",
    "sobreolharde": "sobreolhar",
    "sobreolhardes": "sobreolhar",
    "sobreolhare": "sobreolhar",
    "sobreolharei": "sobreolhar",
    "sobreolhareis": "sobreolhar",
    "sobreolharem": "sobreolhar",
    "sobreolharemos": "sobreolhar",
    "sobreolhares": "sobreolhar",
    "sobreolharia": "sobreolhar",
    "sobreolhariam": "sobreolhar",
    "sobreolharias": "sobreolhar",
    "sobreolharmo": "sobreolhar",
    "sobreolharmos": "sobreolhar",
    "sobreolhará": "sobreolhar",
    "sobreolharás": "sobreolhar",
    "sobreolharão": "sobreolhar",
    "sobreolharíamos": "sobreolhar",
    "sobreolharíeis": "sobreolhar",
    "sobreolhas": "sobreolhar",
    "sobreolhasse": "sobreolhar",
    "sobreolhassem": "sobreolhar",
    "sobreolhasses": "sobreolhar",
    "sobreolhaste": "sobreolhar",
    "sobreolhastes": "sobreolhar",
    "sobreolhava": "sobreolhar",
    "sobreolhavam": "sobreolhar",
    "sobreolhavas": "sobreolhar",
    "sobreolhe": "sobreolhar",
    "sobreolhei": "sobreolhar",
    "sobreolheis": "sobreolhar",
    "sobreolhem": "sobreolhar",
    "sobreolhemo": "sobreolhar",
    "sobreolhemos": "sobreolhar",
    "sobreolhes": "sobreolhar",
    "sobreolho": "sobreolhar",
    "sobreolhou": "sobreolhar",
    "sobreolhá": "sobreolhar",
    "sobreolhámo": "sobreolhar",
    "sobreolhámos": "sobreolhar",
    "sobreolháramo": "sobreolhar",
    "sobreolháramos": "sobreolhar",
    "sobreolhárei": "sobreolhar",
    "sobreolháreis": "sobreolhar",
    "sobreolhásseis": "sobreolhar",
    "sobreolhássemos": "sobreolhar",
    "sobreolhávamo": "sobreolhar",
    "sobreolhávamos": "sobreolhar",
    "sobreolhávei": "sobreolhar",
    "sobreolháveis": "sobreolhar",
    "sobreossos": "sobreosso",
    "sobrepagas": "sobrepaga",
    "sobrepaira": "sobrepairar",
    "sobrepairada": "sobrepairar",
    "sobrepairadas": "sobrepairar",
    "sobrepairado": "sobrepairar",
    "sobrepairados": "sobrepairar",
    "sobrepairai": "sobrepairar",
    "sobrepairais": "sobrepairar",
    "sobrepairam": "sobrepairar",
    "sobrepairamo": "sobrepairar",
    "sobrepairamos": "sobrepairar",
    "sobrepairando": "sobrepairar",
    "sobrepairara": "sobrepairar",
    "sobrepairaram": "sobrepairar",
    "sobrepairaras": "sobrepairar",
    "sobrepairardes": "sobrepairar",
    "sobrepairarei": "sobrepairar",
    "sobrepairareis": "sobrepairar",
    "sobrepairarem": "sobrepairar",
    "sobrepairaremos": "sobrepairar",
    "sobrepairares": "sobrepairar",
    "sobrepairaria": "sobrepairar",
    "sobrepairariam": "sobrepairar",
    "sobrepairarias": "sobrepairar",
    "sobrepairarmo": "sobrepairar",
    "sobrepairarmos": "sobrepairar",
    "sobrepairará": "sobrepairar",
    "sobrepairarás": "sobrepairar",
    "sobrepairarão": "sobrepairar",
    "sobrepairaríamos": "sobrepairar",
    "sobrepairaríeis": "sobrepairar",
    "sobrepairas": "sobrepairar",
    "sobrepairasse": "sobrepairar",
    "sobrepairassem": "sobrepairar",
    "sobrepairasses": "sobrepairar",
    "sobrepairaste": "sobrepairar",
    "sobrepairastes": "sobrepairar",
    "sobrepairava": "sobrepairar",
    "sobrepairavam": "sobrepairar",
    "sobrepairavas": "sobrepairar",
    "sobrepaire": "sobrepairar",
    "sobrepairei": "sobrepairar",
    "sobrepaireis": "sobrepairar",
    "sobrepairem": "sobrepairar",
    "sobrepairemo": "sobrepairar",
    "sobrepairemos": "sobrepairar",
    "sobrepaires": "sobrepairar",
    "sobrepairo": "sobrepairar",
    "sobrepairou": "sobrepairar",
    "sobrepairámo": "sobrepairar",
    "sobrepairámos": "sobrepairar",
    "sobrepairáramo": "sobrepairar",
    "sobrepairáramos": "sobrepairar",
    "sobrepairáreis": "sobrepairar",
    "sobrepairásseis": "sobrepairar",
    "sobrepairássemos": "sobrepairar",
    "sobrepairávamo": "sobrepairar",
    "sobrepairávamos": "sobrepairar",
    "sobrepairáveis": "sobrepairar",
    "sobrepartilhas": "sobrepartilha",
    "sobrepartos": "sobreparto",
    "sobrepassos": "sobrepasso",
    "sobrepastos": "sobrepasto",
    "sobrepelizes": "sobrepeliz",
    "sobrepensa": "sobrepensar",
    "sobrepensada": "sobrepensar",
    "sobrepensadas": "sobrepensar",
    "sobrepensado": "sobrepensar",
    "sobrepensados": "sobrepensar",
    "sobrepensai": "sobrepensar",
    "sobrepensais": "sobrepensar",
    "sobrepensam": "sobrepensar",
    "sobrepensamo": "sobrepensar",
    "sobrepensamos": "sobrepensar",
    "sobrepensando": "sobrepensar",
    "sobrepensara": "sobrepensar",
    "sobrepensaram": "sobrepensar",
    "sobrepensaras": "sobrepensar",
    "sobrepensardes": "sobrepensar",
    "sobrepensarei": "sobrepensar",
    "sobrepensareis": "sobrepensar",
    "sobrepensarem": "sobrepensar",
    "sobrepensaremos": "sobrepensar",
    "sobrepensares": "sobrepensar",
    "sobrepensaria": "sobrepensar",
    "sobrepensariam": "sobrepensar",
    "sobrepensarias": "sobrepensar",
    "sobrepensarmo": "sobrepensar",
    "sobrepensarmos": "sobrepensar",
    "sobrepensará": "sobrepensar",
    "sobrepensarás": "sobrepensar",
    "sobrepensarão": "sobrepensar",
    "sobrepensaríamos": "sobrepensar",
    "sobrepensaríeis": "sobrepensar",
    "sobrepensas": "sobrepensar",
    "sobrepensasse": "sobrepensar",
    "sobrepensassem": "sobrepensar",
    "sobrepensasses": "sobrepensar",
    "sobrepensaste": "sobrepensar",
    "sobrepensastes": "sobrepensar",
    "sobrepensava": "sobrepensar",
    "sobrepensavam": "sobrepensar",
    "sobrepensavas": "sobrepensar",
    "sobrepense": "sobrepensar",
    "sobrepensei": "sobrepensar",
    "sobrepenseis": "sobrepensar",
    "sobrepensem": "sobrepensar",
    "sobrepensemo": "sobrepensar",
    "sobrepensemos": "sobrepensar",
    "sobrepenses": "sobrepensar",
    "sobrepenso": "sobrepensar",
    "sobrepensou": "sobrepensar",
    "sobrepensámo": "sobrepensar",
    "sobrepensámos": "sobrepensar",
    "sobrepensáramo": "sobrepensar",
    "sobrepensáramos": "sobrepensar",
    "sobrepensáreis": "sobrepensar",
    "sobrepensásseis": "sobrepensar",
    "sobrepensássemos": "sobrepensar",
    "sobrepensávamo": "sobrepensar",
    "sobrepensávamos": "sobrepensar",
    "sobrepensáveis": "sobrepensar",
    "sobrepesa": "sobrepesar",
    "sobrepesada": "sobrepesar",
    "sobrepesadas": "sobrepesar",
    "sobrepesado": "sobrepesar",
    "sobrepesados": "sobrepesar",
    "sobrepesai": "sobrepesar",
    "sobrepesais": "sobrepesar",
    "sobrepesam": "sobrepesar",
    "sobrepesamo": "sobrepesar",
    "sobrepesamos": "sobrepesar",
    "sobrepesando": "sobrepesar",
    "sobrepesara": "sobrepesar",
    "sobrepesaram": "sobrepesar",
    "sobrepesaras": "sobrepesar",
    "sobrepesarde": "sobrepesar",
    "sobrepesardes": "sobrepesar",
    "sobrepesare": "sobrepesar",
    "sobrepesarei": "sobrepesar",
    "sobrepesareis": "sobrepesar",
    "sobrepesarem": "sobrepesar",
    "sobrepesaremos": "sobrepesar",
    "sobrepesares": "sobrepesar",
    "sobrepesaria": "sobrepesar",
    "sobrepesariam": "sobrepesar",
    "sobrepesarias": "sobrepesar",
    "sobrepesarmo": "sobrepesar",
    "sobrepesarmos": "sobrepesar",
    "sobrepesará": "sobrepesar",
    "sobrepesarás": "sobrepesar",
    "sobrepesarão": "sobrepesar",
    "sobrepesaríamos": "sobrepesar",
    "sobrepesaríeis": "sobrepesar",
    "sobrepesas": "sobrepesar",
    "sobrepesasse": "sobrepesar",
    "sobrepesassem": "sobrepesar",
    "sobrepesasses": "sobrepesar",
    "sobrepesaste": "sobrepesar",
    "sobrepesastes": "sobrepesar",
    "sobrepesava": "sobrepesar",
    "sobrepesavam": "sobrepesar",
    "sobrepesavas": "sobrepesar",
    "sobrepese": "sobrepesar",
    "sobrepesei": "sobrepesar",
    "sobrepeseis": "sobrepesar",
    "sobrepesem": "sobrepesar",
    "sobrepesemo": "sobrepesar",
    "sobrepesemos": "sobrepesar",
    "sobrepeses": "sobrepesar",
    "sobrepeso": "sobrepesar",
    "sobrepesos": "sobrepeso",
    "sobrepesou": "sobrepesar",
    "sobrepesá": "sobrepesar",
    "sobrepesámo": "sobrepesar",
    "sobrepesámos": "sobrepesar",
    "sobrepesáramo": "sobrepesar",
    "sobrepesáramos": "sobrepesar",
    "sobrepesárei": "sobrepesar",
    "sobrepesáreis": "sobrepesar",
    "sobrepesásseis": "sobrepesar",
    "sobrepesássemos": "sobrepesar",
    "sobrepesávamo": "sobrepesar",
    "sobrepesávamos": "sobrepesar",
    "sobrepesávei": "sobrepesar",
    "sobrepesáveis": "sobrepesar",
    "sobrepomo": "sobrepor",
    "sobrepomos": "sobrepor",
    "sobreponde": "sobrepor",
    "sobrepondes": "sobrepor",
    "sobrepondo": "sobrepor",
    "sobreponha": "sobrepor",
    "sobreponhais": "sobrepor",
    "sobreponham": "sobrepor",
    "sobreponhamo": "sobrepor",
    "sobreponhamos": "sobrepor",
    "sobreponhas": "sobrepor",
    "sobreponho": "sobrepor",
    "sobreponíveis": "sobreponível",
    "sobreporde": "sobrepor",
    "sobrepordes": "sobrepor",
    "sobrepore": "sobrepor",
    "sobreporei": "sobrepor",
    "sobreporeis": "sobrepor",
    "sobreporem": "sobrepor",
    "sobreporemos": "sobrepor",
    "sobrepores": "sobrepor",
    "sobreporia": "sobrepor",
    "sobreporiam": "sobrepor",
    "sobreporias": "sobrepor",
    "sobrepormo": "sobrepor",
    "sobrepormos": "sobrepor",
    "sobreportas": "sobreporta",
    "sobreporá": "sobrepor",
    "sobreporás": "sobrepor",
    "sobreporão": "sobrepor",
    "sobreporíamos": "sobrepor",
    "sobreporíeis": "sobrepor",
    "sobreposições": "sobreposição",
    "sobreposta": "sobreposto",
    "sobrepostas": "sobreposto",
    "sobreposto": "sobrepor",
    "sobrepostos": "sobreposto",
    "sobrepovoa": "sobrepovoar",
    "sobrepovoada": "sobrepovoar",
    "sobrepovoadas": "sobrepovoar",
    "sobrepovoado": "sobrepovoar",
    "sobrepovoados": "sobrepovoar",
    "sobrepovoai": "sobrepovoar",
    "sobrepovoais": "sobrepovoar",
    "sobrepovoam": "sobrepovoar",
    "sobrepovoamo": "sobrepovoar",
    "sobrepovoamos": "sobrepovoar",
    "sobrepovoando": "sobrepovoar",
    "sobrepovoara": "sobrepovoar",
    "sobrepovoaram": "sobrepovoar",
    "sobrepovoaras": "sobrepovoar",
    "sobrepovoarde": "sobrepovoar",
    "sobrepovoardes": "sobrepovoar",
    "sobrepovoare": "sobrepovoar",
    "sobrepovoarei": "sobrepovoar",
    "sobrepovoareis": "sobrepovoar",
    "sobrepovoarem": "sobrepovoar",
    "sobrepovoaremos": "sobrepovoar",
    "sobrepovoares": "sobrepovoar",
    "sobrepovoaria": "sobrepovoar",
    "sobrepovoariam": "sobrepovoar",
    "sobrepovoarias": "sobrepovoar",
    "sobrepovoarmo": "sobrepovoar",
    "sobrepovoarmos": "sobrepovoar",
    "sobrepovoará": "sobrepovoar",
    "sobrepovoarás": "sobrepovoar",
    "sobrepovoarão": "sobrepovoar",
    "sobrepovoaríamos": "sobrepovoar",
    "sobrepovoaríeis": "sobrepovoar",
    "sobrepovoas": "sobrepovoar",
    "sobrepovoasse": "sobrepovoar",
    "sobrepovoassem": "sobrepovoar",
    "sobrepovoasses": "sobrepovoar",
    "sobrepovoaste": "sobrepovoar",
    "sobrepovoastes": "sobrepovoar",
    "sobrepovoava": "sobrepovoar",
    "sobrepovoavam": "sobrepovoar",
    "sobrepovoavas": "sobrepovoar",
    "sobrepovoe": "sobrepovoar",
    "sobrepovoei": "sobrepovoar",
    "sobrepovoeis": "sobrepovoar",
    "sobrepovoem": "sobrepovoar",
    "sobrepovoemo": "sobrepovoar",
    "sobrepovoemos": "sobrepovoar",
    "sobrepovoes": "sobrepovoar",
    "sobrepovoo": "sobrepovoar",
    "sobrepovoou": "sobrepovoar",
    "sobrepovoá": "sobrepovoar",
    "sobrepovoámo": "sobrepovoar",
    "sobrepovoámos": "sobrepovoar",
    "sobrepovoáramo": "sobrepovoar",
    "sobrepovoáramos": "sobrepovoar",
    "sobrepovoárei": "sobrepovoar",
    "sobrepovoáreis": "sobrepovoar",
    "sobrepovoásseis": "sobrepovoar",
    "sobrepovoássemos": "sobrepovoar",
    "sobrepovoávamo": "sobrepovoar",
    "sobrepovoávamos": "sobrepovoar",
    "sobrepovoávei": "sobrepovoar",
    "sobrepovoáveis": "sobrepovoar",
    "sobreprateada": "sobrepratear",
    "sobreprateadas": "sobrepratear",
    "sobreprateado": "sobrepratear",
    "sobreprateados": "sobrepratear",
    "sobreprateai": "sobrepratear",
    "sobreprateais": "sobrepratear",
    "sobreprateamo": "sobrepratear",
    "sobreprateamos": "sobrepratear",
    "sobreprateando": "sobrepratear",
    "sobreprateara": "sobrepratear",
    "sobrepratearam": "sobrepratear",
    "sobrepratearas": "sobrepratear",
    "sobrepratearde": "sobrepratear",
    "sobreprateardes": "sobrepratear",
    "sobreprateare": "sobrepratear",
    "sobrepratearei": "sobrepratear",
    "sobreprateareis": "sobrepratear",
    "sobrepratearem": "sobrepratear",
    "sobrepratearemos": "sobrepratear",
    "sobreprateares": "sobrepratear",
    "sobrepratearia": "sobrepratear",
    "sobreprateariam": "sobrepratear",
    "sobrepratearias": "sobrepratear",
    "sobrepratearmo": "sobrepratear",
    "sobrepratearmos": "sobrepratear",
    "sobreprateará": "sobrepratear",
    "sobrepratearás": "sobrepratear",
    "sobrepratearão": "sobrepratear",
    "sobrepratearíamos": "sobrepratear",
    "sobrepratearíeis": "sobrepratear",
    "sobreprateasse": "sobrepratear",
    "sobreprateassem": "sobrepratear",
    "sobreprateasses": "sobrepratear",
    "sobreprateaste": "sobrepratear",
    "sobreprateastes": "sobrepratear",
    "sobreprateava": "sobrepratear",
    "sobreprateavam": "sobrepratear",
    "sobreprateavas": "sobrepratear",
    "sobreprateei": "sobrepratear",
    "sobreprateeis": "sobrepratear",
    "sobreprateemo": "sobrepratear",
    "sobreprateemos": "sobrepratear",
    "sobreprateia": "sobrepratear",
    "sobreprateiam": "sobrepratear",
    "sobreprateias": "sobrepratear",
    "sobreprateie": "sobrepratear",
    "sobreprateiem": "sobrepratear",
    "sobreprateies": "sobrepratear",
    "sobreprateio": "sobrepratear",
    "sobreprateou": "sobrepratear",
    "sobreprateá": "sobrepratear",
    "sobreprateámo": "sobrepratear",
    "sobreprateámos": "sobrepratear",
    "sobreprateáramo": "sobrepratear",
    "sobreprateáramos": "sobrepratear",
    "sobreprateárei": "sobrepratear",
    "sobreprateáreis": "sobrepratear",
    "sobreprateásseis": "sobrepratear",
    "sobreprateássemos": "sobrepratear",
    "sobreprateávamo": "sobrepratear",
    "sobreprateávamos": "sobrepratear",
    "sobreprateávei": "sobrepratear",
    "sobreprateáveis": "sobrepratear",
    "sobreprovas": "sobreprova",
    "sobrepuja": "sobrepujar",
    "sobrepujada": "sobrepujar",
    "sobrepujadas": "sobrepujar",
    "sobrepujado": "sobrepujar",
    "sobrepujados": "sobrepujar",
    "sobrepujai": "sobrepujar",
    "sobrepujais": "sobrepujar",
    "sobrepujam": "sobrepujar",
    "sobrepujamentos": "sobrepujamento",
    "sobrepujamo": "sobrepujar",
    "sobrepujamos": "sobrepujar",
    "sobrepujando": "sobrepujar",
    "sobrepujantes": "sobrepujante",
    "sobrepujanças": "sobrepujança",
    "sobrepujara": "sobrepujar",
    "sobrepujaram": "sobrepujar",
    "sobrepujaras": "sobrepujar",
    "sobrepujarde": "sobrepujar",
    "sobrepujardes": "sobrepujar",
    "sobrepujare": "sobrepujar",
    "sobrepujarei": "sobrepujar",
    "sobrepujareis": "sobrepujar",
    "sobrepujarem": "sobrepujar",
    "sobrepujaremos": "sobrepujar",
    "sobrepujares": "sobrepujar",
    "sobrepujaria": "sobrepujar",
    "sobrepujariam": "sobrepujar",
    "sobrepujarias": "sobrepujar",
    "sobrepujarmo": "sobrepujar",
    "sobrepujarmos": "sobrepujar",
    "sobrepujará": "sobrepujar",
    "sobrepujarás": "sobrepujar",
    "sobrepujarão": "sobrepujar",
    "sobrepujaríamos": "sobrepujar",
    "sobrepujaríeis": "sobrepujar",
    "sobrepujas": "sobrepujar",
    "sobrepujasse": "sobrepujar",
    "sobrepujassem": "sobrepujar",
    "sobrepujasses": "sobrepujar",
    "sobrepujaste": "sobrepujar",
    "sobrepujastes": "sobrepujar",
    "sobrepujava": "sobrepujar",
    "sobrepujavam": "sobrepujar",
    "sobrepujavas": "sobrepujar",
    "sobrepuje": "sobrepujar",
    "sobrepujei": "sobrepujar",
    "sobrepujeis": "sobrepujar",
    "sobrepujem": "sobrepujar",
    "sobrepujemo": "sobrepujar",
    "sobrepujemos": "sobrepujar",
    "sobrepujes": "sobrepujar",
    "sobrepujo": "sobrepujar",
    "sobrepujou": "sobrepujar",
    "sobrepujá": "sobrepujar",
    "sobrepujámo": "sobrepujar",
    "sobrepujámos": "sobrepujar",
    "sobrepujáramo": "sobrepujar",
    "sobrepujáramos": "sobrepujar",
    "sobrepujárei": "sobrepujar",
    "sobrepujáreis": "sobrepujar",
    "sobrepujásseis": "sobrepujar",
    "sobrepujássemos": "sobrepujar",
    "sobrepujávamo": "sobrepujar",
    "sobrepujávamos": "sobrepujar",
    "sobrepujávei": "sobrepujar",
    "sobrepujáveis": "sobrepujar",
    "sobrepunha": "sobrepor",
    "sobrepunham": "sobrepor",
    "sobrepunhas": "sobrepor",
    "sobrepus": "sobrepor",
    "sobrepusemo": "sobrepor",
    "sobrepusemos": "sobrepor",
    "sobrepuser": "sobrepor",
    "sobrepusera": "sobrepor",
    "sobrepuseram": "sobrepor",
    "sobrepuseras": "sobrepor",
    "sobrepuserdes": "sobrepor",
    "sobrepuserem": "sobrepor",
    "sobrepuseres": "sobrepor",
    "sobrepusermos": "sobrepor",
    "sobrepusesse": "sobrepor",
    "sobrepusessem": "sobrepor",
    "sobrepusesses": "sobrepor",
    "sobrepuseste": "sobrepor",
    "sobrepusestes": "sobrepor",
    "sobrepuséramo": "sobrepor",
    "sobrepuséramos": "sobrepor",
    "sobrepusérei": "sobrepor",
    "sobrepuséreis": "sobrepor",
    "sobrepusésseis": "sobrepor",
    "sobrepuséssemos": "sobrepor",
    "sobrepés": "sobrepé",
    "sobrepô": "sobrepor",
    "sobrepôs": "sobrepor",
    "sobrepõe": "sobrepor",
    "sobrepõem": "sobrepor",
    "sobrepões": "sobrepor",
    "sobrepúnhamo": "sobrepor",
    "sobrepúnhamos": "sobrepor",
    "sobrepúnhei": "sobrepor",
    "sobrepúnheis": "sobrepor",
    "sobrequilhas": "sobrequilha",
    "sobrerrenais": "sobrerrenal",
    "sobrerresta": "sobrerrestar",
    "sobrerrestada": "sobrerrestar",
    "sobrerrestadas": "sobrerrestar",
    "sobrerrestado": "sobrerrestar",
    "sobrerrestados": "sobrerrestar",
    "sobrerrestai": "sobrerrestar",
    "sobrerrestais": "sobrerrestar",
    "sobrerrestam": "sobrerrestar",
    "sobrerrestamo": "sobrerrestar",
    "sobrerrestamos": "sobrerrestar",
    "sobrerrestando": "sobrerrestar",
    "sobrerrestara": "sobrerrestar",
    "sobrerrestaram": "sobrerrestar",
    "sobrerrestaras": "sobrerrestar",
    "sobrerrestardes": "sobrerrestar",
    "sobrerrestarei": "sobrerrestar",
    "sobrerrestareis": "sobrerrestar",
    "sobrerrestarem": "sobrerrestar",
    "sobrerrestaremos": "sobrerrestar",
    "sobrerrestares": "sobrerrestar",
    "sobrerrestaria": "sobrerrestar",
    "sobrerrestariam": "sobrerrestar",
    "sobrerrestarias": "sobrerrestar",
    "sobrerrestarmo": "sobrerrestar",
    "sobrerrestarmos": "sobrerrestar",
    "sobrerrestará": "sobrerrestar",
    "sobrerrestarás": "sobrerrestar",
    "sobrerrestarão": "sobrerrestar",
    "sobrerrestaríamos": "sobrerrestar",
    "sobrerrestaríeis": "sobrerrestar",
    "sobrerrestas": "sobrerrestar",
    "sobrerrestasse": "sobrerrestar",
    "sobrerrestassem": "sobrerrestar",
    "sobrerrestasses": "sobrerrestar",
    "sobrerrestaste": "sobrerrestar",
    "sobrerrestastes": "sobrerrestar",
    "sobrerrestava": "sobrerrestar",
    "sobrerrestavam": "sobrerrestar",
    "sobrerrestavas": "sobrerrestar",
    "sobrerreste": "sobrerrestar",
    "sobrerrestei": "sobrerrestar",
    "sobrerresteis": "sobrerrestar",
    "sobrerrestem": "sobrerrestar",
    "sobrerrestemo": "sobrerrestar",
    "sobrerrestemos": "sobrerrestar",
    "sobrerrestes": "sobrerrestar",
    "sobrerresto": "sobrerrestar",
    "sobrerrestou": "sobrerrestar",
    "sobrerrestámo": "sobrerrestar",
    "sobrerrestámos": "sobrerrestar",
    "sobrerrestáramo": "sobrerrestar",
    "sobrerrestáramos": "sobrerrestar",
    "sobrerrestáreis": "sobrerrestar",
    "sobrerrestásseis": "sobrerrestar",
    "sobrerrestássemos": "sobrerrestar",
    "sobrerrestávamo": "sobrerrestar",
    "sobrerrestávamos": "sobrerrestar",
    "sobrerrestáveis": "sobrerrestar",
    "sobrerronda": "sobrerrondar",
    "sobrerrondada": "sobrerrondar",
    "sobrerrondadas": "sobrerrondar",
    "sobrerrondado": "sobrerrondar",
    "sobrerrondados": "sobrerrondar",
    "sobrerrondai": "sobrerrondar",
    "sobrerrondais": "sobrerrondar",
    "sobrerrondam": "sobrerrondar",
    "sobrerrondamo": "sobrerrondar",
    "sobrerrondamos": "sobrerrondar",
    "sobrerrondando": "sobrerrondar",
    "sobrerrondara": "sobrerrondar",
    "sobrerrondaram": "sobrerrondar",
    "sobrerrondaras": "sobrerrondar",
    "sobrerrondarde": "sobrerrondar",
    "sobrerrondardes": "sobrerrondar",
    "sobrerrondare": "sobrerrondar",
    "sobrerrondarei": "sobrerrondar",
    "sobrerrondareis": "sobrerrondar",
    "sobrerrondarem": "sobrerrondar",
    "sobrerrondaremos": "sobrerrondar",
    "sobrerrondares": "sobrerrondar",
    "sobrerrondaria": "sobrerrondar",
    "sobrerrondariam": "sobrerrondar",
    "sobrerrondarias": "sobrerrondar",
    "sobrerrondarmo": "sobrerrondar",
    "sobrerrondarmos": "sobrerrondar",
    "sobrerrondará": "sobrerrondar",
    "sobrerrondarás": "sobrerrondar",
    "sobrerrondarão": "sobrerrondar",
    "sobrerrondaríamos": "sobrerrondar",
    "sobrerrondaríeis": "sobrerrondar",
    "sobrerrondas": "sobrerrondar",
    "sobrerrondasse": "sobrerrondar",
    "sobrerrondassem": "sobrerrondar",
    "sobrerrondasses": "sobrerrondar",
    "sobrerrondaste": "sobrerrondar",
    "sobrerrondastes": "sobrerrondar",
    "sobrerrondava": "sobrerrondar",
    "sobrerrondavam": "sobrerrondar",
    "sobrerrondavas": "sobrerrondar",
    "sobrerronde": "sobrerrondar",
    "sobrerrondei": "sobrerrondar",
    "sobrerrondeis": "sobrerrondar",
    "sobrerrondem": "sobrerrondar",
    "sobrerrondemo": "sobrerrondar",
    "sobrerrondemos": "sobrerrondar",
    "sobrerrondes": "sobrerrondar",
    "sobrerrondo": "sobrerrondar",
    "sobrerrondou": "sobrerrondar",
    "sobrerrondá": "sobrerrondar",
    "sobrerrondámo": "sobrerrondar",
    "sobrerrondámos": "sobrerrondar",
    "sobrerrondáramo": "sobrerrondar",
    "sobrerrondáramos": "sobrerrondar",
    "sobrerrondárei": "sobrerrondar",
    "sobrerrondáreis": "sobrerrondar",
    "sobrerrondásseis": "sobrerrondar",
    "sobrerrondássemos": "sobrerrondar",
    "sobrerrondávamo": "sobrerrondar",
    "sobrerrondávamos": "sobrerrondar",
    "sobrerrondávei": "sobrerrondar",
    "sobrerrondáveis": "sobrerrondar",
    "sobrerrosada": "sobrerrosado",
    "sobrerrosadas": "sobrerrosado",
    "sobrerrosados": "sobrerrosado",
    "sobres": "sobre",
    "sobrescreva": "sobrescrever",
    "sobrescrevais": "sobrescrever",
    "sobrescrevam": "sobrescrever",
    "sobrescrevamo": "sobrescrever",
    "sobrescrevamos": "sobrescrever",
    "sobrescrevas": "sobrescrever",
    "sobrescreve": "sobrescrever",
    "sobrescrevei": "sobrescrever",
    "sobrescreveis": "sobrescrever",
    "sobrescrevem": "sobrescrever",
    "sobrescrevemo": "sobrescrever",
    "sobrescrevemos": "sobrescrever",
    "sobrescrevendo": "sobrescrever",
    "sobrescrevera": "sobrescrever",
    "sobrescreveram": "sobrescrever",
    "sobrescreveras": "sobrescrever",
    "sobrescreverde": "sobrescrever",
    "sobrescreverdes": "sobrescrever",
    "sobrescrevere": "sobrescrever",
    "sobrescreverei": "sobrescrever",
    "sobrescrevereis": "sobrescrever",
    "sobrescreverem": "sobrescrever",
    "sobrescreveremos": "sobrescrever",
    "sobrescreveres": "sobrescrever",
    "sobrescreveria": "sobrescrever",
    "sobrescreveriam": "sobrescrever",
    "sobrescreverias": "sobrescrever",
    "sobrescrevermo": "sobrescrever",
    "sobrescrevermos": "sobrescrever",
    "sobrescreverá": "sobrescrever",
    "sobrescreverás": "sobrescrever",
    "sobrescreverão": "sobrescrever",
    "sobrescreveríamos": "sobrescrever",
    "sobrescreveríeis": "sobrescrever",
    "sobrescreves": "sobrescrever",
    "sobrescrevesse": "sobrescrever",
    "sobrescrevessem": "sobrescrever",
    "sobrescrevesses": "sobrescrever",
    "sobrescreveste": "sobrescrever",
    "sobrescrevestes": "sobrescrever",
    "sobrescreveu": "sobrescrever",
    "sobrescrevi": "sobrescrever",
    "sobrescrevia": "sobrescrever",
    "sobrescreviam": "sobrescrever",
    "sobrescrevias": "sobrescrever",
    "sobrescrevida": "sobrescrever",
    "sobrescrevidas": "sobrescrever",
    "sobrescrevido": "sobrescrever",
    "sobrescrevidos": "sobrescrever",
    "sobrescrevo": "sobrescrever",
    "sobrescrevê": "sobrescrever",
    "sobrescrevêramo": "sobrescrever",
    "sobrescrevêramos": "sobrescrever",
    "sobrescrevêrei": "sobrescrever",
    "sobrescrevêreis": "sobrescrever",
    "sobrescrevêsseis": "sobrescrever",
    "sobrescrevêssemos": "sobrescrever",
    "sobrescrevíamo": "sobrescrever",
    "sobrescrevíamos": "sobrescrever",
    "sobrescrevíei": "sobrescrever",
    "sobrescrevíeis": "sobrescrever",
    "sobrescrita": "sobrescritar",
    "sobrescritada": "sobrescritar",
    "sobrescritadas": "sobrescritar",
    "sobrescritado": "sobrescritar",
    "sobrescritados": "sobrescritar",
    "sobrescritai": "sobrescritar",
    "sobrescritais": "sobrescritar",
    "sobrescritam": "sobrescritar",
    "sobrescritamo": "sobrescritar",
    "sobrescritamos": "sobrescritar",
    "sobrescritando": "sobrescritar",
    "sobrescritara": "sobrescritar",
    "sobrescritaram": "sobrescritar",
    "sobrescritaras": "sobrescritar",
    "sobrescritarde": "sobrescritar",
    "sobrescritardes": "sobrescritar",
    "sobrescritare": "sobrescritar",
    "sobrescritarei": "sobrescritar",
    "sobrescritareis": "sobrescritar",
    "sobrescritarem": "sobrescritar",
    "sobrescritaremos": "sobrescritar",
    "sobrescritares": "sobrescritar",
    "sobrescritaria": "sobrescritar",
    "sobrescritariam": "sobrescritar",
    "sobrescritarias": "sobrescritar",
    "sobrescritarmo": "sobrescritar",
    "sobrescritarmos": "sobrescritar",
    "sobrescritará": "sobrescritar",
    "sobrescritarás": "sobrescritar",
    "sobrescritarão": "sobrescritar",
    "sobrescritaríamos": "sobrescritar",
    "sobrescritaríeis": "sobrescritar",
    "sobrescritas": "sobrescritar",
    "sobrescritasse": "sobrescritar",
    "sobrescritassem": "sobrescritar",
    "sobrescritasses": "sobrescritar",
    "sobrescritaste": "sobrescritar",
    "sobrescritastes": "sobrescritar",
    "sobrescritava": "sobrescritar",
    "sobrescritavam": "sobrescritar",
    "sobrescritavas": "sobrescritar",
    "sobrescrite": "sobrescritar",
    "sobrescritei": "sobrescritar",
    "sobrescriteis": "sobrescritar",
    "sobrescritem": "sobrescritar",
    "sobrescritemo": "sobrescritar",
    "sobrescritemos": "sobrescritar",
    "sobrescrites": "sobrescritar",
    "sobrescrito": "sobrescritar",
    "sobrescritos": "sobrescrito",
    "sobrescritou": "sobrescritar",
    "sobrescritá": "sobrescritar",
    "sobrescritámo": "sobrescritar",
    "sobrescritámos": "sobrescritar",
    "sobrescritáramo": "sobrescritar",
    "sobrescritáramos": "sobrescritar",
    "sobrescritárei": "sobrescritar",
    "sobrescritáreis": "sobrescritar",
    "sobrescritásseis": "sobrescritar",
    "sobrescritássemos": "sobrescritar",
    "sobrescritávamo": "sobrescritar",
    "sobrescritávamos": "sobrescritar",
    "sobrescritávei": "sobrescritar",
    "sobrescritáveis": "sobrescritar",
    "sobrespera": "sobresperar",
    "sobresperada": "sobresperar",
    "sobresperadas": "sobresperar",
    "sobresperado": "sobresperar",
    "sobresperados": "sobresperar",
    "sobresperai": "sobresperar",
    "sobresperais": "sobresperar",
    "sobresperam": "sobresperar",
    "sobresperamo": "sobresperar",
    "sobresperamos": "sobresperar",
    "sobresperando": "sobresperar",
    "sobresperara": "sobresperar",
    "sobresperaram": "sobresperar",
    "sobresperaras": "sobresperar",
    "sobresperarde": "sobresperar",
    "sobresperardes": "sobresperar",
    "sobresperare": "sobresperar",
    "sobresperarei": "sobresperar",
    "sobresperareis": "sobresperar",
    "sobresperarem": "sobresperar",
    "sobresperaremos": "sobresperar",
    "sobresperares": "sobresperar",
    "sobresperaria": "sobresperar",
    "sobresperariam": "sobresperar",
    "sobresperarias": "sobresperar",
    "sobresperarmo": "sobresperar",
    "sobresperarmos": "sobresperar",
    "sobresperará": "sobresperar",
    "sobresperarás": "sobresperar",
    "sobresperarão": "sobresperar",
    "sobresperaríamos": "sobresperar",
    "sobresperaríeis": "sobresperar",
    "sobresperas": "sobresperar",
    "sobresperasse": "sobresperar",
    "sobresperassem": "sobresperar",
    "sobresperasses": "sobresperar",
    "sobresperaste": "sobresperar",
    "sobresperastes": "sobresperar",
    "sobresperava": "sobresperar",
    "sobresperavam": "sobresperar",
    "sobresperavas": "sobresperar",
    "sobrespere": "sobresperar",
    "sobresperei": "sobresperar",
    "sobrespereis": "sobresperar",
    "sobresperem": "sobresperar",
    "sobresperemo": "sobresperar",
    "sobresperemos": "sobresperar",
    "sobresperes": "sobresperar",
    "sobrespero": "sobresperar",
    "sobresperou": "sobresperar",
    "sobresperá": "sobresperar",
    "sobresperámo": "sobresperar",
    "sobresperámos": "sobresperar",
    "sobresperáramo": "sobresperar",
    "sobresperáramos": "sobresperar",
    "sobresperárei": "sobresperar",
    "sobresperáreis": "sobresperar",
    "sobresperásseis": "sobresperar",
    "sobresperássemos": "sobresperar",
    "sobresperávamo": "sobresperar",
    "sobresperávamos": "sobresperar",
    "sobresperávei": "sobresperar",
    "sobresperáveis": "sobresperar",
    "sobressaem": "sobressair",
    "sobressai": "sobressair",
    "sobressaia": "sobressair",
    "sobressaiais": "sobressair",
    "sobressaiam": "sobressair",
    "sobressaiamo": "sobressair",
    "sobressaiamos": "sobressair",
    "sobressaias": "sobressair",
    "sobressaindo": "sobressair",
    "sobressaio": "sobressair",
    "sobressairdes": "sobressair",
    "sobressairei": "sobressair",
    "sobressaireis": "sobressair",
    "sobressairemos": "sobressair",
    "sobressairia": "sobressair",
    "sobressairiam": "sobressair",
    "sobressairias": "sobressair",
    "sobressairmo": "sobressair",
    "sobressairmos": "sobressair",
    "sobressairá": "sobressair",
    "sobressairás": "sobressair",
    "sobressairão": "sobressair",
    "sobressairíamos": "sobressair",
    "sobressairíeis": "sobressair",
    "sobressais": "sobressair",
    "sobressaiu": "sobressair",
    "sobressalentes": "sobressalente",
    "sobressalientes": "sobressaliente",
    "sobressalta": "sobressaltar",
    "sobressaltada": "sobressaltar",
    "sobressaltadas": "sobressaltar",
    "sobressaltado": "sobressaltar",
    "sobressaltados": "sobressaltar",
    "sobressaltai": "sobressaltar",
    "sobressaltais": "sobressaltar",
    "sobressaltam": "sobressaltar",
    "sobressaltamo": "sobressaltar",
    "sobressaltamos": "sobressaltar",
    "sobressaltando": "sobressaltar",
    "sobressaltantes": "sobressaltante",
    "sobressaltara": "sobressaltar",
    "sobressaltaram": "sobressaltar",
    "sobressaltaras": "sobressaltar",
    "sobressaltarde": "sobressaltar",
    "sobressaltardes": "sobressaltar",
    "sobressaltare": "sobressaltar",
    "sobressaltarei": "sobressaltar",
    "sobressaltareis": "sobressaltar",
    "sobressaltarem": "sobressaltar",
    "sobressaltaremos": "sobressaltar",
    "sobressaltares": "sobressaltar",
    "sobressaltaria": "sobressaltar",
    "sobressaltariam": "sobressaltar",
    "sobressaltarias": "sobressaltar",
    "sobressaltarmo": "sobressaltar",
    "sobressaltarmos": "sobressaltar",
    "sobressaltará": "sobressaltar",
    "sobressaltarás": "sobressaltar",
    "sobressaltarão": "sobressaltar",
    "sobressaltaríamos": "sobressaltar",
    "sobressaltaríeis": "sobressaltar",
    "sobressaltas": "sobressaltar",
    "sobressaltasse": "sobressaltar",
    "sobressaltassem": "sobressaltar",
    "sobressaltasses": "sobressaltar",
    "sobressaltaste": "sobressaltar",
    "sobressaltastes": "sobressaltar",
    "sobressaltava": "sobressaltar",
    "sobressaltavam": "sobressaltar",
    "sobressaltavas": "sobressaltar",
    "sobressalte": "sobressaltar",
    "sobressalteada": "sobressaltear",
    "sobressalteadas": "sobressaltear",
    "sobressalteado": "sobressaltear",
    "sobressalteados": "sobressaltear",
    "sobressalteai": "sobressaltear",
    "sobressalteais": "sobressaltear",
    "sobressalteamo": "sobressaltear",
    "sobressalteamos": "sobressaltear",
    "sobressalteando": "sobressaltear",
    "sobressalteara": "sobressaltear",
    "sobressaltearam": "sobressaltear",
    "sobressaltearas": "sobressaltear",
    "sobressaltearde": "sobressaltear",
    "sobressalteardes": "sobressaltear",
    "sobressalteare": "sobressaltear",
    "sobressaltearei": "sobressaltear",
    "sobressalteareis": "sobressaltear",
    "sobressaltearem": "sobressaltear",
    "sobressaltearemos": "sobressaltear",
    "sobressalteares": "sobressaltear",
    "sobressaltearia": "sobressaltear",
    "sobressalteariam": "sobressaltear",
    "sobressaltearias": "sobressaltear",
    "sobressaltearmo": "sobressaltear",
    "sobressaltearmos": "sobressaltear",
    "sobressalteará": "sobressaltear",
    "sobressaltearás": "sobressaltear",
    "sobressaltearão": "sobressaltear",
    "sobressaltearíamos": "sobressaltear",
    "sobressaltearíeis": "sobressaltear",
    "sobressalteasse": "sobressaltear",
    "sobressalteassem": "sobressaltear",
    "sobressalteasses": "sobressaltear",
    "sobressalteaste": "sobressaltear",
    "sobressalteastes": "sobressaltear",
    "sobressalteava": "sobressaltear",
    "sobressalteavam": "sobressaltear",
    "sobressalteavas": "sobressaltear",
    "sobressalteei": "sobressaltear",
    "sobressalteeis": "sobressaltear",
    "sobressalteemo": "sobressaltear",
    "sobressalteemos": "sobressaltear",
    "sobressaltei": "sobressaltar",
    "sobressalteia": "sobressaltear",
    "sobressalteiam": "sobressaltear",
    "sobressalteias": "sobressaltear",
    "sobressalteie": "sobressaltear",
    "sobressalteiem": "sobressaltear",
    "sobressalteies": "sobressaltear",
    "sobressalteio": "sobressaltear",
    "sobressalteis": "sobressaltar",
    "sobressaltem": "sobressaltar",
    "sobressaltemo": "sobressaltar",
    "sobressaltemos": "sobressaltar",
    "sobressalteou": "sobressaltear",
    "sobressaltes": "sobressaltar",
    "sobressalteá": "sobressaltear",
    "sobressalteámo": "sobressaltear",
    "sobressalteámos": "sobressaltear",
    "sobressalteáramo": "sobressaltear",
    "sobressalteáramos": "sobressaltear",
    "sobressalteárei": "sobressaltear",
    "sobressalteáreis": "sobressaltear",
    "sobressalteásseis": "sobressaltear",
    "sobressalteássemos": "sobressaltear",
    "sobressalteávamo": "sobressaltear",
    "sobressalteávamos": "sobressaltear",
    "sobressalteávei": "sobressaltear",
    "sobressalteáveis": "sobressaltear",
    "sobressalto": "sobressaltar",
    "sobressaltos": "sobressalto",
    "sobressaltou": "sobressaltar",
    "sobressaltá": "sobressaltar",
    "sobressaltámo": "sobressaltar",
    "sobressaltámos": "sobressaltar",
    "sobressaltáramo": "sobressaltar",
    "sobressaltáramos": "sobressaltar",
    "sobressaltárei": "sobressaltar",
    "sobressaltáreis": "sobressaltar",
    "sobressaltásseis": "sobressaltar",
    "sobressaltássemos": "sobressaltar",
    "sobressaltávamo": "sobressaltar",
    "sobressaltávamos": "sobressaltar",
    "sobressaltávei": "sobressaltar",
    "sobressaltáveis": "sobressaltar",
    "sobressanos": "sobressano",
    "sobressara": "sobressarar",
    "sobressarada": "sobressarar",
    "sobressaradas": "sobressarar",
    "sobressarado": "sobressarar",
    "sobressarados": "sobressarar",
    "sobressarai": "sobressarar",
    "sobressarais": "sobressarar",
    "sobressaram": "sobressarar",
    "sobressaramo": "sobressarar",
    "sobressaramos": "sobressarar",
    "sobressarando": "sobressarar",
    "sobressarara": "sobressarar",
    "sobressararam": "sobressarar",
    "sobressararas": "sobressarar",
    "sobressararde": "sobressarar",
    "sobressarardes": "sobressarar",
    "sobressarare": "sobressarar",
    "sobressararei": "sobressarar",
    "sobressarareis": "sobressarar",
    "sobressararem": "sobressarar",
    "sobressararemos": "sobressarar",
    "sobressarares": "sobressarar",
    "sobressararia": "sobressarar",
    "sobressarariam": "sobressarar",
    "sobressararias": "sobressarar",
    "sobressararmo": "sobressarar",
    "sobressararmos": "sobressarar",
    "sobressarará": "sobressarar",
    "sobressararás": "sobressarar",
    "sobressararão": "sobressarar",
    "sobressararíamos": "sobressarar",
    "sobressararíeis": "sobressarar",
    "sobressaras": "sobressarar",
    "sobressarasse": "sobressarar",
    "sobressarassem": "sobressarar",
    "sobressarasses": "sobressarar",
    "sobressaraste": "sobressarar",
    "sobressarastes": "sobressarar",
    "sobressarava": "sobressarar",
    "sobressaravam": "sobressarar",
    "sobressaravas": "sobressarar",
    "sobressare": "sobressarar",
    "sobressarei": "sobressarar",
    "sobressareis": "sobressarar",
    "sobressarem": "sobressarar",
    "sobressaremo": "sobressarar",
    "sobressaremos": "sobressarar",
    "sobressares": "sobressarar",
    "sobressaro": "sobressarar",
    "sobressarou": "sobressarar",
    "sobressará": "sobressarar",
    "sobressarámo": "sobressarar",
    "sobressarámos": "sobressarar",
    "sobressaráramo": "sobressarar",
    "sobressaráramos": "sobressarar",
    "sobressarárei": "sobressarar",
    "sobressaráreis": "sobressarar",
    "sobressarásseis": "sobressarar",
    "sobressarássemos": "sobressarar",
    "sobressarávamo": "sobressarar",
    "sobressarávamos": "sobressarar",
    "sobressarávei": "sobressarar",
    "sobressaráveis": "sobressarar",
    "sobressatura": "sobressaturar",
    "sobressaturada": "sobressaturar",
    "sobressaturadas": "sobressaturar",
    "sobressaturado": "sobressaturar",
    "sobressaturados": "sobressaturar",
    "sobressaturai": "sobressaturar",
    "sobressaturais": "sobressaturar",
    "sobressaturam": "sobressaturar",
    "sobressaturamo": "sobressaturar",
    "sobressaturamos": "sobressaturar",
    "sobressaturando": "sobressaturar",
    "sobressaturara": "sobressaturar",
    "sobressaturaram": "sobressaturar",
    "sobressaturaras": "sobressaturar",
    "sobressaturarde": "sobressaturar",
    "sobressaturardes": "sobressaturar",
    "sobressaturare": "sobressaturar",
    "sobressaturarei": "sobressaturar",
    "sobressaturareis": "sobressaturar",
    "sobressaturarem": "sobressaturar",
    "sobressaturaremos": "sobressaturar",
    "sobressaturares": "sobressaturar",
    "sobressaturaria": "sobressaturar",
    "sobressaturariam": "sobressaturar",
    "sobressaturarias": "sobressaturar",
    "sobressaturarmo": "sobressaturar",
    "sobressaturarmos": "sobressaturar",
    "sobressaturará": "sobressaturar",
    "sobressaturarás": "sobressaturar",
    "sobressaturarão": "sobressaturar",
    "sobressaturaríamos": "sobressaturar",
    "sobressaturaríeis": "sobressaturar",
    "sobressaturas": "sobressaturar",
    "sobressaturasse": "sobressaturar",
    "sobressaturassem": "sobressaturar",
    "sobressaturasses": "sobressaturar",
    "sobressaturaste": "sobressaturar",
    "sobressaturastes": "sobressaturar",
    "sobressaturava": "sobressaturar",
    "sobressaturavam": "sobressaturar",
    "sobressaturavas": "sobressaturar",
    "sobressaturações": "sobressaturação",
    "sobressature": "sobressaturar",
    "sobressaturei": "sobressaturar",
    "sobressatureis": "sobressaturar",
    "sobressaturem": "sobressaturar",
    "sobressaturemo": "sobressaturar",
    "sobressaturemos": "sobressaturar",
    "sobressatures": "sobressaturar",
    "sobressaturo": "sobressaturar",
    "sobressaturou": "sobressaturar",
    "sobressaturá": "sobressaturar",
    "sobressaturámo": "sobressaturar",
    "sobressaturámos": "sobressaturar",
    "sobressaturáramo": "sobressaturar",
    "sobressaturáramos": "sobressaturar",
    "sobressaturárei": "sobressaturar",
    "sobressaturáreis": "sobressaturar",
    "sobressaturásseis": "sobressaturar",
    "sobressaturássemos": "sobressaturar",
    "sobressaturávamo": "sobressaturar",
    "sobressaturávamos": "sobressaturar",
    "sobressaturávei": "sobressaturar",
    "sobressaturáveis": "sobressaturar",
    "sobressaí": "sobressair",
    "sobressaía": "sobressair",
    "sobressaíam": "sobressair",
    "sobressaíamo": "sobressair",
    "sobressaíamos": "sobressair",
    "sobressaías": "sobressair",
    "sobressaída": "sobressair",
    "sobressaídas": "sobressair",
    "sobressaído": "sobressair",
    "sobressaídos": "sobressair",
    "sobressaíeis": "sobressair",
    "sobressaímo": "sobressair",
    "sobressaímos": "sobressair",
    "sobressaíra": "sobressair",
    "sobressaíram": "sobressair",
    "sobressaíramo": "sobressair",
    "sobressaíramos": "sobressair",
    "sobressaíras": "sobressair",
    "sobressaíreis": "sobressair",
    "sobressaírem": "sobressair",
    "sobressaíres": "sobressair",
    "sobressaís": "sobressair",
    "sobressaísse": "sobressair",
    "sobressaísseis": "sobressair",
    "sobressaíssem": "sobressair",
    "sobressaíssemos": "sobressair",
    "sobressaísses": "sobressair",
    "sobressaíste": "sobressair",
    "sobressaístes": "sobressair",
    "sobressede": "sobresser",
    "sobresseja": "sobresser",
    "sobressejais": "sobresser",
    "sobressejam": "sobresser",
    "sobressejamo": "sobresser",
    "sobressejamos": "sobresser",
    "sobressejas": "sobresser",
    "sobresselentes": "sobresselente",
    "sobresselos": "sobresselo",
    "sobressemeada": "sobressemear",
    "sobressemeadas": "sobressemear",
    "sobressemeado": "sobressemear",
    "sobressemeados": "sobressemear",
    "sobressemeai": "sobressemear",
    "sobressemeais": "sobressemear",
    "sobressemeamo": "sobressemear",
    "sobressemeamos": "sobressemear",
    "sobressemeando": "sobressemear",
    "sobressemeara": "sobressemear",
    "sobressemearam": "sobressemear",
    "sobressemearas": "sobressemear",
    "sobressemearde": "sobressemear",
    "sobressemeardes": "sobressemear",
    "sobressemeare": "sobressemear",
    "sobressemearei": "sobressemear",
    "sobressemeareis": "sobressemear",
    "sobressemearem": "sobressemear",
    "sobressemearemos": "sobressemear",
    "sobressemeares": "sobressemear",
    "sobressemearia": "sobressemear",
    "sobressemeariam": "sobressemear",
    "sobressemearias": "sobressemear",
    "sobressemearmo": "sobressemear",
    "sobressemearmos": "sobressemear",
    "sobressemeará": "sobressemear",
    "sobressemearás": "sobressemear",
    "sobressemearão": "sobressemear",
    "sobressemearíamos": "sobressemear",
    "sobressemearíeis": "sobressemear",
    "sobressemeasse": "sobressemear",
    "sobressemeassem": "sobressemear",
    "sobressemeasses": "sobressemear",
    "sobressemeaste": "sobressemear",
    "sobressemeastes": "sobressemear",
    "sobressemeava": "sobressemear",
    "sobressemeavam": "sobressemear",
    "sobressemeavas": "sobressemear",
    "sobressemeei": "sobressemear",
    "sobressemeeis": "sobressemear",
    "sobressemeemo": "sobressemear",
    "sobressemeemos": "sobressemear",
    "sobressemeia": "sobressemear",
    "sobressemeiam": "sobressemear",
    "sobressemeias": "sobressemear",
    "sobressemeie": "sobressemear",
    "sobressemeiem": "sobressemear",
    "sobressemeies": "sobressemear",
    "sobressemeio": "sobressemear",
    "sobressemeou": "sobressemear",
    "sobressemeá": "sobressemear",
    "sobressemeámo": "sobressemear",
    "sobressemeámos": "sobressemear",
    "sobressemeáramo": "sobressemear",
    "sobressemeáramos": "sobressemear",
    "sobressemeárei": "sobressemear",
    "sobressemeáreis": "sobressemear",
    "sobressemeásseis": "sobressemear",
    "sobressemeássemos": "sobressemear",
    "sobressemeávamo": "sobressemear",
    "sobressemeávamos": "sobressemear",
    "sobressemeávei": "sobressemear",
    "sobressemeáveis": "sobressemear",
    "sobressendo": "sobresser",
    "sobresserde": "sobresser",
    "sobresserdes": "sobresser",
    "sobressere": "sobresser",
    "sobresserei": "sobresser",
    "sobressereis": "sobresser",
    "sobresserem": "sobresser",
    "sobresseremos": "sobresser",
    "sobresseres": "sobresser",
    "sobresseria": "sobresser",
    "sobresseriam": "sobresser",
    "sobresserias": "sobresser",
    "sobressermo": "sobresser",
    "sobressermos": "sobresser",
    "sobresserá": "sobresser",
    "sobresserás": "sobresser",
    "sobresserão": "sobresser",
    "sobresseríamos": "sobresser",
    "sobresseríeis": "sobresser",
    "sobressida": "sobresser",
    "sobressidas": "sobresser",
    "sobressido": "sobresser",
    "sobressidos": "sobresser",
    "sobressinais": "sobressinal",
    "sobressoi": "sobresser",
    "sobressois": "sobresser",
    "sobressola": "sobressolar",
    "sobressolada": "sobressolar",
    "sobressoladas": "sobressolar",
    "sobressolado": "sobressolar",
    "sobressolados": "sobressolar",
    "sobressolai": "sobressolar",
    "sobressolais": "sobressolar",
    "sobressolam": "sobressolar",
    "sobressolamo": "sobressolar",
    "sobressolamos": "sobressolar",
    "sobressolando": "sobressolar",
    "sobressolara": "sobressolar",
    "sobressolaram": "sobressolar",
    "sobressolaras": "sobressolar",
    "sobressolarde": "sobressolar",
    "sobressolardes": "sobressolar",
    "sobressolare": "sobressolar",
    "sobressolarei": "sobressolar",
    "sobressolareis": "sobressolar",
    "sobressolarem": "sobressolar",
    "sobressolaremos": "sobressolar",
    "sobressolares": "sobressolar",
    "sobressolaria": "sobressolar",
    "sobressolariam": "sobressolar",
    "sobressolarias": "sobressolar",
    "sobressolarmo": "sobressolar",
    "sobressolarmos": "sobressolar",
    "sobressolará": "sobressolar",
    "sobressolarás": "sobressolar",
    "sobressolarão": "sobressolar",
    "sobressolaríamos": "sobressolar",
    "sobressolaríeis": "sobressolar",
    "sobressolas": "sobressolar",
    "sobressolasse": "sobressolar",
    "sobressolassem": "sobressolar",
    "sobressolasses": "sobressolar",
    "sobressolaste": "sobressolar",
    "sobressolastes": "sobressolar",
    "sobressolava": "sobressolar",
    "sobressolavam": "sobressolar",
    "sobressolavas": "sobressolar",
    "sobressole": "sobressolar",
    "sobressolei": "sobressolar",
    "sobressoleiras": "sobressoleira",
    "sobressoleis": "sobressolar",
    "sobressolem": "sobressolar",
    "sobressolemo": "sobressolar",
    "sobressolemos": "sobressolar",
    "sobressoles": "sobressolar",
    "sobressolo": "sobressolar",
    "sobressolou": "sobressolar",
    "sobressolá": "sobressolar",
    "sobressolámo": "sobressolar",
    "sobressolámos": "sobressolar",
    "sobressoláramo": "sobressolar",
    "sobressoláramos": "sobressolar",
    "sobressolárei": "sobressolar",
    "sobressoláreis": "sobressolar",
    "sobressolásseis": "sobressolar",
    "sobressolássemos": "sobressolar",
    "sobressolávamo": "sobressolar",
    "sobressolávamos": "sobressolar",
    "sobressolávei": "sobressolar",
    "sobressoláveis": "sobressolar",
    "sobressomo": "sobresser",
    "sobressomos": "sobresser",
    "sobressou": "sobresser",
    "sobressubstanciais": "sobressubstancial",
    "sobressão": "sobresser",
    "sobressê": "sobresser",
    "sobresta": "sobrestar",
    "sobrestada": "sobrestar",
    "sobrestadas": "sobrestar",
    "sobrestado": "sobrestar",
    "sobrestados": "sobrestar",
    "sobrestai": "sobrestar",
    "sobrestais": "sobrestar",
    "sobrestam": "sobrestar",
    "sobrestamo": "sobrestar",
    "sobrestamos": "sobrestar",
    "sobrestando": "sobrestar",
    "sobrestantes": "sobrestante",
    "sobrestara": "sobrestar",
    "sobrestaram": "sobrestar",
    "sobrestaras": "sobrestar",
    "sobrestardes": "sobrestar",
    "sobrestarei": "sobrestar",
    "sobrestareis": "sobrestar",
    "sobrestarem": "sobrestar",
    "sobrestaremos": "sobrestar",
    "sobrestares": "sobrestar",
    "sobrestaria": "sobrestar",
    "sobrestariam": "sobrestar",
    "sobrestarias": "sobrestar",
    "sobrestarmo": "sobrestar",
    "sobrestarmos": "sobrestar",
    "sobrestará": "sobrestar",
    "sobrestarás": "sobrestar",
    "sobrestarão": "sobrestar",
    "sobrestaríamos": "sobrestar",
    "sobrestaríeis": "sobrestar",
    "sobrestas": "sobrestar",
    "sobrestasse": "sobrestar",
    "sobrestassem": "sobrestar",
    "sobrestasses": "sobrestar",
    "sobrestaste": "sobrestar",
    "sobrestastes": "sobrestar",
    "sobrestava": "sobrestar",
    "sobrestavam": "sobrestar",
    "sobrestavas": "sobrestar",
    "sobreste": "sobrestar",
    "sobrestei": "sobrestar",
    "sobresteis": "sobrestar",
    "sobrestem": "sobrestar",
    "sobrestemo": "sobrestar",
    "sobrestemos": "sobrestar",
    "sobrestes": "sobrestar",
    "sobrestima": "sobrestimar",
    "sobrestimada": "sobrestimar",
    "sobrestimadas": "sobrestimar",
    "sobrestimado": "sobrestimar",
    "sobrestimados": "sobrestimar",
    "sobrestimai": "sobrestimar",
    "sobrestimais": "sobrestimar",
    "sobrestimam": "sobrestimar",
    "sobrestimamo": "sobrestimar",
    "sobrestimamos": "sobrestimar",
    "sobrestimando": "sobrestimar",
    "sobrestimara": "sobrestimar",
    "sobrestimaram": "sobrestimar",
    "sobrestimaras": "sobrestimar",
    "sobrestimarde": "sobrestimar",
    "sobrestimardes": "sobrestimar",
    "sobrestimare": "sobrestimar",
    "sobrestimarei": "sobrestimar",
    "sobrestimareis": "sobrestimar",
    "sobrestimarem": "sobrestimar",
    "sobrestimaremos": "sobrestimar",
    "sobrestimares": "sobrestimar",
    "sobrestimaria": "sobrestimar",
    "sobrestimariam": "sobrestimar",
    "sobrestimarias": "sobrestimar",
    "sobrestimarmo": "sobrestimar",
    "sobrestimarmos": "sobrestimar",
    "sobrestimará": "sobrestimar",
    "sobrestimarás": "sobrestimar",
    "sobrestimarão": "sobrestimar",
    "sobrestimaríamos": "sobrestimar",
    "sobrestimaríeis": "sobrestimar",
    "sobrestimas": "sobrestimar",
    "sobrestimasse": "sobrestimar",
    "sobrestimassem": "sobrestimar",
    "sobrestimasses": "sobrestimar",
    "sobrestimaste": "sobrestimar",
    "sobrestimastes": "sobrestimar",
    "sobrestimava": "sobrestimar",
    "sobrestimavam": "sobrestimar",
    "sobrestimavas": "sobrestimar",
    "sobrestime": "sobrestimar",
    "sobrestimei": "sobrestimar",
    "sobrestimeis": "sobrestimar",
    "sobrestimem": "sobrestimar",
    "sobrestimemo": "sobrestimar",
    "sobrestimemos": "sobrestimar",
    "sobrestimes": "sobrestimar",
    "sobrestimo": "sobrestimar",
    "sobrestimou": "sobrestimar",
    "sobrestimá": "sobrestimar",
    "sobrestimámo": "sobrestimar",
    "sobrestimámos": "sobrestimar",
    "sobrestimáramo": "sobrestimar",
    "sobrestimáramos": "sobrestimar",
    "sobrestimárei": "sobrestimar",
    "sobrestimáreis": "sobrestimar",
    "sobrestimásseis": "sobrestimar",
    "sobrestimássemos": "sobrestimar",
    "sobrestimávamo": "sobrestimar",
    "sobrestimávamos": "sobrestimar",
    "sobrestimávei": "sobrestimar",
    "sobrestimáveis": "sobrestimar",
    "sobresto": "sobrestar",
    "sobrestou": "sobrestar",
    "sobrestámo": "sobrestar",
    "sobrestámos": "sobrestar",
    "sobrestáramo": "sobrestar",
    "sobrestáramos": "sobrestar",
    "sobrestáreis": "sobrestar",
    "sobrestásseis": "sobrestar",
    "sobrestássemos": "sobrestar",
    "sobrestávamo": "sobrestar",
    "sobrestávamos": "sobrestar",
    "sobrestáveis": "sobrestar",
    "sobretardes": "sobretarde",
    "sobretaxas": "sobretaxa",
    "sobretece": "sobretecer",
    "sobretecei": "sobretecer",
    "sobreteceis": "sobretecer",
    "sobretecem": "sobretecer",
    "sobretecemo": "sobretecer",
    "sobretecemos": "sobretecer",
    "sobretecendo": "sobretecer",
    "sobretecera": "sobretecer",
    "sobreteceram": "sobretecer",
    "sobreteceras": "sobretecer",
    "sobretecerde": "sobretecer",
    "sobretecerdes": "sobretecer",
    "sobretecere": "sobretecer",
    "sobretecerei": "sobretecer",
    "sobretecereis": "sobretecer",
    "sobretecerem": "sobretecer",
    "sobreteceremos": "sobretecer",
    "sobreteceres": "sobretecer",
    "sobreteceria": "sobretecer",
    "sobreteceriam": "sobretecer",
    "sobretecerias": "sobretecer",
    "sobretecermo": "sobretecer",
    "sobretecermos": "sobretecer",
    "sobretecerá": "sobretecer",
    "sobretecerás": "sobretecer",
    "sobretecerão": "sobretecer",
    "sobreteceríamos": "sobretecer",
    "sobreteceríeis": "sobretecer",
    "sobreteces": "sobretecer",
    "sobretecesse": "sobretecer",
    "sobretecessem": "sobretecer",
    "sobretecesses": "sobretecer",
    "sobreteceste": "sobretecer",
    "sobretecestes": "sobretecer",
    "sobreteceu": "sobretecer",
    "sobreteci": "sobretecer",
    "sobretecia": "sobretecer",
    "sobreteciam": "sobretecer",
    "sobretecias": "sobretecer",
    "sobretecida": "sobretecer",
    "sobretecidas": "sobretecer",
    "sobretecido": "sobretecer",
    "sobretecidos": "sobretecer",
    "sobretecê": "sobretecer",
    "sobretecêramo": "sobretecer",
    "sobretecêramos": "sobretecer",
    "sobretecêrei": "sobretecer",
    "sobretecêreis": "sobretecer",
    "sobretecêsseis": "sobretecer",
    "sobretecêssemos": "sobretecer",
    "sobretecíamo": "sobretecer",
    "sobretecíamos": "sobretecer",
    "sobretecíei": "sobretecer",
    "sobretecíeis": "sobretecer",
    "sobreteimas": "sobreteima",
    "sobretensões": "sobretensão",
    "sobreterrestres": "sobreterrestre",
    "sobreteça": "sobretecer",
    "sobreteçais": "sobretecer",
    "sobreteçam": "sobretecer",
    "sobreteçamo": "sobretecer",
    "sobreteçamos": "sobretecer",
    "sobreteças": "sobretecer",
    "sobreteço": "sobretecer",
    "sobretoalhas": "sobretoalha",
    "sobretudos": "sobretudo",
    "sobretítulos": "sobretítulo",
    "sobretónicas": "sobretónica",
    "sobrevaloriza": "sobrevalorizar",
    "sobrevalorizada": "sobrevalorizar",
    "sobrevalorizadas": "sobrevalorizar",
    "sobrevalorizado": "sobrevalorizar",
    "sobrevalorizados": "sobrevalorizar",
    "sobrevalorizai": "sobrevalorizar",
    "sobrevalorizais": "sobrevalorizar",
    "sobrevalorizam": "sobrevalorizar",
    "sobrevalorizamo": "sobrevalorizar",
    "sobrevalorizamos": "sobrevalorizar",
    "sobrevalorizando": "sobrevalorizar",
    "sobrevalorizara": "sobrevalorizar",
    "sobrevalorizaram": "sobrevalorizar",
    "sobrevalorizaras": "sobrevalorizar",
    "sobrevalorizarde": "sobrevalorizar",
    "sobrevalorizardes": "sobrevalorizar",
    "sobrevalorizare": "sobrevalorizar",
    "sobrevalorizarei": "sobrevalorizar",
    "sobrevalorizareis": "sobrevalorizar",
    "sobrevalorizarem": "sobrevalorizar",
    "sobrevalorizaremos": "sobrevalorizar",
    "sobrevalorizares": "sobrevalorizar",
    "sobrevalorizaria": "sobrevalorizar",
    "sobrevalorizariam": "sobrevalorizar",
    "sobrevalorizarias": "sobrevalorizar",
    "sobrevalorizarmo": "sobrevalorizar",
    "sobrevalorizarmos": "sobrevalorizar",
    "sobrevalorizará": "sobrevalorizar",
    "sobrevalorizarás": "sobrevalorizar",
    "sobrevalorizarão": "sobrevalorizar",
    "sobrevalorizaríamos": "sobrevalorizar",
    "sobrevalorizaríeis": "sobrevalorizar",
    "sobrevalorizas": "sobrevalorizar",
    "sobrevalorizasse": "sobrevalorizar",
    "sobrevalorizassem": "sobrevalorizar",
    "sobrevalorizasses": "sobrevalorizar",
    "sobrevalorizaste": "sobrevalorizar",
    "sobrevalorizastes": "sobrevalorizar",
    "sobrevalorizava": "sobrevalorizar",
    "sobrevalorizavam": "sobrevalorizar",
    "sobrevalorizavas": "sobrevalorizar",
    "sobrevalorize": "sobrevalorizar",
    "sobrevalorizei": "sobrevalorizar",
    "sobrevalorizeis": "sobrevalorizar",
    "sobrevalorizem": "sobrevalorizar",
    "sobrevalorizemo": "sobrevalorizar",
    "sobrevalorizemos": "sobrevalorizar",
    "sobrevalorizes": "sobrevalorizar",
    "sobrevalorizo": "sobrevalorizar",
    "sobrevalorizou": "sobrevalorizar",
    "sobrevalorizá": "sobrevalorizar",
    "sobrevalorizámo": "sobrevalorizar",
    "sobrevalorizámos": "sobrevalorizar",
    "sobrevalorizáramo": "sobrevalorizar",
    "sobrevalorizáramos": "sobrevalorizar",
    "sobrevalorizárei": "sobrevalorizar",
    "sobrevalorizáreis": "sobrevalorizar",
    "sobrevalorizásseis": "sobrevalorizar",
    "sobrevalorizássemos": "sobrevalorizar",
    "sobrevalorizávamo": "sobrevalorizar",
    "sobrevalorizávamos": "sobrevalorizar",
    "sobrevalorizávei": "sobrevalorizar",
    "sobrevalorizáveis": "sobrevalorizar",
    "sobreveio": "sobrevir",
    "sobrevem": "sobrevir",
    "sobrevenha": "sobrevir",
    "sobrevenhais": "sobrevir",
    "sobrevenham": "sobrevir",
    "sobrevenhamo": "sobrevir",
    "sobrevenhamos": "sobrevir",
    "sobrevenhas": "sobrevir",
    "sobrevenho": "sobrevir",
    "sobrevenientes": "sobreveniente",
    "sobreventos": "sobrevento",
    "sobrevergas": "sobreverga",
    "sobreveste": "sobrevestir",
    "sobrevestem": "sobrevestir",
    "sobrevestes": "sobrevestir",
    "sobrevesti": "sobrevestir",
    "sobrevestia": "sobrevestir",
    "sobrevestiam": "sobrevestir",
    "sobrevestias": "sobrevestir",
    "sobrevestida": "sobrevestir",
    "sobrevestidas": "sobrevestir",
    "sobrevestido": "sobrevestir",
    "sobrevestidos": "sobrevestir",
    "sobrevestimo": "sobrevestir",
    "sobrevestimos": "sobrevestir",
    "sobrevestindo": "sobrevestir",
    "sobrevestira": "sobrevestir",
    "sobrevestiram": "sobrevestir",
    "sobrevestiras": "sobrevestir",
    "sobrevestirde": "sobrevestir",
    "sobrevestirdes": "sobrevestir",
    "sobrevestire": "sobrevestir",
    "sobrevestirei": "sobrevestir",
    "sobrevestireis": "sobrevestir",
    "sobrevestirem": "sobrevestir",
    "sobrevestiremos": "sobrevestir",
    "sobrevestires": "sobrevestir",
    "sobrevestiria": "sobrevestir",
    "sobrevestiriam": "sobrevestir",
    "sobrevestirias": "sobrevestir",
    "sobrevestirmo": "sobrevestir",
    "sobrevestirmos": "sobrevestir",
    "sobrevestirá": "sobrevestir",
    "sobrevestirás": "sobrevestir",
    "sobrevestirão": "sobrevestir",
    "sobrevestiríamos": "sobrevestir",
    "sobrevestiríeis": "sobrevestir",
    "sobrevestis": "sobrevestir",
    "sobrevestisse": "sobrevestir",
    "sobrevestissem": "sobrevestir",
    "sobrevestisses": "sobrevestir",
    "sobrevestiste": "sobrevestir",
    "sobrevestistes": "sobrevestir",
    "sobrevestiu": "sobrevestir",
    "sobrevestíamo": "sobrevestir",
    "sobrevestíamos": "sobrevestir",
    "sobrevestíei": "sobrevestir",
    "sobrevestíeis": "sobrevestir",
    "sobrevestíramo": "sobrevestir",
    "sobrevestíramos": "sobrevestir",
    "sobrevestírei": "sobrevestir",
    "sobrevestíreis": "sobrevestir",
    "sobrevestísseis": "sobrevestir",
    "sobrevestíssemos": "sobrevestir",
    "sobrevidas": "sobrevida",
    "sobreviemo": "sobrevir",
    "sobreviemos": "sobrevir",
    "sobrevier": "sobrevir",
    "sobreviera": "sobrevir",
    "sobrevieram": "sobrevir",
    "sobrevieras": "sobrevir",
    "sobrevierdes": "sobrevir",
    "sobrevierem": "sobrevir",
    "sobrevieres": "sobrevir",
    "sobreviermos": "sobrevir",
    "sobreviesse": "sobrevir",
    "sobreviessem": "sobrevir",
    "sobreviesses": "sobrevir",
    "sobrevieste": "sobrevir",
    "sobreviestes": "sobrevir",
    "sobrevigia": "sobrevigiar",
    "sobrevigiada": "sobrevigiar",
    "sobrevigiadas": "sobrevigiar",
    "sobrevigiado": "sobrevigiar",
    "sobrevigiados": "sobrevigiar",
    "sobrevigiai": "sobrevigiar",
    "sobrevigiais": "sobrevigiar",
    "sobrevigiam": "sobrevigiar",
    "sobrevigiamo": "sobrevigiar",
    "sobrevigiamos": "sobrevigiar",
    "sobrevigiando": "sobrevigiar",
    "sobrevigiara": "sobrevigiar",
    "sobrevigiaram": "sobrevigiar",
    "sobrevigiaras": "sobrevigiar",
    "sobrevigiarde": "sobrevigiar",
    "sobrevigiardes": "sobrevigiar",
    "sobrevigiare": "sobrevigiar",
    "sobrevigiarei": "sobrevigiar",
    "sobrevigiareis": "sobrevigiar",
    "sobrevigiarem": "sobrevigiar",
    "sobrevigiaremos": "sobrevigiar",
    "sobrevigiares": "sobrevigiar",
    "sobrevigiaria": "sobrevigiar",
    "sobrevigiariam": "sobrevigiar",
    "sobrevigiarias": "sobrevigiar",
    "sobrevigiarmo": "sobrevigiar",
    "sobrevigiarmos": "sobrevigiar",
    "sobrevigiará": "sobrevigiar",
    "sobrevigiarás": "sobrevigiar",
    "sobrevigiarão": "sobrevigiar",
    "sobrevigiaríamos": "sobrevigiar",
    "sobrevigiaríeis": "sobrevigiar",
    "sobrevigias": "sobrevigiar",
    "sobrevigiasse": "sobrevigiar",
    "sobrevigiassem": "sobrevigiar",
    "sobrevigiasses": "sobrevigiar",
    "sobrevigiaste": "sobrevigiar",
    "sobrevigiastes": "sobrevigiar",
    "sobrevigiava": "sobrevigiar",
    "sobrevigiavam": "sobrevigiar",
    "sobrevigiavas": "sobrevigiar",
    "sobrevigie": "sobrevigiar",
    "sobrevigiei": "sobrevigiar",
    "sobrevigieis": "sobrevigiar",
    "sobrevigiem": "sobrevigiar",
    "sobrevigiemo": "sobrevigiar",
    "sobrevigiemos": "sobrevigiar",
    "sobrevigies": "sobrevigiar",
    "sobrevigio": "sobrevigiar",
    "sobrevigiou": "sobrevigiar",
    "sobrevigiá": "sobrevigiar",
    "sobrevigiámo": "sobrevigiar",
    "sobrevigiámos": "sobrevigiar",
    "sobrevigiáramo": "sobrevigiar",
    "sobrevigiáramos": "sobrevigiar",
    "sobrevigiárei": "sobrevigiar",
    "sobrevigiáreis": "sobrevigiar",
    "sobrevigiásseis": "sobrevigiar",
    "sobrevigiássemos": "sobrevigiar",
    "sobrevigiávamo": "sobrevigiar",
    "sobrevigiávamos": "sobrevigiar",
    "sobrevigiávei": "sobrevigiar",
    "sobrevigiáveis": "sobrevigiar",
    "sobrevim": "sobrevir",
    "sobrevimo": "sobrevir",
    "sobrevimos": "sobrevir",
    "sobrevinda": "sobrevir",
    "sobrevindas": "sobrevir",
    "sobrevinde": "sobrevir",
    "sobrevindes": "sobrevir",
    "sobrevindo": "sobrevir",
    "sobrevindos": "sobrevir",
    "sobrevinha": "sobrevir",
    "sobrevinham": "sobrevir",
    "sobrevinhas": "sobrevir",
    "sobrevirdes": "sobrevir",
    "sobrevirei": "sobrevir",
    "sobrevireis": "sobrevir",
    "sobrevirem": "sobrevir",
    "sobreviremos": "sobrevir",
    "sobrevires": "sobrevir",
    "sobreviria": "sobrevir",
    "sobreviriam": "sobrevir",
    "sobrevirias": "sobrevir",
    "sobrevirmo": "sobrevir",
    "sobrevirmos": "sobrevir",
    "sobrevirtudes": "sobrevirtude",
    "sobrevirá": "sobrevir",
    "sobrevirás": "sobrevir",
    "sobrevirão": "sobrevir",
    "sobreviríamos": "sobrevir",
    "sobreviríeis": "sobrevir",
    "sobrevista": "sobrevestir",
    "sobrevistais": "sobrevestir",
    "sobrevistam": "sobrevestir",
    "sobrevistamo": "sobrevestir",
    "sobrevistamos": "sobrevestir",
    "sobrevistas": "sobrevestir",
    "sobrevisto": "sobrevestir",
    "sobreviva": "sobrevivo",
    "sobrevivais": "sobreviver",
    "sobrevivam": "sobreviver",
    "sobrevivamo": "sobreviver",
    "sobrevivamos": "sobreviver",
    "sobrevivas": "sobrevivo",
    "sobrevive": "sobreviver",
    "sobrevivei": "sobreviver",
    "sobreviveis": "sobreviver",
    "sobrevivem": "sobreviver",
    "sobrevivemo": "sobreviver",
    "sobrevivemos": "sobreviver",
    "sobrevivendo": "sobreviver",
    "sobreviventes": "sobrevivente",
    "sobreviventezinha": "sobrevivente",
    "sobreviventezinhas": "sobrevivente",
    "sobreviventezinho": "sobrevivente",
    "sobreviventezinhos": "sobrevivente",
    "sobreviventezita": "sobrevivente",
    "sobreviventezitas": "sobrevivente",
    "sobreviventezito": "sobrevivente",
    "sobreviventezitos": "sobrevivente",
    "sobrevivera": "sobreviver",
    "sobreviveram": "sobreviver",
    "sobreviveras": "sobreviver",
    "sobreviverdes": "sobreviver",
    "sobreviverei": "sobreviver",
    "sobrevivereis": "sobreviver",
    "sobreviverem": "sobreviver",
    "sobreviveremos": "sobreviver",
    "sobreviveres": "sobreviver",
    "sobreviveria": "sobreviver",
    "sobreviveriam": "sobreviver",
    "sobreviverias": "sobreviver",
    "sobrevivermo": "sobreviver",
    "sobrevivermos": "sobreviver",
    "sobreviverá": "sobreviver",
    "sobreviverás": "sobreviver",
    "sobreviverão": "sobreviver",
    "sobreviveríamos": "sobreviver",
    "sobreviveríeis": "sobreviver",
    "sobrevives": "sobreviver",
    "sobrevivesse": "sobreviver",
    "sobrevivessem": "sobreviver",
    "sobrevivesses": "sobreviver",
    "sobreviveste": "sobreviver",
    "sobrevivestes": "sobreviver",
    "sobreviveu": "sobreviver",
    "sobrevivi": "sobreviver",
    "sobrevivia": "sobreviver",
    "sobreviviam": "sobreviver",
    "sobrevivias": "sobreviver",
    "sobrevivida": "sobreviver",
    "sobrevividas": "sobreviver",
    "sobrevivido": "sobreviver",
    "sobrevividos": "sobreviver",
    "sobrevivo": "sobreviver",
    "sobrevivos": "sobrevivo",
    "sobrevivências": "sobrevivência",
    "sobrevivêramo": "sobreviver",
    "sobrevivêramos": "sobreviver",
    "sobrevivêreis": "sobreviver",
    "sobrevivêsseis": "sobreviver",
    "sobrevivêssemos": "sobreviver",
    "sobrevivíamo": "sobreviver",
    "sobrevivíamos": "sobreviver",
    "sobrevivíeis": "sobreviver",
    "sobreviéramo": "sobrevir",
    "sobreviéramos": "sobrevir",
    "sobreviéreis": "sobrevir",
    "sobreviésseis": "sobrevir",
    "sobreviéssemos": "sobrevir",
    "sobrevoa": "sobrevoar",
    "sobrevoada": "sobrevoar",
    "sobrevoadas": "sobrevoar",
    "sobrevoado": "sobrevoar",
    "sobrevoados": "sobrevoar",
    "sobrevoai": "sobrevoar",
    "sobrevoais": "sobrevoar",
    "sobrevoam": "sobrevoar",
    "sobrevoamo": "sobrevoar",
    "sobrevoamos": "sobrevoar",
    "sobrevoando": "sobrevoar",
    "sobrevoara": "sobrevoar",
    "sobrevoaram": "sobrevoar",
    "sobrevoaras": "sobrevoar",
    "sobrevoarde": "sobrevoar",
    "sobrevoardes": "sobrevoar",
    "sobrevoare": "sobrevoar",
    "sobrevoarei": "sobrevoar",
    "sobrevoareis": "sobrevoar",
    "sobrevoarem": "sobrevoar",
    "sobrevoaremos": "sobrevoar",
    "sobrevoares": "sobrevoar",
    "sobrevoaria": "sobrevoar",
    "sobrevoariam": "sobrevoar",
    "sobrevoarias": "sobrevoar",
    "sobrevoarmo": "sobrevoar",
    "sobrevoarmos": "sobrevoar",
    "sobrevoará": "sobrevoar",
    "sobrevoarás": "sobrevoar",
    "sobrevoarão": "sobrevoar",
    "sobrevoaríamos": "sobrevoar",
    "sobrevoaríeis": "sobrevoar",
    "sobrevoas": "sobrevoar",
    "sobrevoasse": "sobrevoar",
    "sobrevoassem": "sobrevoar",
    "sobrevoasses": "sobrevoar",
    "sobrevoaste": "sobrevoar",
    "sobrevoastes": "sobrevoar",
    "sobrevoava": "sobrevoar",
    "sobrevoavam": "sobrevoar",
    "sobrevoavas": "sobrevoar",
    "sobrevoe": "sobrevoar",
    "sobrevoei": "sobrevoar",
    "sobrevoeis": "sobrevoar",
    "sobrevoem": "sobrevoar",
    "sobrevoemo": "sobrevoar",
    "sobrevoemos": "sobrevoar",
    "sobrevoes": "sobrevoar",
    "sobrevoo": "sobrevoar",
    "sobrevoos": "sobrevoo",
    "sobrevoou": "sobrevoar",
    "sobrevoá": "sobrevoar",
    "sobrevoámo": "sobrevoar",
    "sobrevoámos": "sobrevoar",
    "sobrevoáramo": "sobrevoar",
    "sobrevoáramos": "sobrevoar",
    "sobrevoárei": "sobrevoar",
    "sobrevoáreis": "sobrevoar",
    "sobrevoásseis": "sobrevoar",
    "sobrevoássemos": "sobrevoar",
    "sobrevoávamo": "sobrevoar",
    "sobrevoávamos": "sobrevoar",
    "sobrevoávei": "sobrevoar",
    "sobrevoáveis": "sobrevoar",
    "sobrevém": "sobrevir",
    "sobrevéns": "sobrevir",
    "sobrevêm": "sobrevir",
    "sobrevínhamo": "sobrevir",
    "sobrevínhamos": "sobrevir",
    "sobrevínheis": "sobrevir",
    "sobreé": "sobresser",
    "sobreéramo": "sobresser",
    "sobreéramos": "sobresser",
    "sobreérei": "sobresser",
    "sobreéreis": "sobresser",
    "sobreés": "sobresser",
    "sobreíamo": "sobreir",
    "sobreíamos": "sobreir",
    "sobreíeis": "sobreir",
    "sobreíramo": "sobreir",
    "sobreíramos": "sobreir",
    "sobreíreis": "sobreir",
    "sobreísseis": "sobreir",
    "sobreíssemos": "sobreir",
    "sobriedades": "sobriedade",
    "sobrinha": "sobrinho",
    "sobrinhas": "sobrinho",
    "sobrinhinha": "sobrinho",
    "sobrinhinhas": "sobrinho",
    "sobrinhinho": "sobrinho",
    "sobrinhinhos": "sobrinho",
    "sobrinhita": "sobrinho",
    "sobrinhitas": "sobrinho",
    "sobrinhito": "sobrinho",
    "sobrinhitos": "sobrinho",
    "sobrinhos": "sobrinho",
    "sobro": "sobrar",
    "sobrolhos": "sobrolho",
    "sobros": "sobro",
    "sobrou": "sobrar",
    "sobrámo": "sobrar",
    "sobrámos": "sobrar",
    "sobráramo": "sobrar",
    "sobráramos": "sobrar",
    "sobráreis": "sobrar",
    "sobrásseis": "sobrar",
    "sobrássemos": "sobrar",
    "sobrávamo": "sobrar",
    "sobrávamos": "sobrar",
    "sobráveis": "sobrar",
    "soca": "socar",
    "socada": "socar",
    "socadas": "socar",
    "socado": "socar",
    "socados": "socar",
    "socaduras": "socadura",
    "socai": "socar",
    "socairos": "socairo",
    "socais": "socar",
    "socalca": "socalcar",
    "socalcada": "socalcar",
    "socalcadas": "socalcar",
    "socalcado": "socalcar",
    "socalcados": "socalcar",
    "socalcai": "socalcar",
    "socalcais": "socalcar",
    "socalcam": "socalcar",
    "socalcamo": "socalcar",
    "socalcamos": "socalcar",
    "socalcando": "socalcar",
    "socalcara": "socalcar",
    "socalcaram": "socalcar",
    "socalcaras": "socalcar",
    "socalcarde": "socalcar",
    "socalcardes": "socalcar",
    "socalcare": "socalcar",
    "socalcarei": "socalcar",
    "socalcareis": "socalcar",
    "socalcarem": "socalcar",
    "socalcaremos": "socalcar",
    "socalcares": "socalcar",
    "socalcaria": "socalcar",
    "socalcariam": "socalcar",
    "socalcarias": "socalcar",
    "socalcarmo": "socalcar",
    "socalcarmos": "socalcar",
    "socalcará": "socalcar",
    "socalcarás": "socalcar",
    "socalcarão": "socalcar",
    "socalcaríamos": "socalcar",
    "socalcaríeis": "socalcar",
    "socalcas": "socalcar",
    "socalcasse": "socalcar",
    "socalcassem": "socalcar",
    "socalcasses": "socalcar",
    "socalcaste": "socalcar",
    "socalcastes": "socalcar",
    "socalcava": "socalcar",
    "socalcavam": "socalcar",
    "socalcavas": "socalcar",
    "socalco": "socalcar",
    "socalcos": "socalco",
    "socalcou": "socalcar",
    "socalcá": "socalcar",
    "socalcámo": "socalcar",
    "socalcámos": "socalcar",
    "socalcáramo": "socalcar",
    "socalcáramos": "socalcar",
    "socalcárei": "socalcar",
    "socalcáreis": "socalcar",
    "socalcásseis": "socalcar",
    "socalcássemos": "socalcar",
    "socalcávamo": "socalcar",
    "socalcávamos": "socalcar",
    "socalcávei": "socalcar",
    "socalcáveis": "socalcar",
    "socalque": "socalcar",
    "socalquei": "socalcar",
    "socalqueis": "socalcar",
    "socalquem": "socalcar",
    "socalquemo": "socalcar",
    "socalquemos": "socalcar",
    "socalques": "socalcar",
    "socam": "socar",
    "socamo": "socar",
    "socamos": "socar",
    "socancras": "socancra",
    "socando": "socar",
    "socapas": "socapa",
    "socara": "socar",
    "socaram": "socar",
    "socaras": "socar",
    "socarde": "socar",
    "socardes": "socar",
    "socare": "socar",
    "socarei": "socar",
    "socareis": "socar",
    "socarem": "socar",
    "socaremos": "socar",
    "socares": "socar",
    "socaria": "socar",
    "socariam": "socar",
    "socarias": "socar",
    "socarmo": "socar",
    "socarmos": "socar",
    "socarrona": "socarrão",
    "socarronas": "socarrão",
    "socarrões": "socarrão",
    "socará": "socar",
    "socarás": "socar",
    "socarão": "socar",
    "socaríamos": "socar",
    "socaríeis": "socar",
    "socas": "socar",
    "socasse": "socar",
    "socassem": "socar",
    "socasses": "socar",
    "socaste": "socar",
    "socastes": "socar",
    "socates": "socate",
    "socava": "socavar",
    "socavada": "socavar",
    "socavadas": "socavar",
    "socavado": "socavar",
    "socavados": "socavar",
    "socavai": "socavar",
    "socavais": "socavar",
    "socavam": "socavar",
    "socavamo": "socavar",
    "socavamos": "socavar",
    "socavando": "socavar",
    "socavara": "socavar",
    "socavaram": "socavar",
    "socavaras": "socavar",
    "socavarde": "socavar",
    "socavardes": "socavar",
    "socavare": "socavar",
    "socavarei": "socavar",
    "socavareis": "socavar",
    "socavarem": "socavar",
    "socavaremos": "socavar",
    "socavares": "socavar",
    "socavaria": "socavar",
    "socavariam": "socavar",
    "socavarias": "socavar",
    "socavarmo": "socavar",
    "socavarmos": "socavar",
    "socavará": "socavar",
    "socavarás": "socavar",
    "socavarão": "socavar",
    "socavaríamos": "socavar",
    "socavaríeis": "socavar",
    "socavas": "socavar",
    "socavasse": "socavar",
    "socavassem": "socavar",
    "socavasses": "socavar",
    "socavaste": "socavar",
    "socavastes": "socavar",
    "socavava": "socavar",
    "socavavam": "socavar",
    "socavavas": "socavar",
    "socave": "socavar",
    "socavei": "socavar",
    "socaveis": "socavar",
    "socavem": "socavar",
    "socavemo": "socavar",
    "socavemos": "socavar",
    "socaves": "socavar",
    "socavo": "socavar",
    "socavou": "socavar",
    "socavá": "socavar",
    "socavámo": "socavar",
    "socavámos": "socavar",
    "socaváramo": "socavar",
    "socaváramos": "socavar",
    "socavárei": "socavar",
    "socaváreis": "socavar",
    "socavásseis": "socavar",
    "socavássemos": "socavar",
    "socavávamo": "socavar",
    "socavávamos": "socavar",
    "socavávei": "socavar",
    "socaváveis": "socavar",
    "socavões": "socavão",
    "sochantrados": "sochantrado",
    "sochantreada": "sochantrear",
    "sochantreadas": "sochantrear",
    "sochantreado": "sochantrear",
    "sochantreados": "sochantrear",
    "sochantreai": "sochantrear",
    "sochantreais": "sochantrear",
    "sochantreamo": "sochantrear",
    "sochantreamos": "sochantrear",
    "sochantreando": "sochantrear",
    "sochantreara": "sochantrear",
    "sochantrearam": "sochantrear",
    "sochantrearas": "sochantrear",
    "sochantreardes": "sochantrear",
    "sochantrearei": "sochantrear",
    "sochantreareis": "sochantrear",
    "sochantrearem": "sochantrear",
    "sochantrearemos": "sochantrear",
    "sochantreares": "sochantrear",
    "sochantrearia": "sochantrear",
    "sochantreariam": "sochantrear",
    "sochantrearias": "sochantrear",
    "sochantrearmo": "sochantrear",
    "sochantrearmos": "sochantrear",
    "sochantreará": "sochantrear",
    "sochantrearás": "sochantrear",
    "sochantrearão": "sochantrear",
    "sochantrearíamos": "sochantrear",
    "sochantrearíeis": "sochantrear",
    "sochantreasse": "sochantrear",
    "sochantreassem": "sochantrear",
    "sochantreasses": "sochantrear",
    "sochantreaste": "sochantrear",
    "sochantreastes": "sochantrear",
    "sochantreava": "sochantrear",
    "sochantreavam": "sochantrear",
    "sochantreavas": "sochantrear",
    "sochantreei": "sochantrear",
    "sochantreeis": "sochantrear",
    "sochantreemo": "sochantrear",
    "sochantreemos": "sochantrear",
    "sochantreia": "sochantrear",
    "sochantreiam": "sochantrear",
    "sochantreias": "sochantrear",
    "sochantreie": "sochantrear",
    "sochantreiem": "sochantrear",
    "sochantreies": "sochantrear",
    "sochantreio": "sochantrear",
    "sochantreou": "sochantrear",
    "sochantres": "sochantre",
    "sochantreámo": "sochantrear",
    "sochantreámos": "sochantrear",
    "sochantreáramo": "sochantrear",
    "sochantreáramos": "sochantrear",
    "sochantreáreis": "sochantrear",
    "sochantreásseis": "sochantrear",
    "sochantreássemos": "sochantrear",
    "sochantreávamo": "sochantrear",
    "sochantreávamos": "sochantrear",
    "sochantreáveis": "sochantrear",
    "sochantrias": "sochantria",
    "sochões": "sochão",
    "sociabilidades": "sociabilidade",
    "sociabiliza": "sociabilizar",
    "sociabilizada": "sociabilizar",
    "sociabilizadas": "sociabilizar",
    "sociabilizado": "sociabilizar",
    "sociabilizados": "sociabilizar",
    "sociabilizai": "sociabilizar",
    "sociabilizais": "sociabilizar",
    "sociabilizam": "sociabilizar",
    "sociabilizamo": "sociabilizar",
    "sociabilizamos": "sociabilizar",
    "sociabilizando": "sociabilizar",
    "sociabilizara": "sociabilizar",
    "sociabilizaram": "sociabilizar",
    "sociabilizaras": "sociabilizar",
    "sociabilizarde": "sociabilizar",
    "sociabilizardes": "sociabilizar",
    "sociabilizare": "sociabilizar",
    "sociabilizarei": "sociabilizar",
    "sociabilizareis": "sociabilizar",
    "sociabilizarem": "sociabilizar",
    "sociabilizaremos": "sociabilizar",
    "sociabilizares": "sociabilizar",
    "sociabilizaria": "sociabilizar",
    "sociabilizariam": "sociabilizar",
    "sociabilizarias": "sociabilizar",
    "sociabilizarmo": "sociabilizar",
    "sociabilizarmos": "sociabilizar",
    "sociabilizará": "sociabilizar",
    "sociabilizarás": "sociabilizar",
    "sociabilizarão": "sociabilizar",
    "sociabilizaríamos": "sociabilizar",
    "sociabilizaríeis": "sociabilizar",
    "sociabilizas": "sociabilizar",
    "sociabilizasse": "sociabilizar",
    "sociabilizassem": "sociabilizar",
    "sociabilizasses": "sociabilizar",
    "sociabilizaste": "sociabilizar",
    "sociabilizastes": "sociabilizar",
    "sociabilizava": "sociabilizar",
    "sociabilizavam": "sociabilizar",
    "sociabilizavas": "sociabilizar",
    "sociabilizações": "sociabilização",
    "sociabilize": "sociabilizar",
    "sociabilizei": "sociabilizar",
    "sociabilizeis": "sociabilizar",
    "sociabilizem": "sociabilizar",
    "sociabilizemo": "sociabilizar",
    "sociabilizemos": "sociabilizar",
    "sociabilizes": "sociabilizar",
    "sociabilizo": "sociabilizar",
    "sociabilizou": "sociabilizar",
    "sociabilizá": "sociabilizar",
    "sociabilizámo": "sociabilizar",
    "sociabilizámos": "sociabilizar",
    "sociabilizáramo": "sociabilizar",
    "sociabilizáramos": "sociabilizar",
    "sociabilizárei": "sociabilizar",
    "sociabilizáreis": "sociabilizar",
    "sociabilizásseis": "sociabilizar",
    "sociabilizássemos": "sociabilizar",
    "sociabilizávamo": "sociabilizar",
    "sociabilizávamos": "sociabilizar",
    "sociabilizávei": "sociabilizar",
    "sociabilizáveis": "sociabilizar",
    "sociais": "social",
    "socialidades": "socialidade",
    "socialismos": "socialismo",
    "socialistas": "socialista",
    "socialistazinha": "socialista",
    "socialistazinhas": "socialista",
    "socialistazinho": "socialista",
    "socialistazinhos": "socialista",
    "socialistazita": "socialista",
    "socialistazitas": "socialista",
    "socialistazito": "socialista",
    "socialistazitos": "socialista",
    "socializa": "socializar",
    "socializada": "socializar",
    "socializadas": "socializar",
    "socializado": "socializar",
    "socializados": "socializar",
    "socializai": "socializar",
    "socializais": "socializar",
    "socializam": "socializar",
    "socializamo": "socializar",
    "socializamos": "socializar",
    "socializando": "socializar",
    "socializantes": "socializante",
    "socializara": "socializar",
    "socializaram": "socializar",
    "socializaras": "socializar",
    "socializarde": "socializar",
    "socializardes": "socializar",
    "socializare": "socializar",
    "socializarei": "socializar",
    "socializareis": "socializar",
    "socializarem": "socializar",
    "socializaremos": "socializar",
    "socializares": "socializar",
    "socializaria": "socializar",
    "socializariam": "socializar",
    "socializarias": "socializar",
    "socializarmo": "socializar",
    "socializarmos": "socializar",
    "socializará": "socializar",
    "socializarás": "socializar",
    "socializarão": "socializar",
    "socializaríamos": "socializar",
    "socializaríeis": "socializar",
    "socializas": "socializar",
    "socializasse": "socializar",
    "socializassem": "socializar",
    "socializasses": "socializar",
    "socializaste": "socializar",
    "socializastes": "socializar",
    "socializava": "socializar",
    "socializavam": "socializar",
    "socializavas": "socializar",
    "socializações": "socialização",
    "socialize": "socializar",
    "socializei": "socializar",
    "socializeis": "socializar",
    "socializem": "socializar",
    "socializemo": "socializar",
    "socializemos": "socializar",
    "socializes": "socializar",
    "socializo": "socializar",
    "socializou": "socializar",
    "socializá": "socializar",
    "socializámo": "socializar",
    "socializámos": "socializar",
    "socializáramo": "socializar",
    "socializáramos": "socializar",
    "socializárei": "socializar",
    "socializáreis": "socializar",
    "socializásseis": "socializar",
    "socializássemos": "socializar",
    "socializávamo": "socializar",
    "socializávamos": "socializar",
    "socializávei": "socializar",
    "socializáveis": "socializável",
    "sociatrias": "sociatria",
    "sociazinha": "sócio",
    "sociazinhas": "sócio",
    "sociazita": "sócio",
    "sociazitas": "sócio",
    "sociedades": "sociedade",
    "sociedadezinha": "sociedade",
    "sociedadezinhas": "sociedade",
    "sociedadezita": "sociedade",
    "sociedadezitas": "sociedade",
    "societariados": "societariado",
    "societária": "societário",
    "societárias": "societário",
    "societários": "societário",
    "sociocracias": "sociocracia",
    "socioculturais": "sociocultural",
    "sociodramas": "sociodrama",
    "sociofilias": "sociofilia",
    "sociofobias": "sociofobia",
    "sociogenias": "sociogenia",
    "sociografias": "sociografia",
    "sociogramas": "sociograma",
    "sociolaborais": "sociolaboral",
    "sociolatrias": "sociolatria",
    "sociolinguísticas": "sociolinguística",
    "sociologias": "sociologia",
    "sociologismos": "sociologismo",
    "sociologistas": "sociologista",
    "sociologistazinha": "sociologista",
    "sociologistazinhas": "sociologista",
    "sociologistazinho": "sociologista",
    "sociologistazinhos": "sociologista",
    "sociologistazita": "sociologista",
    "sociologistazitas": "sociologista",
    "sociologistazito": "sociologista",
    "sociologistazitos": "sociologista",
    "sociológica": "sociológico",
    "sociológicas": "sociológico",
    "sociológicos": "sociológico",
    "sociometrias": "sociometria",
    "sociopatologias": "sociopatologia",
    "sociopolítica": "sociopolítico",
    "sociopolíticas": "sociopolítico",
    "sociopolíticos": "sociopolítico",
    "socioprofissionais": "socioprofissional",
    "sociotécnicas": "sociotécnica",
    "sociozinho": "sócio",
    "sociozinhos": "sócio",
    "sociozito": "sócio",
    "sociozitos": "sócio",
    "sociáveis": "sociável",
    "socióloga": "sociólogo",
    "sociólogas": "sociólogo",
    "sociólogos": "sociólogo",
    "soclos": "soclo",
    "soco": "socar",
    "socorra": "socorrer",
    "socorrais": "socorrer",
    "socorram": "socorrer",
    "socorramo": "socorrer",
    "socorramos": "socorrer",
    "socorras": "socorrer",
    "socorre": "socorrer",
    "socorredora": "socorredor",
    "socorredoras": "socorredor",
    "socorredores": "socorredor",
    "socorrei": "socorrer",
    "socorreis": "socorrer",
    "socorrem": "socorrer",
    "socorremo": "socorrer",
    "socorremos": "socorrer",
    "socorrendo": "socorrer",
    "socorrera": "socorrer",
    "socorreram": "socorrer",
    "socorreras": "socorrer",
    "socorrerde": "socorrer",
    "socorrerdes": "socorrer",
    "socorrere": "socorrer",
    "socorrerei": "socorrer",
    "socorrereis": "socorrer",
    "socorrerem": "socorrer",
    "socorreremos": "socorrer",
    "socorreres": "socorrer",
    "socorreria": "socorrer",
    "socorreriam": "socorrer",
    "socorrerias": "socorrer",
    "socorrermo": "socorrer",
    "socorrermos": "socorrer",
    "socorrerá": "socorrer",
    "socorrerás": "socorrer",
    "socorrerão": "socorrer",
    "socorreríamos": "socorrer",
    "socorreríeis": "socorrer",
    "socorres": "socorrer",
    "socorresse": "socorrer",
    "socorressem": "socorrer",
    "socorresses": "socorrer",
    "socorreste": "socorrer",
    "socorrestes": "socorrer",
    "socorreu": "socorrer",
    "socorri": "socorrer",
    "socorria": "socorrer",
    "socorriam": "socorrer",
    "socorrias": "socorrer",
    "socorrida": "socorrido",
    "socorridas": "socorrido",
    "socorrido": "socorrer",
    "socorridos": "socorrido",
    "socorrimentos": "socorrimento",
    "socorrismos": "socorrismo",
    "socorristas": "socorrista",
    "socorro": "socorrer",
    "socorros": "socorro",
    "socorrê": "socorrer",
    "socorrêramo": "socorrer",
    "socorrêramos": "socorrer",
    "socorrêrei": "socorrer",
    "socorrêreis": "socorrer",
    "socorrêsseis": "socorrer",
    "socorrêssemos": "socorrer",
    "socorríamo": "socorrer",
    "socorríamos": "socorrer",
    "socorríei": "socorrer",
    "socorríeis": "socorrer",
    "socos": "soco",
    "socotorina": "socotorino",
    "socotorinas": "socotorino",
    "socotorinos": "socotorino",
    "socou": "socar",
    "socratismos": "socratismo",
    "socrática": "socrático",
    "socráticas": "socrático",
    "socráticos": "socrático",
    "socá": "socar",
    "socámo": "socar",
    "socámos": "socar",
    "socáramo": "socar",
    "socáramos": "socar",
    "socárei": "socar",
    "socáreis": "socar",
    "socásseis": "socar",
    "socássemos": "socar",
    "socávamo": "socar",
    "socávamos": "socar",
    "socávei": "socar",
    "socáveis": "socar",
    "sodalites": "sodalite",
    "sodalícios": "sodalício",
    "sodas": "soda",
    "sodomias": "sodomia",
    "sodomitas": "sodomita",
    "sodomiza": "sodomizar",
    "sodomizada": "sodomizar",
    "sodomizadas": "sodomizar",
    "sodomizado": "sodomizar",
    "sodomizados": "sodomizar",
    "sodomizai": "sodomizar",
    "sodomizais": "sodomizar",
    "sodomizam": "sodomizar",
    "sodomizamo": "sodomizar",
    "sodomizamos": "sodomizar",
    "sodomizando": "sodomizar",
    "sodomizara": "sodomizar",
    "sodomizaram": "sodomizar",
    "sodomizaras": "sodomizar",
    "sodomizarde": "sodomizar",
    "sodomizardes": "sodomizar",
    "sodomizare": "sodomizar",
    "sodomizarei": "sodomizar",
    "sodomizareis": "sodomizar",
    "sodomizarem": "sodomizar",
    "sodomizaremos": "sodomizar",
    "sodomizares": "sodomizar",
    "sodomizaria": "sodomizar",
    "sodomizariam": "sodomizar",
    "sodomizarias": "sodomizar",
    "sodomizarmo": "sodomizar",
    "sodomizarmos": "sodomizar",
    "sodomizará": "sodomizar",
    "sodomizarás": "sodomizar",
    "sodomizarão": "sodomizar",
    "sodomizaríamos": "sodomizar",
    "sodomizaríeis": "sodomizar",
    "sodomizas": "sodomizar",
    "sodomizasse": "sodomizar",
    "sodomizassem": "sodomizar",
    "sodomizasses": "sodomizar",
    "sodomizaste": "sodomizar",
    "sodomizastes": "sodomizar",
    "sodomizava": "sodomizar",
    "sodomizavam": "sodomizar",
    "sodomizavas": "sodomizar",
    "sodomize": "sodomizar",
    "sodomizei": "sodomizar",
    "sodomizeis": "sodomizar",
    "sodomizem": "sodomizar",
    "sodomizemo": "sodomizar",
    "sodomizemos": "sodomizar",
    "sodomizes": "sodomizar",
    "sodomizo": "sodomizar",
    "sodomizou": "sodomizar",
    "sodomizá": "sodomizar",
    "sodomizámo": "sodomizar",
    "sodomizámos": "sodomizar",
    "sodomizáramo": "sodomizar",
    "sodomizáramos": "sodomizar",
    "sodomizárei": "sodomizar",
    "sodomizáreis": "sodomizar",
    "sodomizásseis": "sodomizar",
    "sodomizássemos": "sodomizar",
    "sodomizávamo": "sodomizar",
    "sodomizávamos": "sodomizar",
    "sodomizávei": "sodomizar",
    "sodomizáveis": "sodomizar",
    "sodomítica": "sodomítico",
    "sodomíticas": "sodomítico",
    "sodomíticos": "sodomítico",
    "sodras": "sodra",
    "sodómica": "sodómico",
    "sodómicas": "sodómico",
    "sodómicos": "sodómico",
    "soe": "soar",
    "soei": "soer",
    "soeis": "soer",
    "soem": "soer",
    "soemo": "soer",
    "soemos": "soer",
    "soendo": "soer",
    "soera": "soer",
    "soeram": "soer",
    "soeras": "soer",
    "soerdes": "soer",
    "soerei": "soer",
    "soereis": "soer",
    "soerem": "soer",
    "soeremos": "soer",
    "soeres": "soer",
    "soerga": "soerguer",
    "soergais": "soerguer",
    "soergam": "soerguer",
    "soergamo": "soerguer",
    "soergamos": "soerguer",
    "soergas": "soerguer",
    "soergo": "soerguer",
    "soergue": "soerguer",
    "soerguei": "soerguer",
    "soergueis": "soerguer",
    "soerguem": "soerguer",
    "soerguemo": "soerguer",
    "soerguemos": "soerguer",
    "soerguendo": "soerguer",
    "soerguera": "soerguer",
    "soergueram": "soerguer",
    "soergueras": "soerguer",
    "soerguerde": "soerguer",
    "soerguerdes": "soerguer",
    "soerguere": "soerguer",
    "soerguerei": "soerguer",
    "soerguereis": "soerguer",
    "soerguerem": "soerguer",
    "soergueremos": "soerguer",
    "soergueres": "soerguer",
    "soergueria": "soerguer",
    "soergueriam": "soerguer",
    "soerguerias": "soerguer",
    "soerguermo": "soerguer",
    "soerguermos": "soerguer",
    "soerguerá": "soerguer",
    "soerguerás": "soerguer",
    "soerguerão": "soerguer",
    "soergueríamos": "soerguer",
    "soergueríeis": "soerguer",
    "soergues": "soerguer",
    "soerguesse": "soerguer",
    "soerguessem": "soerguer",
    "soerguesses": "soerguer",
    "soergueste": "soerguer",
    "soerguestes": "soerguer",
    "soergueu": "soerguer",
    "soergui": "soerguer",
    "soerguia": "soerguer",
    "soerguiam": "soerguer",
    "soerguias": "soerguer",
    "soerguida": "soerguido",
    "soerguidas": "soerguido",
    "soerguido": "soerguer",
    "soerguidos": "soerguido",
    "soerguê": "soerguer",
    "soerguêramo": "soerguer",
    "soerguêramos": "soerguer",
    "soerguêrei": "soerguer",
    "soerguêreis": "soerguer",
    "soerguêsseis": "soerguer",
    "soerguêssemos": "soerguer",
    "soerguíamo": "soerguer",
    "soerguíamos": "soerguer",
    "soerguíei": "soerguer",
    "soerguíeis": "soerguer",
    "soeria": "soer",
    "soeriam": "soer",
    "soerias": "soer",
    "soermo": "soer",
    "soermos": "soer",
    "soerá": "soer",
    "soerás": "soer",
    "soerão": "soer",
    "soeríamos": "soer",
    "soeríeis": "soer",
    "soes": "soar",
    "soesse": "soer",
    "soessem": "soer",
    "soesses": "soer",
    "soeste": "soer",
    "soestes": "soer",
    "soeu": "soer",
    "soezes": "soez",
    "sofazinho": "sofá",
    "sofazinhos": "sofá",
    "sofazito": "sofá",
    "sofazitos": "sofá",
    "sofisma": "sofismar",
    "sofismada": "sofismar",
    "sofismadas": "sofismar",
    "sofismado": "sofismar",
    "sofismados": "sofismar",
    "sofismai": "sofismar",
    "sofismais": "sofismar",
    "sofismam": "sofismar",
    "sofismamo": "sofismar",
    "sofismamos": "sofismar",
    "sofismando": "sofismar",
    "sofismara": "sofismar",
    "sofismaram": "sofismar",
    "sofismaras": "sofismar",
    "sofismarde": "sofismar",
    "sofismardes": "sofismar",
    "sofismare": "sofismar",
    "sofismarei": "sofismar",
    "sofismareis": "sofismar",
    "sofismarem": "sofismar",
    "sofismaremos": "sofismar",
    "sofismares": "sofismar",
    "sofismaria": "sofismar",
    "sofismariam": "sofismar",
    "sofismarias": "sofismar",
    "sofismarmo": "sofismar",
    "sofismarmos": "sofismar",
    "sofismará": "sofismar",
    "sofismarás": "sofismar",
    "sofismarão": "sofismar",
    "sofismaríamos": "sofismar",
    "sofismaríeis": "sofismar",
    "sofismas": "sofismar",
    "sofismasse": "sofismar",
    "sofismassem": "sofismar",
    "sofismasses": "sofismar",
    "sofismaste": "sofismar",
    "sofismastes": "sofismar",
    "sofismava": "sofismar",
    "sofismavam": "sofismar",
    "sofismavas": "sofismar",
    "sofisme": "sofismar",
    "sofismei": "sofismar",
    "sofismeis": "sofismar",
    "sofismem": "sofismar",
    "sofismemo": "sofismar",
    "sofismemos": "sofismar",
    "sofismes": "sofismar",
    "sofismo": "sofismar",
    "sofismou": "sofismar",
    "sofismá": "sofismar",
    "sofismámo": "sofismar",
    "sofismámos": "sofismar",
    "sofismáramo": "sofismar",
    "sofismáramos": "sofismar",
    "sofismárei": "sofismar",
    "sofismáreis": "sofismar",
    "sofismásseis": "sofismar",
    "sofismássemos": "sofismar",
    "sofismávamo": "sofismar",
    "sofismávamos": "sofismar",
    "sofismávei": "sofismar",
    "sofismáveis": "sofismável",
    "sofistarias": "sofistaria",
    "sofistas": "sofista",
    "sofistazinha": "sofista",
    "sofistazinhas": "sofista",
    "sofistazinho": "sofista",
    "sofistazinhos": "sofista",
    "sofistazita": "sofista",
    "sofistazitas": "sofista",
    "sofistazito": "sofista",
    "sofistazitos": "sofista",
    "sofistica": "sofisticar",
    "sofisticada": "sofisticar",
    "sofisticadas": "sofisticar",
    "sofisticado": "sofisticar",
    "sofisticados": "sofisticar",
    "sofisticadíssima": "sofisticado",
    "sofisticadíssimas": "sofisticado",
    "sofisticadíssimo": "sofisticado",
    "sofisticadíssimos": "sofisticado",
    "sofisticai": "sofisticar",
    "sofisticais": "sofisticar",
    "sofisticam": "sofisticar",
    "sofisticamo": "sofisticar",
    "sofisticamos": "sofisticar",
    "sofisticando": "sofisticar",
    "sofisticara": "sofisticar",
    "sofisticaram": "sofisticar",
    "sofisticaras": "sofisticar",
    "sofisticarde": "sofisticar",
    "sofisticardes": "sofisticar",
    "sofisticare": "sofisticar",
    "sofisticarei": "sofisticar",
    "sofisticareis": "sofisticar",
    "sofisticarem": "sofisticar",
    "sofisticaremos": "sofisticar",
    "sofisticares": "sofisticar",
    "sofisticaria": "sofisticar",
    "sofisticariam": "sofisticar",
    "sofisticarias": "sofisticaria",
    "sofisticarmo": "sofisticar",
    "sofisticarmos": "sofisticar",
    "sofisticará": "sofisticar",
    "sofisticarás": "sofisticar",
    "sofisticarão": "sofisticar",
    "sofisticaríamos": "sofisticar",
    "sofisticaríeis": "sofisticar",
    "sofisticas": "sofisticar",
    "sofisticasse": "sofisticar",
    "sofisticassem": "sofisticar",
    "sofisticasses": "sofisticar",
    "sofisticaste": "sofisticar",
    "sofisticastes": "sofisticar",
    "sofisticava": "sofisticar",
    "sofisticavam": "sofisticar",
    "sofisticavas": "sofisticar",
    "sofisticações": "sofisticação",
    "sofistico": "sofisticar",
    "sofisticou": "sofisticar",
    "sofisticá": "sofisticar",
    "sofisticámo": "sofisticar",
    "sofisticámos": "sofisticar",
    "sofisticáramo": "sofisticar",
    "sofisticáramos": "sofisticar",
    "sofisticárei": "sofisticar",
    "sofisticáreis": "sofisticar",
    "sofisticásseis": "sofisticar",
    "sofisticássemos": "sofisticar",
    "sofisticávamo": "sofisticar",
    "sofisticávamos": "sofisticar",
    "sofisticávei": "sofisticar",
    "sofisticáveis": "sofisticar",
    "sofistificadora": "sofistificador",
    "sofistificadoras": "sofistificador",
    "sofistificadores": "sofistificador",
    "sofistique": "sofisticar",
    "sofistiquei": "sofisticar",
    "sofistiqueis": "sofisticar",
    "sofistiquem": "sofisticar",
    "sofistiquemo": "sofisticar",
    "sofistiquemos": "sofisticar",
    "sofistiques": "sofisticar",
    "sofitos": "sofito",
    "sofocliana": "sofocliano",
    "sofoclianas": "sofocliano",
    "sofoclianos": "sofocliano",
    "sofomanazinha": "sofómano",
    "sofomanazinhas": "sofómano",
    "sofomanazita": "sofómano",
    "sofomanazitas": "sofómano",
    "sofomaniacazinha": "sofomaníaco",
    "sofomaniacazinhas": "sofomaníaco",
    "sofomaniacazita": "sofomaníaco",
    "sofomaniacazitas": "sofomaníaco",
    "sofomaniacozinho": "sofomaníaco",
    "sofomaniacozinhos": "sofomaníaco",
    "sofomaniacozito": "sofomaníaco",
    "sofomaniacozitos": "sofomaníaco",
    "sofomanias": "sofomania",
    "sofomanozinho": "sofómano",
    "sofomanozinhos": "sofómano",
    "sofomanozito": "sofómano",
    "sofomanozitos": "sofómano",
    "sofomaníaca": "sofomaníaco",
    "sofomaníacas": "sofomaníaco",
    "sofomaníacos": "sofomaníaco",
    "sofra": "sofrer",
    "sofrais": "sofrer",
    "sofralda": "sofraldar",
    "sofraldada": "sofraldar",
    "sofraldadas": "sofraldar",
    "sofraldado": "sofraldar",
    "sofraldados": "sofraldar",
    "sofraldai": "sofraldar",
    "sofraldais": "sofraldar",
    "sofraldam": "sofraldar",
    "sofraldamo": "sofraldar",
    "sofraldamos": "sofraldar",
    "sofraldando": "sofraldar",
    "sofraldara": "sofraldar",
    "sofraldaram": "sofraldar",
    "sofraldaras": "sofraldar",
    "sofraldarde": "sofraldar",
    "sofraldardes": "sofraldar",
    "sofraldare": "sofraldar",
    "sofraldarei": "sofraldar",
    "sofraldareis": "sofraldar",
    "sofraldarem": "sofraldar",
    "sofraldaremos": "sofraldar",
    "sofraldares": "sofraldar",
    "sofraldaria": "sofraldar",
    "sofraldariam": "sofraldar",
    "sofraldarias": "sofraldar",
    "sofraldarmo": "sofraldar",
    "sofraldarmos": "sofraldar",
    "sofraldará": "sofraldar",
    "sofraldarás": "sofraldar",
    "sofraldarão": "sofraldar",
    "sofraldaríamos": "sofraldar",
    "sofraldaríeis": "sofraldar",
    "sofraldas": "sofraldar",
    "sofraldasse": "sofraldar",
    "sofraldassem": "sofraldar",
    "sofraldasses": "sofraldar",
    "sofraldaste": "sofraldar",
    "sofraldastes": "sofraldar",
    "sofraldava": "sofraldar",
    "sofraldavam": "sofraldar",
    "sofraldavas": "sofraldar",
    "sofralde": "sofraldar",
    "sofraldei": "sofraldar",
    "sofraldeis": "sofraldar",
    "sofraldem": "sofraldar",
    "sofraldemo": "sofraldar",
    "sofraldemos": "sofraldar",
    "sofraldes": "sofraldar",
    "sofraldo": "sofraldar",
    "sofraldou": "sofraldar",
    "sofraldá": "sofraldar",
    "sofraldámo": "sofraldar",
    "sofraldámos": "sofraldar",
    "sofraldáramo": "sofraldar",
    "sofraldáramos": "sofraldar",
    "sofraldárei": "sofraldar",
    "sofraldáreis": "sofraldar",
    "sofraldásseis": "sofraldar",
    "sofraldássemos": "sofraldar",
    "sofraldávamo": "sofraldar",
    "sofraldávamos": "sofraldar",
    "sofraldávei": "sofraldar",
    "sofraldáveis": "sofraldar",
    "sofram": "sofrer",
    "soframo": "sofrer",
    "soframos": "sofrer",
    "sofras": "sofrer",
    "sofre": "sofrer",
    "sofreada": "sofrear",
    "sofreadas": "sofrear",
    "sofreado": "sofrear",
    "sofreados": "sofrear",
    "sofreai": "sofrear",
    "sofreais": "sofrear",
    "sofreamo": "sofrear",
    "sofreamos": "sofrear",
    "sofreando": "sofrear",
    "sofreara": "sofrear",
    "sofrearam": "sofrear",
    "sofrearas": "sofrear",
    "sofrearde": "sofrear",
    "sofreardes": "sofrear",
    "sofreare": "sofrear",
    "sofrearei": "sofrear",
    "sofreareis": "sofrear",
    "sofrearem": "sofrear",
    "sofrearemos": "sofrear",
    "sofreares": "sofrear",
    "sofrearia": "sofrear",
    "sofreariam": "sofrear",
    "sofrearias": "sofrear",
    "sofrearmo": "sofrear",
    "sofrearmos": "sofrear",
    "sofreará": "sofrear",
    "sofrearás": "sofrear",
    "sofrearão": "sofrear",
    "sofrearíamos": "sofrear",
    "sofrearíeis": "sofrear",
    "sofreasse": "sofrear",
    "sofreassem": "sofrear",
    "sofreasses": "sofrear",
    "sofreaste": "sofrear",
    "sofreastes": "sofrear",
    "sofreava": "sofrear",
    "sofreavam": "sofrear",
    "sofreavas": "sofrear",
    "sofredora": "sofredor",
    "sofredoras": "sofredor",
    "sofredores": "sofredor",
    "sofreei": "sofrear",
    "sofreeis": "sofrear",
    "sofreemo": "sofrear",
    "sofreemos": "sofrear",
    "sofreguices": "sofreguice",
    "sofreguidões": "sofreguidão",
    "sofrei": "sofrer",
    "sofreia": "sofrear",
    "sofreiam": "sofrear",
    "sofreias": "sofrear",
    "sofreie": "sofrear",
    "sofreiem": "sofrear",
    "sofreies": "sofrear",
    "sofreio": "sofrear",
    "sofreis": "sofrer",
    "sofrem": "sofrer",
    "sofremo": "sofrer",
    "sofremos": "sofrer",
    "sofrendo": "sofrer",
    "sofreou": "sofrear",
    "sofrera": "sofrer",
    "sofreram": "sofrer",
    "sofreras": "sofrer",
    "sofrerde": "sofrer",
    "sofrerdes": "sofrer",
    "sofrere": "sofrer",
    "sofrerei": "sofrer",
    "sofrereis": "sofrer",
    "sofrerem": "sofrer",
    "sofreremos": "sofrer",
    "sofreres": "sofrer",
    "sofreria": "sofrer",
    "sofreriam": "sofrer",
    "sofrerias": "sofrer",
    "sofrermo": "sofrer",
    "sofrermos": "sofrer",
    "sofrerá": "sofrer",
    "sofrerás": "sofrer",
    "sofrerão": "sofrer",
    "sofreríamos": "sofrer",
    "sofreríeis": "sofrer",
    "sofres": "sofrer",
    "sofresse": "sofrer",
    "sofressem": "sofrer",
    "sofresses": "sofrer",
    "sofreste": "sofrer",
    "sofrestes": "sofrer",
    "sofreu": "sofrer",
    "sofreá": "sofrear",
    "sofreámo": "sofrear",
    "sofreámos": "sofrear",
    "sofreáramo": "sofrear",
    "sofreáramos": "sofrear",
    "sofreárei": "sofrear",
    "sofreáreis": "sofrear",
    "sofreásseis": "sofrear",
    "sofreássemos": "sofrear",
    "sofreávamo": "sofrear",
    "sofreávamos": "sofrear",
    "sofreávei": "sofrear",
    "sofreáveis": "sofreável",
    "sofri": "sofrer",
    "sofria": "sofrer",
    "sofriam": "sofrer",
    "sofrias": "sofrer",
    "sofrida": "sofrido",
    "sofridas": "sofrido",
    "sofrido": "sofrer",
    "sofridos": "sofrido",
    "sofrimentos": "sofrimento",
    "sofro": "sofrer",
    "sofrés": "sofré",
    "sofrê": "sofrer",
    "sofrêramo": "sofrer",
    "sofrêramos": "sofrer",
    "sofrêrei": "sofrer",
    "sofrêreis": "sofrer",
    "sofrês": "sofrê",
    "sofrêsseis": "sofrer",
    "sofrêssemos": "sofrer",
    "sofríamo": "sofrer",
    "sofríamos": "sofrer",
    "sofríei": "sofrer",
    "sofríeis": "sofrer",
    "sofríveis": "sofrível",
    "softwares": "software",
    "sofás": "sofá",
    "sofística": "sofístico",
    "sofísticas": "sofístico",
    "sofísticos": "sofístico",
    "sofómana": "sofómano",
    "sofómanas": "sofómano",
    "sofómanos": "sofómano",
    "soga": "sogar",
    "sogada": "sogar",
    "sogadas": "sogar",
    "sogado": "sogar",
    "sogados": "sogar",
    "sogai": "sogar",
    "sogais": "sogar",
    "sogam": "sogar",
    "sogamo": "sogar",
    "sogamos": "sogar",
    "sogando": "sogar",
    "sogara": "sogar",
    "sogaram": "sogar",
    "sogaras": "sogar",
    "sogarde": "sogar",
    "sogardes": "sogar",
    "sogare": "sogar",
    "sogarei": "sogar",
    "sogareis": "sogar",
    "sogarem": "sogar",
    "sogaremos": "sogar",
    "sogares": "sogar",
    "sogaria": "sogar",
    "sogariam": "sogar",
    "sogarias": "sogar",
    "sogarmo": "sogar",
    "sogarmos": "sogar",
    "sogará": "sogar",
    "sogarás": "sogar",
    "sogarão": "sogar",
    "sogaríamos": "sogar",
    "sogaríeis": "sogar",
    "sogas": "sogar",
    "sogasse": "sogar",
    "sogassem": "sogar",
    "sogasses": "sogar",
    "sogaste": "sogar",
    "sogastes": "sogar",
    "sogava": "sogar",
    "sogavam": "sogar",
    "sogavas": "sogar",
    "sogo": "sogar",
    "sogou": "sogar",
    "sogra": "sogro",
    "sogras": "sogro",
    "sogros": "sogro",
    "sogue": "sogar",
    "soguei": "sogar",
    "sogueis": "sogar",
    "soguem": "sogar",
    "soguemo": "sogar",
    "soguemos": "sogar",
    "sogues": "sogar",
    "sogá": "sogar",
    "sogámo": "sogar",
    "sogámos": "sogar",
    "sogáramo": "sogar",
    "sogáramos": "sogar",
    "sogárei": "sogar",
    "sogáreis": "sogar",
    "sogásseis": "sogar",
    "sogássemos": "sogar",
    "sogávamo": "sogar",
    "sogávamos": "sogar",
    "sogávei": "sogar",
    "sogáveis": "sogar",
    "soi": "ser",
    "soidades": "soidade",
    "soideiras": "soideira",
    "soidosa": "soidoso",
    "soidosas": "soidoso",
    "soidosos": "soidoso",
    "soidões": "soidão",
    "soirées": "soirée",
    "sois": "ser",
    "soizinhos": "sol",
    "soizitos": "sol",
    "sojas": "soja",
    "sojoadas": "sojoada",
    "solada": "solado",
    "soladas": "solado",
    "solados": "solado",
    "solagens": "solagem",
    "solamas": "solama",
    "solaninas": "solanina",
    "solanáceas": "solanácea",
    "solaníneas": "solanínea",
    "solapa": "solapar",
    "solapada": "solapar",
    "solapadas": "solapar",
    "solapado": "solapar",
    "solapados": "solapar",
    "solapai": "solapar",
    "solapais": "solapar",
    "solapam": "solapar",
    "solapamentos": "solapamento",
    "solapamo": "solapar",
    "solapamos": "solapar",
    "solapando": "solapar",
    "solapara": "solapar",
    "solaparam": "solapar",
    "solaparas": "solapar",
    "solaparde": "solapar",
    "solapardes": "solapar",
    "solapare": "solapar",
    "solaparei": "solapar",
    "solapareis": "solapar",
    "solaparem": "solapar",
    "solaparemos": "solapar",
    "solapares": "solapar",
    "solaparia": "solapar",
    "solapariam": "solapar",
    "solaparias": "solapar",
    "solaparmo": "solapar",
    "solaparmos": "solapar",
    "solapará": "solapar",
    "solaparás": "solapar",
    "solaparão": "solapar",
    "solaparíamos": "solapar",
    "solaparíeis": "solapar",
    "solapas": "solapar",
    "solapasse": "solapar",
    "solapassem": "solapar",
    "solapasses": "solapar",
    "solapaste": "solapar",
    "solapastes": "solapar",
    "solapava": "solapar",
    "solapavam": "solapar",
    "solapavas": "solapar",
    "solape": "solapar",
    "solapei": "solapar",
    "solapeis": "solapar",
    "solapem": "solapar",
    "solapemo": "solapar",
    "solapemos": "solapar",
    "solapes": "solapar",
    "solapo": "solapar",
    "solapou": "solapar",
    "solapá": "solapar",
    "solapámo": "solapar",
    "solapámos": "solapar",
    "solapáramo": "solapar",
    "solapáramos": "solapar",
    "solapárei": "solapar",
    "solapáreis": "solapar",
    "solapásseis": "solapar",
    "solapássemos": "solapar",
    "solapávamo": "solapar",
    "solapávamos": "solapar",
    "solapávei": "solapar",
    "solapáveis": "solapar",
    "solarega": "solarego",
    "solaregas": "solarego",
    "solaregos": "solarego",
    "solarenga": "solarengo",
    "solarengas": "solarengo",
    "solarengos": "solarengo",
    "solares": "solar",
    "solarias": "solaria",
    "solariza": "solarizar",
    "solarizada": "solarizar",
    "solarizadas": "solarizar",
    "solarizado": "solarizar",
    "solarizados": "solarizar",
    "solarizai": "solarizar",
    "solarizais": "solarizar",
    "solarizam": "solarizar",
    "solarizamo": "solarizar",
    "solarizamos": "solarizar",
    "solarizando": "solarizar",
    "solarizara": "solarizar",
    "solarizaram": "solarizar",
    "solarizaras": "solarizar",
    "solarizarde": "solarizar",
    "solarizardes": "solarizar",
    "solarizare": "solarizar",
    "solarizarei": "solarizar",
    "solarizareis": "solarizar",
    "solarizarem": "solarizar",
    "solarizaremos": "solarizar",
    "solarizares": "solarizar",
    "solarizaria": "solarizar",
    "solarizariam": "solarizar",
    "solarizarias": "solarizar",
    "solarizarmo": "solarizar",
    "solarizarmos": "solarizar",
    "solarizará": "solarizar",
    "solarizarás": "solarizar",
    "solarizarão": "solarizar",
    "solarizaríamos": "solarizar",
    "solarizaríeis": "solarizar",
    "solarizas": "solarizar",
    "solarizasse": "solarizar",
    "solarizassem": "solarizar",
    "solarizasses": "solarizar",
    "solarizaste": "solarizar",
    "solarizastes": "solarizar",
    "solarizava": "solarizar",
    "solarizavam": "solarizar",
    "solarizavas": "solarizar",
    "solarizações": "solarização",
    "solarize": "solarizar",
    "solarizei": "solarizar",
    "solarizeis": "solarizar",
    "solarizem": "solarizar",
    "solarizemo": "solarizar",
    "solarizemos": "solarizar",
    "solarizes": "solarizar",
    "solarizo": "solarizar",
    "solarizou": "solarizar",
    "solarizá": "solarizar",
    "solarizámo": "solarizar",
    "solarizámos": "solarizar",
    "solarizáramo": "solarizar",
    "solarizáramos": "solarizar",
    "solarizárei": "solarizar",
    "solarizáreis": "solarizar",
    "solarizásseis": "solarizar",
    "solarizássemos": "solarizar",
    "solarizávamo": "solarizar",
    "solarizávamos": "solarizar",
    "solarizávei": "solarizar",
    "solarizáveis": "solarizar",
    "solarímetros": "solarímetro",
    "solas": "sola",
    "solaus": "solau",
    "solavanca": "solavancar",
    "solavancada": "solavancar",
    "solavancadas": "solavancar",
    "solavancado": "solavancar",
    "solavancados": "solavancar",
    "solavancais": "solavancar",
    "solavancam": "solavancar",
    "solavancamo": "solavancar",
    "solavancamos": "solavancar",
    "solavancando": "solavancar",
    "solavancara": "solavancar",
    "solavancaram": "solavancar",
    "solavancaras": "solavancar",
    "solavancardes": "solavancar",
    "solavancarei": "solavancar",
    "solavancareis": "solavancar",
    "solavancarem": "solavancar",
    "solavancaremos": "solavancar",
    "solavancares": "solavancar",
    "solavancaria": "solavancar",
    "solavancariam": "solavancar",
    "solavancarias": "solavancar",
    "solavancarmo": "solavancar",
    "solavancarmos": "solavancar",
    "solavancará": "solavancar",
    "solavancarás": "solavancar",
    "solavancarão": "solavancar",
    "solavancaríamos": "solavancar",
    "solavancaríeis": "solavancar",
    "solavancas": "solavancar",
    "solavancasse": "solavancar",
    "solavancassem": "solavancar",
    "solavancasses": "solavancar",
    "solavancaste": "solavancar",
    "solavancastes": "solavancar",
    "solavancava": "solavancar",
    "solavancavam": "solavancar",
    "solavancavas": "solavancar",
    "solavanco": "solavancar",
    "solavancos": "solavanco",
    "solavancou": "solavancar",
    "solavancámo": "solavancar",
    "solavancámos": "solavancar",
    "solavancáramo": "solavancar",
    "solavancáramos": "solavancar",
    "solavancáreis": "solavancar",
    "solavancásseis": "solavancar",
    "solavancássemos": "solavancar",
    "solavancávamo": "solavancar",
    "solavancávamos": "solavancar",
    "solavancáveis": "solavancar",
    "solavanque": "solavancar",
    "solavanquei": "solavancar",
    "solavanqueis": "solavancar",
    "solavanquem": "solavancar",
    "solavanquemos": "solavancar",
    "solavanques": "solavancar",
    "solcrises": "solcris",
    "solda": "soldar",
    "soldada": "soldar",
    "soldadas": "soldar",
    "soldadeira": "soldadeiro",
    "soldadeiras": "soldadeiro",
    "soldadeiros": "soldadeiro",
    "soldadenca": "soldadenco",
    "soldadencas": "soldadenco",
    "soldadencos": "soldadenco",
    "soldadescas": "soldadesca",
    "soldadinha": "soldado",
    "soldadinhas": "soldado",
    "soldadinho": "soldado",
    "soldadinhos": "soldado",
    "soldadita": "soldado",
    "soldaditas": "soldado",
    "soldadito": "soldado",
    "soldaditos": "soldado",
    "soldado": "soldar",
    "soldadora": "soldador",
    "soldadoras": "soldador",
    "soldadores": "soldador",
    "soldados": "soldar",
    "soldaduras": "soldadura",
    "soldadíssima": "soldado",
    "soldadíssimas": "soldado",
    "soldadíssimo": "soldado",
    "soldadíssimos": "soldado",
    "soldagens": "soldagem",
    "soldai": "soldar",
    "soldais": "soldar",
    "soldam": "soldar",
    "soldamo": "soldar",
    "soldamos": "soldar",
    "soldando": "soldar",
    "soldanelas": "soldanela",
    "soldara": "soldar",
    "soldaram": "soldar",
    "soldaras": "soldar",
    "soldarde": "soldar",
    "soldardes": "soldar",
    "soldare": "soldar",
    "soldarei": "soldar",
    "soldareis": "soldar",
    "soldarem": "soldar",
    "soldaremos": "soldar",
    "soldares": "soldar",
    "soldaria": "soldar",
    "soldariam": "soldar",
    "soldarias": "soldar",
    "soldarmo": "soldar",
    "soldarmos": "soldar",
    "soldará": "soldar",
    "soldarás": "soldar",
    "soldarão": "soldar",
    "soldaríamos": "soldar",
    "soldaríeis": "soldar",
    "soldas": "soldar",
    "soldasse": "soldar",
    "soldassem": "soldar",
    "soldasses": "soldar",
    "soldaste": "soldar",
    "soldastes": "soldar",
    "soldava": "soldar",
    "soldavam": "soldar",
    "soldavas": "soldar",
    "solde": "soldar",
    "soldei": "soldar",
    "soldeis": "soldar",
    "soldem": "soldar",
    "soldemo": "soldar",
    "soldemos": "soldar",
    "soldes": "soldar",
    "soldo": "soldar",
    "soldos": "soldo",
    "soldou": "soldar",
    "soldras": "soldra",
    "soldá": "soldar",
    "soldámo": "soldar",
    "soldámos": "soldar",
    "soldáramo": "soldar",
    "soldáramos": "soldar",
    "soldárei": "soldar",
    "soldáreis": "soldar",
    "soldásseis": "soldar",
    "soldássemos": "soldar",
    "soldávamo": "soldar",
    "soldávamos": "soldar",
    "soldávei": "soldar",
    "soldáveis": "soldável",
    "soleares": "solear",
    "soleca": "solecar",
    "solecada": "solecar",
    "solecadas": "solecar",
    "solecado": "solecar",
    "solecados": "solecar",
    "solecai": "solecar",
    "solecais": "solecar",
    "solecam": "solecar",
    "solecamo": "solecar",
    "solecamos": "solecar",
    "solecando": "solecar",
    "solecara": "solecar",
    "solecaram": "solecar",
    "solecaras": "solecar",
    "solecarde": "solecar",
    "solecardes": "solecar",
    "solecare": "solecar",
    "solecarei": "solecar",
    "solecareis": "solecar",
    "solecarem": "solecar",
    "solecaremos": "solecar",
    "solecares": "solecar",
    "solecaria": "solecar",
    "solecariam": "solecar",
    "solecarias": "solecar",
    "solecarmo": "solecar",
    "solecarmos": "solecar",
    "solecará": "solecar",
    "solecarás": "solecar",
    "solecarão": "solecar",
    "solecaríamos": "solecar",
    "solecaríeis": "solecar",
    "solecas": "solecar",
    "solecasse": "solecar",
    "solecassem": "solecar",
    "solecasses": "solecar",
    "solecaste": "solecar",
    "solecastes": "solecar",
    "solecava": "solecar",
    "solecavam": "solecar",
    "solecavas": "solecar",
    "solecismos": "solecismo",
    "solecistas": "solecista",
    "soleco": "solecar",
    "solecou": "solecar",
    "solecá": "solecar",
    "solecámo": "solecar",
    "solecámos": "solecar",
    "solecáramo": "solecar",
    "solecáramos": "solecar",
    "solecárei": "solecar",
    "solecáreis": "solecar",
    "solecásseis": "solecar",
    "solecássemos": "solecar",
    "solecávamo": "solecar",
    "solecávamos": "solecar",
    "solecávei": "solecar",
    "solecáveis": "solecar",
    "soledades": "soledade",
    "soleiras": "soleira",
    "soleiros": "soleiro",
    "solenes": "solene",
    "solenidades": "solenidade",
    "soleniza": "solenizar",
    "solenizada": "solenizar",
    "solenizadas": "solenizar",
    "solenizado": "solenizar",
    "solenizadora": "solenizador",
    "solenizadoras": "solenizador",
    "solenizadores": "solenizador",
    "solenizados": "solenizar",
    "solenizai": "solenizar",
    "solenizais": "solenizar",
    "solenizam": "solenizar",
    "solenizamo": "solenizar",
    "solenizamos": "solenizar",
    "solenizando": "solenizar",
    "solenizara": "solenizar",
    "solenizaram": "solenizar",
    "solenizaras": "solenizar",
    "solenizarde": "solenizar",
    "solenizardes": "solenizar",
    "solenizare": "solenizar",
    "solenizarei": "solenizar",
    "solenizareis": "solenizar",
    "solenizarem": "solenizar",
    "solenizaremos": "solenizar",
    "solenizares": "solenizar",
    "solenizaria": "solenizar",
    "solenizariam": "solenizar",
    "solenizarias": "solenizar",
    "solenizarmo": "solenizar",
    "solenizarmos": "solenizar",
    "solenizará": "solenizar",
    "solenizarás": "solenizar",
    "solenizarão": "solenizar",
    "solenizaríamos": "solenizar",
    "solenizaríeis": "solenizar",
    "solenizas": "solenizar",
    "solenizasse": "solenizar",
    "solenizassem": "solenizar",
    "solenizasses": "solenizar",
    "solenizaste": "solenizar",
    "solenizastes": "solenizar",
    "solenizava": "solenizar",
    "solenizavam": "solenizar",
    "solenizavas": "solenizar",
    "solenizações": "solenização",
    "solenize": "solenizar",
    "solenizei": "solenizar",
    "solenizeis": "solenizar",
    "solenizem": "solenizar",
    "solenizemo": "solenizar",
    "solenizemos": "solenizar",
    "solenizes": "solenizar",
    "solenizo": "solenizar",
    "solenizou": "solenizar",
    "solenizá": "solenizar",
    "solenizámo": "solenizar",
    "solenizámos": "solenizar",
    "solenizáramo": "solenizar",
    "solenizáramos": "solenizar",
    "solenizárei": "solenizar",
    "solenizáreis": "solenizar",
    "solenizásseis": "solenizar",
    "solenizássemos": "solenizar",
    "solenizávamo": "solenizar",
    "solenizávamos": "solenizar",
    "solenizávei": "solenizar",
    "solenizáveis": "solenizar",
    "solenostelos": "solenostelo",
    "solenídeos": "solenídeo",
    "soleníssima": "solene",
    "soleníssimas": "solene",
    "soleníssimo": "solene",
    "soleníssimos": "solene",
    "solenócitos": "solenócito",
    "solenóglifos": "solenóglifo",
    "solenóides": "solenóide",
    "soleque": "solecar",
    "solequei": "solecar",
    "solequeis": "solecar",
    "solequem": "solecar",
    "solequemo": "solecar",
    "solequemos": "solecar",
    "soleques": "solecar",
    "solertes": "solerte",
    "soles": "sole",
    "soletas": "soleta",
    "soletra": "soletrar",
    "soletrada": "soletrar",
    "soletradas": "soletrar",
    "soletrado": "soletrar",
    "soletradora": "soletrador",
    "soletradoras": "soletrador",
    "soletradores": "soletrador",
    "soletrados": "soletrar",
    "soletrai": "soletrar",
    "soletrais": "soletrar",
    "soletram": "soletrar",
    "soletramo": "soletrar",
    "soletramos": "soletrar",
    "soletrando": "soletrar",
    "soletrara": "soletrar",
    "soletraram": "soletrar",
    "soletraras": "soletrar",
    "soletrarde": "soletrar",
    "soletrardes": "soletrar",
    "soletrare": "soletrar",
    "soletrarei": "soletrar",
    "soletrareis": "soletrar",
    "soletrarem": "soletrar",
    "soletraremos": "soletrar",
    "soletrares": "soletrar",
    "soletraria": "soletrar",
    "soletrariam": "soletrar",
    "soletrarias": "soletrar",
    "soletrarmo": "soletrar",
    "soletrarmos": "soletrar",
    "soletrará": "soletrar",
    "soletrarás": "soletrar",
    "soletrarão": "soletrar",
    "soletraríamos": "soletrar",
    "soletraríeis": "soletrar",
    "soletras": "soletrar",
    "soletrasse": "soletrar",
    "soletrassem": "soletrar",
    "soletrasses": "soletrar",
    "soletraste": "soletrar",
    "soletrastes": "soletrar",
    "soletrava": "soletrar",
    "soletravam": "soletrar",
    "soletravas": "soletrar",
    "soletrações": "soletração",
    "soletre": "soletrar",
    "soletrei": "soletrar",
    "soletreis": "soletrar",
    "soletrem": "soletrar",
    "soletremo": "soletrar",
    "soletremos": "soletrar",
    "soletres": "soletrar",
    "soletro": "soletrar",
    "soletrou": "soletrar",
    "soletrá": "soletrar",
    "soletrámo": "soletrar",
    "soletrámos": "soletrar",
    "soletráramo": "soletrar",
    "soletráramos": "soletrar",
    "soletrárei": "soletrar",
    "soletráreis": "soletrar",
    "soletrásseis": "soletrar",
    "soletrássemos": "soletrar",
    "soletrávamo": "soletrar",
    "soletrávamos": "soletrar",
    "soletrávei": "soletrar",
    "soletráveis": "soletrar",
    "soleva": "solevar",
    "solevada": "solevar",
    "solevadas": "solevar",
    "solevado": "solevar",
    "solevados": "solevar",
    "solevai": "solevar",
    "solevais": "solevar",
    "solevam": "solevar",
    "solevamentos": "solevamento",
    "solevamo": "solevar",
    "solevamos": "solevar",
    "solevando": "solevar",
    "solevanta": "solevantar",
    "solevantada": "solevantar",
    "solevantadas": "solevantar",
    "solevantado": "solevantar",
    "solevantados": "solevantar",
    "solevantai": "solevantar",
    "solevantais": "solevantar",
    "solevantam": "solevantar",
    "solevantamo": "solevantar",
    "solevantamos": "solevantar",
    "solevantando": "solevantar",
    "solevantara": "solevantar",
    "solevantaram": "solevantar",
    "solevantaras": "solevantar",
    "solevantarde": "solevantar",
    "solevantardes": "solevantar",
    "solevantare": "solevantar",
    "solevantarei": "solevantar",
    "solevantareis": "solevantar",
    "solevantarem": "solevantar",
    "solevantaremos": "solevantar",
    "solevantares": "solevantar",
    "solevantaria": "solevantar",
    "solevantariam": "solevantar",
    "solevantarias": "solevantar",
    "solevantarmo": "solevantar",
    "solevantarmos": "solevantar",
    "solevantará": "solevantar",
    "solevantarás": "solevantar",
    "solevantarão": "solevantar",
    "solevantaríamos": "solevantar",
    "solevantaríeis": "solevantar",
    "solevantas": "solevantar",
    "solevantasse": "solevantar",
    "solevantassem": "solevantar",
    "solevantasses": "solevantar",
    "solevantaste": "solevantar",
    "solevantastes": "solevantar",
    "solevantava": "solevantar",
    "solevantavam": "solevantar",
    "solevantavas": "solevantar",
    "solevante": "solevantar",
    "solevantei": "solevantar",
    "solevanteis": "solevantar",
    "solevantem": "solevantar",
    "solevantemo": "solevantar",
    "solevantemos": "solevantar",
    "solevantes": "solevantar",
    "solevanto": "solevantar",
    "solevantou": "solevantar",
    "solevantá": "solevantar",
    "solevantámo": "solevantar",
    "solevantámos": "solevantar",
    "solevantáramo": "solevantar",
    "solevantáramos": "solevantar",
    "solevantárei": "solevantar",
    "solevantáreis": "solevantar",
    "solevantásseis": "solevantar",
    "solevantássemos": "solevantar",
    "solevantávamo": "solevantar",
    "solevantávamos": "solevantar",
    "solevantávei": "solevantar",
    "solevantáveis": "solevantar",
    "solevara": "solevar",
    "solevaram": "solevar",
    "solevaras": "solevar",
    "solevarde": "solevar",
    "solevardes": "solevar",
    "solevare": "solevar",
    "solevarei": "solevar",
    "solevareis": "solevar",
    "solevarem": "solevar",
    "solevaremos": "solevar",
    "solevares": "solevar",
    "solevaria": "solevar",
    "solevariam": "solevar",
    "solevarias": "solevar",
    "solevarmo": "solevar",
    "solevarmos": "solevar",
    "solevará": "solevar",
    "solevarás": "solevar",
    "solevarão": "solevar",
    "solevaríamos": "solevar",
    "solevaríeis": "solevar",
    "solevas": "solevar",
    "solevasse": "solevar",
    "solevassem": "solevar",
    "solevasses": "solevar",
    "solevaste": "solevar",
    "solevastes": "solevar",
    "solevava": "solevar",
    "solevavam": "solevar",
    "solevavas": "solevar",
    "soleve": "solevar",
    "solevei": "solevar",
    "soleveis": "solevar",
    "solevem": "solevar",
    "solevemo": "solevar",
    "solevemos": "solevar",
    "soleves": "solevar",
    "solevo": "solevar",
    "solevou": "solevar",
    "solevá": "solevar",
    "solevámo": "solevar",
    "solevámos": "solevar",
    "soleváramo": "solevar",
    "soleváramos": "solevar",
    "solevárei": "solevar",
    "soleváreis": "solevar",
    "solevásseis": "solevar",
    "solevássemos": "solevar",
    "solevávamo": "solevar",
    "solevávamos": "solevar",
    "solevávei": "solevar",
    "soleváveis": "solevar",
    "solfa": "solfar",
    "solfada": "solfar",
    "solfadas": "solfar",
    "solfado": "solfar",
    "solfados": "solfar",
    "solfai": "solfar",
    "solfais": "solfar",
    "solfajações": "solfajação",
    "solfam": "solfar",
    "solfamo": "solfar",
    "solfamos": "solfar",
    "solfando": "solfar",
    "solfara": "solfar",
    "solfaram": "solfar",
    "solfaras": "solfar",
    "solfarde": "solfar",
    "solfardes": "solfar",
    "solfare": "solfar",
    "solfarei": "solfar",
    "solfareis": "solfar",
    "solfarem": "solfar",
    "solfaremos": "solfar",
    "solfares": "solfar",
    "solfaria": "solfar",
    "solfariam": "solfar",
    "solfarias": "solfar",
    "solfarmo": "solfar",
    "solfarmos": "solfar",
    "solfará": "solfar",
    "solfarás": "solfar",
    "solfarão": "solfar",
    "solfaríamos": "solfar",
    "solfaríeis": "solfar",
    "solfas": "solfar",
    "solfasse": "solfar",
    "solfassem": "solfar",
    "solfasses": "solfar",
    "solfaste": "solfar",
    "solfastes": "solfar",
    "solfataras": "solfatara",
    "solfava": "solfar",
    "solfavam": "solfar",
    "solfavas": "solfar",
    "solfe": "solfar",
    "solfei": "solfar",
    "solfeis": "solfar",
    "solfeja": "solfejar",
    "solfejada": "solfejar",
    "solfejadas": "solfejar",
    "solfejado": "solfejar",
    "solfejados": "solfejar",
    "solfejai": "solfejar",
    "solfejais": "solfejar",
    "solfejam": "solfejar",
    "solfejamo": "solfejar",
    "solfejamos": "solfejar",
    "solfejando": "solfejar",
    "solfejara": "solfejar",
    "solfejaram": "solfejar",
    "solfejaras": "solfejar",
    "solfejardes": "solfejar",
    "solfejarei": "solfejar",
    "solfejareis": "solfejar",
    "solfejarem": "solfejar",
    "solfejaremos": "solfejar",
    "solfejares": "solfejar",
    "solfejaria": "solfejar",
    "solfejariam": "solfejar",
    "solfejarias": "solfejar",
    "solfejarmo": "solfejar",
    "solfejarmos": "solfejar",
    "solfejará": "solfejar",
    "solfejarás": "solfejar",
    "solfejarão": "solfejar",
    "solfejaríamos": "solfejar",
    "solfejaríeis": "solfejar",
    "solfejas": "solfejar",
    "solfejasse": "solfejar",
    "solfejassem": "solfejar",
    "solfejasses": "solfejar",
    "solfejaste": "solfejar",
    "solfejastes": "solfejar",
    "solfejava": "solfejar",
    "solfejavam": "solfejar",
    "solfejavas": "solfejar",
    "solfeje": "solfejar",
    "solfejei": "solfejar",
    "solfejeis": "solfejar",
    "solfejem": "solfejar",
    "solfejemo": "solfejar",
    "solfejemos": "solfejar",
    "solfejes": "solfejar",
    "solfejistas": "solfejista",
    "solfejo": "solfejar",
    "solfejos": "solfejo",
    "solfejou": "solfejar",
    "solfejámo": "solfejar",
    "solfejámos": "solfejar",
    "solfejáramo": "solfejar",
    "solfejáramos": "solfejar",
    "solfejáreis": "solfejar",
    "solfejásseis": "solfejar",
    "solfejássemos": "solfejar",
    "solfejávamo": "solfejar",
    "solfejávamos": "solfejar",
    "solfejáveis": "solfejar",
    "solfem": "solfar",
    "solfemo": "solfar",
    "solfemos": "solfar",
    "solfes": "solfar",
    "solfistas": "solfista",
    "solfo": "solfar",
    "solfou": "solfar",
    "solfá": "solfar",
    "solfámo": "solfar",
    "solfámos": "solfar",
    "solfáramo": "solfar",
    "solfáramos": "solfar",
    "solfárei": "solfar",
    "solfáreis": "solfar",
    "solfásseis": "solfar",
    "solfássemos": "solfar",
    "solfávamo": "solfar",
    "solfávamos": "solfar",
    "solfávei": "solfar",
    "solfáveis": "solfar",
    "solha": "solhar",
    "solhada": "solhar",
    "solhadas": "solhar",
    "solhado": "solhar",
    "solhados": "solhar",
    "solhai": "solhar",
    "solhais": "solhar",
    "solham": "solhar",
    "solhamo": "solhar",
    "solhamos": "solhar",
    "solhando": "solhar",
    "solhara": "solhar",
    "solharam": "solhar",
    "solharas": "solhar",
    "solharde": "solhar",
    "solhardes": "solhar",
    "solhare": "solhar",
    "solharei": "solhar",
    "solhareis": "solhar",
    "solharem": "solhar",
    "solharemos": "solhar",
    "solhares": "solhar",
    "solharia": "solhar",
    "solhariam": "solhar",
    "solharias": "solhar",
    "solharmo": "solhar",
    "solharmos": "solhar",
    "solhará": "solhar",
    "solharás": "solhar",
    "solharão": "solhar",
    "solharíamos": "solhar",
    "solharíeis": "solhar",
    "solhas": "solhar",
    "solhasse": "solhar",
    "solhassem": "solhar",
    "solhasses": "solhar",
    "solhaste": "solhar",
    "solhastes": "solhar",
    "solhava": "solhar",
    "solhavam": "solhar",
    "solhavas": "solhar",
    "solhe": "solhar",
    "solhei": "solhar",
    "solheiros": "solheiro",
    "solheis": "solhar",
    "solhem": "solhar",
    "solhemo": "solhar",
    "solhemos": "solhar",
    "solhes": "solhar",
    "solho": "solhar",
    "solhos": "solho",
    "solhou": "solhar",
    "solhá": "solhar",
    "solhámo": "solhar",
    "solhámos": "solhar",
    "solháramo": "solhar",
    "solháramos": "solhar",
    "solhárei": "solhar",
    "solháreis": "solhar",
    "solhásseis": "solhar",
    "solhássemos": "solhar",
    "solhávamo": "solhar",
    "solhávamos": "solhar",
    "solhávei": "solhar",
    "solháveis": "solhar",
    "solicita": "solicitar",
    "solicitada": "solicitar",
    "solicitadas": "solicitar",
    "solicitado": "solicitar",
    "solicitadora": "solicitador",
    "solicitadoras": "solicitador",
    "solicitadores": "solicitador",
    "solicitados": "solicitar",
    "solicitadíssima": "solicitado",
    "solicitadíssimas": "solicitado",
    "solicitadíssimo": "solicitado",
    "solicitadíssimos": "solicitado",
    "solicitai": "solicitar",
    "solicitais": "solicitar",
    "solicitam": "solicitar",
    "solicitamo": "solicitar",
    "solicitamos": "solicitar",
    "solicitando": "solicitar",
    "solicitantes": "solicitante",
    "solicitara": "solicitar",
    "solicitaram": "solicitar",
    "solicitaras": "solicitar",
    "solicitarde": "solicitar",
    "solicitardes": "solicitar",
    "solicitare": "solicitar",
    "solicitarei": "solicitar",
    "solicitareis": "solicitar",
    "solicitarem": "solicitar",
    "solicitaremos": "solicitar",
    "solicitares": "solicitar",
    "solicitaria": "solicitar",
    "solicitariam": "solicitar",
    "solicitarias": "solicitar",
    "solicitarmo": "solicitar",
    "solicitarmos": "solicitar",
    "solicitará": "solicitar",
    "solicitarás": "solicitar",
    "solicitarão": "solicitar",
    "solicitaríamos": "solicitar",
    "solicitaríeis": "solicitar",
    "solicitas": "solicitar",
    "solicitasse": "solicitar",
    "solicitassem": "solicitar",
    "solicitasses": "solicitar",
    "solicitaste": "solicitar",
    "solicitastes": "solicitar",
    "solicitava": "solicitar",
    "solicitavam": "solicitar",
    "solicitavas": "solicitar",
    "solicitações": "solicitação",
    "solicite": "solicitar",
    "solicitei": "solicitar",
    "soliciteis": "solicitar",
    "solicitem": "solicitar",
    "solicitemo": "solicitar",
    "solicitemos": "solicitar",
    "solicites": "solicitar",
    "solicito": "solicitar",
    "solicitou": "solicitar",
    "solicitudes": "solicitude",
    "solicitá": "solicitar",
    "solicitámo": "solicitar",
    "solicitámos": "solicitar",
    "solicitáramo": "solicitar",
    "solicitáramos": "solicitar",
    "solicitárei": "solicitar",
    "solicitáreis": "solicitar",
    "solicitásseis": "solicitar",
    "solicitássemos": "solicitar",
    "solicitávamo": "solicitar",
    "solicitávamos": "solicitar",
    "solicitávei": "solicitar",
    "solicitáveis": "solicitável",
    "solida": "solidar",
    "solidada": "solidar",
    "solidadas": "solidar",
    "solidado": "solidar",
    "solidados": "solidar",
    "solidai": "solidar",
    "solidais": "solidar",
    "solidam": "solidar",
    "solidamo": "solidar",
    "solidamos": "solidar",
    "solidando": "solidar",
    "solidara": "solidar",
    "solidaram": "solidar",
    "solidaras": "solidar",
    "solidarde": "solidar",
    "solidardes": "solidar",
    "solidare": "solidar",
    "solidarei": "solidar",
    "solidareis": "solidar",
    "solidarem": "solidar",
    "solidaremos": "solidar",
    "solidares": "solidar",
    "solidaria": "solidar",
    "solidariam": "solidar",
    "solidarias": "solidar",
    "solidariedades": "solidariedade",
    "solidarismos": "solidarismo",
    "solidariza": "solidarizar",
    "solidarizada": "solidarizar",
    "solidarizadas": "solidarizar",
    "solidarizado": "solidarizar",
    "solidarizados": "solidarizar",
    "solidarizai": "solidarizar",
    "solidarizais": "solidarizar",
    "solidarizam": "solidarizar",
    "solidarizamo": "solidarizar",
    "solidarizamos": "solidarizar",
    "solidarizando": "solidarizar",
    "solidarizara": "solidarizar",
    "solidarizaram": "solidarizar",
    "solidarizaras": "solidarizar",
    "solidarizarde": "solidarizar",
    "solidarizardes": "solidarizar",
    "solidarizare": "solidarizar",
    "solidarizarei": "solidarizar",
    "solidarizareis": "solidarizar",
    "solidarizarem": "solidarizar",
    "solidarizaremos": "solidarizar",
    "solidarizares": "solidarizar",
    "solidarizaria": "solidarizar",
    "solidarizariam": "solidarizar",
    "solidarizarias": "solidarizar",
    "solidarizarmo": "solidarizar",
    "solidarizarmos": "solidarizar",
    "solidarizará": "solidarizar",
    "solidarizarás": "solidarizar",
    "solidarizarão": "solidarizar",
    "solidarizaríamos": "solidarizar",
    "solidarizaríeis": "solidarizar",
    "solidarizas": "solidarizar",
    "solidarizasse": "solidarizar",
    "solidarizassem": "solidarizar",
    "solidarizasses": "solidarizar",
    "solidarizaste": "solidarizar",
    "solidarizastes": "solidarizar",
    "solidarizava": "solidarizar",
    "solidarizavam": "solidarizar",
    "solidarizavas": "solidarizar",
    "solidarizações": "solidarização",
    "solidarize": "solidarizar",
    "solidarizei": "solidarizar",
    "solidarizeis": "solidarizar",
    "solidarizem": "solidarizar",
    "solidarizemo": "solidarizar",
    "solidarizemos": "solidarizar",
    "solidarizes": "solidarizar",
    "solidarizo": "solidarizar",
    "solidarizou": "solidarizar",
    "solidarizá": "solidarizar",
    "solidarizámo": "solidarizar",
    "solidarizámos": "solidarizar",
    "solidarizáramo": "solidarizar",
    "solidarizáramos": "solidarizar",
    "solidarizárei": "solidarizar",
    "solidarizáreis": "solidarizar",
    "solidarizásseis": "solidarizar",
    "solidarizássemos": "solidarizar",
    "solidarizávamo": "solidarizar",
    "solidarizávamos": "solidarizar",
    "solidarizávei": "solidarizar",
    "solidarizáveis": "solidarizar",
    "solidarmo": "solidar",
    "solidarmos": "solidar",
    "solidará": "solidar",
    "solidarás": "solidar",
    "solidarão": "solidar",
    "solidaríamos": "solidar",
    "solidaríeis": "solidar",
    "solidas": "solidar",
    "solidasse": "solidar",
    "solidassem": "solidar",
    "solidasses": "solidar",
    "solidaste": "solidar",
    "solidastes": "solidar",
    "solidava": "solidar",
    "solidavam": "solidar",
    "solidavas": "solidar",
    "solide": "solidar",
    "solidei": "solidar",
    "solideis": "solidar",
    "solidem": "solidar",
    "solidemo": "solidar",
    "solidemos": "solidar",
    "solides": "solidar",
    "solidifica": "solidificar",
    "solidificada": "solidificar",
    "solidificadas": "solidificar",
    "solidificado": "solidificar",
    "solidificadora": "solidificador",
    "solidificadoras": "solidificador",
    "solidificadores": "solidificador",
    "solidificados": "solidificar",
    "solidificai": "solidificar",
    "solidificais": "solidificar",
    "solidificam": "solidificar",
    "solidificamo": "solidificar",
    "solidificamos": "solidificar",
    "solidificando": "solidificar",
    "solidificara": "solidificar",
    "solidificaram": "solidificar",
    "solidificaras": "solidificar",
    "solidificarde": "solidificar",
    "solidificardes": "solidificar",
    "solidificare": "solidificar",
    "solidificarei": "solidificar",
    "solidificareis": "solidificar",
    "solidificarem": "solidificar",
    "solidificaremos": "solidificar",
    "solidificares": "solidificar",
    "solidificaria": "solidificar",
    "solidificariam": "solidificar",
    "solidificarias": "solidificar",
    "solidificarmo": "solidificar",
    "solidificarmos": "solidificar",
    "solidificará": "solidificar",
    "solidificarás": "solidificar",
    "solidificarão": "solidificar",
    "solidificaríamos": "solidificar",
    "solidificaríeis": "solidificar",
    "solidificas": "solidificar",
    "solidificasse": "solidificar",
    "solidificassem": "solidificar",
    "solidificasses": "solidificar",
    "solidificaste": "solidificar",
    "solidificastes": "solidificar",
    "solidificava": "solidificar",
    "solidificavam": "solidificar",
    "solidificavas": "solidificar",
    "solidificações": "solidificação",
    "solidifico": "solidificar",
    "solidificou": "solidificar",
    "solidificá": "solidificar",
    "solidificámo": "solidificar",
    "solidificámos": "solidificar",
    "solidificáramo": "solidificar",
    "solidificáramos": "solidificar",
    "solidificárei": "solidificar",
    "solidificáreis": "solidificar",
    "solidificásseis": "solidificar",
    "solidificássemos": "solidificar",
    "solidificávamo": "solidificar",
    "solidificávamos": "solidificar",
    "solidificávei": "solidificar",
    "solidificáveis": "solidificável",
    "solidifique": "solidificar",
    "solidifiquei": "solidificar",
    "solidifiqueis": "solidificar",
    "solidifiquem": "solidificar",
    "solidifiquemo": "solidificar",
    "solidifiquemos": "solidificar",
    "solidifiques": "solidificar",
    "solido": "solidar",
    "solidou": "solidar",
    "solidá": "solidar",
    "solidámo": "solidar",
    "solidámos": "solidar",
    "solidáramo": "solidar",
    "solidáramos": "solidar",
    "solidárei": "solidar",
    "solidáreis": "solidar",
    "solidária": "solidário",
    "solidárias": "solidário",
    "solidários": "solidário",
    "solidásseis": "solidar",
    "solidássemos": "solidar",
    "solidávamo": "solidar",
    "solidávamos": "solidar",
    "solidávei": "solidar",
    "solidáveis": "solidar",
    "solidéus": "solidéu",
    "solidónias": "solidónia",
    "solidões": "solidão",
    "solifluxões": "solifluxão",
    "solilóquios": "solilóquio",
    "solimões": "solimão",
    "solinha": "solinhar",
    "solinhada": "solinhar",
    "solinhadas": "solinhar",
    "solinhadeiras": "solinhadeira",
    "solinhado": "solinhar",
    "solinhados": "solinhar",
    "solinhai": "solinhar",
    "solinhais": "solinhar",
    "solinham": "solinhar",
    "solinhamo": "solinhar",
    "solinhamos": "solinhar",
    "solinhando": "solinhar",
    "solinhara": "solinhar",
    "solinharam": "solinhar",
    "solinharas": "solinhar",
    "solinharde": "solinhar",
    "solinhardes": "solinhar",
    "solinhare": "solinhar",
    "solinharei": "solinhar",
    "solinhareis": "solinhar",
    "solinharem": "solinhar",
    "solinharemos": "solinhar",
    "solinhares": "solinhar",
    "solinharia": "solinhar",
    "solinhariam": "solinhar",
    "solinharias": "solinhar",
    "solinharmo": "solinhar",
    "solinharmos": "solinhar",
    "solinhará": "solinhar",
    "solinharás": "solinhar",
    "solinharão": "solinhar",
    "solinharíamos": "solinhar",
    "solinharíeis": "solinhar",
    "solinhas": "solinhar",
    "solinhasse": "solinhar",
    "solinhassem": "solinhar",
    "solinhasses": "solinhar",
    "solinhaste": "solinhar",
    "solinhastes": "solinhar",
    "solinhava": "solinhar",
    "solinhavam": "solinhar",
    "solinhavas": "solinhar",
    "solinhe": "solinhar",
    "solinhei": "solinhar",
    "solinheis": "solinhar",
    "solinhem": "solinhar",
    "solinhemo": "solinhar",
    "solinhemos": "solinhar",
    "solinhes": "solinhar",
    "solinho": "solinhar",
    "solinhos": "solinho",
    "solinhou": "solinhar",
    "solinhá": "solinhar",
    "solinhámo": "solinhar",
    "solinhámos": "solinhar",
    "solinháramo": "solinhar",
    "solinháramos": "solinhar",
    "solinhárei": "solinhar",
    "solinháreis": "solinhar",
    "solinhásseis": "solinhar",
    "solinhássemos": "solinhar",
    "solinhávamo": "solinhar",
    "solinhávamos": "solinhar",
    "solinhávei": "solinhar",
    "solinháveis": "solinhar",
    "solipas": "solipa",
    "solipsismos": "solipsismo",
    "solipsos": "solipso",
    "solipés": "solipé",
    "solistas": "solista",
    "solitariazinha": "solitário",
    "solitariazinhas": "solitário",
    "solitariazita": "solitário",
    "solitariazitas": "solitário",
    "solitariozinho": "solitário",
    "solitariozinhos": "solitário",
    "solitariozito": "solitário",
    "solitariozitos": "solitário",
    "solitudes": "solitude",
    "solitária": "solitário",
    "solitárias": "solitário",
    "solitários": "solitário",
    "solmiza": "solmizar",
    "solmizada": "solmizar",
    "solmizadas": "solmizar",
    "solmizado": "solmizar",
    "solmizados": "solmizar",
    "solmizai": "solmizar",
    "solmizais": "solmizar",
    "solmizam": "solmizar",
    "solmizamo": "solmizar",
    "solmizamos": "solmizar",
    "solmizando": "solmizar",
    "solmizara": "solmizar",
    "solmizaram": "solmizar",
    "solmizaras": "solmizar",
    "solmizardes": "solmizar",
    "solmizarei": "solmizar",
    "solmizareis": "solmizar",
    "solmizarem": "solmizar",
    "solmizaremos": "solmizar",
    "solmizares": "solmizar",
    "solmizaria": "solmizar",
    "solmizariam": "solmizar",
    "solmizarias": "solmizar",
    "solmizarmo": "solmizar",
    "solmizarmos": "solmizar",
    "solmizará": "solmizar",
    "solmizarás": "solmizar",
    "solmizarão": "solmizar",
    "solmizaríamos": "solmizar",
    "solmizaríeis": "solmizar",
    "solmizas": "solmizar",
    "solmizasse": "solmizar",
    "solmizassem": "solmizar",
    "solmizasses": "solmizar",
    "solmizaste": "solmizar",
    "solmizastes": "solmizar",
    "solmizava": "solmizar",
    "solmizavam": "solmizar",
    "solmizavas": "solmizar",
    "solmizações": "solmização",
    "solmize": "solmizar",
    "solmizei": "solmizar",
    "solmizeis": "solmizar",
    "solmizem": "solmizar",
    "solmizemo": "solmizar",
    "solmizemos": "solmizar",
    "solmizes": "solmizar",
    "solmizo": "solmizar",
    "solmizou": "solmizar",
    "solmizámo": "solmizar",
    "solmizámos": "solmizar",
    "solmizáramo": "solmizar",
    "solmizáramos": "solmizar",
    "solmizáreis": "solmizar",
    "solmizásseis": "solmizar",
    "solmizássemos": "solmizar",
    "solmizávamo": "solmizar",
    "solmizávamos": "solmizar",
    "solmizáveis": "solmizar",
    "solos": "solo",
    "solovoxes": "solovox",
    "solsticiais": "solsticial",
    "solstícios": "solstício",
    "solta": "solto",
    "soltada": "soltar",
    "soltadas": "soltar",
    "soltado": "soltar",
    "soltadora": "soltador",
    "soltadoras": "soltador",
    "soltadores": "soltador",
    "soltados": "soltar",
    "soltai": "soltar",
    "soltais": "soltar",
    "soltam": "soltar",
    "soltamo": "soltar",
    "soltamos": "soltar",
    "soltando": "soltar",
    "soltara": "soltar",
    "soltaram": "soltar",
    "soltaras": "soltar",
    "soltarde": "soltar",
    "soltardes": "soltar",
    "soltare": "soltar",
    "soltarei": "soltar",
    "soltareis": "soltar",
    "soltarem": "soltar",
    "soltaremos": "soltar",
    "soltares": "soltar",
    "soltaria": "soltar",
    "soltariam": "soltar",
    "soltarias": "soltar",
    "soltarmo": "soltar",
    "soltarmos": "soltar",
    "soltará": "soltar",
    "soltarás": "soltar",
    "soltarão": "soltar",
    "soltaríamos": "soltar",
    "soltaríeis": "soltar",
    "soltas": "solto",
    "soltasse": "soltar",
    "soltassem": "soltar",
    "soltasses": "soltar",
    "soltaste": "soltar",
    "soltastes": "soltar",
    "soltava": "soltar",
    "soltavam": "soltar",
    "soltavas": "soltar",
    "solte": "soltar",
    "soltei": "soltar",
    "solteira": "solteiro",
    "solteiras": "solteiro",
    "solteirinha": "solteiro",
    "solteirinhas": "solteiro",
    "solteirinho": "solteiro",
    "solteirinhos": "solteiro",
    "solteirismos": "solteirismo",
    "solteirita": "solteiro",
    "solteiritas": "solteiro",
    "solteirito": "solteiro",
    "solteiritos": "solteiro",
    "solteirona": "solteirão",
    "solteironas": "solteirão",
    "solteiros": "solteiro",
    "solteirões": "solteirão",
    "solteis": "soltar",
    "soltem": "soltar",
    "soltemo": "soltar",
    "soltemos": "soltar",
    "soltes": "soltar",
    "soltinha": "solto",
    "soltinhas": "solto",
    "soltinho": "solto",
    "soltinhos": "solto",
    "soltita": "solto",
    "soltitas": "solto",
    "soltito": "solto",
    "soltitos": "solto",
    "solto": "soltar",
    "soltos": "solto",
    "soltou": "soltar",
    "solturas": "soltura",
    "soltá": "soltar",
    "soltámo": "soltar",
    "soltámos": "soltar",
    "soltáramo": "soltar",
    "soltáramos": "soltar",
    "soltárei": "soltar",
    "soltáreis": "soltar",
    "soltásseis": "soltar",
    "soltássemos": "soltar",
    "soltávamo": "soltar",
    "soltávamos": "soltar",
    "soltávei": "soltar",
    "soltáveis": "soltar",
    "soltíssima": "solto",
    "soltíssimas": "solto",
    "soltíssimo": "solto",
    "soltíssimos": "solto",
    "solubilidades": "solubilidade",
    "solubiliza": "solubilizar",
    "solubilizada": "solubilizar",
    "solubilizadas": "solubilizar",
    "solubilizado": "solubilizar",
    "solubilizados": "solubilizar",
    "solubilizai": "solubilizar",
    "solubilizais": "solubilizar",
    "solubilizam": "solubilizar",
    "solubilizamo": "solubilizar",
    "solubilizamos": "solubilizar",
    "solubilizando": "solubilizar",
    "solubilizantes": "solubilizante",
    "solubilizara": "solubilizar",
    "solubilizaram": "solubilizar",
    "solubilizaras": "solubilizar",
    "solubilizarde": "solubilizar",
    "solubilizardes": "solubilizar",
    "solubilizare": "solubilizar",
    "solubilizarei": "solubilizar",
    "solubilizareis": "solubilizar",
    "solubilizarem": "solubilizar",
    "solubilizaremos": "solubilizar",
    "solubilizares": "solubilizar",
    "solubilizaria": "solubilizar",
    "solubilizariam": "solubilizar",
    "solubilizarias": "solubilizar",
    "solubilizarmo": "solubilizar",
    "solubilizarmos": "solubilizar",
    "solubilizará": "solubilizar",
    "solubilizarás": "solubilizar",
    "solubilizarão": "solubilizar",
    "solubilizaríamos": "solubilizar",
    "solubilizaríeis": "solubilizar",
    "solubilizas": "solubilizar",
    "solubilizasse": "solubilizar",
    "solubilizassem": "solubilizar",
    "solubilizasses": "solubilizar",
    "solubilizaste": "solubilizar",
    "solubilizastes": "solubilizar",
    "solubilizava": "solubilizar",
    "solubilizavam": "solubilizar",
    "solubilizavas": "solubilizar",
    "solubilizações": "solubilização",
    "solubilize": "solubilizar",
    "solubilizei": "solubilizar",
    "solubilizeis": "solubilizar",
    "solubilizem": "solubilizar",
    "solubilizemo": "solubilizar",
    "solubilizemos": "solubilizar",
    "solubilizes": "solubilizar",
    "solubilizo": "solubilizar",
    "solubilizou": "solubilizar",
    "solubilizá": "solubilizar",
    "solubilizámo": "solubilizar",
    "solubilizámos": "solubilizar",
    "solubilizáramo": "solubilizar",
    "solubilizáramos": "solubilizar",
    "solubilizárei": "solubilizar",
    "solubilizáreis": "solubilizar",
    "solubilizásseis": "solubilizar",
    "solubilizássemos": "solubilizar",
    "solubilizávamo": "solubilizar",
    "solubilizávamos": "solubilizar",
    "solubilizávei": "solubilizar",
    "solubilizáveis": "solubilizar",
    "soluce": "soluçar",
    "solucei": "soluçar",
    "soluceis": "soluçar",
    "solucem": "soluçar",
    "solucemo": "soluçar",
    "solucemos": "soluçar",
    "soluces": "soluçar",
    "soluciona": "solucionar",
    "solucionada": "solucionar",
    "solucionadas": "solucionar",
    "solucionado": "solucionar",
    "solucionados": "solucionar",
    "solucionai": "solucionar",
    "solucionais": "solucionar",
    "solucionam": "solucionar",
    "solucionamo": "solucionar",
    "solucionamos": "solucionar",
    "solucionando": "solucionar",
    "solucionara": "solucionar",
    "solucionaram": "solucionar",
    "solucionaras": "solucionar",
    "solucionarde": "solucionar",
    "solucionardes": "solucionar",
    "solucionare": "solucionar",
    "solucionarei": "solucionar",
    "solucionareis": "solucionar",
    "solucionarem": "solucionar",
    "solucionaremos": "solucionar",
    "solucionares": "solucionar",
    "solucionaria": "solucionar",
    "solucionariam": "solucionar",
    "solucionarias": "solucionar",
    "solucionarmo": "solucionar",
    "solucionarmos": "solucionar",
    "solucionará": "solucionar",
    "solucionarás": "solucionar",
    "solucionarão": "solucionar",
    "solucionaríamos": "solucionar",
    "solucionaríeis": "solucionar",
    "solucionas": "solucionar",
    "solucionasse": "solucionar",
    "solucionassem": "solucionar",
    "solucionasses": "solucionar",
    "solucionaste": "solucionar",
    "solucionastes": "solucionar",
    "solucionava": "solucionar",
    "solucionavam": "solucionar",
    "solucionavas": "solucionar",
    "solucione": "solucionar",
    "solucionei": "solucionar",
    "solucioneis": "solucionar",
    "solucionem": "solucionar",
    "solucionemo": "solucionar",
    "solucionemos": "solucionar",
    "soluciones": "solucionar",
    "solucionistas": "solucionista",
    "soluciono": "solucionar",
    "solucionou": "solucionar",
    "solucioná": "solucionar",
    "solucionámo": "solucionar",
    "solucionámos": "solucionar",
    "solucionáramo": "solucionar",
    "solucionáramos": "solucionar",
    "solucionárei": "solucionar",
    "solucionáreis": "solucionar",
    "solucionásseis": "solucionar",
    "solucionássemos": "solucionar",
    "solucionávamo": "solucionar",
    "solucionávamos": "solucionar",
    "solucionávei": "solucionar",
    "solucionáveis": "solucionável",
    "soluns": "solum",
    "solutiva": "solutivo",
    "solutivas": "solutivo",
    "solutivos": "solutivo",
    "solutos": "soluto",
    "soluça": "soluçar",
    "soluçada": "soluçar",
    "soluçadas": "soluçar",
    "soluçado": "soluçar",
    "soluçados": "soluçar",
    "soluçai": "soluçar",
    "soluçais": "soluçar",
    "soluçam": "soluçar",
    "soluçamo": "soluçar",
    "soluçamos": "soluçar",
    "soluçando": "soluçar",
    "soluçantes": "soluçante",
    "soluçara": "soluçar",
    "soluçaram": "soluçar",
    "soluçaras": "soluçar",
    "soluçardes": "soluçar",
    "soluçarei": "soluçar",
    "soluçareis": "soluçar",
    "soluçarem": "soluçar",
    "soluçaremos": "soluçar",
    "soluçares": "soluçar",
    "soluçaria": "soluçar",
    "soluçariam": "soluçar",
    "soluçarias": "soluçar",
    "soluçarmo": "soluçar",
    "soluçarmos": "soluçar",
    "soluçará": "soluçar",
    "soluçarás": "soluçar",
    "soluçarão": "soluçar",
    "soluçaríamos": "soluçar",
    "soluçaríeis": "soluçar",
    "soluças": "soluçar",
    "soluçasse": "soluçar",
    "soluçassem": "soluçar",
    "soluçasses": "soluçar",
    "soluçaste": "soluçar",
    "soluçastes": "soluçar",
    "soluçava": "soluçar",
    "soluçavam": "soluçar",
    "soluçavas": "soluçar",
    "soluço": "soluçar",
    "soluços": "soluço",
    "soluçosa": "soluçoso",
    "soluçosas": "soluçoso",
    "soluçosos": "soluçoso",
    "soluçou": "soluçar",
    "soluçámo": "soluçar",
    "soluçámos": "soluçar",
    "soluçáramo": "soluçar",
    "soluçáramos": "soluçar",
    "soluçáreis": "soluçar",
    "soluçásseis": "soluçar",
    "soluçássemos": "soluçar",
    "soluçávamo": "soluçar",
    "soluçávamos": "soluçar",
    "soluçáveis": "soluçar",
    "soluções": "solução",
    "solva": "solver",
    "solvabilidades": "solvabilidade",
    "solvais": "solver",
    "solvam": "solver",
    "solvamo": "solver",
    "solvamos": "solver",
    "solvas": "solver",
    "solvatações": "solvatação",
    "solve": "solver",
    "solvei": "solver",
    "solveis": "solver",
    "solvem": "solver",
    "solvemo": "solver",
    "solvemos": "solver",
    "solvendo": "solver",
    "solventes": "solvente",
    "solvera": "solver",
    "solveram": "solver",
    "solveras": "solver",
    "solverde": "solver",
    "solverdes": "solver",
    "solvere": "solver",
    "solverei": "solver",
    "solvereis": "solver",
    "solverem": "solver",
    "solveremos": "solver",
    "solveres": "solver",
    "solveria": "solver",
    "solveriam": "solver",
    "solverias": "solver",
    "solvermo": "solver",
    "solvermos": "solver",
    "solverá": "solver",
    "solverás": "solver",
    "solverão": "solver",
    "solveríamos": "solver",
    "solveríeis": "solver",
    "solves": "solver",
    "solvesse": "solver",
    "solvessem": "solver",
    "solvesses": "solver",
    "solveste": "solver",
    "solvestes": "solver",
    "solveu": "solver",
    "solvi": "solver",
    "solvia": "solver",
    "solviam": "solver",
    "solvias": "solver",
    "solvibilidades": "solvibilidade",
    "solvida": "solver",
    "solvidas": "solver",
    "solvido": "solver",
    "solvidos": "solvido",
    "solvo": "solver",
    "solvê": "solver",
    "solvências": "solvência",
    "solvêramo": "solver",
    "solvêramos": "solver",
    "solvêrei": "solver",
    "solvêreis": "solver",
    "solvêsseis": "solver",
    "solvêssemos": "solver",
    "solvíamo": "solver",
    "solvíamos": "solver",
    "solvíei": "solver",
    "solvíeis": "solver",
    "solvíveis": "solvível",
    "solzinho": "sol",
    "solzito": "sol",
    "solários": "solário",
    "solénidas": "solénida",
    "solércias": "solércia",
    "solícita": "solícito",
    "solícitas": "solícito",
    "solícitos": "solícito",
    "solífuga": "solífugo",
    "solífugas": "solífugo",
    "solífugos": "solífugo",
    "solípedes": "solípede",
    "solões": "solão",
    "solúveis": "solúvel",
    "soma": "somar",
    "somada": "somar",
    "somadas": "somar",
    "somado": "somar",
    "somados": "somar",
    "somai": "somar",
    "somais": "somar",
    "somalis": "somali",
    "somam": "somar",
    "somamo": "somar",
    "somamos": "somar",
    "somando": "somar",
    "somara": "somar",
    "somaram": "somar",
    "somaras": "somar",
    "somarde": "somar",
    "somardes": "somar",
    "somare": "somar",
    "somarei": "somar",
    "somareis": "somar",
    "somarem": "somar",
    "somaremos": "somar",
    "somares": "somar",
    "somaria": "somar",
    "somariam": "somar",
    "somarias": "somar",
    "somarmo": "somar",
    "somarmos": "somar",
    "somará": "somar",
    "somarás": "somar",
    "somarão": "somar",
    "somaríamos": "somar",
    "somaríeis": "somar",
    "somas": "somar",
    "somasse": "somar",
    "somassem": "somar",
    "somasses": "somar",
    "somaste": "somar",
    "somastes": "somar",
    "somatiza": "somatizar",
    "somatizada": "somatizar",
    "somatizadas": "somatizar",
    "somatizado": "somatizar",
    "somatizados": "somatizar",
    "somatizai": "somatizar",
    "somatizais": "somatizar",
    "somatizam": "somatizar",
    "somatizamo": "somatizar",
    "somatizamos": "somatizar",
    "somatizando": "somatizar",
    "somatizara": "somatizar",
    "somatizaram": "somatizar",
    "somatizaras": "somatizar",
    "somatizardes": "somatizar",
    "somatizarei": "somatizar",
    "somatizareis": "somatizar",
    "somatizarem": "somatizar",
    "somatizaremos": "somatizar",
    "somatizares": "somatizar",
    "somatizaria": "somatizar",
    "somatizariam": "somatizar",
    "somatizarias": "somatizar",
    "somatizarmo": "somatizar",
    "somatizarmos": "somatizar",
    "somatizará": "somatizar",
    "somatizarás": "somatizar",
    "somatizarão": "somatizar",
    "somatizaríamos": "somatizar",
    "somatizaríeis": "somatizar",
    "somatizas": "somatizar",
    "somatizasse": "somatizar",
    "somatizassem": "somatizar",
    "somatizasses": "somatizar",
    "somatizaste": "somatizar",
    "somatizastes": "somatizar",
    "somatizava": "somatizar",
    "somatizavam": "somatizar",
    "somatizavas": "somatizar",
    "somatize": "somatizar",
    "somatizei": "somatizar",
    "somatizeis": "somatizar",
    "somatizem": "somatizar",
    "somatizemo": "somatizar",
    "somatizemos": "somatizar",
    "somatizes": "somatizar",
    "somatizo": "somatizar",
    "somatizou": "somatizar",
    "somatizámo": "somatizar",
    "somatizámos": "somatizar",
    "somatizáramo": "somatizar",
    "somatizáramos": "somatizar",
    "somatizáreis": "somatizar",
    "somatizásseis": "somatizar",
    "somatizássemos": "somatizar",
    "somatizávamo": "somatizar",
    "somatizávamos": "somatizar",
    "somatizáveis": "somatizar",
    "somatoagnosias": "somatoagnosia",
    "somatognosias": "somatognosia",
    "somatologias": "somatologia",
    "somatológica": "somatológico",
    "somatológicas": "somatológico",
    "somatológicos": "somatológico",
    "somatomancias": "somatomancia",
    "somatopleuras": "somatopleura",
    "somatotopias": "somatotopia",
    "somatória": "somatório",
    "somatórias": "somatório",
    "somatórios": "somatório",
    "somava": "somar",
    "somavam": "somar",
    "somavas": "somar",
    "sombrachos": "sombracho",
    "sombras": "sombra",
    "sombreada": "sombrear",
    "sombreadas": "sombrear",
    "sombreado": "sombrear",
    "sombreados": "sombrear",
    "sombreai": "sombrear",
    "sombreais": "sombrear",
    "sombreamentos": "sombreamento",
    "sombreamo": "sombrear",
    "sombreamos": "sombrear",
    "sombreando": "sombrear",
    "sombreara": "sombrear",
    "sombrearam": "sombrear",
    "sombrearas": "sombrear",
    "sombrearde": "sombrear",
    "sombreardes": "sombrear",
    "sombreare": "sombrear",
    "sombrearei": "sombrear",
    "sombreareis": "sombrear",
    "sombrearem": "sombrear",
    "sombrearemos": "sombrear",
    "sombreares": "sombrear",
    "sombrearia": "sombrear",
    "sombreariam": "sombrear",
    "sombrearias": "sombrear",
    "sombrearmo": "sombrear",
    "sombrearmos": "sombrear",
    "sombreará": "sombrear",
    "sombrearás": "sombrear",
    "sombrearão": "sombrear",
    "sombrearíamos": "sombrear",
    "sombrearíeis": "sombrear",
    "sombreasse": "sombrear",
    "sombreassem": "sombrear",
    "sombreasses": "sombrear",
    "sombreaste": "sombrear",
    "sombreastes": "sombrear",
    "sombreava": "sombrear",
    "sombreavam": "sombrear",
    "sombreavas": "sombrear",
    "sombreei": "sombrear",
    "sombreeis": "sombrear",
    "sombreemo": "sombrear",
    "sombreemos": "sombrear",
    "sombreia": "sombrear",
    "sombreiam": "sombrear",
    "sombreias": "sombrear",
    "sombreie": "sombrear",
    "sombreiem": "sombrear",
    "sombreies": "sombrear",
    "sombreio": "sombrear",
    "sombreiras": "sombreira",
    "sombreireiros": "sombreireiro",
    "sombreiros": "sombreiro",
    "sombreja": "sombrejar",
    "sombrejada": "sombrejar",
    "sombrejadas": "sombrejar",
    "sombrejado": "sombrejar",
    "sombrejados": "sombrejar",
    "sombrejai": "sombrejar",
    "sombrejais": "sombrejar",
    "sombrejam": "sombrejar",
    "sombrejamo": "sombrejar",
    "sombrejamos": "sombrejar",
    "sombrejando": "sombrejar",
    "sombrejara": "sombrejar",
    "sombrejaram": "sombrejar",
    "sombrejaras": "sombrejar",
    "sombrejarde": "sombrejar",
    "sombrejardes": "sombrejar",
    "sombrejare": "sombrejar",
    "sombrejarei": "sombrejar",
    "sombrejareis": "sombrejar",
    "sombrejarem": "sombrejar",
    "sombrejaremos": "sombrejar",
    "sombrejares": "sombrejar",
    "sombrejaria": "sombrejar",
    "sombrejariam": "sombrejar",
    "sombrejarias": "sombrejar",
    "sombrejarmo": "sombrejar",
    "sombrejarmos": "sombrejar",
    "sombrejará": "sombrejar",
    "sombrejarás": "sombrejar",
    "sombrejarão": "sombrejar",
    "sombrejaríamos": "sombrejar",
    "sombrejaríeis": "sombrejar",
    "sombrejas": "sombrejar",
    "sombrejasse": "sombrejar",
    "sombrejassem": "sombrejar",
    "sombrejasses": "sombrejar",
    "sombrejaste": "sombrejar",
    "sombrejastes": "sombrejar",
    "sombrejava": "sombrejar",
    "sombrejavam": "sombrejar",
    "sombrejavas": "sombrejar",
    "sombreje": "sombrejar",
    "sombrejei": "sombrejar",
    "sombrejeis": "sombrejar",
    "sombrejem": "sombrejar",
    "sombrejemo": "sombrejar",
    "sombrejemos": "sombrejar",
    "sombrejes": "sombrejar",
    "sombrejo": "sombrejar",
    "sombrejou": "sombrejar",
    "sombrejá": "sombrejar",
    "sombrejámo": "sombrejar",
    "sombrejámos": "sombrejar",
    "sombrejáramo": "sombrejar",
    "sombrejáramos": "sombrejar",
    "sombrejárei": "sombrejar",
    "sombrejáreis": "sombrejar",
    "sombrejásseis": "sombrejar",
    "sombrejássemos": "sombrejar",
    "sombrejávamo": "sombrejar",
    "sombrejávamos": "sombrejar",
    "sombrejávei": "sombrejar",
    "sombrejáveis": "sombrejar",
    "sombrelas": "sombrela",
    "sombreou": "sombrear",
    "sombreá": "sombrear",
    "sombreámo": "sombrear",
    "sombreámos": "sombrear",
    "sombreáramo": "sombrear",
    "sombreáramos": "sombrear",
    "sombreárei": "sombrear",
    "sombreáreis": "sombrear",
    "sombreásseis": "sombrear",
    "sombreássemos": "sombrear",
    "sombreávamo": "sombrear",
    "sombreávamos": "sombrear",
    "sombreávei": "sombrear",
    "sombreáveis": "sombrear",
    "sombria": "sombrio",
    "sombrias": "sombrio",
    "sombrinha": "sombra",
    "sombrinhas": "sombrinha",
    "sombrios": "sombrio",
    "sombrita": "sombra",
    "sombritas": "sombra",
    "sombrosa": "sombroso",
    "sombrosas": "sombroso",
    "sombrosos": "sombroso",
    "some": "sumir",
    "somei": "somar",
    "someiros": "someiro",
    "someis": "somar",
    "somem": "sumir",
    "somemo": "somar",
    "somemos": "somar",
    "somes": "sumir",
    "somilheres": "somilher",
    "somiticarias": "somiticaria",
    "somitiquices": "somitiquice",
    "somiês": "somiê",
    "somo": "somar",
    "somos": "ser",
    "somou": "somar",
    "somá": "somar",
    "somámo": "somar",
    "somámos": "somar",
    "somáramo": "somar",
    "somáramos": "somar",
    "somárei": "somar",
    "somáreis": "somar",
    "somásseis": "somar",
    "somássemos": "somar",
    "somática": "somático",
    "somáticas": "somático",
    "somáticos": "somático",
    "somávamo": "somar",
    "somávamos": "somar",
    "somávei": "somar",
    "somáveis": "somar",
    "somítica": "somítico",
    "somíticas": "somítico",
    "somíticos": "somítico",
    "sonajas": "sonaja",
    "sonalhas": "sonalha",
    "sonambulares": "sonambular",
    "sonambulazinha": "sonâmbulo",
    "sonambulazinhas": "sonâmbulo",
    "sonambulazita": "sonâmbulo",
    "sonambulazitas": "sonâmbulo",
    "sonambulismos": "sonambulismo",
    "sonambulozinho": "sonâmbulo",
    "sonambulozinhos": "sonâmbulo",
    "sonambulozito": "sonâmbulo",
    "sonambulozitos": "sonâmbulo",
    "sonambúlica": "sonambúlico",
    "sonambúlicas": "sonambúlico",
    "sonambúlicos": "sonambúlico",
    "sonantes": "sonante",
    "sonarenta": "sonarento",
    "sonarentas": "sonarento",
    "sonarentos": "sonarento",
    "sonares": "sonar",
    "sonatas": "sonata",
    "sonatinas": "sonatina",
    "sonatoscopias": "sonatoscopia",
    "sonavas": "sonava",
    "sonda": "sondar",
    "sondada": "sondar",
    "sondadas": "sondar",
    "sondado": "sondar",
    "sondadora": "sondador",
    "sondadoras": "sondador",
    "sondadores": "sondador",
    "sondados": "sondar",
    "sondagens": "sondagem",
    "sondai": "sondar",
    "sondais": "sondar",
    "sondam": "sondar",
    "sondamo": "sondar",
    "sondamos": "sondar",
    "sondando": "sondar",
    "sondara": "sondar",
    "sondaram": "sondar",
    "sondaras": "sondar",
    "sondarde": "sondar",
    "sondardes": "sondar",
    "sondare": "sondar",
    "sondarei": "sondar",
    "sondareis": "sondar",
    "sondarem": "sondar",
    "sondaremos": "sondar",
    "sondares": "sondar",
    "sondarezas": "sondareza",
    "sondaria": "sondar",
    "sondariam": "sondar",
    "sondarias": "sondar",
    "sondarmo": "sondar",
    "sondarmos": "sondar",
    "sondará": "sondar",
    "sondarás": "sondar",
    "sondarão": "sondar",
    "sondaríamos": "sondar",
    "sondaríeis": "sondar",
    "sondas": "sondar",
    "sondasse": "sondar",
    "sondassem": "sondar",
    "sondasses": "sondar",
    "sondaste": "sondar",
    "sondastes": "sondar",
    "sondava": "sondar",
    "sondavam": "sondar",
    "sondavas": "sondar",
    "sonde": "sondar",
    "sondei": "sondar",
    "sondeis": "sondar",
    "sondem": "sondar",
    "sondemo": "sondar",
    "sondemos": "sondar",
    "sondes": "sondar",
    "sondo": "sondar",
    "sondou": "sondar",
    "sondá": "sondar",
    "sondámo": "sondar",
    "sondámos": "sondar",
    "sondáramo": "sondar",
    "sondáramos": "sondar",
    "sondárei": "sondar",
    "sondáreis": "sondar",
    "sondásseis": "sondar",
    "sondássemos": "sondar",
    "sondávamo": "sondar",
    "sondávamos": "sondar",
    "sondávei": "sondar",
    "sondáveis": "sondável",
    "sonecas": "soneca",
    "sonega": "sonegar",
    "sonegada": "sonegar",
    "sonegadas": "sonegar",
    "sonegado": "sonegar",
    "sonegadora": "sonegador",
    "sonegadoras": "sonegador",
    "sonegadores": "sonegador",
    "sonegados": "sonegar",
    "sonegai": "sonegar",
    "sonegais": "sonegar",
    "sonegam": "sonegar",
    "sonegamentos": "sonegamento",
    "sonegamo": "sonegar",
    "sonegamos": "sonegar",
    "sonegando": "sonegar",
    "sonegara": "sonegar",
    "sonegaram": "sonegar",
    "sonegaras": "sonegar",
    "sonegarde": "sonegar",
    "sonegardes": "sonegar",
    "sonegare": "sonegar",
    "sonegarei": "sonegar",
    "sonegareis": "sonegar",
    "sonegarem": "sonegar",
    "sonegaremos": "sonegar",
    "sonegares": "sonegar",
    "sonegaria": "sonegar",
    "sonegariam": "sonegar",
    "sonegarias": "sonegar",
    "sonegarmo": "sonegar",
    "sonegarmos": "sonegar",
    "sonegará": "sonegar",
    "sonegarás": "sonegar",
    "sonegarão": "sonegar",
    "sonegaríamos": "sonegar",
    "sonegaríeis": "sonegar",
    "sonegas": "sonegar",
    "sonegasse": "sonegar",
    "sonegassem": "sonegar",
    "sonegasses": "sonegar",
    "sonegaste": "sonegar",
    "sonegastes": "sonegar",
    "sonegava": "sonegar",
    "sonegavam": "sonegar",
    "sonegavas": "sonegar",
    "sonegações": "sonegação",
    "sonego": "sonegar",
    "sonegou": "sonegar",
    "sonegue": "sonegar",
    "soneguei": "sonegar",
    "sonegueis": "sonegar",
    "soneguem": "sonegar",
    "soneguemo": "sonegar",
    "soneguemos": "sonegar",
    "sonegues": "sonegar",
    "sonegá": "sonegar",
    "sonegámo": "sonegar",
    "sonegámos": "sonegar",
    "sonegáramo": "sonegar",
    "sonegáramos": "sonegar",
    "sonegárei": "sonegar",
    "sonegáreis": "sonegar",
    "sonegásseis": "sonegar",
    "sonegássemos": "sonegar",
    "sonegávamo": "sonegar",
    "sonegávamos": "sonegar",
    "sonegávei": "sonegar",
    "sonegáveis": "sonegar",
    "soneiras": "soneira",
    "soneta": "sonetar",
    "sonetada": "sonetar",
    "sonetadas": "sonetar",
    "sonetado": "sonetar",
    "sonetados": "sonetar",
    "sonetai": "sonetar",
    "sonetais": "sonetar",
    "sonetam": "sonetar",
    "sonetamo": "sonetar",
    "sonetamos": "sonetar",
    "sonetando": "sonetar",
    "sonetara": "sonetar",
    "sonetaram": "sonetar",
    "sonetaras": "sonetar",
    "sonetardes": "sonetar",
    "sonetarei": "sonetar",
    "sonetareis": "sonetar",
    "sonetarem": "sonetar",
    "sonetaremos": "sonetar",
    "sonetares": "sonetar",
    "sonetaria": "sonetar",
    "sonetariam": "sonetar",
    "sonetarias": "sonetaria",
    "sonetarmo": "sonetar",
    "sonetarmos": "sonetar",
    "sonetará": "sonetar",
    "sonetarás": "sonetar",
    "sonetarão": "sonetar",
    "sonetaríamos": "sonetar",
    "sonetaríeis": "sonetar",
    "sonetas": "sonetar",
    "sonetasse": "sonetar",
    "sonetassem": "sonetar",
    "sonetasses": "sonetar",
    "sonetaste": "sonetar",
    "sonetastes": "sonetar",
    "sonetava": "sonetar",
    "sonetavam": "sonetar",
    "sonetavas": "sonetar",
    "sonete": "sonetar",
    "soneteada": "sonetear",
    "soneteadas": "sonetear",
    "soneteado": "sonetear",
    "soneteados": "sonetear",
    "soneteai": "sonetear",
    "soneteais": "sonetear",
    "soneteamo": "sonetear",
    "soneteamos": "sonetear",
    "soneteando": "sonetear",
    "soneteara": "sonetear",
    "sonetearam": "sonetear",
    "sonetearas": "sonetear",
    "soneteardes": "sonetear",
    "sonetearei": "sonetear",
    "soneteareis": "sonetear",
    "sonetearem": "sonetear",
    "sonetearemos": "sonetear",
    "soneteares": "sonetear",
    "sonetearia": "sonetear",
    "soneteariam": "sonetear",
    "sonetearias": "sonetear",
    "sonetearmo": "sonetear",
    "sonetearmos": "sonetear",
    "soneteará": "sonetear",
    "sonetearás": "sonetear",
    "sonetearão": "sonetear",
    "sonetearíamos": "sonetear",
    "sonetearíeis": "sonetear",
    "soneteasse": "sonetear",
    "soneteassem": "sonetear",
    "soneteasses": "sonetear",
    "soneteaste": "sonetear",
    "soneteastes": "sonetear",
    "soneteava": "sonetear",
    "soneteavam": "sonetear",
    "soneteavas": "sonetear",
    "soneteei": "sonetear",
    "soneteeis": "sonetear",
    "soneteemo": "sonetear",
    "soneteemos": "sonetear",
    "sonetei": "sonetar",
    "soneteia": "sonetear",
    "soneteiam": "sonetear",
    "soneteias": "sonetear",
    "soneteie": "sonetear",
    "soneteiem": "sonetear",
    "soneteies": "sonetear",
    "soneteio": "sonetear",
    "soneteira": "soneteiro",
    "soneteiras": "soneteiro",
    "soneteirazinha": "soneteiro",
    "soneteirazinhas": "soneteiro",
    "soneteirazita": "soneteiro",
    "soneteirazitas": "soneteiro",
    "soneteiros": "soneteiro",
    "soneteirozinho": "soneteiro",
    "soneteirozinhos": "soneteiro",
    "soneteirozito": "soneteiro",
    "soneteirozitos": "soneteiro",
    "soneteis": "sonetar",
    "sonetem": "sonetar",
    "sonetemo": "sonetar",
    "sonetemos": "sonetar",
    "soneteou": "sonetear",
    "sonetes": "sonetar",
    "soneteámo": "sonetear",
    "soneteámos": "sonetear",
    "soneteáramo": "sonetear",
    "soneteáramos": "sonetear",
    "soneteáreis": "sonetear",
    "soneteásseis": "sonetear",
    "soneteássemos": "sonetear",
    "soneteávamo": "sonetear",
    "soneteávamos": "sonetear",
    "soneteáveis": "sonetear",
    "sonetilhos": "sonetilho",
    "sonetinho": "soneto",
    "sonetinhos": "soneto",
    "sonetistas": "sonetista",
    "sonetito": "soneto",
    "sonetitos": "soneto",
    "soneto": "sonetar",
    "sonetos": "soneto",
    "sonetou": "sonetar",
    "sonetámo": "sonetar",
    "sonetámos": "sonetar",
    "sonetáramo": "sonetar",
    "sonetáramos": "sonetar",
    "sonetáreis": "sonetar",
    "sonetásseis": "sonetar",
    "sonetássemos": "sonetar",
    "sonetávamo": "sonetar",
    "sonetávamos": "sonetar",
    "sonetáveis": "sonetar",
    "songamongas": "songamonga",
    "songas": "songa",
    "songues": "songue",
    "sonha": "sonhar",
    "sonhada": "sonhar",
    "sonhadas": "sonhar",
    "sonhado": "sonhar",
    "sonhadora": "sonhador",
    "sonhadoras": "sonhador",
    "sonhadorazinha": "sonhador",
    "sonhadorazinhas": "sonhador",
    "sonhadorazita": "sonhador",
    "sonhadorazitas": "sonhador",
    "sonhadores": "sonhador",
    "sonhadorzinho": "sonhador",
    "sonhadorzinhos": "sonhador",
    "sonhadorzito": "sonhador",
    "sonhadorzitos": "sonhador",
    "sonhados": "sonhar",
    "sonhai": "sonhar",
    "sonhais": "sonhar",
    "sonham": "sonhar",
    "sonhamo": "sonhar",
    "sonhamos": "sonhar",
    "sonhando": "sonhar",
    "sonhara": "sonhar",
    "sonharam": "sonhar",
    "sonharas": "sonhar",
    "sonharde": "sonhar",
    "sonhardes": "sonhar",
    "sonhare": "sonhar",
    "sonharei": "sonhar",
    "sonhareis": "sonhar",
    "sonharem": "sonhar",
    "sonharemos": "sonhar",
    "sonhares": "sonhar",
    "sonharia": "sonhar",
    "sonhariam": "sonhar",
    "sonharias": "sonhar",
    "sonharmo": "sonhar",
    "sonharmos": "sonhar",
    "sonhará": "sonhar",
    "sonharás": "sonhar",
    "sonharão": "sonhar",
    "sonharíamos": "sonhar",
    "sonharíeis": "sonhar",
    "sonhas": "sonhar",
    "sonhasse": "sonhar",
    "sonhassem": "sonhar",
    "sonhasses": "sonhar",
    "sonhaste": "sonhar",
    "sonhastes": "sonhar",
    "sonhava": "sonhar",
    "sonhavam": "sonhar",
    "sonhavas": "sonhar",
    "sonhe": "sonhar",
    "sonhei": "sonhar",
    "sonheis": "sonhar",
    "sonhem": "sonhar",
    "sonhemo": "sonhar",
    "sonhemos": "sonhar",
    "sonhes": "sonhar",
    "sonho": "sonhar",
    "sonhos": "sonho",
    "sonhou": "sonhar",
    "sonhá": "sonhar",
    "sonhámo": "sonhar",
    "sonhámos": "sonhar",
    "sonháramo": "sonhar",
    "sonháramos": "sonhar",
    "sonhárei": "sonhar",
    "sonháreis": "sonhar",
    "sonhásseis": "sonhar",
    "sonhássemos": "sonhar",
    "sonhávamo": "sonhar",
    "sonhávamos": "sonhar",
    "sonhávei": "sonhar",
    "sonháveis": "sonhável",
    "sonidos": "sonido",
    "soninho": "sono",
    "soninhos": "sono",
    "sonito": "sono",
    "sonitos": "sono",
    "sonoites": "sonoite",
    "sonolenta": "sonolento",
    "sonolentas": "sonolento",
    "sonolentos": "sonolento",
    "sonoluminescências": "sonoluminescência",
    "sonolências": "sonolência",
    "sonometrias": "sonometria",
    "sonométrica": "sonométrico",
    "sonométricas": "sonométrico",
    "sonométricos": "sonométrico",
    "sonoplastas": "sonoplasta",
    "sonora": "sonoro",
    "sonoras": "sonoro",
    "sonoridades": "sonoridade",
    "sonoriza": "sonorizar",
    "sonorizada": "sonorizar",
    "sonorizadas": "sonorizar",
    "sonorizado": "sonorizar",
    "sonorizados": "sonorizar",
    "sonorizai": "sonorizar",
    "sonorizais": "sonorizar",
    "sonorizam": "sonorizar",
    "sonorizamo": "sonorizar",
    "sonorizamos": "sonorizar",
    "sonorizando": "sonorizar",
    "sonorizara": "sonorizar",
    "sonorizaram": "sonorizar",
    "sonorizaras": "sonorizar",
    "sonorizarde": "sonorizar",
    "sonorizardes": "sonorizar",
    "sonorizare": "sonorizar",
    "sonorizarei": "sonorizar",
    "sonorizareis": "sonorizar",
    "sonorizarem": "sonorizar",
    "sonorizaremos": "sonorizar",
    "sonorizares": "sonorizar",
    "sonorizaria": "sonorizar",
    "sonorizariam": "sonorizar",
    "sonorizarias": "sonorizar",
    "sonorizarmo": "sonorizar",
    "sonorizarmos": "sonorizar",
    "sonorizará": "sonorizar",
    "sonorizarás": "sonorizar",
    "sonorizarão": "sonorizar",
    "sonorizaríamos": "sonorizar",
    "sonorizaríeis": "sonorizar",
    "sonorizas": "sonorizar",
    "sonorizasse": "sonorizar",
    "sonorizassem": "sonorizar",
    "sonorizasses": "sonorizar",
    "sonorizaste": "sonorizar",
    "sonorizastes": "sonorizar",
    "sonorizava": "sonorizar",
    "sonorizavam": "sonorizar",
    "sonorizavas": "sonorizar",
    "sonorizações": "sonorização",
    "sonorize": "sonorizar",
    "sonorizei": "sonorizar",
    "sonorizeis": "sonorizar",
    "sonorizem": "sonorizar",
    "sonorizemo": "sonorizar",
    "sonorizemos": "sonorizar",
    "sonorizes": "sonorizar",
    "sonorizo": "sonorizar",
    "sonorizou": "sonorizar",
    "sonorizá": "sonorizar",
    "sonorizámo": "sonorizar",
    "sonorizámos": "sonorizar",
    "sonorizáramo": "sonorizar",
    "sonorizáramos": "sonorizar",
    "sonorizárei": "sonorizar",
    "sonorizáreis": "sonorizar",
    "sonorizásseis": "sonorizar",
    "sonorizássemos": "sonorizar",
    "sonorizávamo": "sonorizar",
    "sonorizávamos": "sonorizar",
    "sonorizávei": "sonorizar",
    "sonorizáveis": "sonorizar",
    "sonoros": "sonoro",
    "sonorosa": "sonoroso",
    "sonorosas": "sonoroso",
    "sonorosos": "sonoroso",
    "sonoríssima": "sonoro",
    "sonoríssimas": "sonoro",
    "sonoríssimo": "sonoro",
    "sonoríssimos": "sonoro",
    "sonos": "sono",
    "sonotecas": "sonoteca",
    "sonoterapias": "sonoterapia",
    "sonotipos": "sonotipo",
    "sonotécnica": "sonotécnico",
    "sonotécnicas": "sonotécnico",
    "sonotécnicos": "sonotécnico",
    "sons": "som",
    "sonsa": "sonso",
    "sonsas": "sonso",
    "sonsazinha": "sonso",
    "sonsazinhas": "sonso",
    "sonsazita": "sonso",
    "sonsazitas": "sonso",
    "sonsices": "sonsice",
    "sonsinha": "sonso",
    "sonsinhas": "sonso",
    "sonsinho": "sonso",
    "sonsinhos": "sonso",
    "sonsita": "sonso",
    "sonsitas": "sonso",
    "sonsito": "sonso",
    "sonsitos": "sonso",
    "sonsonetes": "sonsonete",
    "sonsos": "sonso",
    "sonsozinho": "sonso",
    "sonsozinhos": "sonso",
    "sonsozito": "sonso",
    "sonsozitos": "sonso",
    "sonsões": "sonsão",
    "sonâmbula": "sonâmbulo",
    "sonâmbulas": "sonâmbulo",
    "sonâmbulos": "sonâmbulo",
    "sonâncias": "sonância",
    "sonífera": "sonífero",
    "soníferas": "sonífero",
    "soníferos": "sonífero",
    "soníloqua": "soníloquo",
    "soníloquas": "soníloquo",
    "soníloquos": "soníloquo",
    "sonípedes": "sonípede",
    "sonívios": "sonívio",
    "sonómetros": "sonómetro",
    "soo": "soer",
    "soou": "soar",
    "sopapeada": "sopapear",
    "sopapeadas": "sopapear",
    "sopapeado": "sopapear",
    "sopapeados": "sopapear",
    "sopapeai": "sopapear",
    "sopapeais": "sopapear",
    "sopapeamo": "sopapear",
    "sopapeamos": "sopapear",
    "sopapeando": "sopapear",
    "sopapeara": "sopapear",
    "sopapearam": "sopapear",
    "sopapearas": "sopapear",
    "sopapearde": "sopapear",
    "sopapeardes": "sopapear",
    "sopapeare": "sopapear",
    "sopapearei": "sopapear",
    "sopapeareis": "sopapear",
    "sopapearem": "sopapear",
    "sopapearemos": "sopapear",
    "sopapeares": "sopapear",
    "sopapearia": "sopapear",
    "sopapeariam": "sopapear",
    "sopapearias": "sopapear",
    "sopapearmo": "sopapear",
    "sopapearmos": "sopapear",
    "sopapeará": "sopapear",
    "sopapearás": "sopapear",
    "sopapearão": "sopapear",
    "sopapearíamos": "sopapear",
    "sopapearíeis": "sopapear",
    "sopapeasse": "sopapear",
    "sopapeassem": "sopapear",
    "sopapeasses": "sopapear",
    "sopapeaste": "sopapear",
    "sopapeastes": "sopapear",
    "sopapeava": "sopapear",
    "sopapeavam": "sopapear",
    "sopapeavas": "sopapear",
    "sopapeei": "sopapear",
    "sopapeeis": "sopapear",
    "sopapeemo": "sopapear",
    "sopapeemos": "sopapear",
    "sopapeia": "sopapear",
    "sopapeiam": "sopapear",
    "sopapeias": "sopapear",
    "sopapeie": "sopapear",
    "sopapeiem": "sopapear",
    "sopapeies": "sopapear",
    "sopapeio": "sopapear",
    "sopapeou": "sopapear",
    "sopapeá": "sopapear",
    "sopapeámo": "sopapear",
    "sopapeámos": "sopapear",
    "sopapeáramo": "sopapear",
    "sopapeáramos": "sopapear",
    "sopapeárei": "sopapear",
    "sopapeáreis": "sopapear",
    "sopapeásseis": "sopapear",
    "sopapeássemos": "sopapear",
    "sopapeávamo": "sopapear",
    "sopapeávamos": "sopapear",
    "sopapeávei": "sopapear",
    "sopapeáveis": "sopapear",
    "sopapos": "sopapo",
    "sopas": "sopa",
    "sopeada": "sopear",
    "sopeadas": "sopear",
    "sopeado": "sopear",
    "sopeadora": "sopeador",
    "sopeadoras": "sopeador",
    "sopeadores": "sopeador",
    "sopeados": "sopear",
    "sopeai": "sopear",
    "sopeais": "sopear",
    "sopeamentos": "sopeamento",
    "sopeamo": "sopear",
    "sopeamos": "sopear",
    "sopeando": "sopear",
    "sopeara": "sopear",
    "sopearam": "sopear",
    "sopearas": "sopear",
    "sopearde": "sopear",
    "sopeardes": "sopear",
    "sopeare": "sopear",
    "sopearei": "sopear",
    "sopeareis": "sopear",
    "sopearem": "sopear",
    "sopearemos": "sopear",
    "sopeares": "sopear",
    "sopearia": "sopear",
    "sopeariam": "sopear",
    "sopearias": "sopear",
    "sopearmo": "sopear",
    "sopearmos": "sopear",
    "sopeará": "sopear",
    "sopearás": "sopear",
    "sopearão": "sopear",
    "sopearíamos": "sopear",
    "sopearíeis": "sopear",
    "sopeasse": "sopear",
    "sopeassem": "sopear",
    "sopeasses": "sopear",
    "sopeaste": "sopear",
    "sopeastes": "sopear",
    "sopeava": "sopear",
    "sopeavam": "sopear",
    "sopeavas": "sopear",
    "sopeei": "sopear",
    "sopeeis": "sopear",
    "sopeemo": "sopear",
    "sopeemos": "sopear",
    "sopega": "sopegar",
    "sopegada": "sopegar",
    "sopegadas": "sopegar",
    "sopegado": "sopegar",
    "sopegados": "sopegar",
    "sopegai": "sopegar",
    "sopegais": "sopegar",
    "sopegam": "sopegar",
    "sopegamo": "sopegar",
    "sopegamos": "sopegar",
    "sopegando": "sopegar",
    "sopegara": "sopegar",
    "sopegaram": "sopegar",
    "sopegaras": "sopegar",
    "sopegardes": "sopegar",
    "sopegarei": "sopegar",
    "sopegareis": "sopegar",
    "sopegarem": "sopegar",
    "sopegaremos": "sopegar",
    "sopegares": "sopegar",
    "sopegaria": "sopegar",
    "sopegariam": "sopegar",
    "sopegarias": "sopegar",
    "sopegarmo": "sopegar",
    "sopegarmos": "sopegar",
    "sopegará": "sopegar",
    "sopegarás": "sopegar",
    "sopegarão": "sopegar",
    "sopegaríamos": "sopegar",
    "sopegaríeis": "sopegar",
    "sopegas": "sopegar",
    "sopegasse": "sopegar",
    "sopegassem": "sopegar",
    "sopegasses": "sopegar",
    "sopegaste": "sopegar",
    "sopegastes": "sopegar",
    "sopegava": "sopegar",
    "sopegavam": "sopegar",
    "sopegavas": "sopegar",
    "sopego": "sopegar",
    "sopegou": "sopegar",
    "sopegue": "sopegar",
    "sopeguei": "sopegar",
    "sopegueis": "sopegar",
    "sopeguem": "sopegar",
    "sopeguemo": "sopegar",
    "sopeguemos": "sopegar",
    "sopegues": "sopegar",
    "sopegámo": "sopegar",
    "sopegámos": "sopegar",
    "sopegáramo": "sopegar",
    "sopegáramos": "sopegar",
    "sopegáreis": "sopegar",
    "sopegásseis": "sopegar",
    "sopegássemos": "sopegar",
    "sopegávamo": "sopegar",
    "sopegávamos": "sopegar",
    "sopegáveis": "sopegar",
    "sopeia": "sopear",
    "sopeiam": "sopear",
    "sopeias": "sopear",
    "sopeie": "sopear",
    "sopeiem": "sopear",
    "sopeies": "sopear",
    "sopeio": "sopear",
    "sopeira": "sopeiro",
    "sopeirais": "sopeiral",
    "sopeirames": "sopeirame",
    "sopeiras": "sopeiro",
    "sopeirazinha": "sopeiro",
    "sopeirazinhas": "sopeiro",
    "sopeirazita": "sopeiro",
    "sopeirazitas": "sopeiro",
    "sopeirinha": "sopeiro",
    "sopeirinhas": "sopeiro",
    "sopeirinho": "sopeiro",
    "sopeirinhos": "sopeiro",
    "sopeirita": "sopeiro",
    "sopeiritas": "sopeiro",
    "sopeirito": "sopeiro",
    "sopeiritos": "sopeiro",
    "sopeiros": "sopeiro",
    "sopeirozinho": "sopeiro",
    "sopeirozinhos": "sopeiro",
    "sopeirozito": "sopeiro",
    "sopeirozitos": "sopeiro",
    "sopeou": "sopear",
    "sopesa": "sopesar",
    "sopesada": "sopesar",
    "sopesadas": "sopesar",
    "sopesado": "sopesar",
    "sopesados": "sopesar",
    "sopesai": "sopesar",
    "sopesais": "sopesar",
    "sopesam": "sopesar",
    "sopesamo": "sopesar",
    "sopesamos": "sopesar",
    "sopesando": "sopesar",
    "sopesara": "sopesar",
    "sopesaram": "sopesar",
    "sopesaras": "sopesar",
    "sopesarde": "sopesar",
    "sopesardes": "sopesar",
    "sopesare": "sopesar",
    "sopesarei": "sopesar",
    "sopesareis": "sopesar",
    "sopesarem": "sopesar",
    "sopesaremos": "sopesar",
    "sopesares": "sopesar",
    "sopesaria": "sopesar",
    "sopesariam": "sopesar",
    "sopesarias": "sopesar",
    "sopesarmo": "sopesar",
    "sopesarmos": "sopesar",
    "sopesará": "sopesar",
    "sopesarás": "sopesar",
    "sopesarão": "sopesar",
    "sopesaríamos": "sopesar",
    "sopesaríeis": "sopesar",
    "sopesas": "sopesar",
    "sopesasse": "sopesar",
    "sopesassem": "sopesar",
    "sopesasses": "sopesar",
    "sopesaste": "sopesar",
    "sopesastes": "sopesar",
    "sopesava": "sopesar",
    "sopesavam": "sopesar",
    "sopesavas": "sopesar",
    "sopese": "sopesar",
    "sopesei": "sopesar",
    "sopeseis": "sopesar",
    "sopesem": "sopesar",
    "sopesemo": "sopesar",
    "sopesemos": "sopesar",
    "sopeses": "sopesar",
    "sopeso": "sopesar",
    "sopesos": "sopeso",
    "sopesou": "sopesar",
    "sopesá": "sopesar",
    "sopesámo": "sopesar",
    "sopesámos": "sopesar",
    "sopesáramo": "sopesar",
    "sopesáramos": "sopesar",
    "sopesárei": "sopesar",
    "sopesáreis": "sopesar",
    "sopesásseis": "sopesar",
    "sopesássemos": "sopesar",
    "sopesávamo": "sopesar",
    "sopesávamos": "sopesar",
    "sopesávei": "sopesar",
    "sopesáveis": "sopesar",
    "sopetarras": "sopetarra",
    "sopeteada": "sopetear",
    "sopeteadas": "sopetear",
    "sopeteado": "sopetear",
    "sopeteados": "sopetear",
    "sopeteai": "sopetear",
    "sopeteais": "sopetear",
    "sopeteamo": "sopetear",
    "sopeteamos": "sopetear",
    "sopeteando": "sopetear",
    "sopeteara": "sopetear",
    "sopetearam": "sopetear",
    "sopetearas": "sopetear",
    "sopeteardes": "sopetear",
    "sopetearei": "sopetear",
    "sopeteareis": "sopetear",
    "sopetearem": "sopetear",
    "sopetearemos": "sopetear",
    "sopeteares": "sopetear",
    "sopetearia": "sopetear",
    "sopeteariam": "sopetear",
    "sopetearias": "sopetear",
    "sopetearmo": "sopetear",
    "sopetearmos": "sopetear",
    "sopeteará": "sopetear",
    "sopetearás": "sopetear",
    "sopetearão": "sopetear",
    "sopetearíamos": "sopetear",
    "sopetearíeis": "sopetear",
    "sopeteasse": "sopetear",
    "sopeteassem": "sopetear",
    "sopeteasses": "sopetear",
    "sopeteaste": "sopetear",
    "sopeteastes": "sopetear",
    "sopeteava": "sopetear",
    "sopeteavam": "sopetear",
    "sopeteavas": "sopetear",
    "sopeteei": "sopetear",
    "sopeteeis": "sopetear",
    "sopeteemo": "sopetear",
    "sopeteemos": "sopetear",
    "sopeteia": "sopetear",
    "sopeteiam": "sopetear",
    "sopeteias": "sopetear",
    "sopeteie": "sopetear",
    "sopeteiem": "sopetear",
    "sopeteies": "sopetear",
    "sopeteio": "sopetear",
    "sopeteou": "sopetear",
    "sopeteámo": "sopetear",
    "sopeteámos": "sopetear",
    "sopeteáramo": "sopetear",
    "sopeteáramos": "sopetear",
    "sopeteáreis": "sopetear",
    "sopeteásseis": "sopetear",
    "sopeteássemos": "sopetear",
    "sopeteávamo": "sopetear",
    "sopeteávamos": "sopetear",
    "sopeteáveis": "sopetear",
    "sopeá": "sopear",
    "sopeámo": "sopear",
    "sopeámos": "sopear",
    "sopeáramo": "sopear",
    "sopeáramos": "sopear",
    "sopeárei": "sopear",
    "sopeáreis": "sopear",
    "sopeásseis": "sopear",
    "sopeássemos": "sopear",
    "sopeávamo": "sopear",
    "sopeávamos": "sopear",
    "sopeávei": "sopear",
    "sopeáveis": "sopear",
    "sopia": "sopiar",
    "sopiada": "sopiar",
    "sopiadas": "sopiar",
    "sopiado": "sopiar",
    "sopiados": "sopiar",
    "sopiai": "sopiar",
    "sopiais": "sopiar",
    "sopiam": "sopiar",
    "sopiamo": "sopiar",
    "sopiamos": "sopiar",
    "sopiando": "sopiar",
    "sopiara": "sopiar",
    "sopiaram": "sopiar",
    "sopiaras": "sopiar",
    "sopiarde": "sopiar",
    "sopiardes": "sopiar",
    "sopiare": "sopiar",
    "sopiarei": "sopiar",
    "sopiareis": "sopiar",
    "sopiarem": "sopiar",
    "sopiaremos": "sopiar",
    "sopiares": "sopiar",
    "sopiaria": "sopiar",
    "sopiariam": "sopiar",
    "sopiarias": "sopiar",
    "sopiarmo": "sopiar",
    "sopiarmos": "sopiar",
    "sopiará": "sopiar",
    "sopiarás": "sopiar",
    "sopiarão": "sopiar",
    "sopiaríamos": "sopiar",
    "sopiaríeis": "sopiar",
    "sopias": "sopiar",
    "sopiasse": "sopiar",
    "sopiassem": "sopiar",
    "sopiasses": "sopiar",
    "sopiaste": "sopiar",
    "sopiastes": "sopiar",
    "sopiava": "sopiar",
    "sopiavam": "sopiar",
    "sopiavas": "sopiar",
    "sopie": "sopiar",
    "sopiei": "sopiar",
    "sopieis": "sopiar",
    "sopiem": "sopiar",
    "sopiemo": "sopiar",
    "sopiemos": "sopiar",
    "sopies": "sopiar",
    "sopinha": "sopa",
    "sopinhas": "sopa",
    "sopio": "sopiar",
    "sopiou": "sopiar",
    "sopistas": "sopista",
    "sopistazinha": "sopista",
    "sopistazinhas": "sopista",
    "sopistazinho": "sopista",
    "sopistazinhos": "sopista",
    "sopistazita": "sopista",
    "sopistazitas": "sopista",
    "sopistazito": "sopista",
    "sopistazitos": "sopista",
    "sopita": "sopito",
    "sopitada": "sopitar",
    "sopitadas": "sopitar",
    "sopitado": "sopitar",
    "sopitados": "sopitar",
    "sopitai": "sopitar",
    "sopitais": "sopitar",
    "sopitam": "sopitar",
    "sopitamentos": "sopitamento",
    "sopitamo": "sopitar",
    "sopitamos": "sopitar",
    "sopitando": "sopitar",
    "sopitara": "sopitar",
    "sopitaram": "sopitar",
    "sopitaras": "sopitar",
    "sopitarde": "sopitar",
    "sopitardes": "sopitar",
    "sopitare": "sopitar",
    "sopitarei": "sopitar",
    "sopitareis": "sopitar",
    "sopitarem": "sopitar",
    "sopitaremos": "sopitar",
    "sopitares": "sopitar",
    "sopitaria": "sopitar",
    "sopitariam": "sopitar",
    "sopitarias": "sopitar",
    "sopitarmo": "sopitar",
    "sopitarmos": "sopitar",
    "sopitará": "sopitar",
    "sopitarás": "sopitar",
    "sopitarão": "sopitar",
    "sopitaríamos": "sopitar",
    "sopitaríeis": "sopitar",
    "sopitas": "sopito",
    "sopitasse": "sopitar",
    "sopitassem": "sopitar",
    "sopitasses": "sopitar",
    "sopitaste": "sopitar",
    "sopitastes": "sopitar",
    "sopitava": "sopitar",
    "sopitavam": "sopitar",
    "sopitavas": "sopitar",
    "sopite": "sopitar",
    "sopitei": "sopitar",
    "sopiteis": "sopitar",
    "sopitem": "sopitar",
    "sopitemo": "sopitar",
    "sopitemos": "sopitar",
    "sopites": "sopitar",
    "sopito": "sopitar",
    "sopitos": "sopito",
    "sopitou": "sopitar",
    "sopitá": "sopitar",
    "sopitámo": "sopitar",
    "sopitámos": "sopitar",
    "sopitáramo": "sopitar",
    "sopitáramos": "sopitar",
    "sopitárei": "sopitar",
    "sopitáreis": "sopitar",
    "sopitásseis": "sopitar",
    "sopitássemos": "sopitar",
    "sopitávamo": "sopitar",
    "sopitávamos": "sopitar",
    "sopitávei": "sopitar",
    "sopitáveis": "sopitar",
    "sopiá": "sopiar",
    "sopiámo": "sopiar",
    "sopiámos": "sopiar",
    "sopiáramo": "sopiar",
    "sopiáramos": "sopiar",
    "sopiárei": "sopiar",
    "sopiáreis": "sopiar",
    "sopiásseis": "sopiar",
    "sopiássemos": "sopiar",
    "sopiávamo": "sopiar",
    "sopiávamos": "sopiar",
    "sopiávei": "sopiar",
    "sopiáveis": "sopiar",
    "sopona": "sopão",
    "soponas": "sopão",
    "soponta": "sopontar",
    "sopontada": "sopontar",
    "sopontadas": "sopontar",
    "sopontado": "sopontar",
    "sopontados": "sopontar",
    "sopontaduras": "sopontadura",
    "sopontai": "sopontar",
    "sopontais": "sopontar",
    "sopontam": "sopontar",
    "sopontamo": "sopontar",
    "sopontamos": "sopontar",
    "sopontando": "sopontar",
    "sopontara": "sopontar",
    "sopontaram": "sopontar",
    "sopontaras": "sopontar",
    "sopontarde": "sopontar",
    "sopontardes": "sopontar",
    "sopontare": "sopontar",
    "sopontarei": "sopontar",
    "sopontareis": "sopontar",
    "sopontarem": "sopontar",
    "sopontaremos": "sopontar",
    "sopontares": "sopontar",
    "sopontaria": "sopontar",
    "sopontariam": "sopontar",
    "sopontarias": "sopontar",
    "sopontarmo": "sopontar",
    "sopontarmos": "sopontar",
    "sopontará": "sopontar",
    "sopontarás": "sopontar",
    "sopontarão": "sopontar",
    "sopontaríamos": "sopontar",
    "sopontaríeis": "sopontar",
    "sopontas": "sopontar",
    "sopontasse": "sopontar",
    "sopontassem": "sopontar",
    "sopontasses": "sopontar",
    "sopontaste": "sopontar",
    "sopontastes": "sopontar",
    "sopontava": "sopontar",
    "sopontavam": "sopontar",
    "sopontavas": "sopontar",
    "soponte": "sopontar",
    "sopontei": "sopontar",
    "soponteis": "sopontar",
    "sopontem": "sopontar",
    "sopontemo": "sopontar",
    "sopontemos": "sopontar",
    "sopontes": "sopontar",
    "soponto": "sopontar",
    "sopontou": "sopontar",
    "sopontá": "sopontar",
    "sopontámo": "sopontar",
    "sopontámos": "sopontar",
    "sopontáramo": "sopontar",
    "sopontáramos": "sopontar",
    "sopontárei": "sopontar",
    "sopontáreis": "sopontar",
    "sopontásseis": "sopontar",
    "sopontássemos": "sopontar",
    "sopontávamo": "sopontar",
    "sopontávamos": "sopontar",
    "sopontávei": "sopontar",
    "sopontáveis": "sopontar",
    "soporada": "soporado",
    "soporadas": "soporado",
    "soporados": "soporado",
    "soporativa": "soporativo",
    "soporativas": "soporativo",
    "soporativos": "soporativo",
    "sopores": "sopor",
    "soporiza": "soporizar",
    "soporizada": "soporizar",
    "soporizadas": "soporizar",
    "soporizado": "soporizar",
    "soporizados": "soporizar",
    "soporizai": "soporizar",
    "soporizais": "soporizar",
    "soporizam": "soporizar",
    "soporizamo": "soporizar",
    "soporizamos": "soporizar",
    "soporizando": "soporizar",
    "soporizara": "soporizar",
    "soporizaram": "soporizar",
    "soporizaras": "soporizar",
    "soporizarde": "soporizar",
    "soporizardes": "soporizar",
    "soporizare": "soporizar",
    "soporizarei": "soporizar",
    "soporizareis": "soporizar",
    "soporizarem": "soporizar",
    "soporizaremos": "soporizar",
    "soporizares": "soporizar",
    "soporizaria": "soporizar",
    "soporizariam": "soporizar",
    "soporizarias": "soporizar",
    "soporizarmo": "soporizar",
    "soporizarmos": "soporizar",
    "soporizará": "soporizar",
    "soporizarás": "soporizar",
    "soporizarão": "soporizar",
    "soporizaríamos": "soporizar",
    "soporizaríeis": "soporizar",
    "soporizas": "soporizar",
    "soporizasse": "soporizar",
    "soporizassem": "soporizar",
    "soporizasses": "soporizar",
    "soporizaste": "soporizar",
    "soporizastes": "soporizar",
    "soporizava": "soporizar",
    "soporizavam": "soporizar",
    "soporizavas": "soporizar",
    "soporize": "soporizar",
    "soporizei": "soporizar",
    "soporizeis": "soporizar",
    "soporizem": "soporizar",
    "soporizemo": "soporizar",
    "soporizemos": "soporizar",
    "soporizes": "soporizar",
    "soporizo": "soporizar",
    "soporizou": "soporizar",
    "soporizá": "soporizar",
    "soporizámo": "soporizar",
    "soporizámos": "soporizar",
    "soporizáramo": "soporizar",
    "soporizáramos": "soporizar",
    "soporizárei": "soporizar",
    "soporizáreis": "soporizar",
    "soporizásseis": "soporizar",
    "soporizássemos": "soporizar",
    "soporizávamo": "soporizar",
    "soporizávamos": "soporizar",
    "soporizávei": "soporizar",
    "soporizáveis": "soporizar",
    "soporosa": "soporoso",
    "soporosas": "soporoso",
    "soporosos": "soporoso",
    "soportais": "soportal",
    "soporífera": "soporífero",
    "soporíferas": "soporífero",
    "soporíferos": "soporífero",
    "soporífica": "soporífico",
    "soporíficas": "soporífico",
    "soporíficos": "soporífico",
    "sopra": "soprar",
    "soprada": "soprar",
    "sopradas": "soprar",
    "soprado": "soprar",
    "sopradora": "soprador",
    "sopradoras": "soprador",
    "sopradorazinha": "soprador",
    "sopradorazinhas": "soprador",
    "sopradorazita": "soprador",
    "sopradorazitas": "soprador",
    "sopradores": "soprador",
    "sopradorzinho": "soprador",
    "sopradorzinhos": "soprador",
    "sopradorzito": "soprador",
    "sopradorzitos": "soprador",
    "soprados": "soprar",
    "soprai": "soprar",
    "soprais": "soprar",
    "sopram": "soprar",
    "sopramo": "soprar",
    "sopramos": "soprar",
    "soprando": "soprar",
    "sopraninos": "sopranino",
    "sopranistas": "sopranista",
    "sopranistazinha": "sopranista",
    "sopranistazinhas": "sopranista",
    "sopranistazinho": "sopranista",
    "sopranistazinhos": "sopranista",
    "sopranistazita": "sopranista",
    "sopranistazitas": "sopranista",
    "sopranistazito": "sopranista",
    "sopranistazitos": "sopranista",
    "sopranos": "soprano",
    "soprara": "soprar",
    "sopraram": "soprar",
    "sopraras": "soprar",
    "soprarde": "soprar",
    "soprardes": "soprar",
    "soprare": "soprar",
    "soprarei": "soprar",
    "soprareis": "soprar",
    "soprarem": "soprar",
    "sopraremos": "soprar",
    "soprares": "soprar",
    "sopraria": "soprar",
    "soprariam": "soprar",
    "soprarias": "soprar",
    "soprarmo": "soprar",
    "soprarmos": "soprar",
    "soprará": "soprar",
    "soprarás": "soprar",
    "soprarão": "soprar",
    "sopraríamos": "soprar",
    "sopraríeis": "soprar",
    "sopras": "soprar",
    "soprasse": "soprar",
    "soprassem": "soprar",
    "soprasses": "soprar",
    "sopraste": "soprar",
    "soprastes": "soprar",
    "soprava": "soprar",
    "sopravam": "soprar",
    "sopravas": "soprar",
    "sopre": "soprar",
    "soprei": "soprar",
    "sopreis": "soprar",
    "soprem": "soprar",
    "sopremo": "soprar",
    "sopremos": "sopremo",
    "sopres": "soprar",
    "sopresa": "sopresar",
    "sopresada": "sopresar",
    "sopresadas": "sopresar",
    "sopresado": "sopresar",
    "sopresados": "sopresar",
    "sopresai": "sopresar",
    "sopresais": "sopresar",
    "sopresam": "sopresar",
    "sopresamo": "sopresar",
    "sopresamos": "sopresar",
    "sopresando": "sopresar",
    "sopresara": "sopresar",
    "sopresaram": "sopresar",
    "sopresaras": "sopresar",
    "sopresarde": "sopresar",
    "sopresardes": "sopresar",
    "sopresare": "sopresar",
    "sopresarei": "sopresar",
    "sopresareis": "sopresar",
    "sopresarem": "sopresar",
    "sopresaremos": "sopresar",
    "sopresares": "sopresar",
    "sopresaria": "sopresar",
    "sopresariam": "sopresar",
    "sopresarias": "sopresar",
    "sopresarmo": "sopresar",
    "sopresarmos": "sopresar",
    "sopresará": "sopresar",
    "sopresarás": "sopresar",
    "sopresarão": "sopresar",
    "sopresaríamos": "sopresar",
    "sopresaríeis": "sopresar",
    "sopresas": "sopresar",
    "sopresasse": "sopresar",
    "sopresassem": "sopresar",
    "sopresasses": "sopresar",
    "sopresaste": "sopresar",
    "sopresastes": "sopresar",
    "sopresava": "sopresar",
    "sopresavam": "sopresar",
    "sopresavas": "sopresar",
    "soprese": "sopresar",
    "sopresei": "sopresar",
    "sopreseis": "sopresar",
    "sopresem": "sopresar",
    "sopresemo": "sopresar",
    "sopresemos": "sopresar",
    "sopreses": "sopresar",
    "sopreso": "sopresar",
    "sopresou": "sopresar",
    "sopresá": "sopresar",
    "sopresámo": "sopresar",
    "sopresámos": "sopresar",
    "sopresáramo": "sopresar",
    "sopresáramos": "sopresar",
    "sopresárei": "sopresar",
    "sopresáreis": "sopresar",
    "sopresásseis": "sopresar",
    "sopresássemos": "sopresar",
    "sopresávamo": "sopresar",
    "sopresávamos": "sopresar",
    "sopresávei": "sopresar",
    "sopresáveis": "sopresar",
    "soprilhos": "soprilho",
    "sopro": "soprar",
    "sopros": "sopro",
    "soprou": "soprar",
    "soprá": "soprar",
    "soprámo": "soprar",
    "soprámos": "soprar",
    "sopráramo": "soprar",
    "sopráramos": "soprar",
    "soprárei": "soprar",
    "sopráreis": "soprar",
    "soprásseis": "soprar",
    "soprássemos": "soprar",
    "soprávamo": "soprar",
    "soprávamos": "soprar",
    "soprávei": "soprar",
    "sopráveis": "soprar",
    "sopés": "sopé",
    "sopões": "sopão",
    "soque": "socar",
    "soqueada": "soquear",
    "soqueadas": "soquear",
    "soqueado": "soquear",
    "soqueados": "soquear",
    "soqueai": "soquear",
    "soqueais": "soquear",
    "soqueamo": "soquear",
    "soqueamos": "soquear",
    "soqueando": "soquear",
    "soqueara": "soquear",
    "soquearam": "soquear",
    "soquearas": "soquear",
    "soquearde": "soquear",
    "soqueardes": "soquear",
    "soqueare": "soquear",
    "soquearei": "soquear",
    "soqueareis": "soquear",
    "soquearem": "soquear",
    "soquearemos": "soquear",
    "soqueares": "soquear",
    "soquearia": "soquear",
    "soqueariam": "soquear",
    "soquearias": "soquear",
    "soquearmo": "soquear",
    "soquearmos": "soquear",
    "soqueará": "soquear",
    "soquearás": "soquear",
    "soquearão": "soquear",
    "soquearíamos": "soquear",
    "soquearíeis": "soquear",
    "soqueasse": "soquear",
    "soqueassem": "soquear",
    "soqueasses": "soquear",
    "soqueaste": "soquear",
    "soqueastes": "soquear",
    "soqueava": "soquear",
    "soqueavam": "soquear",
    "soqueavas": "soquear",
    "soqueei": "soquear",
    "soqueeis": "soquear",
    "soqueemo": "soquear",
    "soqueemos": "soquear",
    "soquei": "socar",
    "soqueia": "soquear",
    "soqueiam": "soquear",
    "soqueias": "soquear",
    "soqueie": "soquear",
    "soqueiem": "soquear",
    "soqueies": "soquear",
    "soqueio": "soquear",
    "soqueira": "soqueiro",
    "soqueiras": "soqueiro",
    "soqueiros": "soqueiro",
    "soqueis": "socar",
    "soqueixa": "soqueixar",
    "soqueixada": "soqueixar",
    "soqueixadas": "soqueixar",
    "soqueixado": "soqueixar",
    "soqueixados": "soqueixar",
    "soqueixai": "soqueixar",
    "soqueixais": "soqueixar",
    "soqueixam": "soqueixar",
    "soqueixamo": "soqueixar",
    "soqueixamos": "soqueixar",
    "soqueixando": "soqueixar",
    "soqueixara": "soqueixar",
    "soqueixaram": "soqueixar",
    "soqueixaras": "soqueixar",
    "soqueixarde": "soqueixar",
    "soqueixardes": "soqueixar",
    "soqueixare": "soqueixar",
    "soqueixarei": "soqueixar",
    "soqueixareis": "soqueixar",
    "soqueixarem": "soqueixar",
    "soqueixaremos": "soqueixar",
    "soqueixares": "soqueixar",
    "soqueixaria": "soqueixar",
    "soqueixariam": "soqueixar",
    "soqueixarias": "soqueixar",
    "soqueixarmo": "soqueixar",
    "soqueixarmos": "soqueixar",
    "soqueixará": "soqueixar",
    "soqueixarás": "soqueixar",
    "soqueixarão": "soqueixar",
    "soqueixaríamos": "soqueixar",
    "soqueixaríeis": "soqueixar",
    "soqueixas": "soqueixar",
    "soqueixasse": "soqueixar",
    "soqueixassem": "soqueixar",
    "soqueixasses": "soqueixar",
    "soqueixaste": "soqueixar",
    "soqueixastes": "soqueixar",
    "soqueixava": "soqueixar",
    "soqueixavam": "soqueixar",
    "soqueixavas": "soqueixar",
    "soqueixe": "soqueixar",
    "soqueixei": "soqueixar",
    "soqueixeis": "soqueixar",
    "soqueixem": "soqueixar",
    "soqueixemo": "soqueixar",
    "soqueixemos": "soqueixar",
    "soqueixes": "soqueixar",
    "soqueixo": "soqueixar",
    "soqueixos": "soqueixo",
    "soqueixou": "soqueixar",
    "soqueixá": "soqueixar",
    "soqueixámo": "soqueixar",
    "soqueixámos": "soqueixar",
    "soqueixáramo": "soqueixar",
    "soqueixáramos": "soqueixar",
    "soqueixárei": "soqueixar",
    "soqueixáreis": "soqueixar",
    "soqueixásseis": "soqueixar",
    "soqueixássemos": "soqueixar",
    "soqueixávamo": "soqueixar",
    "soqueixávamos": "soqueixar",
    "soqueixávei": "soqueixar",
    "soqueixáveis": "soqueixar",
    "soquem": "socar",
    "soquemo": "socar",
    "soquemos": "socar",
    "soqueou": "soquear",
    "soques": "socar",
    "soqueteada": "soquetear",
    "soqueteadas": "soquetear",
    "soqueteado": "soquetear",
    "soqueteados": "soquetear",
    "soqueteai": "soquetear",
    "soqueteais": "soquetear",
    "soqueteamo": "soquetear",
    "soqueteamos": "soquetear",
    "soqueteando": "soquetear",
    "soqueteara": "soquetear",
    "soquetearam": "soquetear",
    "soquetearas": "soquetear",
    "soquetearde": "soquetear",
    "soqueteardes": "soquetear",
    "soqueteare": "soquetear",
    "soquetearei": "soquetear",
    "soqueteareis": "soquetear",
    "soquetearem": "soquetear",
    "soquetearemos": "soquetear",
    "soqueteares": "soquetear",
    "soquetearia": "soquetear",
    "soqueteariam": "soquetear",
    "soquetearias": "soquetear",
    "soquetearmo": "soquetear",
    "soquetearmos": "soquetear",
    "soqueteará": "soquetear",
    "soquetearás": "soquetear",
    "soquetearão": "soquetear",
    "soquetearíamos": "soquetear",
    "soquetearíeis": "soquetear",
    "soqueteasse": "soquetear",
    "soqueteassem": "soquetear",
    "soqueteasses": "soquetear",
    "soqueteaste": "soquetear",
    "soqueteastes": "soquetear",
    "soqueteava": "soquetear",
    "soqueteavam": "soquetear",
    "soqueteavas": "soquetear",
    "soqueteei": "soquetear",
    "soqueteeis": "soquetear",
    "soqueteemo": "soquetear",
    "soqueteemos": "soquetear",
    "soqueteia": "soquetear",
    "soqueteiam": "soquetear",
    "soqueteias": "soquetear",
    "soqueteie": "soquetear",
    "soqueteiem": "soquetear",
    "soqueteies": "soquetear",
    "soqueteio": "soquetear",
    "soqueteou": "soquetear",
    "soquetes": "soquete",
    "soqueteá": "soquetear",
    "soqueteámo": "soquetear",
    "soqueteámos": "soquetear",
    "soqueteáramo": "soquetear",
    "soqueteáramos": "soquetear",
    "soqueteárei": "soquetear",
    "soqueteáreis": "soquetear",
    "soqueteásseis": "soquetear",
    "soqueteássemos": "soquetear",
    "soqueteávamo": "soquetear",
    "soqueteávamos": "soquetear",
    "soqueteávei": "soquetear",
    "soqueteáveis": "soquetear",
    "soqueá": "soquear",
    "soqueámo": "soquear",
    "soqueámos": "soquear",
    "soqueáramo": "soquear",
    "soqueáramos": "soquear",
    "soqueárei": "soquear",
    "soqueáreis": "soquear",
    "soqueásseis": "soquear",
    "soqueássemos": "soquear",
    "soqueávamo": "soquear",
    "soqueávamos": "soquear",
    "soqueávei": "soquear",
    "soqueáveis": "soquear",
    "sora": "sorar",
    "sorada": "sorar",
    "soradas": "sorar",
    "sorado": "sorar",
    "sorados": "sorar",
    "sorai": "sorar",
    "sorais": "sorar",
    "soram": "sorar",
    "soramo": "sorar",
    "soramos": "sorar",
    "sorando": "sorar",
    "sorara": "sorar",
    "soraram": "sorar",
    "soraras": "sorar",
    "sorarde": "sorar",
    "sorardes": "sorar",
    "sorare": "sorar",
    "sorarei": "sorar",
    "sorareis": "sorar",
    "sorarem": "sorar",
    "soraremos": "sorar",
    "sorares": "sorar",
    "soraria": "sorar",
    "sorariam": "sorar",
    "sorarias": "sorar",
    "sorarmo": "sorar",
    "sorarmos": "sorar",
    "sorará": "sorar",
    "sorarás": "sorar",
    "sorarão": "sorar",
    "soraríamos": "sorar",
    "soraríeis": "sorar",
    "soras": "sorar",
    "sorascos": "sorasco",
    "sorasse": "sorar",
    "sorassem": "sorar",
    "sorasses": "sorar",
    "soraste": "sorar",
    "sorastes": "sorar",
    "sorava": "sorar",
    "soravam": "sorar",
    "soravas": "sorar",
    "sorbonistas": "sorbonista",
    "sorbonistazinha": "sorbonista",
    "sorbonistazinhas": "sorbonista",
    "sorbonistazinho": "sorbonista",
    "sorbonistazinhos": "sorbonista",
    "sorbonistazita": "sorbonista",
    "sorbonistazitas": "sorbonista",
    "sorbonistazito": "sorbonista",
    "sorbonistazitos": "sorbonista",
    "sorbónica": "sorbónico",
    "sorbónicas": "sorbónico",
    "sorbónicos": "sorbónico",
    "sordidezas": "sordideza",
    "sordícias": "sordícia",
    "sordícies": "sordície",
    "sore": "sorar",
    "soreadora": "soreador",
    "soreadoras": "soreador",
    "soreadorazinha": "soreador",
    "soreadorazinhas": "soreador",
    "soreadorazita": "soreador",
    "soreadorazitas": "soreador",
    "soreadores": "soreador",
    "soreadorzinho": "soreador",
    "soreadorzinhos": "soreador",
    "soreadorzito": "soreador",
    "soreadorzitos": "soreador",
    "sorei": "sorar",
    "soreis": "sorar",
    "sorem": "sorar",
    "soremo": "sorar",
    "soremos": "sorar",
    "sores": "sorar",
    "sorgos": "sorgo",
    "soriana": "soriano",
    "sorianas": "soriano",
    "sorianazinha": "soriano",
    "sorianazinhas": "soriano",
    "sorianazita": "soriano",
    "sorianazitas": "soriano",
    "sorianos": "soriano",
    "sorianozinho": "soriano",
    "sorianozinhos": "soriano",
    "sorianozito": "soriano",
    "sorianozitos": "soriano",
    "sorices": "sorice",
    "soritas": "sorita",
    "sorna": "sornar",
    "sornada": "sornar",
    "sornadas": "sornar",
    "sornado": "sornar",
    "sornados": "sornar",
    "sornai": "sornar",
    "sornais": "sornar",
    "sornam": "sornar",
    "sornamo": "sornar",
    "sornamos": "sornar",
    "sornando": "sornar",
    "sornara": "sornar",
    "sornaram": "sornar",
    "sornaras": "sornar",
    "sornardes": "sornar",
    "sornarei": "sornar",
    "sornareis": "sornar",
    "sornarem": "sornar",
    "sornaremos": "sornar",
    "sornares": "sornar",
    "sornaria": "sornar",
    "sornariam": "sornar",
    "sornarias": "sornar",
    "sornarmo": "sornar",
    "sornarmos": "sornar",
    "sornará": "sornar",
    "sornarás": "sornar",
    "sornarão": "sornar",
    "sornaríamos": "sornar",
    "sornaríeis": "sornar",
    "sornas": "sornar",
    "sornasse": "sornar",
    "sornassem": "sornar",
    "sornasses": "sornar",
    "sornaste": "sornar",
    "sornastes": "sornar",
    "sornava": "sornar",
    "sornavam": "sornar",
    "sornavas": "sornar",
    "sorne": "sornar",
    "sornei": "sornar",
    "sorneira": "sorneiro",
    "sorneiras": "sorneiro",
    "sorneirazinha": "sorneiro",
    "sorneirazinhas": "sorneiro",
    "sorneirazita": "sorneiro",
    "sorneirazitas": "sorneiro",
    "sorneiros": "sorneiro",
    "sorneirozinho": "sorneiro",
    "sorneirozinhos": "sorneiro",
    "sorneirozito": "sorneiro",
    "sorneirozitos": "sorneiro",
    "sorneis": "sornar",
    "sornem": "sornar",
    "sornemo": "sornar",
    "sornemos": "sornar",
    "sornes": "sornar",
    "sorno": "sornar",
    "sornou": "sornar",
    "sornámo": "sornar",
    "sornámos": "sornar",
    "sornáramo": "sornar",
    "sornáramos": "sornar",
    "sornáreis": "sornar",
    "sornásseis": "sornar",
    "sornássemos": "sornar",
    "sornávamo": "sornar",
    "sornávamos": "sornar",
    "sornáveis": "sornar",
    "soro": "sorar",
    "sorocabana": "sorocabano",
    "sorocabanas": "sorocabano",
    "sorocabanos": "sorocabano",
    "sorogrupos": "sorogrupo",
    "sorologias": "sorologia",
    "sorologistas": "sorologista",
    "soromenhas": "soromenha",
    "soromenhos": "soromenho",
    "soror": "sóror",
    "sororicidas": "sororicida",
    "sororicídios": "sororicídio",
    "sororocas": "sororoca",
    "sorors": "sóror",
    "sororós": "sororó",
    "soros": "soro",
    "sorosa": "soroso",
    "sorosas": "soroso",
    "soroses": "sorose",
    "sorosites": "sorosite",
    "sorosos": "soroso",
    "soroterapias": "soroterapia",
    "soroterápica": "soroterápico",
    "soroterápicas": "soroterápico",
    "soroterápicos": "soroterápico",
    "sorotipos": "sorotipo",
    "sorou": "sorar",
    "sorraba": "sorrabar",
    "sorrabada": "sorrabar",
    "sorrabadas": "sorrabar",
    "sorrabado": "sorrabar",
    "sorrabados": "sorrabar",
    "sorrabai": "sorrabar",
    "sorrabais": "sorrabar",
    "sorrabam": "sorrabar",
    "sorrabamo": "sorrabar",
    "sorrabamos": "sorrabar",
    "sorrabando": "sorrabar",
    "sorrabara": "sorrabar",
    "sorrabaram": "sorrabar",
    "sorrabaras": "sorrabar",
    "sorrabarde": "sorrabar",
    "sorrabardes": "sorrabar",
    "sorrabare": "sorrabar",
    "sorrabarei": "sorrabar",
    "sorrabareis": "sorrabar",
    "sorrabarem": "sorrabar",
    "sorrabaremos": "sorrabar",
    "sorrabares": "sorrabar",
    "sorrabaria": "sorrabar",
    "sorrabariam": "sorrabar",
    "sorrabarias": "sorrabar",
    "sorrabarmo": "sorrabar",
    "sorrabarmos": "sorrabar",
    "sorrabará": "sorrabar",
    "sorrabarás": "sorrabar",
    "sorrabarão": "sorrabar",
    "sorrabaríamos": "sorrabar",
    "sorrabaríeis": "sorrabar",
    "sorrabas": "sorrabar",
    "sorrabasse": "sorrabar",
    "sorrabassem": "sorrabar",
    "sorrabasses": "sorrabar",
    "sorrabaste": "sorrabar",
    "sorrabastes": "sorrabar",
    "sorrabava": "sorrabar",
    "sorrabavam": "sorrabar",
    "sorrabavas": "sorrabar",
    "sorrabe": "sorrabar",
    "sorrabei": "sorrabar",
    "sorrabeis": "sorrabar",
    "sorrabem": "sorrabar",
    "sorrabemo": "sorrabar",
    "sorrabemos": "sorrabar",
    "sorrabes": "sorrabar",
    "sorrabo": "sorrabar",
    "sorrabou": "sorrabar",
    "sorrabá": "sorrabar",
    "sorrabámo": "sorrabar",
    "sorrabámos": "sorrabar",
    "sorrabáramo": "sorrabar",
    "sorrabáramos": "sorrabar",
    "sorrabárei": "sorrabar",
    "sorrabáreis": "sorrabar",
    "sorrabásseis": "sorrabar",
    "sorrabássemos": "sorrabar",
    "sorrabávamo": "sorrabar",
    "sorrabávamos": "sorrabar",
    "sorrabávei": "sorrabar",
    "sorrabáveis": "sorrabar",
    "sorrasca": "sorrascar",
    "sorrascada": "sorrascar",
    "sorrascadas": "sorrascar",
    "sorrascado": "sorrascar",
    "sorrascadoiros": "sorrascadoiro",
    "sorrascadors": "sorrascador",
    "sorrascados": "sorrascar",
    "sorrascadouros": "sorrascadouro",
    "sorrascai": "sorrascar",
    "sorrascais": "sorrascar",
    "sorrascam": "sorrascar",
    "sorrascamo": "sorrascar",
    "sorrascamos": "sorrascar",
    "sorrascando": "sorrascar",
    "sorrascara": "sorrascar",
    "sorrascaram": "sorrascar",
    "sorrascaras": "sorrascar",
    "sorrascarde": "sorrascar",
    "sorrascardes": "sorrascar",
    "sorrascare": "sorrascar",
    "sorrascarei": "sorrascar",
    "sorrascareis": "sorrascar",
    "sorrascarem": "sorrascar",
    "sorrascaremos": "sorrascar",
    "sorrascares": "sorrascar",
    "sorrascaria": "sorrascar",
    "sorrascariam": "sorrascar",
    "sorrascarias": "sorrascar",
    "sorrascarmo": "sorrascar",
    "sorrascarmos": "sorrascar",
    "sorrascará": "sorrascar",
    "sorrascarás": "sorrascar",
    "sorrascarão": "sorrascar",
    "sorrascaríamos": "sorrascar",
    "sorrascaríeis": "sorrascar",
    "sorrascas": "sorrascar",
    "sorrascasse": "sorrascar",
    "sorrascassem": "sorrascar",
    "sorrascasses": "sorrascar",
    "sorrascaste": "sorrascar",
    "sorrascastes": "sorrascar",
    "sorrascava": "sorrascar",
    "sorrascavam": "sorrascar",
    "sorrascavas": "sorrascar",
    "sorrasco": "sorrascar",
    "sorrascou": "sorrascar",
    "sorrascá": "sorrascar",
    "sorrascámo": "sorrascar",
    "sorrascámos": "sorrascar",
    "sorrascáramo": "sorrascar",
    "sorrascáramos": "sorrascar",
    "sorrascárei": "sorrascar",
    "sorrascáreis": "sorrascar",
    "sorrascásseis": "sorrascar",
    "sorrascássemos": "sorrascar",
    "sorrascávamo": "sorrascar",
    "sorrascávamos": "sorrascar",
    "sorrascávei": "sorrascar",
    "sorrascáveis": "sorrascar",
    "sorrasque": "sorrascar",
    "sorrasquei": "sorrascar",
    "sorrasqueiros": "sorrasqueiro",
    "sorrasqueis": "sorrascar",
    "sorrasquem": "sorrascar",
    "sorrasquemo": "sorrascar",
    "sorrasquemos": "sorrascar",
    "sorrasques": "sorrascar",
    "sorrasquinhos": "sorrasquinho",
    "sorrateira": "sorrateiro",
    "sorrateiras": "sorrateiro",
    "sorrateiros": "sorrateiro",
    "sorrates": "sorrate",
    "sorrelfa": "sorrelfo",
    "sorrelfas": "sorrelfo",
    "sorrelfos": "sorrelfo",
    "sorri": "sorrir",
    "sorria": "sorrir",
    "sorriais": "sorrir",
    "sorriam": "sorrir",
    "sorriamo": "sorrir",
    "sorriamos": "sorrir",
    "sorrias": "sorrir",
    "sorrida": "sorrir",
    "sorridas": "sorrir",
    "sorride": "sorrir",
    "sorridentes": "sorridente",
    "sorrides": "sorrir",
    "sorrido": "sorrir",
    "sorridos": "sorrir",
    "sorriem": "sorrir",
    "sorrimo": "sorrir",
    "sorrimos": "sorrir",
    "sorrindo": "sorrir",
    "sorrio": "sorrir",
    "sorrira": "sorrir",
    "sorriram": "sorrir",
    "sorriras": "sorrir",
    "sorrirdes": "sorrir",
    "sorrirei": "sorrir",
    "sorrireis": "sorrir",
    "sorrirem": "sorrir",
    "sorriremos": "sorrir",
    "sorrires": "sorrir",
    "sorriria": "sorrir",
    "sorririam": "sorrir",
    "sorririas": "sorrir",
    "sorrirmo": "sorrir",
    "sorrirmos": "sorrir",
    "sorrirá": "sorrir",
    "sorrirás": "sorrir",
    "sorrirão": "sorrir",
    "sorriríamos": "sorrir",
    "sorriríeis": "sorrir",
    "sorris": "sorrir",
    "sorrisinho": "sorriso",
    "sorrisinhos": "sorriso",
    "sorrisito": "sorriso",
    "sorrisitos": "sorriso",
    "sorrisos": "sorriso",
    "sorrisse": "sorrir",
    "sorrissem": "sorrir",
    "sorrisses": "sorrir",
    "sorriste": "sorrir",
    "sorristes": "sorrir",
    "sorriu": "sorrir",
    "sorríamo": "sorrir",
    "sorríamos": "sorrir",
    "sorríeis": "sorrir",
    "sorríramo": "sorrir",
    "sorríramos": "sorrir",
    "sorríreis": "sorrir",
    "sorrísseis": "sorrir",
    "sorríssemos": "sorrir",
    "sorta": "sortir",
    "sortais": "sortir",
    "sortam": "sortir",
    "sortamo": "sortir",
    "sortamos": "sortir",
    "sortas": "sortir",
    "sorte": "sortir",
    "sorteada": "sortear",
    "sorteadas": "sortear",
    "sorteadazinha": "sorteado",
    "sorteadazinhas": "sorteado",
    "sorteadazita": "sorteado",
    "sorteadazitas": "sorteado",
    "sorteado": "sortear",
    "sorteados": "sortear",
    "sorteadozinho": "sorteado",
    "sorteadozinhos": "sorteado",
    "sorteadozito": "sorteado",
    "sorteadozitos": "sorteado",
    "sorteai": "sortear",
    "sorteais": "sortear",
    "sorteamentos": "sorteamento",
    "sorteamo": "sortear",
    "sorteamos": "sortear",
    "sorteando": "sortear",
    "sorteara": "sortear",
    "sortearam": "sortear",
    "sortearas": "sortear",
    "sortearde": "sortear",
    "sorteardes": "sortear",
    "sorteare": "sortear",
    "sortearei": "sortear",
    "sorteareis": "sortear",
    "sortearem": "sortear",
    "sortearemos": "sortear",
    "sorteares": "sortear",
    "sortearia": "sortear",
    "sorteariam": "sortear",
    "sortearias": "sortear",
    "sortearmo": "sortear",
    "sortearmos": "sortear",
    "sorteará": "sortear",
    "sortearás": "sortear",
    "sortearão": "sortear",
    "sortearíamos": "sortear",
    "sortearíeis": "sortear",
    "sorteasse": "sortear",
    "sorteassem": "sortear",
    "sorteasses": "sortear",
    "sorteaste": "sortear",
    "sorteastes": "sortear",
    "sorteava": "sortear",
    "sorteavam": "sortear",
    "sorteavas": "sortear",
    "sorteei": "sortear",
    "sorteeis": "sortear",
    "sorteemo": "sortear",
    "sorteemos": "sortear",
    "sorteia": "sortear",
    "sorteiam": "sortear",
    "sorteias": "sortear",
    "sorteie": "sortear",
    "sorteiem": "sortear",
    "sorteies": "sortear",
    "sorteio": "sortear",
    "sorteios": "sorteio",
    "sorteira": "sorteiro",
    "sorteiras": "sorteiro",
    "sorteiros": "sorteiro",
    "sortelas": "sortela",
    "sortelhas": "sortelha",
    "sortem": "sortir",
    "sorteou": "sortear",
    "sortes": "sortir",
    "sorteá": "sortear",
    "sorteámo": "sortear",
    "sorteámos": "sortear",
    "sorteáramo": "sortear",
    "sorteáramos": "sortear",
    "sorteárei": "sortear",
    "sorteáreis": "sortear",
    "sorteásseis": "sortear",
    "sorteássemos": "sortear",
    "sorteávamo": "sortear",
    "sorteávamos": "sortear",
    "sorteávei": "sortear",
    "sorteáveis": "sortear",
    "sorti": "sortir",
    "sortia": "sortir",
    "sortiam": "sortir",
    "sortias": "sortir",
    "sortida": "sortir",
    "sortidas": "sortir",
    "sortido": "sortir",
    "sortidos": "sortir",
    "sortidíssima": "sortido",
    "sortidíssimas": "sortido",
    "sortidíssimo": "sortido",
    "sortidíssimos": "sortido",
    "sortilegazinha": "sortílego",
    "sortilegazinhas": "sortílego",
    "sortilegazita": "sortílego",
    "sortilegazitas": "sortílego",
    "sortilegozinho": "sortílego",
    "sortilegozinhos": "sortílego",
    "sortilegozito": "sortílego",
    "sortilegozitos": "sortílego",
    "sortilhas": "sortilha",
    "sortilégios": "sortilégio",
    "sortimentos": "sortimento",
    "sortimo": "sortir",
    "sortimos": "sortir",
    "sortindo": "sortir",
    "sortira": "sortir",
    "sortiram": "sortir",
    "sortiras": "sortir",
    "sortirde": "sortir",
    "sortirdes": "sortir",
    "sortire": "sortir",
    "sortirei": "sortir",
    "sortireis": "sortir",
    "sortirem": "sortir",
    "sortiremos": "sortir",
    "sortires": "sortir",
    "sortiria": "sortir",
    "sortiriam": "sortir",
    "sortirias": "sortir",
    "sortirmo": "sortir",
    "sortirmos": "sortir",
    "sortirá": "sortir",
    "sortirás": "sortir",
    "sortirão": "sortir",
    "sortiríamos": "sortir",
    "sortiríeis": "sortir",
    "sortis": "sortir",
    "sortisse": "sortir",
    "sortissem": "sortir",
    "sortisses": "sortir",
    "sortiste": "sortir",
    "sortistes": "sortir",
    "sortiu": "sortir",
    "sorto": "sortir",
    "sortuda": "sortudo",
    "sortudas": "sortudo",
    "sortudos": "sortudo",
    "sortíamo": "sortir",
    "sortíamos": "sortir",
    "sortíei": "sortir",
    "sortíeis": "sortir",
    "sortílega": "sortílego",
    "sortílegas": "sortílego",
    "sortílegos": "sortílego",
    "sortíramo": "sortir",
    "sortíramos": "sortir",
    "sortírei": "sortir",
    "sortíreis": "sortir",
    "sortísseis": "sortir",
    "sortíssemos": "sortir",
    "sortões": "sortão",
    "sorumas": "soruma",
    "sorumbaticazinha": "sorumbático",
    "sorumbaticazinhas": "sorumbático",
    "sorumbaticazita": "sorumbático",
    "sorumbaticazitas": "sorumbático",
    "sorumbaticozinho": "sorumbático",
    "sorumbaticozinhos": "sorumbático",
    "sorumbaticozito": "sorumbático",
    "sorumbaticozitos": "sorumbático",
    "sorumbatismos": "sorumbatismo",
    "sorumbática": "sorumbático",
    "sorumbáticas": "sorumbático",
    "sorumbáticos": "sorumbático",
    "sorva": "sorver",
    "sorvada": "sorvar",
    "sorvadas": "sorvar",
    "sorvado": "sorvar",
    "sorvados": "sorvar",
    "sorvadíssima": "sorvado",
    "sorvadíssimas": "sorvado",
    "sorvadíssimo": "sorvado",
    "sorvadíssimos": "sorvado",
    "sorvai": "sorvar",
    "sorvais": "sorver",
    "sorvalhadas": "sorvalhada",
    "sorvam": "sorver",
    "sorvamo": "sorver",
    "sorvamos": "sorver",
    "sorvando": "sorvar",
    "sorvara": "sorvar",
    "sorvaram": "sorvar",
    "sorvaras": "sorvar",
    "sorvardes": "sorvar",
    "sorvarei": "sorvar",
    "sorvareis": "sorvar",
    "sorvarem": "sorvar",
    "sorvaremos": "sorvar",
    "sorvares": "sorvar",
    "sorvaria": "sorvar",
    "sorvariam": "sorvar",
    "sorvarias": "sorvar",
    "sorvarmo": "sorvar",
    "sorvarmos": "sorvar",
    "sorvará": "sorvar",
    "sorvarás": "sorvar",
    "sorvarão": "sorvar",
    "sorvaríamos": "sorvar",
    "sorvaríeis": "sorvar",
    "sorvas": "sorver",
    "sorvasse": "sorvar",
    "sorvassem": "sorvar",
    "sorvasses": "sorvar",
    "sorvaste": "sorvar",
    "sorvastes": "sorvar",
    "sorvava": "sorvar",
    "sorvavam": "sorvar",
    "sorvavas": "sorvar",
    "sorve": "sorver",
    "sorvedelas": "sorvedela",
    "sorvedoiros": "sorvedoiro",
    "sorvedouros": "sorvedouro",
    "sorveduras": "sorvedura",
    "sorvei": "sorver",
    "sorveis": "sorver",
    "sorvem": "sorver",
    "sorvemo": "sorver",
    "sorvemos": "sorver",
    "sorvendo": "sorver",
    "sorvera": "sorver",
    "sorveram": "sorver",
    "sorveras": "sorver",
    "sorverdes": "sorver",
    "sorverei": "sorver",
    "sorvereis": "sorver",
    "sorverem": "sorver",
    "sorveremos": "sorver",
    "sorveres": "sorver",
    "sorveria": "sorver",
    "sorveriam": "sorver",
    "sorverias": "sorver",
    "sorvermo": "sorver",
    "sorvermos": "sorver",
    "sorverá": "sorver",
    "sorverás": "sorver",
    "sorverão": "sorver",
    "sorveríamos": "sorver",
    "sorveríeis": "sorver",
    "sorves": "sorver",
    "sorvesse": "sorver",
    "sorvessem": "sorver",
    "sorvesses": "sorver",
    "sorveste": "sorver",
    "sorvestes": "sorver",
    "sorveteira": "sorveteiro",
    "sorveteiras": "sorveteiro",
    "sorveteiros": "sorveteiro",
    "sorvetes": "sorvete",
    "sorveu": "sorver",
    "sorvi": "sorver",
    "sorvia": "sorver",
    "sorviam": "sorver",
    "sorvias": "sorver",
    "sorvida": "sorvido",
    "sorvidas": "sorvido",
    "sorvido": "sorver",
    "sorvidos": "sorvido",
    "sorvo": "sorver",
    "sorvos": "sorvo",
    "sorvou": "sorvar",
    "sorvámo": "sorvar",
    "sorvámos": "sorvar",
    "sorváramo": "sorvar",
    "sorváramos": "sorvar",
    "sorváreis": "sorvar",
    "sorvásseis": "sorvar",
    "sorvássemos": "sorvar",
    "sorvávamo": "sorvar",
    "sorvávamos": "sorvar",
    "sorváveis": "sorvar",
    "sorvêramo": "sorver",
    "sorvêramos": "sorver",
    "sorvêreis": "sorver",
    "sorvêsseis": "sorver",
    "sorvêssemos": "sorver",
    "sorvíamo": "sorver",
    "sorvíamos": "sorver",
    "sorvíeis": "sorver",
    "sorá": "sorar",
    "sorámo": "sorar",
    "sorámos": "sorar",
    "soráramo": "sorar",
    "soráramos": "sorar",
    "sorárei": "sorar",
    "soráreis": "sorar",
    "sorásseis": "sorar",
    "sorássemos": "sorar",
    "sorávamo": "sorar",
    "sorávamos": "sorar",
    "sorávei": "sorar",
    "soráveis": "sorar",
    "sorças": "sorça",
    "sorédias": "sorédia",
    "sorítica": "sorítico",
    "soríticas": "sorítico",
    "soríticos": "sorítico",
    "soslaios": "soslaio",
    "sossa": "sosso",
    "sossas": "sosso",
    "sossega": "sossegar",
    "sossegada": "sossegar",
    "sossegadas": "sossegar",
    "sossegado": "sossegar",
    "sossegadora": "sossegador",
    "sossegadoras": "sossegador",
    "sossegadores": "sossegador",
    "sossegados": "sossegar",
    "sossegadíssima": "sossegado",
    "sossegadíssimas": "sossegado",
    "sossegadíssimo": "sossegado",
    "sossegadíssimos": "sossegado",
    "sossegai": "sossegar",
    "sossegais": "sossegar",
    "sossegam": "sossegar",
    "sossegamo": "sossegar",
    "sossegamos": "sossegar",
    "sossegando": "sossegar",
    "sossegara": "sossegar",
    "sossegaram": "sossegar",
    "sossegaras": "sossegar",
    "sossegarde": "sossegar",
    "sossegardes": "sossegar",
    "sossegare": "sossegar",
    "sossegarei": "sossegar",
    "sossegareis": "sossegar",
    "sossegarem": "sossegar",
    "sossegaremos": "sossegar",
    "sossegares": "sossegar",
    "sossegaria": "sossegar",
    "sossegariam": "sossegar",
    "sossegarias": "sossegar",
    "sossegarmo": "sossegar",
    "sossegarmos": "sossegar",
    "sossegará": "sossegar",
    "sossegarás": "sossegar",
    "sossegarão": "sossegar",
    "sossegaríamos": "sossegar",
    "sossegaríeis": "sossegar",
    "sossegas": "sossegar",
    "sossegasse": "sossegar",
    "sossegassem": "sossegar",
    "sossegasses": "sossegar",
    "sossegaste": "sossegar",
    "sossegastes": "sossegar",
    "sossegava": "sossegar",
    "sossegavam": "sossegar",
    "sossegavas": "sossegar",
    "sossego": "sossegar",
    "sossegos": "sossego",
    "sossegou": "sossegar",
    "sossegue": "sossegar",
    "sosseguei": "sossegar",
    "sossegueis": "sossegar",
    "sosseguem": "sossegar",
    "sosseguemo": "sossegar",
    "sosseguemos": "sossegar",
    "sossegues": "sossegar",
    "sossegá": "sossegar",
    "sossegámo": "sossegar",
    "sossegámos": "sossegar",
    "sossegáramo": "sossegar",
    "sossegáramos": "sossegar",
    "sossegárei": "sossegar",
    "sossegáreis": "sossegar",
    "sossegásseis": "sossegar",
    "sossegássemos": "sossegar",
    "sossegávamo": "sossegar",
    "sossegávamos": "sossegar",
    "sossegávei": "sossegar",
    "sossegáveis": "sossegar",
    "sossos": "sosso",
    "sostenidos": "sostenido",
    "sostras": "sostra",
    "sostrices": "sostrice",
    "sotainas": "sotaina",
    "sotanas": "sotana",
    "sotaqueada": "sotaquear",
    "sotaqueadas": "sotaquear",
    "sotaqueado": "sotaquear",
    "sotaqueados": "sotaquear",
    "sotaqueai": "sotaquear",
    "sotaqueais": "sotaquear",
    "sotaqueamo": "sotaquear",
    "sotaqueamos": "sotaquear",
    "sotaqueando": "sotaquear",
    "sotaqueara": "sotaquear",
    "sotaquearam": "sotaquear",
    "sotaquearas": "sotaquear",
    "sotaquearde": "sotaquear",
    "sotaqueardes": "sotaquear",
    "sotaqueare": "sotaquear",
    "sotaquearei": "sotaquear",
    "sotaqueareis": "sotaquear",
    "sotaquearem": "sotaquear",
    "sotaquearemos": "sotaquear",
    "sotaqueares": "sotaquear",
    "sotaquearia": "sotaquear",
    "sotaqueariam": "sotaquear",
    "sotaquearias": "sotaquear",
    "sotaquearmo": "sotaquear",
    "sotaquearmos": "sotaquear",
    "sotaqueará": "sotaquear",
    "sotaquearás": "sotaquear",
    "sotaquearão": "sotaquear",
    "sotaquearíamos": "sotaquear",
    "sotaquearíeis": "sotaquear",
    "sotaqueasse": "sotaquear",
    "sotaqueassem": "sotaquear",
    "sotaqueasses": "sotaquear",
    "sotaqueaste": "sotaquear",
    "sotaqueastes": "sotaquear",
    "sotaqueava": "sotaquear",
    "sotaqueavam": "sotaquear",
    "sotaqueavas": "sotaquear",
    "sotaqueei": "sotaquear",
    "sotaqueeis": "sotaquear",
    "sotaqueemo": "sotaquear",
    "sotaqueemos": "sotaquear",
    "sotaqueia": "sotaquear",
    "sotaqueiam": "sotaquear",
    "sotaqueias": "sotaquear",
    "sotaqueie": "sotaquear",
    "sotaqueiem": "sotaquear",
    "sotaqueies": "sotaquear",
    "sotaqueio": "sotaquear",
    "sotaqueou": "sotaquear",
    "sotaques": "sotaque",
    "sotaqueá": "sotaquear",
    "sotaqueámo": "sotaquear",
    "sotaqueámos": "sotaquear",
    "sotaqueáramo": "sotaquear",
    "sotaqueáramos": "sotaquear",
    "sotaqueárei": "sotaquear",
    "sotaqueáreis": "sotaquear",
    "sotaqueásseis": "sotaquear",
    "sotaqueássemos": "sotaquear",
    "sotaqueávamo": "sotaquear",
    "sotaqueávamos": "sotaquear",
    "sotaqueávei": "sotaquear",
    "sotaqueáveis": "sotaquear",
    "sotas": "sota",
    "sotaventeada": "sotaventear",
    "sotaventeadas": "sotaventear",
    "sotaventeado": "sotaventear",
    "sotaventeados": "sotaventear",
    "sotaventeai": "sotaventear",
    "sotaventeais": "sotaventear",
    "sotaventeamo": "sotaventear",
    "sotaventeamos": "sotaventear",
    "sotaventeando": "sotaventear",
    "sotaventeara": "sotaventear",
    "sotaventearam": "sotaventear",
    "sotaventearas": "sotaventear",
    "sotaventearde": "sotaventear",
    "sotaventeardes": "sotaventear",
    "sotaventeare": "sotaventear",
    "sotaventearei": "sotaventear",
    "sotaventeareis": "sotaventear",
    "sotaventearem": "sotaventear",
    "sotaventearemos": "sotaventear",
    "sotaventeares": "sotaventear",
    "sotaventearia": "sotaventear",
    "sotaventeariam": "sotaventear",
    "sotaventearias": "sotaventear",
    "sotaventearmo": "sotaventear",
    "sotaventearmos": "sotaventear",
    "sotaventeará": "sotaventear",
    "sotaventearás": "sotaventear",
    "sotaventearão": "sotaventear",
    "sotaventearíamos": "sotaventear",
    "sotaventearíeis": "sotaventear",
    "sotaventeasse": "sotaventear",
    "sotaventeassem": "sotaventear",
    "sotaventeasses": "sotaventear",
    "sotaventeaste": "sotaventear",
    "sotaventeastes": "sotaventear",
    "sotaventeava": "sotaventear",
    "sotaventeavam": "sotaventear",
    "sotaventeavas": "sotaventear",
    "sotaventeei": "sotaventear",
    "sotaventeeis": "sotaventear",
    "sotaventeemo": "sotaventear",
    "sotaventeemos": "sotaventear",
    "sotaventeia": "sotaventear",
    "sotaventeiam": "sotaventear",
    "sotaventeias": "sotaventear",
    "sotaventeie": "sotaventear",
    "sotaventeiem": "sotaventear",
    "sotaventeies": "sotaventear",
    "sotaventeio": "sotaventear",
    "sotaventeou": "sotaventear",
    "sotaventeá": "sotaventear",
    "sotaventeámo": "sotaventear",
    "sotaventeámos": "sotaventear",
    "sotaventeáramo": "sotaventear",
    "sotaventeáramos": "sotaventear",
    "sotaventeárei": "sotaventear",
    "sotaventeáreis": "sotaventear",
    "sotaventeásseis": "sotaventear",
    "sotaventeássemos": "sotaventear",
    "sotaventeávamo": "sotaventear",
    "sotaventeávamos": "sotaventear",
    "sotaventeávei": "sotaventear",
    "sotaventeáveis": "sotaventear",
    "sotaventina": "sotaventino",
    "sotaventinas": "sotaventino",
    "sotaventinos": "sotaventino",
    "sotaventos": "sotavento",
    "soteias": "soteia",
    "soteriologias": "soteriologia",
    "soteropolitana": "soteropolitano",
    "soteropolitanas": "soteropolitano",
    "soteropolitanos": "soteropolitano",
    "soterra": "soterrar",
    "soterrada": "soterrar",
    "soterradas": "soterrar",
    "soterrado": "soterrar",
    "soterrados": "soterrar",
    "soterrai": "soterrar",
    "soterrais": "soterrar",
    "soterram": "soterrar",
    "soterramentos": "soterramento",
    "soterramo": "soterrar",
    "soterramos": "soterrar",
    "soterrando": "soterrar",
    "soterrara": "soterrar",
    "soterraram": "soterrar",
    "soterraras": "soterrar",
    "soterrarde": "soterrar",
    "soterrardes": "soterrar",
    "soterrare": "soterrar",
    "soterrarei": "soterrar",
    "soterrareis": "soterrar",
    "soterrarem": "soterrar",
    "soterraremos": "soterrar",
    "soterrares": "soterrar",
    "soterraria": "soterrar",
    "soterrariam": "soterrar",
    "soterrarias": "soterrar",
    "soterrarmo": "soterrar",
    "soterrarmos": "soterrar",
    "soterrará": "soterrar",
    "soterrarás": "soterrar",
    "soterrarão": "soterrar",
    "soterraríamos": "soterrar",
    "soterraríeis": "soterrar",
    "soterras": "soterrar",
    "soterrasse": "soterrar",
    "soterrassem": "soterrar",
    "soterrasses": "soterrar",
    "soterraste": "soterrar",
    "soterrastes": "soterrar",
    "soterrava": "soterrar",
    "soterravam": "soterrar",
    "soterravas": "soterrar",
    "soterrações": "soterração",
    "soterre": "soterrar",
    "soterrei": "soterrar",
    "soterreis": "soterrar",
    "soterrem": "soterrar",
    "soterremo": "soterrar",
    "soterremos": "soterrar",
    "soterres": "soterrar",
    "soterro": "soterrar",
    "soterrou": "soterrar",
    "soterrá": "soterrar",
    "soterrámo": "soterrar",
    "soterrámos": "soterrar",
    "soterráramo": "soterrar",
    "soterráramos": "soterrar",
    "soterrárei": "soterrar",
    "soterráreis": "soterrar",
    "soterrásseis": "soterrar",
    "soterrássemos": "soterrar",
    "soterrávamo": "soterrar",
    "soterrávamos": "soterrar",
    "soterrávei": "soterrar",
    "soterráveis": "soterrar",
    "soterrânea": "soterrâneo",
    "soterrâneas": "soterrâneo",
    "soterrâneos": "soterrâneo",
    "sotias": "sotia",
    "sotopomo": "sotopor",
    "sotopomos": "sotopor",
    "sotoponde": "sotopor",
    "sotopondes": "sotopor",
    "sotopondo": "sotopor",
    "sotoponha": "sotopor",
    "sotoponhais": "sotopor",
    "sotoponham": "sotopor",
    "sotoponhamo": "sotopor",
    "sotoponhamos": "sotopor",
    "sotoponhas": "sotopor",
    "sotoponho": "sotopor",
    "sotoporde": "sotopor",
    "sotopordes": "sotopor",
    "sotopore": "sotopor",
    "sotoporei": "sotopor",
    "sotoporeis": "sotopor",
    "sotoporem": "sotopor",
    "sotoporemos": "sotopor",
    "sotopores": "sotopor",
    "sotoporia": "sotopor",
    "sotoporiam": "sotopor",
    "sotoporias": "sotopor",
    "sotopormo": "sotopor",
    "sotopormos": "sotopor",
    "sotoporá": "sotopor",
    "sotoporás": "sotopor",
    "sotoporão": "sotopor",
    "sotoporíamos": "sotopor",
    "sotoporíeis": "sotopor",
    "sotoposta": "sotopor",
    "sotopostas": "sotopor",
    "sotoposto": "sotopor",
    "sotopostos": "sotopor",
    "sotopunha": "sotopor",
    "sotopunham": "sotopor",
    "sotopunhas": "sotopor",
    "sotopus": "sotopor",
    "sotopusemo": "sotopor",
    "sotopusemos": "sotopor",
    "sotopuser": "sotopor",
    "sotopusera": "sotopor",
    "sotopuseram": "sotopor",
    "sotopuseras": "sotopor",
    "sotopuserdes": "sotopor",
    "sotopuserem": "sotopor",
    "sotopuseres": "sotopor",
    "sotopusermos": "sotopor",
    "sotopusesse": "sotopor",
    "sotopusessem": "sotopor",
    "sotopusesses": "sotopor",
    "sotopuseste": "sotopor",
    "sotopusestes": "sotopor",
    "sotopuséramo": "sotopor",
    "sotopuséramos": "sotopor",
    "sotopusérei": "sotopor",
    "sotopuséreis": "sotopor",
    "sotopusésseis": "sotopor",
    "sotopuséssemos": "sotopor",
    "sotopô": "sotopor",
    "sotopôs": "sotopor",
    "sotopõe": "sotopor",
    "sotopõem": "sotopor",
    "sotopões": "sotopor",
    "sotopúnhamo": "sotopor",
    "sotopúnhamos": "sotopor",
    "sotopúnhei": "sotopor",
    "sotopúnheis": "sotopor",
    "sotranca": "sotrancar",
    "sotrancada": "sotrancar",
    "sotrancadas": "sotrancar",
    "sotrancado": "sotrancar",
    "sotrancados": "sotrancar",
    "sotrancai": "sotrancar",
    "sotrancais": "sotrancar",
    "sotrancam": "sotrancar",
    "sotrancamo": "sotrancar",
    "sotrancamos": "sotrancar",
    "sotrancando": "sotrancar",
    "sotrancara": "sotrancar",
    "sotrancaram": "sotrancar",
    "sotrancaras": "sotrancar",
    "sotrancarde": "sotrancar",
    "sotrancardes": "sotrancar",
    "sotrancare": "sotrancar",
    "sotrancarei": "sotrancar",
    "sotrancareis": "sotrancar",
    "sotrancarem": "sotrancar",
    "sotrancaremos": "sotrancar",
    "sotrancares": "sotrancar",
    "sotrancaria": "sotrancar",
    "sotrancariam": "sotrancar",
    "sotrancarias": "sotrancar",
    "sotrancarmo": "sotrancar",
    "sotrancarmos": "sotrancar",
    "sotrancará": "sotrancar",
    "sotrancarás": "sotrancar",
    "sotrancarão": "sotrancar",
    "sotrancaríamos": "sotrancar",
    "sotrancaríeis": "sotrancar",
    "sotrancas": "sotrancar",
    "sotrancasse": "sotrancar",
    "sotrancassem": "sotrancar",
    "sotrancasses": "sotrancar",
    "sotrancaste": "sotrancar",
    "sotrancastes": "sotrancar",
    "sotrancava": "sotrancar",
    "sotrancavam": "sotrancar",
    "sotrancavas": "sotrancar",
    "sotranco": "sotrancar",
    "sotrancona": "sotrancão",
    "sotranconas": "sotrancão",
    "sotrancou": "sotrancar",
    "sotrancá": "sotrancar",
    "sotrancámo": "sotrancar",
    "sotrancámos": "sotrancar",
    "sotrancáramo": "sotrancar",
    "sotrancáramos": "sotrancar",
    "sotrancárei": "sotrancar",
    "sotrancáreis": "sotrancar",
    "sotrancásseis": "sotrancar",
    "sotrancássemos": "sotrancar",
    "sotrancávamo": "sotrancar",
    "sotrancávamos": "sotrancar",
    "sotrancávei": "sotrancar",
    "sotrancáveis": "sotrancar",
    "sotrancões": "sotrancão",
    "sotranque": "sotrancar",
    "sotranquei": "sotrancar",
    "sotranqueis": "sotrancar",
    "sotranquem": "sotrancar",
    "sotranquemo": "sotrancar",
    "sotranquemos": "sotrancar",
    "sotranques": "sotrancar",
    "soturna": "soturno",
    "soturnas": "soturno",
    "soturnidades": "soturnidade",
    "soturnos": "soturno",
    "sou": "ser",
    "soube": "saber",
    "soubemo": "saber",
    "soubemos": "saber",
    "souber": "saber",
    "soubera": "saber",
    "souberam": "saber",
    "souberas": "saber",
    "souberdes": "saber",
    "souberem": "saber",
    "souberes": "saber",
    "soubermos": "saber",
    "soubesse": "saber",
    "soubessem": "saber",
    "soubesses": "saber",
    "soubeste": "saber",
    "soubestes": "saber",
    "soubéramo": "saber",
    "soubéramos": "saber",
    "soubérei": "saber",
    "soubéreis": "saber",
    "soubésseis": "saber",
    "soubéssemos": "saber",
    "soufflés": "soufflé",
    "sousões": "sousão",
    "soutiens": "soutien",
    "soutos": "souto",
    "souvenires": "souvenir",
    "sova": "sovar",
    "sovacos": "sovaco",
    "sovada": "sovar",
    "sovadas": "sovar",
    "sovadelas": "sovadela",
    "sovado": "sovar",
    "sovados": "sovar",
    "sovaduras": "sovadura",
    "sovadíssima": "sovado",
    "sovadíssimas": "sovado",
    "sovadíssimo": "sovado",
    "sovadíssimos": "sovado",
    "sovai": "sovar",
    "sovais": "sovar",
    "sovam": "sovar",
    "sovamo": "sovar",
    "sovamos": "sovar",
    "sovando": "sovar",
    "sovaqueira": "sovaqueiro",
    "sovaqueiras": "sovaqueiro",
    "sovaqueiros": "sovaqueiro",
    "sovaquetes": "sovaquete",
    "sovaquinho": "sovaco",
    "sovaquinhos": "sovaco",
    "sovaquito": "sovaco",
    "sovaquitos": "sovaco",
    "sovara": "sovar",
    "sovaram": "sovar",
    "sovaras": "sovar",
    "sovarde": "sovar",
    "sovardes": "sovar",
    "sovare": "sovar",
    "sovarei": "sovar",
    "sovareis": "sovar",
    "sovarem": "sovar",
    "sovaremos": "sovar",
    "sovares": "sovar",
    "sovaria": "sovar",
    "sovariam": "sovar",
    "sovarias": "sovar",
    "sovarmo": "sovar",
    "sovarmos": "sovar",
    "sovará": "sovar",
    "sovarás": "sovar",
    "sovarão": "sovar",
    "sovaríamos": "sovar",
    "sovaríeis": "sovar",
    "sovas": "sovar",
    "sovasse": "sovar",
    "sovassem": "sovar",
    "sovasses": "sovar",
    "sovaste": "sovar",
    "sovastes": "sovar",
    "sovava": "sovar",
    "sovavam": "sovar",
    "sovavas": "sovar",
    "sove": "sovar",
    "sovei": "sovar",
    "soveios": "soveio",
    "soveiros": "soveiro",
    "soveis": "sovar",
    "sovela": "sovelar",
    "sovelada": "sovelar",
    "soveladas": "sovelar",
    "sovelado": "sovelar",
    "sovelados": "sovelar",
    "sovelai": "sovelar",
    "sovelais": "sovelar",
    "sovelam": "sovelar",
    "sovelamo": "sovelar",
    "sovelamos": "sovelar",
    "sovelando": "sovelar",
    "sovelara": "sovelar",
    "sovelaram": "sovelar",
    "sovelaras": "sovelar",
    "sovelarde": "sovelar",
    "sovelardes": "sovelar",
    "sovelare": "sovelar",
    "sovelarei": "sovelar",
    "sovelareis": "sovelar",
    "sovelarem": "sovelar",
    "sovelaremos": "sovelar",
    "sovelares": "sovelar",
    "sovelaria": "sovelar",
    "sovelariam": "sovelar",
    "sovelarias": "sovelar",
    "sovelarmo": "sovelar",
    "sovelarmos": "sovelar",
    "sovelará": "sovelar",
    "sovelarás": "sovelar",
    "sovelarão": "sovelar",
    "sovelaríamos": "sovelar",
    "sovelaríeis": "sovelar",
    "sovelas": "sovelar",
    "sovelasse": "sovelar",
    "sovelassem": "sovelar",
    "sovelasses": "sovelar",
    "sovelaste": "sovelar",
    "sovelastes": "sovelar",
    "sovelava": "sovelar",
    "sovelavam": "sovelar",
    "sovelavas": "sovelar",
    "sovele": "sovelar",
    "sovelei": "sovelar",
    "soveleira": "soveleiro",
    "soveleiras": "soveleiro",
    "soveleiros": "soveleiro",
    "soveleis": "sovelar",
    "sovelem": "sovelar",
    "sovelemo": "sovelar",
    "sovelemos": "sovelar",
    "soveles": "sovelar",
    "sovelo": "sovelar",
    "sovelou": "sovelar",
    "sovelá": "sovelar",
    "sovelámo": "sovelar",
    "sovelámos": "sovelar",
    "soveláramo": "sovelar",
    "soveláramos": "sovelar",
    "sovelárei": "sovelar",
    "soveláreis": "sovelar",
    "sovelásseis": "sovelar",
    "sovelássemos": "sovelar",
    "sovelávamo": "sovelar",
    "sovelávamos": "sovelar",
    "sovelávei": "sovelar",
    "soveláveis": "sovelar",
    "sovelões": "sovelão",
    "sovem": "sovar",
    "sovemo": "sovar",
    "sovemos": "sovar",
    "soventres": "soventre",
    "soverais": "soveral",
    "sovereiros": "sovereiro",
    "soverta": "soverter",
    "sovertais": "soverter",
    "sovertam": "soverter",
    "sovertamo": "soverter",
    "sovertamos": "soverter",
    "sovertas": "soverter",
    "soverte": "soverter",
    "sovertei": "soverter",
    "soverteis": "soverter",
    "sovertem": "soverter",
    "sovertemo": "soverter",
    "sovertemos": "soverter",
    "sovertendo": "soverter",
    "sovertera": "soverter",
    "soverteram": "soverter",
    "soverteras": "soverter",
    "soverterdes": "soverter",
    "soverterei": "soverter",
    "sovertereis": "soverter",
    "soverterem": "soverter",
    "soverteremos": "soverter",
    "soverteres": "soverter",
    "soverteria": "soverter",
    "soverteriam": "soverter",
    "soverterias": "soverter",
    "sovertermo": "soverter",
    "sovertermos": "soverter",
    "soverterá": "soverter",
    "soverterás": "soverter",
    "soverterão": "soverter",
    "soverteríamos": "soverter",
    "soverteríeis": "soverter",
    "sovertes": "soverter",
    "sovertesse": "soverter",
    "sovertessem": "soverter",
    "sovertesses": "soverter",
    "soverteste": "soverter",
    "sovertestes": "soverter",
    "soverteu": "soverter",
    "soverti": "soverter",
    "sovertia": "soverter",
    "sovertiam": "soverter",
    "sovertias": "soverter",
    "sovertida": "soverter",
    "sovertidas": "soverter",
    "sovertido": "soverter",
    "sovertidos": "soverter",
    "soverto": "soverter",
    "sovertêramo": "soverter",
    "sovertêramos": "soverter",
    "sovertêreis": "soverter",
    "sovertêsseis": "soverter",
    "sovertêssemos": "soverter",
    "sovertíamo": "soverter",
    "sovertíamos": "soverter",
    "sovertíeis": "soverter",
    "soves": "sovar",
    "soveus": "soveu",
    "sovietes": "soviete",
    "sovietismos": "sovietismo",
    "sovietistas": "sovietista",
    "sovietizações": "sovietização",
    "sovina": "sovinar",
    "sovinada": "sovinar",
    "sovinadas": "sovinar",
    "sovinado": "sovinar",
    "sovinados": "sovinar",
    "sovinai": "sovinar",
    "sovinais": "sovinar",
    "sovinam": "sovinar",
    "sovinamo": "sovinar",
    "sovinamos": "sovinar",
    "sovinando": "sovinar",
    "sovinara": "sovinar",
    "sovinaram": "sovinar",
    "sovinaras": "sovinar",
    "sovinarde": "sovinar",
    "sovinardes": "sovinar",
    "sovinare": "sovinar",
    "sovinarei": "sovinar",
    "sovinareis": "sovinar",
    "sovinarem": "sovinar",
    "sovinaremos": "sovinar",
    "sovinares": "sovinar",
    "sovinaria": "sovinar",
    "sovinariam": "sovinar",
    "sovinarias": "sovinaria",
    "sovinarmo": "sovinar",
    "sovinarmos": "sovinar",
    "sovinará": "sovinar",
    "sovinarás": "sovinar",
    "sovinarão": "sovinar",
    "sovinaríamos": "sovinar",
    "sovinaríeis": "sovinar",
    "sovinas": "sovinar",
    "sovinasse": "sovinar",
    "sovinassem": "sovinar",
    "sovinasses": "sovinar",
    "sovinaste": "sovinar",
    "sovinastes": "sovinar",
    "sovinava": "sovinar",
    "sovinavam": "sovinar",
    "sovinavas": "sovinar",
    "sovinazinha": "sovina",
    "sovinazinhas": "sovina",
    "sovinazinho": "sovina",
    "sovinazinhos": "sovina",
    "sovinazita": "sovina",
    "sovinazitas": "sovina",
    "sovinazito": "sovina",
    "sovinazitos": "sovina",
    "sovine": "sovinar",
    "sovinei": "sovinar",
    "sovineis": "sovinar",
    "sovinem": "sovinar",
    "sovinemo": "sovinar",
    "sovinemos": "sovinar",
    "sovines": "sovinar",
    "sovinices": "sovinice",
    "sovino": "sovinar",
    "sovinou": "sovinar",
    "soviná": "sovinar",
    "sovinámo": "sovinar",
    "sovinámos": "sovinar",
    "sovináramo": "sovinar",
    "sovináramos": "sovinar",
    "sovinárei": "sovinar",
    "sovináreis": "sovinar",
    "sovinásseis": "sovinar",
    "sovinássemos": "sovinar",
    "sovinávamo": "sovinar",
    "sovinávamos": "sovinar",
    "sovinávei": "sovinar",
    "sovináveis": "sovinar",
    "soviética": "soviético",
    "soviéticas": "soviético",
    "soviéticos": "soviético",
    "sovo": "sovar",
    "sovou": "sovar",
    "sovros": "sovro",
    "sová": "sovar",
    "sovámo": "sovar",
    "sovámos": "sovar",
    "sováramo": "sovar",
    "sováramos": "sovar",
    "sovárei": "sovar",
    "sováreis": "sovar",
    "sovásseis": "sovar",
    "sovássemos": "sovar",
    "sovávamo": "sovar",
    "sovávamos": "sovar",
    "sovávei": "sovar",
    "sováveis": "sovar",
    "sozinha": "só",
    "sozinhas": "só",
    "sozinho": "só",
    "sozinhos": "só",
    "sozita": "só",
    "sozitas": "só",
    "sozito": "só",
    "sozitos": "só",
    "soámo": "soar",
    "soámos": "soar",
    "soáramo": "soar",
    "soáramos": "soar",
    "soáreis": "soar",
    "soásseis": "soar",
    "soássemos": "soar",
    "soávamo": "soar",
    "soávamos": "soar",
    "soáveis": "soar",
    "soçobra": "soçobrar",
    "soçobrada": "soçobrar",
    "soçobradas": "soçobrar",
    "soçobrado": "soçobrar",
    "soçobrados": "soçobrar",
    "soçobrai": "soçobrar",
    "soçobrais": "soçobrar",
    "soçobram": "soçobrar",
    "soçobramo": "soçobrar",
    "soçobramos": "soçobrar",
    "soçobrando": "soçobrar",
    "soçobrar": "obrar",
    "soçobrara": "soçobrar",
    "soçobraram": "soçobrar",
    "soçobraras": "soçobrar",
    "soçobrarde": "soçobrar",
    "soçobrardes": "soçobrar",
    "soçobrare": "soçobrar",
    "soçobrarei": "soçobrar",
    "soçobrareis": "soçobrar",
    "soçobrarem": "soçobrar",
    "soçobraremos": "soçobrar",
    "soçobrares": "soçobrar",
    "soçobraria": "soçobrar",
    "soçobrariam": "soçobrar",
    "soçobrarias": "soçobrar",
    "soçobrarmo": "soçobrar",
    "soçobrarmos": "soçobrar",
    "soçobrará": "soçobrar",
    "soçobrarás": "soçobrar",
    "soçobrarão": "soçobrar",
    "soçobraríamos": "soçobrar",
    "soçobraríeis": "soçobrar",
    "soçobras": "soçobrar",
    "soçobrasse": "soçobrar",
    "soçobrassem": "soçobrar",
    "soçobrasses": "soçobrar",
    "soçobraste": "soçobrar",
    "soçobrastes": "soçobrar",
    "soçobrava": "soçobrar",
    "soçobravam": "soçobrar",
    "soçobravas": "soçobrar",
    "soçobre": "soçobrar",
    "soçobrei": "soçobrar",
    "soçobreis": "soçobrar",
    "soçobrem": "soçobrar",
    "soçobremo": "soçobrar",
    "soçobremos": "soçobrar",
    "soçobres": "soçobrar",
    "soçobro": "soçobrar",
    "soçobros": "soçobro",
    "soçobrou": "soçobrar",
    "soçobrá": "soçobrar",
    "soçobrámo": "soçobrar",
    "soçobrámos": "soçobrar",
    "soçobráramo": "soçobrar",
    "soçobráramos": "soçobrar",
    "soçobrárei": "soçobrar",
    "soçobráreis": "soçobrar",
    "soçobrásseis": "soçobrar",
    "soçobrássemos": "soçobrar",
    "soçobrávamo": "soçobrar",
    "soçobrávamos": "soçobrar",
    "soçobrávei": "soçobrar",
    "soçobráveis": "soçobrar",
    "soêramo": "soer",
    "soêramos": "soer",
    "soêreis": "soer",
    "soêsseis": "soer",
    "soêssemos": "soer",
    "soí": "soer",
    "soía": "soer",
    "soíam": "soer",
    "soíamo": "soer",
    "soíamos": "soer",
    "soías": "soer",
    "soída": "soer",
    "soídas": "soer",
    "soído": "soer",
    "soídos": "soído",
    "soíeis": "soer",
    "soões": "soão",
    "spaghettis": "spaghetti",
    "spinozismos": "spinozismo",
    "spinozistas": "spinozista",
    "spins": "spin",
    "sportinguismos": "sportinguismo",
    "sportinguistas": "sportinguista",
    "spots": "spot",
    "sprays": "spray",
    "sprinters": "sprinter",
    "sprints": "sprint",
    "sra": "sr",
    "sras": "sr",
    "srs": "sr",
    "ss": "s",
    "staffs": "staff",
    "stalinismos": "stalinismo",
    "stalinistas": "stalinista",
    "standards": "standard",
    "standes": "stand",
    "stanozonóis": "stanozonol",
    "stars": "star",
    "stats": "stat",
    "sticks": "stick",
    "stilbs": "stilb",
    "stills": "still",
    "stocks": "stock",
    "stopes": "stop",
    "stressa": "stressar",
    "stressada": "stressar",
    "stressadas": "stressar",
    "stressado": "stressar",
    "stressados": "stressar",
    "stressai": "stressar",
    "stressais": "stressar",
    "stressam": "stressar",
    "stressamo": "stressar",
    "stressamos": "stressar",
    "stressando": "stressar",
    "stressantes": "stressante",
    "stressara": "stressar",
    "stressaram": "stressar",
    "stressaras": "stressar",
    "stressarde": "stressar",
    "stressardes": "stressar",
    "stressare": "stressar",
    "stressarei": "stressar",
    "stressareis": "stressar",
    "stressarem": "stressar",
    "stressaremos": "stressar",
    "stressares": "stressar",
    "stressaria": "stressar",
    "stressariam": "stressar",
    "stressarias": "stressar",
    "stressarmo": "stressar",
    "stressarmos": "stressar",
    "stressará": "stressar",
    "stressarás": "stressar",
    "stressarão": "stressar",
    "stressaríamos": "stressar",
    "stressaríeis": "stressar",
    "stressas": "stressar",
    "stressasse": "stressar",
    "stressassem": "stressar",
    "stressasses": "stressar",
    "stressaste": "stressar",
    "stressastes": "stressar",
    "stressava": "stressar",
    "stressavam": "stressar",
    "stressavas": "stressar",
    "stresse": "stressar",
    "stressei": "stressar",
    "stresseis": "stressar",
    "stressem": "stressar",
    "stressemo": "stressar",
    "stressemos": "stressar",
    "stresses": "stressar",
    "stresso": "stressar",
    "stressou": "stressar",
    "stressá": "stressar",
    "stressámo": "stressar",
    "stressámos": "stressar",
    "stressáramo": "stressar",
    "stressáramos": "stressar",
    "stressárei": "stressar",
    "stressáreis": "stressar",
    "stressásseis": "stressar",
    "stressássemos": "stressar",
    "stressávamo": "stressar",
    "stressávamos": "stressar",
    "stressávei": "stressar",
    "stressáveis": "stressar",
    "studs": "stud",
    "sua": "suar",
    "suada": "suar",
    "suadas": "suar",
    "suadeiras": "suadeira",
    "suadelas": "suadela",
    "suado": "suar",
    "suadoiros": "suadoiro",
    "suadora": "suador",
    "suadoras": "suador",
    "suadorazinha": "suador",
    "suadorazinhas": "suador",
    "suadorazita": "suador",
    "suadorazitas": "suador",
    "suadores": "suador",
    "suadorzinho": "suador",
    "suadorzinhos": "suador",
    "suadorzito": "suador",
    "suadorzitos": "suador",
    "suados": "suar",
    "suadouros": "suadouro",
    "suadíssima": "suado",
    "suadíssimas": "suado",
    "suadíssimo": "suado",
    "suadíssimos": "suado",
    "suai": "suar",
    "suais": "suar",
    "suajos": "suajo",
    "suam": "suar",
    "suamo": "suar",
    "suamos": "suar",
    "suando": "suar",
    "suara": "suar",
    "suaram": "suar",
    "suaras": "suar",
    "suardas": "suarda",
    "suardes": "suar",
    "suarei": "suar",
    "suareis": "suar",
    "suarem": "suar",
    "suaremos": "suar",
    "suarenta": "suarento",
    "suarentas": "suarento",
    "suarentos": "suarento",
    "suares": "suar",
    "suaria": "suar",
    "suariam": "suar",
    "suarias": "suar",
    "suarmo": "suar",
    "suarmos": "suar",
    "suará": "suar",
    "suarás": "suar",
    "suarão": "suar",
    "suaríamos": "suar",
    "suaríeis": "suar",
    "suas": "suar",
    "suasiva": "suasivo",
    "suasivas": "suasivo",
    "suasivos": "suasivo",
    "suasse": "suar",
    "suassem": "suar",
    "suasses": "suar",
    "suaste": "suar",
    "suastes": "suar",
    "suasória": "suasório",
    "suasórias": "suasório",
    "suasórios": "suasório",
    "suava": "suar",
    "suavam": "suar",
    "suavas": "suar",
    "suaves": "suave",
    "suavezinha": "suave",
    "suavezinhas": "suave",
    "suavezinho": "suave",
    "suavezinhos": "suave",
    "suavezita": "suave",
    "suavezitas": "suave",
    "suavezito": "suave",
    "suavezitos": "suave",
    "suavidades": "suavidade",
    "suaviloquências": "suaviloquência",
    "suaviza": "suavizar",
    "suavizada": "suavizar",
    "suavizadas": "suavizar",
    "suavizado": "suavizar",
    "suavizados": "suavizar",
    "suavizai": "suavizar",
    "suavizais": "suavizar",
    "suavizam": "suavizar",
    "suavizamo": "suavizar",
    "suavizamos": "suavizar",
    "suavizando": "suavizar",
    "suavizara": "suavizar",
    "suavizaram": "suavizar",
    "suavizaras": "suavizar",
    "suavizarde": "suavizar",
    "suavizardes": "suavizar",
    "suavizare": "suavizar",
    "suavizarei": "suavizar",
    "suavizareis": "suavizar",
    "suavizarem": "suavizar",
    "suavizaremos": "suavizar",
    "suavizares": "suavizar",
    "suavizaria": "suavizar",
    "suavizariam": "suavizar",
    "suavizarias": "suavizar",
    "suavizarmo": "suavizar",
    "suavizarmos": "suavizar",
    "suavizará": "suavizar",
    "suavizarás": "suavizar",
    "suavizarão": "suavizar",
    "suavizaríamos": "suavizar",
    "suavizaríeis": "suavizar",
    "suavizas": "suavizar",
    "suavizasse": "suavizar",
    "suavizassem": "suavizar",
    "suavizasses": "suavizar",
    "suavizaste": "suavizar",
    "suavizastes": "suavizar",
    "suavizava": "suavizar",
    "suavizavam": "suavizar",
    "suavizavas": "suavizar",
    "suavizações": "suavização",
    "suavize": "suavizar",
    "suavizei": "suavizar",
    "suavizeis": "suavizar",
    "suavizem": "suavizar",
    "suavizemo": "suavizar",
    "suavizemos": "suavizar",
    "suavizes": "suavizar",
    "suavizo": "suavizar",
    "suavizou": "suavizar",
    "suavizá": "suavizar",
    "suavizámo": "suavizar",
    "suavizámos": "suavizar",
    "suavizáramo": "suavizar",
    "suavizáramos": "suavizar",
    "suavizárei": "suavizar",
    "suavizáreis": "suavizar",
    "suavizásseis": "suavizar",
    "suavizássemos": "suavizar",
    "suavizávamo": "suavizar",
    "suavizávamos": "suavizar",
    "suavizávei": "suavizar",
    "suavizáveis": "suavizar",
    "suavíssima": "suave",
    "suavíssimas": "suave",
    "suavíssimo": "suave",
    "suavíssimos": "suave",
    "suazis": "suazi",
    "suaçus": "suaçu",
    "suaíles": "suaíle",
    "suba": "subir",
    "subabdominais": "subabdominal",
    "subadjacentes": "subadjacente",
    "subafluentes": "subafluente",
    "subagentes": "subagente",
    "subagências": "subagência",
    "subais": "subir",
    "subalada": "subalado",
    "subaladas": "subalado",
    "subalados": "subalado",
    "subalares": "subalar",
    "subalimenta": "subalimentar",
    "subalimentada": "subalimentar",
    "subalimentadas": "subalimentar",
    "subalimentado": "subalimentar",
    "subalimentados": "subalimentar",
    "subalimentai": "subalimentar",
    "subalimentais": "subalimentar",
    "subalimentam": "subalimentar",
    "subalimentamo": "subalimentar",
    "subalimentamos": "subalimentar",
    "subalimentando": "subalimentar",
    "subalimentara": "subalimentar",
    "subalimentaram": "subalimentar",
    "subalimentaras": "subalimentar",
    "subalimentarde": "subalimentar",
    "subalimentardes": "subalimentar",
    "subalimentare": "subalimentar",
    "subalimentarei": "subalimentar",
    "subalimentareis": "subalimentar",
    "subalimentarem": "subalimentar",
    "subalimentaremos": "subalimentar",
    "subalimentares": "subalimentar",
    "subalimentaria": "subalimentar",
    "subalimentariam": "subalimentar",
    "subalimentarias": "subalimentar",
    "subalimentarmo": "subalimentar",
    "subalimentarmos": "subalimentar",
    "subalimentará": "subalimentar",
    "subalimentarás": "subalimentar",
    "subalimentarão": "subalimentar",
    "subalimentaríamos": "subalimentar",
    "subalimentaríeis": "subalimentar",
    "subalimentas": "subalimentar",
    "subalimentasse": "subalimentar",
    "subalimentassem": "subalimentar",
    "subalimentasses": "subalimentar",
    "subalimentaste": "subalimentar",
    "subalimentastes": "subalimentar",
    "subalimentava": "subalimentar",
    "subalimentavam": "subalimentar",
    "subalimentavas": "subalimentar",
    "subalimentações": "subalimentação",
    "subalimente": "subalimentar",
    "subalimentei": "subalimentar",
    "subalimenteis": "subalimentar",
    "subalimentem": "subalimentar",
    "subalimentemo": "subalimentar",
    "subalimentemos": "subalimentar",
    "subalimentes": "subalimentar",
    "subalimento": "subalimentar",
    "subalimentou": "subalimentar",
    "subalimentá": "subalimentar",
    "subalimentámo": "subalimentar",
    "subalimentámos": "subalimentar",
    "subalimentáramo": "subalimentar",
    "subalimentáramos": "subalimentar",
    "subalimentárei": "subalimentar",
    "subalimentáreis": "subalimentar",
    "subalimentásseis": "subalimentar",
    "subalimentássemos": "subalimentar",
    "subalimentávamo": "subalimentar",
    "subalimentávamos": "subalimentar",
    "subalimentávei": "subalimentar",
    "subalimentáveis": "subalimentar",
    "subalpina": "subalpino",
    "subalpinas": "subalpino",
    "subalpinos": "subalpino",
    "subalterna": "subalterno",
    "subalternada": "subalternar",
    "subalternadas": "subalternar",
    "subalternado": "subalternar",
    "subalternados": "subalternar",
    "subalternai": "subalternar",
    "subalternais": "subalternar",
    "subalternam": "subalternar",
    "subalternamo": "subalternar",
    "subalternamos": "subalternar",
    "subalternando": "subalternar",
    "subalternara": "subalternar",
    "subalternaram": "subalternar",
    "subalternaras": "subalternar",
    "subalternarde": "subalternar",
    "subalternardes": "subalternar",
    "subalternare": "subalternar",
    "subalternarei": "subalternar",
    "subalternareis": "subalternar",
    "subalternarem": "subalternar",
    "subalternaremos": "subalternar",
    "subalternares": "subalternar",
    "subalternaria": "subalternar",
    "subalternariam": "subalternar",
    "subalternarias": "subalternar",
    "subalternarmo": "subalternar",
    "subalternarmos": "subalternar",
    "subalternará": "subalternar",
    "subalternarás": "subalternar",
    "subalternarão": "subalternar",
    "subalternaríamos": "subalternar",
    "subalternaríeis": "subalternar",
    "subalternas": "subalterno",
    "subalternasse": "subalternar",
    "subalternassem": "subalternar",
    "subalternasses": "subalternar",
    "subalternaste": "subalternar",
    "subalternastes": "subalternar",
    "subalternava": "subalternar",
    "subalternavam": "subalternar",
    "subalternavas": "subalternar",
    "subalternazinha": "subalterno",
    "subalternazinhas": "subalterno",
    "subalternazita": "subalterno",
    "subalternazitas": "subalterno",
    "subalternações": "subalternação",
    "subalterne": "subalternar",
    "subalternei": "subalternar",
    "subalterneis": "subalternar",
    "subalternem": "subalternar",
    "subalternemo": "subalternar",
    "subalternemos": "subalternar",
    "subalternes": "subalternar",
    "subalternidades": "subalternidade",
    "subalterniza": "subalternizar",
    "subalternizada": "subalternizar",
    "subalternizadas": "subalternizar",
    "subalternizado": "subalternizar",
    "subalternizados": "subalternizar",
    "subalternizai": "subalternizar",
    "subalternizais": "subalternizar",
    "subalternizam": "subalternizar",
    "subalternizamo": "subalternizar",
    "subalternizamos": "subalternizar",
    "subalternizando": "subalternizar",
    "subalternizara": "subalternizar",
    "subalternizaram": "subalternizar",
    "subalternizaras": "subalternizar",
    "subalternizarde": "subalternizar",
    "subalternizardes": "subalternizar",
    "subalternizare": "subalternizar",
    "subalternizarei": "subalternizar",
    "subalternizareis": "subalternizar",
    "subalternizarem": "subalternizar",
    "subalternizaremos": "subalternizar",
    "subalternizares": "subalternizar",
    "subalternizaria": "subalternizar",
    "subalternizariam": "subalternizar",
    "subalternizarias": "subalternizar",
    "subalternizarmo": "subalternizar",
    "subalternizarmos": "subalternizar",
    "subalternizará": "subalternizar",
    "subalternizarás": "subalternizar",
    "subalternizarão": "subalternizar",
    "subalternizaríamos": "subalternizar",
    "subalternizaríeis": "subalternizar",
    "subalternizas": "subalternizar",
    "subalternizasse": "subalternizar",
    "subalternizassem": "subalternizar",
    "subalternizasses": "subalternizar",
    "subalternizaste": "subalternizar",
    "subalternizastes": "subalternizar",
    "subalternizava": "subalternizar",
    "subalternizavam": "subalternizar",
    "subalternizavas": "subalternizar",
    "subalternizações": "subalternização",
    "subalternize": "subalternizar",
    "subalternizei": "subalternizar",
    "subalternizeis": "subalternizar",
    "subalternizem": "subalternizar",
    "subalternizemo": "subalternizar",
    "subalternizemos": "subalternizar",
    "subalternizes": "subalternizar",
    "subalternizo": "subalternizar",
    "subalternizou": "subalternizar",
    "subalternizá": "subalternizar",
    "subalternizámo": "subalternizar",
    "subalternizámos": "subalternizar",
    "subalternizáramo": "subalternizar",
    "subalternizáramos": "subalternizar",
    "subalternizárei": "subalternizar",
    "subalternizáreis": "subalternizar",
    "subalternizásseis": "subalternizar",
    "subalternizássemos": "subalternizar",
    "subalternizávamo": "subalternizar",
    "subalternizávamos": "subalternizar",
    "subalternizávei": "subalternizar",
    "subalternizáveis": "subalternizável",
    "subalterno": "subalternar",
    "subalternos": "subalterno",
    "subalternou": "subalternar",
    "subalternozinho": "subalterno",
    "subalternozinhos": "subalterno",
    "subalternozito": "subalterno",
    "subalternozitos": "subalterno",
    "subalterná": "subalternar",
    "subalternámo": "subalternar",
    "subalternámos": "subalternar",
    "subalternáramo": "subalternar",
    "subalternáramos": "subalternar",
    "subalternárei": "subalternar",
    "subalternáreis": "subalternar",
    "subalternásseis": "subalternar",
    "subalternássemos": "subalternar",
    "subalternávamo": "subalternar",
    "subalternávamos": "subalternar",
    "subalternávei": "subalternar",
    "subalternáveis": "subalternar",
    "subalternâncias": "subalternância",
    "subaluga": "subalugar",
    "subalugada": "subalugar",
    "subalugadas": "subalugar",
    "subalugado": "subalugar",
    "subalugados": "subalugar",
    "subalugai": "subalugar",
    "subalugais": "subalugar",
    "subalugam": "subalugar",
    "subalugamo": "subalugar",
    "subalugamos": "subalugar",
    "subalugando": "subalugar",
    "subalugara": "subalugar",
    "subalugaram": "subalugar",
    "subalugaras": "subalugar",
    "subalugarde": "subalugar",
    "subalugardes": "subalugar",
    "subalugare": "subalugar",
    "subalugarei": "subalugar",
    "subalugareis": "subalugar",
    "subalugarem": "subalugar",
    "subalugaremos": "subalugar",
    "subalugares": "subalugar",
    "subalugaria": "subalugar",
    "subalugariam": "subalugar",
    "subalugarias": "subalugar",
    "subalugarmo": "subalugar",
    "subalugarmos": "subalugar",
    "subalugará": "subalugar",
    "subalugarás": "subalugar",
    "subalugarão": "subalugar",
    "subalugaríamos": "subalugar",
    "subalugaríeis": "subalugar",
    "subalugas": "subalugar",
    "subalugasse": "subalugar",
    "subalugassem": "subalugar",
    "subalugasses": "subalugar",
    "subalugaste": "subalugar",
    "subalugastes": "subalugar",
    "subalugava": "subalugar",
    "subalugavam": "subalugar",
    "subalugavas": "subalugar",
    "subalugo": "subalugar",
    "subalugou": "subalugar",
    "subalugue": "subalugar",
    "subaluguei": "subalugar",
    "subalugueis": "subalugar",
    "subaluguem": "subalugar",
    "subaluguemo": "subalugar",
    "subaluguemos": "subalugar",
    "subalugueres": "subaluguer",
    "subalugues": "subalugar",
    "subalugá": "subalugar",
    "subalugámo": "subalugar",
    "subalugámos": "subalugar",
    "subalugáramo": "subalugar",
    "subalugáramos": "subalugar",
    "subalugárei": "subalugar",
    "subalugáreis": "subalugar",
    "subalugásseis": "subalugar",
    "subalugássemos": "subalugar",
    "subalugávamo": "subalugar",
    "subalugávamos": "subalugar",
    "subalugávei": "subalugar",
    "subalugáveis": "subalugável",
    "subam": "subir",
    "subamo": "subir",
    "subamos": "subir",
    "subanéis": "subanel",
    "subaproveitada": "subaproveitado",
    "subaproveitadas": "subaproveitado",
    "subaproveitados": "subaproveitado",
    "subaquática": "subaquático",
    "subaquáticas": "subaquático",
    "subaquáticos": "subaquático",
    "subarbustiva": "subarbustivo",
    "subarbustivas": "subarbustivo",
    "subarbustivos": "subarbustivo",
    "subarbustos": "subarbusto",
    "subarmónica": "subarmónico",
    "subarmónicas": "subarmónico",
    "subarmónicos": "subarmónico",
    "subarqueada": "subarqueado",
    "subarqueadas": "subarqueado",
    "subarqueados": "subarqueado",
    "subarrenda": "subarrendar",
    "subarrendada": "subarrendar",
    "subarrendadas": "subarrendar",
    "subarrendado": "subarrendar",
    "subarrendados": "subarrendar",
    "subarrendai": "subarrendar",
    "subarrendais": "subarrendar",
    "subarrendam": "subarrendar",
    "subarrendamentos": "subarrendamento",
    "subarrendamo": "subarrendar",
    "subarrendamos": "subarrendar",
    "subarrendando": "subarrendar",
    "subarrendara": "subarrendar",
    "subarrendaram": "subarrendar",
    "subarrendaras": "subarrendar",
    "subarrendarde": "subarrendar",
    "subarrendardes": "subarrendar",
    "subarrendare": "subarrendar",
    "subarrendarei": "subarrendar",
    "subarrendareis": "subarrendar",
    "subarrendarem": "subarrendar",
    "subarrendaremos": "subarrendar",
    "subarrendares": "subarrendar",
    "subarrendaria": "subarrendar",
    "subarrendariam": "subarrendar",
    "subarrendarias": "subarrendar",
    "subarrendarmo": "subarrendar",
    "subarrendarmos": "subarrendar",
    "subarrendará": "subarrendar",
    "subarrendarás": "subarrendar",
    "subarrendarão": "subarrendar",
    "subarrendaríamos": "subarrendar",
    "subarrendaríeis": "subarrendar",
    "subarrendas": "subarrendar",
    "subarrendasse": "subarrendar",
    "subarrendassem": "subarrendar",
    "subarrendasses": "subarrendar",
    "subarrendaste": "subarrendar",
    "subarrendastes": "subarrendar",
    "subarrendatariazinha": "subarrendatário",
    "subarrendatariazinhas": "subarrendatário",
    "subarrendatariazita": "subarrendatário",
    "subarrendatariazitas": "subarrendatário",
    "subarrendatariozinho": "subarrendatário",
    "subarrendatariozinhos": "subarrendatário",
    "subarrendatariozito": "subarrendatário",
    "subarrendatariozitos": "subarrendatário",
    "subarrendatária": "subarrendatário",
    "subarrendatárias": "subarrendatário",
    "subarrendatários": "subarrendatário",
    "subarrendava": "subarrendar",
    "subarrendavam": "subarrendar",
    "subarrendavas": "subarrendar",
    "subarrende": "subarrendar",
    "subarrendei": "subarrendar",
    "subarrendeis": "subarrendar",
    "subarrendem": "subarrendar",
    "subarrendemo": "subarrendar",
    "subarrendemos": "subarrendar",
    "subarrendes": "subarrendar",
    "subarrendo": "subarrendar",
    "subarrendou": "subarrendar",
    "subarrendá": "subarrendar",
    "subarrendámo": "subarrendar",
    "subarrendámos": "subarrendar",
    "subarrendáramo": "subarrendar",
    "subarrendáramos": "subarrendar",
    "subarrendárei": "subarrendar",
    "subarrendáreis": "subarrendar",
    "subarrendásseis": "subarrendar",
    "subarrendássemos": "subarrendar",
    "subarrendávamo": "subarrendar",
    "subarrendávamos": "subarrendar",
    "subarrendávei": "subarrendar",
    "subarrendáveis": "subarrendável",
    "subas": "subir",
    "subasta": "subastar",
    "subastada": "subastar",
    "subastadas": "subastar",
    "subastado": "subastar",
    "subastados": "subastar",
    "subastai": "subastar",
    "subastais": "subastar",
    "subastam": "subastar",
    "subastamo": "subastar",
    "subastamos": "subastar",
    "subastando": "subastar",
    "subastara": "subastar",
    "subastaram": "subastar",
    "subastaras": "subastar",
    "subastarde": "subastar",
    "subastardes": "subastar",
    "subastare": "subastar",
    "subastarei": "subastar",
    "subastareis": "subastar",
    "subastarem": "subastar",
    "subastaremos": "subastar",
    "subastares": "subastar",
    "subastaria": "subastar",
    "subastariam": "subastar",
    "subastarias": "subastar",
    "subastarmo": "subastar",
    "subastarmos": "subastar",
    "subastará": "subastar",
    "subastarás": "subastar",
    "subastarão": "subastar",
    "subastaríamos": "subastar",
    "subastaríeis": "subastar",
    "subastas": "subastar",
    "subastasse": "subastar",
    "subastassem": "subastar",
    "subastasses": "subastar",
    "subastaste": "subastar",
    "subastastes": "subastar",
    "subastava": "subastar",
    "subastavam": "subastar",
    "subastavas": "subastar",
    "subastações": "subastação",
    "subaste": "subastar",
    "subastei": "subastar",
    "subasteis": "subastar",
    "subastem": "subastar",
    "subastemo": "subastar",
    "subastemos": "subastar",
    "subastes": "subastar",
    "subasto": "subastar",
    "subastou": "subastar",
    "subastá": "subastar",
    "subastámo": "subastar",
    "subastámos": "subastar",
    "subastáramo": "subastar",
    "subastáramos": "subastar",
    "subastárei": "subastar",
    "subastáreis": "subastar",
    "subastásseis": "subastar",
    "subastássemos": "subastar",
    "subastávamo": "subastar",
    "subastávamos": "subastar",
    "subastávei": "subastar",
    "subastáveis": "subastar",
    "subatómica": "subatómico",
    "subatómicas": "subatómico",
    "subatómicos": "subatómico",
    "subavaliada": "subavaliado",
    "subavaliadas": "subavaliado",
    "subavaliados": "subavaliado",
    "subaxilares": "subaxilar",
    "subaérea": "subaéreo",
    "subaéreas": "subaéreo",
    "subaéreos": "subaéreo",
    "subcacuminais": "subcacuminal",
    "subcategorias": "subcategoria",
    "subcategoriza": "subcategorizar",
    "subcategorizada": "subcategorizar",
    "subcategorizadas": "subcategorizar",
    "subcategorizado": "subcategorizar",
    "subcategorizados": "subcategorizar",
    "subcategorizai": "subcategorizar",
    "subcategorizais": "subcategorizar",
    "subcategorizam": "subcategorizar",
    "subcategorizamo": "subcategorizar",
    "subcategorizamos": "subcategorizar",
    "subcategorizando": "subcategorizar",
    "subcategorizara": "subcategorizar",
    "subcategorizaram": "subcategorizar",
    "subcategorizaras": "subcategorizar",
    "subcategorizarde": "subcategorizar",
    "subcategorizardes": "subcategorizar",
    "subcategorizare": "subcategorizar",
    "subcategorizarei": "subcategorizar",
    "subcategorizareis": "subcategorizar",
    "subcategorizarem": "subcategorizar",
    "subcategorizaremos": "subcategorizar",
    "subcategorizares": "subcategorizar",
    "subcategorizaria": "subcategorizar",
    "subcategorizariam": "subcategorizar",
    "subcategorizarias": "subcategorizar",
    "subcategorizarmo": "subcategorizar",
    "subcategorizarmos": "subcategorizar",
    "subcategorizará": "subcategorizar",
    "subcategorizarás": "subcategorizar",
    "subcategorizarão": "subcategorizar",
    "subcategorizaríamos": "subcategorizar",
    "subcategorizaríeis": "subcategorizar",
    "subcategorizas": "subcategorizar",
    "subcategorizasse": "subcategorizar",
    "subcategorizassem": "subcategorizar",
    "subcategorizasses": "subcategorizar",
    "subcategorizaste": "subcategorizar",
    "subcategorizastes": "subcategorizar",
    "subcategorizava": "subcategorizar",
    "subcategorizavam": "subcategorizar",
    "subcategorizavas": "subcategorizar",
    "subcategorize": "subcategorizar",
    "subcategorizei": "subcategorizar",
    "subcategorizeis": "subcategorizar",
    "subcategorizem": "subcategorizar",
    "subcategorizemo": "subcategorizar",
    "subcategorizemos": "subcategorizar",
    "subcategorizes": "subcategorizar",
    "subcategorizo": "subcategorizar",
    "subcategorizou": "subcategorizar",
    "subcategorizá": "subcategorizar",
    "subcategorizámo": "subcategorizar",
    "subcategorizámos": "subcategorizar",
    "subcategorizáramo": "subcategorizar",
    "subcategorizáramos": "subcategorizar",
    "subcategorizárei": "subcategorizar",
    "subcategorizáreis": "subcategorizar",
    "subcategorizásseis": "subcategorizar",
    "subcategorizássemos": "subcategorizar",
    "subcategorizávamo": "subcategorizar",
    "subcategorizávamos": "subcategorizar",
    "subcategorizávei": "subcategorizar",
    "subcategorizáveis": "subcategorizar",
    "subcaves": "subcave",
    "subchefes": "subchefe",
    "subchefias": "subchefia",
    "subcinerícia": "subcinerício",
    "subcinerícias": "subcinerício",
    "subcinerícios": "subcinerício",
    "subclasses": "subclasse",
    "subclassificações": "subclassificação",
    "subclaviculares": "subclavicular",
    "subcoberturas": "subcobertura",
    "subcomandantes": "subcomandante",
    "subcomissária": "subcomissário",
    "subcomissárias": "subcomissário",
    "subcomissários": "subcomissário",
    "subcomissões": "subcomissão",
    "subconjuntos": "subconjunto",
    "subconscientes": "subconsciente",
    "subconsciências": "subconsciência",
    "subconsumos": "subconsumo",
    "subcontinentes": "subcontinente",
    "subcontratada": "subcontratado",
    "subcontratadas": "subcontratado",
    "subcontratados": "subcontratado",
    "subcontratações": "subcontratação",
    "subcontratos": "subcontrato",
    "subcorpos": "subcorpo",
    "subcorrentes": "subcorrente",
    "subcostais": "subcostal",
    "subcutânea": "subcutâneo",
    "subcutâneas": "subcutâneo",
    "subcutâneos": "subcutâneo",
    "subdelega": "subdelegar",
    "subdelegacias": "subdelegacia",
    "subdelegada": "subdelegar",
    "subdelegadas": "subdelegar",
    "subdelegado": "subdelegar",
    "subdelegados": "subdelegar",
    "subdelegai": "subdelegar",
    "subdelegais": "subdelegar",
    "subdelegam": "subdelegar",
    "subdelegamo": "subdelegar",
    "subdelegamos": "subdelegar",
    "subdelegando": "subdelegar",
    "subdelegantes": "subdelegante",
    "subdelegara": "subdelegar",
    "subdelegaram": "subdelegar",
    "subdelegaras": "subdelegar",
    "subdelegarde": "subdelegar",
    "subdelegardes": "subdelegar",
    "subdelegare": "subdelegar",
    "subdelegarei": "subdelegar",
    "subdelegareis": "subdelegar",
    "subdelegarem": "subdelegar",
    "subdelegaremos": "subdelegar",
    "subdelegares": "subdelegar",
    "subdelegaria": "subdelegar",
    "subdelegariam": "subdelegar",
    "subdelegarias": "subdelegar",
    "subdelegarmo": "subdelegar",
    "subdelegarmos": "subdelegar",
    "subdelegará": "subdelegar",
    "subdelegarás": "subdelegar",
    "subdelegarão": "subdelegar",
    "subdelegaríamos": "subdelegar",
    "subdelegaríeis": "subdelegar",
    "subdelegas": "subdelegar",
    "subdelegasse": "subdelegar",
    "subdelegassem": "subdelegar",
    "subdelegasses": "subdelegar",
    "subdelegaste": "subdelegar",
    "subdelegastes": "subdelegar",
    "subdelegava": "subdelegar",
    "subdelegavam": "subdelegar",
    "subdelegavas": "subdelegar",
    "subdelegações": "subdelegação",
    "subdelego": "subdelegar",
    "subdelegou": "subdelegar",
    "subdelegue": "subdelegar",
    "subdeleguei": "subdelegar",
    "subdelegueis": "subdelegar",
    "subdeleguem": "subdelegar",
    "subdeleguemo": "subdelegar",
    "subdeleguemos": "subdelegar",
    "subdelegues": "subdelegar",
    "subdelegá": "subdelegar",
    "subdelegámo": "subdelegar",
    "subdelegámos": "subdelegar",
    "subdelegáramo": "subdelegar",
    "subdelegáramos": "subdelegar",
    "subdelegárei": "subdelegar",
    "subdelegáreis": "subdelegar",
    "subdelegásseis": "subdelegar",
    "subdelegássemos": "subdelegar",
    "subdelegávamo": "subdelegar",
    "subdelegávamos": "subdelegar",
    "subdelegávei": "subdelegar",
    "subdelegáveis": "subdelegável",
    "subdelírios": "subdelírio",
    "subderivada": "subderivado",
    "subderivadas": "subderivado",
    "subderivados": "subderivado",
    "subdesenvolvida": "subdesenvolvido",
    "subdesenvolvidas": "subdesenvolvido",
    "subdesenvolvidos": "subdesenvolvido",
    "subdesenvolvidíssima": "subdesenvolvido",
    "subdesenvolvidíssimas": "subdesenvolvido",
    "subdesenvolvidíssimo": "subdesenvolvido",
    "subdesenvolvidíssimos": "subdesenvolvido",
    "subdesenvolvimentos": "subdesenvolvimento",
    "subdiaconados": "subdiaconado",
    "subdiaconatos": "subdiaconato",
    "subdiaconisas": "subdiaconisa",
    "subdialectos": "subdialecto",
    "subdimensionamentos": "subdimensionamento",
    "subdirectora": "subdirector",
    "subdirectoras": "subdirector",
    "subdirectores": "subdirector",
    "subdirectorias": "subdirectoria",
    "subdireções": "subdireção",
    "subdirige": "subdirigir",
    "subdirigem": "subdirigir",
    "subdiriges": "subdirigir",
    "subdirigi": "subdirigir",
    "subdirigia": "subdirigir",
    "subdirigiam": "subdirigir",
    "subdirigias": "subdirigir",
    "subdirigida": "subdirigir",
    "subdirigidas": "subdirigir",
    "subdirigido": "subdirigir",
    "subdirigidos": "subdirigir",
    "subdirigimo": "subdirigir",
    "subdirigimos": "subdirigir",
    "subdirigindo": "subdirigir",
    "subdirigira": "subdirigir",
    "subdirigiram": "subdirigir",
    "subdirigiras": "subdirigir",
    "subdirigirde": "subdirigir",
    "subdirigirdes": "subdirigir",
    "subdirigire": "subdirigir",
    "subdirigirei": "subdirigir",
    "subdirigireis": "subdirigir",
    "subdirigirem": "subdirigir",
    "subdirigiremos": "subdirigir",
    "subdirigires": "subdirigir",
    "subdirigiria": "subdirigir",
    "subdirigiriam": "subdirigir",
    "subdirigirias": "subdirigir",
    "subdirigirmo": "subdirigir",
    "subdirigirmos": "subdirigir",
    "subdirigirá": "subdirigir",
    "subdirigirás": "subdirigir",
    "subdirigirão": "subdirigir",
    "subdirigiríamos": "subdirigir",
    "subdirigiríeis": "subdirigir",
    "subdirigis": "subdirigir",
    "subdirigisse": "subdirigir",
    "subdirigissem": "subdirigir",
    "subdirigisses": "subdirigir",
    "subdirigiste": "subdirigir",
    "subdirigistes": "subdirigir",
    "subdirigiu": "subdirigir",
    "subdirigíamo": "subdirigir",
    "subdirigíamos": "subdirigir",
    "subdirigíei": "subdirigir",
    "subdirigíeis": "subdirigir",
    "subdirigíramo": "subdirigir",
    "subdirigíramos": "subdirigir",
    "subdirigírei": "subdirigir",
    "subdirigíreis": "subdirigir",
    "subdirigísseis": "subdirigir",
    "subdirigíssemos": "subdirigir",
    "subdirija": "subdirigir",
    "subdirijais": "subdirigir",
    "subdirijam": "subdirigir",
    "subdirijamo": "subdirigir",
    "subdirijamos": "subdirigir",
    "subdirijas": "subdirigir",
    "subdirijo": "subdirigir",
    "subdistinga": "subdistinguir",
    "subdistingais": "subdistinguir",
    "subdistingam": "subdistinguir",
    "subdistingamo": "subdistinguir",
    "subdistingamos": "subdistinguir",
    "subdistingas": "subdistinguir",
    "subdistingo": "subdistinguir",
    "subdistingue": "subdistinguir",
    "subdistinguem": "subdistinguir",
    "subdistingues": "subdistinguir",
    "subdistingui": "subdistinguir",
    "subdistinguia": "subdistinguir",
    "subdistinguiam": "subdistinguir",
    "subdistinguias": "subdistinguir",
    "subdistinguida": "subdistinguir",
    "subdistinguidas": "subdistinguir",
    "subdistinguido": "subdistinguir",
    "subdistinguidos": "subdistinguir",
    "subdistinguimo": "subdistinguir",
    "subdistinguimos": "subdistinguir",
    "subdistinguindo": "subdistinguir",
    "subdistinguira": "subdistinguir",
    "subdistinguiram": "subdistinguir",
    "subdistinguiras": "subdistinguir",
    "subdistinguirde": "subdistinguir",
    "subdistinguirdes": "subdistinguir",
    "subdistinguire": "subdistinguir",
    "subdistinguirei": "subdistinguir",
    "subdistinguireis": "subdistinguir",
    "subdistinguirem": "subdistinguir",
    "subdistinguiremos": "subdistinguir",
    "subdistinguires": "subdistinguir",
    "subdistinguiria": "subdistinguir",
    "subdistinguiriam": "subdistinguir",
    "subdistinguirias": "subdistinguir",
    "subdistinguirmo": "subdistinguir",
    "subdistinguirmos": "subdistinguir",
    "subdistinguirá": "subdistinguir",
    "subdistinguirás": "subdistinguir",
    "subdistinguirão": "subdistinguir",
    "subdistinguiríamos": "subdistinguir",
    "subdistinguiríeis": "subdistinguir",
    "subdistinguis": "subdistinguir",
    "subdistinguisse": "subdistinguir",
    "subdistinguissem": "subdistinguir",
    "subdistinguisses": "subdistinguir",
    "subdistinguiste": "subdistinguir",
    "subdistinguistes": "subdistinguir",
    "subdistinguiu": "subdistinguir",
    "subdistinguíamo": "subdistinguir",
    "subdistinguíamos": "subdistinguir",
    "subdistinguíei": "subdistinguir",
    "subdistinguíeis": "subdistinguir",
    "subdistinguíramo": "subdistinguir",
    "subdistinguíramos": "subdistinguir",
    "subdistinguírei": "subdistinguir",
    "subdistinguíreis": "subdistinguir",
    "subdistinguísseis": "subdistinguir",
    "subdistinguíssemos": "subdistinguir",
    "subdistinções": "subdistinção",
    "subditazinha": "súbdito",
    "subditazinhas": "súbdito",
    "subditazita": "súbdito",
    "subditazitas": "súbdito",
    "subditozinho": "súbdito",
    "subditozinhos": "súbdito",
    "subditozito": "súbdito",
    "subditozitos": "súbdito",
    "subdivida": "subdividir",
    "subdividais": "subdividir",
    "subdividam": "subdividir",
    "subdividamo": "subdividir",
    "subdividamos": "subdividir",
    "subdividas": "subdividir",
    "subdivide": "subdividir",
    "subdividem": "subdividir",
    "subdivides": "subdividir",
    "subdividi": "subdividir",
    "subdividia": "subdividir",
    "subdividiam": "subdividir",
    "subdividias": "subdividir",
    "subdividida": "subdividir",
    "subdivididas": "subdividir",
    "subdividido": "subdividir",
    "subdivididos": "subdividir",
    "subdividimo": "subdividir",
    "subdividimos": "subdividir",
    "subdividindo": "subdividir",
    "subdividira": "subdividir",
    "subdividiram": "subdividir",
    "subdividiras": "subdividir",
    "subdividirde": "subdividir",
    "subdividirdes": "subdividir",
    "subdividire": "subdividir",
    "subdividirei": "subdividir",
    "subdividireis": "subdividir",
    "subdividirem": "subdividir",
    "subdividiremos": "subdividir",
    "subdividires": "subdividir",
    "subdividiria": "subdividir",
    "subdividiriam": "subdividir",
    "subdividirias": "subdividir",
    "subdividirmo": "subdividir",
    "subdividirmos": "subdividir",
    "subdividirá": "subdividir",
    "subdividirás": "subdividir",
    "subdividirão": "subdividir",
    "subdividiríamos": "subdividir",
    "subdividiríeis": "subdividir",
    "subdividis": "subdividir",
    "subdividisse": "subdividir",
    "subdividissem": "subdividir",
    "subdividisses": "subdividir",
    "subdividiste": "subdividir",
    "subdividistes": "subdividir",
    "subdividiu": "subdividir",
    "subdivido": "subdividir",
    "subdividíamo": "subdividir",
    "subdividíamos": "subdividir",
    "subdividíei": "subdividir",
    "subdividíeis": "subdividir",
    "subdividíramo": "subdividir",
    "subdividíramos": "subdividir",
    "subdividírei": "subdividir",
    "subdividíreis": "subdividir",
    "subdividísseis": "subdividir",
    "subdividíssemos": "subdividir",
    "subdivisionária": "subdivisionário",
    "subdivisionárias": "subdivisionário",
    "subdivisionários": "subdivisionário",
    "subdivisíveis": "subdivisível",
    "subdivisões": "subdivisão",
    "subdiáconos": "subdiácono",
    "subdominantes": "subdominante",
    "subdomínios": "subdomínio",
    "subdupla": "subduplo",
    "subduplas": "subduplo",
    "subduplos": "subduplo",
    "subdécupla": "subdécuplo",
    "subdécuplas": "subdécuplo",
    "subdécuplos": "subdécuplo",
    "subeditora": "subeditor",
    "subeditoras": "subeditor",
    "subeditores": "subeditor",
    "subeditorias": "subeditoria",
    "subemendas": "subemenda",
    "subempraza": "subemprazar",
    "subemprazada": "subemprazar",
    "subemprazadas": "subemprazar",
    "subemprazado": "subemprazar",
    "subemprazados": "subemprazar",
    "subemprazai": "subemprazar",
    "subemprazais": "subemprazar",
    "subemprazam": "subemprazar",
    "subemprazamentos": "subemprazamento",
    "subemprazamo": "subemprazar",
    "subemprazamos": "subemprazar",
    "subemprazando": "subemprazar",
    "subemprazara": "subemprazar",
    "subemprazaram": "subemprazar",
    "subemprazaras": "subemprazar",
    "subemprazarde": "subemprazar",
    "subemprazardes": "subemprazar",
    "subemprazare": "subemprazar",
    "subemprazarei": "subemprazar",
    "subemprazareis": "subemprazar",
    "subemprazarem": "subemprazar",
    "subemprazaremos": "subemprazar",
    "subemprazares": "subemprazar",
    "subemprazaria": "subemprazar",
    "subemprazariam": "subemprazar",
    "subemprazarias": "subemprazar",
    "subemprazarmo": "subemprazar",
    "subemprazarmos": "subemprazar",
    "subemprazará": "subemprazar",
    "subemprazarás": "subemprazar",
    "subemprazarão": "subemprazar",
    "subemprazaríamos": "subemprazar",
    "subemprazaríeis": "subemprazar",
    "subemprazas": "subemprazar",
    "subemprazasse": "subemprazar",
    "subemprazassem": "subemprazar",
    "subemprazasses": "subemprazar",
    "subemprazaste": "subemprazar",
    "subemprazastes": "subemprazar",
    "subemprazava": "subemprazar",
    "subemprazavam": "subemprazar",
    "subemprazavas": "subemprazar",
    "subempraze": "subemprazar",
    "subemprazei": "subemprazar",
    "subemprazeis": "subemprazar",
    "subemprazem": "subemprazar",
    "subemprazemo": "subemprazar",
    "subemprazemos": "subemprazar",
    "subemprazes": "subemprazar",
    "subemprazo": "subemprazar",
    "subemprazou": "subemprazar",
    "subemprazá": "subemprazar",
    "subemprazámo": "subemprazar",
    "subemprazámos": "subemprazar",
    "subemprazáramo": "subemprazar",
    "subemprazáramos": "subemprazar",
    "subemprazárei": "subemprazar",
    "subemprazáreis": "subemprazar",
    "subemprazásseis": "subemprazar",
    "subemprazássemos": "subemprazar",
    "subemprazávamo": "subemprazar",
    "subemprazávamos": "subemprazar",
    "subemprazávei": "subemprazar",
    "subemprazáveis": "subemprazar",
    "subempregada": "subempregado",
    "subempregadas": "subempregado",
    "subempregados": "subempregado",
    "subempregos": "subemprego",
    "subempreitadas": "subempreitada",
    "subempreiteira": "subempreiteiro",
    "subempreiteiras": "subempreiteiro",
    "subempreiteiros": "subempreiteiro",
    "subenfiteuses": "subenfiteuse",
    "subenfiteutas": "subenfiteuta",
    "subenfiteutica": "subenfiteuticar",
    "subenfiteuticada": "subenfiteuticar",
    "subenfiteuticadas": "subenfiteuticar",
    "subenfiteuticado": "subenfiteuticar",
    "subenfiteuticados": "subenfiteuticar",
    "subenfiteuticai": "subenfiteuticar",
    "subenfiteuticais": "subenfiteuticar",
    "subenfiteuticam": "subenfiteuticar",
    "subenfiteuticamo": "subenfiteuticar",
    "subenfiteuticamos": "subenfiteuticar",
    "subenfiteuticando": "subenfiteuticar",
    "subenfiteuticara": "subenfiteuticar",
    "subenfiteuticaram": "subenfiteuticar",
    "subenfiteuticaras": "subenfiteuticar",
    "subenfiteuticarde": "subenfiteuticar",
    "subenfiteuticardes": "subenfiteuticar",
    "subenfiteuticare": "subenfiteuticar",
    "subenfiteuticarei": "subenfiteuticar",
    "subenfiteuticareis": "subenfiteuticar",
    "subenfiteuticarem": "subenfiteuticar",
    "subenfiteuticaremos": "subenfiteuticar",
    "subenfiteuticares": "subenfiteuticar",
    "subenfiteuticaria": "subenfiteuticar",
    "subenfiteuticariam": "subenfiteuticar",
    "subenfiteuticarias": "subenfiteuticar",
    "subenfiteuticarmo": "subenfiteuticar",
    "subenfiteuticarmos": "subenfiteuticar",
    "subenfiteuticará": "subenfiteuticar",
    "subenfiteuticarás": "subenfiteuticar",
    "subenfiteuticarão": "subenfiteuticar",
    "subenfiteuticaríamos": "subenfiteuticar",
    "subenfiteuticaríeis": "subenfiteuticar",
    "subenfiteuticas": "subenfiteuticar",
    "subenfiteuticasse": "subenfiteuticar",
    "subenfiteuticassem": "subenfiteuticar",
    "subenfiteuticasses": "subenfiteuticar",
    "subenfiteuticaste": "subenfiteuticar",
    "subenfiteuticastes": "subenfiteuticar",
    "subenfiteuticava": "subenfiteuticar",
    "subenfiteuticavam": "subenfiteuticar",
    "subenfiteuticavas": "subenfiteuticar",
    "subenfiteutico": "subenfiteuticar",
    "subenfiteuticou": "subenfiteuticar",
    "subenfiteuticá": "subenfiteuticar",
    "subenfiteuticámo": "subenfiteuticar",
    "subenfiteuticámos": "subenfiteuticar",
    "subenfiteuticáramo": "subenfiteuticar",
    "subenfiteuticáramos": "subenfiteuticar",
    "subenfiteuticárei": "subenfiteuticar",
    "subenfiteuticáreis": "subenfiteuticar",
    "subenfiteuticásseis": "subenfiteuticar",
    "subenfiteuticássemos": "subenfiteuticar",
    "subenfiteuticávamo": "subenfiteuticar",
    "subenfiteuticávamos": "subenfiteuticar",
    "subenfiteuticávei": "subenfiteuticar",
    "subenfiteuticáveis": "subenfiteuticar",
    "subenfiteutique": "subenfiteuticar",
    "subenfiteutiquei": "subenfiteuticar",
    "subenfiteutiqueis": "subenfiteuticar",
    "subenfiteutiquem": "subenfiteuticar",
    "subenfiteutiquemo": "subenfiteuticar",
    "subenfiteutiquemos": "subenfiteuticar",
    "subenfiteutiques": "subenfiteuticar",
    "subenfitêutica": "subenfitêutico",
    "subenfitêuticas": "subenfitêutico",
    "subenfitêuticos": "subenfitêutico",
    "subentenda": "subentender",
    "subentendais": "subentender",
    "subentendam": "subentender",
    "subentendamo": "subentender",
    "subentendamos": "subentender",
    "subentendas": "subentender",
    "subentende": "subentender",
    "subentendei": "subentender",
    "subentendeis": "subentender",
    "subentendem": "subentender",
    "subentendemo": "subentender",
    "subentendemos": "subentender",
    "subentendendo": "subentender",
    "subentendera": "subentender",
    "subentenderam": "subentender",
    "subentenderas": "subentender",
    "subentenderde": "subentender",
    "subentenderdes": "subentender",
    "subentendere": "subentender",
    "subentenderei": "subentender",
    "subentendereis": "subentender",
    "subentenderem": "subentender",
    "subentenderemos": "subentender",
    "subentenderes": "subentender",
    "subentenderia": "subentender",
    "subentenderiam": "subentender",
    "subentenderias": "subentender",
    "subentendermo": "subentender",
    "subentendermos": "subentender",
    "subentenderá": "subentender",
    "subentenderás": "subentender",
    "subentenderão": "subentender",
    "subentenderíamos": "subentender",
    "subentenderíeis": "subentender",
    "subentendes": "subentender",
    "subentendesse": "subentender",
    "subentendessem": "subentender",
    "subentendesses": "subentender",
    "subentendeste": "subentender",
    "subentendestes": "subentender",
    "subentendeu": "subentender",
    "subentendi": "subentender",
    "subentendia": "subentender",
    "subentendiam": "subentender",
    "subentendias": "subentender",
    "subentendida": "subentendido",
    "subentendidas": "subentendido",
    "subentendido": "subentender",
    "subentendidos": "subentendido",
    "subentendidíssima": "subentendido",
    "subentendidíssimas": "subentendido",
    "subentendidíssimo": "subentendido",
    "subentendidíssimos": "subentendido",
    "subentendimentos": "subentendimento",
    "subentendo": "subentender",
    "subentendê": "subentender",
    "subentendêramo": "subentender",
    "subentendêramos": "subentender",
    "subentendêrei": "subentender",
    "subentendêreis": "subentender",
    "subentendêsseis": "subentender",
    "subentendêssemos": "subentender",
    "subentendíamo": "subentender",
    "subentendíamos": "subentender",
    "subentendíei": "subentender",
    "subentendíeis": "subentender",
    "subenvasamentos": "subenvasamento",
    "suberatos": "suberato",
    "subericulturas": "subericultura",
    "suberifica": "suberificar",
    "suberificada": "suberificar",
    "suberificadas": "suberificar",
    "suberificado": "suberificar",
    "suberificados": "suberificar",
    "suberificai": "suberificar",
    "suberificais": "suberificar",
    "suberificam": "suberificar",
    "suberificamo": "suberificar",
    "suberificamos": "suberificar",
    "suberificando": "suberificar",
    "suberificara": "suberificar",
    "suberificaram": "suberificar",
    "suberificaras": "suberificar",
    "suberificarde": "suberificar",
    "suberificardes": "suberificar",
    "suberificare": "suberificar",
    "suberificarei": "suberificar",
    "suberificareis": "suberificar",
    "suberificarem": "suberificar",
    "suberificaremos": "suberificar",
    "suberificares": "suberificar",
    "suberificaria": "suberificar",
    "suberificariam": "suberificar",
    "suberificarias": "suberificar",
    "suberificarmo": "suberificar",
    "suberificarmos": "suberificar",
    "suberificará": "suberificar",
    "suberificarás": "suberificar",
    "suberificarão": "suberificar",
    "suberificaríamos": "suberificar",
    "suberificaríeis": "suberificar",
    "suberificas": "suberificar",
    "suberificasse": "suberificar",
    "suberificassem": "suberificar",
    "suberificasses": "suberificar",
    "suberificaste": "suberificar",
    "suberificastes": "suberificar",
    "suberificava": "suberificar",
    "suberificavam": "suberificar",
    "suberificavas": "suberificar",
    "suberificações": "suberificação",
    "suberifico": "suberificar",
    "suberificou": "suberificar",
    "suberificá": "suberificar",
    "suberificámo": "suberificar",
    "suberificámos": "suberificar",
    "suberificáramo": "suberificar",
    "suberificáramos": "suberificar",
    "suberificárei": "suberificar",
    "suberificáreis": "suberificar",
    "suberificásseis": "suberificar",
    "suberificássemos": "suberificar",
    "suberificávamo": "suberificar",
    "suberificávamos": "suberificar",
    "suberificávei": "suberificar",
    "suberificáveis": "suberificar",
    "suberifique": "suberificar",
    "suberifiquei": "suberificar",
    "suberifiqueis": "suberificar",
    "suberifiquem": "suberificar",
    "suberifiquemo": "suberificar",
    "suberifiquemos": "suberificar",
    "suberifiques": "suberificar",
    "suberiformes": "suberiforme",
    "suberinas": "suberina",
    "suberiza": "suberizar",
    "suberizada": "suberizar",
    "suberizadas": "suberizar",
    "suberizado": "suberizar",
    "suberizados": "suberizar",
    "suberizai": "suberizar",
    "suberizais": "suberizar",
    "suberizam": "suberizar",
    "suberizamo": "suberizar",
    "suberizamos": "suberizar",
    "suberizando": "suberizar",
    "suberizara": "suberizar",
    "suberizaram": "suberizar",
    "suberizaras": "suberizar",
    "suberizarde": "suberizar",
    "suberizardes": "suberizar",
    "suberizare": "suberizar",
    "suberizarei": "suberizar",
    "suberizareis": "suberizar",
    "suberizarem": "suberizar",
    "suberizaremos": "suberizar",
    "suberizares": "suberizar",
    "suberizaria": "suberizar",
    "suberizariam": "suberizar",
    "suberizarias": "suberizar",
    "suberizarmo": "suberizar",
    "suberizarmos": "suberizar",
    "suberizará": "suberizar",
    "suberizarás": "suberizar",
    "suberizarão": "suberizar",
    "suberizaríamos": "suberizar",
    "suberizaríeis": "suberizar",
    "suberizas": "suberizar",
    "suberizasse": "suberizar",
    "suberizassem": "suberizar",
    "suberizasses": "suberizar",
    "suberizaste": "suberizar",
    "suberizastes": "suberizar",
    "suberizava": "suberizar",
    "suberizavam": "suberizar",
    "suberizavas": "suberizar",
    "suberizações": "suberização",
    "suberize": "suberizar",
    "suberizei": "suberizar",
    "suberizeis": "suberizar",
    "suberizem": "suberizar",
    "suberizemo": "suberizar",
    "suberizemos": "suberizar",
    "suberizes": "suberizar",
    "suberizo": "suberizar",
    "suberizou": "suberizar",
    "suberizá": "suberizar",
    "suberizámo": "suberizar",
    "suberizámos": "suberizar",
    "suberizáramo": "suberizar",
    "suberizáramos": "suberizar",
    "suberizárei": "suberizar",
    "suberizáreis": "suberizar",
    "suberizásseis": "suberizar",
    "suberizássemos": "suberizar",
    "suberizávamo": "suberizar",
    "suberizávamos": "suberizar",
    "suberizávei": "suberizar",
    "suberizáveis": "suberizar",
    "suberosa": "suberoso",
    "suberosas": "suberoso",
    "suberosos": "suberoso",
    "subescreva": "subescrever",
    "subescrevais": "subescrever",
    "subescrevam": "subescrever",
    "subescrevamo": "subescrever",
    "subescrevamos": "subescrever",
    "subescrevas": "subescrever",
    "subescreve": "subescrever",
    "subescrevei": "subescrever",
    "subescreveis": "subescrever",
    "subescrevem": "subescrever",
    "subescrevemo": "subescrever",
    "subescrevemos": "subescrever",
    "subescrevendo": "subescrever",
    "subescrevera": "subescrever",
    "subescreveram": "subescrever",
    "subescreveras": "subescrever",
    "subescreverde": "subescrever",
    "subescreverdes": "subescrever",
    "subescrevere": "subescrever",
    "subescreverei": "subescrever",
    "subescrevereis": "subescrever",
    "subescreverem": "subescrever",
    "subescreveremos": "subescrever",
    "subescreveres": "subescrever",
    "subescreveria": "subescrever",
    "subescreveriam": "subescrever",
    "subescreverias": "subescrever",
    "subescrevermo": "subescrever",
    "subescrevermos": "subescrever",
    "subescreverá": "subescrever",
    "subescreverás": "subescrever",
    "subescreverão": "subescrever",
    "subescreveríamos": "subescrever",
    "subescreveríeis": "subescrever",
    "subescreves": "subescrever",
    "subescrevesse": "subescrever",
    "subescrevessem": "subescrever",
    "subescrevesses": "subescrever",
    "subescreveste": "subescrever",
    "subescrevestes": "subescrever",
    "subescreveu": "subescrever",
    "subescrevi": "subescrever",
    "subescrevia": "subescrever",
    "subescreviam": "subescrever",
    "subescrevias": "subescrever",
    "subescrevo": "subescrever",
    "subescrevê": "subescrever",
    "subescrevêramo": "subescrever",
    "subescrevêramos": "subescrever",
    "subescrevêrei": "subescrever",
    "subescrevêreis": "subescrever",
    "subescrevêsseis": "subescrever",
    "subescrevêssemos": "subescrever",
    "subescrevíamo": "subescrever",
    "subescrevíamos": "subescrever",
    "subescrevíei": "subescrever",
    "subescrevíeis": "subescrever",
    "subescrita": "subescrever",
    "subescritas": "subescrever",
    "subescrito": "subescrever",
    "subescritos": "subescrever",
    "subespaços": "subespaço",
    "subespecializada": "subespecializado",
    "subespecializadas": "subespecializado",
    "subespecializados": "subespecializado",
    "subespontânea": "subespontâneo",
    "subespontâneas": "subespontâneo",
    "subespontâneos": "subespontâneo",
    "subespécies": "subespécie",
    "subestações": "subestação",
    "subestima": "subestimar",
    "subestimada": "subestimar",
    "subestimadas": "subestimar",
    "subestimado": "subestimar",
    "subestimados": "subestimar",
    "subestimai": "subestimar",
    "subestimais": "subestimar",
    "subestimam": "subestimar",
    "subestimamo": "subestimar",
    "subestimamos": "subestimar",
    "subestimando": "subestimar",
    "subestimara": "subestimar",
    "subestimaram": "subestimar",
    "subestimaras": "subestimar",
    "subestimarde": "subestimar",
    "subestimardes": "subestimar",
    "subestimare": "subestimar",
    "subestimarei": "subestimar",
    "subestimareis": "subestimar",
    "subestimarem": "subestimar",
    "subestimaremos": "subestimar",
    "subestimares": "subestimar",
    "subestimaria": "subestimar",
    "subestimariam": "subestimar",
    "subestimarias": "subestimar",
    "subestimarmo": "subestimar",
    "subestimarmos": "subestimar",
    "subestimará": "subestimar",
    "subestimarás": "subestimar",
    "subestimarão": "subestimar",
    "subestimaríamos": "subestimar",
    "subestimaríeis": "subestimar",
    "subestimas": "subestimar",
    "subestimasse": "subestimar",
    "subestimassem": "subestimar",
    "subestimasses": "subestimar",
    "subestimaste": "subestimar",
    "subestimastes": "subestimar",
    "subestimava": "subestimar",
    "subestimavam": "subestimar",
    "subestimavas": "subestimar",
    "subestimações": "subestimação",
    "subestime": "subestimar",
    "subestimei": "subestimar",
    "subestimeis": "subestimar",
    "subestimem": "subestimar",
    "subestimemo": "subestimar",
    "subestimemos": "subestimar",
    "subestimes": "subestimar",
    "subestimo": "subestimar",
    "subestimou": "subestimar",
    "subestimá": "subestimar",
    "subestimámo": "subestimar",
    "subestimámos": "subestimar",
    "subestimáramo": "subestimar",
    "subestimáramos": "subestimar",
    "subestimárei": "subestimar",
    "subestimáreis": "subestimar",
    "subestimásseis": "subestimar",
    "subestimássemos": "subestimar",
    "subestimávamo": "subestimar",
    "subestimávamos": "subestimar",
    "subestimávei": "subestimar",
    "subestimáveis": "subestimar",
    "subestruturas": "subestrutura",
    "subexposições": "subexposição",
    "subfaces": "subface",
    "subfacturações": "subfacturação",
    "subfamílias": "subfamília",
    "subfeudatários": "subfeudatário",
    "subfeudos": "subfeudo",
    "subfinanciamentos": "subfinanciamento",
    "subfluviais": "subfluvial",
    "subfoliácea": "subfoliáceo",
    "subfoliáceas": "subfoliáceo",
    "subfoliáceos": "subfoliáceo",
    "subfreta": "subfretar",
    "subfretada": "subfretar",
    "subfretadas": "subfretar",
    "subfretado": "subfretar",
    "subfretados": "subfretar",
    "subfretai": "subfretar",
    "subfretais": "subfretar",
    "subfretam": "subfretar",
    "subfretamo": "subfretar",
    "subfretamos": "subfretar",
    "subfretando": "subfretar",
    "subfretara": "subfretar",
    "subfretaram": "subfretar",
    "subfretaras": "subfretar",
    "subfretarde": "subfretar",
    "subfretardes": "subfretar",
    "subfretare": "subfretar",
    "subfretarei": "subfretar",
    "subfretareis": "subfretar",
    "subfretarem": "subfretar",
    "subfretaremos": "subfretar",
    "subfretares": "subfretar",
    "subfretaria": "subfretar",
    "subfretariam": "subfretar",
    "subfretarias": "subfretar",
    "subfretarmo": "subfretar",
    "subfretarmos": "subfretar",
    "subfretará": "subfretar",
    "subfretarás": "subfretar",
    "subfretarão": "subfretar",
    "subfretaríamos": "subfretar",
    "subfretaríeis": "subfretar",
    "subfretas": "subfretar",
    "subfretasse": "subfretar",
    "subfretassem": "subfretar",
    "subfretasses": "subfretar",
    "subfretaste": "subfretar",
    "subfretastes": "subfretar",
    "subfretava": "subfretar",
    "subfretavam": "subfretar",
    "subfretavas": "subfretar",
    "subfrete": "subfretar",
    "subfretei": "subfretar",
    "subfreteis": "subfretar",
    "subfretem": "subfretar",
    "subfretemo": "subfretar",
    "subfretemos": "subfretar",
    "subfretes": "subfretar",
    "subfreto": "subfretar",
    "subfretou": "subfretar",
    "subfretá": "subfretar",
    "subfretámo": "subfretar",
    "subfretámos": "subfretar",
    "subfretáramo": "subfretar",
    "subfretáramos": "subfretar",
    "subfretárei": "subfretar",
    "subfretáreis": "subfretar",
    "subfretásseis": "subfretar",
    "subfretássemos": "subfretar",
    "subfretávamo": "subfretar",
    "subfretávamos": "subfretar",
    "subfretávei": "subfretar",
    "subfretáveis": "subfretar",
    "subgemípara": "subgemíparo",
    "subgemíparas": "subgemíparo",
    "subgemíparos": "subgemíparo",
    "subgerentes": "subgerente",
    "subglabra": "subglabro",
    "subglabras": "subglabro",
    "subglabros": "subglabro",
    "subglobosa": "subgloboso",
    "subglobosas": "subgloboso",
    "subglobosos": "subgloboso",
    "subgraves": "subgrave",
    "subgrupos": "subgrupo",
    "subgéneros": "subgénero",
    "subi": "subir",
    "subia": "subir",
    "subiam": "subir",
    "subias": "subir",
    "subida": "subir",
    "subidas": "subir",
    "subidazinha": "subido",
    "subidazinhas": "subido",
    "subidazita": "subido",
    "subidazitas": "subido",
    "subideiras": "subideira",
    "subidinha": "subido",
    "subidinhas": "subido",
    "subidinho": "subido",
    "subidinhos": "subido",
    "subidita": "subido",
    "subiditas": "subido",
    "subidito": "subido",
    "subiditos": "subido",
    "subido": "subir",
    "subidos": "subir",
    "subidouros": "subidouro",
    "subidozinho": "subido",
    "subidozinhos": "subido",
    "subidozito": "subido",
    "subidozitos": "subido",
    "subidíssima": "subido",
    "subidíssimas": "subido",
    "subidíssimo": "subido",
    "subidíssimos": "subido",
    "subimentos": "subimento",
    "subimo": "subir",
    "subimos": "subir",
    "subindo": "subir",
    "subinflamatória": "subinflamatório",
    "subinflamatórias": "subinflamatório",
    "subinflamatórios": "subinflamatório",
    "subinflamações": "subinflamação",
    "subinspectora": "subinspector",
    "subinspectoras": "subinspector",
    "subinspectores": "subinspector",
    "subinspectorias": "subinspectoria",
    "subintenda": "subintender",
    "subintendais": "subintender",
    "subintendam": "subintender",
    "subintendamo": "subintender",
    "subintendamos": "subintender",
    "subintendas": "subintender",
    "subintende": "subintender",
    "subintendei": "subintender",
    "subintendeis": "subintender",
    "subintendem": "subintender",
    "subintendemo": "subintender",
    "subintendemos": "subintender",
    "subintendendo": "subintender",
    "subintendentes": "subintendente",
    "subintendera": "subintender",
    "subintenderam": "subintender",
    "subintenderas": "subintender",
    "subintenderdes": "subintender",
    "subintenderei": "subintender",
    "subintendereis": "subintender",
    "subintenderem": "subintender",
    "subintenderemos": "subintender",
    "subintenderes": "subintender",
    "subintenderia": "subintender",
    "subintenderiam": "subintender",
    "subintenderias": "subintender",
    "subintendermo": "subintender",
    "subintendermos": "subintender",
    "subintenderá": "subintender",
    "subintenderás": "subintender",
    "subintenderão": "subintender",
    "subintenderíamos": "subintender",
    "subintenderíeis": "subintender",
    "subintendes": "subintender",
    "subintendesse": "subintender",
    "subintendessem": "subintender",
    "subintendesses": "subintender",
    "subintendeste": "subintender",
    "subintendestes": "subintender",
    "subintendeu": "subintender",
    "subintendi": "subintender",
    "subintendia": "subintender",
    "subintendiam": "subintender",
    "subintendias": "subintender",
    "subintendida": "subintender",
    "subintendidas": "subintender",
    "subintendido": "subintender",
    "subintendidos": "subintender",
    "subintendo": "subintender",
    "subintendências": "subintendência",
    "subintendêramo": "subintender",
    "subintendêramos": "subintender",
    "subintendêreis": "subintender",
    "subintendêsseis": "subintender",
    "subintendêssemos": "subintender",
    "subintendíamo": "subintender",
    "subintendíamos": "subintender",
    "subintendíeis": "subintender",
    "subintervalos": "subintervalo",
    "subintes": "subinte",
    "subintitula": "subintitular",
    "subintitulada": "subintitular",
    "subintituladas": "subintitular",
    "subintitulado": "subintitular",
    "subintitulados": "subintitular",
    "subintitulai": "subintitular",
    "subintitulais": "subintitular",
    "subintitulam": "subintitular",
    "subintitulamo": "subintitular",
    "subintitulamos": "subintitular",
    "subintitulando": "subintitular",
    "subintitulara": "subintitular",
    "subintitularam": "subintitular",
    "subintitularas": "subintitular",
    "subintitularde": "subintitular",
    "subintitulardes": "subintitular",
    "subintitulare": "subintitular",
    "subintitularei": "subintitular",
    "subintitulareis": "subintitular",
    "subintitularem": "subintitular",
    "subintitularemos": "subintitular",
    "subintitulares": "subintitular",
    "subintitularia": "subintitular",
    "subintitulariam": "subintitular",
    "subintitularias": "subintitular",
    "subintitularmo": "subintitular",
    "subintitularmos": "subintitular",
    "subintitulará": "subintitular",
    "subintitularás": "subintitular",
    "subintitularão": "subintitular",
    "subintitularíamos": "subintitular",
    "subintitularíeis": "subintitular",
    "subintitulas": "subintitular",
    "subintitulasse": "subintitular",
    "subintitulassem": "subintitular",
    "subintitulasses": "subintitular",
    "subintitulaste": "subintitular",
    "subintitulastes": "subintitular",
    "subintitulava": "subintitular",
    "subintitulavam": "subintitular",
    "subintitulavas": "subintitular",
    "subintitule": "subintitular",
    "subintitulei": "subintitular",
    "subintituleis": "subintitular",
    "subintitulem": "subintitular",
    "subintitulemo": "subintitular",
    "subintitulemos": "subintitular",
    "subintitules": "subintitular",
    "subintitulo": "subintitular",
    "subintitulou": "subintitular",
    "subintitulá": "subintitular",
    "subintitulámo": "subintitular",
    "subintitulámos": "subintitular",
    "subintituláramo": "subintitular",
    "subintituláramos": "subintitular",
    "subintitulárei": "subintitular",
    "subintituláreis": "subintitular",
    "subintitulásseis": "subintitular",
    "subintitulássemos": "subintitular",
    "subintitulávamo": "subintitular",
    "subintitulávamos": "subintitular",
    "subintitulávei": "subintitular",
    "subintituláveis": "subintitular",
    "subira": "subir",
    "subiram": "subir",
    "subiras": "subir",
    "subirde": "subir",
    "subirdes": "subir",
    "subire": "subir",
    "subirei": "subir",
    "subireis": "subir",
    "subirem": "subir",
    "subiremos": "subir",
    "subires": "subir",
    "subiria": "subir",
    "subiriam": "subir",
    "subirias": "subir",
    "subirmo": "subir",
    "subirmos": "subir",
    "subirá": "subir",
    "subirás": "subir",
    "subirão": "subir",
    "subiríamos": "subir",
    "subiríeis": "subir",
    "subis": "subir",
    "subisse": "subir",
    "subissem": "subir",
    "subisses": "subir",
    "subiste": "subir",
    "subistes": "subir",
    "subitaneidades": "subitaneidade",
    "subitânea": "subitâneo",
    "subitâneas": "subitâneo",
    "subitâneos": "subitâneo",
    "subiu": "subir",
    "subjacentes": "subjacente",
    "subjaz": "subjazer",
    "subjaza": "subjazer",
    "subjazais": "subjazer",
    "subjazam": "subjazer",
    "subjazamo": "subjazer",
    "subjazamos": "subjazer",
    "subjazas": "subjazer",
    "subjaze": "subjazer",
    "subjazei": "subjazer",
    "subjazeis": "subjazer",
    "subjazem": "subjazer",
    "subjazemo": "subjazer",
    "subjazemos": "subjazer",
    "subjazendo": "subjazer",
    "subjazera": "subjazer",
    "subjazeram": "subjazer",
    "subjazeras": "subjazer",
    "subjazerdes": "subjazer",
    "subjazerei": "subjazer",
    "subjazereis": "subjazer",
    "subjazerem": "subjazer",
    "subjazeremos": "subjazer",
    "subjazeres": "subjazer",
    "subjazeria": "subjazer",
    "subjazeriam": "subjazer",
    "subjazerias": "subjazer",
    "subjazermo": "subjazer",
    "subjazermos": "subjazer",
    "subjazerá": "subjazer",
    "subjazerás": "subjazer",
    "subjazerão": "subjazer",
    "subjazeríamos": "subjazer",
    "subjazeríeis": "subjazer",
    "subjazes": "subjazer",
    "subjazesse": "subjazer",
    "subjazessem": "subjazer",
    "subjazesses": "subjazer",
    "subjazeste": "subjazer",
    "subjazestes": "subjazer",
    "subjazeu": "subjazer",
    "subjazi": "subjazer",
    "subjazia": "subjazer",
    "subjaziam": "subjazer",
    "subjazias": "subjazer",
    "subjazida": "subjazer",
    "subjazidas": "subjazer",
    "subjazido": "subjazer",
    "subjazidos": "subjazer",
    "subjazo": "subjazer",
    "subjazêramo": "subjazer",
    "subjazêramos": "subjazer",
    "subjazêreis": "subjazer",
    "subjazêsseis": "subjazer",
    "subjazêssemos": "subjazer",
    "subjazíamo": "subjazer",
    "subjazíamos": "subjazer",
    "subjazíeis": "subjazer",
    "subjectiva": "subjectivo",
    "subjectivada": "subjectivar",
    "subjectivadas": "subjectivar",
    "subjectivado": "subjectivar",
    "subjectivados": "subjectivar",
    "subjectivai": "subjectivar",
    "subjectivais": "subjectivar",
    "subjectivam": "subjectivar",
    "subjectivamo": "subjectivar",
    "subjectivamos": "subjectivar",
    "subjectivando": "subjectivar",
    "subjectivara": "subjectivar",
    "subjectivaram": "subjectivar",
    "subjectivaras": "subjectivar",
    "subjectivarde": "subjectivar",
    "subjectivardes": "subjectivar",
    "subjectivare": "subjectivar",
    "subjectivarei": "subjectivar",
    "subjectivareis": "subjectivar",
    "subjectivarem": "subjectivar",
    "subjectivaremos": "subjectivar",
    "subjectivares": "subjectivar",
    "subjectivaria": "subjectivar",
    "subjectivariam": "subjectivar",
    "subjectivarias": "subjectivar",
    "subjectivarmo": "subjectivar",
    "subjectivarmos": "subjectivar",
    "subjectivará": "subjectivar",
    "subjectivarás": "subjectivar",
    "subjectivarão": "subjectivar",
    "subjectivaríamos": "subjectivar",
    "subjectivaríeis": "subjectivar",
    "subjectivas": "subjectivo",
    "subjectivasse": "subjectivar",
    "subjectivassem": "subjectivar",
    "subjectivasses": "subjectivar",
    "subjectivaste": "subjectivar",
    "subjectivastes": "subjectivar",
    "subjectivava": "subjectivar",
    "subjectivavam": "subjectivar",
    "subjectivavas": "subjectivar",
    "subjectivações": "subjectivação",
    "subjective": "subjectivar",
    "subjectivei": "subjectivar",
    "subjectiveis": "subjectivar",
    "subjectivem": "subjectivar",
    "subjectivemo": "subjectivar",
    "subjectivemos": "subjectivar",
    "subjectives": "subjectivar",
    "subjectividades": "subjectividade",
    "subjectivismos": "subjectivismo",
    "subjectivistas": "subjectivista",
    "subjectivo": "subjectivar",
    "subjectivos": "subjectivo",
    "subjectivou": "subjectivar",
    "subjectivá": "subjectivar",
    "subjectivámo": "subjectivar",
    "subjectivámos": "subjectivar",
    "subjectiváramo": "subjectivar",
    "subjectiváramos": "subjectivar",
    "subjectivárei": "subjectivar",
    "subjectiváreis": "subjectivar",
    "subjectivásseis": "subjectivar",
    "subjectivássemos": "subjectivar",
    "subjectivávamo": "subjectivar",
    "subjectivávamos": "subjectivar",
    "subjectivávei": "subjectivar",
    "subjectiváveis": "subjectivar",
    "subjecções": "subjecção",
    "subjuga": "subjugar",
    "subjugada": "subjugar",
    "subjugadas": "subjugar",
    "subjugado": "subjugar",
    "subjugadora": "subjugador",
    "subjugadoras": "subjugador",
    "subjugadores": "subjugador",
    "subjugados": "subjugar",
    "subjugai": "subjugar",
    "subjugais": "subjugar",
    "subjugam": "subjugar",
    "subjugamo": "subjugar",
    "subjugamos": "subjugar",
    "subjugando": "subjugar",
    "subjugantes": "subjugante",
    "subjugara": "subjugar",
    "subjugaram": "subjugar",
    "subjugaras": "subjugar",
    "subjugarde": "subjugar",
    "subjugardes": "subjugar",
    "subjugare": "subjugar",
    "subjugarei": "subjugar",
    "subjugareis": "subjugar",
    "subjugarem": "subjugar",
    "subjugaremos": "subjugar",
    "subjugares": "subjugar",
    "subjugaria": "subjugar",
    "subjugariam": "subjugar",
    "subjugarias": "subjugar",
    "subjugarmo": "subjugar",
    "subjugarmos": "subjugar",
    "subjugará": "subjugar",
    "subjugarás": "subjugar",
    "subjugarão": "subjugar",
    "subjugaríamos": "subjugar",
    "subjugaríeis": "subjugar",
    "subjugas": "subjugar",
    "subjugasse": "subjugar",
    "subjugassem": "subjugar",
    "subjugasses": "subjugar",
    "subjugaste": "subjugar",
    "subjugastes": "subjugar",
    "subjugava": "subjugar",
    "subjugavam": "subjugar",
    "subjugavas": "subjugar",
    "subjugações": "subjugação",
    "subjugo": "subjugar",
    "subjugou": "subjugar",
    "subjugue": "subjugar",
    "subjuguei": "subjugar",
    "subjugueis": "subjugar",
    "subjuguem": "subjugar",
    "subjuguemo": "subjugar",
    "subjuguemos": "subjugar",
    "subjugues": "subjugar",
    "subjugá": "subjugar",
    "subjugámo": "subjugar",
    "subjugámos": "subjugar",
    "subjugáramo": "subjugar",
    "subjugáramos": "subjugar",
    "subjugárei": "subjugar",
    "subjugáreis": "subjugar",
    "subjugásseis": "subjugar",
    "subjugássemos": "subjugar",
    "subjugávamo": "subjugar",
    "subjugávamos": "subjugar",
    "subjugávei": "subjugar",
    "subjugáveis": "subjugar",
    "subjuntiva": "subjuntivo",
    "subjuntivas": "subjuntivo",
    "subjuntivos": "subjuntivo",
    "subjunções": "subjunção",
    "sublacustres": "sublacustre",
    "sublanços": "sublanço",
    "sublegendas": "sublegenda",
    "subleitos": "subleito",
    "sublenhosa": "sublenhoso",
    "sublenhosas": "sublenhoso",
    "sublenhosos": "sublenhoso",
    "subleva": "sublevar",
    "sublevada": "sublevar",
    "sublevadas": "sublevar",
    "sublevado": "sublevar",
    "sublevadora": "sublevador",
    "sublevadoras": "sublevador",
    "sublevadores": "sublevador",
    "sublevados": "sublevar",
    "sublevai": "sublevar",
    "sublevais": "sublevar",
    "sublevam": "sublevar",
    "sublevamo": "sublevar",
    "sublevamos": "sublevar",
    "sublevando": "sublevar",
    "sublevanta": "sublevantar",
    "sublevantada": "sublevantar",
    "sublevantadas": "sublevantar",
    "sublevantado": "sublevantar",
    "sublevantados": "sublevantar",
    "sublevantai": "sublevantar",
    "sublevantais": "sublevantar",
    "sublevantam": "sublevantar",
    "sublevantamentos": "sublevantamento",
    "sublevantamo": "sublevantar",
    "sublevantamos": "sublevantar",
    "sublevantando": "sublevantar",
    "sublevantara": "sublevantar",
    "sublevantaram": "sublevantar",
    "sublevantaras": "sublevantar",
    "sublevantarde": "sublevantar",
    "sublevantardes": "sublevantar",
    "sublevantare": "sublevantar",
    "sublevantarei": "sublevantar",
    "sublevantareis": "sublevantar",
    "sublevantarem": "sublevantar",
    "sublevantaremos": "sublevantar",
    "sublevantares": "sublevantar",
    "sublevantaria": "sublevantar",
    "sublevantariam": "sublevantar",
    "sublevantarias": "sublevantar",
    "sublevantarmo": "sublevantar",
    "sublevantarmos": "sublevantar",
    "sublevantará": "sublevantar",
    "sublevantarás": "sublevantar",
    "sublevantarão": "sublevantar",
    "sublevantaríamos": "sublevantar",
    "sublevantaríeis": "sublevantar",
    "sublevantas": "sublevantar",
    "sublevantasse": "sublevantar",
    "sublevantassem": "sublevantar",
    "sublevantasses": "sublevantar",
    "sublevantaste": "sublevantar",
    "sublevantastes": "sublevantar",
    "sublevantava": "sublevantar",
    "sublevantavam": "sublevantar",
    "sublevantavas": "sublevantar",
    "sublevante": "sublevantar",
    "sublevantei": "sublevantar",
    "sublevanteis": "sublevantar",
    "sublevantem": "sublevantar",
    "sublevantemo": "sublevantar",
    "sublevantemos": "sublevantar",
    "sublevantes": "sublevantar",
    "sublevanto": "sublevantar",
    "sublevantou": "sublevantar",
    "sublevantá": "sublevantar",
    "sublevantámo": "sublevantar",
    "sublevantámos": "sublevantar",
    "sublevantáramo": "sublevantar",
    "sublevantáramos": "sublevantar",
    "sublevantárei": "sublevantar",
    "sublevantáreis": "sublevantar",
    "sublevantásseis": "sublevantar",
    "sublevantássemos": "sublevantar",
    "sublevantávamo": "sublevantar",
    "sublevantávamos": "sublevantar",
    "sublevantávei": "sublevantar",
    "sublevantáveis": "sublevantar",
    "sublevara": "sublevar",
    "sublevaram": "sublevar",
    "sublevaras": "sublevar",
    "sublevarde": "sublevar",
    "sublevardes": "sublevar",
    "sublevare": "sublevar",
    "sublevarei": "sublevar",
    "sublevareis": "sublevar",
    "sublevarem": "sublevar",
    "sublevaremos": "sublevar",
    "sublevares": "sublevar",
    "sublevaria": "sublevar",
    "sublevariam": "sublevar",
    "sublevarias": "sublevar",
    "sublevarmo": "sublevar",
    "sublevarmos": "sublevar",
    "sublevará": "sublevar",
    "sublevarás": "sublevar",
    "sublevarão": "sublevar",
    "sublevaríamos": "sublevar",
    "sublevaríeis": "sublevar",
    "sublevas": "sublevar",
    "sublevasse": "sublevar",
    "sublevassem": "sublevar",
    "sublevasses": "sublevar",
    "sublevaste": "sublevar",
    "sublevastes": "sublevar",
    "sublevava": "sublevar",
    "sublevavam": "sublevar",
    "sublevavas": "sublevar",
    "sublevações": "sublevação",
    "subleve": "sublevar",
    "sublevei": "sublevar",
    "subleveis": "sublevar",
    "sublevem": "sublevar",
    "sublevemo": "sublevar",
    "sublevemos": "sublevar",
    "subleves": "sublevar",
    "sublevo": "sublevar",
    "sublevou": "sublevar",
    "sublevá": "sublevar",
    "sublevámo": "sublevar",
    "sublevámos": "sublevar",
    "subleváramo": "sublevar",
    "subleváramos": "sublevar",
    "sublevárei": "sublevar",
    "subleváreis": "sublevar",
    "sublevásseis": "sublevar",
    "sublevássemos": "sublevar",
    "sublevávamo": "sublevar",
    "sublevávamos": "sublevar",
    "sublevávei": "sublevar",
    "subleváveis": "sublevar",
    "sublima": "sublimar",
    "sublimada": "sublimar",
    "sublimadas": "sublimar",
    "sublimado": "sublimar",
    "sublimados": "sublimar",
    "sublimai": "sublimar",
    "sublimais": "sublimar",
    "sublimam": "sublimar",
    "sublimamo": "sublimar",
    "sublimamos": "sublimar",
    "sublimando": "sublimar",
    "sublimara": "sublimar",
    "sublimaram": "sublimar",
    "sublimaras": "sublimar",
    "sublimarde": "sublimar",
    "sublimardes": "sublimar",
    "sublimare": "sublimar",
    "sublimarei": "sublimar",
    "sublimareis": "sublimar",
    "sublimarem": "sublimar",
    "sublimaremos": "sublimar",
    "sublimares": "sublimar",
    "sublimaria": "sublimar",
    "sublimariam": "sublimar",
    "sublimarias": "sublimar",
    "sublimarmo": "sublimar",
    "sublimarmos": "sublimar",
    "sublimará": "sublimar",
    "sublimarás": "sublimar",
    "sublimarão": "sublimar",
    "sublimaríamos": "sublimar",
    "sublimaríeis": "sublimar",
    "sublimas": "sublimar",
    "sublimasse": "sublimar",
    "sublimassem": "sublimar",
    "sublimasses": "sublimar",
    "sublimaste": "sublimar",
    "sublimastes": "sublimar",
    "sublimativa": "sublimativo",
    "sublimativas": "sublimativo",
    "sublimativos": "sublimativo",
    "sublimatória": "sublimatório",
    "sublimatórias": "sublimatório",
    "sublimatórios": "sublimatório",
    "sublimava": "sublimar",
    "sublimavam": "sublimar",
    "sublimavas": "sublimar",
    "sublimações": "sublimação",
    "sublime": "sublimar",
    "sublimei": "sublimar",
    "sublimeis": "sublimar",
    "sublimem": "sublimar",
    "sublimemo": "sublimar",
    "sublimemos": "sublimar",
    "sublimes": "sublime",
    "sublimidades": "sublimidade",
    "subliminais": "subliminal",
    "subliminares": "subliminar",
    "sublimo": "sublimar",
    "sublimou": "sublimar",
    "sublimá": "sublimar",
    "sublimámo": "sublimar",
    "sublimámos": "sublimar",
    "sublimáramo": "sublimar",
    "sublimáramos": "sublimar",
    "sublimárei": "sublimar",
    "sublimáreis": "sublimar",
    "sublimásseis": "sublimar",
    "sublimássemos": "sublimar",
    "sublimávamo": "sublimar",
    "sublimávamos": "sublimar",
    "sublimávei": "sublimar",
    "sublimáveis": "sublimável",
    "sublineares": "sublinear",
    "sublinguais": "sublingual",
    "sublinha": "sublinhar",
    "sublinhada": "sublinhar",
    "sublinhadas": "sublinhar",
    "sublinhado": "sublinhar",
    "sublinhados": "sublinhar",
    "sublinhai": "sublinhar",
    "sublinhais": "sublinhar",
    "sublinham": "sublinhar",
    "sublinhamo": "sublinhar",
    "sublinhamos": "sublinhar",
    "sublinhando": "sublinhar",
    "sublinhara": "sublinhar",
    "sublinharam": "sublinhar",
    "sublinharas": "sublinhar",
    "sublinharde": "sublinhar",
    "sublinhardes": "sublinhar",
    "sublinhare": "sublinhar",
    "sublinharei": "sublinhar",
    "sublinhareis": "sublinhar",
    "sublinharem": "sublinhar",
    "sublinharemos": "sublinhar",
    "sublinhares": "sublinhar",
    "sublinharia": "sublinhar",
    "sublinhariam": "sublinhar",
    "sublinharias": "sublinhar",
    "sublinharmo": "sublinhar",
    "sublinharmos": "sublinhar",
    "sublinhará": "sublinhar",
    "sublinharás": "sublinhar",
    "sublinharão": "sublinhar",
    "sublinharíamos": "sublinhar",
    "sublinharíeis": "sublinhar",
    "sublinhas": "sublinhar",
    "sublinhasse": "sublinhar",
    "sublinhassem": "sublinhar",
    "sublinhasses": "sublinhar",
    "sublinhaste": "sublinhar",
    "sublinhastes": "sublinhar",
    "sublinhava": "sublinhar",
    "sublinhavam": "sublinhar",
    "sublinhavas": "sublinhar",
    "sublinhe": "sublinhar",
    "sublinhei": "sublinhar",
    "sublinheis": "sublinhar",
    "sublinhem": "sublinhar",
    "sublinhemo": "sublinhar",
    "sublinhemos": "sublinhar",
    "sublinhes": "sublinhar",
    "sublinho": "sublinhar",
    "sublinhou": "sublinhar",
    "sublinhá": "sublinhar",
    "sublinhámo": "sublinhar",
    "sublinhámos": "sublinhar",
    "sublinháramo": "sublinhar",
    "sublinháramos": "sublinhar",
    "sublinhárei": "sublinhar",
    "sublinháreis": "sublinhar",
    "sublinhásseis": "sublinhar",
    "sublinhássemos": "sublinhar",
    "sublinhávamo": "sublinhar",
    "sublinhávamos": "sublinhar",
    "sublinhávei": "sublinhar",
    "sublinháveis": "sublinhar",
    "subliterata": "subliterato",
    "subliteratas": "subliterato",
    "subliteratos": "subliterato",
    "subliteraturas": "subliteratura",
    "subloca": "sublocar",
    "sublocada": "sublocar",
    "sublocadas": "sublocar",
    "sublocado": "sublocar",
    "sublocadora": "sublocador",
    "sublocadoras": "sublocador",
    "sublocadores": "sublocador",
    "sublocados": "sublocar",
    "sublocai": "sublocar",
    "sublocais": "sublocar",
    "sublocam": "sublocar",
    "sublocamo": "sublocar",
    "sublocamos": "sublocar",
    "sublocando": "sublocar",
    "sublocara": "sublocar",
    "sublocaram": "sublocar",
    "sublocaras": "sublocar",
    "sublocarde": "sublocar",
    "sublocardes": "sublocar",
    "sublocare": "sublocar",
    "sublocarei": "sublocar",
    "sublocareis": "sublocar",
    "sublocarem": "sublocar",
    "sublocaremos": "sublocar",
    "sublocares": "sublocar",
    "sublocaria": "sublocar",
    "sublocariam": "sublocar",
    "sublocarias": "sublocar",
    "sublocarmo": "sublocar",
    "sublocarmos": "sublocar",
    "sublocará": "sublocar",
    "sublocarás": "sublocar",
    "sublocarão": "sublocar",
    "sublocaríamos": "sublocar",
    "sublocaríeis": "sublocar",
    "sublocas": "sublocar",
    "sublocasse": "sublocar",
    "sublocassem": "sublocar",
    "sublocasses": "sublocar",
    "sublocaste": "sublocar",
    "sublocastes": "sublocar",
    "sublocatária": "sublocatário",
    "sublocatárias": "sublocatário",
    "sublocatários": "sublocatário",
    "sublocava": "sublocar",
    "sublocavam": "sublocar",
    "sublocavas": "sublocar",
    "sublocações": "sublocação",
    "subloco": "sublocar",
    "sublocou": "sublocar",
    "sublocá": "sublocar",
    "sublocámo": "sublocar",
    "sublocámos": "sublocar",
    "sublocáramo": "sublocar",
    "sublocáramos": "sublocar",
    "sublocárei": "sublocar",
    "sublocáreis": "sublocar",
    "sublocásseis": "sublocar",
    "sublocássemos": "sublocar",
    "sublocávamo": "sublocar",
    "sublocávamos": "sublocar",
    "sublocávei": "sublocar",
    "sublocáveis": "sublocar",
    "subloque": "sublocar",
    "subloquei": "sublocar",
    "subloqueis": "sublocar",
    "subloquem": "sublocar",
    "subloquemo": "sublocar",
    "subloquemos": "sublocar",
    "subloques": "sublocar",
    "subluminosidades": "subluminosidade",
    "sublunares": "sublunar",
    "subluxações": "subluxação",
    "submandatária": "submandatário",
    "submandatárias": "submandatário",
    "submandatários": "submandatário",
    "submarina": "submarino",
    "submarinas": "submarino",
    "submarinhos": "submarinho",
    "submarinistas": "submarinista",
    "submarinos": "submarino",
    "submatas": "submata",
    "submaxilares": "submaxilar",
    "submedidas": "submedida",
    "submentais": "submental",
    "submerge": "submergir",
    "submergem": "submergir",
    "submerges": "submergir",
    "submergi": "submergir",
    "submergia": "submergir",
    "submergiam": "submergir",
    "submergias": "submergir",
    "submergida": "submergir",
    "submergidas": "submergir",
    "submergido": "submergir",
    "submergidos": "submergir",
    "submergimo": "submergir",
    "submergimos": "submergir",
    "submergindo": "submergir",
    "submergira": "submergir",
    "submergiram": "submergir",
    "submergiras": "submergir",
    "submergirde": "submergir",
    "submergirdes": "submergir",
    "submergire": "submergir",
    "submergirei": "submergir",
    "submergireis": "submergir",
    "submergirem": "submergir",
    "submergiremos": "submergir",
    "submergires": "submergir",
    "submergiria": "submergir",
    "submergiriam": "submergir",
    "submergirias": "submergir",
    "submergirmo": "submergir",
    "submergirmos": "submergir",
    "submergirá": "submergir",
    "submergirás": "submergir",
    "submergirão": "submergir",
    "submergiríamos": "submergir",
    "submergiríeis": "submergir",
    "submergis": "submergir",
    "submergisse": "submergir",
    "submergissem": "submergir",
    "submergisses": "submergir",
    "submergiste": "submergir",
    "submergistes": "submergir",
    "submergiu": "submergir",
    "submergíamo": "submergir",
    "submergíamos": "submergir",
    "submergíei": "submergir",
    "submergíeis": "submergir",
    "submergíramo": "submergir",
    "submergíramos": "submergir",
    "submergírei": "submergir",
    "submergíreis": "submergir",
    "submergísseis": "submergir",
    "submergíssemos": "submergir",
    "submergíveis": "submergível",
    "submersa": "submerso",
    "submersas": "submerso",
    "submersos": "submerso",
    "submersíveis": "submersível",
    "submersões": "submersão",
    "submeta": "submeter",
    "submetais": "submeter",
    "submetam": "submeter",
    "submetamo": "submeter",
    "submetamos": "submeter",
    "submetas": "submeter",
    "submete": "submeter",
    "submetei": "submeter",
    "submeteis": "submeter",
    "submetem": "submeter",
    "submetemo": "submeter",
    "submetemos": "submeter",
    "submetendo": "submeter",
    "submetera": "submeter",
    "submeteram": "submeter",
    "submeteras": "submeter",
    "submeterde": "submeter",
    "submeterdes": "submeter",
    "submetere": "submeter",
    "submeterei": "submeter",
    "submetereis": "submeter",
    "submeterem": "submeter",
    "submeteremos": "submeter",
    "submeteres": "submeter",
    "submeteria": "submeter",
    "submeteriam": "submeter",
    "submeterias": "submeter",
    "submetermo": "submeter",
    "submetermos": "submeter",
    "submeterá": "submeter",
    "submeterás": "submeter",
    "submeterão": "submeter",
    "submeteríamos": "submeter",
    "submeteríeis": "submeter",
    "submetes": "submeter",
    "submetesse": "submeter",
    "submetessem": "submeter",
    "submetesses": "submeter",
    "submeteste": "submeter",
    "submetestes": "submeter",
    "submeteu": "submeter",
    "submeti": "submeter",
    "submetia": "submeter",
    "submetiam": "submeter",
    "submetias": "submeter",
    "submetida": "submetido",
    "submetidas": "submetido",
    "submetido": "submeter",
    "submetidos": "submetido",
    "submetimentos": "submetimento",
    "submeto": "submeter",
    "submetralhadoras": "submetralhadora",
    "submetê": "submeter",
    "submetêramo": "submeter",
    "submetêramos": "submeter",
    "submetêrei": "submeter",
    "submetêreis": "submeter",
    "submetêsseis": "submeter",
    "submetêssemos": "submeter",
    "submetíamo": "submeter",
    "submetíamos": "submeter",
    "submetíei": "submeter",
    "submetíeis": "submeter",
    "subministra": "subministro",
    "subministrada": "subministrar",
    "subministradas": "subministrar",
    "subministrado": "subministrar",
    "subministradora": "subministrador",
    "subministradoras": "subministrador",
    "subministradores": "subministrador",
    "subministrados": "subministrar",
    "subministrai": "subministrar",
    "subministrais": "subministrar",
    "subministram": "subministrar",
    "subministramo": "subministrar",
    "subministramos": "subministrar",
    "subministrando": "subministrar",
    "subministrara": "subministrar",
    "subministraram": "subministrar",
    "subministraras": "subministrar",
    "subministrarde": "subministrar",
    "subministrardes": "subministrar",
    "subministrare": "subministrar",
    "subministrarei": "subministrar",
    "subministrareis": "subministrar",
    "subministrarem": "subministrar",
    "subministraremos": "subministrar",
    "subministrares": "subministrar",
    "subministraria": "subministrar",
    "subministrariam": "subministrar",
    "subministrarias": "subministrar",
    "subministrarmo": "subministrar",
    "subministrarmos": "subministrar",
    "subministrará": "subministrar",
    "subministrarás": "subministrar",
    "subministrarão": "subministrar",
    "subministraríamos": "subministrar",
    "subministraríeis": "subministrar",
    "subministras": "subministro",
    "subministrasse": "subministrar",
    "subministrassem": "subministrar",
    "subministrasses": "subministrar",
    "subministraste": "subministrar",
    "subministrastes": "subministrar",
    "subministrava": "subministrar",
    "subministravam": "subministrar",
    "subministravas": "subministrar",
    "subministrações": "subministração",
    "subministre": "subministrar",
    "subministrei": "subministrar",
    "subministreis": "subministrar",
    "subministrem": "subministrar",
    "subministremo": "subministrar",
    "subministremos": "subministrar",
    "subministres": "subministrar",
    "subministro": "subministrar",
    "subministros": "subministro",
    "subministrou": "subministrar",
    "subministrá": "subministrar",
    "subministrámo": "subministrar",
    "subministrámos": "subministrar",
    "subministráramo": "subministrar",
    "subministráramos": "subministrar",
    "subministrárei": "subministrar",
    "subministráreis": "subministrar",
    "subministrásseis": "subministrar",
    "subministrássemos": "subministrar",
    "subministrávamo": "subministrar",
    "subministrávamos": "subministrar",
    "subministrávei": "subministrar",
    "subministráveis": "subministrar",
    "submirja": "submergir",
    "submirjais": "submergir",
    "submirjam": "submergir",
    "submirjamo": "submergir",
    "submirjamos": "submergir",
    "submirjas": "submergir",
    "submirjo": "submergir",
    "submissa": "submisso",
    "submissas": "submisso",
    "submissos": "submisso",
    "submissões": "submissão",
    "submundos": "submundo",
    "submúltipla": "submúltiplo",
    "submúltiplas": "submúltiplo",
    "submúltiplos": "submúltiplo",
    "subnasais": "subnasal",
    "subnega": "subnegar",
    "subnegada": "subnegar",
    "subnegadas": "subnegar",
    "subnegado": "subnegar",
    "subnegados": "subnegar",
    "subnegai": "subnegar",
    "subnegais": "subnegar",
    "subnegam": "subnegar",
    "subnegamo": "subnegar",
    "subnegamos": "subnegar",
    "subnegando": "subnegar",
    "subnegara": "subnegar",
    "subnegaram": "subnegar",
    "subnegaras": "subnegar",
    "subnegarde": "subnegar",
    "subnegardes": "subnegar",
    "subnegare": "subnegar",
    "subnegarei": "subnegar",
    "subnegareis": "subnegar",
    "subnegarem": "subnegar",
    "subnegaremos": "subnegar",
    "subnegares": "subnegar",
    "subnegaria": "subnegar",
    "subnegariam": "subnegar",
    "subnegarias": "subnegar",
    "subnegarmo": "subnegar",
    "subnegarmos": "subnegar",
    "subnegará": "subnegar",
    "subnegarás": "subnegar",
    "subnegarão": "subnegar",
    "subnegaríamos": "subnegar",
    "subnegaríeis": "subnegar",
    "subnegas": "subnegar",
    "subnegasse": "subnegar",
    "subnegassem": "subnegar",
    "subnegasses": "subnegar",
    "subnegaste": "subnegar",
    "subnegastes": "subnegar",
    "subnegava": "subnegar",
    "subnegavam": "subnegar",
    "subnegavas": "subnegar",
    "subnego": "subnegar",
    "subnegou": "subnegar",
    "subnegue": "subnegar",
    "subneguei": "subnegar",
    "subnegueis": "subnegar",
    "subneguem": "subnegar",
    "subneguemo": "subnegar",
    "subneguemos": "subnegar",
    "subnegues": "subnegar",
    "subnegá": "subnegar",
    "subnegámo": "subnegar",
    "subnegámos": "subnegar",
    "subnegáramo": "subnegar",
    "subnegáramos": "subnegar",
    "subnegárei": "subnegar",
    "subnegáreis": "subnegar",
    "subnegásseis": "subnegar",
    "subnegássemos": "subnegar",
    "subnegávamo": "subnegar",
    "subnegávamos": "subnegar",
    "subnegávei": "subnegar",
    "subnegáveis": "subnegar",
    "subnornais": "subnornal",
    "subnutrida": "subnutrido",
    "subnutridas": "subnutrido",
    "subnutridos": "subnutrido",
    "subnutrições": "subnutrição",
    "subo": "subir",
    "suboccipitais": "suboccipital",
    "suboculares": "subocular",
    "suboficiais": "suboficial",
    "subordens": "subordem",
    "subordina": "subordinar",
    "subordinacionismos": "subordinacionismo",
    "subordinada": "subordinar",
    "subordinadas": "subordinar",
    "subordinadazinha": "subordinado",
    "subordinadazinhas": "subordinado",
    "subordinadazita": "subordinado",
    "subordinadazitas": "subordinado",
    "subordinado": "subordinar",
    "subordinadora": "subordinador",
    "subordinadoras": "subordinador",
    "subordinadores": "subordinador",
    "subordinados": "subordinar",
    "subordinadozinho": "subordinado",
    "subordinadozinhos": "subordinado",
    "subordinadozito": "subordinado",
    "subordinadozitos": "subordinado",
    "subordinai": "subordinar",
    "subordinais": "subordinar",
    "subordinam": "subordinar",
    "subordinamo": "subordinar",
    "subordinamos": "subordinar",
    "subordinando": "subordinar",
    "subordinantes": "subordinante",
    "subordinara": "subordinar",
    "subordinaram": "subordinar",
    "subordinaras": "subordinar",
    "subordinarde": "subordinar",
    "subordinardes": "subordinar",
    "subordinare": "subordinar",
    "subordinarei": "subordinar",
    "subordinareis": "subordinar",
    "subordinarem": "subordinar",
    "subordinaremos": "subordinar",
    "subordinares": "subordinar",
    "subordinaria": "subordinar",
    "subordinariam": "subordinar",
    "subordinarias": "subordinar",
    "subordinarmo": "subordinar",
    "subordinarmos": "subordinar",
    "subordinará": "subordinar",
    "subordinarás": "subordinar",
    "subordinarão": "subordinar",
    "subordinaríamos": "subordinar",
    "subordinaríeis": "subordinar",
    "subordinas": "subordinar",
    "subordinasse": "subordinar",
    "subordinassem": "subordinar",
    "subordinasses": "subordinar",
    "subordinaste": "subordinar",
    "subordinastes": "subordinar",
    "subordinativa": "subordinativo",
    "subordinativas": "subordinativo",
    "subordinativos": "subordinativo",
    "subordinava": "subordinar",
    "subordinavam": "subordinar",
    "subordinavas": "subordinar",
    "subordinações": "subordinação",
    "subordine": "subordinar",
    "subordinei": "subordinar",
    "subordineis": "subordinar",
    "subordinem": "subordinar",
    "subordinemo": "subordinar",
    "subordinemos": "subordinar",
    "subordines": "subordinar",
    "subordino": "subordinar",
    "subordinou": "subordinar",
    "subordiná": "subordinar",
    "subordinámo": "subordinar",
    "subordinámos": "subordinar",
    "subordináramo": "subordinar",
    "subordináramos": "subordinar",
    "subordinárei": "subordinar",
    "subordináreis": "subordinar",
    "subordinásseis": "subordinar",
    "subordinássemos": "subordinar",
    "subordinávamo": "subordinar",
    "subordinávamos": "subordinar",
    "subordinávei": "subordinar",
    "subordináveis": "subordinável",
    "suborna": "subornar",
    "subornada": "subornar",
    "subornadas": "subornar",
    "subornado": "subornar",
    "subornadora": "subornador",
    "subornadoras": "subornador",
    "subornadores": "subornador",
    "subornados": "subornar",
    "subornai": "subornar",
    "subornais": "subornar",
    "subornam": "subornar",
    "subornamentos": "subornamento",
    "subornamo": "subornar",
    "subornamos": "subornar",
    "subornando": "subornar",
    "subornara": "subornar",
    "subornaram": "subornar",
    "subornaras": "subornar",
    "subornarde": "subornar",
    "subornardes": "subornar",
    "subornare": "subornar",
    "subornarei": "subornar",
    "subornareis": "subornar",
    "subornarem": "subornar",
    "subornaremos": "subornar",
    "subornares": "subornar",
    "subornaria": "subornar",
    "subornariam": "subornar",
    "subornarias": "subornar",
    "subornarmo": "subornar",
    "subornarmos": "subornar",
    "subornará": "subornar",
    "subornarás": "subornar",
    "subornarão": "subornar",
    "subornaríamos": "subornar",
    "subornaríeis": "subornar",
    "subornas": "subornar",
    "subornasse": "subornar",
    "subornassem": "subornar",
    "subornasses": "subornar",
    "subornaste": "subornar",
    "subornastes": "subornar",
    "subornava": "subornar",
    "subornavam": "subornar",
    "subornavas": "subornar",
    "suborne": "subornar",
    "subornei": "subornar",
    "suborneis": "subornar",
    "subornem": "subornar",
    "subornemo": "subornar",
    "subornemos": "subornar",
    "subornes": "subornar",
    "suborno": "subornar",
    "subornos": "suborno",
    "subornou": "subornar",
    "suborná": "subornar",
    "subornámo": "subornar",
    "subornámos": "subornar",
    "subornáramo": "subornar",
    "subornáramos": "subornar",
    "subornárei": "subornar",
    "subornáreis": "subornar",
    "subornásseis": "subornar",
    "subornássemos": "subornar",
    "subornávamo": "subornar",
    "subornávamos": "subornar",
    "subornávei": "subornar",
    "subornáveis": "subornável",
    "subparágrafos": "subparágrafo",
    "subpolares": "subpolar",
    "subpomo": "subpor",
    "subpomos": "subpor",
    "subponde": "subpor",
    "subpondes": "subpor",
    "subpondo": "subpor",
    "subponha": "subpor",
    "subponhais": "subpor",
    "subponham": "subpor",
    "subponhamo": "subpor",
    "subponhamos": "subpor",
    "subponhas": "subpor",
    "subponho": "subpor",
    "subponíveis": "subponível",
    "subporde": "subpor",
    "subpordes": "subpor",
    "subpore": "subpor",
    "subporei": "subpor",
    "subporeis": "subpor",
    "subporem": "subpor",
    "subporemos": "subpor",
    "subpores": "subpor",
    "subporia": "subpor",
    "subporiam": "subpor",
    "subporias": "subpor",
    "subpormo": "subpor",
    "subpormos": "subpor",
    "subporá": "subpor",
    "subporás": "subpor",
    "subporão": "subpor",
    "subporíamos": "subpor",
    "subporíeis": "subpor",
    "subposta": "subpor",
    "subpostas": "subpor",
    "subposto": "subpor",
    "subpostos": "subpor",
    "subprefeita": "subprefeito",
    "subprefeitas": "subprefeito",
    "subprefeitos": "subprefeito",
    "subprefeituras": "subprefeitura",
    "subprocuradora": "subprocurador",
    "subprocuradoras": "subprocurador",
    "subprocuradores": "subprocurador",
    "subprodutos": "subproduto",
    "subprogramas": "subprograma",
    "subpromotora": "subpromotor",
    "subpromotoras": "subpromotor",
    "subpromotores": "subpromotor",
    "subpunha": "subpor",
    "subpunham": "subpor",
    "subpunhas": "subpor",
    "subpus": "subpor",
    "subpusemo": "subpor",
    "subpusemos": "subpor",
    "subpuser": "subpor",
    "subpusera": "subpor",
    "subpuseram": "subpor",
    "subpuseras": "subpor",
    "subpuserdes": "subpor",
    "subpuserem": "subpor",
    "subpuseres": "subpor",
    "subpusermos": "subpor",
    "subpusesse": "subpor",
    "subpusessem": "subpor",
    "subpusesses": "subpor",
    "subpuseste": "subpor",
    "subpusestes": "subpor",
    "subpuséramo": "subpor",
    "subpuséramos": "subpor",
    "subpusérei": "subpor",
    "subpuséreis": "subpor",
    "subpusésseis": "subpor",
    "subpuséssemos": "subpor",
    "subpô": "subpor",
    "subpôs": "subpor",
    "subpõe": "subpor",
    "subpõem": "subpor",
    "subpões": "subpor",
    "subpúnhamo": "subpor",
    "subpúnhamos": "subpor",
    "subpúnhei": "subpor",
    "subpúnheis": "subpor",
    "subsahariana": "subsahariano",
    "subsaharianas": "subsahariano",
    "subsaharianos": "subsahariano",
    "subsalários": "subsalário",
    "subsargenta": "subsargento",
    "subsargentas": "subsargento",
    "subsargentos": "subsargento",
    "subsariana": "subsariano",
    "subsarianas": "subsariano",
    "subsarianos": "subsariano",
    "subscreva": "subscrever",
    "subscrevais": "subscrever",
    "subscrevam": "subscrever",
    "subscrevamo": "subscrever",
    "subscrevamos": "subscrever",
    "subscrevas": "subscrever",
    "subscreve": "subscrever",
    "subscrevei": "subscrever",
    "subscreveis": "subscrever",
    "subscrevem": "subscrever",
    "subscrevemo": "subscrever",
    "subscrevemos": "subscrever",
    "subscrevendo": "subscrever",
    "subscrevera": "subscrever",
    "subscreveram": "subscrever",
    "subscreveras": "subscrever",
    "subscreverde": "subscrever",
    "subscreverdes": "subscrever",
    "subscrevere": "subscrever",
    "subscreverei": "subscrever",
    "subscrevereis": "subscrever",
    "subscreverem": "subscrever",
    "subscreveremos": "subscrever",
    "subscreveres": "subscrever",
    "subscreveria": "subscrever",
    "subscreveriam": "subscrever",
    "subscreverias": "subscrever",
    "subscrevermo": "subscrever",
    "subscrevermos": "subscrever",
    "subscreverá": "subscrever",
    "subscreverás": "subscrever",
    "subscreverão": "subscrever",
    "subscreveríamos": "subscrever",
    "subscreveríeis": "subscrever",
    "subscreves": "subscrever",
    "subscrevesse": "subscrever",
    "subscrevessem": "subscrever",
    "subscrevesses": "subscrever",
    "subscreveste": "subscrever",
    "subscrevestes": "subscrever",
    "subscreveu": "subscrever",
    "subscrevi": "subscrever",
    "subscrevia": "subscrever",
    "subscreviam": "subscrever",
    "subscrevias": "subscrever",
    "subscrevida": "subscrever",
    "subscrevidas": "subscrever",
    "subscrevido": "subscrever",
    "subscrevidos": "subscrever",
    "subscrevo": "subscrever",
    "subscrevê": "subscrever",
    "subscrevêramo": "subscrever",
    "subscrevêramos": "subscrever",
    "subscrevêrei": "subscrever",
    "subscrevêreis": "subscrever",
    "subscrevêsseis": "subscrever",
    "subscrevêssemos": "subscrever",
    "subscrevíamo": "subscrever",
    "subscrevíamos": "subscrever",
    "subscrevíei": "subscrever",
    "subscrevíeis": "subscrever",
    "subscrita": "subscrito",
    "subscritada": "subscritar",
    "subscritadas": "subscritar",
    "subscritado": "subscritar",
    "subscritados": "subscritar",
    "subscritai": "subscritar",
    "subscritais": "subscritar",
    "subscritam": "subscritar",
    "subscritamo": "subscritar",
    "subscritamos": "subscritar",
    "subscritando": "subscritar",
    "subscritara": "subscritar",
    "subscritaram": "subscritar",
    "subscritaras": "subscritar",
    "subscritarde": "subscritar",
    "subscritardes": "subscritar",
    "subscritare": "subscritar",
    "subscritarei": "subscritar",
    "subscritareis": "subscritar",
    "subscritarem": "subscritar",
    "subscritaremos": "subscritar",
    "subscritares": "subscritar",
    "subscritaria": "subscritar",
    "subscritariam": "subscritar",
    "subscritarias": "subscritar",
    "subscritarmo": "subscritar",
    "subscritarmos": "subscritar",
    "subscritará": "subscritar",
    "subscritarás": "subscritar",
    "subscritarão": "subscritar",
    "subscritaríamos": "subscritar",
    "subscritaríeis": "subscritar",
    "subscritas": "subscrito",
    "subscritasse": "subscritar",
    "subscritassem": "subscritar",
    "subscritasses": "subscritar",
    "subscritaste": "subscritar",
    "subscritastes": "subscritar",
    "subscritava": "subscritar",
    "subscritavam": "subscritar",
    "subscritavas": "subscritar",
    "subscrite": "subscritar",
    "subscritei": "subscritar",
    "subscriteis": "subscritar",
    "subscritem": "subscritar",
    "subscritemo": "subscritar",
    "subscritemos": "subscritar",
    "subscrites": "subscritar",
    "subscrito": "subscritar",
    "subscritora": "subscritor",
    "subscritoras": "subscritor",
    "subscritores": "subscritor",
    "subscritos": "subscrito",
    "subscritou": "subscritar",
    "subscritá": "subscritar",
    "subscritámo": "subscritar",
    "subscritámos": "subscritar",
    "subscritáramo": "subscritar",
    "subscritáramos": "subscritar",
    "subscritárei": "subscritar",
    "subscritáreis": "subscritar",
    "subscritásseis": "subscritar",
    "subscritássemos": "subscritar",
    "subscritávamo": "subscritar",
    "subscritávamos": "subscritar",
    "subscritávei": "subscritar",
    "subscritáveis": "subscritar",
    "subscrições": "subscrição",
    "subseciva": "subsecivo",
    "subsecivas": "subsecivo",
    "subsecivos": "subsecivo",
    "subsecretaria": "subsecretariar",
    "subsecretariada": "subsecretariar",
    "subsecretariadas": "subsecretariar",
    "subsecretariado": "subsecretariar",
    "subsecretariados": "subsecretariar",
    "subsecretariai": "subsecretariar",
    "subsecretariais": "subsecretariar",
    "subsecretariam": "subsecretariar",
    "subsecretariamo": "subsecretariar",
    "subsecretariamos": "subsecretariar",
    "subsecretariando": "subsecretariar",
    "subsecretariara": "subsecretariar",
    "subsecretariaram": "subsecretariar",
    "subsecretariaras": "subsecretariar",
    "subsecretariarde": "subsecretariar",
    "subsecretariardes": "subsecretariar",
    "subsecretariare": "subsecretariar",
    "subsecretariarei": "subsecretariar",
    "subsecretariareis": "subsecretariar",
    "subsecretariarem": "subsecretariar",
    "subsecretariaremos": "subsecretariar",
    "subsecretariares": "subsecretariar",
    "subsecretariaria": "subsecretariar",
    "subsecretariariam": "subsecretariar",
    "subsecretariarias": "subsecretariar",
    "subsecretariarmo": "subsecretariar",
    "subsecretariarmos": "subsecretariar",
    "subsecretariará": "subsecretariar",
    "subsecretariarás": "subsecretariar",
    "subsecretariarão": "subsecretariar",
    "subsecretariaríamos": "subsecretariar",
    "subsecretariaríeis": "subsecretariar",
    "subsecretarias": "subsecretariar",
    "subsecretariasse": "subsecretariar",
    "subsecretariassem": "subsecretariar",
    "subsecretariasses": "subsecretariar",
    "subsecretariaste": "subsecretariar",
    "subsecretariastes": "subsecretariar",
    "subsecretariava": "subsecretariar",
    "subsecretariavam": "subsecretariar",
    "subsecretariavas": "subsecretariar",
    "subsecretarie": "subsecretariar",
    "subsecretariei": "subsecretariar",
    "subsecretarieis": "subsecretariar",
    "subsecretariem": "subsecretariar",
    "subsecretariemo": "subsecretariar",
    "subsecretariemos": "subsecretariar",
    "subsecretaries": "subsecretariar",
    "subsecretario": "subsecretariar",
    "subsecretariou": "subsecretariar",
    "subsecretariá": "subsecretariar",
    "subsecretariámo": "subsecretariar",
    "subsecretariámos": "subsecretariar",
    "subsecretariáramo": "subsecretariar",
    "subsecretariáramos": "subsecretariar",
    "subsecretariárei": "subsecretariar",
    "subsecretariáreis": "subsecretariar",
    "subsecretariásseis": "subsecretariar",
    "subsecretariássemos": "subsecretariar",
    "subsecretariávamo": "subsecretariar",
    "subsecretariávamos": "subsecretariar",
    "subsecretariávei": "subsecretariar",
    "subsecretariáveis": "subsecretariar",
    "subsecretária": "subsecretário",
    "subsecretárias": "subsecretário",
    "subsecretários": "subsecretário",
    "subsectores": "subsector",
    "subsecutiva": "subsecutivo",
    "subsecutivas": "subsecutivo",
    "subsecutivos": "subsecutivo",
    "subsecções": "subsecção",
    "subsegue": "subseguir",
    "subseguem": "subseguir",
    "subsegues": "subseguir",
    "subsegui": "subseguir",
    "subseguia": "subseguir",
    "subseguiam": "subseguir",
    "subseguias": "subseguir",
    "subseguida": "subseguir",
    "subseguidas": "subseguir",
    "subseguido": "subseguir",
    "subseguidos": "subseguir",
    "subseguimo": "subseguir",
    "subseguimos": "subseguir",
    "subseguindo": "subseguir",
    "subseguira": "subseguir",
    "subseguiram": "subseguir",
    "subseguiras": "subseguir",
    "subseguirde": "subseguir",
    "subseguirdes": "subseguir",
    "subseguire": "subseguir",
    "subseguirei": "subseguir",
    "subseguireis": "subseguir",
    "subseguirem": "subseguir",
    "subseguiremos": "subseguir",
    "subseguires": "subseguir",
    "subseguiria": "subseguir",
    "subseguiriam": "subseguir",
    "subseguirias": "subseguir",
    "subseguirmo": "subseguir",
    "subseguirmos": "subseguir",
    "subseguirá": "subseguir",
    "subseguirás": "subseguir",
    "subseguirão": "subseguir",
    "subseguiríamos": "subseguir",
    "subseguiríeis": "subseguir",
    "subseguis": "subseguir",
    "subseguisse": "subseguir",
    "subseguissem": "subseguir",
    "subseguisses": "subseguir",
    "subseguiste": "subseguir",
    "subseguistes": "subseguir",
    "subseguiu": "subseguir",
    "subseguíamo": "subseguir",
    "subseguíamos": "subseguir",
    "subseguíei": "subseguir",
    "subseguíeis": "subseguir",
    "subseguíramo": "subseguir",
    "subseguíramos": "subseguir",
    "subseguírei": "subseguir",
    "subseguíreis": "subseguir",
    "subseguísseis": "subseguir",
    "subseguíssemos": "subseguir",
    "subsentidos": "subsentido",
    "subsequentes": "subsequente",
    "subsequências": "subsequência",
    "subservientes": "subserviente",
    "subserviências": "subserviência",
    "subsidariedades": "subsidariedade",
    "subsidia": "subsidiar",
    "subsidiada": "subsidiar",
    "subsidiadas": "subsidiar",
    "subsidiado": "subsidiar",
    "subsidiados": "subsidiar",
    "subsidiadíssima": "subsidiado",
    "subsidiadíssimas": "subsidiado",
    "subsidiadíssimo": "subsidiado",
    "subsidiadíssimos": "subsidiado",
    "subsidiai": "subsidiar",
    "subsidiais": "subsidiar",
    "subsidiam": "subsidiar",
    "subsidiamo": "subsidiar",
    "subsidiamos": "subsidiar",
    "subsidiando": "subsidiar",
    "subsidiara": "subsidiar",
    "subsidiaram": "subsidiar",
    "subsidiaras": "subsidiar",
    "subsidiarde": "subsidiar",
    "subsidiardes": "subsidiar",
    "subsidiare": "subsidiar",
    "subsidiarei": "subsidiar",
    "subsidiareis": "subsidiar",
    "subsidiarem": "subsidiar",
    "subsidiaremos": "subsidiar",
    "subsidiares": "subsidiar",
    "subsidiaria": "subsidiar",
    "subsidiariam": "subsidiar",
    "subsidiarias": "subsidiar",
    "subsidiariedades": "subsidiariedade",
    "subsidiarmo": "subsidiar",
    "subsidiarmos": "subsidiar",
    "subsidiará": "subsidiar",
    "subsidiarás": "subsidiar",
    "subsidiarão": "subsidiar",
    "subsidiaríamos": "subsidiar",
    "subsidiaríeis": "subsidiar",
    "subsidias": "subsidiar",
    "subsidiasse": "subsidiar",
    "subsidiassem": "subsidiar",
    "subsidiasses": "subsidiar",
    "subsidiaste": "subsidiar",
    "subsidiastes": "subsidiar",
    "subsidiava": "subsidiar",
    "subsidiavam": "subsidiar",
    "subsidiavas": "subsidiar",
    "subsidie": "subsidiar",
    "subsidiei": "subsidiar",
    "subsidieis": "subsidiar",
    "subsidiem": "subsidiar",
    "subsidiemo": "subsidiar",
    "subsidiemos": "subsidiar",
    "subsidies": "subsidiar",
    "subsidio": "subsidiar",
    "subsidiou": "subsidiar",
    "subsidiozinho": "subsídio",
    "subsidiozinhos": "subsídio",
    "subsidiozito": "subsídio",
    "subsidiozitos": "subsídio",
    "subsidiá": "subsidiar",
    "subsidiámo": "subsidiar",
    "subsidiámos": "subsidiar",
    "subsidiáramo": "subsidiar",
    "subsidiáramos": "subsidiar",
    "subsidiárei": "subsidiar",
    "subsidiáreis": "subsidiar",
    "subsidiária": "subsidiário",
    "subsidiárias": "subsidiário",
    "subsidiários": "subsidiário",
    "subsidiásseis": "subsidiar",
    "subsidiássemos": "subsidiar",
    "subsidiávamo": "subsidiar",
    "subsidiávamos": "subsidiar",
    "subsidiávei": "subsidiar",
    "subsidiáveis": "subsidiável",
    "subsidências": "subsidência",
    "subsiga": "subseguir",
    "subsigais": "subseguir",
    "subsigam": "subseguir",
    "subsigamo": "subseguir",
    "subsigamos": "subseguir",
    "subsigas": "subseguir",
    "subsigo": "subseguir",
    "subsista": "subsistir",
    "subsistais": "subsistir",
    "subsistam": "subsistir",
    "subsistamo": "subsistir",
    "subsistamos": "subsistir",
    "subsistas": "subsistir",
    "subsiste": "subsistir",
    "subsistem": "subsistir",
    "subsistemas": "subsistema",
    "subsistentes": "subsistente",
    "subsistes": "subsistir",
    "subsisti": "subsistir",
    "subsistia": "subsistir",
    "subsistiam": "subsistir",
    "subsistias": "subsistir",
    "subsistida": "subsistir",
    "subsistidas": "subsistir",
    "subsistido": "subsistir",
    "subsistidos": "subsistir",
    "subsistimo": "subsistir",
    "subsistimos": "subsistir",
    "subsistindo": "subsistir",
    "subsistira": "subsistir",
    "subsistiram": "subsistir",
    "subsistiras": "subsistir",
    "subsistirdes": "subsistir",
    "subsistirei": "subsistir",
    "subsistireis": "subsistir",
    "subsistirem": "subsistir",
    "subsistiremos": "subsistir",
    "subsistires": "subsistir",
    "subsistiria": "subsistir",
    "subsistiriam": "subsistir",
    "subsistirias": "subsistir",
    "subsistirmo": "subsistir",
    "subsistirmos": "subsistir",
    "subsistirá": "subsistir",
    "subsistirás": "subsistir",
    "subsistirão": "subsistir",
    "subsistiríamos": "subsistir",
    "subsistiríeis": "subsistir",
    "subsistis": "subsistir",
    "subsistisse": "subsistir",
    "subsistissem": "subsistir",
    "subsistisses": "subsistir",
    "subsististe": "subsistir",
    "subsististes": "subsistir",
    "subsistiu": "subsistir",
    "subsisto": "subsistir",
    "subsistências": "subsistência",
    "subsistíamo": "subsistir",
    "subsistíamos": "subsistir",
    "subsistíeis": "subsistir",
    "subsistíramo": "subsistir",
    "subsistíramos": "subsistir",
    "subsistíreis": "subsistir",
    "subsistísseis": "subsistir",
    "subsistíssemos": "subsistir",
    "subsolagens": "subsolagem",
    "subsolana": "subsolano",
    "subsolanas": "subsolano",
    "subsolanos": "subsolano",
    "subsolos": "subsolo",
    "subsome": "subsumir",
    "subsomem": "subsumir",
    "subsomes": "subsumir",
    "substabelece": "substabelecer",
    "substabelecei": "substabelecer",
    "substabeleceis": "substabelecer",
    "substabelecem": "substabelecer",
    "substabelecemo": "substabelecer",
    "substabelecemos": "substabelecer",
    "substabelecendo": "substabelecer",
    "substabelecera": "substabelecer",
    "substabeleceram": "substabelecer",
    "substabeleceras": "substabelecer",
    "substabelecerde": "substabelecer",
    "substabelecerdes": "substabelecer",
    "substabelecere": "substabelecer",
    "substabelecerei": "substabelecer",
    "substabelecereis": "substabelecer",
    "substabelecerem": "substabelecer",
    "substabeleceremos": "substabelecer",
    "substabeleceres": "substabelecer",
    "substabeleceria": "substabelecer",
    "substabeleceriam": "substabelecer",
    "substabelecerias": "substabelecer",
    "substabelecermo": "substabelecer",
    "substabelecermos": "substabelecer",
    "substabelecerá": "substabelecer",
    "substabelecerás": "substabelecer",
    "substabelecerão": "substabelecer",
    "substabeleceríamos": "substabelecer",
    "substabeleceríeis": "substabelecer",
    "substabeleces": "substabelecer",
    "substabelecesse": "substabelecer",
    "substabelecessem": "substabelecer",
    "substabelecesses": "substabelecer",
    "substabeleceste": "substabelecer",
    "substabelecestes": "substabelecer",
    "substabeleceu": "substabelecer",
    "substabeleci": "substabelecer",
    "substabelecia": "substabelecer",
    "substabeleciam": "substabelecer",
    "substabelecias": "substabelecer",
    "substabelecida": "substabelecido",
    "substabelecidas": "substabelecido",
    "substabelecido": "substabelecer",
    "substabelecidos": "substabelecido",
    "substabelecimentos": "substabelecimento",
    "substabelecê": "substabelecer",
    "substabelecêramo": "substabelecer",
    "substabelecêramos": "substabelecer",
    "substabelecêrei": "substabelecer",
    "substabelecêreis": "substabelecer",
    "substabelecêsseis": "substabelecer",
    "substabelecêssemos": "substabelecer",
    "substabelecíamo": "substabelecer",
    "substabelecíamos": "substabelecer",
    "substabelecíei": "substabelecer",
    "substabelecíeis": "substabelecer",
    "substabelecíveis": "substabelecível",
    "substabeleça": "substabelecer",
    "substabeleçais": "substabelecer",
    "substabeleçam": "substabelecer",
    "substabeleçamo": "substabelecer",
    "substabeleçamos": "substabelecer",
    "substabeleças": "substabelecer",
    "substabeleço": "substabelecer",
    "substancia": "substanciar",
    "substanciada": "substanciar",
    "substanciadas": "substanciar",
    "substanciado": "substanciar",
    "substanciados": "substanciar",
    "substanciai": "substanciar",
    "substanciais": "substanciar",
    "substancialidades": "substancialidade",
    "substancialismos": "substancialismo",
    "substancialistas": "substancialista",
    "substancializa": "substancializar",
    "substancializada": "substancializar",
    "substancializadas": "substancializar",
    "substancializado": "substancializar",
    "substancializados": "substancializar",
    "substancializai": "substancializar",
    "substancializais": "substancializar",
    "substancializam": "substancializar",
    "substancializamo": "substancializar",
    "substancializamos": "substancializar",
    "substancializando": "substancializar",
    "substancializara": "substancializar",
    "substancializaram": "substancializar",
    "substancializaras": "substancializar",
    "substancializarde": "substancializar",
    "substancializardes": "substancializar",
    "substancializare": "substancializar",
    "substancializarei": "substancializar",
    "substancializareis": "substancializar",
    "substancializarem": "substancializar",
    "substancializaremos": "substancializar",
    "substancializares": "substancializar",
    "substancializaria": "substancializar",
    "substancializariam": "substancializar",
    "substancializarias": "substancializar",
    "substancializarmo": "substancializar",
    "substancializarmos": "substancializar",
    "substancializará": "substancializar",
    "substancializarás": "substancializar",
    "substancializarão": "substancializar",
    "substancializaríamos": "substancializar",
    "substancializaríeis": "substancializar",
    "substancializas": "substancializar",
    "substancializasse": "substancializar",
    "substancializassem": "substancializar",
    "substancializasses": "substancializar",
    "substancializaste": "substancializar",
    "substancializastes": "substancializar",
    "substancializava": "substancializar",
    "substancializavam": "substancializar",
    "substancializavas": "substancializar",
    "substancialize": "substancializar",
    "substancializei": "substancializar",
    "substancializeis": "substancializar",
    "substancializem": "substancializar",
    "substancializemo": "substancializar",
    "substancializemos": "substancializar",
    "substancializes": "substancializar",
    "substancializo": "substancializar",
    "substancializou": "substancializar",
    "substancializá": "substancializar",
    "substancializámo": "substancializar",
    "substancializámos": "substancializar",
    "substancializáramo": "substancializar",
    "substancializáramos": "substancializar",
    "substancializárei": "substancializar",
    "substancializáreis": "substancializar",
    "substancializásseis": "substancializar",
    "substancializássemos": "substancializar",
    "substancializávamo": "substancializar",
    "substancializávamos": "substancializar",
    "substancializávei": "substancializar",
    "substancializáveis": "substancializar",
    "substanciam": "substanciar",
    "substanciamo": "substanciar",
    "substanciamos": "substanciar",
    "substanciando": "substanciar",
    "substanciara": "substanciar",
    "substanciaram": "substanciar",
    "substanciaras": "substanciar",
    "substanciarde": "substanciar",
    "substanciardes": "substanciar",
    "substanciare": "substanciar",
    "substanciarei": "substanciar",
    "substanciareis": "substanciar",
    "substanciarem": "substanciar",
    "substanciaremos": "substanciar",
    "substanciares": "substanciar",
    "substanciaria": "substanciar",
    "substanciariam": "substanciar",
    "substanciarias": "substanciar",
    "substanciarmo": "substanciar",
    "substanciarmos": "substanciar",
    "substanciará": "substanciar",
    "substanciarás": "substanciar",
    "substanciarão": "substanciar",
    "substanciaríamos": "substanciar",
    "substanciaríeis": "substanciar",
    "substancias": "substanciar",
    "substanciasse": "substanciar",
    "substanciassem": "substanciar",
    "substanciasses": "substanciar",
    "substanciaste": "substanciar",
    "substanciastes": "substanciar",
    "substanciava": "substanciar",
    "substanciavam": "substanciar",
    "substanciavas": "substanciar",
    "substancie": "substanciar",
    "substanciei": "substanciar",
    "substancieis": "substanciar",
    "substanciem": "substanciar",
    "substanciemo": "substanciar",
    "substanciemos": "substanciar",
    "substancies": "substanciar",
    "substancio": "substanciar",
    "substanciosa": "substancioso",
    "substanciosas": "substancioso",
    "substanciosos": "substancioso",
    "substanciou": "substanciar",
    "substanciá": "substanciar",
    "substanciámo": "substanciar",
    "substanciámos": "substanciar",
    "substanciáramo": "substanciar",
    "substanciáramos": "substanciar",
    "substanciárei": "substanciar",
    "substanciáreis": "substanciar",
    "substanciásseis": "substanciar",
    "substanciássemos": "substanciar",
    "substanciávamo": "substanciar",
    "substanciávamos": "substanciar",
    "substanciávei": "substanciar",
    "substanciáveis": "substanciar",
    "substantifica": "substantificar",
    "substantificada": "substantificar",
    "substantificadas": "substantificar",
    "substantificado": "substantificar",
    "substantificados": "substantificar",
    "substantificai": "substantificar",
    "substantificais": "substantificar",
    "substantificam": "substantificar",
    "substantificamo": "substantificar",
    "substantificamos": "substantificar",
    "substantificando": "substantificar",
    "substantificara": "substantificar",
    "substantificaram": "substantificar",
    "substantificaras": "substantificar",
    "substantificarde": "substantificar",
    "substantificardes": "substantificar",
    "substantificare": "substantificar",
    "substantificarei": "substantificar",
    "substantificareis": "substantificar",
    "substantificarem": "substantificar",
    "substantificaremos": "substantificar",
    "substantificares": "substantificar",
    "substantificaria": "substantificar",
    "substantificariam": "substantificar",
    "substantificarias": "substantificar",
    "substantificarmo": "substantificar",
    "substantificarmos": "substantificar",
    "substantificará": "substantificar",
    "substantificarás": "substantificar",
    "substantificarão": "substantificar",
    "substantificaríamos": "substantificar",
    "substantificaríeis": "substantificar",
    "substantificas": "substantificar",
    "substantificasse": "substantificar",
    "substantificassem": "substantificar",
    "substantificasses": "substantificar",
    "substantificaste": "substantificar",
    "substantificastes": "substantificar",
    "substantificava": "substantificar",
    "substantificavam": "substantificar",
    "substantificavas": "substantificar",
    "substantificações": "substantificação",
    "substantifico": "substantificar",
    "substantificou": "substantificar",
    "substantificá": "substantificar",
    "substantificámo": "substantificar",
    "substantificámos": "substantificar",
    "substantificáramo": "substantificar",
    "substantificáramos": "substantificar",
    "substantificárei": "substantificar",
    "substantificáreis": "substantificar",
    "substantificásseis": "substantificar",
    "substantificássemos": "substantificar",
    "substantificávamo": "substantificar",
    "substantificávamos": "substantificar",
    "substantificávei": "substantificar",
    "substantificáveis": "substantificar",
    "substantifique": "substantificar",
    "substantifiquei": "substantificar",
    "substantifiqueis": "substantificar",
    "substantifiquem": "substantificar",
    "substantifiquemo": "substantificar",
    "substantifiquemos": "substantificar",
    "substantifiques": "substantificar",
    "substantiva": "substantivo",
    "substantivada": "substantivar",
    "substantivadas": "substantivar",
    "substantivado": "substantivar",
    "substantivados": "substantivar",
    "substantivai": "substantivar",
    "substantivais": "substantivar",
    "substantivam": "substantivar",
    "substantivamo": "substantivar",
    "substantivamos": "substantivar",
    "substantivando": "substantivar",
    "substantivara": "substantivar",
    "substantivaram": "substantivar",
    "substantivaras": "substantivar",
    "substantivarde": "substantivar",
    "substantivardes": "substantivar",
    "substantivare": "substantivar",
    "substantivarei": "substantivar",
    "substantivareis": "substantivar",
    "substantivarem": "substantivar",
    "substantivaremos": "substantivar",
    "substantivares": "substantivar",
    "substantivaria": "substantivar",
    "substantivariam": "substantivar",
    "substantivarias": "substantivar",
    "substantivarmo": "substantivar",
    "substantivarmos": "substantivar",
    "substantivará": "substantivar",
    "substantivarás": "substantivar",
    "substantivarão": "substantivar",
    "substantivaríamos": "substantivar",
    "substantivaríeis": "substantivar",
    "substantivas": "substantivo",
    "substantivasse": "substantivar",
    "substantivassem": "substantivar",
    "substantivasses": "substantivar",
    "substantivaste": "substantivar",
    "substantivastes": "substantivar",
    "substantivava": "substantivar",
    "substantivavam": "substantivar",
    "substantivavas": "substantivar",
    "substantivações": "substantivação",
    "substantive": "substantivar",
    "substantivei": "substantivar",
    "substantiveis": "substantivar",
    "substantivem": "substantivar",
    "substantivemo": "substantivar",
    "substantivemos": "substantivar",
    "substantives": "substantivar",
    "substantivo": "substantivar",
    "substantivos": "substantivo",
    "substantivou": "substantivar",
    "substantivá": "substantivar",
    "substantivámo": "substantivar",
    "substantivámos": "substantivar",
    "substantiváramo": "substantivar",
    "substantiváramos": "substantivar",
    "substantivárei": "substantivar",
    "substantiváreis": "substantivar",
    "substantivásseis": "substantivar",
    "substantivássemos": "substantivar",
    "substantivávamo": "substantivar",
    "substantivávamos": "substantivar",
    "substantivávei": "substantivar",
    "substantiváveis": "substantivável",
    "substantífica": "substantífico",
    "substantíficas": "substantífico",
    "substantíficos": "substantífico",
    "substatória": "substatório",
    "substatórias": "substatório",
    "substatórios": "substatório",
    "substitua": "substituir",
    "substituais": "substituir",
    "substituam": "substituir",
    "substituamo": "substituir",
    "substituamos": "substituir",
    "substituas": "substituir",
    "substituem": "substituir",
    "substitui": "substituir",
    "substituindo": "substituir",
    "substituintes": "substituinte",
    "substituirde": "substituir",
    "substituirdes": "substituir",
    "substituirei": "substituir",
    "substituireis": "substituir",
    "substituiremos": "substituir",
    "substituiria": "substituir",
    "substituiriam": "substituir",
    "substituirias": "substituir",
    "substituirmo": "substituir",
    "substituirmos": "substituir",
    "substituirá": "substituir",
    "substituirás": "substituir",
    "substituirão": "substituir",
    "substituiríamos": "substituir",
    "substituiríeis": "substituir",
    "substituis": "substituir",
    "substituiu": "substituir",
    "substituições": "substituição",
    "substituo": "substituir",
    "substituta": "substituto",
    "substitutas": "substituto",
    "substitutazinha": "substituto",
    "substitutazinhas": "substituto",
    "substitutazita": "substituto",
    "substitutazitas": "substituto",
    "substitutiva": "substitutivo",
    "substitutivas": "substitutivo",
    "substitutivos": "substitutivo",
    "substitutos": "substituto",
    "substitutozinho": "substituto",
    "substitutozinhos": "substituto",
    "substitutozito": "substituto",
    "substitutozitos": "substituto",
    "substituí": "substituir",
    "substituía": "substituir",
    "substituíam": "substituir",
    "substituíamo": "substituir",
    "substituíamos": "substituir",
    "substituías": "substituir",
    "substituída": "substituir",
    "substituídas": "substituir",
    "substituído": "substituir",
    "substituídos": "substituir",
    "substituíei": "substituir",
    "substituíeis": "substituir",
    "substituímo": "substituir",
    "substituímos": "substituir",
    "substituíra": "substituir",
    "substituíram": "substituir",
    "substituíramo": "substituir",
    "substituíramos": "substituir",
    "substituíras": "substituir",
    "substituíre": "substituir",
    "substituírei": "substituir",
    "substituíreis": "substituir",
    "substituírem": "substituir",
    "substituíres": "substituir",
    "substituís": "substituir",
    "substituísse": "substituir",
    "substituísseis": "substituir",
    "substituíssem": "substituir",
    "substituíssemos": "substituir",
    "substituísses": "substituir",
    "substituíste": "substituir",
    "substituístes": "substituir",
    "substituíveis": "substituível",
    "substratos": "substrato",
    "substruturas": "substrutura",
    "substruções": "substrução",
    "substâncias": "substância",
    "subsulta": "subsultar",
    "subsultada": "subsultar",
    "subsultadas": "subsultar",
    "subsultado": "subsultar",
    "subsultados": "subsultar",
    "subsultai": "subsultar",
    "subsultais": "subsultar",
    "subsultam": "subsultar",
    "subsultamo": "subsultar",
    "subsultamos": "subsultar",
    "subsultando": "subsultar",
    "subsultara": "subsultar",
    "subsultaram": "subsultar",
    "subsultaras": "subsultar",
    "subsultardes": "subsultar",
    "subsultarei": "subsultar",
    "subsultareis": "subsultar",
    "subsultarem": "subsultar",
    "subsultaremos": "subsultar",
    "subsultares": "subsultar",
    "subsultaria": "subsultar",
    "subsultariam": "subsultar",
    "subsultarias": "subsultar",
    "subsultarmo": "subsultar",
    "subsultarmos": "subsultar",
    "subsultará": "subsultar",
    "subsultarás": "subsultar",
    "subsultarão": "subsultar",
    "subsultaríamos": "subsultar",
    "subsultaríeis": "subsultar",
    "subsultas": "subsultar",
    "subsultasse": "subsultar",
    "subsultassem": "subsultar",
    "subsultasses": "subsultar",
    "subsultaste": "subsultar",
    "subsultastes": "subsultar",
    "subsultava": "subsultar",
    "subsultavam": "subsultar",
    "subsultavas": "subsultar",
    "subsulte": "subsultar",
    "subsultei": "subsultar",
    "subsulteis": "subsultar",
    "subsultem": "subsultar",
    "subsultemo": "subsultar",
    "subsultemos": "subsultar",
    "subsultes": "subsultar",
    "subsulto": "subsultar",
    "subsultou": "subsultar",
    "subsultámo": "subsultar",
    "subsultámos": "subsultar",
    "subsultáramo": "subsultar",
    "subsultáramos": "subsultar",
    "subsultáreis": "subsultar",
    "subsultásseis": "subsultar",
    "subsultássemos": "subsultar",
    "subsultávamo": "subsultar",
    "subsultávamos": "subsultar",
    "subsultáveis": "subsultar",
    "subsuma": "subsumir",
    "subsumais": "subsumir",
    "subsumam": "subsumir",
    "subsumamo": "subsumir",
    "subsumamos": "subsumir",
    "subsumas": "subsumir",
    "subsumi": "subsumir",
    "subsumia": "subsumir",
    "subsumiam": "subsumir",
    "subsumias": "subsumir",
    "subsumida": "subsumir",
    "subsumidas": "subsumir",
    "subsumido": "subsumir",
    "subsumidos": "subsumir",
    "subsumimo": "subsumir",
    "subsumimos": "subsumir",
    "subsumindo": "subsumir",
    "subsumira": "subsumir",
    "subsumiram": "subsumir",
    "subsumiras": "subsumir",
    "subsumirdes": "subsumir",
    "subsumirei": "subsumir",
    "subsumireis": "subsumir",
    "subsumirem": "subsumir",
    "subsumiremos": "subsumir",
    "subsumires": "subsumir",
    "subsumiria": "subsumir",
    "subsumiriam": "subsumir",
    "subsumirias": "subsumir",
    "subsumirmo": "subsumir",
    "subsumirmos": "subsumir",
    "subsumirá": "subsumir",
    "subsumirás": "subsumir",
    "subsumirão": "subsumir",
    "subsumiríamos": "subsumir",
    "subsumiríeis": "subsumir",
    "subsumis": "subsumir",
    "subsumisse": "subsumir",
    "subsumissem": "subsumir",
    "subsumisses": "subsumir",
    "subsumiste": "subsumir",
    "subsumistes": "subsumir",
    "subsumiu": "subsumir",
    "subsumo": "subsumir",
    "subsumíamo": "subsumir",
    "subsumíamos": "subsumir",
    "subsumíeis": "subsumir",
    "subsumíramo": "subsumir",
    "subsumíramos": "subsumir",
    "subsumíreis": "subsumir",
    "subsumísseis": "subsumir",
    "subsumíssemos": "subsumir",
    "subsunções": "subsunção",
    "subsídios": "subsídio",
    "subsónica": "subsónico",
    "subsónicas": "subsónico",
    "subsónicos": "subsónico",
    "subtenda": "subtender",
    "subtendais": "subtender",
    "subtendam": "subtender",
    "subtendamo": "subtender",
    "subtendamos": "subtender",
    "subtendas": "subtender",
    "subtende": "subtender",
    "subtendei": "subtender",
    "subtendeis": "subtender",
    "subtendem": "subtender",
    "subtendemo": "subtender",
    "subtendemos": "subtender",
    "subtendendo": "subtender",
    "subtendentes": "subtendente",
    "subtendera": "subtender",
    "subtenderam": "subtender",
    "subtenderas": "subtender",
    "subtenderde": "subtender",
    "subtenderdes": "subtender",
    "subtendere": "subtender",
    "subtenderei": "subtender",
    "subtendereis": "subtender",
    "subtenderem": "subtender",
    "subtenderemos": "subtender",
    "subtenderes": "subtender",
    "subtenderia": "subtender",
    "subtenderiam": "subtender",
    "subtenderias": "subtender",
    "subtendermo": "subtender",
    "subtendermos": "subtender",
    "subtenderá": "subtender",
    "subtenderás": "subtender",
    "subtenderão": "subtender",
    "subtenderíamos": "subtender",
    "subtenderíeis": "subtender",
    "subtendes": "subtender",
    "subtendesse": "subtender",
    "subtendessem": "subtender",
    "subtendesses": "subtender",
    "subtendeste": "subtender",
    "subtendestes": "subtender",
    "subtendeu": "subtender",
    "subtendi": "subtender",
    "subtendia": "subtender",
    "subtendiam": "subtender",
    "subtendias": "subtender",
    "subtendida": "subtender",
    "subtendidas": "subtender",
    "subtendido": "subtender",
    "subtendidos": "subtender",
    "subtendo": "subtender",
    "subtendê": "subtender",
    "subtendêramo": "subtender",
    "subtendêramos": "subtender",
    "subtendêrei": "subtender",
    "subtendêreis": "subtender",
    "subtendêsseis": "subtender",
    "subtendêssemos": "subtender",
    "subtendíamo": "subtender",
    "subtendíamos": "subtender",
    "subtendíei": "subtender",
    "subtendíeis": "subtender",
    "subtenentes": "subtenente",
    "subtensa": "subtenso",
    "subtensas": "subtenso",
    "subtensos": "subtenso",
    "subterfluentes": "subterfluente",
    "subterfoge": "subterfugir",
    "subterfogem": "subterfugir",
    "subterfoges": "subterfugir",
    "subterfugi": "subterfugir",
    "subterfugia": "subterfugir",
    "subterfugiam": "subterfugir",
    "subterfugias": "subterfugir",
    "subterfugida": "subterfugir",
    "subterfugidas": "subterfugir",
    "subterfugido": "subterfugir",
    "subterfugidos": "subterfugir",
    "subterfugimo": "subterfugir",
    "subterfugimos": "subterfugir",
    "subterfugindo": "subterfugir",
    "subterfugira": "subterfugir",
    "subterfugiram": "subterfugir",
    "subterfugiras": "subterfugir",
    "subterfugirdes": "subterfugir",
    "subterfugirei": "subterfugir",
    "subterfugireis": "subterfugir",
    "subterfugirem": "subterfugir",
    "subterfugiremos": "subterfugir",
    "subterfugires": "subterfugir",
    "subterfugiria": "subterfugir",
    "subterfugiriam": "subterfugir",
    "subterfugirias": "subterfugir",
    "subterfugirmo": "subterfugir",
    "subterfugirmos": "subterfugir",
    "subterfugirá": "subterfugir",
    "subterfugirás": "subterfugir",
    "subterfugirão": "subterfugir",
    "subterfugiríamos": "subterfugir",
    "subterfugiríeis": "subterfugir",
    "subterfugis": "subterfugir",
    "subterfugisse": "subterfugir",
    "subterfugissem": "subterfugir",
    "subterfugisses": "subterfugir",
    "subterfugiste": "subterfugir",
    "subterfugistes": "subterfugir",
    "subterfugiu": "subterfugir",
    "subterfugíamo": "subterfugir",
    "subterfugíamos": "subterfugir",
    "subterfugíeis": "subterfugir",
    "subterfugíramo": "subterfugir",
    "subterfugíramos": "subterfugir",
    "subterfugíreis": "subterfugir",
    "subterfugísseis": "subterfugir",
    "subterfugíssemos": "subterfugir",
    "subterfuja": "subterfugir",
    "subterfujais": "subterfugir",
    "subterfujam": "subterfugir",
    "subterfujamo": "subterfugir",
    "subterfujamos": "subterfugir",
    "subterfujas": "subterfugir",
    "subterfujo": "subterfugir",
    "subterfúgios": "subterfúgio",
    "subterminais": "subterminal",
    "subterra": "subterrar",
    "subterrada": "subterrar",
    "subterradas": "subterrar",
    "subterrado": "subterrar",
    "subterrados": "subterrar",
    "subterrai": "subterrar",
    "subterrais": "subterrar",
    "subterram": "subterrar",
    "subterramo": "subterrar",
    "subterramos": "subterrar",
    "subterrando": "subterrar",
    "subterrara": "subterrar",
    "subterraram": "subterrar",
    "subterraras": "subterrar",
    "subterrarde": "subterrar",
    "subterrardes": "subterrar",
    "subterrare": "subterrar",
    "subterrarei": "subterrar",
    "subterrareis": "subterrar",
    "subterrarem": "subterrar",
    "subterraremos": "subterrar",
    "subterrares": "subterrar",
    "subterraria": "subterrar",
    "subterrariam": "subterrar",
    "subterrarias": "subterrar",
    "subterrarmo": "subterrar",
    "subterrarmos": "subterrar",
    "subterrará": "subterrar",
    "subterrarás": "subterrar",
    "subterrarão": "subterrar",
    "subterraríamos": "subterrar",
    "subterraríeis": "subterrar",
    "subterras": "subterrar",
    "subterrasse": "subterrar",
    "subterrassem": "subterrar",
    "subterrasses": "subterrar",
    "subterraste": "subterrar",
    "subterrastes": "subterrar",
    "subterrava": "subterrar",
    "subterravam": "subterrar",
    "subterravas": "subterrar",
    "subterre": "subterrar",
    "subterrei": "subterrar",
    "subterreis": "subterrar",
    "subterrem": "subterrar",
    "subterremo": "subterrar",
    "subterremos": "subterrar",
    "subterres": "subterrar",
    "subterro": "subterrar",
    "subterrou": "subterrar",
    "subterrá": "subterrar",
    "subterrámo": "subterrar",
    "subterrámos": "subterrar",
    "subterráramo": "subterrar",
    "subterráramos": "subterrar",
    "subterrárei": "subterrar",
    "subterráreis": "subterrar",
    "subterrásseis": "subterrar",
    "subterrássemos": "subterrar",
    "subterrávamo": "subterrar",
    "subterrávamos": "subterrar",
    "subterrávei": "subterrar",
    "subterráveis": "subterrar",
    "subterrânea": "subterrâneo",
    "subterrâneas": "subterrâneo",
    "subterrâneos": "subterrâneo",
    "subtilezas": "subtileza",
    "subtilidades": "subtilidade",
    "subtiliza": "subtilizar",
    "subtilizada": "subtilizar",
    "subtilizadas": "subtilizar",
    "subtilizado": "subtilizar",
    "subtilizadora": "subtilizador",
    "subtilizadoras": "subtilizador",
    "subtilizadores": "subtilizador",
    "subtilizados": "subtilizar",
    "subtilizai": "subtilizar",
    "subtilizais": "subtilizar",
    "subtilizam": "subtilizar",
    "subtilizamo": "subtilizar",
    "subtilizamos": "subtilizar",
    "subtilizando": "subtilizar",
    "subtilizara": "subtilizar",
    "subtilizaram": "subtilizar",
    "subtilizaras": "subtilizar",
    "subtilizarde": "subtilizar",
    "subtilizardes": "subtilizar",
    "subtilizare": "subtilizar",
    "subtilizarei": "subtilizar",
    "subtilizareis": "subtilizar",
    "subtilizarem": "subtilizar",
    "subtilizaremos": "subtilizar",
    "subtilizares": "subtilizar",
    "subtilizaria": "subtilizar",
    "subtilizariam": "subtilizar",
    "subtilizarias": "subtilizar",
    "subtilizarmo": "subtilizar",
    "subtilizarmos": "subtilizar",
    "subtilizará": "subtilizar",
    "subtilizarás": "subtilizar",
    "subtilizarão": "subtilizar",
    "subtilizaríamos": "subtilizar",
    "subtilizaríeis": "subtilizar",
    "subtilizas": "subtilizar",
    "subtilizasse": "subtilizar",
    "subtilizassem": "subtilizar",
    "subtilizasses": "subtilizar",
    "subtilizaste": "subtilizar",
    "subtilizastes": "subtilizar",
    "subtilizava": "subtilizar",
    "subtilizavam": "subtilizar",
    "subtilizavas": "subtilizar",
    "subtilizações": "subtilização",
    "subtilize": "subtilizar",
    "subtilizei": "subtilizar",
    "subtilizeis": "subtilizar",
    "subtilizem": "subtilizar",
    "subtilizemo": "subtilizar",
    "subtilizemos": "subtilizar",
    "subtilizes": "subtilizar",
    "subtilizo": "subtilizar",
    "subtilizou": "subtilizar",
    "subtilizá": "subtilizar",
    "subtilizámo": "subtilizar",
    "subtilizámos": "subtilizar",
    "subtilizáramo": "subtilizar",
    "subtilizáramos": "subtilizar",
    "subtilizárei": "subtilizar",
    "subtilizáreis": "subtilizar",
    "subtilizásseis": "subtilizar",
    "subtilizássemos": "subtilizar",
    "subtilizávamo": "subtilizar",
    "subtilizávamos": "subtilizar",
    "subtilizávei": "subtilizar",
    "subtilizáveis": "subtilizar",
    "subtipos": "subtipo",
    "subtis": "subtil",
    "subtractiva": "subtractivo",
    "subtractivas": "subtractivo",
    "subtractivos": "subtractivo",
    "subtracções": "subtracção",
    "subtraem": "subtrair",
    "subtraendos": "subtraendo",
    "subtrai": "subtrair",
    "subtraia": "subtrair",
    "subtraiais": "subtrair",
    "subtraiam": "subtrair",
    "subtraiamo": "subtrair",
    "subtraiamos": "subtrair",
    "subtraias": "subtrair",
    "subtraida": "subtraido",
    "subtraidas": "subtraido",
    "subtraidos": "subtraido",
    "subtraindo": "subtrair",
    "subtraio": "subtrair",
    "subtrairde": "subtrair",
    "subtrairdes": "subtrair",
    "subtrairei": "subtrair",
    "subtraireis": "subtrair",
    "subtrairemos": "subtrair",
    "subtrairia": "subtrair",
    "subtrairiam": "subtrair",
    "subtrairias": "subtrair",
    "subtrairmo": "subtrair",
    "subtrairmos": "subtrair",
    "subtrairá": "subtrair",
    "subtrairás": "subtrair",
    "subtrairão": "subtrair",
    "subtrairíamos": "subtrair",
    "subtrairíeis": "subtrair",
    "subtrais": "subtrair",
    "subtraiu": "subtrair",
    "subtraí": "subtrair",
    "subtraía": "subtrair",
    "subtraíam": "subtrair",
    "subtraíamo": "subtrair",
    "subtraíamos": "subtrair",
    "subtraías": "subtrair",
    "subtraída": "subtrair",
    "subtraídas": "subtrair",
    "subtraído": "subtrair",
    "subtraídos": "subtrair",
    "subtraíei": "subtrair",
    "subtraíeis": "subtrair",
    "subtraímo": "subtrair",
    "subtraímos": "subtrair",
    "subtraíra": "subtrair",
    "subtraíram": "subtrair",
    "subtraíramo": "subtrair",
    "subtraíramos": "subtrair",
    "subtraíras": "subtrair",
    "subtraíre": "subtrair",
    "subtraírei": "subtrair",
    "subtraíreis": "subtrair",
    "subtraírem": "subtrair",
    "subtraíres": "subtrair",
    "subtraís": "subtrair",
    "subtraísse": "subtrair",
    "subtraísseis": "subtrair",
    "subtraíssem": "subtrair",
    "subtraíssemos": "subtrair",
    "subtraísses": "subtrair",
    "subtraíste": "subtrair",
    "subtraístes": "subtrair",
    "subtraíveis": "subtraível",
    "subtribos": "subtribo",
    "subtropicais": "subtropical",
    "subtutora": "subtutor",
    "subtutoras": "subtutor",
    "subtutores": "subtutor",
    "subtérrea": "subtérreo",
    "subtérreas": "subtérreo",
    "subtérreos": "subtérreo",
    "subtítulos": "subtítulo",
    "subtónicas": "subtónica",
    "subulada": "subulado",
    "subuladas": "subulado",
    "subulados": "subulado",
    "subumanidades": "subumanidade",
    "subungulados": "subungulado",
    "subunidades": "subunidade",
    "suburbana": "suburbano",
    "suburbanas": "suburbano",
    "suburbanos": "suburbano",
    "suburbicária": "suburbicário",
    "suburbicárias": "suburbicário",
    "suburbicários": "suburbicário",
    "subvaloriza": "subvalorizar",
    "subvalorizada": "subvalorizar",
    "subvalorizadas": "subvalorizar",
    "subvalorizado": "subvalorizar",
    "subvalorizados": "subvalorizar",
    "subvalorizai": "subvalorizar",
    "subvalorizais": "subvalorizar",
    "subvalorizam": "subvalorizar",
    "subvalorizamo": "subvalorizar",
    "subvalorizamos": "subvalorizar",
    "subvalorizando": "subvalorizar",
    "subvalorizara": "subvalorizar",
    "subvalorizaram": "subvalorizar",
    "subvalorizaras": "subvalorizar",
    "subvalorizarde": "subvalorizar",
    "subvalorizardes": "subvalorizar",
    "subvalorizare": "subvalorizar",
    "subvalorizarei": "subvalorizar",
    "subvalorizareis": "subvalorizar",
    "subvalorizarem": "subvalorizar",
    "subvalorizaremos": "subvalorizar",
    "subvalorizares": "subvalorizar",
    "subvalorizaria": "subvalorizar",
    "subvalorizariam": "subvalorizar",
    "subvalorizarias": "subvalorizar",
    "subvalorizarmo": "subvalorizar",
    "subvalorizarmos": "subvalorizar",
    "subvalorizará": "subvalorizar",
    "subvalorizarás": "subvalorizar",
    "subvalorizarão": "subvalorizar",
    "subvalorizaríamos": "subvalorizar",
    "subvalorizaríeis": "subvalorizar",
    "subvalorizas": "subvalorizar",
    "subvalorizasse": "subvalorizar",
    "subvalorizassem": "subvalorizar",
    "subvalorizasses": "subvalorizar",
    "subvalorizaste": "subvalorizar",
    "subvalorizastes": "subvalorizar",
    "subvalorizava": "subvalorizar",
    "subvalorizavam": "subvalorizar",
    "subvalorizavas": "subvalorizar",
    "subvalorize": "subvalorizar",
    "subvalorizei": "subvalorizar",
    "subvalorizeis": "subvalorizar",
    "subvalorizem": "subvalorizar",
    "subvalorizemo": "subvalorizar",
    "subvalorizemos": "subvalorizar",
    "subvalorizes": "subvalorizar",
    "subvalorizo": "subvalorizar",
    "subvalorizou": "subvalorizar",
    "subvalorizá": "subvalorizar",
    "subvalorizámo": "subvalorizar",
    "subvalorizámos": "subvalorizar",
    "subvalorizáramo": "subvalorizar",
    "subvalorizáramos": "subvalorizar",
    "subvalorizárei": "subvalorizar",
    "subvalorizáreis": "subvalorizar",
    "subvalorizásseis": "subvalorizar",
    "subvalorizássemos": "subvalorizar",
    "subvalorizávamo": "subvalorizar",
    "subvalorizávamos": "subvalorizar",
    "subvalorizávei": "subvalorizar",
    "subvalorizáveis": "subvalorizar",
    "subvenciona": "subvencionar",
    "subvencionada": "subvencionar",
    "subvencionadas": "subvencionar",
    "subvencionado": "subvencionar",
    "subvencionadora": "subvencionador",
    "subvencionadoras": "subvencionador",
    "subvencionadores": "subvencionador",
    "subvencionados": "subvencionar",
    "subvencionai": "subvencionar",
    "subvencionais": "subvencionar",
    "subvencionam": "subvencionar",
    "subvencionamo": "subvencionar",
    "subvencionamos": "subvencionar",
    "subvencionando": "subvencionar",
    "subvencionara": "subvencionar",
    "subvencionaram": "subvencionar",
    "subvencionaras": "subvencionar",
    "subvencionarde": "subvencionar",
    "subvencionardes": "subvencionar",
    "subvencionare": "subvencionar",
    "subvencionarei": "subvencionar",
    "subvencionareis": "subvencionar",
    "subvencionarem": "subvencionar",
    "subvencionaremos": "subvencionar",
    "subvencionares": "subvencionar",
    "subvencionaria": "subvencionar",
    "subvencionariam": "subvencionar",
    "subvencionarias": "subvencionar",
    "subvencionarmo": "subvencionar",
    "subvencionarmos": "subvencionar",
    "subvencionará": "subvencionar",
    "subvencionarás": "subvencionar",
    "subvencionarão": "subvencionar",
    "subvencionaríamos": "subvencionar",
    "subvencionaríeis": "subvencionar",
    "subvencionas": "subvencionar",
    "subvencionasse": "subvencionar",
    "subvencionassem": "subvencionar",
    "subvencionasses": "subvencionar",
    "subvencionaste": "subvencionar",
    "subvencionastes": "subvencionar",
    "subvencionava": "subvencionar",
    "subvencionavam": "subvencionar",
    "subvencionavas": "subvencionar",
    "subvencione": "subvencionar",
    "subvencionei": "subvencionar",
    "subvencioneis": "subvencionar",
    "subvencionem": "subvencionar",
    "subvencionemo": "subvencionar",
    "subvencionemos": "subvencionar",
    "subvenciones": "subvencionar",
    "subvenciono": "subvencionar",
    "subvencionou": "subvencionar",
    "subvencioná": "subvencionar",
    "subvencionámo": "subvencionar",
    "subvencionámos": "subvencionar",
    "subvencionáramo": "subvencionar",
    "subvencionáramos": "subvencionar",
    "subvencionárei": "subvencionar",
    "subvencionáreis": "subvencionar",
    "subvencionásseis": "subvencionar",
    "subvencionássemos": "subvencionar",
    "subvencionávamo": "subvencionar",
    "subvencionávamos": "subvencionar",
    "subvencionávei": "subvencionar",
    "subvencionáveis": "subvencionável",
    "subventrais": "subventral",
    "subvenções": "subvenção",
    "subverbetes": "subverbete",
    "subversiva": "subversivo",
    "subversivas": "subversivo",
    "subversivos": "subversivo",
    "subversora": "subversor",
    "subversoras": "subversor",
    "subversores": "subversor",
    "subversões": "subversão",
    "subverta": "subverter",
    "subvertais": "subverter",
    "subvertam": "subverter",
    "subvertamo": "subverter",
    "subvertamos": "subverter",
    "subvertas": "subverter",
    "subverte": "subverter",
    "subvertedora": "subvertedor",
    "subvertedoras": "subvertedor",
    "subvertedores": "subvertedor",
    "subvertei": "subverter",
    "subverteis": "subverter",
    "subvertem": "subverter",
    "subvertemo": "subverter",
    "subvertemos": "subverter",
    "subvertendo": "subverter",
    "subvertera": "subverter",
    "subverteram": "subverter",
    "subverteras": "subverter",
    "subverterde": "subverter",
    "subverterdes": "subverter",
    "subvertere": "subverter",
    "subverterei": "subverter",
    "subvertereis": "subverter",
    "subverterem": "subverter",
    "subverteremos": "subverter",
    "subverteres": "subverter",
    "subverteria": "subverter",
    "subverteriam": "subverter",
    "subverterias": "subverter",
    "subvertermo": "subverter",
    "subvertermos": "subverter",
    "subverterá": "subverter",
    "subverterás": "subverter",
    "subverterão": "subverter",
    "subverteríamos": "subverter",
    "subverteríeis": "subverter",
    "subvertes": "subverter",
    "subvertesse": "subverter",
    "subvertessem": "subverter",
    "subvertesses": "subverter",
    "subverteste": "subverter",
    "subvertestes": "subverter",
    "subverteu": "subverter",
    "subverti": "subverter",
    "subvertia": "subverter",
    "subvertiam": "subverter",
    "subvertias": "subverter",
    "subvertida": "subvertido",
    "subvertidas": "subvertido",
    "subvertido": "subverter",
    "subvertidos": "subvertido",
    "subvertimentos": "subvertimento",
    "subverto": "subverter",
    "subvertê": "subverter",
    "subvertêramo": "subverter",
    "subvertêramos": "subverter",
    "subvertêrei": "subverter",
    "subvertêreis": "subverter",
    "subvertêsseis": "subverter",
    "subvertêssemos": "subverter",
    "subvertíamo": "subverter",
    "subvertíamos": "subverter",
    "subvertíei": "subverter",
    "subvertíeis": "subverter",
    "subvertíveis": "subvertível",
    "subzonas": "subzona",
    "subérica": "subérico",
    "subéricas": "subérico",
    "subéricos": "subérico",
    "subíamo": "subir",
    "subíamos": "subir",
    "subíei": "subir",
    "subíeis": "subir",
    "subíramo": "subir",
    "subíramos": "subir",
    "subírei": "subir",
    "subíreis": "subir",
    "subísseis": "subir",
    "subíssemos": "subir",
    "subúrbios": "subúrbio",
    "sucarás": "sucará",
    "sucatagens": "sucatagem",
    "sucatas": "sucata",
    "sucateira": "sucateiro",
    "sucateiras": "sucateiro",
    "sucateiros": "sucateiro",
    "succinatos": "succinato",
    "succínea": "succíneo",
    "succíneas": "succíneo",
    "succíneos": "succíneo",
    "succínica": "succínico",
    "succínicas": "succínico",
    "succínicos": "succínico",
    "suceda": "suceder",
    "sucedais": "suceder",
    "sucedam": "suceder",
    "sucedamo": "suceder",
    "sucedamos": "suceder",
    "sucedaneazinha": "sucedâneo",
    "sucedaneazinhas": "sucedâneo",
    "sucedaneazita": "sucedâneo",
    "sucedaneazitas": "sucedâneo",
    "sucedaneozinho": "sucedâneo",
    "sucedaneozinhos": "sucedâneo",
    "sucedaneozito": "sucedâneo",
    "sucedaneozitos": "sucedâneo",
    "sucedas": "suceder",
    "sucede": "suceder",
    "sucedei": "suceder",
    "sucedeis": "suceder",
    "sucedem": "suceder",
    "sucedemo": "suceder",
    "sucedemos": "suceder",
    "sucedendo": "suceder",
    "sucedera": "suceder",
    "sucederam": "suceder",
    "sucederas": "suceder",
    "sucederdes": "suceder",
    "sucederei": "suceder",
    "sucedereis": "suceder",
    "sucederem": "suceder",
    "sucederemos": "suceder",
    "sucederes": "suceder",
    "sucederia": "suceder",
    "sucederiam": "suceder",
    "sucederias": "suceder",
    "sucedermo": "suceder",
    "sucedermos": "suceder",
    "sucederá": "suceder",
    "sucederás": "suceder",
    "sucederão": "suceder",
    "sucederíamos": "suceder",
    "sucederíeis": "suceder",
    "sucedes": "suceder",
    "sucedesse": "suceder",
    "sucedessem": "suceder",
    "sucedesses": "suceder",
    "sucedeste": "suceder",
    "sucedestes": "suceder",
    "sucedeu": "suceder",
    "sucedi": "suceder",
    "sucedia": "suceder",
    "sucediam": "suceder",
    "sucedias": "suceder",
    "sucedida": "sucedido",
    "sucedidas": "sucedido",
    "sucedido": "suceder",
    "sucedidos": "sucedido",
    "sucedimentos": "sucedimento",
    "sucedo": "suceder",
    "sucedânea": "sucedâneo",
    "sucedâneas": "sucedâneo",
    "sucedâneos": "sucedâneo",
    "sucedêramo": "suceder",
    "sucedêramos": "suceder",
    "sucedêreis": "suceder",
    "sucedêsseis": "suceder",
    "sucedêssemos": "suceder",
    "sucedíamo": "suceder",
    "sucedíamos": "suceder",
    "sucedíeis": "suceder",
    "sucessibilidades": "sucessibilidade",
    "sucessiva": "sucessivo",
    "sucessivas": "sucessivo",
    "sucessivos": "sucessivo",
    "sucessora": "sucessor",
    "sucessoras": "sucessor",
    "sucessorazinha": "sucessor",
    "sucessorazinhas": "sucessor",
    "sucessorazita": "sucessor",
    "sucessorazitas": "sucessor",
    "sucessores": "sucessor",
    "sucessorzinho": "sucessor",
    "sucessorzinhos": "sucessor",
    "sucessorzito": "sucessor",
    "sucessorzitos": "sucessor",
    "sucessos": "sucesso",
    "sucessíveis": "sucessível",
    "sucessória": "sucessório",
    "sucessórias": "sucessório",
    "sucessórios": "sucessório",
    "sucessões": "sucessão",
    "sucia": "suciar",
    "suciada": "suciar",
    "suciadas": "suciar",
    "suciado": "suciar",
    "suciados": "suciar",
    "suciai": "suciar",
    "suciais": "suciar",
    "suciam": "suciar",
    "suciamo": "suciar",
    "suciamos": "suciar",
    "suciando": "suciar",
    "suciara": "suciar",
    "suciaram": "suciar",
    "suciaras": "suciar",
    "suciardes": "suciar",
    "suciarei": "suciar",
    "suciareis": "suciar",
    "suciarem": "suciar",
    "suciaremos": "suciar",
    "suciares": "suciar",
    "suciaria": "suciar",
    "suciariam": "suciar",
    "suciarias": "suciar",
    "suciarmo": "suciar",
    "suciarmos": "suciar",
    "suciará": "suciar",
    "suciarás": "suciar",
    "suciarão": "suciar",
    "suciaríamos": "suciar",
    "suciaríeis": "suciar",
    "sucias": "suciar",
    "suciasse": "suciar",
    "suciassem": "suciar",
    "suciasses": "suciar",
    "suciaste": "suciar",
    "suciastes": "suciar",
    "suciatas": "suciata",
    "suciava": "suciar",
    "suciavam": "suciar",
    "suciavas": "suciar",
    "sucie": "suciar",
    "suciei": "suciar",
    "sucieis": "suciar",
    "suciem": "suciar",
    "suciemo": "suciar",
    "suciemos": "suciar",
    "sucies": "suciar",
    "sucinos": "sucino",
    "sucinta": "sucinto",
    "sucintas": "sucinto",
    "sucintos": "sucinto",
    "sucio": "suciar",
    "suciou": "suciar",
    "suciámo": "suciar",
    "suciámos": "suciar",
    "suciáramo": "suciar",
    "suciáramos": "suciar",
    "suciáreis": "suciar",
    "suciásseis": "suciar",
    "suciássemos": "suciar",
    "suciávamo": "suciar",
    "suciávamos": "suciar",
    "suciáveis": "suciar",
    "sucos": "suco",
    "sucosa": "sucoso",
    "sucosas": "sucoso",
    "sucosidades": "sucosidade",
    "sucosos": "sucoso",
    "sucroquímicas": "sucroquímica",
    "sucroses": "sucrose",
    "suctória": "suctório",
    "suctórias": "suctório",
    "suctórios": "suctório",
    "suculenta": "suculento",
    "suculentas": "suculento",
    "suculentos": "suculento",
    "suculências": "suculência",
    "sucumba": "sucumbir",
    "sucumbais": "sucumbir",
    "sucumbam": "sucumbir",
    "sucumbamo": "sucumbir",
    "sucumbamos": "sucumbir",
    "sucumbas": "sucumbir",
    "sucumbe": "sucumbir",
    "sucumbem": "sucumbir",
    "sucumbes": "sucumbir",
    "sucumbi": "sucumbir",
    "sucumbia": "sucumbir",
    "sucumbiam": "sucumbir",
    "sucumbias": "sucumbir",
    "sucumbida": "sucumbir",
    "sucumbidas": "sucumbir",
    "sucumbido": "sucumbir",
    "sucumbidos": "sucumbir",
    "sucumbimo": "sucumbir",
    "sucumbimos": "sucumbir",
    "sucumbindo": "sucumbir",
    "sucumbira": "sucumbir",
    "sucumbiram": "sucumbir",
    "sucumbiras": "sucumbir",
    "sucumbirdes": "sucumbir",
    "sucumbirei": "sucumbir",
    "sucumbireis": "sucumbir",
    "sucumbirem": "sucumbir",
    "sucumbiremos": "sucumbir",
    "sucumbires": "sucumbir",
    "sucumbiria": "sucumbir",
    "sucumbiriam": "sucumbir",
    "sucumbirias": "sucumbir",
    "sucumbirmo": "sucumbir",
    "sucumbirmos": "sucumbir",
    "sucumbirá": "sucumbir",
    "sucumbirás": "sucumbir",
    "sucumbirão": "sucumbir",
    "sucumbiríamos": "sucumbir",
    "sucumbiríeis": "sucumbir",
    "sucumbis": "sucumbir",
    "sucumbisse": "sucumbir",
    "sucumbissem": "sucumbir",
    "sucumbisses": "sucumbir",
    "sucumbiste": "sucumbir",
    "sucumbistes": "sucumbir",
    "sucumbiu": "sucumbir",
    "sucumbo": "sucumbir",
    "sucumbências": "sucumbência",
    "sucumbíamo": "sucumbir",
    "sucumbíamos": "sucumbir",
    "sucumbíeis": "sucumbir",
    "sucumbíramo": "sucumbir",
    "sucumbíramos": "sucumbir",
    "sucumbíreis": "sucumbir",
    "sucumbísseis": "sucumbir",
    "sucumbíssemos": "sucumbir",
    "sucurijubas": "sucurijuba",
    "sucuris": "sucuri",
    "sucuriúbas": "sucuriúba",
    "sucursais": "sucursal",
    "sucussões": "sucussão",
    "sucções": "sucção",
    "sudada": "sudado",
    "sudadas": "sudado",
    "sudados": "sudado",
    "sudanesa": "sudanês",
    "sudanesas": "sudanês",
    "sudaneses": "sudanês",
    "sudatória": "sudatório",
    "sudatórias": "sudatório",
    "sudatórios": "sudatório",
    "sudações": "sudação",
    "sudestes": "sudeste",
    "sudoesta": "sudoestar",
    "sudoestada": "sudoestar",
    "sudoestadas": "sudoestar",
    "sudoestado": "sudoestar",
    "sudoestados": "sudoestar",
    "sudoestai": "sudoestar",
    "sudoestais": "sudoestar",
    "sudoestam": "sudoestar",
    "sudoestamo": "sudoestar",
    "sudoestamos": "sudoestar",
    "sudoestando": "sudoestar",
    "sudoestara": "sudoestar",
    "sudoestaram": "sudoestar",
    "sudoestaras": "sudoestar",
    "sudoestardes": "sudoestar",
    "sudoestarei": "sudoestar",
    "sudoestareis": "sudoestar",
    "sudoestarem": "sudoestar",
    "sudoestaremos": "sudoestar",
    "sudoestares": "sudoestar",
    "sudoestaria": "sudoestar",
    "sudoestariam": "sudoestar",
    "sudoestarias": "sudoestar",
    "sudoestarmo": "sudoestar",
    "sudoestarmos": "sudoestar",
    "sudoestará": "sudoestar",
    "sudoestarás": "sudoestar",
    "sudoestarão": "sudoestar",
    "sudoestaríamos": "sudoestar",
    "sudoestaríeis": "sudoestar",
    "sudoestas": "sudoestar",
    "sudoestasse": "sudoestar",
    "sudoestassem": "sudoestar",
    "sudoestasses": "sudoestar",
    "sudoestaste": "sudoestar",
    "sudoestastes": "sudoestar",
    "sudoestava": "sudoestar",
    "sudoestavam": "sudoestar",
    "sudoestavas": "sudoestar",
    "sudoeste": "sudoestar",
    "sudoestei": "sudoestar",
    "sudoesteis": "sudoestar",
    "sudoestem": "sudoestar",
    "sudoestemo": "sudoestar",
    "sudoestemos": "sudoestar",
    "sudoestes": "sudoeste",
    "sudoesto": "sudoestar",
    "sudoestou": "sudoestar",
    "sudoestámo": "sudoestar",
    "sudoestámos": "sudoestar",
    "sudoestáramo": "sudoestar",
    "sudoestáramos": "sudoestar",
    "sudoestáreis": "sudoestar",
    "sudoestásseis": "sudoestar",
    "sudoestássemos": "sudoestar",
    "sudoestávamo": "sudoestar",
    "sudoestávamos": "sudoestar",
    "sudoestáveis": "sudoestar",
    "sudorações": "sudoração",
    "sudorosa": "sudoroso",
    "sudorosas": "sudoroso",
    "sudorosos": "sudoroso",
    "sudorífera": "sudorífero",
    "sudoríferas": "sudorífero",
    "sudoríferos": "sudorífero",
    "sudorífica": "sudorífico",
    "sudoríficas": "sudorífico",
    "sudoríficos": "sudorífico",
    "sudorípara": "sudoríparo",
    "sudoríparas": "sudoríparo",
    "sudoríparos": "sudoríparo",
    "sudra": "sudro",
    "sudras": "sudro",
    "sudros": "sudro",
    "sudários": "sudário",
    "sudâminas": "sudâmina",
    "sue": "suar",
    "sueca": "sueco",
    "suecas": "sueco",
    "suecos": "sueco",
    "suedes": "suede",
    "suedines": "suedine",
    "suei": "suar",
    "sueis": "suar",
    "suem": "suar",
    "suemo": "suar",
    "suemos": "suar",
    "sues": "suar",
    "suesta": "suestar",
    "suestada": "suestar",
    "suestadas": "suestar",
    "suestado": "suestar",
    "suestados": "suestar",
    "suestai": "suestar",
    "suestais": "suestar",
    "suestam": "suestar",
    "suestamo": "suestar",
    "suestamos": "suestar",
    "suestando": "suestar",
    "suestara": "suestar",
    "suestaram": "suestar",
    "suestaras": "suestar",
    "suestardes": "suestar",
    "suestarei": "suestar",
    "suestareis": "suestar",
    "suestarem": "suestar",
    "suestaremos": "suestar",
    "suestares": "suestar",
    "suestaria": "suestar",
    "suestariam": "suestar",
    "suestarias": "suestar",
    "suestarmo": "suestar",
    "suestarmos": "suestar",
    "suestará": "suestar",
    "suestarás": "suestar",
    "suestarão": "suestar",
    "suestaríamos": "suestar",
    "suestaríeis": "suestar",
    "suestas": "suestar",
    "suestasse": "suestar",
    "suestassem": "suestar",
    "suestasses": "suestar",
    "suestaste": "suestar",
    "suestastes": "suestar",
    "suestava": "suestar",
    "suestavam": "suestar",
    "suestavas": "suestar",
    "sueste": "suestar",
    "suestei": "suestar",
    "suesteis": "suestar",
    "suestem": "suestar",
    "suestemo": "suestar",
    "suestemos": "suestar",
    "suestes": "sueste",
    "suesto": "suestar",
    "suestou": "suestar",
    "suestámo": "suestar",
    "suestámos": "suestar",
    "suestáramo": "suestar",
    "suestáramos": "suestar",
    "suestáreis": "suestar",
    "suestásseis": "suestar",
    "suestássemos": "suestar",
    "suestávamo": "suestar",
    "suestávamos": "suestar",
    "suestáveis": "suestar",
    "suetos": "sueto",
    "sueva": "suevo",
    "suevas": "suevo",
    "suevos": "suevo",
    "sufaraques": "sufaraque",
    "sufarás": "sufará",
    "sufetas": "sufeta",
    "suficientes": "suficiente",
    "suficiências": "suficiência",
    "sufismos": "sufismo",
    "sufistas": "sufista",
    "sufixa": "sufixar",
    "sufixada": "sufixar",
    "sufixadas": "sufixar",
    "sufixado": "sufixar",
    "sufixados": "sufixar",
    "sufixai": "sufixar",
    "sufixais": "sufixar",
    "sufixam": "sufixar",
    "sufixamo": "sufixar",
    "sufixamos": "sufixar",
    "sufixando": "sufixar",
    "sufixara": "sufixar",
    "sufixaram": "sufixar",
    "sufixaras": "sufixar",
    "sufixarde": "sufixar",
    "sufixardes": "sufixar",
    "sufixare": "sufixar",
    "sufixarei": "sufixar",
    "sufixareis": "sufixar",
    "sufixarem": "sufixar",
    "sufixaremos": "sufixar",
    "sufixares": "sufixar",
    "sufixaria": "sufixar",
    "sufixariam": "sufixar",
    "sufixarias": "sufixar",
    "sufixarmo": "sufixar",
    "sufixarmos": "sufixar",
    "sufixará": "sufixar",
    "sufixarás": "sufixar",
    "sufixarão": "sufixar",
    "sufixaríamos": "sufixar",
    "sufixaríeis": "sufixar",
    "sufixas": "sufixar",
    "sufixasse": "sufixar",
    "sufixassem": "sufixar",
    "sufixasses": "sufixar",
    "sufixaste": "sufixar",
    "sufixastes": "sufixar",
    "sufixativa": "sufixativo",
    "sufixativas": "sufixativo",
    "sufixativos": "sufixativo",
    "sufixava": "sufixar",
    "sufixavam": "sufixar",
    "sufixavas": "sufixar",
    "sufixações": "sufixação",
    "sufixe": "sufixar",
    "sufixei": "sufixar",
    "sufixeis": "sufixar",
    "sufixem": "sufixar",
    "sufixemo": "sufixar",
    "sufixemos": "sufixar",
    "sufixes": "sufixar",
    "sufixo": "sufixar",
    "sufixos": "sufixo",
    "sufixou": "sufixar",
    "sufixá": "sufixar",
    "sufixámo": "sufixar",
    "sufixámos": "sufixar",
    "sufixáramo": "sufixar",
    "sufixáramos": "sufixar",
    "sufixárei": "sufixar",
    "sufixáreis": "sufixar",
    "sufixásseis": "sufixar",
    "sufixássemos": "sufixar",
    "sufixávamo": "sufixar",
    "sufixávamos": "sufixar",
    "sufixávei": "sufixar",
    "sufixáveis": "sufixável",
    "sufla": "suflar",
    "suflada": "suflar",
    "sufladas": "suflar",
    "suflado": "suflar",
    "suflados": "suflar",
    "suflai": "suflar",
    "suflais": "suflar",
    "suflam": "suflar",
    "suflamo": "suflar",
    "suflamos": "suflar",
    "suflando": "suflar",
    "suflara": "suflar",
    "suflaram": "suflar",
    "suflaras": "suflar",
    "suflarde": "suflar",
    "suflardes": "suflar",
    "suflare": "suflar",
    "suflarei": "suflar",
    "suflareis": "suflar",
    "suflarem": "suflar",
    "suflaremos": "suflar",
    "suflares": "suflar",
    "suflaria": "suflar",
    "suflariam": "suflar",
    "suflarias": "suflar",
    "suflarmo": "suflar",
    "suflarmos": "suflar",
    "suflará": "suflar",
    "suflarás": "suflar",
    "suflarão": "suflar",
    "suflaríamos": "suflar",
    "suflaríeis": "suflar",
    "suflas": "suflar",
    "suflasse": "suflar",
    "suflassem": "suflar",
    "suflasses": "suflar",
    "suflaste": "suflar",
    "suflastes": "suflar",
    "suflava": "suflar",
    "suflavam": "suflar",
    "suflavas": "suflar",
    "sufle": "suflar",
    "suflei": "suflar",
    "sufleis": "suflar",
    "suflem": "suflar",
    "suflemo": "suflar",
    "suflemos": "suflar",
    "sufles": "suflar",
    "suflo": "suflar",
    "suflou": "suflar",
    "suflá": "suflar",
    "suflámo": "suflar",
    "suflámos": "suflar",
    "sufláramo": "suflar",
    "sufláramos": "suflar",
    "suflárei": "suflar",
    "sufláreis": "suflar",
    "suflásseis": "suflar",
    "suflássemos": "suflar",
    "suflávamo": "suflar",
    "suflávamos": "suflar",
    "suflávei": "suflar",
    "sufláveis": "suflar",
    "suflês": "suflê",
    "sufoca": "sufocar",
    "sufocada": "sufocar",
    "sufocadas": "sufocar",
    "sufocado": "sufocar",
    "sufocadora": "sufocador",
    "sufocadoras": "sufocador",
    "sufocadores": "sufocador",
    "sufocados": "sufocar",
    "sufocadíssima": "sufocado",
    "sufocadíssimas": "sufocado",
    "sufocadíssimo": "sufocado",
    "sufocadíssimos": "sufocado",
    "sufocai": "sufocar",
    "sufocais": "sufocar",
    "sufocam": "sufocar",
    "sufocamentos": "sufocamento",
    "sufocamo": "sufocar",
    "sufocamos": "sufocar",
    "sufocando": "sufocar",
    "sufocantes": "sufocante",
    "sufocara": "sufocar",
    "sufocaram": "sufocar",
    "sufocaras": "sufocar",
    "sufocarde": "sufocar",
    "sufocardes": "sufocar",
    "sufocare": "sufocar",
    "sufocarei": "sufocar",
    "sufocareis": "sufocar",
    "sufocarem": "sufocar",
    "sufocaremos": "sufocar",
    "sufocares": "sufocar",
    "sufocaria": "sufocar",
    "sufocariam": "sufocar",
    "sufocarias": "sufocar",
    "sufocarmo": "sufocar",
    "sufocarmos": "sufocar",
    "sufocará": "sufocar",
    "sufocarás": "sufocar",
    "sufocarão": "sufocar",
    "sufocaríamos": "sufocar",
    "sufocaríeis": "sufocar",
    "sufocas": "sufocar",
    "sufocasse": "sufocar",
    "sufocassem": "sufocar",
    "sufocasses": "sufocar",
    "sufocaste": "sufocar",
    "sufocastes": "sufocar",
    "sufocativa": "sufocativo",
    "sufocativas": "sufocativo",
    "sufocativos": "sufocativo",
    "sufocava": "sufocar",
    "sufocavam": "sufocar",
    "sufocavas": "sufocar",
    "sufocações": "sufocação",
    "sufoco": "sufocar",
    "sufocos": "sufoco",
    "sufocou": "sufocar",
    "sufocá": "sufocar",
    "sufocámo": "sufocar",
    "sufocámos": "sufocar",
    "sufocáramo": "sufocar",
    "sufocáramos": "sufocar",
    "sufocárei": "sufocar",
    "sufocáreis": "sufocar",
    "sufocásseis": "sufocar",
    "sufocássemos": "sufocar",
    "sufocávamo": "sufocar",
    "sufocávamos": "sufocar",
    "sufocávei": "sufocar",
    "sufocáveis": "sufocável",
    "sufoque": "sufocar",
    "sufoquei": "sufocar",
    "sufoqueis": "sufocar",
    "sufoquem": "sufocar",
    "sufoquemo": "sufocar",
    "sufoquemos": "sufocar",
    "sufoques": "sufocar",
    "sufraga": "sufragar",
    "sufragada": "sufragar",
    "sufragadas": "sufragar",
    "sufragado": "sufragar",
    "sufragados": "sufragar",
    "sufragai": "sufragar",
    "sufragais": "sufragar",
    "sufragam": "sufragar",
    "sufragamo": "sufragar",
    "sufragamos": "sufragar",
    "sufragando": "sufragar",
    "sufragara": "sufragar",
    "sufragaram": "sufragar",
    "sufragaras": "sufragar",
    "sufragarde": "sufragar",
    "sufragardes": "sufragar",
    "sufragare": "sufragar",
    "sufragarei": "sufragar",
    "sufragareis": "sufragar",
    "sufragarem": "sufragar",
    "sufragaremos": "sufragar",
    "sufragares": "sufragar",
    "sufragaria": "sufragar",
    "sufragariam": "sufragar",
    "sufragarias": "sufragar",
    "sufragarmo": "sufragar",
    "sufragarmos": "sufragar",
    "sufragará": "sufragar",
    "sufragarás": "sufragar",
    "sufragarão": "sufragar",
    "sufragaríamos": "sufragar",
    "sufragaríeis": "sufragar",
    "sufragas": "sufragar",
    "sufragasse": "sufragar",
    "sufragassem": "sufragar",
    "sufragasses": "sufragar",
    "sufragaste": "sufragar",
    "sufragastes": "sufragar",
    "sufragava": "sufragar",
    "sufragavam": "sufragar",
    "sufragavas": "sufragar",
    "sufragismos": "sufragismo",
    "sufragistas": "sufragista",
    "sufragistazinha": "sufragista",
    "sufragistazinhas": "sufragista",
    "sufragistazinho": "sufragista",
    "sufragistazinhos": "sufragista",
    "sufragistazita": "sufragista",
    "sufragistazitas": "sufragista",
    "sufragistazito": "sufragista",
    "sufragistazitos": "sufragista",
    "sufrago": "sufragar",
    "sufragou": "sufragar",
    "sufrague": "sufragar",
    "sufraguei": "sufragar",
    "sufragueis": "sufragar",
    "sufraguem": "sufragar",
    "sufraguemo": "sufragar",
    "sufraguemos": "sufragar",
    "sufragues": "sufragar",
    "sufragá": "sufragar",
    "sufragámo": "sufragar",
    "sufragámos": "sufragar",
    "sufragáramo": "sufragar",
    "sufragáramos": "sufragar",
    "sufragárei": "sufragar",
    "sufragáreis": "sufragar",
    "sufragásseis": "sufragar",
    "sufragássemos": "sufragar",
    "sufragávamo": "sufragar",
    "sufragávamos": "sufragar",
    "sufragávei": "sufragar",
    "sufragáveis": "sufragar",
    "sufragânea": "sufragâneo",
    "sufragâneas": "sufragâneo",
    "sufragâneos": "sufragâneo",
    "sufrágios": "sufrágio",
    "sufumiga": "sufumigar",
    "sufumigada": "sufumigar",
    "sufumigadas": "sufumigar",
    "sufumigado": "sufumigar",
    "sufumigados": "sufumigar",
    "sufumigai": "sufumigar",
    "sufumigais": "sufumigar",
    "sufumigam": "sufumigar",
    "sufumigamo": "sufumigar",
    "sufumigamos": "sufumigar",
    "sufumigando": "sufumigar",
    "sufumigara": "sufumigar",
    "sufumigaram": "sufumigar",
    "sufumigaras": "sufumigar",
    "sufumigarde": "sufumigar",
    "sufumigardes": "sufumigar",
    "sufumigare": "sufumigar",
    "sufumigarei": "sufumigar",
    "sufumigareis": "sufumigar",
    "sufumigarem": "sufumigar",
    "sufumigaremos": "sufumigar",
    "sufumigares": "sufumigar",
    "sufumigaria": "sufumigar",
    "sufumigariam": "sufumigar",
    "sufumigarias": "sufumigar",
    "sufumigarmo": "sufumigar",
    "sufumigarmos": "sufumigar",
    "sufumigará": "sufumigar",
    "sufumigarás": "sufumigar",
    "sufumigarão": "sufumigar",
    "sufumigaríamos": "sufumigar",
    "sufumigaríeis": "sufumigar",
    "sufumigas": "sufumigar",
    "sufumigasse": "sufumigar",
    "sufumigassem": "sufumigar",
    "sufumigasses": "sufumigar",
    "sufumigaste": "sufumigar",
    "sufumigastes": "sufumigar",
    "sufumigava": "sufumigar",
    "sufumigavam": "sufumigar",
    "sufumigavas": "sufumigar",
    "sufumigações": "sufumigação",
    "sufumigo": "sufumigar",
    "sufumigou": "sufumigar",
    "sufumigue": "sufumigar",
    "sufumiguei": "sufumigar",
    "sufumigueis": "sufumigar",
    "sufumiguem": "sufumigar",
    "sufumiguemo": "sufumigar",
    "sufumiguemos": "sufumigar",
    "sufumigues": "sufumigar",
    "sufumigá": "sufumigar",
    "sufumigámo": "sufumigar",
    "sufumigámos": "sufumigar",
    "sufumigáramo": "sufumigar",
    "sufumigáramos": "sufumigar",
    "sufumigárei": "sufumigar",
    "sufumigáreis": "sufumigar",
    "sufumigásseis": "sufumigar",
    "sufumigássemos": "sufumigar",
    "sufumigávamo": "sufumigar",
    "sufumigávamos": "sufumigar",
    "sufumigávei": "sufumigar",
    "sufumigáveis": "sufumigar",
    "sufumígios": "sufumígio",
    "sufusões": "sufusão",
    "suga": "sugar",
    "sugada": "sugar",
    "sugadas": "sugar",
    "sugado": "sugar",
    "sugadoiros": "sugadoiro",
    "sugadora": "sugador",
    "sugadoras": "sugador",
    "sugadores": "sugador",
    "sugados": "sugar",
    "sugadouros": "sugadouro",
    "sugai": "sugar",
    "sugais": "sugar",
    "sugam": "sugar",
    "sugamo": "sugar",
    "sugamos": "sugar",
    "sugando": "sugar",
    "sugara": "sugar",
    "sugaram": "sugar",
    "sugaras": "sugar",
    "sugarde": "sugar",
    "sugardes": "sugar",
    "sugare": "sugar",
    "sugarei": "sugar",
    "sugareis": "sugar",
    "sugarem": "sugar",
    "sugaremos": "sugar",
    "sugares": "sugar",
    "sugaria": "sugar",
    "sugariam": "sugar",
    "sugarias": "sugar",
    "sugarmo": "sugar",
    "sugarmos": "sugar",
    "sugará": "sugar",
    "sugarás": "sugar",
    "sugarão": "sugar",
    "sugaríamos": "sugar",
    "sugaríeis": "sugar",
    "sugas": "sugar",
    "sugasse": "sugar",
    "sugassem": "sugar",
    "sugasses": "sugar",
    "sugaste": "sugar",
    "sugastes": "sugar",
    "sugava": "sugar",
    "sugavam": "sugar",
    "sugavas": "sugar",
    "sugações": "sugação",
    "sugere": "sugerir",
    "sugerem": "sugerir",
    "sugeres": "sugerir",
    "sugeri": "sugerir",
    "sugeria": "sugerir",
    "sugeriam": "sugerir",
    "sugerias": "sugerir",
    "sugerida": "sugerir",
    "sugeridas": "sugerir",
    "sugerido": "sugerir",
    "sugeridos": "sugerir",
    "sugerimo": "sugerir",
    "sugerimos": "sugerir",
    "sugerindo": "sugerir",
    "sugerira": "sugerir",
    "sugeriram": "sugerir",
    "sugeriras": "sugerir",
    "sugerirde": "sugerir",
    "sugerirdes": "sugerir",
    "sugerire": "sugerir",
    "sugerirei": "sugerir",
    "sugerireis": "sugerir",
    "sugerirem": "sugerir",
    "sugeriremos": "sugerir",
    "sugerires": "sugerir",
    "sugeriria": "sugerir",
    "sugeririam": "sugerir",
    "sugeririas": "sugerir",
    "sugerirmo": "sugerir",
    "sugerirmos": "sugerir",
    "sugerirá": "sugerir",
    "sugerirás": "sugerir",
    "sugerirão": "sugerir",
    "sugeriríamos": "sugerir",
    "sugeriríeis": "sugerir",
    "sugeris": "sugerir",
    "sugerisse": "sugerir",
    "sugerissem": "sugerir",
    "sugerisses": "sugerir",
    "sugeriste": "sugerir",
    "sugeristes": "sugerir",
    "sugeriu": "sugerir",
    "sugeríamo": "sugerir",
    "sugeríamos": "sugerir",
    "sugeríei": "sugerir",
    "sugeríeis": "sugerir",
    "sugeríramo": "sugerir",
    "sugeríramos": "sugerir",
    "sugerírei": "sugerir",
    "sugeríreis": "sugerir",
    "sugerísseis": "sugerir",
    "sugeríssemos": "sugerir",
    "sugeríveis": "sugerível",
    "sugestibilidades": "sugestibilidade",
    "sugestiona": "sugestionar",
    "sugestionada": "sugestionar",
    "sugestionadas": "sugestionar",
    "sugestionado": "sugestionar",
    "sugestionados": "sugestionar",
    "sugestionai": "sugestionar",
    "sugestionais": "sugestionar",
    "sugestionam": "sugestionar",
    "sugestionamo": "sugestionar",
    "sugestionamos": "sugestionar",
    "sugestionando": "sugestionar",
    "sugestionara": "sugestionar",
    "sugestionaram": "sugestionar",
    "sugestionaras": "sugestionar",
    "sugestionarde": "sugestionar",
    "sugestionardes": "sugestionar",
    "sugestionare": "sugestionar",
    "sugestionarei": "sugestionar",
    "sugestionareis": "sugestionar",
    "sugestionarem": "sugestionar",
    "sugestionaremos": "sugestionar",
    "sugestionares": "sugestionar",
    "sugestionaria": "sugestionar",
    "sugestionariam": "sugestionar",
    "sugestionarias": "sugestionar",
    "sugestionarmo": "sugestionar",
    "sugestionarmos": "sugestionar",
    "sugestionará": "sugestionar",
    "sugestionarás": "sugestionar",
    "sugestionarão": "sugestionar",
    "sugestionaríamos": "sugestionar",
    "sugestionaríeis": "sugestionar",
    "sugestionas": "sugestionar",
    "sugestionasse": "sugestionar",
    "sugestionassem": "sugestionar",
    "sugestionasses": "sugestionar",
    "sugestionaste": "sugestionar",
    "sugestionastes": "sugestionar",
    "sugestionava": "sugestionar",
    "sugestionavam": "sugestionar",
    "sugestionavas": "sugestionar",
    "sugestione": "sugestionar",
    "sugestionei": "sugestionar",
    "sugestioneis": "sugestionar",
    "sugestionem": "sugestionar",
    "sugestionemo": "sugestionar",
    "sugestionemos": "sugestionar",
    "sugestiones": "sugestionar",
    "sugestiono": "sugestionar",
    "sugestionou": "sugestionar",
    "sugestioná": "sugestionar",
    "sugestionámo": "sugestionar",
    "sugestionámos": "sugestionar",
    "sugestionáramo": "sugestionar",
    "sugestionáramos": "sugestionar",
    "sugestionárei": "sugestionar",
    "sugestionáreis": "sugestionar",
    "sugestionásseis": "sugestionar",
    "sugestionássemos": "sugestionar",
    "sugestionávamo": "sugestionar",
    "sugestionávamos": "sugestionar",
    "sugestionávei": "sugestionar",
    "sugestionáveis": "sugestionável",
    "sugestiva": "sugestivo",
    "sugestivas": "sugestivo",
    "sugestivos": "sugestivo",
    "sugestos": "sugesto",
    "sugestíveis": "sugestível",
    "sugestões": "sugestão",
    "sugila": "sugilar",
    "sugilada": "sugilar",
    "sugiladas": "sugilar",
    "sugilado": "sugilar",
    "sugilados": "sugilar",
    "sugilai": "sugilar",
    "sugilais": "sugilar",
    "sugilam": "sugilar",
    "sugilamo": "sugilar",
    "sugilamos": "sugilar",
    "sugilando": "sugilar",
    "sugilara": "sugilar",
    "sugilaram": "sugilar",
    "sugilaras": "sugilar",
    "sugilarde": "sugilar",
    "sugilardes": "sugilar",
    "sugilare": "sugilar",
    "sugilarei": "sugilar",
    "sugilareis": "sugilar",
    "sugilarem": "sugilar",
    "sugilaremos": "sugilar",
    "sugilares": "sugilar",
    "sugilaria": "sugilar",
    "sugilariam": "sugilar",
    "sugilarias": "sugilar",
    "sugilarmo": "sugilar",
    "sugilarmos": "sugilar",
    "sugilará": "sugilar",
    "sugilarás": "sugilar",
    "sugilarão": "sugilar",
    "sugilaríamos": "sugilar",
    "sugilaríeis": "sugilar",
    "sugilas": "sugilar",
    "sugilasse": "sugilar",
    "sugilassem": "sugilar",
    "sugilasses": "sugilar",
    "sugilaste": "sugilar",
    "sugilastes": "sugilar",
    "sugilava": "sugilar",
    "sugilavam": "sugilar",
    "sugilavas": "sugilar",
    "sugilações": "sugilação",
    "sugile": "sugilar",
    "sugilei": "sugilar",
    "sugileis": "sugilar",
    "sugilem": "sugilar",
    "sugilemo": "sugilar",
    "sugilemos": "sugilar",
    "sugiles": "sugilar",
    "sugilo": "sugilar",
    "sugilou": "sugilar",
    "sugilá": "sugilar",
    "sugilámo": "sugilar",
    "sugilámos": "sugilar",
    "sugiláramo": "sugilar",
    "sugiláramos": "sugilar",
    "sugilárei": "sugilar",
    "sugiláreis": "sugilar",
    "sugilásseis": "sugilar",
    "sugilássemos": "sugilar",
    "sugilávamo": "sugilar",
    "sugilávamos": "sugilar",
    "sugilávei": "sugilar",
    "sugiláveis": "sugilar",
    "sugira": "sugerir",
    "sugirais": "sugerir",
    "sugiram": "sugerir",
    "sugiramo": "sugerir",
    "sugiramos": "sugerir",
    "sugiras": "sugerir",
    "sugiro": "sugerir",
    "sugo": "sugar",
    "sugos": "sugo",
    "sugou": "sugar",
    "sugue": "sugar",
    "suguei": "sugar",
    "sugueis": "sugar",
    "suguem": "sugar",
    "suguemo": "sugar",
    "suguemos": "sugar",
    "sugues": "sugar",
    "sugá": "sugar",
    "sugámo": "sugar",
    "sugámos": "sugar",
    "sugáramo": "sugar",
    "sugáramos": "sugar",
    "sugárei": "sugar",
    "sugáreis": "sugar",
    "sugásseis": "sugar",
    "sugássemos": "sugar",
    "sugávamo": "sugar",
    "sugávamos": "sugar",
    "sugávei": "sugar",
    "sugáveis": "sugar",
    "suicida": "suicidar",
    "suicidada": "suicidar",
    "suicidadas": "suicidar",
    "suicidado": "suicidar",
    "suicidados": "suicidar",
    "suicidai": "suicidar",
    "suicidais": "suicidar",
    "suicidam": "suicidar",
    "suicidamo": "suicidar",
    "suicidamos": "suicidar",
    "suicidando": "suicidar",
    "suicidara": "suicidar",
    "suicidaram": "suicidar",
    "suicidaras": "suicidar",
    "suicidarde": "suicidar",
    "suicidardes": "suicidar",
    "suicidare": "suicidar",
    "suicidarei": "suicidar",
    "suicidareis": "suicidar",
    "suicidarem": "suicidar",
    "suicidaremos": "suicidar",
    "suicidares": "suicidar",
    "suicidaria": "suicidar",
    "suicidariam": "suicidar",
    "suicidarias": "suicidar",
    "suicidarmo": "suicidar",
    "suicidarmos": "suicidar",
    "suicidará": "suicidar",
    "suicidarás": "suicidar",
    "suicidarão": "suicidar",
    "suicidaríamos": "suicidar",
    "suicidaríeis": "suicidar",
    "suicidas": "suicidar",
    "suicidasse": "suicidar",
    "suicidassem": "suicidar",
    "suicidasses": "suicidar",
    "suicidaste": "suicidar",
    "suicidastes": "suicidar",
    "suicidava": "suicidar",
    "suicidavam": "suicidar",
    "suicidavas": "suicidar",
    "suicidazinha": "suicida",
    "suicidazinhas": "suicida",
    "suicidazinho": "suicida",
    "suicidazinhos": "suicida",
    "suicidazita": "suicida",
    "suicidazitas": "suicida",
    "suicidazito": "suicida",
    "suicidazitos": "suicida",
    "suicide": "suicidar",
    "suicidei": "suicidar",
    "suicideis": "suicidar",
    "suicidem": "suicidar",
    "suicidemo": "suicidar",
    "suicidemos": "suicidar",
    "suicides": "suicidar",
    "suicidiologias": "suicidiologia",
    "suicido": "suicidar",
    "suicidomanias": "suicidomania",
    "suicidomaníaca": "suicidomaníaco",
    "suicidomaníacas": "suicidomaníaco",
    "suicidomaníacos": "suicidomaníaco",
    "suicidou": "suicidar",
    "suicidá": "suicidar",
    "suicidámo": "suicidar",
    "suicidámos": "suicidar",
    "suicidáramo": "suicidar",
    "suicidáramos": "suicidar",
    "suicidárei": "suicidar",
    "suicidáreis": "suicidar",
    "suicidária": "suicidário",
    "suicidárias": "suicidário",
    "suicidários": "suicidário",
    "suicidásseis": "suicidar",
    "suicidássemos": "suicidar",
    "suicidávamo": "suicidar",
    "suicidávamos": "suicidar",
    "suicidávei": "suicidar",
    "suicidáveis": "suicidar",
    "suicídios": "suicídio",
    "suinazinha": "suíno",
    "suinazinhas": "suíno",
    "suinazita": "suíno",
    "suinazitas": "suíno",
    "suingues": "suingue",
    "suinicultora": "suinicultor",
    "suinicultoras": "suinicultor",
    "suinicultores": "suinicultor",
    "suiniculturas": "suinicultura",
    "suinozinho": "suíno",
    "suinozinhos": "suíno",
    "suinozito": "suíno",
    "suinozitos": "suíno",
    "suis": "sul",
    "suites": "suite",
    "suiçazinha": "suíço",
    "suiçazinhas": "suíço",
    "suiçazita": "suíço",
    "suiçazitas": "suíço",
    "suiçozinho": "suíço",
    "suiçozinhos": "suíço",
    "suiçozito": "suíço",
    "suiçozitos": "suíço",
    "suja": "sujo",
    "sujada": "sujar",
    "sujadas": "sujar",
    "sujado": "sujar",
    "sujadora": "sujador",
    "sujadoras": "sujador",
    "sujadores": "sujador",
    "sujados": "sujar",
    "sujai": "sujar",
    "sujais": "sujar",
    "sujam": "sujar",
    "sujamo": "sujar",
    "sujamos": "sujar",
    "sujando": "sujar",
    "sujara": "sujar",
    "sujaram": "sujar",
    "sujaras": "sujar",
    "sujarde": "sujar",
    "sujardes": "sujar",
    "sujare": "sujar",
    "sujarei": "sujar",
    "sujareis": "sujar",
    "sujarem": "sujar",
    "sujaremos": "sujar",
    "sujares": "sujar",
    "sujaria": "sujar",
    "sujariam": "sujar",
    "sujarias": "sujar",
    "sujarmo": "sujar",
    "sujarmos": "sujar",
    "sujará": "sujar",
    "sujarás": "sujar",
    "sujarão": "sujar",
    "sujaríamos": "sujar",
    "sujaríeis": "sujar",
    "sujas": "sujo",
    "sujasse": "sujar",
    "sujassem": "sujar",
    "sujasses": "sujar",
    "sujaste": "sujar",
    "sujastes": "sujar",
    "sujava": "sujar",
    "sujavam": "sujar",
    "sujavas": "sujar",
    "suje": "sujar",
    "sujei": "sujar",
    "sujeiras": "sujeira",
    "sujeis": "sujar",
    "sujeita": "sujeito",
    "sujeitada": "sujeitar",
    "sujeitadas": "sujeitar",
    "sujeitado": "sujeitar",
    "sujeitadora": "sujeitador",
    "sujeitadoras": "sujeitador",
    "sujeitadores": "sujeitador",
    "sujeitados": "sujeitar",
    "sujeitai": "sujeitar",
    "sujeitais": "sujeitar",
    "sujeitam": "sujeitar",
    "sujeitamo": "sujeitar",
    "sujeitamos": "sujeitar",
    "sujeitando": "sujeitar",
    "sujeitara": "sujeitar",
    "sujeitaram": "sujeitar",
    "sujeitaras": "sujeitar",
    "sujeitarde": "sujeitar",
    "sujeitardes": "sujeitar",
    "sujeitare": "sujeitar",
    "sujeitarei": "sujeitar",
    "sujeitareis": "sujeitar",
    "sujeitarem": "sujeitar",
    "sujeitaremos": "sujeitar",
    "sujeitares": "sujeitar",
    "sujeitaria": "sujeitar",
    "sujeitariam": "sujeitar",
    "sujeitarias": "sujeitar",
    "sujeitarmo": "sujeitar",
    "sujeitarmos": "sujeitar",
    "sujeitará": "sujeitar",
    "sujeitarás": "sujeitar",
    "sujeitarão": "sujeitar",
    "sujeitaríamos": "sujeitar",
    "sujeitaríeis": "sujeitar",
    "sujeitas": "sujeito",
    "sujeitasse": "sujeitar",
    "sujeitassem": "sujeitar",
    "sujeitasses": "sujeitar",
    "sujeitaste": "sujeitar",
    "sujeitastes": "sujeitar",
    "sujeitava": "sujeitar",
    "sujeitavam": "sujeitar",
    "sujeitavas": "sujeitar",
    "sujeitazinha": "sujeito",
    "sujeitazinhas": "sujeito",
    "sujeitazita": "sujeito",
    "sujeitazitas": "sujeito",
    "sujeite": "sujeitar",
    "sujeitei": "sujeitar",
    "sujeiteis": "sujeitar",
    "sujeitem": "sujeitar",
    "sujeitemo": "sujeitar",
    "sujeitemos": "sujeitar",
    "sujeites": "sujeitar",
    "sujeito": "sujeitar",
    "sujeitos": "sujeito",
    "sujeitou": "sujeitar",
    "sujeitozinho": "sujeito",
    "sujeitozinhos": "sujeito",
    "sujeitozito": "sujeito",
    "sujeitozitos": "sujeito",
    "sujeitá": "sujeitar",
    "sujeitámo": "sujeitar",
    "sujeitámos": "sujeitar",
    "sujeitáramo": "sujeitar",
    "sujeitáramos": "sujeitar",
    "sujeitárei": "sujeitar",
    "sujeitáreis": "sujeitar",
    "sujeitásseis": "sujeitar",
    "sujeitássemos": "sujeitar",
    "sujeitávamo": "sujeitar",
    "sujeitávamos": "sujeitar",
    "sujeitávei": "sujeitar",
    "sujeitáveis": "sujeitável",
    "sujeitória": "sujeitório",
    "sujeitórias": "sujeitório",
    "sujeitórios": "sujeitório",
    "sujeições": "sujeição",
    "sujem": "sujar",
    "sujemo": "sujar",
    "sujemos": "sujar",
    "sujes": "sujar",
    "sujidades": "sujidade",
    "sujo": "sujar",
    "sujos": "sujo",
    "sujou": "sujar",
    "sujá": "sujar",
    "sujámo": "sujar",
    "sujámos": "sujar",
    "sujáramo": "sujar",
    "sujáramos": "sujar",
    "sujárei": "sujar",
    "sujáreis": "sujar",
    "sujásseis": "sujar",
    "sujássemos": "sujar",
    "sujávamo": "sujar",
    "sujávamos": "sujar",
    "sujávei": "sujar",
    "sujáveis": "sujar",
    "sujíssima": "sujo",
    "sujíssimas": "sujo",
    "sujíssimo": "sujo",
    "sujíssimos": "sujo",
    "sulana": "sulano",
    "sulanas": "sulano",
    "sulanos": "sulano",
    "sulas": "sula",
    "sulaventeada": "sulaventear",
    "sulaventeadas": "sulaventear",
    "sulaventeado": "sulaventear",
    "sulaventeados": "sulaventear",
    "sulaventeai": "sulaventear",
    "sulaventeais": "sulaventear",
    "sulaventeamo": "sulaventear",
    "sulaventeamos": "sulaventear",
    "sulaventeando": "sulaventear",
    "sulaventeara": "sulaventear",
    "sulaventearam": "sulaventear",
    "sulaventearas": "sulaventear",
    "sulaventeardes": "sulaventear",
    "sulaventearei": "sulaventear",
    "sulaventeareis": "sulaventear",
    "sulaventearem": "sulaventear",
    "sulaventearemos": "sulaventear",
    "sulaventeares": "sulaventear",
    "sulaventearia": "sulaventear",
    "sulaventeariam": "sulaventear",
    "sulaventearias": "sulaventear",
    "sulaventearmo": "sulaventear",
    "sulaventearmos": "sulaventear",
    "sulaventeará": "sulaventear",
    "sulaventearás": "sulaventear",
    "sulaventearão": "sulaventear",
    "sulaventearíamos": "sulaventear",
    "sulaventearíeis": "sulaventear",
    "sulaventeasse": "sulaventear",
    "sulaventeassem": "sulaventear",
    "sulaventeasses": "sulaventear",
    "sulaventeaste": "sulaventear",
    "sulaventeastes": "sulaventear",
    "sulaventeava": "sulaventear",
    "sulaventeavam": "sulaventear",
    "sulaventeavas": "sulaventear",
    "sulaventeei": "sulaventear",
    "sulaventeeis": "sulaventear",
    "sulaventeemo": "sulaventear",
    "sulaventeemos": "sulaventear",
    "sulaventeia": "sulaventear",
    "sulaventeiam": "sulaventear",
    "sulaventeias": "sulaventear",
    "sulaventeie": "sulaventear",
    "sulaventeiem": "sulaventear",
    "sulaventeies": "sulaventear",
    "sulaventeio": "sulaventear",
    "sulaventeou": "sulaventear",
    "sulaventeámo": "sulaventear",
    "sulaventeámos": "sulaventear",
    "sulaventeáramo": "sulaventear",
    "sulaventeáramos": "sulaventear",
    "sulaventeáreis": "sulaventear",
    "sulaventeásseis": "sulaventear",
    "sulaventeássemos": "sulaventear",
    "sulaventeávamo": "sulaventear",
    "sulaventeávamos": "sulaventear",
    "sulaventeáveis": "sulaventear",
    "sulaventos": "sulavento",
    "sulca": "sulcar",
    "sulcada": "sulcar",
    "sulcadas": "sulcar",
    "sulcado": "sulcar",
    "sulcadora": "sulcador",
    "sulcadoras": "sulcador",
    "sulcadores": "sulcador",
    "sulcados": "sulcar",
    "sulcai": "sulcar",
    "sulcais": "sulcar",
    "sulcam": "sulcar",
    "sulcamo": "sulcar",
    "sulcamos": "sulcar",
    "sulcando": "sulcar",
    "sulcara": "sulcar",
    "sulcaram": "sulcar",
    "sulcaras": "sulcar",
    "sulcarde": "sulcar",
    "sulcardes": "sulcar",
    "sulcare": "sulcar",
    "sulcarei": "sulcar",
    "sulcareis": "sulcar",
    "sulcarem": "sulcar",
    "sulcaremos": "sulcar",
    "sulcares": "sulcar",
    "sulcaria": "sulcar",
    "sulcariam": "sulcar",
    "sulcarias": "sulcar",
    "sulcarmo": "sulcar",
    "sulcarmos": "sulcar",
    "sulcará": "sulcar",
    "sulcarás": "sulcar",
    "sulcarão": "sulcar",
    "sulcaríamos": "sulcar",
    "sulcaríeis": "sulcar",
    "sulcas": "sulcar",
    "sulcasse": "sulcar",
    "sulcassem": "sulcar",
    "sulcasses": "sulcar",
    "sulcaste": "sulcar",
    "sulcastes": "sulcar",
    "sulcava": "sulcar",
    "sulcavam": "sulcar",
    "sulcavas": "sulcar",
    "sulciformes": "sulciforme",
    "sulcirrostra": "sulcirrostro",
    "sulcirrostras": "sulcirrostro",
    "sulcirrostros": "sulcirrostro",
    "sulco": "sulcar",
    "sulcos": "sulco",
    "sulcou": "sulcar",
    "sulcá": "sulcar",
    "sulcámo": "sulcar",
    "sulcámos": "sulcar",
    "sulcáramo": "sulcar",
    "sulcáramos": "sulcar",
    "sulcárei": "sulcar",
    "sulcáreis": "sulcar",
    "sulcásseis": "sulcar",
    "sulcássemos": "sulcar",
    "sulcávamo": "sulcar",
    "sulcávamos": "sulcar",
    "sulcávei": "sulcar",
    "sulcáveis": "sulcar",
    "sulcífera": "sulcífero",
    "sulcíferas": "sulcífero",
    "sulcíferos": "sulcífero",
    "sulenta": "sulento",
    "sulentas": "sulento",
    "sulentos": "sulento",
    "sulfamidas": "sulfamida",
    "sulfanilamidas": "sulfanilamida",
    "sulfata": "sulfatar",
    "sulfatada": "sulfatar",
    "sulfatadas": "sulfatar",
    "sulfatadeiras": "sulfatadeira",
    "sulfatado": "sulfatar",
    "sulfatadora": "sulfatador",
    "sulfatadoras": "sulfatador",
    "sulfatadores": "sulfatador",
    "sulfatados": "sulfatar",
    "sulfatagens": "sulfatagem",
    "sulfatai": "sulfatar",
    "sulfatais": "sulfatar",
    "sulfatam": "sulfatar",
    "sulfatamo": "sulfatar",
    "sulfatamos": "sulfatar",
    "sulfatando": "sulfatar",
    "sulfatara": "sulfatar",
    "sulfataram": "sulfatar",
    "sulfataras": "sulfatara",
    "sulfatarde": "sulfatar",
    "sulfatardes": "sulfatar",
    "sulfatare": "sulfatar",
    "sulfatarei": "sulfatar",
    "sulfatareis": "sulfatar",
    "sulfatarem": "sulfatar",
    "sulfataremos": "sulfatar",
    "sulfatares": "sulfatar",
    "sulfataria": "sulfatar",
    "sulfatariam": "sulfatar",
    "sulfatarias": "sulfatar",
    "sulfatarmo": "sulfatar",
    "sulfatarmos": "sulfatar",
    "sulfatará": "sulfatar",
    "sulfatarás": "sulfatar",
    "sulfatarão": "sulfatar",
    "sulfataríamos": "sulfatar",
    "sulfataríeis": "sulfatar",
    "sulfatas": "sulfatar",
    "sulfatasse": "sulfatar",
    "sulfatassem": "sulfatar",
    "sulfatasses": "sulfatar",
    "sulfataste": "sulfatar",
    "sulfatastes": "sulfatar",
    "sulfatava": "sulfatar",
    "sulfatavam": "sulfatar",
    "sulfatavas": "sulfatar",
    "sulfatações": "sulfatação",
    "sulfate": "sulfatar",
    "sulfatei": "sulfatar",
    "sulfateis": "sulfatar",
    "sulfatem": "sulfatar",
    "sulfatemo": "sulfatar",
    "sulfatemos": "sulfatar",
    "sulfates": "sulfatar",
    "sulfatiza": "sulfatizar",
    "sulfatizada": "sulfatizar",
    "sulfatizadas": "sulfatizar",
    "sulfatizado": "sulfatizar",
    "sulfatizados": "sulfatizar",
    "sulfatizai": "sulfatizar",
    "sulfatizais": "sulfatizar",
    "sulfatizam": "sulfatizar",
    "sulfatizamo": "sulfatizar",
    "sulfatizamos": "sulfatizar",
    "sulfatizando": "sulfatizar",
    "sulfatizara": "sulfatizar",
    "sulfatizaram": "sulfatizar",
    "sulfatizaras": "sulfatizar",
    "sulfatizarde": "sulfatizar",
    "sulfatizardes": "sulfatizar",
    "sulfatizare": "sulfatizar",
    "sulfatizarei": "sulfatizar",
    "sulfatizareis": "sulfatizar",
    "sulfatizarem": "sulfatizar",
    "sulfatizaremos": "sulfatizar",
    "sulfatizares": "sulfatizar",
    "sulfatizaria": "sulfatizar",
    "sulfatizariam": "sulfatizar",
    "sulfatizarias": "sulfatizar",
    "sulfatizarmo": "sulfatizar",
    "sulfatizarmos": "sulfatizar",
    "sulfatizará": "sulfatizar",
    "sulfatizarás": "sulfatizar",
    "sulfatizarão": "sulfatizar",
    "sulfatizaríamos": "sulfatizar",
    "sulfatizaríeis": "sulfatizar",
    "sulfatizas": "sulfatizar",
    "sulfatizasse": "sulfatizar",
    "sulfatizassem": "sulfatizar",
    "sulfatizasses": "sulfatizar",
    "sulfatizaste": "sulfatizar",
    "sulfatizastes": "sulfatizar",
    "sulfatizava": "sulfatizar",
    "sulfatizavam": "sulfatizar",
    "sulfatizavas": "sulfatizar",
    "sulfatizações": "sulfatização",
    "sulfatize": "sulfatizar",
    "sulfatizei": "sulfatizar",
    "sulfatizeis": "sulfatizar",
    "sulfatizem": "sulfatizar",
    "sulfatizemo": "sulfatizar",
    "sulfatizemos": "sulfatizar",
    "sulfatizes": "sulfatizar",
    "sulfatizo": "sulfatizar",
    "sulfatizou": "sulfatizar",
    "sulfatizá": "sulfatizar",
    "sulfatizámo": "sulfatizar",
    "sulfatizámos": "sulfatizar",
    "sulfatizáramo": "sulfatizar",
    "sulfatizáramos": "sulfatizar",
    "sulfatizárei": "sulfatizar",
    "sulfatizáreis": "sulfatizar",
    "sulfatizásseis": "sulfatizar",
    "sulfatizássemos": "sulfatizar",
    "sulfatizávamo": "sulfatizar",
    "sulfatizávamos": "sulfatizar",
    "sulfatizávei": "sulfatizar",
    "sulfatizáveis": "sulfatizar",
    "sulfato": "sulfatar",
    "sulfatos": "sulfato",
    "sulfatou": "sulfatar",
    "sulfatá": "sulfatar",
    "sulfatámo": "sulfatar",
    "sulfatámos": "sulfatar",
    "sulfatáramo": "sulfatar",
    "sulfatáramos": "sulfatar",
    "sulfatárei": "sulfatar",
    "sulfatáreis": "sulfatar",
    "sulfatásseis": "sulfatar",
    "sulfatássemos": "sulfatar",
    "sulfatávamo": "sulfatar",
    "sulfatávamos": "sulfatar",
    "sulfatávei": "sulfatar",
    "sulfatáveis": "sulfatar",
    "sulfetações": "sulfetação",
    "sulfetos": "sulfeto",
    "sulfidrometrias": "sulfidrometria",
    "sulfitos": "sulfito",
    "sulfobactérias": "sulfobactéria",
    "sulfonais": "sulfonal",
    "sulfonamidas": "sulfonamida",
    "sulfonitros": "sulfonitro",
    "sulfoxilatos": "sulfoxilato",
    "sulfura": "sulfurar",
    "sulfurada": "sulfurar",
    "sulfuradas": "sulfurar",
    "sulfuradeiras": "sulfuradeira",
    "sulfurado": "sulfurar",
    "sulfuradores": "sulfurador",
    "sulfurados": "sulfurar",
    "sulfurai": "sulfurar",
    "sulfurais": "sulfurar",
    "sulfuram": "sulfurar",
    "sulfuramo": "sulfurar",
    "sulfuramos": "sulfurar",
    "sulfurando": "sulfurar",
    "sulfurara": "sulfurar",
    "sulfuraram": "sulfurar",
    "sulfuraras": "sulfurar",
    "sulfurarde": "sulfurar",
    "sulfurardes": "sulfurar",
    "sulfurare": "sulfurar",
    "sulfurarei": "sulfurar",
    "sulfurareis": "sulfurar",
    "sulfurarem": "sulfurar",
    "sulfuraremos": "sulfurar",
    "sulfurares": "sulfurar",
    "sulfuraria": "sulfurar",
    "sulfurariam": "sulfurar",
    "sulfurarias": "sulfurar",
    "sulfurarmo": "sulfurar",
    "sulfurarmos": "sulfurar",
    "sulfurará": "sulfurar",
    "sulfurarás": "sulfurar",
    "sulfurarão": "sulfurar",
    "sulfuraríamos": "sulfurar",
    "sulfuraríeis": "sulfurar",
    "sulfuras": "sulfurar",
    "sulfurasse": "sulfurar",
    "sulfurassem": "sulfurar",
    "sulfurasses": "sulfurar",
    "sulfuraste": "sulfurar",
    "sulfurastes": "sulfurar",
    "sulfurava": "sulfurar",
    "sulfuravam": "sulfurar",
    "sulfuravas": "sulfurar",
    "sulfurações": "sulfuração",
    "sulfure": "sulfurar",
    "sulfurei": "sulfurar",
    "sulfureiras": "sulfureira",
    "sulfureis": "sulfurar",
    "sulfurem": "sulfurar",
    "sulfuremo": "sulfurar",
    "sulfuremos": "sulfurar",
    "sulfures": "sulfurar",
    "sulfuretações": "sulfuretação",
    "sulfuretos": "sulfureto",
    "sulfurina": "sulfurino",
    "sulfurinas": "sulfurino",
    "sulfurinos": "sulfurino",
    "sulfurizações": "sulfurização",
    "sulfuro": "sulfurar",
    "sulfurosa": "sulfuroso",
    "sulfurosas": "sulfuroso",
    "sulfurosos": "sulfuroso",
    "sulfurou": "sulfurar",
    "sulfurá": "sulfurar",
    "sulfurámo": "sulfurar",
    "sulfurámos": "sulfurar",
    "sulfuráramo": "sulfurar",
    "sulfuráramos": "sulfurar",
    "sulfurárei": "sulfurar",
    "sulfuráreis": "sulfurar",
    "sulfurásseis": "sulfurar",
    "sulfurássemos": "sulfurar",
    "sulfurávamo": "sulfurar",
    "sulfurávamos": "sulfurar",
    "sulfurávei": "sulfurar",
    "sulfuráveis": "sulfurável",
    "sulfídrica": "sulfídrico",
    "sulfídricas": "sulfídrico",
    "sulfídricos": "sulfídrico",
    "sulfónica": "sulfónico",
    "sulfónicas": "sulfónico",
    "sulfónicos": "sulfónico",
    "sulfúrea": "sulfúreo",
    "sulfúreas": "sulfúreo",
    "sulfúreos": "sulfúreo",
    "sulfúrica": "sulfúrico",
    "sulfúricas": "sulfúrico",
    "sulfúricos": "sulfúrico",
    "sulina": "sulino",
    "sulinas": "sulino",
    "sulinos": "sulino",
    "sulipas": "sulipa",
    "sulistas": "sulista",
    "sulistazinha": "sulista",
    "sulistazinhas": "sulista",
    "sulistazinho": "sulista",
    "sulistazinhos": "sulista",
    "sulistazita": "sulista",
    "sulistazitas": "sulista",
    "sulistazito": "sulista",
    "sulistazitos": "sulista",
    "sulmonenses": "sulmonense",
    "sulque": "sulcar",
    "sulquei": "sulcar",
    "sulqueis": "sulcar",
    "sulquem": "sulcar",
    "sulquemo": "sulcar",
    "sulquemos": "sulcar",
    "sulques": "sulcar",
    "sultana": "sultão",
    "sultanados": "sultanado",
    "sultanas": "sultão",
    "sultanatos": "sultanato",
    "sultanesca": "sultanesco",
    "sultanescas": "sultanesco",
    "sultanescos": "sultanesco",
    "sultanias": "sultania",
    "sultaninos": "sultanino",
    "sultanis": "sultani",
    "sults": "sultão",
    "sultânica": "sultânico",
    "sultânicas": "sultânico",
    "sultânicos": "sultânico",
    "sultães": "sultão",
    "sultões": "sultão",
    "sulventos": "sulvento",
    "sulídeos": "sulídeo",
    "suma": "sumir",
    "sumacas": "sumaca",
    "sumagra": "sumagrar",
    "sumagrada": "sumagrar",
    "sumagradas": "sumagrar",
    "sumagrado": "sumagrar",
    "sumagrados": "sumagrar",
    "sumagrai": "sumagrar",
    "sumagrais": "sumagrar",
    "sumagram": "sumagrar",
    "sumagramo": "sumagrar",
    "sumagramos": "sumagrar",
    "sumagrando": "sumagrar",
    "sumagrara": "sumagrar",
    "sumagraram": "sumagrar",
    "sumagraras": "sumagrar",
    "sumagrarde": "sumagrar",
    "sumagrardes": "sumagrar",
    "sumagrare": "sumagrar",
    "sumagrarei": "sumagrar",
    "sumagrareis": "sumagrar",
    "sumagrarem": "sumagrar",
    "sumagraremos": "sumagrar",
    "sumagrares": "sumagrar",
    "sumagraria": "sumagrar",
    "sumagrariam": "sumagrar",
    "sumagrarias": "sumagrar",
    "sumagrarmo": "sumagrar",
    "sumagrarmos": "sumagrar",
    "sumagrará": "sumagrar",
    "sumagrarás": "sumagrar",
    "sumagrarão": "sumagrar",
    "sumagraríamos": "sumagrar",
    "sumagraríeis": "sumagrar",
    "sumagras": "sumagrar",
    "sumagrasse": "sumagrar",
    "sumagrassem": "sumagrar",
    "sumagrasses": "sumagrar",
    "sumagraste": "sumagrar",
    "sumagrastes": "sumagrar",
    "sumagrava": "sumagrar",
    "sumagravam": "sumagrar",
    "sumagravas": "sumagrar",
    "sumagre": "sumagrar",
    "sumagrei": "sumagrar",
    "sumagreiras": "sumagreira",
    "sumagreiros": "sumagreiro",
    "sumagreis": "sumagrar",
    "sumagrem": "sumagrar",
    "sumagremo": "sumagrar",
    "sumagremos": "sumagrar",
    "sumagres": "sumagre",
    "sumagro": "sumagrar",
    "sumagrou": "sumagrar",
    "sumagrá": "sumagrar",
    "sumagrámo": "sumagrar",
    "sumagrámos": "sumagrar",
    "sumagráramo": "sumagrar",
    "sumagráramos": "sumagrar",
    "sumagrárei": "sumagrar",
    "sumagráreis": "sumagrar",
    "sumagrásseis": "sumagrar",
    "sumagrássemos": "sumagrar",
    "sumagrávamo": "sumagrar",
    "sumagrávamos": "sumagrar",
    "sumagrávei": "sumagrar",
    "sumagráveis": "sumagrar",
    "sumais": "sumir",
    "sumam": "sumir",
    "sumamo": "sumir",
    "sumamos": "sumir",
    "sumarenta": "sumarento",
    "sumarentas": "sumarento",
    "sumarentos": "sumarento",
    "sumaria": "sumariar",
    "sumariada": "sumariar",
    "sumariadas": "sumariar",
    "sumariado": "sumariar",
    "sumariados": "sumariar",
    "sumariai": "sumariar",
    "sumariais": "sumariar",
    "sumariam": "sumariar",
    "sumariamo": "sumariar",
    "sumariamos": "sumariar",
    "sumariando": "sumariar",
    "sumariara": "sumariar",
    "sumariaram": "sumariar",
    "sumariaras": "sumariar",
    "sumariarde": "sumariar",
    "sumariardes": "sumariar",
    "sumariare": "sumariar",
    "sumariarei": "sumariar",
    "sumariareis": "sumariar",
    "sumariarem": "sumariar",
    "sumariaremos": "sumariar",
    "sumariares": "sumariar",
    "sumariaria": "sumariar",
    "sumariariam": "sumariar",
    "sumariarias": "sumariar",
    "sumariarmo": "sumariar",
    "sumariarmos": "sumariar",
    "sumariará": "sumariar",
    "sumariarás": "sumariar",
    "sumariarão": "sumariar",
    "sumariaríamos": "sumariar",
    "sumariaríeis": "sumariar",
    "sumarias": "sumariar",
    "sumariasse": "sumariar",
    "sumariassem": "sumariar",
    "sumariasses": "sumariar",
    "sumariaste": "sumariar",
    "sumariastes": "sumariar",
    "sumariava": "sumariar",
    "sumariavam": "sumariar",
    "sumariavas": "sumariar",
    "sumariazinha": "sumário",
    "sumariazinhas": "sumário",
    "sumariazita": "sumário",
    "sumariazitas": "sumário",
    "sumarie": "sumariar",
    "sumariei": "sumariar",
    "sumarieis": "sumariar",
    "sumariem": "sumariar",
    "sumariemo": "sumariar",
    "sumariemos": "sumariar",
    "sumaries": "sumariar",
    "sumario": "sumariar",
    "sumariou": "sumariar",
    "sumariozinho": "sumário",
    "sumariozinhos": "sumário",
    "sumariozito": "sumário",
    "sumariozitos": "sumário",
    "sumarizações": "sumarização",
    "sumariá": "sumariar",
    "sumariámo": "sumariar",
    "sumariámos": "sumariar",
    "sumariáramo": "sumariar",
    "sumariáramos": "sumariar",
    "sumariárei": "sumariar",
    "sumariáreis": "sumariar",
    "sumariásseis": "sumariar",
    "sumariássemos": "sumariar",
    "sumariávamo": "sumariar",
    "sumariávamos": "sumariar",
    "sumariávei": "sumariar",
    "sumariáveis": "sumariar",
    "sumas": "sumir",
    "sumaúmas": "sumaúma",
    "sumbambas": "sumbamba",
    "sumi": "sumir",
    "sumia": "sumir",
    "sumiam": "sumir",
    "sumias": "sumir",
    "sumida": "sumir",
    "sumidades": "sumidade",
    "sumidas": "sumir",
    "sumidiça": "sumidiço",
    "sumidiças": "sumidiço",
    "sumidiços": "sumidiço",
    "sumido": "sumir",
    "sumidoiros": "sumidoiro",
    "sumidos": "sumir",
    "sumidouros": "sumidouro",
    "sumiduras": "sumidura",
    "sumidíssima": "sumido",
    "sumidíssimas": "sumido",
    "sumidíssimo": "sumido",
    "sumidíssimos": "sumido",
    "sumilheres": "sumilher",
    "sumimo": "sumir",
    "sumimos": "sumir",
    "sumindo": "sumir",
    "suminho": "sumo",
    "suminhos": "sumo",
    "sumira": "sumir",
    "sumiram": "sumir",
    "sumiras": "sumir",
    "sumirdes": "sumir",
    "sumirei": "sumir",
    "sumireis": "sumir",
    "sumirem": "sumir",
    "sumiremos": "sumir",
    "sumires": "sumir",
    "sumiria": "sumir",
    "sumiriam": "sumir",
    "sumirias": "sumir",
    "sumirmo": "sumir",
    "sumirmos": "sumir",
    "sumirá": "sumir",
    "sumirás": "sumir",
    "sumirão": "sumir",
    "sumiríamos": "sumir",
    "sumiríeis": "sumir",
    "sumis": "sumir",
    "sumisse": "sumir",
    "sumissem": "sumir",
    "sumisses": "sumir",
    "sumistas": "sumista",
    "sumiste": "sumir",
    "sumistes": "sumir",
    "sumito": "sumo",
    "sumitos": "sumo",
    "sumiu": "sumir",
    "sumiços": "sumiço",
    "sumições": "sumição",
    "sumo": "sumir",
    "sumos": "sumo",
    "sumosa": "sumoso",
    "sumosas": "sumoso",
    "sumosos": "sumoso",
    "sumptos": "sumpto",
    "sumptuosa": "sumptuoso",
    "sumptuosas": "sumptuoso",
    "sumptuosidades": "sumptuosidade",
    "sumptuosos": "sumptuoso",
    "sumptuária": "sumptuário",
    "sumptuárias": "sumptuário",
    "sumptuários": "sumptuário",
    "sumpções": "sumpção",
    "sumula": "sumular",
    "sumulada": "sumular",
    "sumuladas": "sumular",
    "sumulado": "sumular",
    "sumulados": "sumular",
    "sumulai": "sumular",
    "sumulais": "sumular",
    "sumulam": "sumular",
    "sumulamo": "sumular",
    "sumulamos": "sumular",
    "sumulando": "sumular",
    "sumulara": "sumular",
    "sumularam": "sumular",
    "sumularas": "sumular",
    "sumularde": "sumular",
    "sumulardes": "sumular",
    "sumulare": "sumular",
    "sumularei": "sumular",
    "sumulareis": "sumular",
    "sumularem": "sumular",
    "sumularemos": "sumular",
    "sumulares": "sumular",
    "sumularia": "sumular",
    "sumulariam": "sumular",
    "sumularias": "sumular",
    "sumularmo": "sumular",
    "sumularmos": "sumular",
    "sumulará": "sumular",
    "sumularás": "sumular",
    "sumularão": "sumular",
    "sumularíamos": "sumular",
    "sumularíeis": "sumular",
    "sumulas": "sumular",
    "sumulasse": "sumular",
    "sumulassem": "sumular",
    "sumulasses": "sumular",
    "sumulaste": "sumular",
    "sumulastes": "sumular",
    "sumulava": "sumular",
    "sumulavam": "sumular",
    "sumulavas": "sumular",
    "sumule": "sumular",
    "sumulei": "sumular",
    "sumuleis": "sumular",
    "sumulem": "sumular",
    "sumulemo": "sumular",
    "sumulemos": "sumular",
    "sumules": "sumular",
    "sumulistas": "sumulista",
    "sumulo": "sumular",
    "sumulou": "sumular",
    "sumulá": "sumular",
    "sumulámo": "sumular",
    "sumulámos": "sumular",
    "sumuláramo": "sumular",
    "sumuláramos": "sumular",
    "sumulárei": "sumular",
    "sumuláreis": "sumular",
    "sumulásseis": "sumular",
    "sumulássemos": "sumular",
    "sumulávamo": "sumular",
    "sumulávamos": "sumular",
    "sumulávei": "sumular",
    "sumuláveis": "sumular",
    "sumária": "sumário",
    "sumárias": "sumário",
    "sumários": "sumário",
    "sumíamo": "sumir",
    "sumíamos": "sumir",
    "sumíeis": "sumir",
    "sumíramo": "sumir",
    "sumíramos": "sumir",
    "sumíreis": "sumir",
    "sumísseis": "sumir",
    "sumíssemos": "sumir",
    "sunas": "suna",
    "sunga": "sungar",
    "sungada": "sungar",
    "sungadas": "sungar",
    "sungado": "sungar",
    "sungados": "sungar",
    "sungai": "sungar",
    "sungais": "sungar",
    "sungam": "sungar",
    "sungamo": "sungar",
    "sungamos": "sungar",
    "sungando": "sungar",
    "sungara": "sungar",
    "sungaram": "sungar",
    "sungaras": "sungar",
    "sungarde": "sungar",
    "sungardes": "sungar",
    "sungare": "sungar",
    "sungarei": "sungar",
    "sungareis": "sungar",
    "sungarem": "sungar",
    "sungaremos": "sungar",
    "sungares": "sungar",
    "sungaria": "sungar",
    "sungariam": "sungar",
    "sungarias": "sungar",
    "sungarmo": "sungar",
    "sungarmos": "sungar",
    "sungará": "sungar",
    "sungarás": "sungar",
    "sungarão": "sungar",
    "sungaríamos": "sungar",
    "sungaríeis": "sungar",
    "sungas": "sungar",
    "sungasse": "sungar",
    "sungassem": "sungar",
    "sungasses": "sungar",
    "sungaste": "sungar",
    "sungastes": "sungar",
    "sungava": "sungar",
    "sungavam": "sungar",
    "sungavas": "sungar",
    "sungo": "sungar",
    "sungou": "sungar",
    "sungue": "sungar",
    "sunguei": "sungar",
    "sungueis": "sungar",
    "sunguem": "sungar",
    "sunguemo": "sungar",
    "sunguemos": "sungar",
    "sungues": "sungar",
    "sungá": "sungar",
    "sungámo": "sungar",
    "sungámos": "sungar",
    "sungáramo": "sungar",
    "sungáramos": "sungar",
    "sungárei": "sungar",
    "sungáreis": "sungar",
    "sungásseis": "sungar",
    "sungássemos": "sungar",
    "sungávamo": "sungar",
    "sungávamos": "sungar",
    "sungávei": "sungar",
    "sungáveis": "sungar",
    "sunitas": "sunita",
    "sunções": "sunção",
    "suo": "suar",
    "suores": "suor",
    "suou": "suar",
    "supedita": "supeditar",
    "supeditada": "supeditar",
    "supeditadas": "supeditar",
    "supeditado": "supeditar",
    "supeditados": "supeditar",
    "supeditai": "supeditar",
    "supeditais": "supeditar",
    "supeditam": "supeditar",
    "supeditamo": "supeditar",
    "supeditamos": "supeditar",
    "supeditando": "supeditar",
    "supeditara": "supeditar",
    "supeditaram": "supeditar",
    "supeditaras": "supeditar",
    "supeditarde": "supeditar",
    "supeditardes": "supeditar",
    "supeditare": "supeditar",
    "supeditarei": "supeditar",
    "supeditareis": "supeditar",
    "supeditarem": "supeditar",
    "supeditaremos": "supeditar",
    "supeditares": "supeditar",
    "supeditaria": "supeditar",
    "supeditariam": "supeditar",
    "supeditarias": "supeditar",
    "supeditarmo": "supeditar",
    "supeditarmos": "supeditar",
    "supeditará": "supeditar",
    "supeditarás": "supeditar",
    "supeditarão": "supeditar",
    "supeditaríamos": "supeditar",
    "supeditaríeis": "supeditar",
    "supeditas": "supeditar",
    "supeditasse": "supeditar",
    "supeditassem": "supeditar",
    "supeditasses": "supeditar",
    "supeditaste": "supeditar",
    "supeditastes": "supeditar",
    "supeditava": "supeditar",
    "supeditavam": "supeditar",
    "supeditavas": "supeditar",
    "supedite": "supeditar",
    "supeditei": "supeditar",
    "supediteis": "supeditar",
    "supeditem": "supeditar",
    "supeditemo": "supeditar",
    "supeditemos": "supeditar",
    "supedites": "supeditar",
    "supedito": "supeditar",
    "supeditou": "supeditar",
    "supeditá": "supeditar",
    "supeditámo": "supeditar",
    "supeditámos": "supeditar",
    "supeditáramo": "supeditar",
    "supeditáramos": "supeditar",
    "supeditárei": "supeditar",
    "supeditáreis": "supeditar",
    "supeditásseis": "supeditar",
    "supeditássemos": "supeditar",
    "supeditávamo": "supeditar",
    "supeditávamos": "supeditar",
    "supeditávei": "supeditar",
    "supeditáveis": "supeditar",
    "supedâneos": "supedâneo",
    "supera": "superar",
    "superabunda": "superabundar",
    "superabundada": "superabundar",
    "superabundadas": "superabundar",
    "superabundado": "superabundar",
    "superabundados": "superabundar",
    "superabundai": "superabundar",
    "superabundais": "superabundar",
    "superabundam": "superabundar",
    "superabundamo": "superabundar",
    "superabundamos": "superabundar",
    "superabundando": "superabundar",
    "superabundantes": "superabundante",
    "superabundara": "superabundar",
    "superabundaram": "superabundar",
    "superabundaras": "superabundar",
    "superabundardes": "superabundar",
    "superabundarei": "superabundar",
    "superabundareis": "superabundar",
    "superabundarem": "superabundar",
    "superabundaremos": "superabundar",
    "superabundares": "superabundar",
    "superabundaria": "superabundar",
    "superabundariam": "superabundar",
    "superabundarias": "superabundar",
    "superabundarmo": "superabundar",
    "superabundarmos": "superabundar",
    "superabundará": "superabundar",
    "superabundarás": "superabundar",
    "superabundarão": "superabundar",
    "superabundaríamos": "superabundar",
    "superabundaríeis": "superabundar",
    "superabundas": "superabundar",
    "superabundasse": "superabundar",
    "superabundassem": "superabundar",
    "superabundasses": "superabundar",
    "superabundaste": "superabundar",
    "superabundastes": "superabundar",
    "superabundava": "superabundar",
    "superabundavam": "superabundar",
    "superabundavas": "superabundar",
    "superabunde": "superabundar",
    "superabundei": "superabundar",
    "superabundeis": "superabundar",
    "superabundem": "superabundar",
    "superabundemo": "superabundar",
    "superabundemos": "superabundar",
    "superabundes": "superabundar",
    "superabundo": "superabundar",
    "superabundou": "superabundar",
    "superabundámo": "superabundar",
    "superabundámos": "superabundar",
    "superabundáramo": "superabundar",
    "superabundáramos": "superabundar",
    "superabundáreis": "superabundar",
    "superabundásseis": "superabundar",
    "superabundássemos": "superabundar",
    "superabundávamo": "superabundar",
    "superabundávamos": "superabundar",
    "superabundáveis": "superabundar",
    "superabundâncias": "superabundância",
    "superaceleradores": "superacelerador",
    "superacidezes": "superacidez",
    "superada": "superar",
    "superadas": "superar",
    "superado": "superar",
    "superados": "superar",
    "superagudos": "superagudo",
    "superai": "superar",
    "superais": "superar",
    "superalimenta": "superalimentar",
    "superalimentada": "superalimentar",
    "superalimentadas": "superalimentar",
    "superalimentado": "superalimentar",
    "superalimentados": "superalimentar",
    "superalimentai": "superalimentar",
    "superalimentais": "superalimentar",
    "superalimentam": "superalimentar",
    "superalimentamo": "superalimentar",
    "superalimentamos": "superalimentar",
    "superalimentando": "superalimentar",
    "superalimentara": "superalimentar",
    "superalimentaram": "superalimentar",
    "superalimentaras": "superalimentar",
    "superalimentarde": "superalimentar",
    "superalimentardes": "superalimentar",
    "superalimentare": "superalimentar",
    "superalimentarei": "superalimentar",
    "superalimentareis": "superalimentar",
    "superalimentarem": "superalimentar",
    "superalimentaremos": "superalimentar",
    "superalimentares": "superalimentar",
    "superalimentaria": "superalimentar",
    "superalimentariam": "superalimentar",
    "superalimentarias": "superalimentar",
    "superalimentarmo": "superalimentar",
    "superalimentarmos": "superalimentar",
    "superalimentará": "superalimentar",
    "superalimentarás": "superalimentar",
    "superalimentarão": "superalimentar",
    "superalimentaríamos": "superalimentar",
    "superalimentaríeis": "superalimentar",
    "superalimentas": "superalimentar",
    "superalimentasse": "superalimentar",
    "superalimentassem": "superalimentar",
    "superalimentasses": "superalimentar",
    "superalimentaste": "superalimentar",
    "superalimentastes": "superalimentar",
    "superalimentava": "superalimentar",
    "superalimentavam": "superalimentar",
    "superalimentavas": "superalimentar",
    "superalimentações": "superalimentação",
    "superalimente": "superalimentar",
    "superalimentei": "superalimentar",
    "superalimenteis": "superalimentar",
    "superalimentem": "superalimentar",
    "superalimentemo": "superalimentar",
    "superalimentemos": "superalimentar",
    "superalimentes": "superalimentar",
    "superalimento": "superalimentar",
    "superalimentou": "superalimentar",
    "superalimentá": "superalimentar",
    "superalimentámo": "superalimentar",
    "superalimentámos": "superalimentar",
    "superalimentáramo": "superalimentar",
    "superalimentáramos": "superalimentar",
    "superalimentárei": "superalimentar",
    "superalimentáreis": "superalimentar",
    "superalimentásseis": "superalimentar",
    "superalimentássemos": "superalimentar",
    "superalimentávamo": "superalimentar",
    "superalimentávamos": "superalimentar",
    "superalimentávei": "superalimentar",
    "superalimentáveis": "superalimentar",
    "superam": "superar",
    "superamo": "superar",
    "superamos": "superar",
    "superanda": "superando",
    "superandas": "superando",
    "superando": "superar",
    "superandos": "superando",
    "superantes": "superante",
    "superaquecimentos": "superaquecimento",
    "superaquisições": "superaquisição",
    "superara": "superar",
    "superaram": "superar",
    "superaras": "superar",
    "superarde": "superar",
    "superardes": "superar",
    "superare": "superar",
    "superarei": "superar",
    "superareis": "superar",
    "superarem": "superar",
    "superaremos": "superar",
    "superares": "superar",
    "superaria": "superar",
    "superariam": "superar",
    "superarias": "superar",
    "superarmo": "superar",
    "superarmos": "superar",
    "superará": "superar",
    "superarás": "superar",
    "superarão": "superar",
    "superaríamos": "superar",
    "superaríeis": "superar",
    "superas": "superar",
    "superasse": "superar",
    "superassem": "superar",
    "superasses": "superar",
    "superaste": "superar",
    "superastes": "superar",
    "superava": "superar",
    "superavam": "superar",
    "superavas": "superar",
    "superavites": "superavit",
    "superaxilares": "superaxilar",
    "superações": "superação",
    "supercalandras": "supercalandra",
    "supercampionatos": "supercampionato",
    "supercampiã": "supercampião",
    "supercampiãs": "supercampião",
    "supercampiões": "supercampião",
    "supercarburantes": "supercarburante",
    "superciliares": "superciliar",
    "superciliosa": "supercilioso",
    "superciliosas": "supercilioso",
    "superciliosos": "supercilioso",
    "supercimentos": "supercimento",
    "supercivilizada": "supercivilizado",
    "supercivilizadas": "supercivilizado",
    "supercivilizados": "supercivilizado",
    "supercivilizações": "supercivilização",
    "superclasses": "superclasse",
    "supercomputadores": "supercomputador",
    "superconcentrações": "superconcentração",
    "supercondutividades": "supercondutividade",
    "supercondutora": "supercondutor",
    "supercondutoras": "supercondutor",
    "supercondutores": "supercondutor",
    "superconfiantes": "superconfiante",
    "superconjunções": "superconjunção",
    "supercílios": "supercílio",
    "superdefensiva": "superdefensivo",
    "superdefensivas": "superdefensivo",
    "superdefensivos": "superdefensivo",
    "superdominantes": "superdominante",
    "superdominâncias": "superdominância",
    "superdoses": "superdose",
    "superdotada": "superdotado",
    "superdotadas": "superdotado",
    "superdotados": "superdotado",
    "supere": "superar",
    "superegos": "superego",
    "superei": "superar",
    "supereis": "superar",
    "superelegantes": "superelegante",
    "superelevações": "superelevação",
    "superem": "superar",
    "supereminentes": "supereminente",
    "supereminências": "supereminência",
    "superemo": "superar",
    "superemos": "superar",
    "superes": "superar",
    "superesquadras": "superesquadra",
    "superestimas": "superestima",
    "superestimações": "superestimação",
    "superestrelas": "superestrela",
    "superestruturas": "superestrutura",
    "superexaltações": "superexaltação",
    "superexcelências": "superexcelência",
    "superexcita": "superexcitar",
    "superexcitada": "superexcitar",
    "superexcitadas": "superexcitar",
    "superexcitado": "superexcitar",
    "superexcitados": "superexcitar",
    "superexcitai": "superexcitar",
    "superexcitais": "superexcitar",
    "superexcitam": "superexcitar",
    "superexcitamo": "superexcitar",
    "superexcitamos": "superexcitar",
    "superexcitando": "superexcitar",
    "superexcitara": "superexcitar",
    "superexcitaram": "superexcitar",
    "superexcitaras": "superexcitar",
    "superexcitarde": "superexcitar",
    "superexcitardes": "superexcitar",
    "superexcitare": "superexcitar",
    "superexcitarei": "superexcitar",
    "superexcitareis": "superexcitar",
    "superexcitarem": "superexcitar",
    "superexcitaremos": "superexcitar",
    "superexcitares": "superexcitar",
    "superexcitaria": "superexcitar",
    "superexcitariam": "superexcitar",
    "superexcitarias": "superexcitar",
    "superexcitarmo": "superexcitar",
    "superexcitarmos": "superexcitar",
    "superexcitará": "superexcitar",
    "superexcitarás": "superexcitar",
    "superexcitarão": "superexcitar",
    "superexcitaríamos": "superexcitar",
    "superexcitaríeis": "superexcitar",
    "superexcitas": "superexcitar",
    "superexcitasse": "superexcitar",
    "superexcitassem": "superexcitar",
    "superexcitasses": "superexcitar",
    "superexcitaste": "superexcitar",
    "superexcitastes": "superexcitar",
    "superexcitava": "superexcitar",
    "superexcitavam": "superexcitar",
    "superexcitavas": "superexcitar",
    "superexcitações": "superexcitação",
    "superexcite": "superexcitar",
    "superexcitei": "superexcitar",
    "superexciteis": "superexcitar",
    "superexcitem": "superexcitar",
    "superexcitemo": "superexcitar",
    "superexcitemos": "superexcitar",
    "superexcites": "superexcitar",
    "superexcito": "superexcitar",
    "superexcitou": "superexcitar",
    "superexcitá": "superexcitar",
    "superexcitámo": "superexcitar",
    "superexcitámos": "superexcitar",
    "superexcitáramo": "superexcitar",
    "superexcitáramos": "superexcitar",
    "superexcitárei": "superexcitar",
    "superexcitáreis": "superexcitar",
    "superexcitásseis": "superexcitar",
    "superexcitássemos": "superexcitar",
    "superexcitávamo": "superexcitar",
    "superexcitávamos": "superexcitar",
    "superexcitávei": "superexcitar",
    "superexcitáveis": "superexcitar",
    "superexcreções": "superexcreção",
    "superexigentes": "superexigente",
    "superexposições": "superexposição",
    "superfamílias": "superfamília",
    "superfavorita": "superfavorito",
    "superfavoritas": "superfavorito",
    "superfavoritos": "superfavorito",
    "superfeta": "superfetar",
    "superfetada": "superfetar",
    "superfetadas": "superfetar",
    "superfetado": "superfetar",
    "superfetados": "superfetar",
    "superfetai": "superfetar",
    "superfetais": "superfetar",
    "superfetam": "superfetar",
    "superfetamo": "superfetar",
    "superfetamos": "superfetar",
    "superfetando": "superfetar",
    "superfetara": "superfetar",
    "superfetaram": "superfetar",
    "superfetaras": "superfetar",
    "superfetardes": "superfetar",
    "superfetarei": "superfetar",
    "superfetareis": "superfetar",
    "superfetarem": "superfetar",
    "superfetaremos": "superfetar",
    "superfetares": "superfetar",
    "superfetaria": "superfetar",
    "superfetariam": "superfetar",
    "superfetarias": "superfetar",
    "superfetarmo": "superfetar",
    "superfetarmos": "superfetar",
    "superfetará": "superfetar",
    "superfetarás": "superfetar",
    "superfetarão": "superfetar",
    "superfetaríamos": "superfetar",
    "superfetaríeis": "superfetar",
    "superfetas": "superfetar",
    "superfetasse": "superfetar",
    "superfetassem": "superfetar",
    "superfetasses": "superfetar",
    "superfetaste": "superfetar",
    "superfetastes": "superfetar",
    "superfetava": "superfetar",
    "superfetavam": "superfetar",
    "superfetavas": "superfetar",
    "superfetações": "superfetação",
    "superfete": "superfetar",
    "superfetei": "superfetar",
    "superfeteis": "superfetar",
    "superfetem": "superfetar",
    "superfetemo": "superfetar",
    "superfetemos": "superfetar",
    "superfetes": "superfetar",
    "superfeto": "superfetar",
    "superfetou": "superfetar",
    "superfetámo": "superfetar",
    "superfetámos": "superfetar",
    "superfetáramo": "superfetar",
    "superfetáramos": "superfetar",
    "superfetáreis": "superfetar",
    "superfetásseis": "superfetar",
    "superfetássemos": "superfetar",
    "superfetávamo": "superfetar",
    "superfetávamos": "superfetar",
    "superfetáveis": "superfetar",
    "superficiais": "superficial",
    "superficialidades": "superficialidade",
    "superficialismos": "superficialismo",
    "superfina": "superfino",
    "superfinais": "superfinal",
    "superfinas": "superfino",
    "superfinidades": "superfinidade",
    "superfinos": "superfino",
    "superfluidades": "superfluidade",
    "superfluidezs": "superfluidez",
    "superfluídos": "superfluído",
    "superfortalezas": "superfortaleza",
    "superfortes": "superforte",
    "superfosfatos": "superfosfato",
    "superfícies": "superfície",
    "supergigantes": "supergigante",
    "superhomens": "superhomem",
    "superinfecções": "superinfecção",
    "superintenda": "superintender",
    "superintendais": "superintender",
    "superintendam": "superintender",
    "superintendamo": "superintender",
    "superintendamos": "superintender",
    "superintendas": "superintender",
    "superintende": "superintender",
    "superintendei": "superintender",
    "superintendeis": "superintender",
    "superintendem": "superintender",
    "superintendemo": "superintender",
    "superintendemos": "superintender",
    "superintendendo": "superintender",
    "superintendentes": "superintendente",
    "superintendera": "superintender",
    "superintenderam": "superintender",
    "superintenderas": "superintender",
    "superintenderde": "superintender",
    "superintenderdes": "superintender",
    "superintendere": "superintender",
    "superintenderei": "superintender",
    "superintendereis": "superintender",
    "superintenderem": "superintender",
    "superintenderemos": "superintender",
    "superintenderes": "superintender",
    "superintenderia": "superintender",
    "superintenderiam": "superintender",
    "superintenderias": "superintender",
    "superintendermo": "superintender",
    "superintendermos": "superintender",
    "superintenderá": "superintender",
    "superintenderás": "superintender",
    "superintenderão": "superintender",
    "superintenderíamos": "superintender",
    "superintenderíeis": "superintender",
    "superintendes": "superintender",
    "superintendesse": "superintender",
    "superintendessem": "superintender",
    "superintendesses": "superintender",
    "superintendeste": "superintender",
    "superintendestes": "superintender",
    "superintendeu": "superintender",
    "superintendi": "superintender",
    "superintendia": "superintender",
    "superintendiam": "superintender",
    "superintendias": "superintender",
    "superintendida": "superintender",
    "superintendidas": "superintender",
    "superintendido": "superintender",
    "superintendidos": "superintender",
    "superintendo": "superintender",
    "superintendê": "superintender",
    "superintendências": "superintendência",
    "superintendêramo": "superintender",
    "superintendêramos": "superintender",
    "superintendêrei": "superintender",
    "superintendêreis": "superintender",
    "superintendêsseis": "superintender",
    "superintendêssemos": "superintender",
    "superintendíamo": "superintender",
    "superintendíamos": "superintender",
    "superintendíei": "superintender",
    "superintendíeis": "superintender",
    "superinvenções": "superinvenção",
    "superioras": "superiora",
    "superioratos": "superiorato",
    "superiores": "superior",
    "superioridades": "superioridade",
    "superioriza": "superiorizar",
    "superiorizada": "superiorizar",
    "superiorizadas": "superiorizar",
    "superiorizado": "superiorizar",
    "superiorizados": "superiorizar",
    "superiorizai": "superiorizar",
    "superiorizais": "superiorizar",
    "superiorizam": "superiorizar",
    "superiorizamo": "superiorizar",
    "superiorizamos": "superiorizar",
    "superiorizando": "superiorizar",
    "superiorizara": "superiorizar",
    "superiorizaram": "superiorizar",
    "superiorizaras": "superiorizar",
    "superiorizarde": "superiorizar",
    "superiorizardes": "superiorizar",
    "superiorizare": "superiorizar",
    "superiorizarei": "superiorizar",
    "superiorizareis": "superiorizar",
    "superiorizarem": "superiorizar",
    "superiorizaremos": "superiorizar",
    "superiorizares": "superiorizar",
    "superiorizaria": "superiorizar",
    "superiorizariam": "superiorizar",
    "superiorizarias": "superiorizar",
    "superiorizarmo": "superiorizar",
    "superiorizarmos": "superiorizar",
    "superiorizará": "superiorizar",
    "superiorizarás": "superiorizar",
    "superiorizarão": "superiorizar",
    "superiorizaríamos": "superiorizar",
    "superiorizaríeis": "superiorizar",
    "superiorizas": "superiorizar",
    "superiorizasse": "superiorizar",
    "superiorizassem": "superiorizar",
    "superiorizasses": "superiorizar",
    "superiorizaste": "superiorizar",
    "superiorizastes": "superiorizar",
    "superiorizava": "superiorizar",
    "superiorizavam": "superiorizar",
    "superiorizavas": "superiorizar",
    "superiorizações": "superiorização",
    "superiorize": "superiorizar",
    "superiorizei": "superiorizar",
    "superiorizeis": "superiorizar",
    "superiorizem": "superiorizar",
    "superiorizemo": "superiorizar",
    "superiorizemos": "superiorizar",
    "superiorizes": "superiorizar",
    "superiorizo": "superiorizar",
    "superiorizou": "superiorizar",
    "superiorizá": "superiorizar",
    "superiorizámo": "superiorizar",
    "superiorizámos": "superiorizar",
    "superiorizáramo": "superiorizar",
    "superiorizáramos": "superiorizar",
    "superiorizárei": "superiorizar",
    "superiorizáreis": "superiorizar",
    "superiorizásseis": "superiorizar",
    "superiorizássemos": "superiorizar",
    "superiorizávamo": "superiorizar",
    "superiorizávamos": "superiorizar",
    "superiorizávei": "superiorizar",
    "superiorizáveis": "superiorizar",
    "superlarguras": "superlargura",
    "superlativa": "superlativo",
    "superlativada": "superlativar",
    "superlativadas": "superlativar",
    "superlativado": "superlativar",
    "superlativados": "superlativar",
    "superlativai": "superlativar",
    "superlativais": "superlativar",
    "superlativam": "superlativar",
    "superlativamo": "superlativar",
    "superlativamos": "superlativar",
    "superlativando": "superlativar",
    "superlativara": "superlativar",
    "superlativaram": "superlativar",
    "superlativaras": "superlativar",
    "superlativarde": "superlativar",
    "superlativardes": "superlativar",
    "superlativare": "superlativar",
    "superlativarei": "superlativar",
    "superlativareis": "superlativar",
    "superlativarem": "superlativar",
    "superlativaremos": "superlativar",
    "superlativares": "superlativar",
    "superlativaria": "superlativar",
    "superlativariam": "superlativar",
    "superlativarias": "superlativar",
    "superlativarmo": "superlativar",
    "superlativarmos": "superlativar",
    "superlativará": "superlativar",
    "superlativarás": "superlativar",
    "superlativarão": "superlativar",
    "superlativaríamos": "superlativar",
    "superlativaríeis": "superlativar",
    "superlativas": "superlativo",
    "superlativasse": "superlativar",
    "superlativassem": "superlativar",
    "superlativasses": "superlativar",
    "superlativaste": "superlativar",
    "superlativastes": "superlativar",
    "superlativava": "superlativar",
    "superlativavam": "superlativar",
    "superlativavas": "superlativar",
    "superlativações": "superlativação",
    "superlative": "superlativar",
    "superlativei": "superlativar",
    "superlativeis": "superlativar",
    "superlativem": "superlativar",
    "superlativemo": "superlativar",
    "superlativemos": "superlativar",
    "superlatives": "superlativar",
    "superlativo": "superlativar",
    "superlativos": "superlativo",
    "superlativou": "superlativar",
    "superlativá": "superlativar",
    "superlativámo": "superlativar",
    "superlativámos": "superlativar",
    "superlativáramo": "superlativar",
    "superlativáramos": "superlativar",
    "superlativárei": "superlativar",
    "superlativáreis": "superlativar",
    "superlativásseis": "superlativar",
    "superlativássemos": "superlativar",
    "superlativávamo": "superlativar",
    "superlativávamos": "superlativar",
    "superlativávei": "superlativar",
    "superlativáveis": "superlativar",
    "superlota": "superlotar",
    "superlotada": "superlotar",
    "superlotadas": "superlotar",
    "superlotado": "superlotar",
    "superlotados": "superlotar",
    "superlotai": "superlotar",
    "superlotais": "superlotar",
    "superlotam": "superlotar",
    "superlotamo": "superlotar",
    "superlotamos": "superlotar",
    "superlotando": "superlotar",
    "superlotara": "superlotar",
    "superlotaram": "superlotar",
    "superlotaras": "superlotar",
    "superlotarde": "superlotar",
    "superlotardes": "superlotar",
    "superlotare": "superlotar",
    "superlotarei": "superlotar",
    "superlotareis": "superlotar",
    "superlotarem": "superlotar",
    "superlotaremos": "superlotar",
    "superlotares": "superlotar",
    "superlotaria": "superlotar",
    "superlotariam": "superlotar",
    "superlotarias": "superlotar",
    "superlotarmo": "superlotar",
    "superlotarmos": "superlotar",
    "superlotará": "superlotar",
    "superlotarás": "superlotar",
    "superlotarão": "superlotar",
    "superlotaríamos": "superlotar",
    "superlotaríeis": "superlotar",
    "superlotas": "superlotar",
    "superlotasse": "superlotar",
    "superlotassem": "superlotar",
    "superlotasses": "superlotar",
    "superlotaste": "superlotar",
    "superlotastes": "superlotar",
    "superlotava": "superlotar",
    "superlotavam": "superlotar",
    "superlotavas": "superlotar",
    "superlotações": "superlotação",
    "superlote": "superlotar",
    "superlotei": "superlotar",
    "superloteis": "superlotar",
    "superlotem": "superlotar",
    "superlotemo": "superlotar",
    "superlotemos": "superlotar",
    "superlotes": "superlotar",
    "superloto": "superlotar",
    "superlotou": "superlotar",
    "superlotá": "superlotar",
    "superlotámo": "superlotar",
    "superlotámos": "superlotar",
    "superlotáramo": "superlotar",
    "superlotáramos": "superlotar",
    "superlotárei": "superlotar",
    "superlotáreis": "superlotar",
    "superlotásseis": "superlotar",
    "superlotássemos": "superlotar",
    "superlotávamo": "superlotar",
    "superlotávamos": "superlotar",
    "superlotávei": "superlotar",
    "superlotáveis": "superlotar",
    "supermediadora": "supermediador",
    "supermediadoras": "supermediador",
    "supermediadores": "supermediador",
    "supermercados": "supermercado",
    "supermilionária": "supermilionário",
    "supermilionárias": "supermilionário",
    "supermilionários": "supermilionário",
    "superministra": "superministro",
    "superministras": "superministro",
    "superministros": "superministro",
    "superministérios": "superministério",
    "supermulheres": "supermulher",
    "supermães": "supermãe",
    "superna": "superno",
    "supernais": "supernal",
    "supernas": "superno",
    "supernaturais": "supernatural",
    "supernos": "superno",
    "supernovas": "supernova",
    "supernumerária": "supernumerário",
    "supernumerárias": "supernumerário",
    "supernumerários": "supernumerário",
    "supero": "superar",
    "superosculações": "superosculação",
    "superou": "superar",
    "superovariada": "superovariado",
    "superovariadas": "superovariado",
    "superovariados": "superovariado",
    "superoxidações": "superoxidação",
    "superpais": "superpai",
    "superpesada": "superpesado",
    "superpesadas": "superpesado",
    "superpesados": "superpesado",
    "superpolícias": "superpolícia",
    "superpomo": "superpor",
    "superpomos": "superpor",
    "superponde": "superpor",
    "superpondes": "superpor",
    "superpondo": "superpor",
    "superponha": "superpor",
    "superponhais": "superpor",
    "superponham": "superpor",
    "superponhamo": "superpor",
    "superponhamos": "superpor",
    "superponhas": "superpor",
    "superponho": "superpor",
    "superponíveis": "superponível",
    "superpopulações": "superpopulação",
    "superporde": "superpor",
    "superpordes": "superpor",
    "superpore": "superpor",
    "superporei": "superpor",
    "superporeis": "superpor",
    "superporem": "superpor",
    "superporemos": "superpor",
    "superpores": "superpor",
    "superporia": "superpor",
    "superporiam": "superpor",
    "superporias": "superpor",
    "superpormo": "superpor",
    "superpormos": "superpor",
    "superporá": "superpor",
    "superporás": "superpor",
    "superporão": "superpor",
    "superporíamos": "superpor",
    "superporíeis": "superpor",
    "superposições": "superposição",
    "superposta": "superpor",
    "superpostas": "superpor",
    "superposto": "superpor",
    "superpostos": "superpor",
    "superpotências": "superpotência",
    "superpovoada": "superpovoado",
    "superpovoadas": "superpovoado",
    "superpovoados": "superpovoado",
    "superpovoamentos": "superpovoamento",
    "superpreparada": "superpreparado",
    "superpreparadas": "superpreparado",
    "superpreparados": "superpreparado",
    "superproduções": "superprodução",
    "superprotectora": "superprotector",
    "superprotectoras": "superprotector",
    "superprotectores": "superprotector",
    "superprotecções": "superprotecção",
    "superprotegida": "superprotegido",
    "superprotegidas": "superprotegido",
    "superprotegidos": "superprotegido",
    "superprotões": "superprotão",
    "superpunha": "superpor",
    "superpunham": "superpor",
    "superpunhas": "superpor",
    "superpurgações": "superpurgação",
    "superpus": "superpor",
    "superpusemo": "superpor",
    "superpusemos": "superpor",
    "superpuser": "superpor",
    "superpusera": "superpor",
    "superpuseram": "superpor",
    "superpuseras": "superpor",
    "superpuserdes": "superpor",
    "superpuserem": "superpor",
    "superpuseres": "superpor",
    "superpusermos": "superpor",
    "superpusesse": "superpor",
    "superpusessem": "superpor",
    "superpusesses": "superpor",
    "superpuseste": "superpor",
    "superpusestes": "superpor",
    "superpuséramo": "superpor",
    "superpuséramos": "superpor",
    "superpusérei": "superpor",
    "superpuséreis": "superpor",
    "superpusésseis": "superpor",
    "superpuséssemos": "superpor",
    "superpô": "superpor",
    "superpôs": "superpor",
    "superpõe": "superpor",
    "superpõem": "superpor",
    "superpões": "superpor",
    "superpúnhamo": "superpor",
    "superpúnhamos": "superpor",
    "superpúnhei": "superpor",
    "superpúnheis": "superpor",
    "supersafras": "supersafra",
    "supersaturações": "supersaturação",
    "supersecretos": "supersecreto",
    "supersecreções": "supersecreção",
    "supersensíveis": "supersensível",
    "supersons": "supersom",
    "superstars": "superstar",
    "supersticiosa": "supersticioso",
    "supersticiosas": "supersticioso",
    "supersticiosidades": "supersticiosidade",
    "supersticiosos": "supersticioso",
    "superstições": "superstição",
    "superstratos": "superstrato",
    "supersubstanciais": "supersubstancial",
    "supersónica": "supersónico",
    "supersónicas": "supersónico",
    "supersónicos": "supersónico",
    "supertuberculinizações": "supertuberculinização",
    "supertónicas": "supertónica",
    "superumerais": "superumeral",
    "supervacânea": "supervacâneo",
    "supervacâneas": "supervacâneo",
    "supervacâneos": "supervacâneo",
    "supervaidades": "supervaidade",
    "supervalorizada": "supervalorizado",
    "supervalorizadas": "supervalorizado",
    "supervalorizados": "supervalorizado",
    "supervelozes": "superveloz",
    "supervenientes": "superveniente",
    "superveniências": "superveniência",
    "supervenções": "supervenção",
    "supervisa": "supervisar",
    "supervisada": "supervisar",
    "supervisadas": "supervisar",
    "supervisado": "supervisar",
    "supervisados": "supervisar",
    "supervisai": "supervisar",
    "supervisais": "supervisar",
    "supervisam": "supervisar",
    "supervisamo": "supervisar",
    "supervisamos": "supervisar",
    "supervisando": "supervisar",
    "supervisara": "supervisar",
    "supervisaram": "supervisar",
    "supervisaras": "supervisar",
    "supervisarde": "supervisar",
    "supervisardes": "supervisar",
    "supervisare": "supervisar",
    "supervisarei": "supervisar",
    "supervisareis": "supervisar",
    "supervisarem": "supervisar",
    "supervisaremos": "supervisar",
    "supervisares": "supervisar",
    "supervisaria": "supervisar",
    "supervisariam": "supervisar",
    "supervisarias": "supervisar",
    "supervisarmo": "supervisar",
    "supervisarmos": "supervisar",
    "supervisará": "supervisar",
    "supervisarás": "supervisar",
    "supervisarão": "supervisar",
    "supervisaríamos": "supervisar",
    "supervisaríeis": "supervisar",
    "supervisas": "supervisar",
    "supervisasse": "supervisar",
    "supervisassem": "supervisar",
    "supervisasses": "supervisar",
    "supervisaste": "supervisar",
    "supervisastes": "supervisar",
    "supervisava": "supervisar",
    "supervisavam": "supervisar",
    "supervisavas": "supervisar",
    "supervise": "supervisar",
    "supervisei": "supervisar",
    "superviseis": "supervisar",
    "supervisem": "supervisar",
    "supervisemo": "supervisar",
    "supervisemos": "supervisar",
    "supervises": "supervisar",
    "supervisiona": "supervisionar",
    "supervisionada": "supervisionar",
    "supervisionadas": "supervisionar",
    "supervisionado": "supervisionar",
    "supervisionados": "supervisionar",
    "supervisionai": "supervisionar",
    "supervisionais": "supervisionar",
    "supervisionam": "supervisionar",
    "supervisionamo": "supervisionar",
    "supervisionamos": "supervisionar",
    "supervisionando": "supervisionar",
    "supervisionara": "supervisionar",
    "supervisionaram": "supervisionar",
    "supervisionaras": "supervisionar",
    "supervisionarde": "supervisionar",
    "supervisionardes": "supervisionar",
    "supervisionare": "supervisionar",
    "supervisionarei": "supervisionar",
    "supervisionareis": "supervisionar",
    "supervisionarem": "supervisionar",
    "supervisionaremos": "supervisionar",
    "supervisionares": "supervisionar",
    "supervisionaria": "supervisionar",
    "supervisionariam": "supervisionar",
    "supervisionarias": "supervisionar",
    "supervisionarmo": "supervisionar",
    "supervisionarmos": "supervisionar",
    "supervisionará": "supervisionar",
    "supervisionarás": "supervisionar",
    "supervisionarão": "supervisionar",
    "supervisionaríamos": "supervisionar",
    "supervisionaríeis": "supervisionar",
    "supervisionas": "supervisionar",
    "supervisionasse": "supervisionar",
    "supervisionassem": "supervisionar",
    "supervisionasses": "supervisionar",
    "supervisionaste": "supervisionar",
    "supervisionastes": "supervisionar",
    "supervisionava": "supervisionar",
    "supervisionavam": "supervisionar",
    "supervisionavas": "supervisionar",
    "supervisione": "supervisionar",
    "supervisionei": "supervisionar",
    "supervisioneis": "supervisionar",
    "supervisionem": "supervisionar",
    "supervisionemo": "supervisionar",
    "supervisionemos": "supervisionar",
    "supervisiones": "supervisionar",
    "supervisiono": "supervisionar",
    "supervisionou": "supervisionar",
    "supervisioná": "supervisionar",
    "supervisionámo": "supervisionar",
    "supervisionámos": "supervisionar",
    "supervisionáramo": "supervisionar",
    "supervisionáramos": "supervisionar",
    "supervisionárei": "supervisionar",
    "supervisionáreis": "supervisionar",
    "supervisionásseis": "supervisionar",
    "supervisionássemos": "supervisionar",
    "supervisionávamo": "supervisionar",
    "supervisionávamos": "supervisionar",
    "supervisionávei": "supervisionar",
    "supervisionáveis": "supervisionável",
    "superviso": "supervisar",
    "supervisora": "supervisor",
    "supervisoras": "supervisor",
    "supervisores": "supervisor",
    "supervisou": "supervisar",
    "supervisá": "supervisar",
    "supervisámo": "supervisar",
    "supervisámos": "supervisar",
    "supervisáramo": "supervisar",
    "supervisáramos": "supervisar",
    "supervisárei": "supervisar",
    "supervisáreis": "supervisar",
    "supervisásseis": "supervisar",
    "supervisássemos": "supervisar",
    "supervisávamo": "supervisar",
    "supervisávamos": "supervisar",
    "supervisávei": "supervisar",
    "supervisáveis": "supervisar",
    "supervisões": "supervisão",
    "superviventes": "supervivente",
    "supervivências": "supervivência",
    "supervácua": "supervácuo",
    "supervácuas": "supervácuo",
    "supervácuos": "supervácuo",
    "superá": "superar",
    "superácida": "superácido",
    "superácidas": "superácido",
    "superácidos": "superácido",
    "superámo": "superar",
    "superámos": "superar",
    "superáramo": "superar",
    "superáramos": "superar",
    "superárbitros": "superárbitro",
    "superárei": "superar",
    "superáreis": "superar",
    "superásseis": "superar",
    "superássemos": "superar",
    "superávamo": "superar",
    "superávamos": "superar",
    "superávei": "superar",
    "superáveis": "superável",
    "superávites": "superávit",
    "supetões": "supetão",
    "supimpas": "supimpa",
    "supina": "supino",
    "supinadora": "supinador",
    "supinadoras": "supinador",
    "supinadores": "supinador",
    "supinas": "supino",
    "supinações": "supinação",
    "supinos": "supino",
    "suplanta": "suplantar",
    "suplantada": "suplantar",
    "suplantadas": "suplantar",
    "suplantado": "suplantar",
    "suplantadora": "suplantador",
    "suplantadoras": "suplantador",
    "suplantadores": "suplantador",
    "suplantados": "suplantar",
    "suplantai": "suplantar",
    "suplantais": "suplantar",
    "suplantam": "suplantar",
    "suplantamo": "suplantar",
    "suplantamos": "suplantar",
    "suplantando": "suplantar",
    "suplantara": "suplantar",
    "suplantaram": "suplantar",
    "suplantaras": "suplantar",
    "suplantarde": "suplantar",
    "suplantardes": "suplantar",
    "suplantare": "suplantar",
    "suplantarei": "suplantar",
    "suplantareis": "suplantar",
    "suplantarem": "suplantar",
    "suplantaremos": "suplantar",
    "suplantares": "suplantar",
    "suplantaria": "suplantar",
    "suplantariam": "suplantar",
    "suplantarias": "suplantar",
    "suplantarmo": "suplantar",
    "suplantarmos": "suplantar",
    "suplantará": "suplantar",
    "suplantarás": "suplantar",
    "suplantarão": "suplantar",
    "suplantaríamos": "suplantar",
    "suplantaríeis": "suplantar",
    "suplantas": "suplantar",
    "suplantasse": "suplantar",
    "suplantassem": "suplantar",
    "suplantasses": "suplantar",
    "suplantaste": "suplantar",
    "suplantastes": "suplantar",
    "suplantava": "suplantar",
    "suplantavam": "suplantar",
    "suplantavas": "suplantar",
    "suplantações": "suplantação",
    "suplante": "suplantar",
    "suplantei": "suplantar",
    "suplanteis": "suplantar",
    "suplantem": "suplantar",
    "suplantemo": "suplantar",
    "suplantemos": "suplantar",
    "suplantes": "suplantar",
    "suplanto": "suplantar",
    "suplantou": "suplantar",
    "suplantá": "suplantar",
    "suplantámo": "suplantar",
    "suplantámos": "suplantar",
    "suplantáramo": "suplantar",
    "suplantáramos": "suplantar",
    "suplantárei": "suplantar",
    "suplantáreis": "suplantar",
    "suplantásseis": "suplantar",
    "suplantássemos": "suplantar",
    "suplantávamo": "suplantar",
    "suplantávamos": "suplantar",
    "suplantávei": "suplantar",
    "suplantáveis": "suplantável",
    "suplectiva": "suplectivo",
    "suplectivas": "suplectivo",
    "suplectivos": "suplectivo",
    "suplementares": "suplementar",
    "suplementações": "suplementação",
    "suplementos": "suplemento",
    "suplementária": "suplementário",
    "suplementárias": "suplementário",
    "suplementários": "suplementário",
    "suplentes": "suplente",
    "suplentezinha": "suplente",
    "suplentezinhas": "suplente",
    "suplentezinho": "suplente",
    "suplentezinhos": "suplente",
    "suplentezita": "suplente",
    "suplentezitas": "suplente",
    "suplentezito": "suplente",
    "suplentezitos": "suplente",
    "supletiva": "supletivo",
    "supletivas": "supletivo",
    "supletivos": "supletivo",
    "supletória": "supletório",
    "supletórias": "supletório",
    "supletórios": "supletório",
    "suplica": "suplicar",
    "suplicada": "suplicar",
    "suplicadas": "suplicar",
    "suplicado": "suplicar",
    "suplicados": "suplicar",
    "suplicai": "suplicar",
    "suplicais": "suplicar",
    "suplicam": "suplicar",
    "suplicamo": "suplicar",
    "suplicamos": "suplicar",
    "suplicando": "suplicar",
    "suplicantes": "suplicante",
    "suplicara": "suplicar",
    "suplicaram": "suplicar",
    "suplicaras": "suplicar",
    "suplicarde": "suplicar",
    "suplicardes": "suplicar",
    "suplicare": "suplicar",
    "suplicarei": "suplicar",
    "suplicareis": "suplicar",
    "suplicarem": "suplicar",
    "suplicaremos": "suplicar",
    "suplicares": "suplicar",
    "suplicaria": "suplicar",
    "suplicariam": "suplicar",
    "suplicarias": "suplicar",
    "suplicarmo": "suplicar",
    "suplicarmos": "suplicar",
    "suplicará": "suplicar",
    "suplicarás": "suplicar",
    "suplicarão": "suplicar",
    "suplicaríamos": "suplicar",
    "suplicaríeis": "suplicar",
    "suplicas": "suplicar",
    "suplicasse": "suplicar",
    "suplicassem": "suplicar",
    "suplicasses": "suplicar",
    "suplicaste": "suplicar",
    "suplicastes": "suplicar",
    "suplicativa": "suplicativo",
    "suplicativas": "suplicativo",
    "suplicativos": "suplicativo",
    "suplicatória": "suplicatório",
    "suplicatórias": "suplicatório",
    "suplicatórios": "suplicatório",
    "suplicava": "suplicar",
    "suplicavam": "suplicar",
    "suplicavas": "suplicar",
    "suplicações": "suplicação",
    "suplicia": "supliciar",
    "supliciada": "supliciar",
    "supliciadas": "supliciar",
    "supliciado": "supliciar",
    "supliciadora": "supliciador",
    "supliciadoras": "supliciador",
    "supliciadores": "supliciador",
    "supliciados": "supliciar",
    "supliciadíssima": "supliciado",
    "supliciadíssimas": "supliciado",
    "supliciadíssimo": "supliciado",
    "supliciadíssimos": "supliciado",
    "supliciai": "supliciar",
    "supliciais": "supliciar",
    "supliciam": "supliciar",
    "supliciamo": "supliciar",
    "supliciamos": "supliciar",
    "supliciando": "supliciar",
    "supliciantes": "supliciante",
    "supliciara": "supliciar",
    "supliciaram": "supliciar",
    "supliciaras": "supliciar",
    "supliciarde": "supliciar",
    "supliciardes": "supliciar",
    "supliciare": "supliciar",
    "supliciarei": "supliciar",
    "supliciareis": "supliciar",
    "supliciarem": "supliciar",
    "supliciaremos": "supliciar",
    "supliciares": "supliciar",
    "supliciaria": "supliciar",
    "supliciariam": "supliciar",
    "supliciarias": "supliciar",
    "supliciarmo": "supliciar",
    "supliciarmos": "supliciar",
    "supliciará": "supliciar",
    "supliciarás": "supliciar",
    "supliciarão": "supliciar",
    "supliciaríamos": "supliciar",
    "supliciaríeis": "supliciar",
    "suplicias": "supliciar",
    "supliciasse": "supliciar",
    "supliciassem": "supliciar",
    "supliciasses": "supliciar",
    "supliciaste": "supliciar",
    "supliciastes": "supliciar",
    "supliciava": "supliciar",
    "supliciavam": "supliciar",
    "supliciavas": "supliciar",
    "suplicie": "supliciar",
    "supliciei": "supliciar",
    "suplicieis": "supliciar",
    "supliciem": "supliciar",
    "supliciemo": "supliciar",
    "supliciemos": "supliciar",
    "suplicies": "supliciar",
    "suplicio": "supliciar",
    "supliciou": "supliciar",
    "supliciá": "supliciar",
    "supliciámo": "supliciar",
    "supliciámos": "supliciar",
    "supliciáramo": "supliciar",
    "supliciáramos": "supliciar",
    "supliciárei": "supliciar",
    "supliciáreis": "supliciar",
    "supliciásseis": "supliciar",
    "supliciássemos": "supliciar",
    "supliciávamo": "supliciar",
    "supliciávamos": "supliciar",
    "supliciávei": "supliciar",
    "supliciáveis": "supliciar",
    "suplico": "suplicar",
    "suplicou": "suplicar",
    "suplicá": "suplicar",
    "suplicámo": "suplicar",
    "suplicámos": "suplicar",
    "suplicáramo": "suplicar",
    "suplicáramos": "suplicar",
    "suplicárei": "suplicar",
    "suplicáreis": "suplicar",
    "suplicásseis": "suplicar",
    "suplicássemos": "suplicar",
    "suplicávamo": "suplicar",
    "suplicávamos": "suplicar",
    "suplicávei": "suplicar",
    "suplicáveis": "suplicar",
    "suplique": "suplicar",
    "supliquei": "suplicar",
    "supliqueis": "suplicar",
    "supliquem": "suplicar",
    "supliquemo": "suplicar",
    "supliquemos": "suplicar",
    "supliques": "suplicar",
    "suplências": "suplência",
    "suplícios": "suplício",
    "supnaturalismos": "supnaturalismo",
    "supomo": "supor",
    "supomos": "supor",
    "suponde": "supor",
    "supondes": "supor",
    "supondo": "supor",
    "suponha": "supor",
    "suponhais": "supor",
    "suponham": "supor",
    "suponhamo": "supor",
    "suponhamos": "supor",
    "suponhas": "supor",
    "suponho": "supor",
    "suporde": "supor",
    "supordes": "supor",
    "supore": "supor",
    "suporei": "supor",
    "suporeis": "supor",
    "suporem": "supor",
    "suporemos": "supor",
    "supores": "supor",
    "suporia": "supor",
    "suporiam": "supor",
    "suporias": "supor",
    "supormo": "supor",
    "supormos": "supor",
    "suporta": "suportar",
    "suportabilidades": "suportabilidade",
    "suportada": "suportar",
    "suportadas": "suportar",
    "suportado": "suportar",
    "suportados": "suportar",
    "suportai": "suportar",
    "suportais": "suportar",
    "suportam": "suportar",
    "suportamo": "suportar",
    "suportamos": "suportar",
    "suportando": "suportar",
    "suportara": "suportar",
    "suportaram": "suportar",
    "suportaras": "suportar",
    "suportarde": "suportar",
    "suportardes": "suportar",
    "suportare": "suportar",
    "suportarei": "suportar",
    "suportareis": "suportar",
    "suportarem": "suportar",
    "suportaremos": "suportar",
    "suportares": "suportar",
    "suportaria": "suportar",
    "suportariam": "suportar",
    "suportarias": "suportar",
    "suportarmo": "suportar",
    "suportarmos": "suportar",
    "suportará": "suportar",
    "suportarás": "suportar",
    "suportarão": "suportar",
    "suportaríamos": "suportar",
    "suportaríeis": "suportar",
    "suportas": "suportar",
    "suportasse": "suportar",
    "suportassem": "suportar",
    "suportasses": "suportar",
    "suportaste": "suportar",
    "suportastes": "suportar",
    "suportava": "suportar",
    "suportavam": "suportar",
    "suportavas": "suportar",
    "suportações": "suportação",
    "suporte": "suportar",
    "suportei": "suportar",
    "suporteis": "suportar",
    "suportem": "suportar",
    "suportemo": "suportar",
    "suportemos": "suportar",
    "suportes": "suporte",
    "suporto": "suportar",
    "suportou": "suportar",
    "suportá": "suportar",
    "suportámo": "suportar",
    "suportámos": "suportar",
    "suportáramo": "suportar",
    "suportáramos": "suportar",
    "suportárei": "suportar",
    "suportáreis": "suportar",
    "suportásseis": "suportar",
    "suportássemos": "suportar",
    "suportávamo": "suportar",
    "suportávamos": "suportar",
    "suportávei": "suportar",
    "suportáveis": "suportável",
    "suporá": "supor",
    "suporás": "supor",
    "suporão": "supor",
    "suporíamos": "supor",
    "suporíeis": "supor",
    "supos": "supo",
    "supositiva": "supositivo",
    "supositivas": "supositivo",
    "supositivos": "supositivo",
    "supositícia": "supositício",
    "supositícias": "supositício",
    "supositícios": "supositício",
    "supositórios": "supositório",
    "suposições": "suposição",
    "suposta": "suposto",
    "supostas": "suposto",
    "suposto": "supor",
    "supostos": "suposto",
    "supra": "suprir",
    "supraciliares": "supraciliar",
    "supracita": "supracitar",
    "supracitada": "supracitar",
    "supracitadas": "supracitar",
    "supracitado": "supracitar",
    "supracitados": "supracitar",
    "supracitai": "supracitar",
    "supracitais": "supracitar",
    "supracitam": "supracitar",
    "supracitamo": "supracitar",
    "supracitamos": "supracitar",
    "supracitando": "supracitar",
    "supracitara": "supracitar",
    "supracitaram": "supracitar",
    "supracitaras": "supracitar",
    "supracitarde": "supracitar",
    "supracitardes": "supracitar",
    "supracitare": "supracitar",
    "supracitarei": "supracitar",
    "supracitareis": "supracitar",
    "supracitarem": "supracitar",
    "supracitaremos": "supracitar",
    "supracitares": "supracitar",
    "supracitaria": "supracitar",
    "supracitariam": "supracitar",
    "supracitarias": "supracitar",
    "supracitarmo": "supracitar",
    "supracitarmos": "supracitar",
    "supracitará": "supracitar",
    "supracitarás": "supracitar",
    "supracitarão": "supracitar",
    "supracitaríamos": "supracitar",
    "supracitaríeis": "supracitar",
    "supracitas": "supracitar",
    "supracitasse": "supracitar",
    "supracitassem": "supracitar",
    "supracitasses": "supracitar",
    "supracitaste": "supracitar",
    "supracitastes": "supracitar",
    "supracitava": "supracitar",
    "supracitavam": "supracitar",
    "supracitavas": "supracitar",
    "supracite": "supracitar",
    "supracitei": "supracitar",
    "supraciteis": "supracitar",
    "supracitem": "supracitar",
    "supracitemo": "supracitar",
    "supracitemos": "supracitar",
    "supracites": "supracitar",
    "supracito": "supracitar",
    "supracitou": "supracitar",
    "supracitá": "supracitar",
    "supracitámo": "supracitar",
    "supracitámos": "supracitar",
    "supracitáramo": "supracitar",
    "supracitáramos": "supracitar",
    "supracitárei": "supracitar",
    "supracitáreis": "supracitar",
    "supracitásseis": "supracitar",
    "supracitássemos": "supracitar",
    "supracitávamo": "supracitar",
    "supracitávamos": "supracitar",
    "supracitávei": "supracitar",
    "supracitáveis": "supracitar",
    "supracondutividades": "supracondutividade",
    "supracómica": "supracómico",
    "supracómicas": "supracómico",
    "supracómicos": "supracómico",
    "supradita": "supradito",
    "supraditas": "supradito",
    "supraditos": "supradito",
    "suprais": "suprir",
    "suprajacentes": "suprajacente",
    "suprajuraica": "suprajuraico",
    "suprajuraicas": "suprajuraico",
    "suprajuraicos": "suprajuraico",
    "suprajurássica": "suprajurássico",
    "suprajurássicas": "suprajurássico",
    "suprajurássicos": "suprajurássico",
    "supralunares": "supralunar",
    "supram": "suprir",
    "supramencionada": "supramencionado",
    "supramencionadas": "supramencionado",
    "supramencionados": "supramencionado",
    "supramo": "suprir",
    "supramos": "suprir",
    "supramundana": "supramundano",
    "supramundanas": "supramundano",
    "supramundanos": "supramundano",
    "supramunicipais": "supramunicipal",
    "supranacionais": "supranacional",
    "supranaturais": "supranatural",
    "supranaturalismos": "supranaturalismo",
    "supranaturalistas": "supranaturalista",
    "supranumerária": "supranumerário",
    "supranumerárias": "supranumerário",
    "supranumerários": "supranumerário",
    "suprapartidarismos": "suprapartidarismo",
    "supras": "suprir",
    "supraterrena": "supraterreno",
    "supraterrenas": "supraterreno",
    "supraterrenos": "supraterreno",
    "supratorácica": "supratorácico",
    "supratorácicas": "supratorácico",
    "supratorácicos": "supratorácico",
    "supratranscrita": "supratranscrito",
    "supratranscritas": "supratranscrito",
    "supratranscritos": "supratranscrito",
    "supravisões": "supravisão",
    "supre": "suprir",
    "suprem": "suprir",
    "suprema": "supremo",
    "supremacias": "supremacia",
    "supremas": "supremo",
    "suprematismos": "suprematismo",
    "suprematistas": "suprematista",
    "supremos": "supremo",
    "supres": "suprir",
    "supressiva": "supressivo",
    "supressivas": "supressivo",
    "supressivos": "supressivo",
    "supressora": "supressor",
    "supressoras": "supressor",
    "supressores": "supressor",
    "supressória": "supressório",
    "supressórias": "supressório",
    "supressórios": "supressório",
    "supressões": "supressão",
    "supri": "suprir",
    "supria": "suprir",
    "supriam": "suprir",
    "suprias": "suprir",
    "suprida": "suprir",
    "supridas": "suprir",
    "suprido": "suprir",
    "supridora": "supridor",
    "supridoras": "supridor",
    "supridores": "supridor",
    "supridos": "suprir",
    "suprima": "suprimir",
    "suprimais": "suprimir",
    "suprimam": "suprimir",
    "suprimamo": "suprimir",
    "suprimamos": "suprimir",
    "suprimas": "suprimir",
    "suprime": "suprimir",
    "suprimem": "suprimir",
    "suprimentos": "suprimento",
    "suprimes": "suprimir",
    "suprimi": "suprimir",
    "suprimia": "suprimir",
    "suprimiam": "suprimir",
    "suprimias": "suprimir",
    "suprimida": "suprimir",
    "suprimidas": "suprimir",
    "suprimido": "suprimir",
    "suprimidos": "suprimir",
    "suprimimo": "suprimir",
    "suprimimos": "suprimir",
    "suprimindo": "suprimir",
    "suprimira": "suprimir",
    "suprimiram": "suprimir",
    "suprimiras": "suprimir",
    "suprimirde": "suprimir",
    "suprimirdes": "suprimir",
    "suprimire": "suprimir",
    "suprimirei": "suprimir",
    "suprimireis": "suprimir",
    "suprimirem": "suprimir",
    "suprimiremos": "suprimir",
    "suprimires": "suprimir",
    "suprimiria": "suprimir",
    "suprimiriam": "suprimir",
    "suprimirias": "suprimir",
    "suprimirmo": "suprimir",
    "suprimirmos": "suprimir",
    "suprimirá": "suprimir",
    "suprimirás": "suprimir",
    "suprimirão": "suprimir",
    "suprimiríamos": "suprimir",
    "suprimiríeis": "suprimir",
    "suprimis": "suprimir",
    "suprimisse": "suprimir",
    "suprimissem": "suprimir",
    "suprimisses": "suprimir",
    "suprimiste": "suprimir",
    "suprimistes": "suprimir",
    "suprimiu": "suprimir",
    "suprimo": "suprir",
    "suprimos": "suprir",
    "suprimíamo": "suprimir",
    "suprimíamos": "suprimir",
    "suprimíei": "suprimir",
    "suprimíeis": "suprimir",
    "suprimíramo": "suprimir",
    "suprimíramos": "suprimir",
    "suprimírei": "suprimir",
    "suprimíreis": "suprimir",
    "suprimísseis": "suprimir",
    "suprimíssemos": "suprimir",
    "suprimíveis": "suprimível",
    "suprindo": "suprir",
    "suprira": "suprir",
    "supriram": "suprir",
    "supriras": "suprir",
    "suprirde": "suprir",
    "suprirdes": "suprir",
    "suprire": "suprir",
    "suprirei": "suprir",
    "suprireis": "suprir",
    "suprirem": "suprir",
    "supriremos": "suprir",
    "suprires": "suprir",
    "supriria": "suprir",
    "supririam": "suprir",
    "supririas": "suprir",
    "suprirmo": "suprir",
    "suprirmos": "suprir",
    "suprirá": "suprir",
    "suprirás": "suprir",
    "suprirão": "suprir",
    "supriríamos": "suprir",
    "supriríeis": "suprir",
    "supris": "suprir",
    "suprisse": "suprir",
    "suprissem": "suprir",
    "suprisses": "suprir",
    "supriste": "suprir",
    "supristes": "suprir",
    "supriu": "suprir",
    "supro": "suprir",
    "supríamo": "suprir",
    "supríamos": "suprir",
    "supríei": "suprir",
    "supríeis": "suprir",
    "supríramo": "suprir",
    "supríramos": "suprir",
    "suprírei": "suprir",
    "supríreis": "suprir",
    "suprísseis": "suprir",
    "supríssemos": "suprir",
    "supríveis": "suprível",
    "supunha": "supor",
    "supunham": "supor",
    "supunhas": "supor",
    "supura": "supurar",
    "supurada": "supurar",
    "supuradas": "supurar",
    "supurado": "supurar",
    "supurados": "supurar",
    "supurai": "supurar",
    "supurais": "supurar",
    "supuram": "supurar",
    "supuramo": "supurar",
    "supuramos": "supurar",
    "supurando": "supurar",
    "supurantes": "supurante",
    "supurara": "supurar",
    "supuraram": "supurar",
    "supuraras": "supurar",
    "supurardes": "supurar",
    "supurarei": "supurar",
    "supurareis": "supurar",
    "supurarem": "supurar",
    "supuraremos": "supurar",
    "supurares": "supurar",
    "supuraria": "supurar",
    "supurariam": "supurar",
    "supurarias": "supurar",
    "supurarmo": "supurar",
    "supurarmos": "supurar",
    "supurará": "supurar",
    "supurarás": "supurar",
    "supurarão": "supurar",
    "supuraríamos": "supurar",
    "supuraríeis": "supurar",
    "supuras": "supurar",
    "supurasse": "supurar",
    "supurassem": "supurar",
    "supurasses": "supurar",
    "supuraste": "supurar",
    "supurastes": "supurar",
    "supurativa": "supurativo",
    "supurativas": "supurativo",
    "supurativos": "supurativo",
    "supuratória": "supuratório",
    "supuratórias": "supuratório",
    "supuratórios": "supuratório",
    "supurava": "supurar",
    "supuravam": "supurar",
    "supuravas": "supurar",
    "supurações": "supuração",
    "supure": "supurar",
    "supurei": "supurar",
    "supureis": "supurar",
    "supurem": "supurar",
    "supuremo": "supurar",
    "supuremos": "supurar",
    "supures": "supurar",
    "supuro": "supurar",
    "supurou": "supurar",
    "supurámo": "supurar",
    "supurámos": "supurar",
    "supuráramo": "supurar",
    "supuráramos": "supurar",
    "supuráreis": "supurar",
    "supurásseis": "supurar",
    "supurássemos": "supurar",
    "supurávamo": "supurar",
    "supurávamos": "supurar",
    "supuráveis": "supurar",
    "supus": "supor",
    "supusemo": "supor",
    "supusemos": "supor",
    "supuser": "supor",
    "supusera": "supor",
    "supuseram": "supor",
    "supuseras": "supor",
    "supuserdes": "supor",
    "supuserem": "supor",
    "supuseres": "supor",
    "supusermos": "supor",
    "supusesse": "supor",
    "supusessem": "supor",
    "supusesses": "supor",
    "supuseste": "supor",
    "supusestes": "supor",
    "supuséramo": "supor",
    "supuséramos": "supor",
    "supusérei": "supor",
    "supuséreis": "supor",
    "supusésseis": "supor",
    "supuséssemos": "supor",
    "suputa": "suputar",
    "suputada": "suputar",
    "suputadas": "suputar",
    "suputado": "suputar",
    "suputados": "suputar",
    "suputai": "suputar",
    "suputais": "suputar",
    "suputam": "suputar",
    "suputamo": "suputar",
    "suputamos": "suputar",
    "suputando": "suputar",
    "suputara": "suputar",
    "suputaram": "suputar",
    "suputaras": "suputar",
    "suputarde": "suputar",
    "suputardes": "suputar",
    "suputare": "suputar",
    "suputarei": "suputar",
    "suputareis": "suputar",
    "suputarem": "suputar",
    "suputaremos": "suputar",
    "suputares": "suputar",
    "suputaria": "suputar",
    "suputariam": "suputar",
    "suputarias": "suputar",
    "suputarmo": "suputar",
    "suputarmos": "suputar",
    "suputará": "suputar",
    "suputarás": "suputar",
    "suputarão": "suputar",
    "suputaríamos": "suputar",
    "suputaríeis": "suputar",
    "suputas": "suputar",
    "suputasse": "suputar",
    "suputassem": "suputar",
    "suputasses": "suputar",
    "suputaste": "suputar",
    "suputastes": "suputar",
    "suputava": "suputar",
    "suputavam": "suputar",
    "suputavas": "suputar",
    "supute": "suputar",
    "suputei": "suputar",
    "suputeis": "suputar",
    "suputem": "suputar",
    "suputemo": "suputar",
    "suputemos": "suputar",
    "suputes": "suputar",
    "suputo": "suputar",
    "suputou": "suputar",
    "suputá": "suputar",
    "suputámo": "suputar",
    "suputámos": "suputar",
    "suputáramo": "suputar",
    "suputáramos": "suputar",
    "suputárei": "suputar",
    "suputáreis": "suputar",
    "suputásseis": "suputar",
    "suputássemos": "suputar",
    "suputávamo": "suputar",
    "suputávamos": "suputar",
    "suputávei": "suputar",
    "suputáveis": "suputar",
    "supérflua": "supérfluo",
    "supérfluas": "supérfluo",
    "supérfluos": "supérfluo",
    "supérstites": "supérstite",
    "supô": "supor",
    "supôs": "supor",
    "supõe": "supor",
    "supõem": "supor",
    "supões": "supor",
    "supúnhamo": "supor",
    "supúnhamos": "supor",
    "supúnhei": "supor",
    "supúnheis": "supor",
    "suqua": "suquir",
    "suquais": "suquir",
    "suquam": "suquir",
    "suquamo": "suquir",
    "suquamos": "suquir",
    "suquas": "suquir",
    "suquem": "suquir",
    "suqui": "suquir",
    "suquindo": "suquir",
    "suquirdes": "suquir",
    "suquirei": "suquir",
    "suquireis": "suquir",
    "suquiremos": "suquir",
    "suquiria": "suquir",
    "suquiriam": "suquir",
    "suquirias": "suquir",
    "suquirmo": "suquir",
    "suquirmos": "suquir",
    "suquirá": "suquir",
    "suquirás": "suquir",
    "suquirão": "suquir",
    "suquiríamos": "suquir",
    "suquiríeis": "suquir",
    "suquis": "suquir",
    "suquiu": "suquir",
    "suquo": "suquir",
    "suquí": "suquir",
    "suquía": "suquir",
    "suquíam": "suquir",
    "suquíamo": "suquir",
    "suquíamos": "suquir",
    "suquías": "suquir",
    "suquída": "suquir",
    "suquídas": "suquir",
    "suquído": "suquir",
    "suquídos": "suquir",
    "suquíeis": "suquir",
    "suquímo": "suquir",
    "suquímos": "suquir",
    "suquíra": "suquir",
    "suquíram": "suquir",
    "suquíramo": "suquir",
    "suquíramos": "suquir",
    "suquíras": "suquir",
    "suquíreis": "suquir",
    "suquírem": "suquir",
    "suquíres": "suquir",
    "suquís": "suquir",
    "suquísse": "suquir",
    "suquísseis": "suquir",
    "suquíssem": "suquir",
    "suquíssemos": "suquir",
    "suquísses": "suquir",
    "suquíste": "suquir",
    "suquístes": "suquir",
    "sura": "suro",
    "surais": "sural",
    "suranas": "surana",
    "suras": "suro",
    "surda": "surdo",
    "surdais": "surdir",
    "surdam": "surdir",
    "surdamo": "surdir",
    "surdamos": "surdir",
    "surdas": "surdo",
    "surdazinha": "surdo",
    "surdazinhas": "surdo",
    "surdazita": "surdo",
    "surdazitas": "surdo",
    "surde": "surdir",
    "surdeada": "surdear",
    "surdeadas": "surdear",
    "surdeado": "surdear",
    "surdeados": "surdear",
    "surdeai": "surdear",
    "surdeais": "surdear",
    "surdeamo": "surdear",
    "surdeamos": "surdear",
    "surdeando": "surdear",
    "surdeara": "surdear",
    "surdearam": "surdear",
    "surdearas": "surdear",
    "surdeardes": "surdear",
    "surdearei": "surdear",
    "surdeareis": "surdear",
    "surdearem": "surdear",
    "surdearemos": "surdear",
    "surdeares": "surdear",
    "surdearia": "surdear",
    "surdeariam": "surdear",
    "surdearias": "surdear",
    "surdearmo": "surdear",
    "surdearmos": "surdear",
    "surdeará": "surdear",
    "surdearás": "surdear",
    "surdearão": "surdear",
    "surdearíamos": "surdear",
    "surdearíeis": "surdear",
    "surdeasse": "surdear",
    "surdeassem": "surdear",
    "surdeasses": "surdear",
    "surdeaste": "surdear",
    "surdeastes": "surdear",
    "surdeava": "surdear",
    "surdeavam": "surdear",
    "surdeavas": "surdear",
    "surdeei": "surdear",
    "surdeeis": "surdear",
    "surdeemo": "surdear",
    "surdeemos": "surdear",
    "surdeia": "surdear",
    "surdeiam": "surdear",
    "surdeias": "surdear",
    "surdeie": "surdear",
    "surdeiem": "surdear",
    "surdeies": "surdear",
    "surdeio": "surdear",
    "surdem": "surdir",
    "surdeou": "surdear",
    "surdes": "surdir",
    "surdescentes": "surdescente",
    "surdezes": "surdez",
    "surdeámo": "surdear",
    "surdeámos": "surdear",
    "surdeáramo": "surdear",
    "surdeáramos": "surdear",
    "surdeáreis": "surdear",
    "surdeásseis": "surdear",
    "surdeássemos": "surdear",
    "surdeávamo": "surdear",
    "surdeávamos": "surdear",
    "surdeáveis": "surdear",
    "surdi": "surdir",
    "surdia": "surdir",
    "surdiam": "surdir",
    "surdias": "surdir",
    "surdida": "surdir",
    "surdidas": "surdir",
    "surdido": "surdir",
    "surdidos": "surdir",
    "surdimo": "surdir",
    "surdimos": "surdir",
    "surdimutismos": "surdimutismo",
    "surdina": "surdinar",
    "surdinada": "surdinar",
    "surdinadas": "surdinar",
    "surdinado": "surdinar",
    "surdinados": "surdinar",
    "surdinai": "surdinar",
    "surdinais": "surdinar",
    "surdinam": "surdinar",
    "surdinamo": "surdinar",
    "surdinamos": "surdinar",
    "surdinando": "surdinar",
    "surdinara": "surdinar",
    "surdinaram": "surdinar",
    "surdinaras": "surdinar",
    "surdinardes": "surdinar",
    "surdinarei": "surdinar",
    "surdinareis": "surdinar",
    "surdinarem": "surdinar",
    "surdinaremos": "surdinar",
    "surdinares": "surdinar",
    "surdinaria": "surdinar",
    "surdinariam": "surdinar",
    "surdinarias": "surdinar",
    "surdinarmo": "surdinar",
    "surdinarmos": "surdinar",
    "surdinará": "surdinar",
    "surdinarás": "surdinar",
    "surdinarão": "surdinar",
    "surdinaríamos": "surdinar",
    "surdinaríeis": "surdinar",
    "surdinas": "surdinar",
    "surdinasse": "surdinar",
    "surdinassem": "surdinar",
    "surdinasses": "surdinar",
    "surdinaste": "surdinar",
    "surdinastes": "surdinar",
    "surdinava": "surdinar",
    "surdinavam": "surdinar",
    "surdinavas": "surdinar",
    "surdindo": "surdir",
    "surdine": "surdinar",
    "surdinei": "surdinar",
    "surdineis": "surdinar",
    "surdinem": "surdinar",
    "surdinemo": "surdinar",
    "surdinemos": "surdinar",
    "surdines": "surdinar",
    "surdinha": "surdo",
    "surdinhas": "surdo",
    "surdinho": "surdo",
    "surdinhos": "surdo",
    "surdino": "surdinar",
    "surdinou": "surdinar",
    "surdinámo": "surdinar",
    "surdinámos": "surdinar",
    "surdináramo": "surdinar",
    "surdináramos": "surdinar",
    "surdináreis": "surdinar",
    "surdinásseis": "surdinar",
    "surdinássemos": "surdinar",
    "surdinávamo": "surdinar",
    "surdinávamos": "surdinar",
    "surdináveis": "surdinar",
    "surdira": "surdir",
    "surdiram": "surdir",
    "surdiras": "surdir",
    "surdirdes": "surdir",
    "surdirei": "surdir",
    "surdireis": "surdir",
    "surdirem": "surdir",
    "surdiremos": "surdir",
    "surdires": "surdir",
    "surdiria": "surdir",
    "surdiriam": "surdir",
    "surdirias": "surdir",
    "surdirmo": "surdir",
    "surdirmos": "surdir",
    "surdirá": "surdir",
    "surdirás": "surdir",
    "surdirão": "surdir",
    "surdiríamos": "surdir",
    "surdiríeis": "surdir",
    "surdis": "surdir",
    "surdisse": "surdir",
    "surdissem": "surdir",
    "surdisses": "surdir",
    "surdiste": "surdir",
    "surdistes": "surdir",
    "surdita": "surdo",
    "surditas": "surdo",
    "surdito": "surdo",
    "surditos": "surdo",
    "surdiu": "surdir",
    "surdivéns": "surdivém",
    "surdo": "surdir",
    "surdos": "surdo",
    "surdozinho": "surdo",
    "surdozinhos": "surdo",
    "surdozito": "surdo",
    "surdozitos": "surdo",
    "surdíamo": "surdir",
    "surdíamos": "surdir",
    "surdíeis": "surdir",
    "surdíramo": "surdir",
    "surdíramos": "surdir",
    "surdíreis": "surdir",
    "surdísseis": "surdir",
    "surdíssemos": "surdir",
    "surdíssima": "surdo",
    "surdíssimas": "surdo",
    "surdíssimo": "surdo",
    "surdíssimos": "surdo",
    "surfa": "surfar",
    "surfada": "surfar",
    "surfadas": "surfar",
    "surfado": "surfar",
    "surfados": "surfar",
    "surfai": "surfar",
    "surfais": "surfar",
    "surfam": "surfar",
    "surfamo": "surfar",
    "surfamos": "surfar",
    "surfando": "surfar",
    "surfara": "surfar",
    "surfaram": "surfar",
    "surfaras": "surfar",
    "surfarde": "surfar",
    "surfardes": "surfar",
    "surfare": "surfar",
    "surfarei": "surfar",
    "surfareis": "surfar",
    "surfarem": "surfar",
    "surfaremos": "surfar",
    "surfares": "surfar",
    "surfaria": "surfar",
    "surfariam": "surfar",
    "surfarias": "surfar",
    "surfarmo": "surfar",
    "surfarmos": "surfar",
    "surfará": "surfar",
    "surfarás": "surfar",
    "surfarão": "surfar",
    "surfaríamos": "surfar",
    "surfaríeis": "surfar",
    "surfas": "surfar",
    "surfasse": "surfar",
    "surfassem": "surfar",
    "surfasses": "surfar",
    "surfaste": "surfar",
    "surfastes": "surfar",
    "surfava": "surfar",
    "surfavam": "surfar",
    "surfavas": "surfar",
    "surfe": "surfar",
    "surfei": "surfar",
    "surfeis": "surfar",
    "surfem": "surfar",
    "surfemo": "surfar",
    "surfemos": "surfar",
    "surfes": "surfe",
    "surfistas": "surfista",
    "surfo": "surfar",
    "surfou": "surfar",
    "surfá": "surfar",
    "surfámo": "surfar",
    "surfámos": "surfar",
    "surfáramo": "surfar",
    "surfáramos": "surfar",
    "surfárei": "surfar",
    "surfáreis": "surfar",
    "surfásseis": "surfar",
    "surfássemos": "surfar",
    "surfávamo": "surfar",
    "surfávamos": "surfar",
    "surfávei": "surfar",
    "surfáveis": "surfar",
    "surge": "surgir",
    "surgem": "surgir",
    "surges": "surgir",
    "surgi": "surgir",
    "surgia": "surgir",
    "surgiam": "surgir",
    "surgias": "surgir",
    "surgida": "surgir",
    "surgidas": "surgir",
    "surgido": "surgir",
    "surgidoiros": "surgidoiro",
    "surgidos": "surgir",
    "surgidouros": "surgidouro",
    "surgimentos": "surgimento",
    "surgimo": "surgir",
    "surgimos": "surgir",
    "surgindo": "surgir",
    "surgira": "surgir",
    "surgiram": "surgir",
    "surgiras": "surgir",
    "surgirdes": "surgir",
    "surgirei": "surgir",
    "surgireis": "surgir",
    "surgirem": "surgir",
    "surgiremos": "surgir",
    "surgires": "surgir",
    "surgiria": "surgir",
    "surgiriam": "surgir",
    "surgirias": "surgir",
    "surgirmo": "surgir",
    "surgirmos": "surgir",
    "surgirá": "surgir",
    "surgirás": "surgir",
    "surgirão": "surgir",
    "surgiríamos": "surgir",
    "surgiríeis": "surgir",
    "surgis": "surgir",
    "surgisse": "surgir",
    "surgissem": "surgir",
    "surgisses": "surgir",
    "surgiste": "surgir",
    "surgistes": "surgir",
    "surgiu": "surgir",
    "surgíamo": "surgir",
    "surgíamos": "surgir",
    "surgíeis": "surgir",
    "surgíramo": "surgir",
    "surgíramos": "surgir",
    "surgíreis": "surgir",
    "surgísseis": "surgir",
    "surgíssemos": "surgir",
    "surinamesa": "surinamês",
    "surinamesas": "surinamês",
    "surinameses": "surinamês",
    "surja": "surgir",
    "surjais": "surgir",
    "surjam": "surgir",
    "surjamo": "surgir",
    "surjamos": "surgir",
    "surjas": "surgir",
    "surjo": "surgir",
    "suropos": "suropo",
    "suros": "suro",
    "surpreenda": "surpreender",
    "surpreendais": "surpreender",
    "surpreendam": "surpreender",
    "surpreendamo": "surpreender",
    "surpreendamos": "surpreender",
    "surpreendas": "surpreender",
    "surpreende": "surpreender",
    "surpreendei": "surpreender",
    "surpreendeis": "surpreender",
    "surpreendem": "surpreender",
    "surpreendemo": "surpreender",
    "surpreendemos": "surpreender",
    "surpreendendo": "surpreender",
    "surpreendentes": "surpreendente",
    "surpreendera": "surpreender",
    "surpreenderam": "surpreender",
    "surpreenderas": "surpreender",
    "surpreenderde": "surpreender",
    "surpreenderdes": "surpreender",
    "surpreendere": "surpreender",
    "surpreenderei": "surpreender",
    "surpreendereis": "surpreender",
    "surpreenderem": "surpreender",
    "surpreenderemos": "surpreender",
    "surpreenderes": "surpreender",
    "surpreenderia": "surpreender",
    "surpreenderiam": "surpreender",
    "surpreenderias": "surpreender",
    "surpreendermo": "surpreender",
    "surpreendermos": "surpreender",
    "surpreenderá": "surpreender",
    "surpreenderás": "surpreender",
    "surpreenderão": "surpreender",
    "surpreenderíamos": "surpreender",
    "surpreenderíeis": "surpreender",
    "surpreendes": "surpreender",
    "surpreendesse": "surpreender",
    "surpreendessem": "surpreender",
    "surpreendesses": "surpreender",
    "surpreendeste": "surpreender",
    "surpreendestes": "surpreender",
    "surpreendeu": "surpreender",
    "surpreendi": "surpreender",
    "surpreendia": "surpreender",
    "surpreendiam": "surpreender",
    "surpreendias": "surpreender",
    "surpreendida": "surpreendido",
    "surpreendidas": "surpreendido",
    "surpreendido": "surpreender",
    "surpreendidos": "surpreendido",
    "surpreendidíssima": "surpreendido",
    "surpreendidíssimas": "surpreendido",
    "surpreendidíssimo": "surpreendido",
    "surpreendidíssimos": "surpreendido",
    "surpreendo": "surpreender",
    "surpreendê": "surpreender",
    "surpreendêramo": "surpreender",
    "surpreendêramos": "surpreender",
    "surpreendêrei": "surpreender",
    "surpreendêreis": "surpreender",
    "surpreendêsseis": "surpreender",
    "surpreendêssemos": "surpreender",
    "surpreendíamo": "surpreender",
    "surpreendíamos": "surpreender",
    "surpreendíei": "surpreender",
    "surpreendíeis": "surpreender",
    "surpresa": "surpreso",
    "surpresada": "surpresar",
    "surpresadas": "surpresar",
    "surpresado": "surpresar",
    "surpresados": "surpresar",
    "surpresai": "surpresar",
    "surpresais": "surpresar",
    "surpresam": "surpresar",
    "surpresamo": "surpresar",
    "surpresamos": "surpresar",
    "surpresando": "surpresar",
    "surpresara": "surpresar",
    "surpresaram": "surpresar",
    "surpresaras": "surpresar",
    "surpresarde": "surpresar",
    "surpresardes": "surpresar",
    "surpresare": "surpresar",
    "surpresarei": "surpresar",
    "surpresareis": "surpresar",
    "surpresarem": "surpresar",
    "surpresaremos": "surpresar",
    "surpresares": "surpresar",
    "surpresaria": "surpresar",
    "surpresariam": "surpresar",
    "surpresarias": "surpresar",
    "surpresarmo": "surpresar",
    "surpresarmos": "surpresar",
    "surpresará": "surpresar",
    "surpresarás": "surpresar",
    "surpresarão": "surpresar",
    "surpresaríamos": "surpresar",
    "surpresaríeis": "surpresar",
    "surpresas": "surpreso",
    "surpresasse": "surpresar",
    "surpresassem": "surpresar",
    "surpresasses": "surpresar",
    "surpresaste": "surpresar",
    "surpresastes": "surpresar",
    "surpresava": "surpresar",
    "surpresavam": "surpresar",
    "surpresavas": "surpresar",
    "surprese": "surpresar",
    "surpresei": "surpresar",
    "surpreseis": "surpresar",
    "surpresem": "surpresar",
    "surpresemo": "surpresar",
    "surpresemos": "surpresar",
    "surpreses": "surpresar",
    "surpreso": "surpresar",
    "surpresos": "surpreso",
    "surpresou": "surpresar",
    "surpresá": "surpresar",
    "surpresámo": "surpresar",
    "surpresámos": "surpresar",
    "surpresáramo": "surpresar",
    "surpresáramos": "surpresar",
    "surpresárei": "surpresar",
    "surpresáreis": "surpresar",
    "surpresásseis": "surpresar",
    "surpresássemos": "surpresar",
    "surpresávamo": "surpresar",
    "surpresávamos": "surpresar",
    "surpresávei": "surpresar",
    "surpresáveis": "surpresar",
    "surra": "surrar",
    "surrada": "surrar",
    "surradas": "surrar",
    "surrado": "surrar",
    "surradora": "surrador",
    "surradoras": "surrador",
    "surradores": "surrador",
    "surrados": "surrar",
    "surrai": "surrar",
    "surrais": "surrar",
    "surram": "surrar",
    "surramentos": "surramento",
    "surramo": "surrar",
    "surramos": "surrar",
    "surrando": "surrar",
    "surrara": "surrar",
    "surraram": "surrar",
    "surraras": "surrar",
    "surrardes": "surrar",
    "surrarei": "surrar",
    "surrareis": "surrar",
    "surrarem": "surrar",
    "surraremos": "surrar",
    "surrares": "surrar",
    "surraria": "surrar",
    "surrariam": "surrar",
    "surrarias": "surrar",
    "surrarmo": "surrar",
    "surrarmos": "surrar",
    "surrará": "surrar",
    "surrarás": "surrar",
    "surrarão": "surrar",
    "surraríamos": "surrar",
    "surraríeis": "surrar",
    "surras": "surrar",
    "surrasse": "surrar",
    "surrassem": "surrar",
    "surrasses": "surrar",
    "surraste": "surrar",
    "surrastes": "surrar",
    "surrava": "surrar",
    "surravam": "surrar",
    "surravas": "surrar",
    "surre": "surrar",
    "surreais": "surreal",
    "surrealidades": "surrealidade",
    "surrealismos": "surrealismo",
    "surrealistas": "surrealista",
    "surrealistazinha": "surrealista",
    "surrealistazinhas": "surrealista",
    "surrealistazinho": "surrealista",
    "surrealistazinhos": "surrealista",
    "surrealistazita": "surrealista",
    "surrealistazitas": "surrealista",
    "surrealistazito": "surrealista",
    "surrealistazitos": "surrealista",
    "surrei": "surrar",
    "surreis": "surrar",
    "surrem": "surrar",
    "surremo": "surrar",
    "surremos": "surrar",
    "surrenta": "surrento",
    "surrentas": "surrento",
    "surrentos": "surrento",
    "surres": "surrar",
    "surria": "surriar",
    "surriada": "surriar",
    "surriadas": "surriar",
    "surriado": "surriar",
    "surriados": "surriar",
    "surriai": "surriar",
    "surriais": "surriar",
    "surriam": "surriar",
    "surriamo": "surriar",
    "surriamos": "surriar",
    "surriando": "surriar",
    "surriara": "surriar",
    "surriaram": "surriar",
    "surriaras": "surriar",
    "surriarde": "surriar",
    "surriardes": "surriar",
    "surriare": "surriar",
    "surriarei": "surriar",
    "surriareis": "surriar",
    "surriarem": "surriar",
    "surriaremos": "surriar",
    "surriares": "surriar",
    "surriaria": "surriar",
    "surriariam": "surriar",
    "surriarias": "surriar",
    "surriarmo": "surriar",
    "surriarmos": "surriar",
    "surriará": "surriar",
    "surriarás": "surriar",
    "surriarão": "surriar",
    "surriaríamos": "surriar",
    "surriaríeis": "surriar",
    "surrias": "surriar",
    "surriasse": "surriar",
    "surriassem": "surriar",
    "surriasses": "surriar",
    "surriaste": "surriar",
    "surriastes": "surriar",
    "surriava": "surriar",
    "surriavam": "surriar",
    "surriavas": "surriar",
    "surriba": "surribar",
    "surribada": "surribar",
    "surribadas": "surribar",
    "surribado": "surribar",
    "surribados": "surribar",
    "surribai": "surribar",
    "surribais": "surribar",
    "surribam": "surribar",
    "surribamo": "surribar",
    "surribamos": "surribar",
    "surribando": "surribar",
    "surribara": "surribar",
    "surribaram": "surribar",
    "surribaras": "surribar",
    "surribarde": "surribar",
    "surribardes": "surribar",
    "surribare": "surribar",
    "surribarei": "surribar",
    "surribareis": "surribar",
    "surribarem": "surribar",
    "surribaremos": "surribar",
    "surribares": "surribar",
    "surribaria": "surribar",
    "surribariam": "surribar",
    "surribarias": "surribar",
    "surribarmo": "surribar",
    "surribarmos": "surribar",
    "surribará": "surribar",
    "surribarás": "surribar",
    "surribarão": "surribar",
    "surribaríamos": "surribar",
    "surribaríeis": "surribar",
    "surribas": "surribar",
    "surribasse": "surribar",
    "surribassem": "surribar",
    "surribasses": "surribar",
    "surribaste": "surribar",
    "surribastes": "surribar",
    "surribava": "surribar",
    "surribavam": "surribar",
    "surribavas": "surribar",
    "surribe": "surribar",
    "surribei": "surribar",
    "surribeis": "surribar",
    "surribem": "surribar",
    "surribemo": "surribar",
    "surribemos": "surribar",
    "surribes": "surribar",
    "surribo": "surribar",
    "surribou": "surribar",
    "surribá": "surribar",
    "surribámo": "surribar",
    "surribámos": "surribar",
    "surribáramo": "surribar",
    "surribáramos": "surribar",
    "surribárei": "surribar",
    "surribáreis": "surribar",
    "surribásseis": "surribar",
    "surribássemos": "surribar",
    "surribávamo": "surribar",
    "surribávamos": "surribar",
    "surribávei": "surribar",
    "surribáveis": "surribar",
    "surrie": "surriar",
    "surriei": "surriar",
    "surrieis": "surriar",
    "surriem": "surriar",
    "surriemo": "surriar",
    "surriemos": "surriar",
    "surries": "surriar",
    "surrio": "surriar",
    "surriou": "surriar",
    "surripia": "surripiar",
    "surripiada": "surripiar",
    "surripiadas": "surripiar",
    "surripiado": "surripiar",
    "surripiados": "surripiar",
    "surripiagens": "surripiagem",
    "surripiai": "surripiar",
    "surripiais": "surripiar",
    "surripiam": "surripiar",
    "surripiamo": "surripiar",
    "surripiamos": "surripiar",
    "surripiando": "surripiar",
    "surripianços": "surripianço",
    "surripiara": "surripiar",
    "surripiaram": "surripiar",
    "surripiaras": "surripiar",
    "surripiarde": "surripiar",
    "surripiardes": "surripiar",
    "surripiare": "surripiar",
    "surripiarei": "surripiar",
    "surripiareis": "surripiar",
    "surripiarem": "surripiar",
    "surripiaremos": "surripiar",
    "surripiares": "surripiar",
    "surripiaria": "surripiar",
    "surripiariam": "surripiar",
    "surripiarias": "surripiar",
    "surripiarmo": "surripiar",
    "surripiarmos": "surripiar",
    "surripiará": "surripiar",
    "surripiarás": "surripiar",
    "surripiarão": "surripiar",
    "surripiaríamos": "surripiar",
    "surripiaríeis": "surripiar",
    "surripias": "surripiar",
    "surripiasse": "surripiar",
    "surripiassem": "surripiar",
    "surripiasses": "surripiar",
    "surripiaste": "surripiar",
    "surripiastes": "surripiar",
    "surripiava": "surripiar",
    "surripiavam": "surripiar",
    "surripiavas": "surripiar",
    "surripie": "surripiar",
    "surripiei": "surripiar",
    "surripieis": "surripiar",
    "surripiem": "surripiar",
    "surripiemo": "surripiar",
    "surripiemos": "surripiar",
    "surripies": "surripiar",
    "surripilha": "surripilhar",
    "surripilhada": "surripilhar",
    "surripilhadas": "surripilhar",
    "surripilhado": "surripilhar",
    "surripilhados": "surripilhar",
    "surripilhai": "surripilhar",
    "surripilhais": "surripilhar",
    "surripilham": "surripilhar",
    "surripilhamo": "surripilhar",
    "surripilhamos": "surripilhar",
    "surripilhando": "surripilhar",
    "surripilhara": "surripilhar",
    "surripilharam": "surripilhar",
    "surripilharas": "surripilhar",
    "surripilharde": "surripilhar",
    "surripilhardes": "surripilhar",
    "surripilhare": "surripilhar",
    "surripilharei": "surripilhar",
    "surripilhareis": "surripilhar",
    "surripilharem": "surripilhar",
    "surripilharemos": "surripilhar",
    "surripilhares": "surripilhar",
    "surripilharia": "surripilhar",
    "surripilhariam": "surripilhar",
    "surripilharias": "surripilhar",
    "surripilharmo": "surripilhar",
    "surripilharmos": "surripilhar",
    "surripilhará": "surripilhar",
    "surripilharás": "surripilhar",
    "surripilharão": "surripilhar",
    "surripilharíamos": "surripilhar",
    "surripilharíeis": "surripilhar",
    "surripilhas": "surripilhar",
    "surripilhasse": "surripilhar",
    "surripilhassem": "surripilhar",
    "surripilhasses": "surripilhar",
    "surripilhaste": "surripilhar",
    "surripilhastes": "surripilhar",
    "surripilhava": "surripilhar",
    "surripilhavam": "surripilhar",
    "surripilhavas": "surripilhar",
    "surripilhe": "surripilhar",
    "surripilhei": "surripilhar",
    "surripilheis": "surripilhar",
    "surripilhem": "surripilhar",
    "surripilhemo": "surripilhar",
    "surripilhemos": "surripilhar",
    "surripilhes": "surripilhar",
    "surripilho": "surripilhar",
    "surripilhou": "surripilhar",
    "surripilhá": "surripilhar",
    "surripilhámo": "surripilhar",
    "surripilhámos": "surripilhar",
    "surripilháramo": "surripilhar",
    "surripilháramos": "surripilhar",
    "surripilhárei": "surripilhar",
    "surripilháreis": "surripilhar",
    "surripilhásseis": "surripilhar",
    "surripilhássemos": "surripilhar",
    "surripilhávamo": "surripilhar",
    "surripilhávamos": "surripilhar",
    "surripilhávei": "surripilhar",
    "surripilháveis": "surripilhar",
    "surripio": "surripiar",
    "surripiou": "surripiar",
    "surripiá": "surripiar",
    "surripiámo": "surripiar",
    "surripiámos": "surripiar",
    "surripiáramo": "surripiar",
    "surripiáramos": "surripiar",
    "surripiárei": "surripiar",
    "surripiáreis": "surripiar",
    "surripiásseis": "surripiar",
    "surripiássemos": "surripiar",
    "surripiávamo": "surripiar",
    "surripiávamos": "surripiar",
    "surripiávei": "surripiar",
    "surripiáveis": "surripiar",
    "surriá": "surriar",
    "surriámo": "surriar",
    "surriámos": "surriar",
    "surriáramo": "surriar",
    "surriáramos": "surriar",
    "surriárei": "surriar",
    "surriáreis": "surriar",
    "surriásseis": "surriar",
    "surriássemos": "surriar",
    "surriávamo": "surriar",
    "surriávamos": "surriar",
    "surriávei": "surriar",
    "surriáveis": "surriar",
    "surro": "surrar",
    "surrobecos": "surrobeco",
    "surros": "surro",
    "surrou": "surrar",
    "surrámo": "surrar",
    "surrámos": "surrar",
    "surráramo": "surrar",
    "surráramos": "surrar",
    "surráreis": "surrar",
    "surrásseis": "surrar",
    "surrássemos": "surrar",
    "surrávamo": "surrar",
    "surrávamos": "surrar",
    "surráveis": "surrar",
    "surrões": "surrão",
    "surta": "surto",
    "surtais": "surtir",
    "surtam": "surtir",
    "surtamo": "surtir",
    "surtamos": "surtir",
    "surtas": "surto",
    "surte": "surtir",
    "surtem": "surtir",
    "surtes": "surtir",
    "surti": "surtir",
    "surtia": "surtir",
    "surtiam": "surtir",
    "surtias": "surtir",
    "surtida": "surtir",
    "surtidas": "surtir",
    "surtido": "surtir",
    "surtidos": "surtir",
    "surtimo": "surtir",
    "surtimos": "surtir",
    "surtindo": "surtir",
    "surtira": "surtir",
    "surtiram": "surtir",
    "surtiras": "surtir",
    "surtirde": "surtir",
    "surtirdes": "surtir",
    "surtire": "surtir",
    "surtirei": "surtir",
    "surtireis": "surtir",
    "surtirem": "surtir",
    "surtiremos": "surtir",
    "surtires": "surtir",
    "surtiria": "surtir",
    "surtiriam": "surtir",
    "surtirias": "surtir",
    "surtirmo": "surtir",
    "surtirmos": "surtir",
    "surtirá": "surtir",
    "surtirás": "surtir",
    "surtirão": "surtir",
    "surtiríamos": "surtir",
    "surtiríeis": "surtir",
    "surtis": "surtir",
    "surtisse": "surtir",
    "surtissem": "surtir",
    "surtisses": "surtir",
    "surtiste": "surtir",
    "surtistes": "surtir",
    "surtiu": "surtir",
    "surto": "surtir",
    "surtos": "surto",
    "surtíamo": "surtir",
    "surtíamos": "surtir",
    "surtíei": "surtir",
    "surtíeis": "surtir",
    "surtíramo": "surtir",
    "surtíramos": "surtir",
    "surtírei": "surtir",
    "surtíreis": "surtir",
    "surtísseis": "surtir",
    "surtíssemos": "surtir",
    "surucucus": "surucucu",
    "surças": "surça",
    "susceptibilidades": "susceptibilidade",
    "susceptibiliza": "susceptibilizar",
    "susceptibilizada": "susceptibilizar",
    "susceptibilizadas": "susceptibilizar",
    "susceptibilizado": "susceptibilizar",
    "susceptibilizados": "susceptibilizar",
    "susceptibilizai": "susceptibilizar",
    "susceptibilizais": "susceptibilizar",
    "susceptibilizam": "susceptibilizar",
    "susceptibilizamo": "susceptibilizar",
    "susceptibilizamos": "susceptibilizar",
    "susceptibilizando": "susceptibilizar",
    "susceptibilizara": "susceptibilizar",
    "susceptibilizaram": "susceptibilizar",
    "susceptibilizaras": "susceptibilizar",
    "susceptibilizarde": "susceptibilizar",
    "susceptibilizardes": "susceptibilizar",
    "susceptibilizare": "susceptibilizar",
    "susceptibilizarei": "susceptibilizar",
    "susceptibilizareis": "susceptibilizar",
    "susceptibilizarem": "susceptibilizar",
    "susceptibilizaremos": "susceptibilizar",
    "susceptibilizares": "susceptibilizar",
    "susceptibilizaria": "susceptibilizar",
    "susceptibilizariam": "susceptibilizar",
    "susceptibilizarias": "susceptibilizar",
    "susceptibilizarmo": "susceptibilizar",
    "susceptibilizarmos": "susceptibilizar",
    "susceptibilizará": "susceptibilizar",
    "susceptibilizarás": "susceptibilizar",
    "susceptibilizarão": "susceptibilizar",
    "susceptibilizaríamos": "susceptibilizar",
    "susceptibilizaríeis": "susceptibilizar",
    "susceptibilizas": "susceptibilizar",
    "susceptibilizasse": "susceptibilizar",
    "susceptibilizassem": "susceptibilizar",
    "susceptibilizasses": "susceptibilizar",
    "susceptibilizaste": "susceptibilizar",
    "susceptibilizastes": "susceptibilizar",
    "susceptibilizava": "susceptibilizar",
    "susceptibilizavam": "susceptibilizar",
    "susceptibilizavas": "susceptibilizar",
    "susceptibilize": "susceptibilizar",
    "susceptibilizei": "susceptibilizar",
    "susceptibilizeis": "susceptibilizar",
    "susceptibilizem": "susceptibilizar",
    "susceptibilizemo": "susceptibilizar",
    "susceptibilizemos": "susceptibilizar",
    "susceptibilizes": "susceptibilizar",
    "susceptibilizo": "susceptibilizar",
    "susceptibilizou": "susceptibilizar",
    "susceptibilizá": "susceptibilizar",
    "susceptibilizámo": "susceptibilizar",
    "susceptibilizámos": "susceptibilizar",
    "susceptibilizáramo": "susceptibilizar",
    "susceptibilizáramos": "susceptibilizar",
    "susceptibilizárei": "susceptibilizar",
    "susceptibilizáreis": "susceptibilizar",
    "susceptibilizásseis": "susceptibilizar",
    "susceptibilizássemos": "susceptibilizar",
    "susceptibilizávamo": "susceptibilizar",
    "susceptibilizávamos": "susceptibilizar",
    "susceptibilizávei": "susceptibilizar",
    "susceptibilizáveis": "susceptibilizar",
    "susceptâncias": "susceptância",
    "susceptíveis": "susceptível",
    "suscita": "suscitar",
    "suscitada": "suscitar",
    "suscitadas": "suscitar",
    "suscitado": "suscitar",
    "suscitadora": "suscitador",
    "suscitadoras": "suscitador",
    "suscitadores": "suscitador",
    "suscitados": "suscitar",
    "suscitai": "suscitar",
    "suscitais": "suscitar",
    "suscitam": "suscitar",
    "suscitamentos": "suscitamento",
    "suscitamo": "suscitar",
    "suscitamos": "suscitar",
    "suscitando": "suscitar",
    "suscitantes": "suscitante",
    "suscitara": "suscitar",
    "suscitaram": "suscitar",
    "suscitaras": "suscitar",
    "suscitarde": "suscitar",
    "suscitardes": "suscitar",
    "suscitare": "suscitar",
    "suscitarei": "suscitar",
    "suscitareis": "suscitar",
    "suscitarem": "suscitar",
    "suscitaremos": "suscitar",
    "suscitares": "suscitar",
    "suscitaria": "suscitar",
    "suscitariam": "suscitar",
    "suscitarias": "suscitar",
    "suscitarmo": "suscitar",
    "suscitarmos": "suscitar",
    "suscitará": "suscitar",
    "suscitarás": "suscitar",
    "suscitarão": "suscitar",
    "suscitaríamos": "suscitar",
    "suscitaríeis": "suscitar",
    "suscitas": "suscitar",
    "suscitasse": "suscitar",
    "suscitassem": "suscitar",
    "suscitasses": "suscitar",
    "suscitaste": "suscitar",
    "suscitastes": "suscitar",
    "suscitava": "suscitar",
    "suscitavam": "suscitar",
    "suscitavas": "suscitar",
    "suscitações": "suscitação",
    "suscite": "suscitar",
    "suscitei": "suscitar",
    "susciteis": "suscitar",
    "suscitem": "suscitar",
    "suscitemo": "suscitar",
    "suscitemos": "suscitar",
    "suscites": "suscitar",
    "suscito": "suscitar",
    "suscitou": "suscitar",
    "suscitá": "suscitar",
    "suscitámo": "suscitar",
    "suscitámos": "suscitar",
    "suscitáramo": "suscitar",
    "suscitáramos": "suscitar",
    "suscitárei": "suscitar",
    "suscitáreis": "suscitar",
    "suscitásseis": "suscitar",
    "suscitássemos": "suscitar",
    "suscitávamo": "suscitar",
    "suscitávamos": "suscitar",
    "suscitávei": "suscitar",
    "suscitáveis": "suscitável",
    "suserana": "suserano",
    "suseranas": "suserano",
    "suseranias": "suserania",
    "suseranos": "suserano",
    "sushis": "sushi",
    "susodita": "susodito",
    "susoditas": "susodito",
    "susoditos": "susodito",
    "suspeita": "suspeito",
    "suspeitada": "suspeitar",
    "suspeitadas": "suspeitar",
    "suspeitado": "suspeitar",
    "suspeitadora": "suspeitador",
    "suspeitadoras": "suspeitador",
    "suspeitadores": "suspeitador",
    "suspeitados": "suspeitar",
    "suspeitai": "suspeitar",
    "suspeitais": "suspeitar",
    "suspeitam": "suspeitar",
    "suspeitamo": "suspeitar",
    "suspeitamos": "suspeitar",
    "suspeitando": "suspeitar",
    "suspeitara": "suspeitar",
    "suspeitaram": "suspeitar",
    "suspeitaras": "suspeitar",
    "suspeitarde": "suspeitar",
    "suspeitardes": "suspeitar",
    "suspeitare": "suspeitar",
    "suspeitarei": "suspeitar",
    "suspeitareis": "suspeitar",
    "suspeitarem": "suspeitar",
    "suspeitaremos": "suspeitar",
    "suspeitares": "suspeitar",
    "suspeitaria": "suspeitar",
    "suspeitariam": "suspeitar",
    "suspeitarias": "suspeitar",
    "suspeitarmo": "suspeitar",
    "suspeitarmos": "suspeitar",
    "suspeitará": "suspeitar",
    "suspeitarás": "suspeitar",
    "suspeitarão": "suspeitar",
    "suspeitaríamos": "suspeitar",
    "suspeitaríeis": "suspeitar",
    "suspeitas": "suspeito",
    "suspeitasse": "suspeitar",
    "suspeitassem": "suspeitar",
    "suspeitasses": "suspeitar",
    "suspeitaste": "suspeitar",
    "suspeitastes": "suspeitar",
    "suspeitava": "suspeitar",
    "suspeitavam": "suspeitar",
    "suspeitavas": "suspeitar",
    "suspeitazinha": "suspeito",
    "suspeitazinhas": "suspeito",
    "suspeitazita": "suspeito",
    "suspeitazitas": "suspeito",
    "suspeite": "suspeitar",
    "suspeitei": "suspeitar",
    "suspeiteis": "suspeitar",
    "suspeitem": "suspeitar",
    "suspeitemo": "suspeitar",
    "suspeitemos": "suspeitar",
    "suspeites": "suspeitar",
    "suspeito": "suspeitar",
    "suspeitos": "suspeito",
    "suspeitosa": "suspeitoso",
    "suspeitosas": "suspeitoso",
    "suspeitosos": "suspeitoso",
    "suspeitou": "suspeitar",
    "suspeitozinho": "suspeito",
    "suspeitozinhos": "suspeito",
    "suspeitozito": "suspeito",
    "suspeitozitos": "suspeito",
    "suspeitá": "suspeitar",
    "suspeitámo": "suspeitar",
    "suspeitámos": "suspeitar",
    "suspeitáramo": "suspeitar",
    "suspeitáramos": "suspeitar",
    "suspeitárei": "suspeitar",
    "suspeitáreis": "suspeitar",
    "suspeitásseis": "suspeitar",
    "suspeitássemos": "suspeitar",
    "suspeitávamo": "suspeitar",
    "suspeitávamos": "suspeitar",
    "suspeitávei": "suspeitar",
    "suspeitáveis": "suspeitar",
    "suspeições": "suspeição",
    "suspenda": "suspender",
    "suspendais": "suspender",
    "suspendam": "suspender",
    "suspendamo": "suspender",
    "suspendamos": "suspender",
    "suspendas": "suspender",
    "suspende": "suspender",
    "suspendei": "suspender",
    "suspendeis": "suspender",
    "suspendem": "suspender",
    "suspendemo": "suspender",
    "suspendemos": "suspender",
    "suspendendo": "suspender",
    "suspendera": "suspender",
    "suspenderam": "suspender",
    "suspenderas": "suspender",
    "suspenderde": "suspender",
    "suspenderdes": "suspender",
    "suspendere": "suspender",
    "suspenderei": "suspender",
    "suspendereis": "suspender",
    "suspenderem": "suspender",
    "suspenderemos": "suspender",
    "suspenderes": "suspender",
    "suspenderia": "suspender",
    "suspenderiam": "suspender",
    "suspenderias": "suspender",
    "suspendermo": "suspender",
    "suspendermos": "suspender",
    "suspenderá": "suspender",
    "suspenderás": "suspender",
    "suspenderão": "suspender",
    "suspenderíamos": "suspender",
    "suspenderíeis": "suspender",
    "suspendes": "suspender",
    "suspendesse": "suspender",
    "suspendessem": "suspender",
    "suspendesses": "suspender",
    "suspendeste": "suspender",
    "suspendestes": "suspender",
    "suspendeu": "suspender",
    "suspendi": "suspender",
    "suspendia": "suspender",
    "suspendiam": "suspender",
    "suspendias": "suspender",
    "suspendida": "suspendido",
    "suspendidas": "suspendido",
    "suspendido": "suspender",
    "suspendidos": "suspendido",
    "suspendo": "suspender",
    "suspendê": "suspender",
    "suspendêramo": "suspender",
    "suspendêramos": "suspender",
    "suspendêrei": "suspender",
    "suspendêreis": "suspender",
    "suspendêsseis": "suspender",
    "suspendêssemos": "suspender",
    "suspendíamo": "suspender",
    "suspendíamos": "suspender",
    "suspendíei": "suspender",
    "suspendíeis": "suspender",
    "suspensa": "suspenso",
    "suspensas": "suspenso",
    "suspenses": "suspense",
    "suspensiva": "suspensivo",
    "suspensivas": "suspensivo",
    "suspensivos": "suspensivo",
    "suspensora": "suspensor",
    "suspensoras": "suspensor",
    "suspensores": "suspensor",
    "suspensos": "suspenso",
    "suspensóides": "suspensóide",
    "suspensória": "suspensório",
    "suspensórias": "suspensório",
    "suspensórios": "suspensório",
    "suspensões": "suspensão",
    "suspicazes": "suspicaz",
    "suspicácias": "suspicácia",
    "suspira": "suspirar",
    "suspirada": "suspirar",
    "suspiradas": "suspirar",
    "suspirado": "suspirar",
    "suspiradora": "suspirador",
    "suspiradoras": "suspirador",
    "suspiradores": "suspirador",
    "suspirados": "suspirar",
    "suspirai": "suspirar",
    "suspirais": "suspirar",
    "suspiram": "suspirar",
    "suspiramo": "suspirar",
    "suspiramos": "suspirar",
    "suspirando": "suspirar",
    "suspirantes": "suspirante",
    "suspirara": "suspirar",
    "suspiraram": "suspirar",
    "suspiraras": "suspirar",
    "suspirardes": "suspirar",
    "suspirarei": "suspirar",
    "suspirareis": "suspirar",
    "suspirarem": "suspirar",
    "suspiraremos": "suspirar",
    "suspirares": "suspirar",
    "suspiraria": "suspirar",
    "suspirariam": "suspirar",
    "suspirarias": "suspirar",
    "suspirarmo": "suspirar",
    "suspirarmos": "suspirar",
    "suspirará": "suspirar",
    "suspirarás": "suspirar",
    "suspirarão": "suspirar",
    "suspiraríamos": "suspirar",
    "suspiraríeis": "suspirar",
    "suspiras": "suspirar",
    "suspirasse": "suspirar",
    "suspirassem": "suspirar",
    "suspirasses": "suspirar",
    "suspiraste": "suspirar",
    "suspirastes": "suspirar",
    "suspirava": "suspirar",
    "suspiravam": "suspirar",
    "suspiravas": "suspirar",
    "suspire": "suspirar",
    "suspirei": "suspirar",
    "suspireis": "suspirar",
    "suspirem": "suspirar",
    "suspiremo": "suspirar",
    "suspiremos": "suspirar",
    "suspires": "suspirar",
    "suspirinho": "suspiro",
    "suspirinhos": "suspiro",
    "suspirito": "suspiro",
    "suspiritos": "suspiro",
    "suspiro": "suspirar",
    "suspiros": "suspiro",
    "suspirosa": "suspiroso",
    "suspirosas": "suspiroso",
    "suspirosos": "suspiroso",
    "suspirou": "suspirar",
    "suspirozinho": "suspiro",
    "suspirozinhos": "suspiro",
    "suspirozito": "suspiro",
    "suspirozitos": "suspiro",
    "suspiráculos": "suspiráculo",
    "suspirámo": "suspirar",
    "suspirámos": "suspirar",
    "suspiráramo": "suspirar",
    "suspiráramos": "suspirar",
    "suspiráreis": "suspirar",
    "suspirásseis": "suspirar",
    "suspirássemos": "suspirar",
    "suspirávamo": "suspirar",
    "suspirávamos": "suspirar",
    "suspiráveis": "suspirar",
    "susqua": "susquir",
    "susquais": "susquir",
    "susquam": "susquir",
    "susquamo": "susquir",
    "susquamos": "susquir",
    "susquas": "susquir",
    "susque": "susquir",
    "susquem": "susquir",
    "susques": "susquir",
    "susqui": "susquir",
    "susquia": "susquir",
    "susquiam": "susquir",
    "susquias": "susquir",
    "susquida": "susquir",
    "susquidas": "susquir",
    "susquido": "susquir",
    "susquidos": "susquir",
    "susquimo": "susquir",
    "susquimos": "susquir",
    "susquindo": "susquir",
    "susquira": "susquir",
    "susquiram": "susquir",
    "susquiras": "susquir",
    "susquirde": "susquir",
    "susquirdes": "susquir",
    "susquire": "susquir",
    "susquirei": "susquir",
    "susquireis": "susquir",
    "susquirem": "susquir",
    "susquiremos": "susquir",
    "susquires": "susquir",
    "susquiria": "susquir",
    "susquiriam": "susquir",
    "susquirias": "susquir",
    "susquirmo": "susquir",
    "susquirmos": "susquir",
    "susquirá": "susquir",
    "susquirás": "susquir",
    "susquirão": "susquir",
    "susquiríamos": "susquir",
    "susquiríeis": "susquir",
    "susquis": "susquir",
    "susquisse": "susquir",
    "susquissem": "susquir",
    "susquisses": "susquir",
    "susquiste": "susquir",
    "susquistes": "susquir",
    "susquiu": "susquir",
    "susquo": "susquir",
    "susquíamo": "susquir",
    "susquíamos": "susquir",
    "susquíei": "susquir",
    "susquíeis": "susquir",
    "susquíramo": "susquir",
    "susquíramos": "susquir",
    "susquírei": "susquir",
    "susquíreis": "susquir",
    "susquísseis": "susquir",
    "susquíssemos": "susquir",
    "sussurra": "sussurrar",
    "sussurrada": "sussurrar",
    "sussurradas": "sussurrar",
    "sussurrado": "sussurrar",
    "sussurrados": "sussurrar",
    "sussurrai": "sussurrar",
    "sussurrais": "sussurrar",
    "sussurram": "sussurrar",
    "sussurramo": "sussurrar",
    "sussurramos": "sussurrar",
    "sussurrando": "sussurrar",
    "sussurrantes": "sussurrante",
    "sussurrara": "sussurrar",
    "sussurraram": "sussurrar",
    "sussurraras": "sussurrar",
    "sussurrardes": "sussurrar",
    "sussurrarei": "sussurrar",
    "sussurrareis": "sussurrar",
    "sussurrarem": "sussurrar",
    "sussurraremos": "sussurrar",
    "sussurrares": "sussurrar",
    "sussurraria": "sussurrar",
    "sussurrariam": "sussurrar",
    "sussurrarias": "sussurrar",
    "sussurrarmo": "sussurrar",
    "sussurrarmos": "sussurrar",
    "sussurrará": "sussurrar",
    "sussurrarás": "sussurrar",
    "sussurrarão": "sussurrar",
    "sussurraríamos": "sussurrar",
    "sussurraríeis": "sussurrar",
    "sussurras": "sussurrar",
    "sussurrasse": "sussurrar",
    "sussurrassem": "sussurrar",
    "sussurrasses": "sussurrar",
    "sussurraste": "sussurrar",
    "sussurrastes": "sussurrar",
    "sussurrava": "sussurrar",
    "sussurravam": "sussurrar",
    "sussurravas": "sussurrar",
    "sussurraçãos": "sussurração",
    "sussurre": "sussurrar",
    "sussurrei": "sussurrar",
    "sussurreis": "sussurrar",
    "sussurrem": "sussurrar",
    "sussurremo": "sussurrar",
    "sussurremos": "sussurrar",
    "sussurres": "sussurrar",
    "sussurro": "sussurrar",
    "sussurros": "sussurro",
    "sussurrou": "sussurrar",
    "sussurrámo": "sussurrar",
    "sussurrámos": "sussurrar",
    "sussurráramo": "sussurrar",
    "sussurráramos": "sussurrar",
    "sussurráreis": "sussurrar",
    "sussurrásseis": "sussurrar",
    "sussurrássemos": "sussurrar",
    "sussurrávamo": "sussurrar",
    "sussurrávamos": "sussurrar",
    "sussurráveis": "sussurrar",
    "susta": "sustar",
    "sustada": "sustar",
    "sustadas": "sustar",
    "sustado": "sustar",
    "sustados": "sustar",
    "sustai": "sustar",
    "sustais": "sustar",
    "sustam": "sustar",
    "sustamo": "sustar",
    "sustamos": "sustar",
    "sustando": "sustar",
    "sustara": "sustar",
    "sustaram": "sustar",
    "sustaras": "sustar",
    "sustarde": "sustar",
    "sustardes": "sustar",
    "sustare": "sustar",
    "sustarei": "sustar",
    "sustareis": "sustar",
    "sustarem": "sustar",
    "sustaremos": "sustar",
    "sustares": "sustar",
    "sustaria": "sustar",
    "sustariam": "sustar",
    "sustarias": "sustar",
    "sustarmo": "sustar",
    "sustarmos": "sustar",
    "sustará": "sustar",
    "sustarás": "sustar",
    "sustarão": "sustar",
    "sustaríamos": "sustar",
    "sustaríeis": "sustar",
    "sustas": "sustar",
    "sustasse": "sustar",
    "sustassem": "sustar",
    "sustasses": "sustar",
    "sustaste": "sustar",
    "sustastes": "sustar",
    "sustatória": "sustatório",
    "sustatórias": "sustatório",
    "sustatórios": "sustatório",
    "sustava": "sustar",
    "sustavam": "sustar",
    "sustavas": "sustar",
    "sustações": "sustação",
    "suste": "sustar",
    "sustei": "sustar",
    "susteis": "sustar",
    "sustem": "sustar",
    "sustemo": "suster",
    "sustemos": "suster",
    "sustende": "suster",
    "sustendes": "suster",
    "sustendo": "suster",
    "sustenha": "suster",
    "sustenhais": "suster",
    "sustenham": "suster",
    "sustenhamo": "suster",
    "sustenhamos": "suster",
    "sustenhas": "suster",
    "sustenho": "suster",
    "sustenida": "sustenido",
    "sustenidas": "sustenido",
    "sustenidos": "sustenido",
    "susteniza": "sustenizar",
    "sustenizada": "sustenizar",
    "sustenizadas": "sustenizar",
    "sustenizado": "sustenizar",
    "sustenizados": "sustenizar",
    "sustenizai": "sustenizar",
    "sustenizais": "sustenizar",
    "sustenizam": "sustenizar",
    "sustenizamo": "sustenizar",
    "sustenizamos": "sustenizar",
    "sustenizando": "sustenizar",
    "sustenizara": "sustenizar",
    "sustenizaram": "sustenizar",
    "sustenizaras": "sustenizar",
    "sustenizarde": "sustenizar",
    "sustenizardes": "sustenizar",
    "sustenizare": "sustenizar",
    "sustenizarei": "sustenizar",
    "sustenizareis": "sustenizar",
    "sustenizarem": "sustenizar",
    "sustenizaremos": "sustenizar",
    "sustenizares": "sustenizar",
    "sustenizaria": "sustenizar",
    "sustenizariam": "sustenizar",
    "sustenizarias": "sustenizar",
    "sustenizarmo": "sustenizar",
    "sustenizarmos": "sustenizar",
    "sustenizará": "sustenizar",
    "sustenizarás": "sustenizar",
    "sustenizarão": "sustenizar",
    "sustenizaríamos": "sustenizar",
    "sustenizaríeis": "sustenizar",
    "sustenizas": "sustenizar",
    "sustenizasse": "sustenizar",
    "sustenizassem": "sustenizar",
    "sustenizasses": "sustenizar",
    "sustenizaste": "sustenizar",
    "sustenizastes": "sustenizar",
    "sustenizava": "sustenizar",
    "sustenizavam": "sustenizar",
    "sustenizavas": "sustenizar",
    "sustenize": "sustenizar",
    "sustenizei": "sustenizar",
    "sustenizeis": "sustenizar",
    "sustenizem": "sustenizar",
    "sustenizemo": "sustenizar",
    "sustenizemos": "sustenizar",
    "sustenizes": "sustenizar",
    "sustenizo": "sustenizar",
    "sustenizou": "sustenizar",
    "sustenizá": "sustenizar",
    "sustenizámo": "sustenizar",
    "sustenizámos": "sustenizar",
    "sustenizáramo": "sustenizar",
    "sustenizáramos": "sustenizar",
    "sustenizárei": "sustenizar",
    "sustenizáreis": "sustenizar",
    "sustenizásseis": "sustenizar",
    "sustenizássemos": "sustenizar",
    "sustenizávamo": "sustenizar",
    "sustenizávamos": "sustenizar",
    "sustenizávei": "sustenizar",
    "sustenizáveis": "sustenizar",
    "sustenta": "sustentar",
    "sustentabilidades": "sustentabilidade",
    "sustentada": "sustentar",
    "sustentadas": "sustentar",
    "sustentado": "sustentar",
    "sustentadora": "sustentador",
    "sustentadoras": "sustentador",
    "sustentadores": "sustentador",
    "sustentados": "sustentar",
    "sustentai": "sustentar",
    "sustentais": "sustentar",
    "sustentam": "sustentar",
    "sustentamentos": "sustentamento",
    "sustentamo": "sustentar",
    "sustentamos": "sustentar",
    "sustentando": "sustentar",
    "sustentantes": "sustentante",
    "sustentara": "sustentar",
    "sustentaram": "sustentar",
    "sustentaras": "sustentar",
    "sustentarde": "sustentar",
    "sustentardes": "sustentar",
    "sustentare": "sustentar",
    "sustentarei": "sustentar",
    "sustentareis": "sustentar",
    "sustentarem": "sustentar",
    "sustentaremos": "sustentar",
    "sustentares": "sustentar",
    "sustentaria": "sustentar",
    "sustentariam": "sustentar",
    "sustentarias": "sustentar",
    "sustentarmo": "sustentar",
    "sustentarmos": "sustentar",
    "sustentará": "sustentar",
    "sustentarás": "sustentar",
    "sustentarão": "sustentar",
    "sustentaríamos": "sustentar",
    "sustentaríeis": "sustentar",
    "sustentas": "sustentar",
    "sustentasse": "sustentar",
    "sustentassem": "sustentar",
    "sustentasses": "sustentar",
    "sustentaste": "sustentar",
    "sustentastes": "sustentar",
    "sustentava": "sustentar",
    "sustentavam": "sustentar",
    "sustentavas": "sustentar",
    "sustentações": "sustentação",
    "sustente": "sustentar",
    "sustentei": "sustentar",
    "sustenteis": "sustentar",
    "sustentem": "sustentar",
    "sustentemo": "sustentar",
    "sustentemos": "sustentar",
    "sustentes": "sustentar",
    "sustento": "sustentar",
    "sustentos": "sustento",
    "sustentou": "sustentar",
    "sustentá": "sustentar",
    "sustentáculos": "sustentáculo",
    "sustentámo": "sustentar",
    "sustentámos": "sustentar",
    "sustentáramo": "sustentar",
    "sustentáramos": "sustentar",
    "sustentárei": "sustentar",
    "sustentáreis": "sustentar",
    "sustentásseis": "sustentar",
    "sustentássemos": "sustentar",
    "sustentávamo": "sustentar",
    "sustentávamos": "sustentar",
    "sustentávei": "sustentar",
    "sustentáveis": "sustentável",
    "susterde": "suster",
    "susterdes": "suster",
    "sustere": "suster",
    "susterei": "suster",
    "sustereis": "suster",
    "susterem": "suster",
    "susteremos": "suster",
    "susteres": "suster",
    "susteria": "suster",
    "susteriam": "suster",
    "susterias": "suster",
    "sustermo": "suster",
    "sustermos": "suster",
    "susterá": "suster",
    "susterás": "suster",
    "susterão": "suster",
    "susteríamos": "suster",
    "susteríeis": "suster",
    "sustes": "sustar",
    "susteve": "suster",
    "sustida": "sustido",
    "sustidas": "sustido",
    "sustido": "suster",
    "sustidos": "sustido",
    "sustimentos": "sustimento",
    "sustinha": "suster",
    "sustinham": "suster",
    "sustinhas": "suster",
    "sustive": "suster",
    "sustivemo": "suster",
    "sustivemos": "suster",
    "sustiver": "suster",
    "sustivera": "suster",
    "sustiveram": "suster",
    "sustiveras": "suster",
    "sustiverdes": "suster",
    "sustiverem": "suster",
    "sustiveres": "suster",
    "sustivermos": "suster",
    "sustivesse": "suster",
    "sustivessem": "suster",
    "sustivesses": "suster",
    "sustiveste": "suster",
    "sustivestes": "suster",
    "sustivéramo": "suster",
    "sustivéramos": "suster",
    "sustivérei": "suster",
    "sustivéreis": "suster",
    "sustivésseis": "suster",
    "sustivéssemos": "suster",
    "susto": "sustar",
    "sustos": "susto",
    "sustou": "sustar",
    "sustá": "sustar",
    "sustámo": "sustar",
    "sustámos": "sustar",
    "sustáramo": "sustar",
    "sustáramos": "sustar",
    "sustárei": "sustar",
    "sustáreis": "sustar",
    "sustásseis": "sustar",
    "sustássemos": "sustar",
    "sustávamo": "sustar",
    "sustávamos": "sustar",
    "sustávei": "sustar",
    "sustáveis": "sustar",
    "sustâncias": "sustância",
    "sustém": "suster",
    "susténs": "suster",
    "sustê": "suster",
    "sustêm": "suster",
    "sustínhamo": "suster",
    "sustínhamos": "suster",
    "sustínhei": "suster",
    "sustínheis": "suster",
    "susunus": "susunu",
    "suta": "sutar",
    "sutaches": "sutache",
    "sutada": "sutar",
    "sutadas": "sutar",
    "sutado": "sutar",
    "sutados": "sutar",
    "sutai": "sutar",
    "sutais": "sutar",
    "sutam": "sutar",
    "sutamo": "sutar",
    "sutamos": "sutar",
    "sutando": "sutar",
    "sutara": "sutar",
    "sutaram": "sutar",
    "sutaras": "sutar",
    "sutarde": "sutar",
    "sutardes": "sutar",
    "sutare": "sutar",
    "sutarei": "sutar",
    "sutareis": "sutar",
    "sutarem": "sutar",
    "sutaremos": "sutar",
    "sutares": "sutar",
    "sutaria": "sutar",
    "sutariam": "sutar",
    "sutarias": "sutar",
    "sutarmo": "sutar",
    "sutarmos": "sutar",
    "sutará": "sutar",
    "sutarás": "sutar",
    "sutarão": "sutar",
    "sutaríamos": "sutar",
    "sutaríeis": "sutar",
    "sutas": "sutar",
    "sutasse": "sutar",
    "sutassem": "sutar",
    "sutasses": "sutar",
    "sutaste": "sutar",
    "sutastes": "sutar",
    "sutava": "sutar",
    "sutavam": "sutar",
    "sutavas": "sutar",
    "sute": "sutar",
    "sutei": "sutar",
    "suteis": "sutar",
    "sutem": "sutar",
    "sutemo": "sutar",
    "sutemos": "sutar",
    "sutes": "sutar",
    "sutis": "sutil",
    "sutiãs": "sutiã",
    "suto": "sutar",
    "sutou": "sutar",
    "sutras": "sutra",
    "sutura": "suturar",
    "suturada": "suturar",
    "suturadas": "suturar",
    "suturado": "suturar",
    "suturados": "suturar",
    "suturai": "suturar",
    "suturais": "suturar",
    "suturam": "suturar",
    "suturamo": "suturar",
    "suturamos": "suturar",
    "suturando": "suturar",
    "suturara": "suturar",
    "suturaram": "suturar",
    "suturaras": "suturar",
    "suturarde": "suturar",
    "suturardes": "suturar",
    "suturare": "suturar",
    "suturarei": "suturar",
    "suturareis": "suturar",
    "suturarem": "suturar",
    "suturaremos": "suturar",
    "suturares": "suturar",
    "suturaria": "suturar",
    "suturariam": "suturar",
    "suturarias": "suturar",
    "suturarmo": "suturar",
    "suturarmos": "suturar",
    "suturará": "suturar",
    "suturarás": "suturar",
    "suturarão": "suturar",
    "suturaríamos": "suturar",
    "suturaríeis": "suturar",
    "suturas": "suturar",
    "suturasse": "suturar",
    "suturassem": "suturar",
    "suturasses": "suturar",
    "suturaste": "suturar",
    "suturastes": "suturar",
    "suturava": "suturar",
    "suturavam": "suturar",
    "suturavas": "suturar",
    "suture": "suturar",
    "suturei": "suturar",
    "sutureis": "suturar",
    "suturem": "suturar",
    "suturemo": "suturar",
    "suturemos": "suturar",
    "sutures": "suturar",
    "suturo": "suturar",
    "suturou": "suturar",
    "suturá": "suturar",
    "suturámo": "suturar",
    "suturámos": "suturar",
    "suturáramo": "suturar",
    "suturáramos": "suturar",
    "suturárei": "suturar",
    "suturáreis": "suturar",
    "suturásseis": "suturar",
    "suturássemos": "suturar",
    "suturávamo": "suturar",
    "suturávamos": "suturar",
    "suturávei": "suturar",
    "suturáveis": "suturar",
    "sutá": "sutar",
    "sutámo": "sutar",
    "sutámos": "sutar",
    "sutáramo": "sutar",
    "sutáramos": "sutar",
    "sutárei": "sutar",
    "sutáreis": "sutar",
    "sutásseis": "sutar",
    "sutássemos": "sutar",
    "sutávamo": "sutar",
    "sutávamos": "sutar",
    "sutávei": "sutar",
    "sutáveis": "sutar",
    "suvenirs": "suvenir",
    "suvinos": "suvino",
    "suvões": "suvão",
    "suxa": "suxar",
    "suxada": "suxar",
    "suxadas": "suxar",
    "suxado": "suxar",
    "suxados": "suxar",
    "suxai": "suxar",
    "suxais": "suxar",
    "suxam": "suxar",
    "suxamo": "suxar",
    "suxamos": "suxar",
    "suxando": "suxar",
    "suxara": "suxar",
    "suxaram": "suxar",
    "suxaras": "suxar",
    "suxarde": "suxar",
    "suxardes": "suxar",
    "suxare": "suxar",
    "suxarei": "suxar",
    "suxareis": "suxar",
    "suxarem": "suxar",
    "suxaremos": "suxar",
    "suxares": "suxar",
    "suxaria": "suxar",
    "suxariam": "suxar",
    "suxarias": "suxar",
    "suxarmo": "suxar",
    "suxarmos": "suxar",
    "suxará": "suxar",
    "suxarás": "suxar",
    "suxarão": "suxar",
    "suxaríamos": "suxar",
    "suxaríeis": "suxar",
    "suxas": "suxar",
    "suxasse": "suxar",
    "suxassem": "suxar",
    "suxasses": "suxar",
    "suxaste": "suxar",
    "suxastes": "suxar",
    "suxava": "suxar",
    "suxavam": "suxar",
    "suxavas": "suxar",
    "suxe": "suxar",
    "suxei": "suxar",
    "suxeis": "suxar",
    "suxem": "suxar",
    "suxemo": "suxar",
    "suxemos": "suxar",
    "suxes": "suxar",
    "suxo": "suxar",
    "suxou": "suxar",
    "suxá": "suxar",
    "suxámo": "suxar",
    "suxámos": "suxar",
    "suxáramo": "suxar",
    "suxáramos": "suxar",
    "suxárei": "suxar",
    "suxáreis": "suxar",
    "suxásseis": "suxar",
    "suxássemos": "suxar",
    "suxávamo": "suxar",
    "suxávamos": "suxar",
    "suxávei": "suxar",
    "suxáveis": "suxar",
    "suámo": "suar",
    "suámos": "suar",
    "suáramo": "suar",
    "suáramos": "suar",
    "suáreis": "suar",
    "suásseis": "suar",
    "suássemos": "suar",
    "suástica": "suástico",
    "suásticas": "suástico",
    "suásticos": "suástico",
    "suávamo": "suar",
    "suávamos": "suar",
    "suáveis": "suar",
    "suã": "suão",
    "suãos": "suão",
    "suãs": "suão",
    "suçuaparas": "suçuapara",
    "suécia": "suécio",
    "suécias": "suécio",
    "suécios": "suécio",
    "suéters": "suéter",
    "suídeos": "suídeo",
    "suína": "suíno",
    "suínas": "suíno",
    "suínos": "suíno",
    "suíça": "suíço",
    "suíças": "suíço",
    "suíços": "suíço",
    "suões": "suão",
    "swinga": "swingar",
    "swingada": "swingar",
    "swingadas": "swingar",
    "swingado": "swingar",
    "swingados": "swingar",
    "swingai": "swingar",
    "swingais": "swingar",
    "swingam": "swingar",
    "swingamo": "swingar",
    "swingamos": "swingar",
    "swingando": "swingar",
    "swingara": "swingar",
    "swingaram": "swingar",
    "swingaras": "swingar",
    "swingarde": "swingar",
    "swingardes": "swingar",
    "swingare": "swingar",
    "swingarei": "swingar",
    "swingareis": "swingar",
    "swingarem": "swingar",
    "swingaremos": "swingar",
    "swingares": "swingar",
    "swingaria": "swingar",
    "swingariam": "swingar",
    "swingarias": "swingar",
    "swingarmo": "swingar",
    "swingarmos": "swingar",
    "swingará": "swingar",
    "swingarás": "swingar",
    "swingarão": "swingar",
    "swingaríamos": "swingar",
    "swingaríeis": "swingar",
    "swingas": "swingar",
    "swingasse": "swingar",
    "swingassem": "swingar",
    "swingasses": "swingar",
    "swingaste": "swingar",
    "swingastes": "swingar",
    "swingava": "swingar",
    "swingavam": "swingar",
    "swingavas": "swingar",
    "swingo": "swingar",
    "swingou": "swingar",
    "swings": "swing",
    "swingue": "swingar",
    "swinguei": "swingar",
    "swingueis": "swingar",
    "swinguem": "swingar",
    "swinguemo": "swingar",
    "swinguemos": "swingar",
    "swingues": "swingar",
    "swingá": "swingar",
    "swingámo": "swingar",
    "swingámos": "swingar",
    "swingáramo": "swingar",
    "swingáramos": "swingar",
    "swingárei": "swingar",
    "swingáreis": "swingar",
    "swingásseis": "swingar",
    "swingássemos": "swingar",
    "swingávamo": "swingar",
    "swingávamos": "swingar",
    "swingávei": "swingar",
    "swingáveis": "swingar",
    "sábados": "sábado",
    "sábia": "sábio",
    "sábias": "sábio",
    "sábios": "sábio",
    "sáculos": "sáculo",
    "sádica": "sádico",
    "sádicas": "sádico",
    "sádicos": "sádico",
    "sáfara": "sáfaro",
    "sáfaras": "sáfaro",
    "sáfaros": "sáfaro",
    "sáfia": "sáfio",
    "sáfias": "sáfio",
    "sáfica": "sáfico",
    "sáficas": "sáfico",
    "sáficos": "sáfico",
    "sáfios": "sáfio",
    "sália": "sálio",
    "sálias": "sálio",
    "sálica": "sálico",
    "sálicas": "sálico",
    "sálicos": "sálico",
    "sálios": "sálio",
    "sálmica": "sálmico",
    "sálmicas": "sálmico",
    "sálmicos": "sálmico",
    "sálpidas": "sálpida",
    "sáltrias": "sáltria",
    "sálvias": "sálvia",
    "sápias": "sápia",
    "sápida": "sápido",
    "sápidas": "sápido",
    "sápidos": "sápido",
    "sárdios": "sárdio",
    "sárica": "sárico",
    "sáricas": "sárico",
    "sáricos": "sárico",
    "sáris": "sári",
    "sármatas": "sármata",
    "sátiras": "sátira",
    "sátiros": "sátiro",
    "sátrapas": "sátrapa",
    "sáturas": "sátura",
    "sáuria": "sáurio",
    "sáurias": "sáurio",
    "sáurios": "sáurio",
    "sáveis": "sável",
    "sáxea": "sáxeo",
    "sáxeas": "sáxeo",
    "sáxeos": "sáxeo",
    "sâmagos": "sâmago",
    "sâmaras": "sâmara",
    "sâmia": "sâmio",
    "sâmias": "sâmio",
    "sâmios": "sâmio",
    "sândalos": "sândalo",
    "sânies": "sânie",
    "sânquias": "sânquia",
    "sânscritos": "sânscrito",
    "sã": "são",
    "são": "ser",
    "sãos": "são",
    "sãozinho": "são",
    "sãozinhos": "são",
    "sãozito": "são",
    "sãozitos": "são",
    "sãs": "são",
    "sãzinha": "são",
    "sãzinhas": "são",
    "sãzita": "são",
    "sãzitas": "são",
    "sécia": "sécio",
    "sécias": "sécio",
    "sécios": "sécio",
    "séctiis": "séctil",
    "séculos": "século",
    "sédula": "sédulo",
    "sédulas": "sédulo",
    "sédulos": "sédulo",
    "sémens": "sémen",
    "sémitas": "sémita",
    "sénecas": "séneca",
    "sénicas": "sénica",
    "sénios": "sénio",
    "sépalas": "sépala",
    "sépias": "sépia",
    "séptica": "séptico",
    "sépticas": "séptico",
    "sépticos": "séptico",
    "séptis": "séptil",
    "séptuores": "séptuor",
    "séptupla": "séptuplo",
    "séquana": "séquano",
    "séquanas": "séquano",
    "séquanos": "séquano",
    "séquitos": "séquito",
    "séria": "sério",
    "sérias": "sério",
    "sérica": "sérico",
    "séricas": "sérico",
    "séricos": "sérico",
    "séries": "série",
    "sérios": "sério",
    "sérrea": "sérreo",
    "sérreas": "sérreo",
    "sérreos": "sérreo",
    "séruns": "sérum",
    "sérvia": "sérvio",
    "sérvias": "sérvio",
    "sérvios": "sérvio",
    "sés": "sé",
    "sésamos": "sésamo",
    "séssis": "séssil",
    "sétima": "sétimo",
    "sétimas": "sétimo",
    "sétimos": "sétimo",
    "séviros": "séviro",
    "sê": "ser",
    "sêmeas": "sêmea",
    "sêmolas": "sêmola",
    "sênsis": "sênsil",
    "sês": "sê",
    "sêxtupla": "sêxtuplo",
    "sêxtuplos": "sêxtuplo",
    "síbilos": "síbilo",
    "síbinas": "síbina",
    "síceras": "sícera",
    "sícones": "sícone",
    "sícula": "sículo",
    "sículas": "sículo",
    "sículos": "sículo",
    "sífiliss": "sífilis",
    "sílabas": "sílaba",
    "sílabos": "sílabo",
    "sílexes": "sílex",
    "sílfides": "sílfide",
    "sílicas": "sílica",
    "sílices": "sílice",
    "síliquas": "síliqua",
    "símbolos": "símbolo",
    "símia": "símio",
    "símias": "símio",
    "símile": "símil",
    "símiles": "símile",
    "símios": "símio",
    "símis": "símil",
    "símplices": "símplice",
    "símploces": "símploce",
    "sínciputes": "sínciput",
    "sínclises": "sínclise",
    "síncopas": "síncopa",
    "síncopes": "síncope",
    "síncrises": "síncrise",
    "síncrona": "síncrono",
    "síncronas": "síncrono",
    "síncronos": "síncrono",
    "síndeses": "síndese",
    "síndetons": "síndeton",
    "síndetos": "síndeto",
    "síndicos": "síndico",
    "síndromas": "síndroma",
    "síndromes": "síndrome",
    "síndromos": "síndromo",
    "síneses": "sínese",
    "sínfilos": "sínfilo",
    "sínfises": "sínfise",
    "sínfitos": "sínfito",
    "síngrafos": "síngrafo",
    "sínica": "sínico",
    "sínicas": "sínico",
    "sínicos": "sínico",
    "sínodos": "sínodo",
    "sínquises": "sínquise",
    "sínteses": "síntese",
    "síntipos": "síntipo",
    "síria": "sírio",
    "sírias": "sírio",
    "sírios": "sírio",
    "sísmica": "sísmico",
    "sísmicas": "sísmico",
    "sísmicos": "sísmico",
    "sístoles": "sístole",
    "sítios": "sítio",
    "sítulas": "sítula",
    "sóboles": "sóbole",
    "sóbria": "sóbrio",
    "sóbrias": "sóbrio",
    "sóbrios": "sóbrio",
    "sócia": "sócio",
    "sócias": "sócio",
    "sócios": "sócio",
    "sódica": "sódico",
    "sódicas": "sódico",
    "sódicos": "sódico",
    "sódios": "sódio",
    "sói": "soer",
    "sóis": "sol",
    "sólida": "sólido",
    "sólidas": "sólido",
    "sólidos": "sólido",
    "sólios": "sólio",
    "sólita": "sólito",
    "sólitas": "sólito",
    "sólitos": "sólito",
    "sónica": "sónico",
    "sónicas": "sónico",
    "sónicos": "sónico",
    "sóracos": "sóraco",
    "sórdida": "sórdido",
    "sórdidas": "sórdido",
    "sórdidos": "sórdido",
    "sórors": "sóror",
    "sós": "só",
    "sósias": "sósia",
    "sótãos": "sótão",
    "sôfrega": "sôfrego",
    "sôfregas": "sôfrego",
    "sôfregos": "sôfrego",
    "sôs": "sô",
    "súbdita": "súbdito",
    "súbditas": "súbdito",
    "súbditos": "súbdito",
    "súberes": "súber",
    "súbita": "súbito",
    "súbitas": "súbito",
    "súbitos": "súbito",
    "súccinos": "súccino",
    "súcia": "súcio",
    "súcias": "súcio",
    "súcios": "súcio",
    "súcuba": "súcubo",
    "súcubas": "súcubo",
    "súcubos": "súcubo",
    "súidas": "súida",
    "súlfurs": "súlfur",
    "súlidas": "súlida",
    "súmulas": "súmula",
    "súpera": "súpero",
    "súperas": "súpero",
    "súperos": "súpero",
    "súpetos": "súpeto",
    "súpita": "súpito",
    "súpitas": "súpito",
    "súpitos": "súpito",
    "súplicas": "súplica",
    "súplices": "súplice",
    "súrculos": "súrculo",
    "súsina": "súsino",
    "súsinas": "súsino",
    "súsinos": "súsino",
    "sútis": "sútil",
    "tabacais": "tabacal",
    "tabacarias": "tabacaria",
    "tabacina": "tabacino",
    "tabacinas": "tabacino",
    "tabacinos": "tabacino",
    "tabacos": "tabaco",
    "tabafeias": "tabafeia",
    "tabafeiras": "tabafeira",
    "tabagismos": "tabagismo",
    "tabagistas": "tabagista",
    "tabajaras": "tabajara",
    "tabancas": "tabanca",
    "tabangas": "tabanga",
    "tabanídeos": "tabanídeo",
    "tabaqueada": "tabaquear",
    "tabaqueadas": "tabaquear",
    "tabaqueado": "tabaquear",
    "tabaqueados": "tabaquear",
    "tabaqueai": "tabaquear",
    "tabaqueais": "tabaquear",
    "tabaqueamo": "tabaquear",
    "tabaqueamos": "tabaquear",
    "tabaqueando": "tabaquear",
    "tabaqueara": "tabaquear",
    "tabaquearam": "tabaquear",
    "tabaquearas": "tabaquear",
    "tabaquearde": "tabaquear",
    "tabaqueardes": "tabaquear",
    "tabaqueare": "tabaquear",
    "tabaquearei": "tabaquear",
    "tabaqueareis": "tabaquear",
    "tabaquearem": "tabaquear",
    "tabaquearemos": "tabaquear",
    "tabaqueares": "tabaquear",
    "tabaquearia": "tabaquear",
    "tabaqueariam": "tabaquear",
    "tabaquearias": "tabaquear",
    "tabaquearmo": "tabaquear",
    "tabaquearmos": "tabaquear",
    "tabaqueará": "tabaquear",
    "tabaquearás": "tabaquear",
    "tabaquearão": "tabaquear",
    "tabaquearíamos": "tabaquear",
    "tabaquearíeis": "tabaquear",
    "tabaqueasse": "tabaquear",
    "tabaqueassem": "tabaquear",
    "tabaqueasses": "tabaquear",
    "tabaqueaste": "tabaquear",
    "tabaqueastes": "tabaquear",
    "tabaqueava": "tabaquear",
    "tabaqueavam": "tabaquear",
    "tabaqueavas": "tabaquear",
    "tabaqueaveis": "tabaqueavel",
    "tabaqueei": "tabaquear",
    "tabaqueeis": "tabaquear",
    "tabaqueemo": "tabaquear",
    "tabaqueemos": "tabaquear",
    "tabaqueia": "tabaquear",
    "tabaqueiam": "tabaquear",
    "tabaqueias": "tabaquear",
    "tabaqueie": "tabaquear",
    "tabaqueiem": "tabaquear",
    "tabaqueies": "tabaquear",
    "tabaqueio": "tabaquear",
    "tabaqueira": "tabaqueiro",
    "tabaqueiras": "tabaqueiro",
    "tabaqueiros": "tabaqueiro",
    "tabaqueou": "tabaquear",
    "tabaques": "tabaque",
    "tabaqueá": "tabaquear",
    "tabaqueámo": "tabaquear",
    "tabaqueámos": "tabaquear",
    "tabaqueáramo": "tabaquear",
    "tabaqueáramos": "tabaquear",
    "tabaqueárei": "tabaquear",
    "tabaqueáreis": "tabaquear",
    "tabaqueásseis": "tabaquear",
    "tabaqueássemos": "tabaquear",
    "tabaqueávamo": "tabaquear",
    "tabaqueávamos": "tabaquear",
    "tabaqueávei": "tabaquear",
    "tabaqueáveis": "tabaquear",
    "tabaquistas": "tabaquista",
    "tabardilhas": "tabardilha",
    "tabardilhos": "tabardilho",
    "tabaréus": "tabaréu",
    "tabas": "taba",
    "tabascos": "tabasco",
    "tabatingas": "tabatinga",
    "tabefes": "tabefe",
    "tabela": "tabelar",
    "tabelada": "tabelar",
    "tabeladas": "tabelar",
    "tabelado": "tabelar",
    "tabelados": "tabelar",
    "tabelai": "tabelar",
    "tabelais": "tabelar",
    "tabelam": "tabelar",
    "tabelamentos": "tabelamento",
    "tabelamo": "tabelar",
    "tabelamos": "tabelar",
    "tabelando": "tabelar",
    "tabelara": "tabelar",
    "tabelaram": "tabelar",
    "tabelaras": "tabelar",
    "tabelarde": "tabelar",
    "tabelardes": "tabelar",
    "tabelare": "tabelar",
    "tabelarei": "tabelar",
    "tabelareis": "tabelar",
    "tabelarem": "tabelar",
    "tabelaremos": "tabelar",
    "tabelares": "tabelar",
    "tabelaria": "tabelar",
    "tabelariam": "tabelar",
    "tabelarias": "tabelar",
    "tabelarmo": "tabelar",
    "tabelarmos": "tabelar",
    "tabelará": "tabelar",
    "tabelarás": "tabelar",
    "tabelarão": "tabelar",
    "tabelaríamos": "tabelar",
    "tabelaríeis": "tabelar",
    "tabelas": "tabelar",
    "tabelasse": "tabelar",
    "tabelassem": "tabelar",
    "tabelasses": "tabelar",
    "tabelaste": "tabelar",
    "tabelastes": "tabelar",
    "tabelava": "tabelar",
    "tabelavam": "tabelar",
    "tabelavas": "tabelar",
    "tabelazinha": "tabela",
    "tabelazinhas": "tabela",
    "tabelazita": "tabela",
    "tabelazitas": "tabela",
    "tabele": "tabelar",
    "tabelei": "tabelar",
    "tabeleis": "tabelar",
    "tabelem": "tabelar",
    "tabelemo": "tabelar",
    "tabelemos": "tabelar",
    "tabeles": "tabelar",
    "tabelia": "tabeliar",
    "tabeliada": "tabeliar",
    "tabeliadas": "tabeliar",
    "tabeliado": "tabeliar",
    "tabeliados": "tabeliar",
    "tabeliai": "tabeliar",
    "tabeliais": "tabeliar",
    "tabeliam": "tabeliar",
    "tabeliamo": "tabeliar",
    "tabeliamos": "tabeliar",
    "tabeliando": "tabeliar",
    "tabeliara": "tabeliar",
    "tabeliaram": "tabeliar",
    "tabeliaras": "tabeliar",
    "tabeliardes": "tabeliar",
    "tabeliarei": "tabeliar",
    "tabeliareis": "tabeliar",
    "tabeliarem": "tabeliar",
    "tabeliaremos": "tabeliar",
    "tabeliares": "tabeliar",
    "tabeliaria": "tabeliar",
    "tabeliariam": "tabeliar",
    "tabeliarias": "tabeliar",
    "tabeliarmo": "tabeliar",
    "tabeliarmos": "tabeliar",
    "tabeliará": "tabeliar",
    "tabeliarás": "tabeliar",
    "tabeliarão": "tabeliar",
    "tabeliaríamos": "tabeliar",
    "tabeliaríeis": "tabeliar",
    "tabelias": "tabeliar",
    "tabeliasse": "tabeliar",
    "tabeliassem": "tabeliar",
    "tabeliasses": "tabeliar",
    "tabeliaste": "tabeliar",
    "tabeliastes": "tabeliar",
    "tabeliava": "tabeliar",
    "tabeliavam": "tabeliar",
    "tabeliavas": "tabeliar",
    "tabelie": "tabeliar",
    "tabeliei": "tabeliar",
    "tabelieis": "tabeliar",
    "tabeliem": "tabeliar",
    "tabeliemo": "tabeliar",
    "tabeliemos": "tabeliar",
    "tabelies": "tabeliar",
    "tabelinha": "tabela",
    "tabelinhas": "tabela",
    "tabelio": "tabeliar",
    "tabelioas": "tabelioa",
    "tabelionados": "tabelionado",
    "tabelionatos": "tabelionato",
    "tabeliou": "tabeliar",
    "tabelita": "tabela",
    "tabelitas": "tabela",
    "tabeliámo": "tabeliar",
    "tabeliámos": "tabeliar",
    "tabeliáramo": "tabeliar",
    "tabeliáramos": "tabeliar",
    "tabeliáreis": "tabeliar",
    "tabeliásseis": "tabeliar",
    "tabeliássemos": "tabeliar",
    "tabeliávamo": "tabeliar",
    "tabeliávamos": "tabeliar",
    "tabeliáveis": "tabeliar",
    "tabeliã": "tabelião",
    "tabeliãos": "tabelião",
    "tabeliãs": "tabelião",
    "tabelo": "tabelar",
    "tabelou": "tabelar",
    "tabelá": "tabelar",
    "tabelámo": "tabelar",
    "tabelámos": "tabelar",
    "tabeláramo": "tabelar",
    "tabeláramos": "tabelar",
    "tabelárei": "tabelar",
    "tabeláreis": "tabelar",
    "tabelásseis": "tabelar",
    "tabelássemos": "tabelar",
    "tabelávamo": "tabelar",
    "tabelávamos": "tabelar",
    "tabelávei": "tabelar",
    "tabeláveis": "tabelável",
    "tabernais": "tabernal",
    "tabernaques": "tabernaque",
    "tabernas": "taberna",
    "taberneira": "taberneiro",
    "taberneiras": "taberneiro",
    "taberneiros": "taberneiro",
    "taberninha": "taberna",
    "taberninhas": "taberna",
    "tabernita": "taberna",
    "tabernitas": "taberna",
    "tabernáculos": "tabernáculo",
    "tabernária": "tabernário",
    "tabernárias": "tabernário",
    "tabernários": "tabernário",
    "tabernórias": "tabernória",
    "tabes": "tabe",
    "tabescentes": "tabescente",
    "tabescências": "tabescência",
    "tabica": "tabicar",
    "tabicada": "tabicar",
    "tabicadas": "tabicar",
    "tabicado": "tabicar",
    "tabicados": "tabicar",
    "tabicai": "tabicar",
    "tabicais": "tabicar",
    "tabicam": "tabicar",
    "tabicamo": "tabicar",
    "tabicamos": "tabicar",
    "tabicando": "tabicar",
    "tabicara": "tabicar",
    "tabicaram": "tabicar",
    "tabicaras": "tabicar",
    "tabicarde": "tabicar",
    "tabicardes": "tabicar",
    "tabicare": "tabicar",
    "tabicarei": "tabicar",
    "tabicareis": "tabicar",
    "tabicarem": "tabicar",
    "tabicaremos": "tabicar",
    "tabicares": "tabicar",
    "tabicaria": "tabicar",
    "tabicariam": "tabicar",
    "tabicarias": "tabicar",
    "tabicarmo": "tabicar",
    "tabicarmos": "tabicar",
    "tabicará": "tabicar",
    "tabicarás": "tabicar",
    "tabicarão": "tabicar",
    "tabicaríamos": "tabicar",
    "tabicaríeis": "tabicar",
    "tabicas": "tabicar",
    "tabicasse": "tabicar",
    "tabicassem": "tabicar",
    "tabicasses": "tabicar",
    "tabicaste": "tabicar",
    "tabicastes": "tabicar",
    "tabicava": "tabicar",
    "tabicavam": "tabicar",
    "tabicavas": "tabicar",
    "tabico": "tabicar",
    "tabicou": "tabicar",
    "tabicá": "tabicar",
    "tabicámo": "tabicar",
    "tabicámos": "tabicar",
    "tabicáramo": "tabicar",
    "tabicáramos": "tabicar",
    "tabicárei": "tabicar",
    "tabicáreis": "tabicar",
    "tabicásseis": "tabicar",
    "tabicássemos": "tabicar",
    "tabicávamo": "tabicar",
    "tabicávamos": "tabicar",
    "tabicávei": "tabicar",
    "tabicáveis": "tabicável",
    "tabidezes": "tabidez",
    "tabique": "tabicar",
    "tabiquei": "tabicar",
    "tabiqueis": "tabicar",
    "tabiquem": "tabicar",
    "tabiquemo": "tabicar",
    "tabiquemos": "tabicar",
    "tabiques": "tabique",
    "tabis": "tabi",
    "tabiza": "tabizar",
    "tabizada": "tabizar",
    "tabizadas": "tabizar",
    "tabizado": "tabizar",
    "tabizados": "tabizar",
    "tabizai": "tabizar",
    "tabizais": "tabizar",
    "tabizam": "tabizar",
    "tabizamo": "tabizar",
    "tabizamos": "tabizar",
    "tabizando": "tabizar",
    "tabizara": "tabizar",
    "tabizaram": "tabizar",
    "tabizaras": "tabizar",
    "tabizarde": "tabizar",
    "tabizardes": "tabizar",
    "tabizare": "tabizar",
    "tabizarei": "tabizar",
    "tabizareis": "tabizar",
    "tabizarem": "tabizar",
    "tabizaremos": "tabizar",
    "tabizares": "tabizar",
    "tabizaria": "tabizar",
    "tabizariam": "tabizar",
    "tabizarias": "tabizar",
    "tabizarmo": "tabizar",
    "tabizarmos": "tabizar",
    "tabizará": "tabizar",
    "tabizarás": "tabizar",
    "tabizarão": "tabizar",
    "tabizaríamos": "tabizar",
    "tabizaríeis": "tabizar",
    "tabizas": "tabizar",
    "tabizasse": "tabizar",
    "tabizassem": "tabizar",
    "tabizasses": "tabizar",
    "tabizaste": "tabizar",
    "tabizastes": "tabizar",
    "tabizava": "tabizar",
    "tabizavam": "tabizar",
    "tabizavas": "tabizar",
    "tabize": "tabizar",
    "tabizei": "tabizar",
    "tabizeis": "tabizar",
    "tabizem": "tabizar",
    "tabizemo": "tabizar",
    "tabizemos": "tabizar",
    "tabizes": "tabizar",
    "tabizo": "tabizar",
    "tabizou": "tabizar",
    "tabizá": "tabizar",
    "tabizámo": "tabizar",
    "tabizámos": "tabizar",
    "tabizáramo": "tabizar",
    "tabizáramos": "tabizar",
    "tabizárei": "tabizar",
    "tabizáreis": "tabizar",
    "tabizásseis": "tabizar",
    "tabizássemos": "tabizar",
    "tabizávamo": "tabizar",
    "tabizávamos": "tabizar",
    "tabizávei": "tabizar",
    "tabizáveis": "tabizável",
    "tablados": "tablado",
    "tablas": "tabla",
    "tabliers": "tablier",
    "tablilhas": "tablilha",
    "tablóides": "tablóide",
    "tabocais": "tabocal",
    "tabocas": "taboca",
    "taboqueira": "taboqueiro",
    "taboqueiras": "taboqueiro",
    "taboqueiros": "taboqueiro",
    "tabos": "tabo",
    "tabuadas": "tabuada",
    "tabuados": "tabuado",
    "tabuais": "tabual",
    "tabuas": "tabua",
    "tabuinha": "tábua",
    "tabuinhas": "tábua",
    "tabuita": "tábua",
    "tabuitas": "tábua",
    "tabuladoras": "tabuladora",
    "tabuladores": "tabulador",
    "tabulados": "tabulado",
    "tabulageiros": "tabulageiro",
    "tabulagens": "tabulagem",
    "tabulares": "tabular",
    "tabuleiros": "tabuleiro",
    "tabuletas": "tabuleta",
    "tabulistas": "tabulista",
    "tabulária": "tabulário",
    "tabulárias": "tabulário",
    "tabulários": "tabulário",
    "tabulões": "tabulão",
    "taburnos": "taburno",
    "tabus": "tabu",
    "tabuões": "tabuão",
    "tabágica": "tabágico",
    "tabágicas": "tabágico",
    "tabágicos": "tabágico",
    "tabánidas": "tabánida",
    "tabética": "tabético",
    "tabéticas": "tabético",
    "tabéticos": "tabético",
    "tabífica": "tabífico",
    "tabíficas": "tabífico",
    "tabíficos": "tabífico",
    "tabões": "tabão",
    "taca": "tacar",
    "tacacás": "tacacá",
    "tacada": "tacar",
    "tacadas": "tacar",
    "tacadinha": "tacada",
    "tacadinhas": "tacada",
    "tacadita": "tacada",
    "tacaditas": "tacada",
    "tacado": "tacar",
    "tacados": "tacar",
    "tacais": "tacar",
    "tacam": "tacar",
    "tacamacas": "tacamaca",
    "tacamagueiros": "tacamagueiro",
    "tacamaqueiros": "tacamaqueiro",
    "tacamo": "tacar",
    "tacamos": "tacar",
    "tacando": "tacar",
    "tacanha": "tacanho",
    "tacanharias": "tacanharia",
    "tacanhas": "tacanho",
    "tacanheada": "tacanhear",
    "tacanheadas": "tacanhear",
    "tacanheado": "tacanhear",
    "tacanheados": "tacanhear",
    "tacanheai": "tacanhear",
    "tacanheais": "tacanhear",
    "tacanheamo": "tacanhear",
    "tacanheamos": "tacanhear",
    "tacanheando": "tacanhear",
    "tacanheara": "tacanhear",
    "tacanhearam": "tacanhear",
    "tacanhearas": "tacanhear",
    "tacanheardes": "tacanhear",
    "tacanhearei": "tacanhear",
    "tacanheareis": "tacanhear",
    "tacanhearem": "tacanhear",
    "tacanhearemos": "tacanhear",
    "tacanheares": "tacanhear",
    "tacanhearia": "tacanhear",
    "tacanheariam": "tacanhear",
    "tacanhearias": "tacanhear",
    "tacanhearmo": "tacanhear",
    "tacanhearmos": "tacanhear",
    "tacanheará": "tacanhear",
    "tacanhearás": "tacanhear",
    "tacanhearão": "tacanhear",
    "tacanhearíamos": "tacanhear",
    "tacanhearíeis": "tacanhear",
    "tacanheasse": "tacanhear",
    "tacanheassem": "tacanhear",
    "tacanheasses": "tacanhear",
    "tacanheaste": "tacanhear",
    "tacanheastes": "tacanhear",
    "tacanheava": "tacanhear",
    "tacanheavam": "tacanhear",
    "tacanheavas": "tacanhear",
    "tacanheei": "tacanhear",
    "tacanheeis": "tacanhear",
    "tacanheemo": "tacanhear",
    "tacanheemos": "tacanhear",
    "tacanheia": "tacanhear",
    "tacanheiam": "tacanhear",
    "tacanheias": "tacanhear",
    "tacanheie": "tacanhear",
    "tacanheiem": "tacanhear",
    "tacanheies": "tacanhear",
    "tacanheio": "tacanhear",
    "tacanheou": "tacanhear",
    "tacanhezas": "tacanheza",
    "tacanhezes": "tacanhez",
    "tacanheámo": "tacanhear",
    "tacanheámos": "tacanhear",
    "tacanheáramo": "tacanhear",
    "tacanheáramos": "tacanhear",
    "tacanheáreis": "tacanhear",
    "tacanheásseis": "tacanhear",
    "tacanheássemos": "tacanhear",
    "tacanheávamo": "tacanhear",
    "tacanheávamos": "tacanhear",
    "tacanheáveis": "tacanhear",
    "tacanhices": "tacanhice",
    "tacanhos": "tacanho",
    "tacaniças": "tacaniça",
    "tacapes": "tacape",
    "tacara": "tacar",
    "tacaram": "tacar",
    "tacaras": "tacar",
    "tacardes": "tacar",
    "tacarei": "tacar",
    "tacareis": "tacar",
    "tacarem": "tacar",
    "tacaremos": "tacar",
    "tacares": "tacar",
    "tacaria": "tacar",
    "tacariam": "tacar",
    "tacarias": "tacar",
    "tacarmo": "tacar",
    "tacarmos": "tacar",
    "tacará": "tacar",
    "tacarás": "tacar",
    "tacarão": "tacar",
    "tacaríamos": "tacar",
    "tacaríeis": "tacar",
    "tacas": "tacar",
    "tacasse": "tacar",
    "tacassem": "tacar",
    "tacasses": "tacar",
    "tacaste": "tacar",
    "tacastes": "tacar",
    "tacava": "tacar",
    "tacavam": "tacar",
    "tacavas": "tacar",
    "taceiras": "taceira",
    "tacelos": "tacelo",
    "tacha": "tachar",
    "tachada": "tachar",
    "tachadas": "tachar",
    "tachado": "tachar",
    "tachados": "tachar",
    "tachai": "tachar",
    "tachais": "tachar",
    "tacham": "tachar",
    "tachamo": "tachar",
    "tachamos": "tachar",
    "tachando": "tachar",
    "tachara": "tachar",
    "tacharam": "tachar",
    "tacharas": "tachar",
    "tacharde": "tachar",
    "tachardes": "tachar",
    "tachare": "tachar",
    "tacharei": "tachar",
    "tachareis": "tachar",
    "tacharem": "tachar",
    "tacharemos": "tachar",
    "tachares": "tachar",
    "tacharia": "tachar",
    "tachariam": "tachar",
    "tacharias": "tachar",
    "tacharmo": "tachar",
    "tacharmos": "tachar",
    "tachará": "tachar",
    "tacharás": "tachar",
    "tacharão": "tachar",
    "tacharíamos": "tachar",
    "tacharíeis": "tachar",
    "tachas": "tachar",
    "tachasse": "tachar",
    "tachassem": "tachar",
    "tachasses": "tachar",
    "tachaste": "tachar",
    "tachastes": "tachar",
    "tachava": "tachar",
    "tachavam": "tachar",
    "tachavas": "tachar",
    "tachaveis": "tachavel",
    "tache": "tachar",
    "tacheada": "tachear",
    "tacheadas": "tachear",
    "tacheado": "tachear",
    "tacheados": "tachear",
    "tacheai": "tachear",
    "tacheais": "tachear",
    "tacheamo": "tachear",
    "tacheamos": "tachear",
    "tacheando": "tachear",
    "tacheara": "tachear",
    "tachearam": "tachear",
    "tachearas": "tachear",
    "tachearde": "tachear",
    "tacheardes": "tachear",
    "tacheare": "tachear",
    "tachearei": "tachear",
    "tacheareis": "tachear",
    "tachearem": "tachear",
    "tachearemos": "tachear",
    "tacheares": "tachear",
    "tachearia": "tachear",
    "tacheariam": "tachear",
    "tachearias": "tachear",
    "tachearmo": "tachear",
    "tachearmos": "tachear",
    "tacheará": "tachear",
    "tachearás": "tachear",
    "tachearão": "tachear",
    "tachearíamos": "tachear",
    "tachearíeis": "tachear",
    "tacheasse": "tachear",
    "tacheassem": "tachear",
    "tacheasses": "tachear",
    "tacheaste": "tachear",
    "tacheastes": "tachear",
    "tacheava": "tachear",
    "tacheavam": "tachear",
    "tacheavas": "tachear",
    "tacheaveis": "tacheavel",
    "tacheei": "tachear",
    "tacheeis": "tachear",
    "tacheemo": "tachear",
    "tacheemos": "tachear",
    "tachei": "tachar",
    "tacheia": "tachear",
    "tacheiam": "tachear",
    "tacheias": "tachear",
    "tacheie": "tachear",
    "tacheiem": "tachear",
    "tacheies": "tachear",
    "tacheio": "tachear",
    "tacheis": "tachar",
    "tachem": "tachar",
    "tachemo": "tachar",
    "tachemos": "tachar",
    "tacheou": "tachear",
    "taches": "tachar",
    "tacheá": "tachear",
    "tacheámo": "tachear",
    "tacheámos": "tachear",
    "tacheáramo": "tachear",
    "tacheáramos": "tachear",
    "tacheárei": "tachear",
    "tacheáreis": "tachear",
    "tacheásseis": "tachear",
    "tacheássemos": "tachear",
    "tacheávamo": "tachear",
    "tacheávamos": "tachear",
    "tacheávei": "tachear",
    "tacheáveis": "tachear",
    "tachinho": "tacho",
    "tachinhos": "tacho",
    "tachins": "tachim",
    "tachito": "tacho",
    "tachitos": "tacho",
    "tacho": "tachar",
    "tacholas": "tachola",
    "tachona": "tachonar",
    "tachonada": "tachonar",
    "tachonadas": "tachonar",
    "tachonado": "tachonar",
    "tachonados": "tachonar",
    "tachonai": "tachonar",
    "tachonais": "tachonar",
    "tachonam": "tachonar",
    "tachonamo": "tachonar",
    "tachonamos": "tachonar",
    "tachonando": "tachonar",
    "tachonara": "tachonar",
    "tachonaram": "tachonar",
    "tachonaras": "tachonar",
    "tachonarde": "tachonar",
    "tachonardes": "tachonar",
    "tachonare": "tachonar",
    "tachonarei": "tachonar",
    "tachonareis": "tachonar",
    "tachonarem": "tachonar",
    "tachonaremos": "tachonar",
    "tachonares": "tachonar",
    "tachonaria": "tachonar",
    "tachonariam": "tachonar",
    "tachonarias": "tachonar",
    "tachonarmo": "tachonar",
    "tachonarmos": "tachonar",
    "tachonará": "tachonar",
    "tachonarás": "tachonar",
    "tachonarão": "tachonar",
    "tachonaríamos": "tachonar",
    "tachonaríeis": "tachonar",
    "tachonas": "tachonar",
    "tachonasse": "tachonar",
    "tachonassem": "tachonar",
    "tachonasses": "tachonar",
    "tachonaste": "tachonar",
    "tachonastes": "tachonar",
    "tachonava": "tachonar",
    "tachonavam": "tachonar",
    "tachonavas": "tachonar",
    "tachone": "tachonar",
    "tachonei": "tachonar",
    "tachoneis": "tachonar",
    "tachonem": "tachonar",
    "tachonemo": "tachonar",
    "tachonemos": "tachonar",
    "tachones": "tachonar",
    "tachono": "tachonar",
    "tachonou": "tachonar",
    "tachoná": "tachonar",
    "tachonámo": "tachonar",
    "tachonámos": "tachonar",
    "tachonáramo": "tachonar",
    "tachonáramos": "tachonar",
    "tachonárei": "tachonar",
    "tachonáreis": "tachonar",
    "tachonásseis": "tachonar",
    "tachonássemos": "tachonar",
    "tachonávamo": "tachonar",
    "tachonávamos": "tachonar",
    "tachonávei": "tachonar",
    "tachonáveis": "tachonável",
    "tachos": "tacho",
    "tachou": "tachar",
    "tachá": "tachar",
    "tachámo": "tachar",
    "tachámos": "tachar",
    "tacháramo": "tachar",
    "tacháramos": "tachar",
    "tachárei": "tachar",
    "tacháreis": "tachar",
    "tachásseis": "tachar",
    "tachássemos": "tachar",
    "tachávamo": "tachar",
    "tachávamos": "tachar",
    "tachávei": "tachar",
    "tacháveis": "tachar",
    "tachãs": "tachã",
    "tacinha": "taça",
    "tacinhas": "taça",
    "tacita": "taça",
    "tacitas": "taça",
    "taciturna": "taciturno",
    "taciturnas": "taciturno",
    "taciturnidades": "taciturnidade",
    "taciturnos": "taciturno",
    "tacitíflua": "tacitífluo",
    "tacitífluas": "tacitífluo",
    "tacitífluos": "tacitífluo",
    "taco": "tacar",
    "tacona": "tacão",
    "taconas": "tacão",
    "tacos": "taco",
    "tacou": "tacar",
    "tacs": "tac",
    "tacteabilidades": "tacteabilidade",
    "tacteada": "tactear",
    "tacteadas": "tactear",
    "tacteado": "tactear",
    "tacteados": "tactear",
    "tacteai": "tactear",
    "tacteais": "tactear",
    "tacteamentos": "tacteamento",
    "tacteamo": "tactear",
    "tacteamos": "tactear",
    "tacteando": "tactear",
    "tacteantes": "tacteante",
    "tacteara": "tactear",
    "tactearam": "tactear",
    "tactearas": "tactear",
    "tactearde": "tactear",
    "tacteardes": "tactear",
    "tacteare": "tactear",
    "tactearei": "tactear",
    "tacteareis": "tactear",
    "tactearem": "tactear",
    "tactearemos": "tactear",
    "tacteares": "tactear",
    "tactearia": "tactear",
    "tacteariam": "tactear",
    "tactearias": "tactear",
    "tactearmo": "tactear",
    "tactearmos": "tactear",
    "tacteará": "tactear",
    "tactearás": "tactear",
    "tactearão": "tactear",
    "tactearíamos": "tactear",
    "tactearíeis": "tactear",
    "tacteasse": "tactear",
    "tacteassem": "tactear",
    "tacteasses": "tactear",
    "tacteaste": "tactear",
    "tacteastes": "tactear",
    "tacteava": "tactear",
    "tacteavam": "tactear",
    "tacteavas": "tactear",
    "tacteei": "tactear",
    "tacteeis": "tactear",
    "tacteemo": "tactear",
    "tacteemos": "tactear",
    "tacteia": "tactear",
    "tacteiam": "tactear",
    "tacteias": "tactear",
    "tacteie": "tactear",
    "tacteiem": "tactear",
    "tacteies": "tactear",
    "tacteio": "tactear",
    "tacteios": "tacteio",
    "tacteou": "tactear",
    "tacteá": "tactear",
    "tacteámo": "tactear",
    "tacteámos": "tactear",
    "tacteáramo": "tactear",
    "tacteáramos": "tactear",
    "tacteárei": "tactear",
    "tacteáreis": "tactear",
    "tacteásseis": "tactear",
    "tacteássemos": "tactear",
    "tacteávamo": "tactear",
    "tacteávamos": "tactear",
    "tacteávei": "tactear",
    "tacteáveis": "tacteável",
    "tacticografias": "tacticografia",
    "tacticógrafa": "tacticógrafo",
    "tacticógrafas": "tacticógrafo",
    "tacticógrafos": "tacticógrafo",
    "tactilidades": "tactilidade",
    "tactismos": "tactismo",
    "tactos": "tacto",
    "tacturas": "tactura",
    "tacáceas": "tacácea",
    "tacámo": "tacar",
    "tacámos": "tacar",
    "tacáramo": "tacar",
    "tacáramos": "tacar",
    "tacáreis": "tacar",
    "tacásseis": "tacar",
    "tacássemos": "tacar",
    "tacávamo": "tacar",
    "tacávamos": "tacar",
    "tacáveis": "tacar",
    "tacículas": "tacícula",
    "tacógrafos": "tacógrafo",
    "tacómetros": "tacómetro",
    "tacões": "tacão",
    "taeis": "tael",
    "tafeciras": "tafecira",
    "tafetás": "tafetá",
    "tafiletes": "tafilete",
    "tafiás": "tafiá",
    "tafofobias": "tafofobia",
    "tafuis": "taful",
    "tafula": "tafulo",
    "tafulada": "tafular",
    "tafuladas": "tafular",
    "tafulado": "tafular",
    "tafulados": "tafular",
    "tafulai": "tafular",
    "tafulais": "tafular",
    "tafulam": "tafular",
    "tafulamo": "tafular",
    "tafulamos": "tafular",
    "tafulando": "tafular",
    "tafulara": "tafular",
    "tafularam": "tafular",
    "tafularas": "tafular",
    "tafulardes": "tafular",
    "tafularei": "tafular",
    "tafulareis": "tafular",
    "tafularem": "tafular",
    "tafularemos": "tafular",
    "tafulares": "tafular",
    "tafularia": "tafular",
    "tafulariam": "tafular",
    "tafularias": "tafularia",
    "tafularmo": "tafular",
    "tafularmos": "tafular",
    "tafulará": "tafular",
    "tafularás": "tafular",
    "tafularão": "tafular",
    "tafularíamos": "tafular",
    "tafularíeis": "tafular",
    "tafulas": "tafulo",
    "tafulasse": "tafular",
    "tafulassem": "tafular",
    "tafulasses": "tafular",
    "tafulaste": "tafular",
    "tafulastes": "tafular",
    "tafulava": "tafular",
    "tafulavam": "tafular",
    "tafulavas": "tafular",
    "tafule": "tafular",
    "tafulei": "tafular",
    "tafuleis": "tafular",
    "tafulem": "tafular",
    "tafulemo": "tafular",
    "tafulemos": "tafular",
    "tafules": "tafular",
    "tafulha": "tafulhar",
    "tafulhada": "tafulhar",
    "tafulhadas": "tafulhar",
    "tafulhado": "tafulhar",
    "tafulhados": "tafulhar",
    "tafulhai": "tafulhar",
    "tafulhais": "tafulhar",
    "tafulham": "tafulhar",
    "tafulhamo": "tafulhar",
    "tafulhamos": "tafulhar",
    "tafulhando": "tafulhar",
    "tafulhara": "tafulhar",
    "tafulharam": "tafulhar",
    "tafulharas": "tafulhar",
    "tafulharde": "tafulhar",
    "tafulhardes": "tafulhar",
    "tafulhare": "tafulhar",
    "tafulharei": "tafulhar",
    "tafulhareis": "tafulhar",
    "tafulharem": "tafulhar",
    "tafulharemos": "tafulhar",
    "tafulhares": "tafulhar",
    "tafulharia": "tafulhar",
    "tafulhariam": "tafulhar",
    "tafulharias": "tafulhar",
    "tafulharmo": "tafulhar",
    "tafulharmos": "tafulhar",
    "tafulhará": "tafulhar",
    "tafulharás": "tafulhar",
    "tafulharão": "tafulhar",
    "tafulharíamos": "tafulhar",
    "tafulharíeis": "tafulhar",
    "tafulhas": "tafulhar",
    "tafulhasse": "tafulhar",
    "tafulhassem": "tafulhar",
    "tafulhasses": "tafulhar",
    "tafulhaste": "tafulhar",
    "tafulhastes": "tafulhar",
    "tafulhava": "tafulhar",
    "tafulhavam": "tafulhar",
    "tafulhavas": "tafulhar",
    "tafulhe": "tafulhar",
    "tafulhei": "tafulhar",
    "tafulheis": "tafulhar",
    "tafulhem": "tafulhar",
    "tafulhemo": "tafulhar",
    "tafulhemos": "tafulhar",
    "tafulhes": "tafulhar",
    "tafulho": "tafulhar",
    "tafulhos": "tafulho",
    "tafulhou": "tafulhar",
    "tafulhá": "tafulhar",
    "tafulhámo": "tafulhar",
    "tafulhámos": "tafulhar",
    "tafulháramo": "tafulhar",
    "tafulháramos": "tafulhar",
    "tafulhárei": "tafulhar",
    "tafulháreis": "tafulhar",
    "tafulhásseis": "tafulhar",
    "tafulhássemos": "tafulhar",
    "tafulhávamo": "tafulhar",
    "tafulhávamos": "tafulhar",
    "tafulhávei": "tafulhar",
    "tafulháveis": "tafulhável",
    "tafulices": "tafulice",
    "tafulo": "tafular",
    "tafulos": "tafulo",
    "tafulou": "tafular",
    "tafulámo": "tafular",
    "tafulámos": "tafular",
    "tafuláramo": "tafular",
    "tafuláramos": "tafular",
    "tafuláreis": "tafular",
    "tafulásseis": "tafular",
    "tafulássemos": "tafular",
    "tafulávamo": "tafular",
    "tafulávamos": "tafular",
    "tafuláveis": "tafular",
    "tagais": "tagal",
    "tagalhos": "tagalho",
    "tagalos": "tagalo",
    "taganas": "tagana",
    "taganta": "tagantar",
    "tagantada": "tagantar",
    "tagantadas": "tagantar",
    "tagantado": "tagantar",
    "tagantados": "tagantar",
    "tagantai": "tagantar",
    "tagantais": "tagantar",
    "tagantam": "tagantar",
    "tagantamo": "tagantar",
    "tagantamos": "tagantar",
    "tagantando": "tagantar",
    "tagantara": "tagantar",
    "tagantaram": "tagantar",
    "tagantaras": "tagantar",
    "tagantarde": "tagantar",
    "tagantardes": "tagantar",
    "tagantare": "tagantar",
    "tagantarei": "tagantar",
    "tagantareis": "tagantar",
    "tagantarem": "tagantar",
    "tagantaremos": "tagantar",
    "tagantares": "tagantar",
    "tagantaria": "tagantar",
    "tagantariam": "tagantar",
    "tagantarias": "tagantar",
    "tagantarmo": "tagantar",
    "tagantarmos": "tagantar",
    "tagantará": "tagantar",
    "tagantarás": "tagantar",
    "tagantarão": "tagantar",
    "tagantaríamos": "tagantar",
    "tagantaríeis": "tagantar",
    "tagantas": "tagantar",
    "tagantasse": "tagantar",
    "tagantassem": "tagantar",
    "tagantasses": "tagantar",
    "tagantaste": "tagantar",
    "tagantastes": "tagantar",
    "tagantava": "tagantar",
    "tagantavam": "tagantar",
    "tagantavas": "tagantar",
    "tagante": "tagantar",
    "taganteada": "tagantear",
    "taganteadas": "tagantear",
    "taganteado": "tagantear",
    "taganteados": "tagantear",
    "taganteai": "tagantear",
    "taganteais": "tagantear",
    "taganteamo": "tagantear",
    "taganteamos": "tagantear",
    "taganteando": "tagantear",
    "taganteara": "tagantear",
    "tagantearam": "tagantear",
    "tagantearas": "tagantear",
    "tagantearde": "tagantear",
    "taganteardes": "tagantear",
    "taganteare": "tagantear",
    "tagantearei": "tagantear",
    "taganteareis": "tagantear",
    "tagantearem": "tagantear",
    "tagantearemos": "tagantear",
    "taganteares": "tagantear",
    "tagantearia": "tagantear",
    "taganteariam": "tagantear",
    "tagantearias": "tagantear",
    "tagantearmo": "tagantear",
    "tagantearmos": "tagantear",
    "taganteará": "tagantear",
    "tagantearás": "tagantear",
    "tagantearão": "tagantear",
    "tagantearíamos": "tagantear",
    "tagantearíeis": "tagantear",
    "taganteasse": "tagantear",
    "taganteassem": "tagantear",
    "taganteasses": "tagantear",
    "taganteaste": "tagantear",
    "taganteastes": "tagantear",
    "taganteava": "tagantear",
    "taganteavam": "tagantear",
    "taganteavas": "tagantear",
    "taganteei": "tagantear",
    "taganteeis": "tagantear",
    "taganteemo": "tagantear",
    "taganteemos": "tagantear",
    "tagantei": "tagantar",
    "taganteia": "tagantear",
    "taganteiam": "tagantear",
    "taganteias": "tagantear",
    "taganteie": "tagantear",
    "taganteiem": "tagantear",
    "taganteies": "tagantear",
    "taganteio": "tagantear",
    "taganteis": "tagantar",
    "tagantem": "tagantar",
    "tagantemo": "tagantar",
    "tagantemos": "tagantar",
    "taganteou": "tagantear",
    "tagantes": "tagante",
    "taganteá": "tagantear",
    "taganteámo": "tagantear",
    "taganteámos": "tagantear",
    "taganteáramo": "tagantear",
    "taganteáramos": "tagantear",
    "taganteárei": "tagantear",
    "taganteáreis": "tagantear",
    "taganteásseis": "tagantear",
    "taganteássemos": "tagantear",
    "taganteávamo": "tagantear",
    "taganteávamos": "tagantear",
    "taganteávei": "tagantear",
    "taganteáveis": "taganteável",
    "taganto": "tagantar",
    "tagantou": "tagantar",
    "tagantá": "tagantar",
    "tagantámo": "tagantar",
    "tagantámos": "tagantar",
    "tagantáramo": "tagantar",
    "tagantáramos": "tagantar",
    "tagantárei": "tagantar",
    "tagantáreis": "tagantar",
    "tagantásseis": "tagantar",
    "tagantássemos": "tagantar",
    "tagantávamo": "tagantar",
    "tagantávamos": "tagantar",
    "tagantávei": "tagantar",
    "tagantáveis": "tagantável",
    "tagarela": "tagarelar",
    "tagarelada": "tagarelar",
    "tagareladas": "tagarelar",
    "tagarelado": "tagarelar",
    "tagarelados": "tagarelar",
    "tagarelai": "tagarelar",
    "tagarelais": "tagarelar",
    "tagarelam": "tagarelar",
    "tagarelamo": "tagarelar",
    "tagarelamos": "tagarelar",
    "tagarelando": "tagarelar",
    "tagarelara": "tagarelar",
    "tagarelaram": "tagarelar",
    "tagarelaras": "tagarelar",
    "tagarelardes": "tagarelar",
    "tagarelarei": "tagarelar",
    "tagarelareis": "tagarelar",
    "tagarelarem": "tagarelar",
    "tagarelaremos": "tagarelar",
    "tagarelares": "tagarelar",
    "tagarelaria": "tagarelar",
    "tagarelariam": "tagarelar",
    "tagarelarias": "tagarelar",
    "tagarelarmo": "tagarelar",
    "tagarelarmos": "tagarelar",
    "tagarelará": "tagarelar",
    "tagarelarás": "tagarelar",
    "tagarelarão": "tagarelar",
    "tagarelaríamos": "tagarelar",
    "tagarelaríeis": "tagarelar",
    "tagarelas": "tagarelar",
    "tagarelasse": "tagarelar",
    "tagarelassem": "tagarelar",
    "tagarelasses": "tagarelar",
    "tagarelaste": "tagarelar",
    "tagarelastes": "tagarelar",
    "tagarelava": "tagarelar",
    "tagarelavam": "tagarelar",
    "tagarelavas": "tagarelar",
    "tagarele": "tagarelar",
    "tagarelei": "tagarelar",
    "tagareleis": "tagarelar",
    "tagarelem": "tagarelar",
    "tagarelemo": "tagarelar",
    "tagarelemos": "tagarelar",
    "tagareles": "tagarelar",
    "tagarelices": "tagarelice",
    "tagarelo": "tagarelar",
    "tagarelou": "tagarelar",
    "tagarelámo": "tagarelar",
    "tagarelámos": "tagarelar",
    "tagareláramo": "tagarelar",
    "tagareláramos": "tagarelar",
    "tagareláreis": "tagarelar",
    "tagarelásseis": "tagarelar",
    "tagarelássemos": "tagarelar",
    "tagarelávamo": "tagarelar",
    "tagarelávamos": "tagarelar",
    "tagareláveis": "tagarelar",
    "tagarinos": "tagarino",
    "tagarotes": "tagarote",
    "tagarras": "tagarra",
    "tagarrilhas": "tagarrilha",
    "tagassastos": "tagassasto",
    "tagatés": "tagaté",
    "tagazes": "tagaz",
    "tagras": "tagra",
    "taias": "taia",
    "taifas": "taifa",
    "taifeiros": "taifeiro",
    "tailandesa": "tailandês",
    "tailandesas": "tailandês",
    "tailandeses": "tailandês",
    "tailleures": "tailleur",
    "taimada": "taimado",
    "taimadas": "taimado",
    "taimados": "taimado",
    "taina": "tainar",
    "tainada": "tainar",
    "tainadas": "tainar",
    "tainado": "tainar",
    "tainados": "tainar",
    "tainai": "tainar",
    "tainais": "tainar",
    "tainam": "tainar",
    "tainamo": "tainar",
    "tainamos": "tainar",
    "tainando": "tainar",
    "tainara": "tainar",
    "tainaram": "tainar",
    "tainaras": "tainar",
    "tainardes": "tainar",
    "tainarei": "tainar",
    "tainareis": "tainar",
    "tainarem": "tainar",
    "tainaremos": "tainar",
    "tainares": "tainar",
    "tainaria": "tainar",
    "tainariam": "tainar",
    "tainarias": "tainar",
    "tainarmo": "tainar",
    "tainarmos": "tainar",
    "tainará": "tainar",
    "tainarás": "tainar",
    "tainarão": "tainar",
    "tainaríamos": "tainar",
    "tainaríeis": "tainar",
    "tainas": "tainar",
    "tainasse": "tainar",
    "tainassem": "tainar",
    "tainasses": "tainar",
    "tainaste": "tainar",
    "tainastes": "tainar",
    "tainava": "tainar",
    "tainavam": "tainar",
    "tainavas": "tainar",
    "taine": "tainar",
    "tainei": "tainar",
    "taineira": "taineiro",
    "taineiras": "taineiro",
    "taineiros": "taineiro",
    "taineis": "tainar",
    "tainem": "tainar",
    "tainemo": "tainar",
    "tainemos": "tainar",
    "taines": "tainar",
    "tainhas": "tainha",
    "tainheiras": "tainheira",
    "tainheiros": "tainheiro",
    "taino": "tainar",
    "tainos": "taino",
    "tainou": "tainar",
    "tainámo": "tainar",
    "tainámos": "tainar",
    "taináramo": "tainar",
    "taináramos": "tainar",
    "taináreis": "tainar",
    "tainásseis": "tainar",
    "tainássemos": "tainar",
    "tainávamo": "tainar",
    "tainávamos": "tainar",
    "taináveis": "tainar",
    "taiobas": "taioba",
    "taiocas": "taioca",
    "taiovas": "taiova",
    "taipa": "taipar",
    "taipada": "taipar",
    "taipadas": "taipar",
    "taipado": "taipar",
    "taipados": "taipar",
    "taipai": "taipar",
    "taipais": "taipar",
    "taipam": "taipar",
    "taipamo": "taipar",
    "taipamos": "taipar",
    "taipando": "taipar",
    "taipara": "taipar",
    "taiparam": "taipar",
    "taiparas": "taipar",
    "taiparde": "taipar",
    "taipardes": "taipar",
    "taipare": "taipar",
    "taiparei": "taipar",
    "taipareis": "taipar",
    "taiparem": "taipar",
    "taiparemos": "taipar",
    "taipares": "taipar",
    "taiparia": "taipar",
    "taipariam": "taipar",
    "taiparias": "taipar",
    "taiparmo": "taipar",
    "taiparmos": "taipar",
    "taipará": "taipar",
    "taiparás": "taipar",
    "taiparão": "taipar",
    "taiparíamos": "taipar",
    "taiparíeis": "taipar",
    "taipas": "taipar",
    "taipasse": "taipar",
    "taipassem": "taipar",
    "taipasses": "taipar",
    "taipaste": "taipar",
    "taipastes": "taipar",
    "taipava": "taipar",
    "taipavam": "taipar",
    "taipavas": "taipar",
    "taipe": "taipar",
    "taipei": "taipar",
    "taipeira": "taipeiro",
    "taipeiras": "taipeiro",
    "taipeiros": "taipeiro",
    "taipeis": "taipar",
    "taipem": "taipar",
    "taipemo": "taipar",
    "taipemos": "taipar",
    "taipes": "taipar",
    "taipo": "taipar",
    "taipou": "taipar",
    "taipá": "taipar",
    "taipámo": "taipar",
    "taipámos": "taipar",
    "taipáramo": "taipar",
    "taipáramos": "taipar",
    "taipárei": "taipar",
    "taipáreis": "taipar",
    "taipásseis": "taipar",
    "taipássemos": "taipar",
    "taipávamo": "taipar",
    "taipávamos": "taipar",
    "taipávei": "taipar",
    "taipáveis": "taipável",
    "taipões": "taipão",
    "tairas": "taira",
    "tairoca": "tairocar",
    "tairocada": "tairocar",
    "tairocadas": "tairocar",
    "tairocado": "tairocar",
    "tairocados": "tairocar",
    "tairocais": "tairocar",
    "tairocam": "tairocar",
    "tairocamo": "tairocar",
    "tairocamos": "tairocar",
    "tairocando": "tairocar",
    "tairocara": "tairocar",
    "tairocaram": "tairocar",
    "tairocaras": "tairocar",
    "tairocardes": "tairocar",
    "tairocarei": "tairocar",
    "tairocareis": "tairocar",
    "tairocarem": "tairocar",
    "tairocaremos": "tairocar",
    "tairocares": "tairocar",
    "tairocaria": "tairocar",
    "tairocariam": "tairocar",
    "tairocarias": "tairocar",
    "tairocarmo": "tairocar",
    "tairocarmos": "tairocar",
    "tairocará": "tairocar",
    "tairocarás": "tairocar",
    "tairocarão": "tairocar",
    "tairocaríamos": "tairocar",
    "tairocaríeis": "tairocar",
    "tairocas": "tairocar",
    "tairocasse": "tairocar",
    "tairocassem": "tairocar",
    "tairocasses": "tairocar",
    "tairocaste": "tairocar",
    "tairocastes": "tairocar",
    "tairocava": "tairocar",
    "tairocavam": "tairocar",
    "tairocavas": "tairocar",
    "tairoco": "tairocar",
    "tairocou": "tairocar",
    "tairocámo": "tairocar",
    "tairocámos": "tairocar",
    "tairocáramo": "tairocar",
    "tairocáramos": "tairocar",
    "tairocáreis": "tairocar",
    "tairocásseis": "tairocar",
    "tairocássemos": "tairocar",
    "tairocávamo": "tairocar",
    "tairocávamos": "tairocar",
    "tairocáveis": "tairocar",
    "tairoque": "tairocar",
    "tairoquei": "tairocar",
    "tairoqueis": "tairocar",
    "tairoquem": "tairocar",
    "tairoquemos": "tairocar",
    "tairoques": "tairocar",
    "tais": "tal",
    "taiuiás": "taiuiá",
    "tajais": "tajal",
    "tajarrilhas": "tajarrilha",
    "tajasnos": "tajasno",
    "tajaçus": "tajaçu",
    "tajubas": "tajuba",
    "tajujás": "tajujá",
    "tajãs": "tajã",
    "tala": "talar",
    "talabardões": "talabardão",
    "talabartarias": "talabartaria",
    "talabartes": "talabarte",
    "talada": "talar",
    "taladas": "talar",
    "talado": "talar",
    "taladora": "talador",
    "taladoras": "talador",
    "taladores": "talador",
    "talados": "talar",
    "talagarças": "talagarça",
    "talagaxas": "talagaxa",
    "talai": "talar",
    "talais": "talar",
    "talam": "talar",
    "talambores": "talambor",
    "talamentos": "talamento",
    "talamo": "talar",
    "talamos": "talar",
    "talando": "talar",
    "talantes": "talante",
    "talapões": "talapão",
    "talara": "talar",
    "talaram": "talar",
    "talaras": "talar",
    "talarde": "talar",
    "talardes": "talar",
    "talare": "talar",
    "talarei": "talar",
    "talareis": "talar",
    "talarem": "talar",
    "talaremos": "talar",
    "talares": "talar",
    "talaria": "talar",
    "talariam": "talar",
    "talarias": "talar",
    "talarmo": "talar",
    "talarmos": "talar",
    "talará": "talar",
    "talarás": "talar",
    "talarão": "talar",
    "talaríamos": "talar",
    "talaríeis": "talar",
    "talas": "talar",
    "talassaes": "talassa",
    "talassarias": "talassaria",
    "talasse": "talar",
    "talassem": "talar",
    "talasses": "talar",
    "talassiarcas": "talassiarca",
    "talassiarquias": "talassiarquia",
    "talassias": "talassia",
    "talassices": "talassice",
    "talassiófitos": "talassiófito",
    "talassobiontes": "talassobionte",
    "talassocracias": "talassocracia",
    "talassofobias": "talassofobia",
    "talassografias": "talassografia",
    "talassoplânctons": "talassoplâncton",
    "talassosferas": "talassosfera",
    "talassoterapias": "talassoterapia",
    "talassotéra": "talassotéro",
    "talassotéras": "talassotéro",
    "talassotéros": "talassotéro",
    "talassícolaes": "talassícola",
    "talassódromos": "talassódromo",
    "talassófita": "talassófito",
    "talassófitas": "talassófito",
    "talassófitos": "talassófito",
    "talassómetros": "talassómetro",
    "talassótoca": "talassótoco",
    "talassótocas": "talassótoco",
    "talassótocos": "talassótoco",
    "talaste": "talar",
    "talastes": "talar",
    "talava": "talar",
    "talavam": "talar",
    "talavas": "talar",
    "talcos": "talco",
    "talcosa": "talcoso",
    "talcosas": "talcoso",
    "talcosos": "talcoso",
    "tale": "talar",
    "talei": "talar",
    "taleigadas": "taleigada",
    "taleigas": "taleiga",
    "taleigos": "taleigo",
    "taleis": "talar",
    "talem": "talar",
    "talemo": "talar",
    "talemos": "talar",
    "talentos": "talento",
    "talentosa": "talentoso",
    "talentosas": "talentoso",
    "talentosos": "talentoso",
    "tales": "talar",
    "talha": "talhar",
    "talhada": "talhar",
    "talhadas": "talhar",
    "talhadeiras": "talhadeira",
    "talhadias": "talhadia",
    "talhadiça": "talhadiço",
    "talhadiças": "talhadiço",
    "talhadiços": "talhadiço",
    "talhado": "talhar",
    "talhadoiros": "talhadoiro",
    "talhadora": "talhador",
    "talhadoras": "talhador",
    "talhadores": "talhador",
    "talhados": "talhar",
    "talhadouros": "talhadouro",
    "talhaduras": "talhadura",
    "talhadíssima": "talhado",
    "talhadíssimas": "talhado",
    "talhadíssimo": "talhado",
    "talhadíssimos": "talhado",
    "talhai": "talhar",
    "talhais": "talhar",
    "talham": "talhar",
    "talhamentos": "talhamento",
    "talhames": "talhame",
    "talhamo": "talhar",
    "talhamos": "talhar",
    "talhando": "talhar",
    "talhantees": "talhante",
    "talhantes": "talhante",
    "talhara": "talhar",
    "talharam": "talhar",
    "talharas": "talhar",
    "talharde": "talhar",
    "talhardes": "talhar",
    "talhare": "talhar",
    "talharei": "talhar",
    "talhareis": "talhar",
    "talharem": "talhar",
    "talharemos": "talhar",
    "talhares": "talhar",
    "talharia": "talhar",
    "talhariam": "talhar",
    "talharias": "talharia",
    "talharins": "talharim",
    "talharmo": "talhar",
    "talharmos": "talhar",
    "talharolas": "talharola",
    "talhará": "talhar",
    "talharás": "talhar",
    "talharão": "talhar",
    "talharíamos": "talhar",
    "talharíeis": "talhar",
    "talhas": "talhar",
    "talhasse": "talhar",
    "talhassem": "talhar",
    "talhasses": "talhar",
    "talhaste": "talhar",
    "talhastes": "talhar",
    "talhava": "talhar",
    "talhavam": "talhar",
    "talhavas": "talhar",
    "talhe": "talhar",
    "talhei": "talhar",
    "talheis": "talhar",
    "talhem": "talhar",
    "talhemo": "talhar",
    "talhemos": "talhar",
    "talheres": "talher",
    "talhes": "talhe",
    "talho": "talhar",
    "talhos": "talho",
    "talhou": "talhar",
    "talhá": "talhar",
    "talhámo": "talhar",
    "talhámos": "talhar",
    "talháramo": "talhar",
    "talháramos": "talhar",
    "talhárei": "talhar",
    "talháreis": "talhar",
    "talhásseis": "talhar",
    "talhássemos": "talhar",
    "talhávamo": "talhar",
    "talhávamos": "talhar",
    "talhávei": "talhar",
    "talháveis": "talhável",
    "talhões": "talhão",
    "talibãs": "talibã",
    "talictros": "talictro",
    "talidomidas": "talidomida",
    "taliformes": "taliforme",
    "talinga": "talingar",
    "talingada": "talingar",
    "talingadas": "talingar",
    "talingado": "talingar",
    "talingados": "talingar",
    "talingaduras": "talingadura",
    "talingai": "talingar",
    "talingais": "talingar",
    "talingam": "talingar",
    "talingamo": "talingar",
    "talingamos": "talingar",
    "talingando": "talingar",
    "talingara": "talingar",
    "talingaram": "talingar",
    "talingaras": "talingar",
    "talingarde": "talingar",
    "talingardes": "talingar",
    "talingare": "talingar",
    "talingarei": "talingar",
    "talingareis": "talingar",
    "talingarem": "talingar",
    "talingaremos": "talingar",
    "talingares": "talingar",
    "talingaria": "talingar",
    "talingariam": "talingar",
    "talingarias": "talingar",
    "talingarmo": "talingar",
    "talingarmos": "talingar",
    "talingará": "talingar",
    "talingarás": "talingar",
    "talingarão": "talingar",
    "talingaríamos": "talingar",
    "talingaríeis": "talingar",
    "talingas": "talingar",
    "talingasse": "talingar",
    "talingassem": "talingar",
    "talingasses": "talingar",
    "talingaste": "talingar",
    "talingastes": "talingar",
    "talingava": "talingar",
    "talingavam": "talingar",
    "talingavas": "talingar",
    "talingo": "talingar",
    "talingou": "talingar",
    "talingue": "talingar",
    "talinguei": "talingar",
    "talingueis": "talingar",
    "talinguem": "talingar",
    "talinguemo": "talingar",
    "talinguemos": "talingar",
    "talingues": "talingar",
    "talingá": "talingar",
    "talingámo": "talingar",
    "talingámos": "talingar",
    "talingáramo": "talingar",
    "talingáramos": "talingar",
    "talingárei": "talingar",
    "talingáreis": "talingar",
    "talingásseis": "talingar",
    "talingássemos": "talingar",
    "talingávamo": "talingar",
    "talingávamos": "talingar",
    "talingávei": "talingar",
    "talingáveis": "talingável",
    "talinheiras": "talinheira",
    "talins": "talim",
    "taliona": "talionar",
    "talionada": "talionar",
    "talionadas": "talionar",
    "talionado": "talionar",
    "talionados": "talionar",
    "talionai": "talionar",
    "talionais": "talionar",
    "talionam": "talionar",
    "talionamo": "talionar",
    "talionamos": "talionar",
    "talionando": "talionar",
    "talionara": "talionar",
    "talionaram": "talionar",
    "talionaras": "talionar",
    "talionarde": "talionar",
    "talionardes": "talionar",
    "talionare": "talionar",
    "talionarei": "talionar",
    "talionareis": "talionar",
    "talionarem": "talionar",
    "talionaremos": "talionar",
    "talionares": "talionar",
    "talionaria": "talionar",
    "talionariam": "talionar",
    "talionarias": "talionar",
    "talionarmo": "talionar",
    "talionarmos": "talionar",
    "talionará": "talionar",
    "talionarás": "talionar",
    "talionarão": "talionar",
    "talionaríamos": "talionar",
    "talionaríeis": "talionar",
    "talionas": "talionar",
    "talionasse": "talionar",
    "talionassem": "talionar",
    "talionasses": "talionar",
    "talionaste": "talionar",
    "talionastes": "talionar",
    "talionatos": "talionato",
    "talionava": "talionar",
    "talionavam": "talionar",
    "talionavas": "talionar",
    "talione": "talionar",
    "talionei": "talionar",
    "talioneis": "talionar",
    "talionem": "talionar",
    "talionemo": "talionar",
    "talionemos": "talionar",
    "taliones": "talionar",
    "taliono": "talionar",
    "talionou": "talionar",
    "talioná": "talionar",
    "talionámo": "talionar",
    "talionámos": "talionar",
    "talionáramo": "talionar",
    "talionáramos": "talionar",
    "talionárei": "talionar",
    "talionáreis": "talionar",
    "talionásseis": "talionar",
    "talionássemos": "talionar",
    "talionávamo": "talionar",
    "talionávamos": "talionar",
    "talionávei": "talionar",
    "talionáveis": "talionável",
    "taliscas": "talisca",
    "talismânica": "talismânico",
    "talismânicas": "talismânico",
    "talismânicos": "talismânico",
    "talismãs": "talismã",
    "taliácea": "taliáceo",
    "taliáceas": "taliáceo",
    "taliáceos": "taliáceo",
    "taliões": "talião",
    "talmudes": "talmude",
    "talmudistas": "talmudista",
    "talmúdica": "talmúdico",
    "talmúdicas": "talmúdico",
    "talmúdicos": "talmúdico",
    "talo": "talar",
    "talocas": "taloca",
    "talochas": "talocha",
    "taloeiras": "taloeira",
    "talonada": "talonado",
    "talonadas": "talonado",
    "talonados": "talonado",
    "talos": "talo",
    "talosa": "taloso",
    "talosas": "taloso",
    "talosos": "taloso",
    "talou": "talar",
    "talpiformes": "talpiforme",
    "talpídeos": "talpídeo",
    "taluda": "taludo",
    "taludada": "taludar",
    "taludadas": "taludar",
    "taludado": "taludar",
    "taludados": "taludar",
    "taludai": "taludar",
    "taludais": "taludar",
    "taludam": "taludar",
    "taludamo": "taludar",
    "taludamos": "taludar",
    "taludando": "taludar",
    "taludara": "taludar",
    "taludaram": "taludar",
    "taludaras": "taludar",
    "taludarde": "taludar",
    "taludardes": "taludar",
    "taludare": "taludar",
    "taludarei": "taludar",
    "taludareis": "taludar",
    "taludarem": "taludar",
    "taludaremos": "taludar",
    "taludares": "taludar",
    "taludaria": "taludar",
    "taludariam": "taludar",
    "taludarias": "taludar",
    "taludarmo": "taludar",
    "taludarmos": "taludar",
    "taludará": "taludar",
    "taludarás": "taludar",
    "taludarão": "taludar",
    "taludaríamos": "taludar",
    "taludaríeis": "taludar",
    "taludas": "taludo",
    "taludasse": "taludar",
    "taludassem": "taludar",
    "taludasses": "taludar",
    "taludaste": "taludar",
    "taludastes": "taludar",
    "taludava": "taludar",
    "taludavam": "taludar",
    "taludavas": "taludar",
    "talude": "taludar",
    "taludei": "taludar",
    "taludeis": "taludar",
    "taludem": "taludar",
    "taludemo": "taludar",
    "taludemos": "taludar",
    "taludes": "talude",
    "taludo": "taludar",
    "taludos": "taludo",
    "taludota": "taludote",
    "taludotas": "taludote",
    "taludotes": "taludote",
    "taludou": "taludar",
    "taludá": "taludar",
    "taludámo": "taludar",
    "taludámos": "taludar",
    "taludáramo": "taludar",
    "taludáramos": "taludar",
    "taludárei": "taludar",
    "taludáreis": "taludar",
    "taludásseis": "taludar",
    "taludássemos": "taludar",
    "taludávamo": "taludar",
    "taludávamos": "taludar",
    "taludávei": "taludar",
    "taludáveis": "taludável",
    "taludões": "taludão",
    "talvegues": "talvegue",
    "talá": "talar",
    "talámo": "talar",
    "talámos": "talar",
    "taláramo": "talar",
    "taláramos": "talar",
    "talárei": "talar",
    "taláreis": "talar",
    "talásseis": "talar",
    "talássemos": "talar",
    "talássica": "talássico",
    "talássicas": "talássico",
    "talássicos": "talássico",
    "talávamo": "talar",
    "talávamos": "talar",
    "talávei": "talar",
    "taláveis": "talável",
    "talófitas": "talófita",
    "talófitos": "talófito",
    "talões": "talão",
    "tamacuarés": "tamacuaré",
    "tamagueiros": "tamagueiro",
    "tamanca": "tamanco",
    "tamancadas": "tamancada",
    "tamancarias": "tamancaria",
    "tamancas": "tamanco",
    "tamancos": "tamanco",
    "tamanha": "tamanho",
    "tamanhas": "tamanho",
    "tamanhazinha": "tamanho",
    "tamanhazinhas": "tamanho",
    "tamanhazita": "tamanho",
    "tamanhazitas": "tamanho",
    "tamanhina": "tamanhino",
    "tamanhinas": "tamanhino",
    "tamanhinha": "tamanho",
    "tamanhinhas": "tamanho",
    "tamanhinho": "tamanho",
    "tamanhinhos": "tamanho",
    "tamanhinos": "tamanhino",
    "tamanhita": "tamanho",
    "tamanhitas": "tamanho",
    "tamanhito": "tamanho",
    "tamanhitos": "tamanho",
    "tamanhona": "tamanho",
    "tamanhonas": "tamanho",
    "tamanhos": "tamanho",
    "tamanhozinho": "tamanho",
    "tamanhozinhos": "tamanho",
    "tamanhozito": "tamanho",
    "tamanhozitos": "tamanho",
    "tamanhão": "tamanho",
    "tamanhíssima": "tamanho",
    "tamanhíssimas": "tamanho",
    "tamanhíssimo": "tamanho",
    "tamanhíssimos": "tamanho",
    "tamanhões": "tamanho",
    "tamanina": "tamanino",
    "tamaninas": "tamanino",
    "tamaninha": "tamaninho",
    "tamaninhas": "tamaninho",
    "tamaninhos": "tamaninho",
    "tamaninos": "tamanino",
    "tamanqueada": "tamanquear",
    "tamanqueadas": "tamanquear",
    "tamanqueado": "tamanquear",
    "tamanqueados": "tamanquear",
    "tamanqueai": "tamanquear",
    "tamanqueais": "tamanquear",
    "tamanqueamo": "tamanquear",
    "tamanqueamos": "tamanquear",
    "tamanqueando": "tamanquear",
    "tamanqueara": "tamanquear",
    "tamanquearam": "tamanquear",
    "tamanquearas": "tamanquear",
    "tamanqueardes": "tamanquear",
    "tamanquearei": "tamanquear",
    "tamanqueareis": "tamanquear",
    "tamanquearem": "tamanquear",
    "tamanquearemos": "tamanquear",
    "tamanqueares": "tamanquear",
    "tamanquearia": "tamanquear",
    "tamanqueariam": "tamanquear",
    "tamanquearias": "tamanquear",
    "tamanquearmo": "tamanquear",
    "tamanquearmos": "tamanquear",
    "tamanqueará": "tamanquear",
    "tamanquearás": "tamanquear",
    "tamanquearão": "tamanquear",
    "tamanquearíamos": "tamanquear",
    "tamanquearíeis": "tamanquear",
    "tamanqueasse": "tamanquear",
    "tamanqueassem": "tamanquear",
    "tamanqueasses": "tamanquear",
    "tamanqueaste": "tamanquear",
    "tamanqueastes": "tamanquear",
    "tamanqueava": "tamanquear",
    "tamanqueavam": "tamanquear",
    "tamanqueavas": "tamanquear",
    "tamanqueei": "tamanquear",
    "tamanqueeis": "tamanquear",
    "tamanqueemo": "tamanquear",
    "tamanqueemos": "tamanquear",
    "tamanqueia": "tamanquear",
    "tamanqueiam": "tamanquear",
    "tamanqueias": "tamanquear",
    "tamanqueie": "tamanquear",
    "tamanqueiem": "tamanquear",
    "tamanqueies": "tamanquear",
    "tamanqueio": "tamanquear",
    "tamanqueira": "tamanqueiro",
    "tamanqueiras": "tamanqueiro",
    "tamanqueiros": "tamanqueiro",
    "tamanqueou": "tamanquear",
    "tamanqueámo": "tamanquear",
    "tamanqueámos": "tamanquear",
    "tamanqueáramo": "tamanquear",
    "tamanqueáramos": "tamanquear",
    "tamanqueáreis": "tamanquear",
    "tamanqueásseis": "tamanquear",
    "tamanqueássemos": "tamanquear",
    "tamanqueávamo": "tamanquear",
    "tamanqueávamos": "tamanquear",
    "tamanqueáveis": "tamanquear",
    "tamanquinha": "tamanca",
    "tamanquinhas": "tamanca",
    "tamanquita": "tamanca",
    "tamanquitas": "tamanca",
    "tamarais": "tamaral",
    "tamareiras": "tamareira",
    "tamareses": "tamarês",
    "tamargais": "tamargal",
    "tamargas": "tamarga",
    "tamargueiras": "tamargueira",
    "tamaricácea": "tamaricáceo",
    "tamaricáceas": "tamaricáceo",
    "tamaricáceos": "tamaricáceo",
    "tamarinadas": "tamarinada",
    "tamarindas": "tamarinda",
    "tamarindeiras": "tamarindeira",
    "tamarindeiros": "tamarindeiro",
    "tamarindos": "tamarindo",
    "tamarineiros": "tamarineiro",
    "tamarinheiros": "tamarinheiro",
    "tamarinhos": "tamarinho",
    "tamarinos": "tamarino",
    "tamariscos": "tamarisco",
    "tamarizes": "tamariz",
    "tamarus": "tamaru",
    "tamarutacas": "tamarutaca",
    "tamatiás": "tamatiá",
    "tamaxeques": "tamaxeque",
    "tambacas": "tambaca",
    "tambaques": "tambaque",
    "tambaranes": "tambarane",
    "tambarutacas": "tambarutaca",
    "tambatajás": "tambatajá",
    "tambeiras": "tambeira",
    "tambejos": "tambejo",
    "tambicas": "tambica",
    "tamboeiras": "tamboeira",
    "tambores": "tambor",
    "tamboretes": "tamborete",
    "tamborila": "tamborilar",
    "tamborilada": "tamborilar",
    "tamboriladas": "tamborilar",
    "tamborilado": "tamborilar",
    "tamborilados": "tamborilar",
    "tamborilai": "tamborilar",
    "tamborilais": "tamborilar",
    "tamborilam": "tamborilar",
    "tamborilamo": "tamborilar",
    "tamborilamos": "tamborilar",
    "tamborilando": "tamborilar",
    "tamborilara": "tamborilar",
    "tamborilaram": "tamborilar",
    "tamborilaras": "tamborilar",
    "tamborilardes": "tamborilar",
    "tamborilarei": "tamborilar",
    "tamborilareis": "tamborilar",
    "tamborilarem": "tamborilar",
    "tamborilaremos": "tamborilar",
    "tamborilares": "tamborilar",
    "tamborilaria": "tamborilar",
    "tamborilariam": "tamborilar",
    "tamborilarias": "tamborilar",
    "tamborilarmo": "tamborilar",
    "tamborilarmos": "tamborilar",
    "tamborilará": "tamborilar",
    "tamborilarás": "tamborilar",
    "tamborilarão": "tamborilar",
    "tamborilaríamos": "tamborilar",
    "tamborilaríeis": "tamborilar",
    "tamborilas": "tamborilar",
    "tamborilasse": "tamborilar",
    "tamborilassem": "tamborilar",
    "tamborilasses": "tamborilar",
    "tamborilaste": "tamborilar",
    "tamborilastes": "tamborilar",
    "tamborilava": "tamborilar",
    "tamborilavam": "tamborilar",
    "tamborilavas": "tamborilar",
    "tamborile": "tamborilar",
    "tamborilei": "tamborilar",
    "tamborileira": "tamborileiro",
    "tamborileiras": "tamborileiro",
    "tamborileiros": "tamborileiro",
    "tamborileis": "tamborilar",
    "tamborilem": "tamborilar",
    "tamborilemo": "tamborilar",
    "tamborilemos": "tamborilar",
    "tamboriles": "tamborilar",
    "tamborilo": "tamborilar",
    "tamborilou": "tamborilar",
    "tamborilámo": "tamborilar",
    "tamborilámos": "tamborilar",
    "tamboriláramo": "tamborilar",
    "tamboriláramos": "tamborilar",
    "tamboriláreis": "tamborilar",
    "tamborilásseis": "tamborilar",
    "tamborilássemos": "tamborilar",
    "tamborilávamo": "tamborilar",
    "tamborilávamos": "tamborilar",
    "tamboriláveis": "tamborilar",
    "tamborina": "tamborinar",
    "tamborinada": "tamborinar",
    "tamborinadas": "tamborinar",
    "tamborinado": "tamborinar",
    "tamborinados": "tamborinar",
    "tamborinai": "tamborinar",
    "tamborinais": "tamborinar",
    "tamborinam": "tamborinar",
    "tamborinamo": "tamborinar",
    "tamborinamos": "tamborinar",
    "tamborinando": "tamborinar",
    "tamborinara": "tamborinar",
    "tamborinaram": "tamborinar",
    "tamborinaras": "tamborinar",
    "tamborinardes": "tamborinar",
    "tamborinarei": "tamborinar",
    "tamborinareis": "tamborinar",
    "tamborinarem": "tamborinar",
    "tamborinaremos": "tamborinar",
    "tamborinares": "tamborinar",
    "tamborinaria": "tamborinar",
    "tamborinariam": "tamborinar",
    "tamborinarias": "tamborinar",
    "tamborinarmo": "tamborinar",
    "tamborinarmos": "tamborinar",
    "tamborinará": "tamborinar",
    "tamborinarás": "tamborinar",
    "tamborinarão": "tamborinar",
    "tamborinaríamos": "tamborinar",
    "tamborinaríeis": "tamborinar",
    "tamborinas": "tamborinar",
    "tamborinasse": "tamborinar",
    "tamborinassem": "tamborinar",
    "tamborinasses": "tamborinar",
    "tamborinaste": "tamborinar",
    "tamborinastes": "tamborinar",
    "tamborinava": "tamborinar",
    "tamborinavam": "tamborinar",
    "tamborinavas": "tamborinar",
    "tamborine": "tamborinar",
    "tamborinei": "tamborinar",
    "tamborineis": "tamborinar",
    "tamborinem": "tamborinar",
    "tamborinemo": "tamborinar",
    "tamborinemos": "tamborinar",
    "tamborines": "tamborinar",
    "tamborino": "tamborinar",
    "tamborinou": "tamborinar",
    "tamborins": "tamborim",
    "tamborinámo": "tamborinar",
    "tamborinámos": "tamborinar",
    "tamborináramo": "tamborinar",
    "tamborináramos": "tamborinar",
    "tamborináreis": "tamborinar",
    "tamborinásseis": "tamborinar",
    "tamborinássemos": "tamborinar",
    "tamborinávamo": "tamborinar",
    "tamborinávamos": "tamborinar",
    "tamborináveis": "tamborinar",
    "tamboris": "tamboril",
    "tambos": "tambo",
    "tambuladeiras": "tambuladeira",
    "tambulas": "tambula",
    "tamburás": "tamburá",
    "tamearamas": "tamearama",
    "tameiras": "tameira",
    "tamiceira": "tamiceiro",
    "tamiceiras": "tamiceiro",
    "tamiceiros": "tamiceiro",
    "taminas": "tamina",
    "tamis": "tamil",
    "tamisa": "tamisar",
    "tamisada": "tamisar",
    "tamisadas": "tamisar",
    "tamisado": "tamisar",
    "tamisados": "tamisar",
    "tamisai": "tamisar",
    "tamisais": "tamisar",
    "tamisam": "tamisar",
    "tamisamo": "tamisar",
    "tamisamos": "tamisar",
    "tamisando": "tamisar",
    "tamisara": "tamisar",
    "tamisaram": "tamisar",
    "tamisaras": "tamisar",
    "tamisarde": "tamisar",
    "tamisardes": "tamisar",
    "tamisare": "tamisar",
    "tamisarei": "tamisar",
    "tamisareis": "tamisar",
    "tamisarem": "tamisar",
    "tamisaremos": "tamisar",
    "tamisares": "tamisar",
    "tamisaria": "tamisar",
    "tamisariam": "tamisar",
    "tamisarias": "tamisar",
    "tamisarmo": "tamisar",
    "tamisarmos": "tamisar",
    "tamisará": "tamisar",
    "tamisarás": "tamisar",
    "tamisarão": "tamisar",
    "tamisaríamos": "tamisar",
    "tamisaríeis": "tamisar",
    "tamisas": "tamisar",
    "tamisasse": "tamisar",
    "tamisassem": "tamisar",
    "tamisasses": "tamisar",
    "tamisaste": "tamisar",
    "tamisastes": "tamisar",
    "tamisava": "tamisar",
    "tamisavam": "tamisar",
    "tamisavas": "tamisar",
    "tamisações": "tamisação",
    "tamise": "tamisar",
    "tamisei": "tamisar",
    "tamiseis": "tamisar",
    "tamisem": "tamisar",
    "tamisemo": "tamisar",
    "tamisemos": "tamisar",
    "tamises": "tamisar",
    "tamiso": "tamisar",
    "tamisou": "tamisar",
    "tamisá": "tamisar",
    "tamisámo": "tamisar",
    "tamisámos": "tamisar",
    "tamisáramo": "tamisar",
    "tamisáramos": "tamisar",
    "tamisárei": "tamisar",
    "tamisáreis": "tamisar",
    "tamisásseis": "tamisar",
    "tamisássemos": "tamisar",
    "tamisávamo": "tamisar",
    "tamisávamos": "tamisar",
    "tamisávei": "tamisar",
    "tamisáveis": "tamisável",
    "tamiças": "tamiça",
    "tamoeiros": "tamoeiro",
    "tampa": "tampar",
    "tampada": "tampar",
    "tampadas": "tampar",
    "tampado": "tampar",
    "tampados": "tampar",
    "tampai": "tampar",
    "tampais": "tampar",
    "tampam": "tampar",
    "tampamo": "tampar",
    "tampamos": "tampar",
    "tampando": "tampar",
    "tampara": "tampar",
    "tamparam": "tampar",
    "tamparas": "tampar",
    "tamparde": "tampar",
    "tampardes": "tampar",
    "tampare": "tampar",
    "tamparei": "tampar",
    "tampareis": "tampar",
    "tamparem": "tampar",
    "tamparemos": "tampar",
    "tampares": "tampar",
    "tamparia": "tampar",
    "tampariam": "tampar",
    "tamparias": "tampar",
    "tamparmo": "tampar",
    "tamparmos": "tampar",
    "tampará": "tampar",
    "tamparás": "tampar",
    "tamparão": "tampar",
    "tamparíamos": "tampar",
    "tamparíeis": "tampar",
    "tampas": "tampar",
    "tampasse": "tampar",
    "tampassem": "tampar",
    "tampasses": "tampar",
    "tampaste": "tampar",
    "tampastes": "tampar",
    "tampava": "tampar",
    "tampavam": "tampar",
    "tampavas": "tampar",
    "tampe": "tampar",
    "tampei": "tampar",
    "tampeiras": "tampeira",
    "tampeis": "tampar",
    "tampem": "tampar",
    "tampemo": "tampar",
    "tampemos": "tampar",
    "tampes": "tampar",
    "tampinha": "tampa",
    "tampinhas": "tampa",
    "tampita": "tampa",
    "tampitas": "tampa",
    "tampo": "tampar",
    "tampona": "tamponar",
    "tamponada": "tamponar",
    "tamponadas": "tamponar",
    "tamponado": "tamponar",
    "tamponados": "tamponar",
    "tamponai": "tamponar",
    "tamponais": "tamponar",
    "tamponam": "tamponar",
    "tamponamentos": "tamponamento",
    "tamponamo": "tamponar",
    "tamponamos": "tamponar",
    "tamponando": "tamponar",
    "tamponara": "tamponar",
    "tamponaram": "tamponar",
    "tamponaras": "tamponar",
    "tamponarde": "tamponar",
    "tamponardes": "tamponar",
    "tamponare": "tamponar",
    "tamponarei": "tamponar",
    "tamponareis": "tamponar",
    "tamponarem": "tamponar",
    "tamponaremos": "tamponar",
    "tamponares": "tamponar",
    "tamponaria": "tamponar",
    "tamponariam": "tamponar",
    "tamponarias": "tamponar",
    "tamponarmo": "tamponar",
    "tamponarmos": "tamponar",
    "tamponará": "tamponar",
    "tamponarás": "tamponar",
    "tamponarão": "tamponar",
    "tamponaríamos": "tamponar",
    "tamponaríeis": "tamponar",
    "tamponas": "tamponar",
    "tamponasse": "tamponar",
    "tamponassem": "tamponar",
    "tamponasses": "tamponar",
    "tamponaste": "tamponar",
    "tamponastes": "tamponar",
    "tamponava": "tamponar",
    "tamponavam": "tamponar",
    "tamponavas": "tamponar",
    "tampone": "tamponar",
    "tamponei": "tamponar",
    "tamponeis": "tamponar",
    "tamponem": "tamponar",
    "tamponemo": "tamponar",
    "tamponemos": "tamponar",
    "tampones": "tamponar",
    "tampono": "tamponar",
    "tamponou": "tamponar",
    "tamponá": "tamponar",
    "tamponámo": "tamponar",
    "tamponámos": "tamponar",
    "tamponáramo": "tamponar",
    "tamponáramos": "tamponar",
    "tamponárei": "tamponar",
    "tamponáreis": "tamponar",
    "tamponásseis": "tamponar",
    "tamponássemos": "tamponar",
    "tamponávamo": "tamponar",
    "tamponávamos": "tamponar",
    "tamponávei": "tamponar",
    "tamponáveis": "tamponar",
    "tampores": "tampor",
    "tampos": "tampo",
    "tampou": "tampar",
    "tampá": "tampar",
    "tampámo": "tampar",
    "tampámos": "tampar",
    "tampáramo": "tampar",
    "tampáramos": "tampar",
    "tampárei": "tampar",
    "tampáreis": "tampar",
    "tampásseis": "tampar",
    "tampássemos": "tampar",
    "tampávamo": "tampar",
    "tampávamos": "tampar",
    "tampávei": "tampar",
    "tampáveis": "tampável",
    "tampões": "tampão",
    "tamujes": "tamuje",
    "tamujos": "tamujo",
    "tamungões": "tamungão",
    "tanacetos": "tanaceto",
    "tanada": "tanado",
    "tanadada": "tanadado",
    "tanadadas": "tanadado",
    "tanadados": "tanadado",
    "tanadarias": "tanadaria",
    "tanadas": "tanado",
    "tanados": "tanado",
    "tanadáveis": "tanadável",
    "tanagrídeos": "tanagrídeo",
    "tanatocenoses": "tanatocenose",
    "tanatofilias": "tanatofilia",
    "tanatofobias": "tanatofobia",
    "tanatologias": "tanatologia",
    "tanatomanias": "tanatomania",
    "tanatopsiquistas": "tanatopsiquista",
    "tanatormeias": "tanatormeia",
    "tanatómetros": "tanatómetro",
    "tanatós": "tanató",
    "tancareiras": "tancareira",
    "tancares": "tancar",
    "tancha": "tanchar",
    "tanchada": "tanchar",
    "tanchadas": "tanchar",
    "tanchado": "tanchar",
    "tanchados": "tanchar",
    "tanchagens": "tanchagem",
    "tanchai": "tanchar",
    "tanchais": "tanchar",
    "tancham": "tanchar",
    "tanchamo": "tanchar",
    "tanchamos": "tanchar",
    "tanchando": "tanchar",
    "tanchara": "tanchar",
    "tancharam": "tanchar",
    "tancharas": "tanchar",
    "tancharde": "tanchar",
    "tanchardes": "tanchar",
    "tanchare": "tanchar",
    "tancharei": "tanchar",
    "tanchareis": "tanchar",
    "tancharem": "tanchar",
    "tancharemos": "tanchar",
    "tanchares": "tanchar",
    "tancharia": "tanchar",
    "tanchariam": "tanchar",
    "tancharias": "tanchar",
    "tancharmo": "tanchar",
    "tancharmos": "tanchar",
    "tanchará": "tanchar",
    "tancharás": "tanchar",
    "tancharão": "tanchar",
    "tancharíamos": "tanchar",
    "tancharíeis": "tanchar",
    "tanchas": "tanchar",
    "tanchasse": "tanchar",
    "tanchassem": "tanchar",
    "tanchasses": "tanchar",
    "tanchaste": "tanchar",
    "tanchastes": "tanchar",
    "tanchava": "tanchar",
    "tanchavam": "tanchar",
    "tanchavas": "tanchar",
    "tanche": "tanchar",
    "tanchei": "tanchar",
    "tancheis": "tanchar",
    "tanchem": "tanchar",
    "tanchemo": "tanchar",
    "tanchemos": "tanchar",
    "tanches": "tanchar",
    "tancho": "tanchar",
    "tanchoais": "tanchoal",
    "tanchoeiras": "tanchoeira",
    "tanchou": "tanchar",
    "tanchá": "tanchar",
    "tanchámo": "tanchar",
    "tanchámos": "tanchar",
    "tancháramo": "tanchar",
    "tancháramos": "tanchar",
    "tanchárei": "tanchar",
    "tancháreis": "tanchar",
    "tanchásseis": "tanchar",
    "tanchássemos": "tanchar",
    "tanchávamo": "tanchar",
    "tanchávamos": "tanchar",
    "tanchávei": "tanchar",
    "tancháveis": "tanchável",
    "tanchões": "tanchão",
    "tancredos": "tancredo",
    "tancás": "tancá",
    "tandens": "tandem",
    "tanecos": "taneco",
    "tanetianos": "tanetiano",
    "tanga": "tangar",
    "tangada": "tangar",
    "tangadas": "tangar",
    "tangado": "tangar",
    "tangados": "tangar",
    "tangai": "tangar",
    "tangais": "tangar",
    "tangam": "tangar",
    "tangamo": "tangar",
    "tangamos": "tangar",
    "tangando": "tangar",
    "tanganheira": "tanganheiro",
    "tanganheiras": "tanganheiro",
    "tanganheiros": "tanganheiro",
    "tanganhos": "tanganho",
    "tanganhões": "tanganhão",
    "tanganins": "tanganim",
    "tangapemas": "tangapema",
    "tangara": "tangar",
    "tangaracás": "tangaracá",
    "tangaram": "tangar",
    "tangaras": "tangar",
    "tangarde": "tangar",
    "tangardes": "tangar",
    "tangare": "tangar",
    "tangarei": "tangar",
    "tangareis": "tangar",
    "tangarem": "tangar",
    "tangaremos": "tangar",
    "tangares": "tangar",
    "tangaria": "tangar",
    "tangariam": "tangar",
    "tangarias": "tangar",
    "tangarmo": "tangar",
    "tangarmos": "tangar",
    "tangará": "tangar",
    "tangarás": "tangará",
    "tangarão": "tangar",
    "tangaríamos": "tangar",
    "tangaríeis": "tangar",
    "tangas": "tangar",
    "tangasse": "tangar",
    "tangassem": "tangar",
    "tangasses": "tangar",
    "tangaste": "tangar",
    "tangastes": "tangar",
    "tangava": "tangar",
    "tangavam": "tangar",
    "tangavas": "tangar",
    "tange": "tanger",
    "tangedoiras": "tangedoira",
    "tangedoiros": "tangedoiro",
    "tangedora": "tangedor",
    "tangedoras": "tangedor",
    "tangedores": "tangedor",
    "tangedouras": "tangedoura",
    "tangedouros": "tangedouro",
    "tangei": "tanger",
    "tangeis": "tanger",
    "tangem": "tanger",
    "tangemo": "tanger",
    "tangemos": "tanger",
    "tangencia": "tangenciar",
    "tangenciada": "tangenciar",
    "tangenciadas": "tangenciar",
    "tangenciado": "tangenciar",
    "tangenciados": "tangenciar",
    "tangenciai": "tangenciar",
    "tangenciais": "tangenciar",
    "tangenciam": "tangenciar",
    "tangenciamo": "tangenciar",
    "tangenciamos": "tangenciar",
    "tangenciando": "tangenciar",
    "tangenciara": "tangenciar",
    "tangenciaram": "tangenciar",
    "tangenciaras": "tangenciar",
    "tangenciarde": "tangenciar",
    "tangenciardes": "tangenciar",
    "tangenciare": "tangenciar",
    "tangenciarei": "tangenciar",
    "tangenciareis": "tangenciar",
    "tangenciarem": "tangenciar",
    "tangenciaremos": "tangenciar",
    "tangenciares": "tangenciar",
    "tangenciaria": "tangenciar",
    "tangenciariam": "tangenciar",
    "tangenciarias": "tangenciar",
    "tangenciarmo": "tangenciar",
    "tangenciarmos": "tangenciar",
    "tangenciará": "tangenciar",
    "tangenciarás": "tangenciar",
    "tangenciarão": "tangenciar",
    "tangenciaríamos": "tangenciar",
    "tangenciaríeis": "tangenciar",
    "tangencias": "tangenciar",
    "tangenciasse": "tangenciar",
    "tangenciassem": "tangenciar",
    "tangenciasses": "tangenciar",
    "tangenciaste": "tangenciar",
    "tangenciastes": "tangenciar",
    "tangenciava": "tangenciar",
    "tangenciavam": "tangenciar",
    "tangenciavas": "tangenciar",
    "tangencie": "tangenciar",
    "tangenciei": "tangenciar",
    "tangencieis": "tangenciar",
    "tangenciem": "tangenciar",
    "tangenciemo": "tangenciar",
    "tangenciemos": "tangenciar",
    "tangencies": "tangenciar",
    "tangencio": "tangenciar",
    "tangenciou": "tangenciar",
    "tangenciá": "tangenciar",
    "tangenciámo": "tangenciar",
    "tangenciámos": "tangenciar",
    "tangenciáramo": "tangenciar",
    "tangenciáramos": "tangenciar",
    "tangenciárei": "tangenciar",
    "tangenciáreis": "tangenciar",
    "tangenciásseis": "tangenciar",
    "tangenciássemos": "tangenciar",
    "tangenciávamo": "tangenciar",
    "tangenciávamos": "tangenciar",
    "tangenciávei": "tangenciar",
    "tangenciáveis": "tangenciável",
    "tangendo": "tanger",
    "tangentes": "tangente",
    "tangera": "tanger",
    "tangeram": "tanger",
    "tangeras": "tanger",
    "tangerde": "tanger",
    "tangerdes": "tanger",
    "tangere": "tanger",
    "tangerei": "tanger",
    "tangereis": "tanger",
    "tangerem": "tanger",
    "tangeremos": "tanger",
    "tangeres": "tanger",
    "tangeria": "tanger",
    "tangeriam": "tanger",
    "tangerias": "tanger",
    "tangerina": "tangerino",
    "tangerinas": "tangerino",
    "tangerineiras": "tangerineira",
    "tangerinos": "tangerino",
    "tangermo": "tanger",
    "tangermos": "tanger",
    "tangerá": "tanger",
    "tangerás": "tanger",
    "tangerão": "tanger",
    "tangeríamos": "tanger",
    "tangeríeis": "tanger",
    "tanges": "tanger",
    "tangesse": "tanger",
    "tangessem": "tanger",
    "tangesses": "tanger",
    "tangeste": "tanger",
    "tangestes": "tanger",
    "tangeu": "tanger",
    "tangi": "tanger",
    "tangia": "tanger",
    "tangiam": "tanger",
    "tangias": "tanger",
    "tangibilidades": "tangibilidade",
    "tangida": "tangido",
    "tangidas": "tangido",
    "tangido": "tanger",
    "tangidos": "tangido",
    "tangidíssima": "tangido",
    "tangidíssimas": "tangido",
    "tangidíssimo": "tangido",
    "tangidíssimos": "tangido",
    "tanglomanglos": "tanglomanglo",
    "tango": "tangar",
    "tangos": "tango",
    "tangou": "tangar",
    "tangromangros": "tangromangro",
    "tangue": "tangar",
    "tangueada": "tanguear",
    "tangueadas": "tanguear",
    "tangueado": "tanguear",
    "tangueados": "tanguear",
    "tangueai": "tanguear",
    "tangueais": "tanguear",
    "tangueamo": "tanguear",
    "tangueamos": "tanguear",
    "tangueando": "tanguear",
    "tangueara": "tanguear",
    "tanguearam": "tanguear",
    "tanguearas": "tanguear",
    "tanguearde": "tanguear",
    "tangueardes": "tanguear",
    "tangueare": "tanguear",
    "tanguearei": "tanguear",
    "tangueareis": "tanguear",
    "tanguearem": "tanguear",
    "tanguearemos": "tanguear",
    "tangueares": "tanguear",
    "tanguearia": "tanguear",
    "tangueariam": "tanguear",
    "tanguearias": "tanguear",
    "tanguearmo": "tanguear",
    "tanguearmos": "tanguear",
    "tangueará": "tanguear",
    "tanguearás": "tanguear",
    "tanguearão": "tanguear",
    "tanguearíamos": "tanguear",
    "tanguearíeis": "tanguear",
    "tangueasse": "tanguear",
    "tangueassem": "tanguear",
    "tangueasses": "tanguear",
    "tangueaste": "tanguear",
    "tangueastes": "tanguear",
    "tangueava": "tanguear",
    "tangueavam": "tanguear",
    "tangueavas": "tanguear",
    "tangueei": "tanguear",
    "tangueeis": "tanguear",
    "tangueemo": "tanguear",
    "tangueemos": "tanguear",
    "tanguei": "tangar",
    "tangueia": "tanguear",
    "tangueiam": "tanguear",
    "tangueias": "tanguear",
    "tangueie": "tanguear",
    "tangueiem": "tanguear",
    "tangueies": "tanguear",
    "tangueio": "tanguear",
    "tangueira": "tangueiro",
    "tangueiras": "tangueiro",
    "tangueiros": "tangueiro",
    "tangueis": "tangar",
    "tanguem": "tangar",
    "tanguemo": "tangar",
    "tanguemos": "tangar",
    "tangueou": "tanguear",
    "tangues": "tangar",
    "tangueá": "tanguear",
    "tangueámo": "tanguear",
    "tangueámos": "tanguear",
    "tangueáramo": "tanguear",
    "tangueáramos": "tanguear",
    "tangueárei": "tanguear",
    "tangueáreis": "tanguear",
    "tangueásseis": "tanguear",
    "tangueássemos": "tanguear",
    "tangueávamo": "tanguear",
    "tangueávamos": "tanguear",
    "tangueávei": "tanguear",
    "tangueáveis": "tanguear",
    "tanguinha": "tanga",
    "tanguinhas": "tanga",
    "tanguistas": "tanguista",
    "tanguita": "tanga",
    "tanguitas": "tanga",
    "tangá": "tangar",
    "tangámo": "tangar",
    "tangámos": "tangar",
    "tangáramo": "tangar",
    "tangáramos": "tangar",
    "tangárei": "tangar",
    "tangáreis": "tangar",
    "tangásseis": "tangar",
    "tangássemos": "tangar",
    "tangávamo": "tangar",
    "tangávamos": "tangar",
    "tangávei": "tangar",
    "tangáveis": "tangável",
    "tangê": "tanger",
    "tangênciais": "tangêncial",
    "tangências": "tangência",
    "tangêramo": "tanger",
    "tangêramos": "tanger",
    "tangêrei": "tanger",
    "tangêreis": "tanger",
    "tangêsseis": "tanger",
    "tangêssemos": "tanger",
    "tangíamo": "tanger",
    "tangíamos": "tanger",
    "tangíei": "tanger",
    "tangíeis": "tanger",
    "tangíveis": "tangível",
    "tangões": "tangão",
    "tanhos": "tanho",
    "tanigénios": "tanigénio",
    "tanina": "taninar",
    "taninada": "taninar",
    "taninadas": "taninar",
    "taninado": "taninar",
    "taninados": "taninar",
    "taninai": "taninar",
    "taninais": "taninar",
    "taninam": "taninar",
    "taninamo": "taninar",
    "taninamos": "taninar",
    "taninando": "taninar",
    "taninara": "taninar",
    "taninaram": "taninar",
    "taninaras": "taninar",
    "taninarde": "taninar",
    "taninardes": "taninar",
    "taninare": "taninar",
    "taninarei": "taninar",
    "taninareis": "taninar",
    "taninarem": "taninar",
    "taninaremos": "taninar",
    "taninares": "taninar",
    "taninaria": "taninar",
    "taninariam": "taninar",
    "taninarias": "taninar",
    "taninarmo": "taninar",
    "taninarmos": "taninar",
    "taninará": "taninar",
    "taninarás": "taninar",
    "taninarão": "taninar",
    "taninaríamos": "taninar",
    "taninaríeis": "taninar",
    "taninas": "taninar",
    "taninasse": "taninar",
    "taninassem": "taninar",
    "taninasses": "taninar",
    "taninaste": "taninar",
    "taninastes": "taninar",
    "taninava": "taninar",
    "taninavam": "taninar",
    "taninavas": "taninar",
    "tanine": "taninar",
    "taninei": "taninar",
    "tanineis": "taninar",
    "taninem": "taninar",
    "taninemo": "taninar",
    "taninemos": "taninar",
    "tanines": "taninar",
    "tanino": "taninar",
    "taninos": "tanino",
    "taninosa": "taninoso",
    "taninosas": "taninoso",
    "taninosos": "taninoso",
    "taninou": "taninar",
    "taniná": "taninar",
    "taninámo": "taninar",
    "taninámos": "taninar",
    "tanináramo": "taninar",
    "tanináramos": "taninar",
    "taninárei": "taninar",
    "tanináreis": "taninar",
    "taninásseis": "taninar",
    "taninássemos": "taninar",
    "taninávamo": "taninar",
    "taninávamos": "taninar",
    "taninávei": "taninar",
    "tanináveis": "taninável",
    "tanis": "tani",
    "tanja": "tanger",
    "tanjais": "tanger",
    "tanjam": "tanger",
    "tanjamo": "tanger",
    "tanjamos": "tanger",
    "tanjardos": "tanjardo",
    "tanjarros": "tanjarro",
    "tanjas": "tanja",
    "tanjasnos": "tanjasno",
    "tanjerros": "tanjerro",
    "tanjo": "tanger",
    "tanjona": "tanjão",
    "tanjonas": "tanjão",
    "tanjões": "tanjão",
    "tanoa": "tanoar",
    "tanoada": "tanoar",
    "tanoadas": "tanoar",
    "tanoado": "tanoar",
    "tanoados": "tanoar",
    "tanoai": "tanoar",
    "tanoais": "tanoar",
    "tanoam": "tanoar",
    "tanoamo": "tanoar",
    "tanoamos": "tanoar",
    "tanoando": "tanoar",
    "tanoara": "tanoar",
    "tanoaram": "tanoar",
    "tanoaras": "tanoar",
    "tanoardes": "tanoar",
    "tanoarei": "tanoar",
    "tanoareis": "tanoar",
    "tanoarem": "tanoar",
    "tanoaremos": "tanoar",
    "tanoares": "tanoar",
    "tanoaria": "tanoar",
    "tanoariam": "tanoar",
    "tanoarias": "tanoaria",
    "tanoarmo": "tanoar",
    "tanoarmos": "tanoar",
    "tanoará": "tanoar",
    "tanoarás": "tanoar",
    "tanoarão": "tanoar",
    "tanoaríamos": "tanoar",
    "tanoaríeis": "tanoar",
    "tanoas": "tanoar",
    "tanoasse": "tanoar",
    "tanoassem": "tanoar",
    "tanoasses": "tanoar",
    "tanoaste": "tanoar",
    "tanoastes": "tanoar",
    "tanoava": "tanoar",
    "tanoavam": "tanoar",
    "tanoavas": "tanoar",
    "tanoclarímetros": "tanoclarímetro",
    "tanoe": "tanoar",
    "tanoei": "tanoar",
    "tanoeira": "tanoeiro",
    "tanoeiras": "tanoeiro",
    "tanoeiros": "tanoeiro",
    "tanoeis": "tanoar",
    "tanoem": "tanoar",
    "tanoemo": "tanoar",
    "tanoemos": "tanoar",
    "tanoes": "tanoar",
    "tanofórmios": "tanofórmio",
    "tanoo": "tanoar",
    "tanoou": "tanoar",
    "tanoámo": "tanoar",
    "tanoámos": "tanoar",
    "tanoáramo": "tanoar",
    "tanoáramos": "tanoar",
    "tanoáreis": "tanoar",
    "tanoásseis": "tanoar",
    "tanoássemos": "tanoar",
    "tanoávamo": "tanoar",
    "tanoávamos": "tanoar",
    "tanoáveis": "tanoar",
    "tanques": "tanque",
    "tanquezinho": "tanque",
    "tanquezinhos": "tanque",
    "tanquezito": "tanque",
    "tanquezitos": "tanque",
    "tansa": "tanso",
    "tansas": "tanso",
    "tansazinha": "tanso",
    "tansazinhas": "tanso",
    "tansazita": "tanso",
    "tansazitas": "tanso",
    "tanseiras": "tanseira",
    "tansinha": "tanso",
    "tansinhas": "tanso",
    "tansinho": "tanso",
    "tansinhos": "tanso",
    "tansita": "tanso",
    "tansitas": "tanso",
    "tansito": "tanso",
    "tansitos": "tanso",
    "tansos": "tanso",
    "tansozinho": "tanso",
    "tansozinhos": "tanso",
    "tansozito": "tanso",
    "tansozitos": "tanso",
    "tanta": "tanto",
    "tantalites": "tantalite",
    "tantaliza": "tantalizar",
    "tantalizada": "tantalizar",
    "tantalizadas": "tantalizar",
    "tantalizado": "tantalizar",
    "tantalizados": "tantalizar",
    "tantalizai": "tantalizar",
    "tantalizais": "tantalizar",
    "tantalizam": "tantalizar",
    "tantalizamo": "tantalizar",
    "tantalizamos": "tantalizar",
    "tantalizando": "tantalizar",
    "tantalizara": "tantalizar",
    "tantalizaram": "tantalizar",
    "tantalizaras": "tantalizar",
    "tantalizarde": "tantalizar",
    "tantalizardes": "tantalizar",
    "tantalizare": "tantalizar",
    "tantalizarei": "tantalizar",
    "tantalizareis": "tantalizar",
    "tantalizarem": "tantalizar",
    "tantalizaremos": "tantalizar",
    "tantalizares": "tantalizar",
    "tantalizaria": "tantalizar",
    "tantalizariam": "tantalizar",
    "tantalizarias": "tantalizar",
    "tantalizarmo": "tantalizar",
    "tantalizarmos": "tantalizar",
    "tantalizará": "tantalizar",
    "tantalizarás": "tantalizar",
    "tantalizarão": "tantalizar",
    "tantalizaríamos": "tantalizar",
    "tantalizaríeis": "tantalizar",
    "tantalizas": "tantalizar",
    "tantalizasse": "tantalizar",
    "tantalizassem": "tantalizar",
    "tantalizasses": "tantalizar",
    "tantalizaste": "tantalizar",
    "tantalizastes": "tantalizar",
    "tantalizava": "tantalizar",
    "tantalizavam": "tantalizar",
    "tantalizavas": "tantalizar",
    "tantalizações": "tantalização",
    "tantalize": "tantalizar",
    "tantalizei": "tantalizar",
    "tantalizeis": "tantalizar",
    "tantalizem": "tantalizar",
    "tantalizemo": "tantalizar",
    "tantalizemos": "tantalizar",
    "tantalizes": "tantalizar",
    "tantalizo": "tantalizar",
    "tantalizou": "tantalizar",
    "tantalizá": "tantalizar",
    "tantalizámo": "tantalizar",
    "tantalizámos": "tantalizar",
    "tantalizáramo": "tantalizar",
    "tantalizáramos": "tantalizar",
    "tantalizárei": "tantalizar",
    "tantalizáreis": "tantalizar",
    "tantalizásseis": "tantalizar",
    "tantalizássemos": "tantalizar",
    "tantalizávamo": "tantalizar",
    "tantalizávamos": "tantalizar",
    "tantalizávei": "tantalizar",
    "tantalizáveis": "tantalizável",
    "tantanguês": "tantanguê",
    "tantas": "tanto",
    "tantos": "tanto",
    "tantras": "tantra",
    "tantálica": "tantálico",
    "tantálicas": "tantálico",
    "tantálicos": "tantálico",
    "tantãs": "tantã",
    "tantíssimo": "tanto",
    "tanzaniana": "tanzaniano",
    "tanzanianas": "tanzaniano",
    "tanzanianos": "tanzaniano",
    "tanásias": "tanásia",
    "tapa": "tapar",
    "tapada": "tapar",
    "tapadas": "tapar",
    "tapadazinha": "tapado",
    "tapadazinhas": "tapado",
    "tapadazita": "tapado",
    "tapadazitas": "tapado",
    "tapadeiras": "tapadeira",
    "tapadinha": "tapado",
    "tapadinhas": "tapado",
    "tapadinho": "tapado",
    "tapadinhos": "tapado",
    "tapadita": "tapado",
    "tapaditas": "tapado",
    "tapadito": "tapado",
    "tapaditos": "tapado",
    "tapado": "tapar",
    "tapadoiras": "tapadoira",
    "tapadoiros": "tapadoiro",
    "tapadona": "tapado",
    "tapadonas": "tapado",
    "tapadora": "tapador",
    "tapadoras": "tapador",
    "tapadores": "tapador",
    "tapados": "tapar",
    "tapadouras": "tapadoura",
    "tapadouros": "tapadouro",
    "tapadozinho": "tapado",
    "tapadozinhos": "tapado",
    "tapadozito": "tapado",
    "tapadozitos": "tapado",
    "tapaduras": "tapadura",
    "tapadão": "tapado",
    "tapadíssima": "tapado",
    "tapadíssimas": "tapado",
    "tapadíssimo": "tapado",
    "tapadíssimos": "tapado",
    "tapadões": "tapado",
    "tapagens": "tapagem",
    "tapai": "tapar",
    "tapais": "tapar",
    "tapajós": "tapajó",
    "tapam": "tapar",
    "tapamentos": "tapamento",
    "tapamo": "tapar",
    "tapamos": "tapar",
    "tapando": "tapar",
    "tapara": "tapar",
    "taparam": "tapar",
    "taparas": "tapar",
    "taparde": "tapar",
    "tapardes": "tapar",
    "tapare": "tapar",
    "taparei": "tapar",
    "tapareis": "tapar",
    "taparem": "tapar",
    "taparemos": "tapar",
    "tapares": "tapar",
    "taparia": "tapar",
    "tapariam": "tapar",
    "taparias": "tapar",
    "taparmo": "tapar",
    "taparmos": "tapar",
    "tapará": "tapar",
    "taparás": "tapar",
    "taparão": "tapar",
    "taparíamos": "tapar",
    "taparíeis": "tapar",
    "tapas": "tapar",
    "tapasse": "tapar",
    "tapassem": "tapar",
    "tapasses": "tapar",
    "tapaste": "tapar",
    "tapastes": "tapar",
    "tapava": "tapar",
    "tapavam": "tapar",
    "tapavas": "tapar",
    "tape": "tapar",
    "tapeada": "tapear",
    "tapeadas": "tapear",
    "tapeado": "tapear",
    "tapeados": "tapear",
    "tapeai": "tapear",
    "tapeais": "tapear",
    "tapeamo": "tapear",
    "tapeamos": "tapear",
    "tapeando": "tapear",
    "tapeara": "tapear",
    "tapearam": "tapear",
    "tapearas": "tapear",
    "tapearde": "tapear",
    "tapeardes": "tapear",
    "tapeare": "tapear",
    "tapearei": "tapear",
    "tapeareis": "tapear",
    "tapearem": "tapear",
    "tapearemos": "tapear",
    "tapeares": "tapear",
    "tapearia": "tapear",
    "tapeariam": "tapear",
    "tapearias": "tapear",
    "tapearmo": "tapear",
    "tapearmos": "tapear",
    "tapeará": "tapear",
    "tapearás": "tapear",
    "tapearão": "tapear",
    "tapearíamos": "tapear",
    "tapearíeis": "tapear",
    "tapeasse": "tapear",
    "tapeassem": "tapear",
    "tapeasses": "tapear",
    "tapeaste": "tapear",
    "tapeastes": "tapear",
    "tapeava": "tapear",
    "tapeavam": "tapear",
    "tapeavas": "tapear",
    "tapeações": "tapeação",
    "tapece": "tapeçar",
    "tapecei": "tapeçar",
    "tapeceira": "tapeceiro",
    "tapeceiras": "tapeceiro",
    "tapeceiros": "tapeceiro",
    "tapeceis": "tapeçar",
    "tapecem": "tapeçar",
    "tapecemo": "tapeçar",
    "tapecemos": "tapeçar",
    "tapeces": "tapeçar",
    "tapeei": "tapear",
    "tapeeis": "tapear",
    "tapeemo": "tapear",
    "tapeemos": "tapear",
    "tapei": "tapar",
    "tapeia": "tapear",
    "tapeiam": "tapear",
    "tapeias": "tapear",
    "tapeie": "tapear",
    "tapeiem": "tapear",
    "tapeies": "tapear",
    "tapeio": "tapear",
    "tapeis": "tapar",
    "tapem": "tapar",
    "tapemo": "tapar",
    "tapemos": "tapar",
    "tapeou": "tapear",
    "taperas": "tapera",
    "taperás": "taperá",
    "tapes": "tapar",
    "tapeta": "tapetar",
    "tapetada": "tapetar",
    "tapetadas": "tapetar",
    "tapetado": "tapetar",
    "tapetados": "tapetar",
    "tapetai": "tapetar",
    "tapetais": "tapetar",
    "tapetam": "tapetar",
    "tapetamo": "tapetar",
    "tapetamos": "tapetar",
    "tapetando": "tapetar",
    "tapetara": "tapetar",
    "tapetaram": "tapetar",
    "tapetaras": "tapetar",
    "tapetarde": "tapetar",
    "tapetardes": "tapetar",
    "tapetare": "tapetar",
    "tapetarei": "tapetar",
    "tapetareis": "tapetar",
    "tapetarem": "tapetar",
    "tapetaremos": "tapetar",
    "tapetares": "tapetar",
    "tapetaria": "tapetar",
    "tapetariam": "tapetar",
    "tapetarias": "tapetar",
    "tapetarmo": "tapetar",
    "tapetarmos": "tapetar",
    "tapetará": "tapetar",
    "tapetarás": "tapetar",
    "tapetarão": "tapetar",
    "tapetaríamos": "tapetar",
    "tapetaríeis": "tapetar",
    "tapetas": "tapetar",
    "tapetasse": "tapetar",
    "tapetassem": "tapetar",
    "tapetasses": "tapetar",
    "tapetaste": "tapetar",
    "tapetastes": "tapetar",
    "tapetava": "tapetar",
    "tapetavam": "tapetar",
    "tapetavas": "tapetar",
    "tapete": "tapetar",
    "tapetei": "tapetar",
    "tapeteira": "tapeteiro",
    "tapeteiras": "tapeteiro",
    "tapeteiros": "tapeteiro",
    "tapeteis": "tapetar",
    "tapetem": "tapetar",
    "tapetemo": "tapetar",
    "tapetemos": "tapetar",
    "tapetes": "tapete",
    "tapetinho": "tapete",
    "tapetinhos": "tapete",
    "tapetito": "tapete",
    "tapetitos": "tapete",
    "tapeto": "tapetar",
    "tapetou": "tapetar",
    "tapetá": "tapetar",
    "tapetámo": "tapetar",
    "tapetámos": "tapetar",
    "tapetáramo": "tapetar",
    "tapetáramos": "tapetar",
    "tapetárei": "tapetar",
    "tapetáreis": "tapetar",
    "tapetásseis": "tapetar",
    "tapetássemos": "tapetar",
    "tapetávamo": "tapetar",
    "tapetávamos": "tapetar",
    "tapetávei": "tapetar",
    "tapetáveis": "tapetável",
    "tapeá": "tapear",
    "tapeámo": "tapear",
    "tapeámos": "tapear",
    "tapeáramo": "tapear",
    "tapeáramos": "tapear",
    "tapeárei": "tapear",
    "tapeáreis": "tapear",
    "tapeásseis": "tapear",
    "tapeássemos": "tapear",
    "tapeávamo": "tapear",
    "tapeávamos": "tapear",
    "tapeávei": "tapear",
    "tapeáveis": "tapeável",
    "tapeça": "tapeçar",
    "tapeçada": "tapeçar",
    "tapeçadas": "tapeçar",
    "tapeçado": "tapeçar",
    "tapeçados": "tapeçar",
    "tapeçai": "tapeçar",
    "tapeçais": "tapeçar",
    "tapeçam": "tapeçar",
    "tapeçamo": "tapeçar",
    "tapeçamos": "tapeçar",
    "tapeçando": "tapeçar",
    "tapeçara": "tapeçar",
    "tapeçaram": "tapeçar",
    "tapeçaras": "tapeçar",
    "tapeçarde": "tapeçar",
    "tapeçardes": "tapeçar",
    "tapeçare": "tapeçar",
    "tapeçarei": "tapeçar",
    "tapeçareis": "tapeçar",
    "tapeçarem": "tapeçar",
    "tapeçaremos": "tapeçar",
    "tapeçares": "tapeçar",
    "tapeçaria": "tapeçar",
    "tapeçariam": "tapeçar",
    "tapeçarias": "tapeçaria",
    "tapeçarmo": "tapeçar",
    "tapeçarmos": "tapeçar",
    "tapeçará": "tapeçar",
    "tapeçarás": "tapeçar",
    "tapeçarão": "tapeçar",
    "tapeçaríamos": "tapeçar",
    "tapeçaríeis": "tapeçar",
    "tapeças": "tapeçar",
    "tapeçasse": "tapeçar",
    "tapeçassem": "tapeçar",
    "tapeçasses": "tapeçar",
    "tapeçaste": "tapeçar",
    "tapeçastes": "tapeçar",
    "tapeçava": "tapeçar",
    "tapeçavam": "tapeçar",
    "tapeçavas": "tapeçar",
    "tapeço": "tapeçar",
    "tapeçou": "tapeçar",
    "tapeçá": "tapeçar",
    "tapeçámo": "tapeçar",
    "tapeçámos": "tapeçar",
    "tapeçáramo": "tapeçar",
    "tapeçáramos": "tapeçar",
    "tapeçárei": "tapeçar",
    "tapeçáreis": "tapeçar",
    "tapeçásseis": "tapeçar",
    "tapeçássemos": "tapeçar",
    "tapeçávamo": "tapeçar",
    "tapeçávamos": "tapeçar",
    "tapeçávei": "tapeçar",
    "tapeçáveis": "tapeçável",
    "tapicuris": "tapicuri",
    "tapicurus": "tapicuru",
    "tapigos": "tapigo",
    "tapiocas": "tapioca",
    "tapiras": "tapira",
    "tapires": "tapir",
    "tapiribas": "tapiriba",
    "tapiros": "tapiro",
    "tapirídeos": "tapirídeo",
    "tapisas": "tapisa",
    "tapiza": "tapizar",
    "tapizada": "tapizar",
    "tapizadas": "tapizar",
    "tapizado": "tapizar",
    "tapizados": "tapizar",
    "tapizai": "tapizar",
    "tapizais": "tapizar",
    "tapizam": "tapizar",
    "tapizamo": "tapizar",
    "tapizamos": "tapizar",
    "tapizando": "tapizar",
    "tapizara": "tapizar",
    "tapizaram": "tapizar",
    "tapizaras": "tapizar",
    "tapizarde": "tapizar",
    "tapizardes": "tapizar",
    "tapizare": "tapizar",
    "tapizarei": "tapizar",
    "tapizareis": "tapizar",
    "tapizarem": "tapizar",
    "tapizaremos": "tapizar",
    "tapizares": "tapizar",
    "tapizaria": "tapizar",
    "tapizariam": "tapizar",
    "tapizarias": "tapizar",
    "tapizarmo": "tapizar",
    "tapizarmos": "tapizar",
    "tapizará": "tapizar",
    "tapizarás": "tapizar",
    "tapizarão": "tapizar",
    "tapizaríamos": "tapizar",
    "tapizaríeis": "tapizar",
    "tapizas": "tapizar",
    "tapizasse": "tapizar",
    "tapizassem": "tapizar",
    "tapizasses": "tapizar",
    "tapizaste": "tapizar",
    "tapizastes": "tapizar",
    "tapizava": "tapizar",
    "tapizavam": "tapizar",
    "tapizavas": "tapizar",
    "tapize": "tapizar",
    "tapizei": "tapizar",
    "tapizeis": "tapizar",
    "tapizem": "tapizar",
    "tapizemo": "tapizar",
    "tapizemos": "tapizar",
    "tapizes": "tapizar",
    "tapizo": "tapizar",
    "tapizou": "tapizar",
    "tapizá": "tapizar",
    "tapizámo": "tapizar",
    "tapizámos": "tapizar",
    "tapizáramo": "tapizar",
    "tapizáramos": "tapizar",
    "tapizárei": "tapizar",
    "tapizáreis": "tapizar",
    "tapizásseis": "tapizar",
    "tapizássemos": "tapizar",
    "tapizávamo": "tapizar",
    "tapizávamos": "tapizar",
    "tapizávei": "tapizar",
    "tapizáveis": "tapizável",
    "tapiás": "tapiá",
    "tapiços": "tapiço",
    "tapo": "tapar",
    "taponas": "tapona",
    "tapos": "tapo",
    "tapou": "tapar",
    "tapuas": "tapua",
    "tapuia": "tapuio",
    "tapuias": "tapuio",
    "tapuios": "tapuio",
    "tapulha": "tapulhar",
    "tapulhada": "tapulhar",
    "tapulhadas": "tapulhar",
    "tapulhado": "tapulhar",
    "tapulhados": "tapulhar",
    "tapulhai": "tapulhar",
    "tapulhais": "tapulhar",
    "tapulham": "tapulhar",
    "tapulhamo": "tapulhar",
    "tapulhamos": "tapulhar",
    "tapulhando": "tapulhar",
    "tapulhara": "tapulhar",
    "tapulharam": "tapulhar",
    "tapulharas": "tapulhar",
    "tapulharde": "tapulhar",
    "tapulhardes": "tapulhar",
    "tapulhare": "tapulhar",
    "tapulharei": "tapulhar",
    "tapulhareis": "tapulhar",
    "tapulharem": "tapulhar",
    "tapulharemos": "tapulhar",
    "tapulhares": "tapulhar",
    "tapulharia": "tapulhar",
    "tapulhariam": "tapulhar",
    "tapulharias": "tapulhar",
    "tapulharmo": "tapulhar",
    "tapulharmos": "tapulhar",
    "tapulhará": "tapulhar",
    "tapulharás": "tapulhar",
    "tapulharão": "tapulhar",
    "tapulharíamos": "tapulhar",
    "tapulharíeis": "tapulhar",
    "tapulhas": "tapulhar",
    "tapulhasse": "tapulhar",
    "tapulhassem": "tapulhar",
    "tapulhasses": "tapulhar",
    "tapulhaste": "tapulhar",
    "tapulhastes": "tapulhar",
    "tapulhava": "tapulhar",
    "tapulhavam": "tapulhar",
    "tapulhavas": "tapulhar",
    "tapulhe": "tapulhar",
    "tapulhei": "tapulhar",
    "tapulheis": "tapulhar",
    "tapulhem": "tapulhar",
    "tapulhemo": "tapulhar",
    "tapulhemos": "tapulhar",
    "tapulhes": "tapulhar",
    "tapulho": "tapulhar",
    "tapulhos": "tapulho",
    "tapulhou": "tapulhar",
    "tapulhá": "tapulhar",
    "tapulhámo": "tapulhar",
    "tapulhámos": "tapulhar",
    "tapulháramo": "tapulhar",
    "tapulháramos": "tapulhar",
    "tapulhárei": "tapulhar",
    "tapulháreis": "tapulhar",
    "tapulhásseis": "tapulhar",
    "tapulhássemos": "tapulhar",
    "tapulhávamo": "tapulhar",
    "tapulhávamos": "tapulhar",
    "tapulhávei": "tapulhar",
    "tapulháveis": "tapulhável",
    "tapumes": "tapume",
    "tapá": "tapar",
    "tapámo": "tapar",
    "tapámos": "tapar",
    "tapáramo": "tapar",
    "tapáramos": "tapar",
    "tapárei": "tapar",
    "tapáreis": "tapar",
    "tapásseis": "tapar",
    "tapássemos": "tapar",
    "tapávamo": "tapar",
    "tapávamos": "tapar",
    "tapávei": "tapar",
    "tapáveis": "tapável",
    "tapíridas": "tapírida",
    "taquarais": "taquaral",
    "taquaras": "taquara",
    "taquaris": "taquari",
    "taque": "tacar",
    "taquei": "tacar",
    "taqueiras": "taqueira",
    "taqueis": "tacar",
    "taquem": "tacar",
    "taquemos": "tacar",
    "taqueometrias": "taqueometria",
    "taques": "taque",
    "taquetaques": "taquetaque",
    "taqueógrafos": "taqueógrafo",
    "taqueómetros": "taqueómetro",
    "taquicardias": "taquicardia",
    "taquicardíaca": "taquicardíaco",
    "taquicardíacas": "taquicardíaco",
    "taquicardíacos": "taquicardíaco",
    "taquigrafa": "taquigrafar",
    "taquigrafada": "taquigrafar",
    "taquigrafadas": "taquigrafar",
    "taquigrafado": "taquigrafar",
    "taquigrafados": "taquigrafar",
    "taquigrafai": "taquigrafar",
    "taquigrafais": "taquigrafar",
    "taquigrafam": "taquigrafar",
    "taquigrafamo": "taquigrafar",
    "taquigrafamos": "taquigrafar",
    "taquigrafando": "taquigrafar",
    "taquigrafara": "taquigrafar",
    "taquigrafaram": "taquigrafar",
    "taquigrafaras": "taquigrafar",
    "taquigrafarde": "taquigrafar",
    "taquigrafardes": "taquigrafar",
    "taquigrafare": "taquigrafar",
    "taquigrafarei": "taquigrafar",
    "taquigrafareis": "taquigrafar",
    "taquigrafarem": "taquigrafar",
    "taquigrafaremos": "taquigrafar",
    "taquigrafares": "taquigrafar",
    "taquigrafaria": "taquigrafar",
    "taquigrafariam": "taquigrafar",
    "taquigrafarias": "taquigrafar",
    "taquigrafarmo": "taquigrafar",
    "taquigrafarmos": "taquigrafar",
    "taquigrafará": "taquigrafar",
    "taquigrafarás": "taquigrafar",
    "taquigrafarão": "taquigrafar",
    "taquigrafaríamos": "taquigrafar",
    "taquigrafaríeis": "taquigrafar",
    "taquigrafas": "taquigrafar",
    "taquigrafasse": "taquigrafar",
    "taquigrafassem": "taquigrafar",
    "taquigrafasses": "taquigrafar",
    "taquigrafaste": "taquigrafar",
    "taquigrafastes": "taquigrafar",
    "taquigrafava": "taquigrafar",
    "taquigrafavam": "taquigrafar",
    "taquigrafavas": "taquigrafar",
    "taquigrafe": "taquigrafar",
    "taquigrafei": "taquigrafar",
    "taquigrafeis": "taquigrafar",
    "taquigrafem": "taquigrafar",
    "taquigrafemo": "taquigrafar",
    "taquigrafemos": "taquigrafar",
    "taquigrafes": "taquigrafar",
    "taquigrafias": "taquigrafia",
    "taquigrafo": "taquigrafar",
    "taquigrafou": "taquigrafar",
    "taquigrafá": "taquigrafar",
    "taquigrafámo": "taquigrafar",
    "taquigrafámos": "taquigrafar",
    "taquigrafáramo": "taquigrafar",
    "taquigrafáramos": "taquigrafar",
    "taquigrafárei": "taquigrafar",
    "taquigrafáreis": "taquigrafar",
    "taquigrafásseis": "taquigrafar",
    "taquigrafássemos": "taquigrafar",
    "taquigrafávamo": "taquigrafar",
    "taquigrafávamos": "taquigrafar",
    "taquigrafávei": "taquigrafar",
    "taquigrafáveis": "taquigrafável",
    "taquigráfica": "taquigráfico",
    "taquigráficas": "taquigráfico",
    "taquigráficos": "taquigráfico",
    "taquigéneses": "taquigénese",
    "taquilalias": "taquilalia",
    "taquilhas": "taquilha",
    "taquipsiquias": "taquipsiquia",
    "taquígrafa": "taquígrafo",
    "taquígrafas": "taquígrafo",
    "taquígrafos": "taquígrafo",
    "taquímetros": "taquímetro",
    "tara": "tarar",
    "tarada": "tarar",
    "taradas": "tarar",
    "taradinha": "tarado",
    "taradinhas": "tarado",
    "taradinho": "tarado",
    "taradinhos": "tarado",
    "taradita": "tarado",
    "taraditas": "tarado",
    "taradito": "tarado",
    "taraditos": "tarado",
    "tarado": "tarar",
    "tarados": "tarar",
    "taradíssima": "tarado",
    "taradíssimas": "tarado",
    "taradíssimo": "tarado",
    "taradíssimos": "tarado",
    "tarai": "tarar",
    "tarais": "tarar",
    "taralha": "taralhar",
    "taralhada": "taralhar",
    "taralhadas": "taralhar",
    "taralhado": "taralhar",
    "taralhados": "taralhar",
    "taralhai": "taralhar",
    "taralhais": "taralhar",
    "taralham": "taralhar",
    "taralhamo": "taralhar",
    "taralhamos": "taralhar",
    "taralhando": "taralhar",
    "taralhara": "taralhar",
    "taralharam": "taralhar",
    "taralharas": "taralhar",
    "taralhardes": "taralhar",
    "taralharei": "taralhar",
    "taralhareis": "taralhar",
    "taralharem": "taralhar",
    "taralharemos": "taralhar",
    "taralhares": "taralhar",
    "taralharia": "taralhar",
    "taralhariam": "taralhar",
    "taralharias": "taralhar",
    "taralharmo": "taralhar",
    "taralharmos": "taralhar",
    "taralhará": "taralhar",
    "taralharás": "taralhar",
    "taralharão": "taralhar",
    "taralharíamos": "taralhar",
    "taralharíeis": "taralhar",
    "taralhas": "taralhar",
    "taralhasse": "taralhar",
    "taralhassem": "taralhar",
    "taralhasses": "taralhar",
    "taralhaste": "taralhar",
    "taralhastes": "taralhar",
    "taralhava": "taralhar",
    "taralhavam": "taralhar",
    "taralhavas": "taralhar",
    "taralhe": "taralhar",
    "taralhei": "taralhar",
    "taralheiras": "taralheira",
    "taralheis": "taralhar",
    "taralhem": "taralhar",
    "taralhemo": "taralhar",
    "taralhemos": "taralhar",
    "taralhes": "taralhar",
    "taralho": "taralhar",
    "taralhoeiras": "taralhoeira",
    "taralhou": "taralhar",
    "taralhámo": "taralhar",
    "taralhámos": "taralhar",
    "taralháramo": "taralhar",
    "taralháramos": "taralhar",
    "taralháreis": "taralhar",
    "taralhásseis": "taralhar",
    "taralhássemos": "taralhar",
    "taralhávamo": "taralhar",
    "taralhávamos": "taralhar",
    "taralháveis": "taralhar",
    "taralhões": "taralhão",
    "taram": "tarar",
    "tarambecos": "tarambeco",
    "tarambolas": "tarambola",
    "tarambotes": "tarambote",
    "taramela": "taramelar",
    "taramelada": "taramelar",
    "tarameladas": "taramelar",
    "taramelado": "taramelar",
    "taramelados": "taramelar",
    "taramelagens": "taramelagem",
    "taramelai": "taramelar",
    "taramelais": "taramelar",
    "taramelam": "taramelar",
    "taramelamo": "taramelar",
    "taramelamos": "taramelar",
    "taramelando": "taramelar",
    "taramelara": "taramelar",
    "taramelaram": "taramelar",
    "taramelaras": "taramelar",
    "taramelarde": "taramelar",
    "taramelardes": "taramelar",
    "taramelare": "taramelar",
    "taramelarei": "taramelar",
    "taramelareis": "taramelar",
    "taramelarem": "taramelar",
    "taramelaremos": "taramelar",
    "taramelares": "taramelar",
    "taramelaria": "taramelar",
    "taramelariam": "taramelar",
    "taramelarias": "taramelar",
    "taramelarmo": "taramelar",
    "taramelarmos": "taramelar",
    "taramelará": "taramelar",
    "taramelarás": "taramelar",
    "taramelarão": "taramelar",
    "taramelaríamos": "taramelar",
    "taramelaríeis": "taramelar",
    "taramelas": "taramelar",
    "taramelasse": "taramelar",
    "taramelassem": "taramelar",
    "taramelasses": "taramelar",
    "taramelaste": "taramelar",
    "taramelastes": "taramelar",
    "taramelava": "taramelar",
    "taramelavam": "taramelar",
    "taramelavas": "taramelar",
    "taramele": "taramelar",
    "tarameleada": "taramelear",
    "tarameleadas": "taramelear",
    "tarameleado": "taramelear",
    "tarameleados": "taramelear",
    "tarameleai": "taramelear",
    "tarameleais": "taramelear",
    "tarameleamo": "taramelear",
    "tarameleamos": "taramelear",
    "tarameleando": "taramelear",
    "tarameleara": "taramelear",
    "taramelearam": "taramelear",
    "taramelearas": "taramelear",
    "tarameleardes": "taramelear",
    "taramelearei": "taramelear",
    "tarameleareis": "taramelear",
    "taramelearem": "taramelear",
    "taramelearemos": "taramelear",
    "tarameleares": "taramelear",
    "taramelearia": "taramelear",
    "tarameleariam": "taramelear",
    "taramelearias": "taramelear",
    "taramelearmo": "taramelear",
    "taramelearmos": "taramelear",
    "tarameleará": "taramelear",
    "taramelearás": "taramelear",
    "taramelearão": "taramelear",
    "taramelearíamos": "taramelear",
    "taramelearíeis": "taramelear",
    "tarameleasse": "taramelear",
    "tarameleassem": "taramelear",
    "tarameleasses": "taramelear",
    "tarameleaste": "taramelear",
    "tarameleastes": "taramelear",
    "tarameleava": "taramelear",
    "tarameleavam": "taramelear",
    "tarameleavas": "taramelear",
    "tarameleei": "taramelear",
    "tarameleeis": "taramelear",
    "tarameleemo": "taramelear",
    "tarameleemos": "taramelear",
    "taramelei": "taramelar",
    "tarameleia": "taramelear",
    "tarameleiam": "taramelear",
    "tarameleias": "taramelear",
    "tarameleie": "taramelear",
    "tarameleiem": "taramelear",
    "tarameleies": "taramelear",
    "tarameleio": "taramelear",
    "tarameleira": "tarameleiro",
    "tarameleiras": "tarameleiro",
    "tarameleiros": "tarameleiro",
    "tarameleis": "taramelar",
    "taramelem": "taramelar",
    "taramelemo": "taramelar",
    "taramelemos": "taramelar",
    "tarameleou": "taramelear",
    "tarameles": "taramelar",
    "tarameleámo": "taramelear",
    "tarameleámos": "taramelear",
    "tarameleáramo": "taramelear",
    "tarameleáramos": "taramelear",
    "tarameleáreis": "taramelear",
    "tarameleásseis": "taramelear",
    "tarameleássemos": "taramelear",
    "tarameleávamo": "taramelear",
    "tarameleávamos": "taramelear",
    "tarameleáveis": "taramelear",
    "taramelices": "taramelice",
    "taramelo": "taramelar",
    "taramelos": "taramelo",
    "taramelou": "taramelar",
    "taramelá": "taramelar",
    "taramelámo": "taramelar",
    "taramelámos": "taramelar",
    "tarameláramo": "taramelar",
    "tarameláramos": "taramelar",
    "taramelárei": "taramelar",
    "tarameláreis": "taramelar",
    "taramelásseis": "taramelar",
    "taramelássemos": "taramelar",
    "taramelávamo": "taramelar",
    "taramelávamos": "taramelar",
    "taramelávei": "taramelar",
    "tarameláveis": "taramelar",
    "taramo": "tarar",
    "taramos": "tarar",
    "tarampabos": "tarampabo",
    "tarampantões": "tarampantão",
    "taramás": "taramá",
    "tarando": "tarar",
    "tarantantãs": "tarantantã",
    "tarantas": "taranta",
    "tarantelas": "tarantela",
    "tarantismos": "tarantismo",
    "tarantulismos": "tarantulismo",
    "tarapantões": "tarapantão",
    "tarara": "tarar",
    "tararam": "tarar",
    "tararas": "tarara",
    "tararde": "tarar",
    "tarardes": "tarar",
    "tarare": "tarar",
    "tararei": "tarar",
    "tarareis": "tarar",
    "tararem": "tarar",
    "tararemos": "tarar",
    "tarares": "tarar",
    "tararia": "tarar",
    "tarariam": "tarar",
    "tararias": "tarar",
    "tararmo": "tarar",
    "tararmos": "tarar",
    "tarará": "tarar",
    "tararás": "tarará",
    "tararão": "tarar",
    "tararíamos": "tarar",
    "tararíeis": "tarar",
    "taras": "tarar",
    "tarasca": "tarasco",
    "tarascas": "tarasco",
    "tarascos": "tarasco",
    "tarasquenta": "tarasquento",
    "tarasquentas": "tarasquento",
    "tarasquentos": "tarasquento",
    "tarasse": "tarar",
    "tarassem": "tarar",
    "tarasses": "tarar",
    "taraste": "tarar",
    "tarastes": "tarar",
    "taratas": "tarata",
    "tarava": "tarar",
    "taravam": "tarar",
    "taravas": "tarar",
    "taraxacos": "taraxaco",
    "tarda": "tardo",
    "tardada": "tardar",
    "tardadas": "tardar",
    "tardado": "tardar",
    "tardadora": "tardador",
    "tardadoras": "tardador",
    "tardadores": "tardador",
    "tardados": "tardar",
    "tardai": "tardar",
    "tardais": "tardar",
    "tardam": "tardar",
    "tardamentos": "tardamento",
    "tardamo": "tardar",
    "tardamos": "tardar",
    "tardando": "tardar",
    "tardanças": "tardança",
    "tardara": "tardar",
    "tardaram": "tardar",
    "tardaras": "tardar",
    "tardardes": "tardar",
    "tardarei": "tardar",
    "tardareis": "tardar",
    "tardarem": "tardar",
    "tardaremos": "tardar",
    "tardares": "tardar",
    "tardaria": "tardar",
    "tardariam": "tardar",
    "tardarias": "tardar",
    "tardarmo": "tardar",
    "tardarmos": "tardar",
    "tardará": "tardar",
    "tardarás": "tardar",
    "tardarão": "tardar",
    "tardaríamos": "tardar",
    "tardaríeis": "tardar",
    "tardas": "tardo",
    "tardasse": "tardar",
    "tardassem": "tardar",
    "tardasses": "tardar",
    "tardaste": "tardar",
    "tardastes": "tardar",
    "tardava": "tardar",
    "tardavam": "tardar",
    "tardavas": "tardar",
    "tarde": "tardar",
    "tardega": "tardego",
    "tardegas": "tardego",
    "tardegos": "tardego",
    "tardei": "tardar",
    "tardeira": "tardeiro",
    "tardeiras": "tardeiro",
    "tardeiros": "tardeiro",
    "tardeis": "tardar",
    "tardem": "tardar",
    "tardemo": "tardar",
    "tardemos": "tardar",
    "tardes": "tarde",
    "tardezas": "tardeza",
    "tardia": "tardio",
    "tardias": "tardio",
    "tardinha": "tarde",
    "tardinhas": "tarde",
    "tardinheira": "tardinheiro",
    "tardinheiras": "tardinheiro",
    "tardinheiros": "tardinheiro",
    "tardiona": "tardião",
    "tardionas": "tardião",
    "tardios": "tardio",
    "tardita": "tarde",
    "tarditas": "tarde",
    "tardiões": "tardião",
    "tardo": "tardar",
    "tardona": "tardão",
    "tardonas": "tardão",
    "tardonha": "tardonho",
    "tardonhas": "tardonho",
    "tardonhos": "tardonho",
    "tardores": "tardor",
    "tardos": "tardo",
    "tardou": "tardar",
    "tardozes": "tardoz",
    "tardámo": "tardar",
    "tardámos": "tardar",
    "tardáramo": "tardar",
    "tardáramos": "tardar",
    "tardáreis": "tardar",
    "tardásseis": "tardar",
    "tardássemos": "tardar",
    "tardávamo": "tardar",
    "tardávamos": "tardar",
    "tardáveis": "tardável",
    "tardígrada": "tardígrado",
    "tardígradas": "tardígrado",
    "tardígrados": "tardígrado",
    "tardíloqua": "tardíloquo",
    "tardíloquas": "tardíloquo",
    "tardíloquos": "tardíloquo",
    "tardíssimo": "tarde",
    "tardívaga": "tardívago",
    "tardívagas": "tardívago",
    "tardívagos": "tardívago",
    "tardões": "tardão",
    "tare": "tarar",
    "tareada": "tarear",
    "tareadas": "tarear",
    "tareado": "tarear",
    "tareados": "tarear",
    "tareai": "tarear",
    "tareais": "tarear",
    "tareamo": "tarear",
    "tareamos": "tarear",
    "tareando": "tarear",
    "tareara": "tarear",
    "tarearam": "tarear",
    "tarearas": "tarear",
    "tarearde": "tarear",
    "tareardes": "tarear",
    "tareare": "tarear",
    "tarearei": "tarear",
    "tareareis": "tarear",
    "tarearem": "tarear",
    "tarearemos": "tarear",
    "tareares": "tarear",
    "tarearia": "tarear",
    "tareariam": "tarear",
    "tarearias": "tarear",
    "tarearmo": "tarear",
    "tarearmos": "tarear",
    "tareará": "tarear",
    "tarearás": "tarear",
    "tarearão": "tarear",
    "tarearíamos": "tarear",
    "tarearíeis": "tarear",
    "tareasse": "tarear",
    "tareassem": "tarear",
    "tareasses": "tarear",
    "tareaste": "tarear",
    "tareastes": "tarear",
    "tareava": "tarear",
    "tareavam": "tarear",
    "tareavas": "tarear",
    "tareca": "tareco",
    "tarecadas": "tarecada",
    "tarecas": "tareco",
    "tarecos": "tareco",
    "tareei": "tarear",
    "tareeis": "tarear",
    "tareemo": "tarear",
    "tareemos": "tarear",
    "tarefa": "tarefar",
    "tarefada": "tarefar",
    "tarefadas": "tarefar",
    "tarefado": "tarefar",
    "tarefados": "tarefar",
    "tarefai": "tarefar",
    "tarefais": "tarefar",
    "tarefam": "tarefar",
    "tarefamo": "tarefar",
    "tarefamos": "tarefar",
    "tarefando": "tarefar",
    "tarefara": "tarefar",
    "tarefaram": "tarefar",
    "tarefaras": "tarefar",
    "tarefarde": "tarefar",
    "tarefardes": "tarefar",
    "tarefare": "tarefar",
    "tarefarei": "tarefar",
    "tarefareis": "tarefar",
    "tarefarem": "tarefar",
    "tarefaremos": "tarefar",
    "tarefares": "tarefar",
    "tarefaria": "tarefar",
    "tarefariam": "tarefar",
    "tarefarias": "tarefar",
    "tarefarmo": "tarefar",
    "tarefarmos": "tarefar",
    "tarefará": "tarefar",
    "tarefarás": "tarefar",
    "tarefarão": "tarefar",
    "tarefaríamos": "tarefar",
    "tarefaríeis": "tarefar",
    "tarefas": "tarefar",
    "tarefasse": "tarefar",
    "tarefassem": "tarefar",
    "tarefasses": "tarefar",
    "tarefaste": "tarefar",
    "tarefastes": "tarefar",
    "tarefava": "tarefar",
    "tarefavam": "tarefar",
    "tarefavas": "tarefar",
    "tarefe": "tarefar",
    "tarefei": "tarefar",
    "tarefeira": "tarefeiro",
    "tarefeiras": "tarefeiro",
    "tarefeiros": "tarefeiro",
    "tarefeis": "tarefar",
    "tarefem": "tarefar",
    "tarefemo": "tarefar",
    "tarefemos": "tarefar",
    "tarefes": "tarefar",
    "tarefo": "tarefar",
    "tarefou": "tarefar",
    "tarefá": "tarefar",
    "tarefámo": "tarefar",
    "tarefámos": "tarefar",
    "tarefáramo": "tarefar",
    "tarefáramos": "tarefar",
    "tarefárei": "tarefar",
    "tarefáreis": "tarefar",
    "tarefásseis": "tarefar",
    "tarefássemos": "tarefar",
    "tarefávamo": "tarefar",
    "tarefávamos": "tarefar",
    "tarefávei": "tarefar",
    "tarefáveis": "tarefável",
    "taregas": "tarega",
    "taregicagens": "taregicagem",
    "tarei": "tarar",
    "tareia": "tarear",
    "tareiam": "tarear",
    "tareias": "tareia",
    "tareie": "tarear",
    "tareiem": "tarear",
    "tareies": "tarear",
    "tareio": "tarear",
    "tareis": "tarar",
    "tarela": "tarelar",
    "tarelada": "tarelar",
    "tareladas": "tarelar",
    "tarelado": "tarelar",
    "tarelados": "tarelar",
    "tarelai": "tarelar",
    "tarelais": "tarelar",
    "tarelam": "tarelar",
    "tarelamo": "tarelar",
    "tarelamos": "tarelar",
    "tarelando": "tarelar",
    "tarelara": "tarelar",
    "tarelaram": "tarelar",
    "tarelaras": "tarelar",
    "tarelardes": "tarelar",
    "tarelarei": "tarelar",
    "tarelareis": "tarelar",
    "tarelarem": "tarelar",
    "tarelaremos": "tarelar",
    "tarelares": "tarelar",
    "tarelaria": "tarelar",
    "tarelariam": "tarelar",
    "tarelarias": "tarelar",
    "tarelarmo": "tarelar",
    "tarelarmos": "tarelar",
    "tarelará": "tarelar",
    "tarelarás": "tarelar",
    "tarelarão": "tarelar",
    "tarelaríamos": "tarelar",
    "tarelaríeis": "tarelar",
    "tarelas": "tarelar",
    "tarelasse": "tarelar",
    "tarelassem": "tarelar",
    "tarelasses": "tarelar",
    "tarelaste": "tarelar",
    "tarelastes": "tarelar",
    "tarelava": "tarelar",
    "tarelavam": "tarelar",
    "tarelavas": "tarelar",
    "tarele": "tarelar",
    "tarelei": "tarelar",
    "tareleis": "tarelar",
    "tarelem": "tarelar",
    "tarelemo": "tarelar",
    "tarelemos": "tarelar",
    "tareles": "tarelar",
    "tarelices": "tarelice",
    "tarelo": "tarelar",
    "tarelos": "tarelo",
    "tarelou": "tarelar",
    "tarelámo": "tarelar",
    "tarelámos": "tarelar",
    "tareláramo": "tarelar",
    "tareláramos": "tarelar",
    "tareláreis": "tarelar",
    "tarelásseis": "tarelar",
    "tarelássemos": "tarelar",
    "tarelávamo": "tarelar",
    "tarelávamos": "tarelar",
    "tareláveis": "tarelar",
    "tarem": "tarar",
    "taremo": "tarar",
    "taremos": "tarar",
    "tarentina": "tarentino",
    "tarentinas": "tarentino",
    "tarentinos": "tarentino",
    "tarentismos": "tarentismo",
    "tareou": "tarear",
    "tarequinha": "tareco",
    "tarequinhas": "tareco",
    "tarequinho": "tareco",
    "tarequinhos": "tareco",
    "tarequita": "tareco",
    "tarequitas": "tareco",
    "tarequito": "tareco",
    "tarequitos": "tareco",
    "tares": "tarar",
    "tareá": "tarear",
    "tareámo": "tarear",
    "tareámos": "tarear",
    "tareáramo": "tarear",
    "tareáramos": "tarear",
    "tareárei": "tarear",
    "tareáreis": "tarear",
    "tareásseis": "tarear",
    "tareássemos": "tarear",
    "tareávamo": "tarear",
    "tareávamos": "tarear",
    "tareávei": "tarear",
    "tareáveis": "tareável",
    "targanas": "targana",
    "tarifa": "tarifar",
    "tarifada": "tarifar",
    "tarifadas": "tarifar",
    "tarifado": "tarifar",
    "tarifados": "tarifar",
    "tarifai": "tarifar",
    "tarifais": "tarifar",
    "tarifam": "tarifar",
    "tarifamo": "tarifar",
    "tarifamos": "tarifar",
    "tarifando": "tarifar",
    "tarifara": "tarifar",
    "tarifaram": "tarifar",
    "tarifaras": "tarifar",
    "tarifarde": "tarifar",
    "tarifardes": "tarifar",
    "tarifare": "tarifar",
    "tarifarei": "tarifar",
    "tarifareis": "tarifar",
    "tarifarem": "tarifar",
    "tarifaremos": "tarifar",
    "tarifares": "tarifar",
    "tarifaria": "tarifar",
    "tarifariam": "tarifar",
    "tarifarias": "tarifar",
    "tarifarmo": "tarifar",
    "tarifarmos": "tarifar",
    "tarifará": "tarifar",
    "tarifarás": "tarifar",
    "tarifarão": "tarifar",
    "tarifaríamos": "tarifar",
    "tarifaríeis": "tarifar",
    "tarifas": "tarifar",
    "tarifasse": "tarifar",
    "tarifassem": "tarifar",
    "tarifasses": "tarifar",
    "tarifaste": "tarifar",
    "tarifastes": "tarifar",
    "tarifava": "tarifar",
    "tarifavam": "tarifar",
    "tarifavas": "tarifar",
    "tarifações": "tarifação",
    "tarife": "tarifar",
    "tarifei": "tarifar",
    "tarifeis": "tarifar",
    "tarifem": "tarifar",
    "tarifemo": "tarifar",
    "tarifemos": "tarifar",
    "tarifes": "tarifar",
    "tarifida": "tarifido",
    "tarifidas": "tarifido",
    "tarifidos": "tarifido",
    "tarifo": "tarifar",
    "tarifou": "tarifar",
    "tarifá": "tarifar",
    "tarifámo": "tarifar",
    "tarifámos": "tarifar",
    "tarifáramo": "tarifar",
    "tarifáramos": "tarifar",
    "tarifárei": "tarifar",
    "tarifáreis": "tarifar",
    "tarifária": "tarifário",
    "tarifárias": "tarifário",
    "tarifários": "tarifário",
    "tarifásseis": "tarifar",
    "tarifássemos": "tarifar",
    "tarifávamo": "tarifar",
    "tarifávamos": "tarifar",
    "tarifávei": "tarifar",
    "tarifáveis": "tarifável",
    "tarimas": "tarima",
    "tarimba": "tarimbar",
    "tarimbada": "tarimbar",
    "tarimbadas": "tarimbar",
    "tarimbado": "tarimbar",
    "tarimbados": "tarimbar",
    "tarimbai": "tarimbar",
    "tarimbais": "tarimbar",
    "tarimbam": "tarimbar",
    "tarimbamo": "tarimbar",
    "tarimbamos": "tarimbar",
    "tarimbando": "tarimbar",
    "tarimbara": "tarimbar",
    "tarimbaram": "tarimbar",
    "tarimbaras": "tarimbar",
    "tarimbardes": "tarimbar",
    "tarimbarei": "tarimbar",
    "tarimbareis": "tarimbar",
    "tarimbarem": "tarimbar",
    "tarimbaremos": "tarimbar",
    "tarimbares": "tarimbar",
    "tarimbaria": "tarimbar",
    "tarimbariam": "tarimbar",
    "tarimbarias": "tarimbar",
    "tarimbarmo": "tarimbar",
    "tarimbarmos": "tarimbar",
    "tarimbará": "tarimbar",
    "tarimbarás": "tarimbar",
    "tarimbarão": "tarimbar",
    "tarimbaríamos": "tarimbar",
    "tarimbaríeis": "tarimbar",
    "tarimbas": "tarimbar",
    "tarimbasse": "tarimbar",
    "tarimbassem": "tarimbar",
    "tarimbasses": "tarimbar",
    "tarimbaste": "tarimbar",
    "tarimbastes": "tarimbar",
    "tarimbava": "tarimbar",
    "tarimbavam": "tarimbar",
    "tarimbavas": "tarimbar",
    "tarimbe": "tarimbar",
    "tarimbei": "tarimbar",
    "tarimbeira": "tarimbeiro",
    "tarimbeiras": "tarimbeiro",
    "tarimbeiros": "tarimbeiro",
    "tarimbeis": "tarimbar",
    "tarimbem": "tarimbar",
    "tarimbemo": "tarimbar",
    "tarimbemos": "tarimbar",
    "tarimbes": "tarimbar",
    "tarimbo": "tarimbar",
    "tarimbou": "tarimbar",
    "tarimbámo": "tarimbar",
    "tarimbámos": "tarimbar",
    "tarimbáramo": "tarimbar",
    "tarimbáramos": "tarimbar",
    "tarimbáreis": "tarimbar",
    "tarimbásseis": "tarimbar",
    "tarimbássemos": "tarimbar",
    "tarimbávamo": "tarimbar",
    "tarimbávamos": "tarimbar",
    "tarimbáveis": "tarimbar",
    "tarins": "tarim",
    "tariotas": "tariota",
    "taris": "tari",
    "tarja": "tarjar",
    "tarjada": "tarjar",
    "tarjadas": "tarjar",
    "tarjado": "tarjar",
    "tarjados": "tarjar",
    "tarjadíssima": "tarjado",
    "tarjadíssimas": "tarjado",
    "tarjadíssimo": "tarjado",
    "tarjadíssimos": "tarjado",
    "tarjai": "tarjar",
    "tarjais": "tarjar",
    "tarjam": "tarjar",
    "tarjamo": "tarjar",
    "tarjamos": "tarjar",
    "tarjando": "tarjar",
    "tarjara": "tarjar",
    "tarjaram": "tarjar",
    "tarjaras": "tarjar",
    "tarjarde": "tarjar",
    "tarjardes": "tarjar",
    "tarjare": "tarjar",
    "tarjarei": "tarjar",
    "tarjareis": "tarjar",
    "tarjarem": "tarjar",
    "tarjaremos": "tarjar",
    "tarjares": "tarjar",
    "tarjaria": "tarjar",
    "tarjariam": "tarjar",
    "tarjarias": "tarjar",
    "tarjarmo": "tarjar",
    "tarjarmos": "tarjar",
    "tarjará": "tarjar",
    "tarjarás": "tarjar",
    "tarjarão": "tarjar",
    "tarjaríamos": "tarjar",
    "tarjaríeis": "tarjar",
    "tarjas": "tarjar",
    "tarjasse": "tarjar",
    "tarjassem": "tarjar",
    "tarjasses": "tarjar",
    "tarjaste": "tarjar",
    "tarjastes": "tarjar",
    "tarjava": "tarjar",
    "tarjavam": "tarjar",
    "tarjavas": "tarjar",
    "tarje": "tarjar",
    "tarjei": "tarjar",
    "tarjeis": "tarjar",
    "tarjem": "tarjar",
    "tarjemo": "tarjar",
    "tarjemos": "tarjar",
    "tarjes": "tarjar",
    "tarjetas": "tarjeta",
    "tarjo": "tarjar",
    "tarjou": "tarjar",
    "tarjá": "tarjar",
    "tarjámo": "tarjar",
    "tarjámos": "tarjar",
    "tarjáramo": "tarjar",
    "tarjáramos": "tarjar",
    "tarjárei": "tarjar",
    "tarjáreis": "tarjar",
    "tarjásseis": "tarjar",
    "tarjássemos": "tarjar",
    "tarjávamo": "tarjar",
    "tarjávamos": "tarjar",
    "tarjávei": "tarjar",
    "tarjáveis": "tarjável",
    "tarlatanas": "tarlatana",
    "taro": "tarar",
    "taroca": "tarocar",
    "tarocada": "tarocar",
    "tarocadas": "tarocar",
    "tarocado": "tarocar",
    "tarocados": "tarocar",
    "tarocais": "tarocar",
    "tarocam": "tarocar",
    "tarocamo": "tarocar",
    "tarocamos": "tarocar",
    "tarocando": "tarocar",
    "tarocara": "tarocar",
    "tarocaram": "tarocar",
    "tarocaras": "tarocar",
    "tarocardes": "tarocar",
    "tarocarei": "tarocar",
    "tarocareis": "tarocar",
    "tarocarem": "tarocar",
    "tarocaremos": "tarocar",
    "tarocares": "tarocar",
    "tarocaria": "tarocar",
    "tarocariam": "tarocar",
    "tarocarias": "tarocar",
    "tarocarmo": "tarocar",
    "tarocarmos": "tarocar",
    "tarocará": "tarocar",
    "tarocarás": "tarocar",
    "tarocarão": "tarocar",
    "tarocaríamos": "tarocar",
    "tarocaríeis": "tarocar",
    "tarocas": "tarocar",
    "tarocasse": "tarocar",
    "tarocassem": "tarocar",
    "tarocasses": "tarocar",
    "tarocaste": "tarocar",
    "tarocastes": "tarocar",
    "tarocava": "tarocar",
    "tarocavam": "tarocar",
    "tarocavas": "tarocar",
    "taroco": "tarocar",
    "tarocos": "taroco",
    "tarocou": "tarocar",
    "tarocámo": "tarocar",
    "tarocámos": "tarocar",
    "tarocáramo": "tarocar",
    "tarocáramos": "tarocar",
    "tarocáreis": "tarocar",
    "tarocásseis": "tarocar",
    "tarocássemos": "tarocar",
    "tarocávamo": "tarocar",
    "tarocávamos": "tarocar",
    "tarocáveis": "tarocar",
    "tarois": "tarol",
    "tarolas": "tarola",
    "taroque": "tarocar",
    "taroquei": "tarocar",
    "taroqueis": "tarocar",
    "taroquem": "tarocar",
    "taroquemos": "tarocar",
    "taroques": "tarocar",
    "taros": "taro",
    "tarou": "tarar",
    "tarouca": "tarouco",
    "taroucas": "tarouco",
    "taroucos": "tarouco",
    "tarouquices": "tarouquice",
    "tarrachos": "tarracho",
    "tarraconenses": "tarraconense",
    "tarracos": "tarraco",
    "tarradas": "tarrada",
    "tarrafa": "tarrafar",
    "tarrafada": "tarrafar",
    "tarrafadas": "tarrafar",
    "tarrafado": "tarrafar",
    "tarrafados": "tarrafar",
    "tarrafai": "tarrafar",
    "tarrafais": "tarrafar",
    "tarrafam": "tarrafar",
    "tarrafamo": "tarrafar",
    "tarrafamos": "tarrafar",
    "tarrafando": "tarrafar",
    "tarrafara": "tarrafar",
    "tarrafaram": "tarrafar",
    "tarrafaras": "tarrafar",
    "tarrafardes": "tarrafar",
    "tarrafarei": "tarrafar",
    "tarrafareis": "tarrafar",
    "tarrafarem": "tarrafar",
    "tarrafaremos": "tarrafar",
    "tarrafares": "tarrafar",
    "tarrafaria": "tarrafar",
    "tarrafariam": "tarrafar",
    "tarrafarias": "tarrafar",
    "tarrafarmo": "tarrafar",
    "tarrafarmos": "tarrafar",
    "tarrafará": "tarrafar",
    "tarrafarás": "tarrafar",
    "tarrafarão": "tarrafar",
    "tarrafaríamos": "tarrafar",
    "tarrafaríeis": "tarrafar",
    "tarrafas": "tarrafar",
    "tarrafasse": "tarrafar",
    "tarrafassem": "tarrafar",
    "tarrafasses": "tarrafar",
    "tarrafaste": "tarrafar",
    "tarrafastes": "tarrafar",
    "tarrafava": "tarrafar",
    "tarrafavam": "tarrafar",
    "tarrafavas": "tarrafar",
    "tarrafe": "tarrafar",
    "tarrafeada": "tarrafear",
    "tarrafeadas": "tarrafear",
    "tarrafeado": "tarrafear",
    "tarrafeados": "tarrafear",
    "tarrafeai": "tarrafear",
    "tarrafeais": "tarrafear",
    "tarrafeamo": "tarrafear",
    "tarrafeamos": "tarrafear",
    "tarrafeando": "tarrafear",
    "tarrafeara": "tarrafear",
    "tarrafearam": "tarrafear",
    "tarrafearas": "tarrafear",
    "tarrafeardes": "tarrafear",
    "tarrafearei": "tarrafear",
    "tarrafeareis": "tarrafear",
    "tarrafearem": "tarrafear",
    "tarrafearemos": "tarrafear",
    "tarrafeares": "tarrafear",
    "tarrafearia": "tarrafear",
    "tarrafeariam": "tarrafear",
    "tarrafearias": "tarrafear",
    "tarrafearmo": "tarrafear",
    "tarrafearmos": "tarrafear",
    "tarrafeará": "tarrafear",
    "tarrafearás": "tarrafear",
    "tarrafearão": "tarrafear",
    "tarrafearíamos": "tarrafear",
    "tarrafearíeis": "tarrafear",
    "tarrafeasse": "tarrafear",
    "tarrafeassem": "tarrafear",
    "tarrafeasses": "tarrafear",
    "tarrafeaste": "tarrafear",
    "tarrafeastes": "tarrafear",
    "tarrafeava": "tarrafear",
    "tarrafeavam": "tarrafear",
    "tarrafeavas": "tarrafear",
    "tarrafeei": "tarrafear",
    "tarrafeeis": "tarrafear",
    "tarrafeemo": "tarrafear",
    "tarrafeemos": "tarrafear",
    "tarrafei": "tarrafar",
    "tarrafeia": "tarrafear",
    "tarrafeiam": "tarrafear",
    "tarrafeias": "tarrafear",
    "tarrafeie": "tarrafear",
    "tarrafeiem": "tarrafear",
    "tarrafeies": "tarrafear",
    "tarrafeio": "tarrafear",
    "tarrafeis": "tarrafar",
    "tarrafem": "tarrafar",
    "tarrafemo": "tarrafar",
    "tarrafemos": "tarrafar",
    "tarrafeou": "tarrafear",
    "tarrafes": "tarrafar",
    "tarrafeámo": "tarrafear",
    "tarrafeámos": "tarrafear",
    "tarrafeáramo": "tarrafear",
    "tarrafeáramos": "tarrafear",
    "tarrafeáreis": "tarrafear",
    "tarrafeásseis": "tarrafear",
    "tarrafeássemos": "tarrafear",
    "tarrafeávamo": "tarrafear",
    "tarrafeávamos": "tarrafear",
    "tarrafeáveis": "tarrafear",
    "tarrafo": "tarrafar",
    "tarrafou": "tarrafar",
    "tarrafámo": "tarrafar",
    "tarrafámos": "tarrafar",
    "tarrafáramo": "tarrafar",
    "tarrafáramos": "tarrafar",
    "tarrafáreis": "tarrafar",
    "tarrafásseis": "tarrafar",
    "tarrafássemos": "tarrafar",
    "tarrafávamo": "tarrafar",
    "tarrafávamos": "tarrafar",
    "tarrafáveis": "tarrafar",
    "tarranos": "tarrano",
    "tarranquins": "tarranquim",
    "tarrantanas": "tarrantana",
    "tarraquéns": "tarraquém",
    "tarrascas": "tarrasca",
    "tarrates": "tarrate",
    "tarratões": "tarratão",
    "tarraxa": "tarraxar",
    "tarraxada": "tarraxar",
    "tarraxadas": "tarraxar",
    "tarraxado": "tarraxar",
    "tarraxados": "tarraxar",
    "tarraxai": "tarraxar",
    "tarraxais": "tarraxar",
    "tarraxam": "tarraxar",
    "tarraxamo": "tarraxar",
    "tarraxamos": "tarraxar",
    "tarraxando": "tarraxar",
    "tarraxara": "tarraxar",
    "tarraxaram": "tarraxar",
    "tarraxaras": "tarraxar",
    "tarraxarde": "tarraxar",
    "tarraxardes": "tarraxar",
    "tarraxare": "tarraxar",
    "tarraxarei": "tarraxar",
    "tarraxareis": "tarraxar",
    "tarraxarem": "tarraxar",
    "tarraxaremos": "tarraxar",
    "tarraxares": "tarraxar",
    "tarraxaria": "tarraxar",
    "tarraxariam": "tarraxar",
    "tarraxarias": "tarraxar",
    "tarraxarmo": "tarraxar",
    "tarraxarmos": "tarraxar",
    "tarraxará": "tarraxar",
    "tarraxarás": "tarraxar",
    "tarraxarão": "tarraxar",
    "tarraxaríamos": "tarraxar",
    "tarraxaríeis": "tarraxar",
    "tarraxas": "tarraxar",
    "tarraxasse": "tarraxar",
    "tarraxassem": "tarraxar",
    "tarraxasses": "tarraxar",
    "tarraxaste": "tarraxar",
    "tarraxastes": "tarraxar",
    "tarraxava": "tarraxar",
    "tarraxavam": "tarraxar",
    "tarraxavas": "tarraxar",
    "tarraxe": "tarraxar",
    "tarraxei": "tarraxar",
    "tarraxeis": "tarraxar",
    "tarraxem": "tarraxar",
    "tarraxemo": "tarraxar",
    "tarraxemos": "tarraxar",
    "tarraxes": "tarraxar",
    "tarraxo": "tarraxar",
    "tarraxou": "tarraxar",
    "tarraxá": "tarraxar",
    "tarraxámo": "tarraxar",
    "tarraxámos": "tarraxar",
    "tarraxáramo": "tarraxar",
    "tarraxáramos": "tarraxar",
    "tarraxárei": "tarraxar",
    "tarraxáreis": "tarraxar",
    "tarraxásseis": "tarraxar",
    "tarraxássemos": "tarraxar",
    "tarraxávamo": "tarraxar",
    "tarraxávamos": "tarraxar",
    "tarraxávei": "tarraxar",
    "tarraxáveis": "tarraxar",
    "tarraçadas": "tarraçada",
    "tarraços": "tarraço",
    "tarrecos": "tarreco",
    "tarrelos": "tarrelo",
    "tarretas": "tarreta",
    "tarrinca": "tarrincar",
    "tarrincada": "tarrincar",
    "tarrincadas": "tarrincar",
    "tarrincado": "tarrincar",
    "tarrincados": "tarrincar",
    "tarrincai": "tarrincar",
    "tarrincais": "tarrincar",
    "tarrincam": "tarrincar",
    "tarrincamo": "tarrincar",
    "tarrincamos": "tarrincar",
    "tarrincando": "tarrincar",
    "tarrincara": "tarrincar",
    "tarrincaram": "tarrincar",
    "tarrincaras": "tarrincar",
    "tarrincarde": "tarrincar",
    "tarrincardes": "tarrincar",
    "tarrincare": "tarrincar",
    "tarrincarei": "tarrincar",
    "tarrincareis": "tarrincar",
    "tarrincarem": "tarrincar",
    "tarrincaremos": "tarrincar",
    "tarrincares": "tarrincar",
    "tarrincaria": "tarrincar",
    "tarrincariam": "tarrincar",
    "tarrincarias": "tarrincar",
    "tarrincarmo": "tarrincar",
    "tarrincarmos": "tarrincar",
    "tarrincará": "tarrincar",
    "tarrincarás": "tarrincar",
    "tarrincarão": "tarrincar",
    "tarrincaríamos": "tarrincar",
    "tarrincaríeis": "tarrincar",
    "tarrincas": "tarrincar",
    "tarrincasse": "tarrincar",
    "tarrincassem": "tarrincar",
    "tarrincasses": "tarrincar",
    "tarrincaste": "tarrincar",
    "tarrincastes": "tarrincar",
    "tarrincava": "tarrincar",
    "tarrincavam": "tarrincar",
    "tarrincavas": "tarrincar",
    "tarrinco": "tarrincar",
    "tarrincou": "tarrincar",
    "tarrincá": "tarrincar",
    "tarrincámo": "tarrincar",
    "tarrincámos": "tarrincar",
    "tarrincáramo": "tarrincar",
    "tarrincáramos": "tarrincar",
    "tarrincárei": "tarrincar",
    "tarrincáreis": "tarrincar",
    "tarrincásseis": "tarrincar",
    "tarrincássemos": "tarrincar",
    "tarrincávamo": "tarrincar",
    "tarrincávamos": "tarrincar",
    "tarrincávei": "tarrincar",
    "tarrincáveis": "tarrincável",
    "tarrinheiras": "tarrinheira",
    "tarrinque": "tarrincar",
    "tarrinquei": "tarrincar",
    "tarrinqueis": "tarrincar",
    "tarrinquem": "tarrincar",
    "tarrinquemo": "tarrincar",
    "tarrinquemos": "tarrincar",
    "tarrinques": "tarrincar",
    "tarroeiras": "tarroeira",
    "tarros": "tarro",
    "tarrotes": "tarrote",
    "tarrraxáveis": "tarrraxável",
    "tarréus": "tarréu",
    "tarsalgias": "tarsalgia",
    "tarsectomias": "tarsectomia",
    "tarseítes": "tarseíte",
    "tarsiana": "tarsiano",
    "tarsianas": "tarsiano",
    "tarsianos": "tarsiano",
    "tarsites": "tarsite",
    "tarsióideos": "tarsióideo",
    "tarsióides": "tarsióide",
    "tarsos": "tarso",
    "tarsotomias": "tarsotomia",
    "tartameleada": "tartamelear",
    "tartameleadas": "tartamelear",
    "tartameleado": "tartamelear",
    "tartameleados": "tartamelear",
    "tartameleai": "tartamelear",
    "tartameleais": "tartamelear",
    "tartameleamo": "tartamelear",
    "tartameleamos": "tartamelear",
    "tartameleando": "tartamelear",
    "tartameleara": "tartamelear",
    "tartamelearam": "tartamelear",
    "tartamelearas": "tartamelear",
    "tartameleardes": "tartamelear",
    "tartamelearei": "tartamelear",
    "tartameleareis": "tartamelear",
    "tartamelearem": "tartamelear",
    "tartamelearemos": "tartamelear",
    "tartameleares": "tartamelear",
    "tartamelearia": "tartamelear",
    "tartameleariam": "tartamelear",
    "tartamelearias": "tartamelear",
    "tartamelearmo": "tartamelear",
    "tartamelearmos": "tartamelear",
    "tartameleará": "tartamelear",
    "tartamelearás": "tartamelear",
    "tartamelearão": "tartamelear",
    "tartamelearíamos": "tartamelear",
    "tartamelearíeis": "tartamelear",
    "tartameleasse": "tartamelear",
    "tartameleassem": "tartamelear",
    "tartameleasses": "tartamelear",
    "tartameleaste": "tartamelear",
    "tartameleastes": "tartamelear",
    "tartameleava": "tartamelear",
    "tartameleavam": "tartamelear",
    "tartameleavas": "tartamelear",
    "tartameleei": "tartamelear",
    "tartameleeis": "tartamelear",
    "tartameleemo": "tartamelear",
    "tartameleemos": "tartamelear",
    "tartameleia": "tartamelear",
    "tartameleiam": "tartamelear",
    "tartameleias": "tartamelear",
    "tartameleie": "tartamelear",
    "tartameleiem": "tartamelear",
    "tartameleies": "tartamelear",
    "tartameleio": "tartamelear",
    "tartameleou": "tartamelear",
    "tartameleámo": "tartamelear",
    "tartameleámos": "tartamelear",
    "tartameleáramo": "tartamelear",
    "tartameleáramos": "tartamelear",
    "tartameleáreis": "tartamelear",
    "tartameleásseis": "tartamelear",
    "tartameleássemos": "tartamelear",
    "tartameleávamo": "tartamelear",
    "tartameleávamos": "tartamelear",
    "tartameleáveis": "tartamelear",
    "tartameloa": "tartameloo",
    "tartameloas": "tartameloo",
    "tartameloos": "tartameloo",
    "tartamuda": "tartamudo",
    "tartamudas": "tartamudo",
    "tartamudeada": "tartamudear",
    "tartamudeadas": "tartamudear",
    "tartamudeado": "tartamudear",
    "tartamudeados": "tartamudear",
    "tartamudeai": "tartamudear",
    "tartamudeais": "tartamudear",
    "tartamudeamo": "tartamudear",
    "tartamudeamos": "tartamudear",
    "tartamudeando": "tartamudear",
    "tartamudeara": "tartamudear",
    "tartamudearam": "tartamudear",
    "tartamudearas": "tartamudear",
    "tartamudeardes": "tartamudear",
    "tartamudearei": "tartamudear",
    "tartamudeareis": "tartamudear",
    "tartamudearem": "tartamudear",
    "tartamudearemos": "tartamudear",
    "tartamudeares": "tartamudear",
    "tartamudearia": "tartamudear",
    "tartamudeariam": "tartamudear",
    "tartamudearias": "tartamudear",
    "tartamudearmo": "tartamudear",
    "tartamudearmos": "tartamudear",
    "tartamudeará": "tartamudear",
    "tartamudearás": "tartamudear",
    "tartamudearão": "tartamudear",
    "tartamudearíamos": "tartamudear",
    "tartamudearíeis": "tartamudear",
    "tartamudeasse": "tartamudear",
    "tartamudeassem": "tartamudear",
    "tartamudeasses": "tartamudear",
    "tartamudeaste": "tartamudear",
    "tartamudeastes": "tartamudear",
    "tartamudeava": "tartamudear",
    "tartamudeavam": "tartamudear",
    "tartamudeavas": "tartamudear",
    "tartamudeei": "tartamudear",
    "tartamudeeis": "tartamudear",
    "tartamudeemo": "tartamudear",
    "tartamudeemos": "tartamudear",
    "tartamudeia": "tartamudear",
    "tartamudeiam": "tartamudear",
    "tartamudeias": "tartamudear",
    "tartamudeie": "tartamudear",
    "tartamudeiem": "tartamudear",
    "tartamudeies": "tartamudear",
    "tartamudeio": "tartamudear",
    "tartamudeou": "tartamudear",
    "tartamudezes": "tartamudez",
    "tartamudeámo": "tartamudear",
    "tartamudeámos": "tartamudear",
    "tartamudeáramo": "tartamudear",
    "tartamudeáramos": "tartamudear",
    "tartamudeáreis": "tartamudear",
    "tartamudeásseis": "tartamudear",
    "tartamudeássemos": "tartamudear",
    "tartamudeávamo": "tartamudear",
    "tartamudeávamos": "tartamudear",
    "tartamudeáveis": "tartamudear",
    "tartamudos": "tartamudo",
    "tartanas": "tartana",
    "tartara": "tartaro",
    "tartaranhas": "tartaranha",
    "tartaranhões": "tartaranhão",
    "tartaras": "tartaro",
    "tartaratos": "tartarato",
    "tartareada": "tartarear",
    "tartareadas": "tartarear",
    "tartareado": "tartarear",
    "tartareados": "tartarear",
    "tartareai": "tartarear",
    "tartareais": "tartarear",
    "tartareamo": "tartarear",
    "tartareamos": "tartarear",
    "tartareando": "tartarear",
    "tartareara": "tartarear",
    "tartarearam": "tartarear",
    "tartarearas": "tartarear",
    "tartareardes": "tartarear",
    "tartarearei": "tartarear",
    "tartareareis": "tartarear",
    "tartarearem": "tartarear",
    "tartarearemos": "tartarear",
    "tartareares": "tartarear",
    "tartarearia": "tartarear",
    "tartareariam": "tartarear",
    "tartarearias": "tartarear",
    "tartarearmo": "tartarear",
    "tartarearmos": "tartarear",
    "tartareará": "tartarear",
    "tartarearás": "tartarear",
    "tartarearão": "tartarear",
    "tartarearíamos": "tartarear",
    "tartarearíeis": "tartarear",
    "tartareasse": "tartarear",
    "tartareassem": "tartarear",
    "tartareasses": "tartarear",
    "tartareaste": "tartarear",
    "tartareastes": "tartarear",
    "tartareava": "tartarear",
    "tartareavam": "tartarear",
    "tartareavas": "tartarear",
    "tartareei": "tartarear",
    "tartareeis": "tartarear",
    "tartareemo": "tartarear",
    "tartareemos": "tartarear",
    "tartareia": "tartarear",
    "tartareiam": "tartarear",
    "tartareias": "tartarear",
    "tartareie": "tartarear",
    "tartareiem": "tartarear",
    "tartareies": "tartarear",
    "tartareio": "tartarear",
    "tartareou": "tartarear",
    "tartareámo": "tartarear",
    "tartareámos": "tartarear",
    "tartareáramo": "tartarear",
    "tartareáramos": "tartarear",
    "tartareáreis": "tartarear",
    "tartareásseis": "tartarear",
    "tartareássemos": "tartarear",
    "tartareávamo": "tartarear",
    "tartareávamos": "tartarear",
    "tartareáveis": "tartarear",
    "tartariza": "tartarizar",
    "tartarizada": "tartarizar",
    "tartarizadas": "tartarizar",
    "tartarizado": "tartarizar",
    "tartarizados": "tartarizar",
    "tartarizai": "tartarizar",
    "tartarizais": "tartarizar",
    "tartarizam": "tartarizar",
    "tartarizamo": "tartarizar",
    "tartarizamos": "tartarizar",
    "tartarizando": "tartarizar",
    "tartarizara": "tartarizar",
    "tartarizaram": "tartarizar",
    "tartarizaras": "tartarizar",
    "tartarizarde": "tartarizar",
    "tartarizardes": "tartarizar",
    "tartarizare": "tartarizar",
    "tartarizarei": "tartarizar",
    "tartarizareis": "tartarizar",
    "tartarizarem": "tartarizar",
    "tartarizaremos": "tartarizar",
    "tartarizares": "tartarizar",
    "tartarizaria": "tartarizar",
    "tartarizariam": "tartarizar",
    "tartarizarias": "tartarizar",
    "tartarizarmo": "tartarizar",
    "tartarizarmos": "tartarizar",
    "tartarizará": "tartarizar",
    "tartarizarás": "tartarizar",
    "tartarizarão": "tartarizar",
    "tartarizaríamos": "tartarizar",
    "tartarizaríeis": "tartarizar",
    "tartarizas": "tartarizar",
    "tartarizasse": "tartarizar",
    "tartarizassem": "tartarizar",
    "tartarizasses": "tartarizar",
    "tartarizaste": "tartarizar",
    "tartarizastes": "tartarizar",
    "tartarizava": "tartarizar",
    "tartarizavam": "tartarizar",
    "tartarizavas": "tartarizar",
    "tartarize": "tartarizar",
    "tartarizei": "tartarizar",
    "tartarizeis": "tartarizar",
    "tartarizem": "tartarizar",
    "tartarizemo": "tartarizar",
    "tartarizemos": "tartarizar",
    "tartarizes": "tartarizar",
    "tartarizo": "tartarizar",
    "tartarizou": "tartarizar",
    "tartarizá": "tartarizar",
    "tartarizámo": "tartarizar",
    "tartarizámos": "tartarizar",
    "tartarizáramo": "tartarizar",
    "tartarizáramos": "tartarizar",
    "tartarizárei": "tartarizar",
    "tartarizáreis": "tartarizar",
    "tartarizásseis": "tartarizar",
    "tartarizássemos": "tartarizar",
    "tartarizávamo": "tartarizar",
    "tartarizávamos": "tartarizar",
    "tartarizávei": "tartarizar",
    "tartarizáveis": "tartarizável",
    "tartaros": "tartaro",
    "tartarosa": "tartaroso",
    "tartarosas": "tartaroso",
    "tartarosos": "tartaroso",
    "tartarugas": "tartaruga",
    "tartaruguinhas": "tartaruguinha",
    "tartes": "tarte",
    "tartufica": "tartuficar",
    "tartuficada": "tartuficar",
    "tartuficadas": "tartuficar",
    "tartuficado": "tartuficar",
    "tartuficados": "tartuficar",
    "tartuficai": "tartuficar",
    "tartuficais": "tartuficar",
    "tartuficam": "tartuficar",
    "tartuficamo": "tartuficar",
    "tartuficamos": "tartuficar",
    "tartuficando": "tartuficar",
    "tartuficara": "tartuficar",
    "tartuficaram": "tartuficar",
    "tartuficaras": "tartuficar",
    "tartuficarde": "tartuficar",
    "tartuficardes": "tartuficar",
    "tartuficare": "tartuficar",
    "tartuficarei": "tartuficar",
    "tartuficareis": "tartuficar",
    "tartuficarem": "tartuficar",
    "tartuficaremos": "tartuficar",
    "tartuficares": "tartuficar",
    "tartuficaria": "tartuficar",
    "tartuficariam": "tartuficar",
    "tartuficarias": "tartuficar",
    "tartuficarmo": "tartuficar",
    "tartuficarmos": "tartuficar",
    "tartuficará": "tartuficar",
    "tartuficarás": "tartuficar",
    "tartuficarão": "tartuficar",
    "tartuficaríamos": "tartuficar",
    "tartuficaríeis": "tartuficar",
    "tartuficas": "tartuficar",
    "tartuficasse": "tartuficar",
    "tartuficassem": "tartuficar",
    "tartuficasses": "tartuficar",
    "tartuficaste": "tartuficar",
    "tartuficastes": "tartuficar",
    "tartuficava": "tartuficar",
    "tartuficavam": "tartuficar",
    "tartuficavas": "tartuficar",
    "tartufices": "tartufice",
    "tartufico": "tartuficar",
    "tartuficou": "tartuficar",
    "tartuficá": "tartuficar",
    "tartuficámo": "tartuficar",
    "tartuficámos": "tartuficar",
    "tartuficáramo": "tartuficar",
    "tartuficáramos": "tartuficar",
    "tartuficárei": "tartuficar",
    "tartuficáreis": "tartuficar",
    "tartuficásseis": "tartuficar",
    "tartuficássemos": "tartuficar",
    "tartuficávamo": "tartuficar",
    "tartuficávamos": "tartuficar",
    "tartuficávei": "tartuficar",
    "tartuficáveis": "tartuficável",
    "tartufique": "tartuficar",
    "tartufiquei": "tartuficar",
    "tartufiqueis": "tartuficar",
    "tartufiquem": "tartuficar",
    "tartufiquemo": "tartuficar",
    "tartufiquemos": "tartuficar",
    "tartufiques": "tartuficar",
    "tartufismos": "tartufismo",
    "tartufistas": "tartufista",
    "tartufos": "tartufo",
    "tartárea": "tartáreo",
    "tartáreas": "tartáreo",
    "tartáreos": "tartáreo",
    "tartárica": "tartárico",
    "tartáricas": "tartárico",
    "tartáricos": "tartárico",
    "tarucas": "taruca",
    "taruga": "tarugar",
    "tarugada": "tarugar",
    "tarugadas": "tarugar",
    "tarugado": "tarugar",
    "tarugados": "tarugar",
    "tarugai": "tarugar",
    "tarugais": "tarugar",
    "tarugam": "tarugar",
    "tarugamentos": "tarugamento",
    "tarugamo": "tarugar",
    "tarugamos": "tarugar",
    "tarugando": "tarugar",
    "tarugara": "tarugar",
    "tarugaram": "tarugar",
    "tarugaras": "tarugar",
    "tarugarde": "tarugar",
    "tarugardes": "tarugar",
    "tarugare": "tarugar",
    "tarugarei": "tarugar",
    "tarugareis": "tarugar",
    "tarugarem": "tarugar",
    "tarugaremos": "tarugar",
    "tarugares": "tarugar",
    "tarugaria": "tarugar",
    "tarugariam": "tarugar",
    "tarugarias": "tarugar",
    "tarugarmo": "tarugar",
    "tarugarmos": "tarugar",
    "tarugará": "tarugar",
    "tarugarás": "tarugar",
    "tarugarão": "tarugar",
    "tarugaríamos": "tarugar",
    "tarugaríeis": "tarugar",
    "tarugas": "tarugar",
    "tarugasse": "tarugar",
    "tarugassem": "tarugar",
    "tarugasses": "tarugar",
    "tarugaste": "tarugar",
    "tarugastes": "tarugar",
    "tarugava": "tarugar",
    "tarugavam": "tarugar",
    "tarugavas": "tarugar",
    "tarugo": "tarugar",
    "tarugos": "tarugo",
    "tarugou": "tarugar",
    "tarugue": "tarugar",
    "taruguei": "tarugar",
    "tarugueis": "tarugar",
    "taruguem": "tarugar",
    "taruguemo": "tarugar",
    "taruguemos": "tarugar",
    "tarugues": "tarugar",
    "tarugá": "tarugar",
    "tarugámo": "tarugar",
    "tarugámos": "tarugar",
    "tarugáramo": "tarugar",
    "tarugáramos": "tarugar",
    "tarugárei": "tarugar",
    "tarugáreis": "tarugar",
    "tarugásseis": "tarugar",
    "tarugássemos": "tarugar",
    "tarugávamo": "tarugar",
    "tarugávamos": "tarugar",
    "tarugávei": "tarugar",
    "tarugáveis": "tarugável",
    "tará": "tarar",
    "tarámo": "tarar",
    "tarámos": "tarar",
    "taráramo": "tarar",
    "taráramos": "tarar",
    "tarárei": "tarar",
    "taráreis": "tarar",
    "tarárias": "tarária",
    "tarásseis": "tarar",
    "tarássemos": "tarar",
    "tarávamo": "tarar",
    "tarávamos": "tarar",
    "tarávei": "tarar",
    "taráveis": "tarável",
    "tarântulas": "tarântula",
    "tarêntulas": "tarêntula",
    "tarós": "taró",
    "tasca": "tascar",
    "tascada": "tascar",
    "tascadas": "tascar",
    "tascadeiras": "tascadeira",
    "tascado": "tascar",
    "tascados": "tascar",
    "tascai": "tascar",
    "tascais": "tascar",
    "tascam": "tascar",
    "tascamo": "tascar",
    "tascamos": "tascar",
    "tascando": "tascar",
    "tascantes": "tascante",
    "tascara": "tascar",
    "tascaram": "tascar",
    "tascaras": "tascar",
    "tascarde": "tascar",
    "tascardes": "tascar",
    "tascare": "tascar",
    "tascarei": "tascar",
    "tascareis": "tascar",
    "tascarem": "tascar",
    "tascaremos": "tascar",
    "tascares": "tascar",
    "tascaria": "tascar",
    "tascariam": "tascar",
    "tascarias": "tascar",
    "tascarmo": "tascar",
    "tascarmos": "tascar",
    "tascará": "tascar",
    "tascarás": "tascar",
    "tascarão": "tascar",
    "tascaríamos": "tascar",
    "tascaríeis": "tascar",
    "tascas": "tascar",
    "tascasse": "tascar",
    "tascassem": "tascar",
    "tascasses": "tascar",
    "tascaste": "tascar",
    "tascastes": "tascar",
    "tascava": "tascar",
    "tascavam": "tascar",
    "tascavas": "tascar",
    "tasco": "tascar",
    "tascoa": "tascoar",
    "tascoada": "tascoar",
    "tascoadas": "tascoar",
    "tascoado": "tascoar",
    "tascoados": "tascoar",
    "tascoai": "tascoar",
    "tascoais": "tascoar",
    "tascoam": "tascoar",
    "tascoamo": "tascoar",
    "tascoamos": "tascoar",
    "tascoando": "tascoar",
    "tascoara": "tascoar",
    "tascoaram": "tascoar",
    "tascoaras": "tascoar",
    "tascoarde": "tascoar",
    "tascoardes": "tascoar",
    "tascoare": "tascoar",
    "tascoarei": "tascoar",
    "tascoareis": "tascoar",
    "tascoarem": "tascoar",
    "tascoaremos": "tascoar",
    "tascoares": "tascoar",
    "tascoaria": "tascoar",
    "tascoariam": "tascoar",
    "tascoarias": "tascoar",
    "tascoarmo": "tascoar",
    "tascoarmos": "tascoar",
    "tascoará": "tascoar",
    "tascoarás": "tascoar",
    "tascoarão": "tascoar",
    "tascoaríamos": "tascoar",
    "tascoaríeis": "tascoar",
    "tascoas": "tascoar",
    "tascoasse": "tascoar",
    "tascoassem": "tascoar",
    "tascoasses": "tascoar",
    "tascoaste": "tascoar",
    "tascoastes": "tascoar",
    "tascoava": "tascoar",
    "tascoavam": "tascoar",
    "tascoavas": "tascoar",
    "tascoe": "tascoar",
    "tascoei": "tascoar",
    "tascoeis": "tascoar",
    "tascoem": "tascoar",
    "tascoemo": "tascoar",
    "tascoemos": "tascoar",
    "tascoes": "tascoar",
    "tascoo": "tascoar",
    "tascoou": "tascoar",
    "tascos": "tasco",
    "tascou": "tascar",
    "tascoá": "tascoar",
    "tascoámo": "tascoar",
    "tascoámos": "tascoar",
    "tascoáramo": "tascoar",
    "tascoáramos": "tascoar",
    "tascoárei": "tascoar",
    "tascoáreis": "tascoar",
    "tascoásseis": "tascoar",
    "tascoássemos": "tascoar",
    "tascoávamo": "tascoar",
    "tascoávamos": "tascoar",
    "tascoávei": "tascoar",
    "tascoáveis": "tascoar",
    "tascá": "tascar",
    "tascámo": "tascar",
    "tascámos": "tascar",
    "tascáramo": "tascar",
    "tascáramos": "tascar",
    "tascárei": "tascar",
    "tascáreis": "tascar",
    "tascásseis": "tascar",
    "tascássemos": "tascar",
    "tascávamo": "tascar",
    "tascávamos": "tascar",
    "tascávei": "tascar",
    "tascáveis": "tascável",
    "tasmânia": "tasmânio",
    "tasmânias": "tasmânio",
    "tasmânios": "tasmânio",
    "tasnas": "tasna",
    "tasneiras": "tasneira",
    "tasneirinha": "tasneira",
    "tasneirinhas": "tasneira",
    "tasneirita": "tasneira",
    "tasneiritas": "tasneira",
    "tasque": "tascar",
    "tasquei": "tascar",
    "tasqueira": "tasqueiro",
    "tasqueiras": "tasqueiro",
    "tasqueiros": "tasqueiro",
    "tasqueis": "tascar",
    "tasquem": "tascar",
    "tasquemo": "tascar",
    "tasquemos": "tascar",
    "tasques": "tascar",
    "tasquinha": "tasquinhar",
    "tasquinhada": "tasquinhar",
    "tasquinhadas": "tasquinhar",
    "tasquinhado": "tasquinhar",
    "tasquinhadora": "tasquinhador",
    "tasquinhadoras": "tasquinhador",
    "tasquinhadores": "tasquinhador",
    "tasquinhados": "tasquinhar",
    "tasquinhai": "tasquinhar",
    "tasquinhais": "tasquinhar",
    "tasquinham": "tasquinhar",
    "tasquinhamo": "tasquinhar",
    "tasquinhamos": "tasquinhar",
    "tasquinhando": "tasquinhar",
    "tasquinhara": "tasquinhar",
    "tasquinharam": "tasquinhar",
    "tasquinharas": "tasquinhar",
    "tasquinharde": "tasquinhar",
    "tasquinhardes": "tasquinhar",
    "tasquinhare": "tasquinhar",
    "tasquinharei": "tasquinhar",
    "tasquinhareis": "tasquinhar",
    "tasquinharem": "tasquinhar",
    "tasquinharemos": "tasquinhar",
    "tasquinhares": "tasquinhar",
    "tasquinharia": "tasquinhar",
    "tasquinhariam": "tasquinhar",
    "tasquinharias": "tasquinhar",
    "tasquinharmo": "tasquinhar",
    "tasquinharmos": "tasquinhar",
    "tasquinhará": "tasquinhar",
    "tasquinharás": "tasquinhar",
    "tasquinharão": "tasquinhar",
    "tasquinharíamos": "tasquinhar",
    "tasquinharíeis": "tasquinhar",
    "tasquinhas": "tasquinhar",
    "tasquinhasse": "tasquinhar",
    "tasquinhassem": "tasquinhar",
    "tasquinhasses": "tasquinhar",
    "tasquinhaste": "tasquinhar",
    "tasquinhastes": "tasquinhar",
    "tasquinhava": "tasquinhar",
    "tasquinhavam": "tasquinhar",
    "tasquinhavas": "tasquinhar",
    "tasquinhe": "tasquinhar",
    "tasquinhei": "tasquinhar",
    "tasquinheis": "tasquinhar",
    "tasquinhem": "tasquinhar",
    "tasquinhemo": "tasquinhar",
    "tasquinhemos": "tasquinhar",
    "tasquinhes": "tasquinhar",
    "tasquinho": "tasquinhar",
    "tasquinhos": "tasco",
    "tasquinhou": "tasquinhar",
    "tasquinhá": "tasquinhar",
    "tasquinhámo": "tasquinhar",
    "tasquinhámos": "tasquinhar",
    "tasquinháramo": "tasquinhar",
    "tasquinháramos": "tasquinhar",
    "tasquinhárei": "tasquinhar",
    "tasquinháreis": "tasquinhar",
    "tasquinhásseis": "tasquinhar",
    "tasquinhássemos": "tasquinhar",
    "tasquinhávamo": "tasquinhar",
    "tasquinhávamos": "tasquinhar",
    "tasquinhávei": "tasquinhar",
    "tasquinháveis": "tasquinhável",
    "tasquito": "tasco",
    "tasquitos": "tasco",
    "tassalhos": "tassalho",
    "tasselos": "tasselo",
    "tata": "tato",
    "tatajibas": "tatajiba",
    "tatajubas": "tatajuba",
    "tatala": "tatalar",
    "tatalada": "tatalar",
    "tataladas": "tatalar",
    "tatalado": "tatalar",
    "tatalados": "tatalar",
    "tatalai": "tatalar",
    "tatalais": "tatalar",
    "tatalam": "tatalar",
    "tatalamo": "tatalar",
    "tatalamos": "tatalar",
    "tatalando": "tatalar",
    "tatalara": "tatalar",
    "tatalaram": "tatalar",
    "tatalaras": "tatalar",
    "tatalardes": "tatalar",
    "tatalarei": "tatalar",
    "tatalareis": "tatalar",
    "tatalarem": "tatalar",
    "tatalaremos": "tatalar",
    "tatalares": "tatalar",
    "tatalaria": "tatalar",
    "tatalariam": "tatalar",
    "tatalarias": "tatalar",
    "tatalarmo": "tatalar",
    "tatalarmos": "tatalar",
    "tatalará": "tatalar",
    "tatalarás": "tatalar",
    "tatalarão": "tatalar",
    "tatalaríamos": "tatalar",
    "tatalaríeis": "tatalar",
    "tatalas": "tatalar",
    "tatalasse": "tatalar",
    "tatalassem": "tatalar",
    "tatalasses": "tatalar",
    "tatalaste": "tatalar",
    "tatalastes": "tatalar",
    "tatalava": "tatalar",
    "tatalavam": "tatalar",
    "tatalavas": "tatalar",
    "tatale": "tatalar",
    "tatalei": "tatalar",
    "tataleis": "tatalar",
    "tatalem": "tatalar",
    "tatalemo": "tatalar",
    "tatalemos": "tatalar",
    "tatales": "tatalar",
    "tatalo": "tatalar",
    "tatalou": "tatalar",
    "tatalámo": "tatalar",
    "tatalámos": "tatalar",
    "tataláramo": "tatalar",
    "tataláramos": "tatalar",
    "tataláreis": "tatalar",
    "tatalásseis": "tatalar",
    "tatalássemos": "tatalar",
    "tatalávamo": "tatalar",
    "tatalávamos": "tatalar",
    "tataláveis": "tatalar",
    "tatamanduás": "tatamanduá",
    "tatambas": "tatamba",
    "tataraneta": "tataraneto",
    "tataranetas": "tataraneto",
    "tataranetos": "tataraneto",
    "tataranha": "tataranho",
    "tataranhada": "tataranhar",
    "tataranhadas": "tataranhar",
    "tataranhado": "tataranhar",
    "tataranhados": "tataranhar",
    "tataranhai": "tataranhar",
    "tataranhais": "tataranhar",
    "tataranham": "tataranhar",
    "tataranhamo": "tataranhar",
    "tataranhamos": "tataranhar",
    "tataranhando": "tataranhar",
    "tataranhara": "tataranhar",
    "tataranharam": "tataranhar",
    "tataranharas": "tataranhar",
    "tataranhardes": "tataranhar",
    "tataranharei": "tataranhar",
    "tataranhareis": "tataranhar",
    "tataranharem": "tataranhar",
    "tataranharemos": "tataranhar",
    "tataranhares": "tataranhar",
    "tataranharia": "tataranhar",
    "tataranhariam": "tataranhar",
    "tataranharias": "tataranhar",
    "tataranharmo": "tataranhar",
    "tataranharmos": "tataranhar",
    "tataranhará": "tataranhar",
    "tataranharás": "tataranhar",
    "tataranharão": "tataranhar",
    "tataranharíamos": "tataranhar",
    "tataranharíeis": "tataranhar",
    "tataranhas": "tataranho",
    "tataranhasse": "tataranhar",
    "tataranhassem": "tataranhar",
    "tataranhasses": "tataranhar",
    "tataranhaste": "tataranhar",
    "tataranhastes": "tataranhar",
    "tataranhava": "tataranhar",
    "tataranhavam": "tataranhar",
    "tataranhavas": "tataranhar",
    "tataranhe": "tataranhar",
    "tataranhei": "tataranhar",
    "tataranheis": "tataranhar",
    "tataranhem": "tataranhar",
    "tataranhemo": "tataranhar",
    "tataranhemos": "tataranhar",
    "tataranhes": "tataranhar",
    "tataranho": "tataranhar",
    "tataranhos": "tataranho",
    "tataranhou": "tataranhar",
    "tataranhámo": "tataranhar",
    "tataranhámos": "tataranhar",
    "tataranháramo": "tataranhar",
    "tataranháramos": "tataranhar",
    "tataranháreis": "tataranhar",
    "tataranhásseis": "tataranhar",
    "tataranhássemos": "tataranhar",
    "tataranhávamo": "tataranhar",
    "tataranhávamos": "tataranhar",
    "tataranháveis": "tataranhar",
    "tataranhões": "tataranhão",
    "tataravozinha": "tataravô",
    "tataravozinhas": "tataravô",
    "tataravozinho": "tataravô",
    "tataravozinhos": "tataravô",
    "tataravozita": "tataravô",
    "tataravozitas": "tataravô",
    "tataravozito": "tataravô",
    "tataravozitos": "tataravô",
    "tataravó": "tataravô",
    "tataravós": "tataravô",
    "tataravôs": "tataravô",
    "tataremas": "tatarema",
    "tatarezes": "tatarez",
    "tatas": "tato",
    "tataíbas": "tataíba",
    "tataís": "tataí",
    "tataúbas": "tataúba",
    "tatetos": "tateto",
    "tatibitates": "tatibitate",
    "tatos": "tato",
    "tatua": "tatuar",
    "tatuada": "tatuar",
    "tatuadas": "tatuar",
    "tatuadinha": "tatuado",
    "tatuadinhas": "tatuado",
    "tatuadinho": "tatuado",
    "tatuadinhos": "tatuado",
    "tatuadita": "tatuado",
    "tatuaditas": "tatuado",
    "tatuadito": "tatuado",
    "tatuaditos": "tatuado",
    "tatuado": "tatuar",
    "tatuadora": "tatuador",
    "tatuadoras": "tatuador",
    "tatuadores": "tatuador",
    "tatuados": "tatuar",
    "tatuadíssima": "tatuado",
    "tatuadíssimas": "tatuado",
    "tatuadíssimo": "tatuado",
    "tatuadíssimos": "tatuado",
    "tatuagens": "tatuagem",
    "tatuai": "tatuar",
    "tatuais": "tatuar",
    "tatuam": "tatuar",
    "tatuamo": "tatuar",
    "tatuamos": "tatuar",
    "tatuando": "tatuar",
    "tatuara": "tatuar",
    "tatuaram": "tatuar",
    "tatuaras": "tatuar",
    "tatuarde": "tatuar",
    "tatuardes": "tatuar",
    "tatuare": "tatuar",
    "tatuarei": "tatuar",
    "tatuareis": "tatuar",
    "tatuarem": "tatuar",
    "tatuaremos": "tatuar",
    "tatuares": "tatuar",
    "tatuaria": "tatuar",
    "tatuariam": "tatuar",
    "tatuarias": "tatuar",
    "tatuarmo": "tatuar",
    "tatuarmos": "tatuar",
    "tatuará": "tatuar",
    "tatuarás": "tatuar",
    "tatuarão": "tatuar",
    "tatuaríamos": "tatuar",
    "tatuaríeis": "tatuar",
    "tatuas": "tatuar",
    "tatuasse": "tatuar",
    "tatuassem": "tatuar",
    "tatuasses": "tatuar",
    "tatuaste": "tatuar",
    "tatuastes": "tatuar",
    "tatuava": "tatuar",
    "tatuavam": "tatuar",
    "tatuavas": "tatuar",
    "tatue": "tatuar",
    "tatuei": "tatuar",
    "tatueis": "tatuar",
    "tatuem": "tatuar",
    "tatuemo": "tatuar",
    "tatuemos": "tatuar",
    "tatues": "tatuar",
    "tatuo": "tatuar",
    "tatuou": "tatuar",
    "tatus": "tatu",
    "tatuá": "tatuar",
    "tatuámo": "tatuar",
    "tatuámos": "tatuar",
    "tatuáramo": "tatuar",
    "tatuáramos": "tatuar",
    "tatuárei": "tatuar",
    "tatuáreis": "tatuar",
    "tatuásseis": "tatuar",
    "tatuássemos": "tatuar",
    "tatuávamo": "tatuar",
    "tatuávamos": "tatuar",
    "tatuávei": "tatuar",
    "tatuáveis": "tatuável",
    "tauaçus": "tauaçu",
    "taubateana": "taubateano",
    "taubateanas": "taubateano",
    "taubateanos": "taubateano",
    "taubateenses": "taubateense",
    "taumaturga": "taumaturgo",
    "taumaturgas": "taumaturgo",
    "taumaturgias": "taumaturgia",
    "taumaturgos": "taumaturgo",
    "taumatúrgica": "taumatúrgico",
    "taumatúrgicas": "taumatúrgico",
    "taumatúrgicos": "taumatúrgico",
    "tauricidas": "tauricida",
    "tauricornes": "tauricorne",
    "tauricéfala": "tauricéfalo",
    "tauricéfalas": "tauricéfalo",
    "tauricéfalos": "tauricéfalo",
    "tauricídios": "tauricídio",
    "tauricórnea": "tauricórneo",
    "tauricórneas": "tauricórneo",
    "tauricórneos": "tauricórneo",
    "tauriformes": "tauriforme",
    "taurifrôntea": "taurifrônteo",
    "taurifrônteas": "taurifrônteo",
    "taurifrônteos": "taurifrônteo",
    "taurina": "taurino",
    "taurinas": "taurino",
    "taurinos": "taurino",
    "taurocatapsias": "taurocatapsia",
    "taurocéfala": "taurocéfalo",
    "taurocéfalas": "taurocéfalo",
    "taurocéfalos": "taurocéfalo",
    "tauromaquias": "tauromaquia",
    "tauromáquica": "tauromáquico",
    "tauromáquicas": "tauromáquico",
    "tauromáquicos": "tauromáquico",
    "tauromática": "tauromático",
    "tauromáticas": "tauromático",
    "tauromáticos": "tauromático",
    "tauros": "tauro",
    "taurífera": "taurífero",
    "tauríferas": "taurífero",
    "tauríferos": "taurífero",
    "tauródromos": "tauródromo",
    "taus": "tau",
    "tautaus": "tautau",
    "tautocronismos": "tautocronismo",
    "tautofonias": "tautofonia",
    "tautogramas": "tautograma",
    "tautologias": "tautologia",
    "tautológica": "tautológico",
    "tautológicas": "tautológico",
    "tautológicos": "tautológico",
    "tautomerias": "tautomeria",
    "tautomerismos": "tautomerismo",
    "tautometrias": "tautometria",
    "tautonímias": "tautonímia",
    "tautossilabismos": "tautossilabismo",
    "tautossilábica": "tautossilábico",
    "tautossilábicas": "tautossilábico",
    "tautossilábicos": "tautossilábico",
    "tautócrona": "tautócrono",
    "tautócronas": "tautócrono",
    "tautócronos": "tautócrono",
    "tautófona": "tautófono",
    "tautófonas": "tautófono",
    "tautófonos": "tautófono",
    "tautómera": "tautómero",
    "tautómeras": "tautómero",
    "tautómeros": "tautómero",
    "tautónima": "tautónimo",
    "tautónimas": "tautónimo",
    "tautónimos": "tautónimo",
    "tauxia": "tauxiar",
    "tauxiada": "tauxiar",
    "tauxiadas": "tauxiar",
    "tauxiado": "tauxiar",
    "tauxiados": "tauxiar",
    "tauxiai": "tauxiar",
    "tauxiais": "tauxiar",
    "tauxiam": "tauxiar",
    "tauxiamo": "tauxiar",
    "tauxiamos": "tauxiar",
    "tauxiando": "tauxiar",
    "tauxiara": "tauxiar",
    "tauxiaram": "tauxiar",
    "tauxiaras": "tauxiar",
    "tauxiarde": "tauxiar",
    "tauxiardes": "tauxiar",
    "tauxiare": "tauxiar",
    "tauxiarei": "tauxiar",
    "tauxiareis": "tauxiar",
    "tauxiarem": "tauxiar",
    "tauxiaremos": "tauxiar",
    "tauxiares": "tauxiar",
    "tauxiaria": "tauxiar",
    "tauxiariam": "tauxiar",
    "tauxiarias": "tauxiar",
    "tauxiarmo": "tauxiar",
    "tauxiarmos": "tauxiar",
    "tauxiará": "tauxiar",
    "tauxiarás": "tauxiar",
    "tauxiarão": "tauxiar",
    "tauxiaríamos": "tauxiar",
    "tauxiaríeis": "tauxiar",
    "tauxias": "tauxiar",
    "tauxiasse": "tauxiar",
    "tauxiassem": "tauxiar",
    "tauxiasses": "tauxiar",
    "tauxiaste": "tauxiar",
    "tauxiastes": "tauxiar",
    "tauxiava": "tauxiar",
    "tauxiavam": "tauxiar",
    "tauxiavas": "tauxiar",
    "tauxie": "tauxiar",
    "tauxiei": "tauxiar",
    "tauxieis": "tauxiar",
    "tauxiem": "tauxiar",
    "tauxiemo": "tauxiar",
    "tauxiemos": "tauxiar",
    "tauxies": "tauxiar",
    "tauxio": "tauxiar",
    "tauxiou": "tauxiar",
    "tauxiá": "tauxiar",
    "tauxiámo": "tauxiar",
    "tauxiámos": "tauxiar",
    "tauxiáramo": "tauxiar",
    "tauxiáramos": "tauxiar",
    "tauxiárei": "tauxiar",
    "tauxiáreis": "tauxiar",
    "tauxiásseis": "tauxiar",
    "tauxiássemos": "tauxiar",
    "tauxiávamo": "tauxiar",
    "tauxiávamos": "tauxiar",
    "tauxiávei": "tauxiar",
    "tauxiáveis": "tauxiável",
    "tauísmos": "tauísmo",
    "tauístas": "tauísta",
    "tavajibas": "tavajiba",
    "tavajubas": "tavajuba",
    "tavanesa": "tavanês",
    "tavanesas": "tavanês",
    "tavaneses": "tavanês",
    "tavernas": "taverna",
    "taverneira": "taverneiro",
    "taverneiras": "taverneiro",
    "taverneiros": "taverneiro",
    "tavolageira": "tavolageiro",
    "tavolageiras": "tavolageiro",
    "tavolageiros": "tavolageiro",
    "tavolagens": "tavolagem",
    "tavões": "tavão",
    "taxa": "taxar",
    "taxada": "taxar",
    "taxadas": "taxar",
    "taxadinha": "taxado",
    "taxadinhas": "taxado",
    "taxadinho": "taxado",
    "taxadinhos": "taxado",
    "taxadita": "taxado",
    "taxaditas": "taxado",
    "taxadito": "taxado",
    "taxaditos": "taxado",
    "taxado": "taxar",
    "taxadora": "taxador",
    "taxadoras": "taxador",
    "taxadores": "taxador",
    "taxados": "taxar",
    "taxadíssima": "taxado",
    "taxadíssimas": "taxado",
    "taxadíssimo": "taxado",
    "taxadíssimos": "taxado",
    "taxai": "taxar",
    "taxais": "taxar",
    "taxam": "taxar",
    "taxamo": "taxar",
    "taxamos": "taxar",
    "taxando": "taxar",
    "taxara": "taxar",
    "taxaram": "taxar",
    "taxaras": "taxar",
    "taxarde": "taxar",
    "taxardes": "taxar",
    "taxare": "taxar",
    "taxarei": "taxar",
    "taxareis": "taxar",
    "taxarem": "taxar",
    "taxaremos": "taxar",
    "taxares": "taxar",
    "taxaria": "taxar",
    "taxariam": "taxar",
    "taxarias": "taxar",
    "taxarmo": "taxar",
    "taxarmos": "taxar",
    "taxará": "taxar",
    "taxarás": "taxar",
    "taxarão": "taxar",
    "taxaríamos": "taxar",
    "taxaríeis": "taxar",
    "taxas": "taxar",
    "taxasse": "taxar",
    "taxassem": "taxar",
    "taxasses": "taxar",
    "taxaste": "taxar",
    "taxastes": "taxar",
    "taxativa": "taxativo",
    "taxativas": "taxativo",
    "taxativos": "taxativo",
    "taxava": "taxar",
    "taxavam": "taxar",
    "taxavas": "taxar",
    "taxações": "taxação",
    "taxe": "taxar",
    "taxei": "taxar",
    "taxeis": "taxar",
    "taxem": "taxar",
    "taxemo": "taxar",
    "taxemos": "taxar",
    "taxes": "taxar",
    "taxias": "taxia",
    "taxidermias": "taxidermia",
    "taxidermistas": "taxidermista",
    "taxidérmica": "taxidérmico",
    "taxidérmicas": "taxidérmico",
    "taxidérmicos": "taxidérmico",
    "taxiformes": "taxiforme",
    "taxilogias": "taxilogia",
    "taxilogistas": "taxilogista",
    "taxilógica": "taxilógico",
    "taxilógicas": "taxilógico",
    "taxilógicos": "taxilógico",
    "taxinomias": "taxinomia",
    "taxinomistas": "taxinomista",
    "taxinómica": "taxinómico",
    "taxinómicas": "taxinómico",
    "taxinómicos": "taxinómico",
    "taxiologias": "taxiologia",
    "taxiologistas": "taxiologista",
    "taxiológica": "taxiológico",
    "taxiológicas": "taxiológico",
    "taxiológicos": "taxiológico",
    "taxionomias": "taxionomia",
    "taxionomistas": "taxionomista",
    "taxionómica": "taxionómico",
    "taxionómicas": "taxionómico",
    "taxionómicos": "taxionómico",
    "taxis": "taxi",
    "taxistas": "taxista",
    "taxióloga": "taxiólogo",
    "taxiólogas": "taxiólogo",
    "taxiólogos": "taxiólogo",
    "taxo": "taxar",
    "taxodiáceas": "taxodiácea",
    "taxodontes": "taxodonte",
    "taxonomias": "taxonomia",
    "taxou": "taxar",
    "taxá": "taxar",
    "taxáceas": "taxácea",
    "taxámo": "taxar",
    "taxámos": "taxar",
    "taxáramo": "taxar",
    "taxáramos": "taxar",
    "taxárei": "taxar",
    "taxáreis": "taxar",
    "taxásseis": "taxar",
    "taxássemos": "taxar",
    "taxávamo": "taxar",
    "taxávamos": "taxar",
    "taxávei": "taxar",
    "taxáveis": "taxável",
    "taxícolas": "taxícola",
    "taxíloga": "taxílogo",
    "taxílogas": "taxílogo",
    "taxílogos": "taxílogo",
    "taxímetros": "taxímetro",
    "taylorismos": "taylorismo",
    "tayloristas": "taylorista",
    "taçadas": "taçada",
    "taças": "taça",
    "taçazinha": "taça",
    "taçazinhas": "taça",
    "taçazita": "taça",
    "taçazitas": "taça",
    "tchetchena": "tchetcheno",
    "tchetchenas": "tchetcheno",
    "tchetchenos": "tchetcheno",
    "teagens": "teagem",
    "teandrias": "teandria",
    "teares": "tear",
    "teatinos": "teatino",
    "teatradas": "teatrada",
    "teatrais": "teatral",
    "teatralidades": "teatralidade",
    "teatralismos": "teatralismo",
    "teatraliza": "teatralizar",
    "teatralizada": "teatralizar",
    "teatralizadas": "teatralizar",
    "teatralizado": "teatralizar",
    "teatralizados": "teatralizar",
    "teatralizai": "teatralizar",
    "teatralizais": "teatralizar",
    "teatralizam": "teatralizar",
    "teatralizamo": "teatralizar",
    "teatralizamos": "teatralizar",
    "teatralizando": "teatralizar",
    "teatralizara": "teatralizar",
    "teatralizaram": "teatralizar",
    "teatralizaras": "teatralizar",
    "teatralizarde": "teatralizar",
    "teatralizardes": "teatralizar",
    "teatralizare": "teatralizar",
    "teatralizarei": "teatralizar",
    "teatralizareis": "teatralizar",
    "teatralizarem": "teatralizar",
    "teatralizaremos": "teatralizar",
    "teatralizares": "teatralizar",
    "teatralizaria": "teatralizar",
    "teatralizariam": "teatralizar",
    "teatralizarias": "teatralizar",
    "teatralizarmo": "teatralizar",
    "teatralizarmos": "teatralizar",
    "teatralizará": "teatralizar",
    "teatralizarás": "teatralizar",
    "teatralizarão": "teatralizar",
    "teatralizaríamos": "teatralizar",
    "teatralizaríeis": "teatralizar",
    "teatralizas": "teatralizar",
    "teatralizasse": "teatralizar",
    "teatralizassem": "teatralizar",
    "teatralizasses": "teatralizar",
    "teatralizaste": "teatralizar",
    "teatralizastes": "teatralizar",
    "teatralizava": "teatralizar",
    "teatralizavam": "teatralizar",
    "teatralizavas": "teatralizar",
    "teatralizações": "teatralização",
    "teatralize": "teatralizar",
    "teatralizei": "teatralizar",
    "teatralizeis": "teatralizar",
    "teatralizem": "teatralizar",
    "teatralizemo": "teatralizar",
    "teatralizemos": "teatralizar",
    "teatralizes": "teatralizar",
    "teatralizo": "teatralizar",
    "teatralizou": "teatralizar",
    "teatralizá": "teatralizar",
    "teatralizámo": "teatralizar",
    "teatralizámos": "teatralizar",
    "teatralizáramo": "teatralizar",
    "teatralizáramos": "teatralizar",
    "teatralizárei": "teatralizar",
    "teatralizáreis": "teatralizar",
    "teatralizásseis": "teatralizar",
    "teatralizássemos": "teatralizar",
    "teatralizávamo": "teatralizar",
    "teatralizávamos": "teatralizar",
    "teatralizávei": "teatralizar",
    "teatralizáveis": "teatralizável",
    "teatrecos": "teatreco",
    "teatrelhos": "teatrelho",
    "teatrinho": "teatro",
    "teatrinhos": "teatro",
    "teatristas": "teatrista",
    "teatrito": "teatro",
    "teatritos": "teatro",
    "teatros": "teatro",
    "teatroterapias": "teatroterapia",
    "teatrozinho": "teatro",
    "teatrozinhos": "teatro",
    "teatrozito": "teatro",
    "teatrozitos": "teatro",
    "teatróloga": "teatrólogo",
    "teatrólogas": "teatrólogo",
    "teatrólogos": "teatrólogo",
    "teatrórios": "teatrório",
    "teaças": "teaça",
    "tebaica": "tebaico",
    "tebaicas": "tebaico",
    "tebaicos": "tebaico",
    "tebaidas": "tebaida",
    "tebana": "tebano",
    "tebanas": "tebano",
    "tebanos": "tebano",
    "tecamebas": "tecameba",
    "tecas": "teca",
    "tece": "tecer",
    "tecedeira": "tecedor",
    "tecedeiras": "tecedor",
    "tecedora": "tecedor",
    "tecedoras": "tecedor",
    "tecedores": "tecedor",
    "teceduras": "tecedura",
    "tecei": "tecer",
    "teceis": "tecer",
    "tecelagens": "tecelagem",
    "tecelã": "tecelão",
    "tecelãos": "tecelão",
    "tecelãs": "tecelão",
    "tecem": "tecer",
    "tecemo": "tecer",
    "tecemos": "tecer",
    "tecendo": "tecer",
    "tecera": "tecer",
    "teceram": "tecer",
    "teceras": "tecer",
    "tecerde": "tecer",
    "tecerdes": "tecer",
    "tecere": "tecer",
    "tecerei": "tecer",
    "tecereis": "tecer",
    "tecerem": "tecer",
    "teceremos": "tecer",
    "teceres": "tecer",
    "teceria": "tecer",
    "teceriam": "tecer",
    "tecerias": "tecer",
    "tecermo": "tecer",
    "tecermos": "tecer",
    "tecerá": "tecer",
    "tecerás": "tecer",
    "tecerão": "tecer",
    "teceríamos": "tecer",
    "teceríeis": "tecer",
    "teces": "tecer",
    "tecesse": "tecer",
    "tecessem": "tecer",
    "tecesses": "tecer",
    "teceste": "tecer",
    "tecestes": "tecer",
    "teceu": "tecer",
    "teci": "tecer",
    "tecia": "tecer",
    "teciam": "tecer",
    "tecias": "tecer",
    "tecida": "tecido",
    "tecidas": "tecido",
    "tecidinha": "tecido",
    "tecidinhas": "tecido",
    "tecidinho": "tecido",
    "tecidinhos": "tecido",
    "tecidita": "tecido",
    "teciditas": "tecido",
    "tecidito": "tecido",
    "teciditos": "tecido",
    "tecido": "tecer",
    "tecidos": "tecido",
    "teciduais": "tecidual",
    "tecidíssima": "tecido",
    "tecidíssimas": "tecido",
    "tecidíssimo": "tecido",
    "tecidíssimos": "tecido",
    "teclados": "teclado",
    "teclas": "tecla",
    "teclistas": "teclista",
    "tecnicidades": "tecnicidade",
    "tecnicismos": "tecnicismo",
    "tecnicistas": "tecnicista",
    "tecnicolores": "tecnicolor",
    "tecnismos": "tecnismo",
    "tecnocracias": "tecnocracia",
    "tecnocratas": "tecnocrata",
    "tecnocratizações": "tecnocratização",
    "tecnocrática": "tecnocrático",
    "tecnocráticas": "tecnocrático",
    "tecnocráticos": "tecnocrático",
    "tecnografias": "tecnografia",
    "tecnográfica": "tecnográfico",
    "tecnográficas": "tecnográfico",
    "tecnográficos": "tecnográfico",
    "tecnologias": "tecnologia",
    "tecnologistas": "tecnologista",
    "tecnológica": "tecnológico",
    "tecnológicas": "tecnológico",
    "tecnológicos": "tecnológico",
    "tecnopsicologias": "tecnopsicologia",
    "tecnécios": "tecnécio",
    "tecnógrafa": "tecnógrafo",
    "tecnógrafas": "tecnógrafo",
    "tecnógrafos": "tecnógrafo",
    "tecnóloga": "tecnólogo",
    "tecnólogas": "tecnólogo",
    "tecnólogos": "tecnólogo",
    "tecodontes": "tecodonte",
    "tecticos": "tectico",
    "tectiformes": "tectiforme",
    "tectogéneses": "tectogénese",
    "tectonitos": "tectonito",
    "tectoniza": "tectonizar",
    "tectonizada": "tectonizar",
    "tectonizadas": "tectonizar",
    "tectonizado": "tectonizar",
    "tectonizados": "tectonizar",
    "tectonizai": "tectonizar",
    "tectonizais": "tectonizar",
    "tectonizam": "tectonizar",
    "tectonizamo": "tectonizar",
    "tectonizamos": "tectonizar",
    "tectonizando": "tectonizar",
    "tectonizara": "tectonizar",
    "tectonizaram": "tectonizar",
    "tectonizaras": "tectonizar",
    "tectonizarde": "tectonizar",
    "tectonizardes": "tectonizar",
    "tectonizare": "tectonizar",
    "tectonizarei": "tectonizar",
    "tectonizareis": "tectonizar",
    "tectonizarem": "tectonizar",
    "tectonizaremos": "tectonizar",
    "tectonizares": "tectonizar",
    "tectonizaria": "tectonizar",
    "tectonizariam": "tectonizar",
    "tectonizarias": "tectonizar",
    "tectonizarmo": "tectonizar",
    "tectonizarmos": "tectonizar",
    "tectonizará": "tectonizar",
    "tectonizarás": "tectonizar",
    "tectonizarão": "tectonizar",
    "tectonizaríamos": "tectonizar",
    "tectonizaríeis": "tectonizar",
    "tectonizas": "tectonizar",
    "tectonizasse": "tectonizar",
    "tectonizassem": "tectonizar",
    "tectonizasses": "tectonizar",
    "tectonizaste": "tectonizar",
    "tectonizastes": "tectonizar",
    "tectonizava": "tectonizar",
    "tectonizavam": "tectonizar",
    "tectonizavas": "tectonizar",
    "tectonizações": "tectonização",
    "tectonize": "tectonizar",
    "tectonizei": "tectonizar",
    "tectonizeis": "tectonizar",
    "tectonizem": "tectonizar",
    "tectonizemo": "tectonizar",
    "tectonizemos": "tectonizar",
    "tectonizes": "tectonizar",
    "tectonizo": "tectonizar",
    "tectonizou": "tectonizar",
    "tectonizá": "tectonizar",
    "tectonizámo": "tectonizar",
    "tectonizámos": "tectonizar",
    "tectonizáramo": "tectonizar",
    "tectonizáramos": "tectonizar",
    "tectonizárei": "tectonizar",
    "tectonizáreis": "tectonizar",
    "tectonizásseis": "tectonizar",
    "tectonizássemos": "tectonizar",
    "tectonizávamo": "tectonizar",
    "tectonizávamos": "tectonizar",
    "tectonizávei": "tectonizar",
    "tectonizáveis": "tectonizar",
    "tectos": "tecto",
    "tectrizes": "tectriz",
    "tectónica": "tectónico",
    "tectónicas": "tectónico",
    "tectónicos": "tectónico",
    "tecunas": "tecuna",
    "tecuns": "tecum",
    "tecê": "tecer",
    "tecêramo": "tecer",
    "tecêramos": "tecer",
    "tecêrei": "tecer",
    "tecêreis": "tecer",
    "tecêsseis": "tecer",
    "tecêssemos": "tecer",
    "tecíamo": "tecer",
    "tecíamos": "tecer",
    "tecíei": "tecer",
    "tecíeis": "tecer",
    "tecíveis": "tecível",
    "tecófora": "tecóforo",
    "tecóforas": "tecóforo",
    "tecóforos": "tecóforo",
    "tediosa": "tedioso",
    "tediosas": "tedioso",
    "tediosos": "tedioso",
    "tedífera": "tedífero",
    "tedíferas": "tedífero",
    "tedíferos": "tedífero",
    "tefigramas": "tefigrama",
    "tefromancias": "tefromancia",
    "tegmes": "tegme",
    "tegulares": "tegular",
    "tegumentares": "tegumentar",
    "tegumentos": "tegumento",
    "tegumentária": "tegumentário",
    "tegumentárias": "tegumentário",
    "tegumentários": "tegumentário",
    "tegões": "tegão",
    "teias": "teia",
    "teigas": "teiga",
    "teima": "teimar",
    "teimada": "teimar",
    "teimadas": "teimar",
    "teimado": "teimar",
    "teimados": "teimar",
    "teimai": "teimar",
    "teimais": "teimar",
    "teimam": "teimar",
    "teimamo": "teimar",
    "teimamos": "teimar",
    "teimando": "teimar",
    "teimara": "teimar",
    "teimaram": "teimar",
    "teimaras": "teimar",
    "teimardes": "teimar",
    "teimarei": "teimar",
    "teimareis": "teimar",
    "teimarem": "teimar",
    "teimaremos": "teimar",
    "teimares": "teimar",
    "teimaria": "teimar",
    "teimariam": "teimar",
    "teimarias": "teimar",
    "teimarmo": "teimar",
    "teimarmos": "teimar",
    "teimará": "teimar",
    "teimarás": "teimar",
    "teimarão": "teimar",
    "teimaríamos": "teimar",
    "teimaríeis": "teimar",
    "teimas": "teimar",
    "teimasse": "teimar",
    "teimassem": "teimar",
    "teimasses": "teimar",
    "teimaste": "teimar",
    "teimastes": "teimar",
    "teimava": "teimar",
    "teimavam": "teimar",
    "teimavas": "teimar",
    "teime": "teimar",
    "teimei": "teimar",
    "teimeis": "teimar",
    "teimem": "teimar",
    "teimemo": "teimar",
    "teimemos": "teimar",
    "teimes": "teimar",
    "teimices": "teimice",
    "teimo": "teimar",
    "teimosa": "teimoso",
    "teimosas": "teimoso",
    "teimosias": "teimosia",
    "teimosices": "teimosice",
    "teimosinha": "teimoso",
    "teimosinhas": "teimoso",
    "teimosinho": "teimoso",
    "teimosinhos": "teimoso",
    "teimosita": "teimoso",
    "teimositas": "teimoso",
    "teimosito": "teimoso",
    "teimositos": "teimoso",
    "teimosos": "teimoso",
    "teimosíssima": "teimoso",
    "teimosíssimas": "teimoso",
    "teimosíssimo": "teimoso",
    "teimosíssimos": "teimoso",
    "teimou": "teimar",
    "teimámo": "teimar",
    "teimámos": "teimar",
    "teimáramo": "teimar",
    "teimáramos": "teimar",
    "teimáreis": "teimar",
    "teimásseis": "teimar",
    "teimássemos": "teimar",
    "teimávamo": "teimar",
    "teimávamos": "teimar",
    "teimáveis": "teimar",
    "teirogas": "teiroga",
    "teixes": "teixe",
    "teixos": "teixo",
    "teixugos": "teixugo",
    "tejadilhos": "tejadilho",
    "tejagilhos": "tejagilho",
    "tejoilas": "tejoila",
    "tejos": "tejo",
    "tejoulas": "tejoula",
    "tejuaçus": "tejuaçu",
    "tejus": "teju",
    "tejídeos": "tejídeo",
    "telagarças": "telagarça",
    "telalgias": "telalgia",
    "telamões": "telamão",
    "telangiectasias": "telangiectasia",
    "telangiomas": "telangioma",
    "telas": "tela",
    "telautógrafos": "telautógrafo",
    "telecomanda": "telecomandar",
    "telecomandada": "telecomandar",
    "telecomandadas": "telecomandar",
    "telecomandado": "telecomandar",
    "telecomandados": "telecomandar",
    "telecomandai": "telecomandar",
    "telecomandais": "telecomandar",
    "telecomandam": "telecomandar",
    "telecomandamo": "telecomandar",
    "telecomandamos": "telecomandar",
    "telecomandando": "telecomandar",
    "telecomandara": "telecomandar",
    "telecomandaram": "telecomandar",
    "telecomandaras": "telecomandar",
    "telecomandarde": "telecomandar",
    "telecomandardes": "telecomandar",
    "telecomandare": "telecomandar",
    "telecomandarei": "telecomandar",
    "telecomandareis": "telecomandar",
    "telecomandarem": "telecomandar",
    "telecomandaremos": "telecomandar",
    "telecomandares": "telecomandar",
    "telecomandaria": "telecomandar",
    "telecomandariam": "telecomandar",
    "telecomandarias": "telecomandar",
    "telecomandarmo": "telecomandar",
    "telecomandarmos": "telecomandar",
    "telecomandará": "telecomandar",
    "telecomandarás": "telecomandar",
    "telecomandarão": "telecomandar",
    "telecomandaríamos": "telecomandar",
    "telecomandaríeis": "telecomandar",
    "telecomandas": "telecomandar",
    "telecomandasse": "telecomandar",
    "telecomandassem": "telecomandar",
    "telecomandasses": "telecomandar",
    "telecomandaste": "telecomandar",
    "telecomandastes": "telecomandar",
    "telecomandava": "telecomandar",
    "telecomandavam": "telecomandar",
    "telecomandavas": "telecomandar",
    "telecomande": "telecomandar",
    "telecomandei": "telecomandar",
    "telecomandeis": "telecomandar",
    "telecomandem": "telecomandar",
    "telecomandemo": "telecomandar",
    "telecomandemos": "telecomandar",
    "telecomandes": "telecomandar",
    "telecomando": "telecomandar",
    "telecomandos": "telecomando",
    "telecomandou": "telecomandar",
    "telecomandá": "telecomandar",
    "telecomandámo": "telecomandar",
    "telecomandámos": "telecomandar",
    "telecomandáramo": "telecomandar",
    "telecomandáramos": "telecomandar",
    "telecomandárei": "telecomandar",
    "telecomandáreis": "telecomandar",
    "telecomandásseis": "telecomandar",
    "telecomandássemos": "telecomandar",
    "telecomandávamo": "telecomandar",
    "telecomandávamos": "telecomandar",
    "telecomandávei": "telecomandar",
    "telecomandáveis": "telecomandável",
    "telecomunicações": "telecomunicação",
    "teleconferências": "teleconferência",
    "teleconógrafos": "teleconógrafo",
    "telecopiada": "telecopiado",
    "telecopiadas": "telecopiado",
    "telecopiados": "telecopiado",
    "telecópias": "telecópia",
    "teledetecta": "teledetectar",
    "teledetectada": "teledetectar",
    "teledetectadas": "teledetectar",
    "teledetectado": "teledetectar",
    "teledetectados": "teledetectar",
    "teledetectai": "teledetectar",
    "teledetectais": "teledetectar",
    "teledetectam": "teledetectar",
    "teledetectamo": "teledetectar",
    "teledetectamos": "teledetectar",
    "teledetectando": "teledetectar",
    "teledetectara": "teledetectar",
    "teledetectaram": "teledetectar",
    "teledetectaras": "teledetectar",
    "teledetectarde": "teledetectar",
    "teledetectardes": "teledetectar",
    "teledetectare": "teledetectar",
    "teledetectarei": "teledetectar",
    "teledetectareis": "teledetectar",
    "teledetectarem": "teledetectar",
    "teledetectaremos": "teledetectar",
    "teledetectares": "teledetectar",
    "teledetectaria": "teledetectar",
    "teledetectariam": "teledetectar",
    "teledetectarias": "teledetectar",
    "teledetectarmo": "teledetectar",
    "teledetectarmos": "teledetectar",
    "teledetectará": "teledetectar",
    "teledetectarás": "teledetectar",
    "teledetectarão": "teledetectar",
    "teledetectaríamos": "teledetectar",
    "teledetectaríeis": "teledetectar",
    "teledetectas": "teledetectar",
    "teledetectasse": "teledetectar",
    "teledetectassem": "teledetectar",
    "teledetectasses": "teledetectar",
    "teledetectaste": "teledetectar",
    "teledetectastes": "teledetectar",
    "teledetectava": "teledetectar",
    "teledetectavam": "teledetectar",
    "teledetectavas": "teledetectar",
    "teledetecte": "teledetectar",
    "teledetectei": "teledetectar",
    "teledetecteis": "teledetectar",
    "teledetectem": "teledetectar",
    "teledetectemo": "teledetectar",
    "teledetectemos": "teledetectar",
    "teledetectes": "teledetectar",
    "teledetecto": "teledetectar",
    "teledetectou": "teledetectar",
    "teledetectá": "teledetectar",
    "teledetectámo": "teledetectar",
    "teledetectámos": "teledetectar",
    "teledetectáramo": "teledetectar",
    "teledetectáramos": "teledetectar",
    "teledetectárei": "teledetectar",
    "teledetectáreis": "teledetectar",
    "teledetectásseis": "teledetectar",
    "teledetectássemos": "teledetectar",
    "teledetectávamo": "teledetectar",
    "teledetectávamos": "teledetectar",
    "teledetectávei": "teledetectar",
    "teledetectáveis": "teledetectável",
    "teledifundida": "teledifundido",
    "teledifundidas": "teledifundido",
    "teledifundidos": "teledifundido",
    "teledifusões": "teledifusão",
    "teledinâmica": "teledinâmico",
    "teledinâmicas": "teledinâmico",
    "teledinâmicos": "teledinâmico",
    "teledirige": "teledirigir",
    "teledirigem": "teledirigir",
    "telediriges": "teledirigir",
    "teledirigi": "teledirigir",
    "teledirigia": "teledirigir",
    "teledirigiam": "teledirigir",
    "teledirigias": "teledirigir",
    "teledirigida": "teledirigir",
    "teledirigidas": "teledirigir",
    "teledirigido": "teledirigir",
    "teledirigidos": "teledirigir",
    "teledirigimo": "teledirigir",
    "teledirigimos": "teledirigir",
    "teledirigindo": "teledirigir",
    "teledirigira": "teledirigir",
    "teledirigiram": "teledirigir",
    "teledirigiras": "teledirigir",
    "teledirigirde": "teledirigir",
    "teledirigirdes": "teledirigir",
    "teledirigire": "teledirigir",
    "teledirigirei": "teledirigir",
    "teledirigireis": "teledirigir",
    "teledirigirem": "teledirigir",
    "teledirigiremos": "teledirigir",
    "teledirigires": "teledirigir",
    "teledirigiria": "teledirigir",
    "teledirigiriam": "teledirigir",
    "teledirigirias": "teledirigir",
    "teledirigirmo": "teledirigir",
    "teledirigirmos": "teledirigir",
    "teledirigirá": "teledirigir",
    "teledirigirás": "teledirigir",
    "teledirigirão": "teledirigir",
    "teledirigiríamos": "teledirigir",
    "teledirigiríeis": "teledirigir",
    "teledirigis": "teledirigir",
    "teledirigisse": "teledirigir",
    "teledirigissem": "teledirigir",
    "teledirigisses": "teledirigir",
    "teledirigiste": "teledirigir",
    "teledirigistes": "teledirigir",
    "teledirigiu": "teledirigir",
    "teledirigíamo": "teledirigir",
    "teledirigíamos": "teledirigir",
    "teledirigíei": "teledirigir",
    "teledirigíeis": "teledirigir",
    "teledirigíramo": "teledirigir",
    "teledirigíramos": "teledirigir",
    "teledirigírei": "teledirigir",
    "teledirigíreis": "teledirigir",
    "teledirigísseis": "teledirigir",
    "teledirigíssemos": "teledirigir",
    "teledirigíveis": "teledirigível",
    "teledirija": "teledirigir",
    "teledirijais": "teledirigir",
    "teledirijam": "teledirigir",
    "teledirijamo": "teledirigir",
    "teledirijamos": "teledirigir",
    "teledirijas": "teledirigir",
    "teledirijo": "teledirigir",
    "telediscos": "teledisco",
    "telefaxes": "telefax",
    "telefilmes": "telefilme",
    "telefona": "telefonar",
    "telefonada": "telefonar",
    "telefonadas": "telefonar",
    "telefonadelas": "telefonadela",
    "telefonado": "telefonar",
    "telefonados": "telefonar",
    "telefonai": "telefonar",
    "telefonais": "telefonar",
    "telefonam": "telefonar",
    "telefonamo": "telefonar",
    "telefonamos": "telefonar",
    "telefonando": "telefonar",
    "telefonara": "telefonar",
    "telefonaram": "telefonar",
    "telefonaras": "telefonar",
    "telefonardes": "telefonar",
    "telefonarei": "telefonar",
    "telefonareis": "telefonar",
    "telefonarem": "telefonar",
    "telefonaremos": "telefonar",
    "telefonares": "telefonar",
    "telefonaria": "telefonar",
    "telefonariam": "telefonar",
    "telefonarias": "telefonar",
    "telefonarmo": "telefonar",
    "telefonarmos": "telefonar",
    "telefonará": "telefonar",
    "telefonarás": "telefonar",
    "telefonarão": "telefonar",
    "telefonaríamos": "telefonar",
    "telefonaríeis": "telefonar",
    "telefonas": "telefonar",
    "telefonasse": "telefonar",
    "telefonassem": "telefonar",
    "telefonasses": "telefonar",
    "telefonaste": "telefonar",
    "telefonastes": "telefonar",
    "telefonava": "telefonar",
    "telefonavam": "telefonar",
    "telefonavas": "telefonar",
    "telefone": "telefonar",
    "telefonei": "telefonar",
    "telefoneis": "telefonar",
    "telefonem": "telefonar",
    "telefonemas": "telefonema",
    "telefonemo": "telefonar",
    "telefonemos": "telefonar",
    "telefones": "telefone",
    "telefonias": "telefonia",
    "telefonistas": "telefonista",
    "telefono": "telefonar",
    "telefonou": "telefonar",
    "telefonámo": "telefonar",
    "telefonámos": "telefonar",
    "telefonáramo": "telefonar",
    "telefonáramos": "telefonar",
    "telefonáreis": "telefonar",
    "telefonásseis": "telefonar",
    "telefonássemos": "telefonar",
    "telefonávamo": "telefonar",
    "telefonávamos": "telefonar",
    "telefonáveis": "telefonar",
    "telefotografias": "telefotografia",
    "telefotográfica": "telefotográfico",
    "telefotográficas": "telefotográfico",
    "telefotográficos": "telefotográfico",
    "telefotometrias": "telefotometria",
    "telefotos": "telefoto",
    "telefotógrafa": "telefotógrafo",
    "telefotógrafas": "telefotógrafo",
    "telefotógrafos": "telefotógrafo",
    "teleféricos": "teleférico",
    "telefónica": "telefónico",
    "telefónicas": "telefónico",
    "telefónicos": "telefónico",
    "telegas": "telega",
    "telegenias": "telegenia",
    "telegonias": "telegonia",
    "telegrafa": "telegrafar",
    "telegrafada": "telegrafar",
    "telegrafadas": "telegrafar",
    "telegrafado": "telegrafar",
    "telegrafados": "telegrafar",
    "telegrafai": "telegrafar",
    "telegrafais": "telegrafar",
    "telegrafam": "telegrafar",
    "telegrafamo": "telegrafar",
    "telegrafamos": "telegrafar",
    "telegrafando": "telegrafar",
    "telegrafara": "telegrafar",
    "telegrafaram": "telegrafar",
    "telegrafaras": "telegrafar",
    "telegrafarde": "telegrafar",
    "telegrafardes": "telegrafar",
    "telegrafare": "telegrafar",
    "telegrafarei": "telegrafar",
    "telegrafareis": "telegrafar",
    "telegrafarem": "telegrafar",
    "telegrafaremos": "telegrafar",
    "telegrafares": "telegrafar",
    "telegrafaria": "telegrafar",
    "telegrafariam": "telegrafar",
    "telegrafarias": "telegrafar",
    "telegrafarmo": "telegrafar",
    "telegrafarmos": "telegrafar",
    "telegrafará": "telegrafar",
    "telegrafarás": "telegrafar",
    "telegrafarão": "telegrafar",
    "telegrafaríamos": "telegrafar",
    "telegrafaríeis": "telegrafar",
    "telegrafas": "telegrafar",
    "telegrafasse": "telegrafar",
    "telegrafassem": "telegrafar",
    "telegrafasses": "telegrafar",
    "telegrafaste": "telegrafar",
    "telegrafastes": "telegrafar",
    "telegrafava": "telegrafar",
    "telegrafavam": "telegrafar",
    "telegrafavas": "telegrafar",
    "telegrafe": "telegrafar",
    "telegrafei": "telegrafar",
    "telegrafeis": "telegrafar",
    "telegrafem": "telegrafar",
    "telegrafemo": "telegrafar",
    "telegrafemos": "telegrafar",
    "telegrafes": "telegrafar",
    "telegrafias": "telegrafia",
    "telegrafistas": "telegrafista",
    "telegrafo": "telegrafar",
    "telegrafou": "telegrafar",
    "telegrafá": "telegrafar",
    "telegrafámo": "telegrafar",
    "telegrafámos": "telegrafar",
    "telegrafáramo": "telegrafar",
    "telegrafáramos": "telegrafar",
    "telegrafárei": "telegrafar",
    "telegrafáreis": "telegrafar",
    "telegrafásseis": "telegrafar",
    "telegrafássemos": "telegrafar",
    "telegrafávamo": "telegrafar",
    "telegrafávamos": "telegrafar",
    "telegrafávei": "telegrafar",
    "telegrafáveis": "telegrafável",
    "telegramas": "telegrama",
    "telegráfica": "telegráfico",
    "telegráficas": "telegráfico",
    "telegráficos": "telegráfico",
    "teleguia": "teleguiar",
    "teleguiada": "teleguiar",
    "teleguiadas": "teleguiar",
    "teleguiado": "teleguiar",
    "teleguiados": "teleguiar",
    "teleguiai": "teleguiar",
    "teleguiais": "teleguiar",
    "teleguiam": "teleguiar",
    "teleguiamo": "teleguiar",
    "teleguiamos": "teleguiar",
    "teleguiando": "teleguiar",
    "teleguiara": "teleguiar",
    "teleguiaram": "teleguiar",
    "teleguiaras": "teleguiar",
    "teleguiarde": "teleguiar",
    "teleguiardes": "teleguiar",
    "teleguiare": "teleguiar",
    "teleguiarei": "teleguiar",
    "teleguiareis": "teleguiar",
    "teleguiarem": "teleguiar",
    "teleguiaremos": "teleguiar",
    "teleguiares": "teleguiar",
    "teleguiaria": "teleguiar",
    "teleguiariam": "teleguiar",
    "teleguiarias": "teleguiar",
    "teleguiarmo": "teleguiar",
    "teleguiarmos": "teleguiar",
    "teleguiará": "teleguiar",
    "teleguiarás": "teleguiar",
    "teleguiarão": "teleguiar",
    "teleguiaríamos": "teleguiar",
    "teleguiaríeis": "teleguiar",
    "teleguias": "teleguiar",
    "teleguiasse": "teleguiar",
    "teleguiassem": "teleguiar",
    "teleguiasses": "teleguiar",
    "teleguiaste": "teleguiar",
    "teleguiastes": "teleguiar",
    "teleguiava": "teleguiar",
    "teleguiavam": "teleguiar",
    "teleguiavas": "teleguiar",
    "teleguie": "teleguiar",
    "teleguiei": "teleguiar",
    "teleguieis": "teleguiar",
    "teleguiem": "teleguiar",
    "teleguiemo": "teleguiar",
    "teleguiemos": "teleguiar",
    "teleguies": "teleguiar",
    "teleguio": "teleguiar",
    "teleguiou": "teleguiar",
    "teleguiá": "teleguiar",
    "teleguiámo": "teleguiar",
    "teleguiámos": "teleguiar",
    "teleguiáramo": "teleguiar",
    "teleguiáramos": "teleguiar",
    "teleguiárei": "teleguiar",
    "teleguiáreis": "teleguiar",
    "teleguiásseis": "teleguiar",
    "teleguiássemos": "teleguiar",
    "teleguiávamo": "teleguiar",
    "teleguiávamos": "teleguiar",
    "teleguiávei": "teleguiar",
    "teleguiáveis": "teleguiável",
    "telegénica": "telegénico",
    "telegénicas": "telegénico",
    "telegénicos": "telegénico",
    "teleimpressoras": "teleimpressora",
    "teleimpressores": "teleimpressor",
    "telejornais": "telejornal",
    "telemetrias": "telemetria",
    "telemetristas": "telemetrista",
    "telemicrofones": "telemicrofone",
    "telemobilizada": "telemobilizado",
    "telemobilizadas": "telemobilizado",
    "telemobilizados": "telemobilizado",
    "telemáticas": "telemática",
    "telemétrica": "telemétrico",
    "telemétricas": "telemétrico",
    "telemétricos": "telemétrico",
    "telemóveis": "telemóvel",
    "telencefalizações": "telencefalização",
    "telencéfalos": "telencéfalo",
    "telenovelas": "telenovela",
    "telenovelesca": "telenovelesco",
    "telenovelescas": "telenovelesco",
    "telenovelescos": "telenovelesco",
    "teleobjectivas": "teleobjectiva",
    "teleologias": "teleologia",
    "teleológica": "teleológico",
    "teleológicas": "teleológico",
    "teleológicos": "teleológico",
    "teleossáurios": "teleossáurio",
    "telepatas": "telepata",
    "telepatazinha": "telepata",
    "telepatazinhas": "telepata",
    "telepatazinho": "telepata",
    "telepatazinhos": "telepata",
    "telepatazita": "telepata",
    "telepatazitas": "telepata",
    "telepatazito": "telepata",
    "telepatazitos": "telepata",
    "telepatias": "telepatia",
    "telepizzas": "telepizza",
    "telepontos": "teleponto",
    "teleprocessada": "teleprocessado",
    "teleprocessadas": "teleprocessado",
    "teleprocessados": "teleprocessado",
    "teleprojéctis": "teleprojéctil",
    "telepática": "telepático",
    "telepáticas": "telepático",
    "telepáticos": "telepático",
    "telequinesias": "telequinesia",
    "teles": "tele",
    "telescolas": "telescola",
    "telescopias": "telescopia",
    "telescritora": "telescritor",
    "telescritoras": "telescritor",
    "telescritores": "telescritor",
    "telescópica": "telescópico",
    "telescópicas": "telescópico",
    "telescópicos": "telescópico",
    "telescópios": "telescópio",
    "telespectadora": "telespectador",
    "telespectadoras": "telespectador",
    "telespectadores": "telespectador",
    "telessismos": "telessismo",
    "telessismógrafos": "telessismógrafo",
    "telessondas": "telessonda",
    "telestereógrafos": "telestereógrafo",
    "teletextos": "teletexto",
    "teletrabalhos": "teletrabalho",
    "teletransmissões": "teletransmissão",
    "televede": "telever",
    "televedes": "telever",
    "televeja": "telever",
    "televejais": "telever",
    "televejam": "telever",
    "televejamo": "telever",
    "televejamos": "telever",
    "televejas": "telever",
    "televejo": "telever",
    "televemo": "telever",
    "televemos": "telever",
    "televendo": "telever",
    "televerde": "telever",
    "televerdes": "telever",
    "televere": "telever",
    "televerei": "telever",
    "televereis": "telever",
    "televerem": "telever",
    "televeremos": "telever",
    "televeres": "telever",
    "televeria": "telever",
    "televeriam": "telever",
    "televerias": "telever",
    "televermo": "telever",
    "televermos": "telever",
    "televerá": "telever",
    "televerás": "telever",
    "televerão": "telever",
    "televeríamos": "telever",
    "televeríeis": "telever",
    "televi": "telever",
    "televia": "telever",
    "televiam": "telever",
    "televias": "telever",
    "televimo": "telever",
    "televimos": "telever",
    "televir": "telever",
    "televira": "telever",
    "televiram": "telever",
    "televiras": "telever",
    "televirdes": "telever",
    "televirem": "telever",
    "televires": "telever",
    "televirmos": "telever",
    "televisionada": "televisionado",
    "televisionadas": "televisionado",
    "televisionados": "televisionado",
    "televisiva": "televisivo",
    "televisivas": "televisivo",
    "televisivos": "televisivo",
    "televisores": "televisor",
    "televisse": "telever",
    "televissem": "telever",
    "televisses": "telever",
    "televista": "telever",
    "televistas": "telever",
    "televiste": "telever",
    "televistes": "telever",
    "televisto": "telever",
    "televistos": "telever",
    "televisões": "televisão",
    "televiu": "telever",
    "televê": "telever",
    "televêem": "telever",
    "televês": "telever",
    "televíamo": "telever",
    "televíamos": "telever",
    "televíei": "telever",
    "televíeis": "telever",
    "televíramo": "telever",
    "televíramos": "telever",
    "televírei": "telever",
    "televíreis": "telever",
    "televísseis": "telever",
    "televíssemos": "telever",
    "telexa": "telexar",
    "telexada": "telexar",
    "telexadas": "telexar",
    "telexado": "telexar",
    "telexados": "telexar",
    "telexai": "telexar",
    "telexais": "telexar",
    "telexam": "telexar",
    "telexamo": "telexar",
    "telexamos": "telexar",
    "telexando": "telexar",
    "telexara": "telexar",
    "telexaram": "telexar",
    "telexaras": "telexar",
    "telexarde": "telexar",
    "telexardes": "telexar",
    "telexare": "telexar",
    "telexarei": "telexar",
    "telexareis": "telexar",
    "telexarem": "telexar",
    "telexaremos": "telexar",
    "telexares": "telexar",
    "telexaria": "telexar",
    "telexariam": "telexar",
    "telexarias": "telexar",
    "telexarmo": "telexar",
    "telexarmos": "telexar",
    "telexará": "telexar",
    "telexarás": "telexar",
    "telexarão": "telexar",
    "telexaríamos": "telexar",
    "telexaríeis": "telexar",
    "telexas": "telexar",
    "telexasse": "telexar",
    "telexassem": "telexar",
    "telexasses": "telexar",
    "telexaste": "telexar",
    "telexastes": "telexar",
    "telexava": "telexar",
    "telexavam": "telexar",
    "telexavas": "telexar",
    "telexe": "telexar",
    "telexei": "telexar",
    "telexeis": "telexar",
    "telexem": "telexar",
    "telexemo": "telexar",
    "telexemos": "telexar",
    "telexes": "telexar",
    "telexo": "telexar",
    "telexou": "telexar",
    "telexá": "telexar",
    "telexámo": "telexar",
    "telexámos": "telexar",
    "telexáramo": "telexar",
    "telexáramos": "telexar",
    "telexárei": "telexar",
    "telexáreis": "telexar",
    "telexásseis": "telexar",
    "telexássemos": "telexar",
    "telexávamo": "telexar",
    "telexávamos": "telexar",
    "telexávei": "telexar",
    "telexáveis": "telexar",
    "teleóstea": "teleósteo",
    "teleósteas": "teleósteo",
    "teleósteos": "teleósteo",
    "teleóstoma": "teleóstomo",
    "teleóstomas": "teleóstomo",
    "teleóstomos": "teleóstomo",
    "telha": "telhar",
    "telhada": "telhar",
    "telhadas": "telhar",
    "telhado": "telhar",
    "telhadora": "telhador",
    "telhadoras": "telhador",
    "telhadores": "telhador",
    "telhados": "telhar",
    "telhaduras": "telhadura",
    "telhai": "telhar",
    "telhais": "telhar",
    "telham": "telhar",
    "telhamo": "telhar",
    "telhamos": "telhar",
    "telhando": "telhar",
    "telhara": "telhar",
    "telharam": "telhar",
    "telharas": "telhar",
    "telharde": "telhar",
    "telhardes": "telhar",
    "telhare": "telhar",
    "telharei": "telhar",
    "telhareis": "telhar",
    "telharem": "telhar",
    "telharemos": "telhar",
    "telhares": "telhar",
    "telharia": "telhar",
    "telhariam": "telhar",
    "telharias": "telhar",
    "telharmo": "telhar",
    "telharmos": "telhar",
    "telhará": "telhar",
    "telharás": "telhar",
    "telharão": "telhar",
    "telharíamos": "telhar",
    "telharíeis": "telhar",
    "telhas": "telhar",
    "telhasse": "telhar",
    "telhassem": "telhar",
    "telhasses": "telhar",
    "telhaste": "telhar",
    "telhastes": "telhar",
    "telhava": "telhar",
    "telhavam": "telhar",
    "telhavas": "telhar",
    "telhe": "telhar",
    "telhei": "telhar",
    "telheira": "telheiro",
    "telheiras": "telheiro",
    "telheiros": "telheiro",
    "telheis": "telhar",
    "telhem": "telhar",
    "telhemo": "telhar",
    "telhemos": "telhar",
    "telhes": "telhar",
    "telhices": "telhice",
    "telho": "telhar",
    "telhos": "telho",
    "telhou": "telhar",
    "telhuda": "telhudo",
    "telhudas": "telhudo",
    "telhudinha": "telhudo",
    "telhudinhas": "telhudo",
    "telhudinho": "telhudo",
    "telhudinhos": "telhudo",
    "telhudita": "telhudo",
    "telhuditas": "telhudo",
    "telhudito": "telhudo",
    "telhuditos": "telhudo",
    "telhudos": "telhudo",
    "telhudíssima": "telhudo",
    "telhudíssimas": "telhudo",
    "telhudíssimo": "telhudo",
    "telhudíssimos": "telhudo",
    "telhá": "telhar",
    "telhámo": "telhar",
    "telhámos": "telhar",
    "telháramo": "telhar",
    "telháramos": "telhar",
    "telhárei": "telhar",
    "telháreis": "telhar",
    "telhásseis": "telhar",
    "telhássemos": "telhar",
    "telhávamo": "telhar",
    "telhávamos": "telhar",
    "telhávei": "telhar",
    "telháveis": "telhável",
    "telhões": "telhão",
    "teligonáceas": "teligonácea",
    "telilhas": "telilha",
    "telins": "telim",
    "telinta": "telintar",
    "telintada": "telintar",
    "telintadas": "telintar",
    "telintado": "telintar",
    "telintados": "telintar",
    "telintai": "telintar",
    "telintais": "telintar",
    "telintam": "telintar",
    "telintamo": "telintar",
    "telintamos": "telintar",
    "telintando": "telintar",
    "telintara": "telintar",
    "telintaram": "telintar",
    "telintaras": "telintar",
    "telintardes": "telintar",
    "telintarei": "telintar",
    "telintareis": "telintar",
    "telintarem": "telintar",
    "telintaremos": "telintar",
    "telintares": "telintar",
    "telintaria": "telintar",
    "telintariam": "telintar",
    "telintarias": "telintar",
    "telintarmo": "telintar",
    "telintarmos": "telintar",
    "telintará": "telintar",
    "telintarás": "telintar",
    "telintarão": "telintar",
    "telintaríamos": "telintar",
    "telintaríeis": "telintar",
    "telintas": "telintar",
    "telintasse": "telintar",
    "telintassem": "telintar",
    "telintasses": "telintar",
    "telintaste": "telintar",
    "telintastes": "telintar",
    "telintava": "telintar",
    "telintavam": "telintar",
    "telintavas": "telintar",
    "telinte": "telintar",
    "telintei": "telintar",
    "telinteis": "telintar",
    "telintem": "telintar",
    "telintemo": "telintar",
    "telintemos": "telintar",
    "telintes": "telintar",
    "telinto": "telintar",
    "telintou": "telintar",
    "telintámo": "telintar",
    "telintámos": "telintar",
    "telintáramo": "telintar",
    "telintáramos": "telintar",
    "telintáreis": "telintar",
    "telintásseis": "telintar",
    "telintássemos": "telintar",
    "telintávamo": "telintar",
    "telintávamos": "telintar",
    "telintáveis": "telintar",
    "telinídeos": "telinídeo",
    "telites": "telite",
    "telizes": "teliz",
    "telolecítica": "telolecítico",
    "telolecíticas": "telolecítico",
    "telolecíticos": "telolecítico",
    "telometrias": "telometria",
    "telométrica": "telométrico",
    "telométricas": "telométrico",
    "telométricos": "telométrico",
    "telopsias": "telopsia",
    "telorragias": "telorragia",
    "telosporídeos": "telosporídeo",
    "teluriana": "teluriano",
    "telurianas": "teluriano",
    "telurianos": "teluriano",
    "telurismos": "telurismo",
    "telurífera": "telurífero",
    "teluríferas": "telurífero",
    "teluríferos": "telurífero",
    "teléfios": "teléfio",
    "telégrafos": "telégrafo",
    "telémetros": "telémetro",
    "teléricos": "telérico",
    "telésias": "telésia",
    "telínidas": "telínida",
    "telófases": "telófase",
    "telómetros": "telómetro",
    "telónios": "telónio",
    "telóptica": "telóptico",
    "telópticas": "telóptico",
    "telópticos": "telóptico",
    "telônios": "telônio",
    "telões": "telão",
    "telúrica": "telúrico",
    "telúricas": "telúrico",
    "telúricos": "telúrico",
    "telúrios": "telúrio",
    "tem": "ter",
    "tema": "temer",
    "temais": "temer",
    "temam": "temer",
    "temamo": "temer",
    "temamos": "temer",
    "temas": "temer",
    "tematiza": "tematizar",
    "tematizada": "tematizar",
    "tematizadas": "tematizar",
    "tematizado": "tematizar",
    "tematizados": "tematizar",
    "tematizai": "tematizar",
    "tematizais": "tematizar",
    "tematizam": "tematizar",
    "tematizamo": "tematizar",
    "tematizamos": "tematizar",
    "tematizando": "tematizar",
    "tematizara": "tematizar",
    "tematizaram": "tematizar",
    "tematizaras": "tematizar",
    "tematizarde": "tematizar",
    "tematizardes": "tematizar",
    "tematizare": "tematizar",
    "tematizarei": "tematizar",
    "tematizareis": "tematizar",
    "tematizarem": "tematizar",
    "tematizaremos": "tematizar",
    "tematizares": "tematizar",
    "tematizaria": "tematizar",
    "tematizariam": "tematizar",
    "tematizarias": "tematizar",
    "tematizarmo": "tematizar",
    "tematizarmos": "tematizar",
    "tematizará": "tematizar",
    "tematizarás": "tematizar",
    "tematizarão": "tematizar",
    "tematizaríamos": "tematizar",
    "tematizaríeis": "tematizar",
    "tematizas": "tematizar",
    "tematizasse": "tematizar",
    "tematizassem": "tematizar",
    "tematizasses": "tematizar",
    "tematizaste": "tematizar",
    "tematizastes": "tematizar",
    "tematizava": "tematizar",
    "tematizavam": "tematizar",
    "tematizavas": "tematizar",
    "tematize": "tematizar",
    "tematizei": "tematizar",
    "tematizeis": "tematizar",
    "tematizem": "tematizar",
    "tematizemo": "tematizar",
    "tematizemos": "tematizar",
    "tematizes": "tematizar",
    "tematizo": "tematizar",
    "tematizou": "tematizar",
    "tematizá": "tematizar",
    "tematizámo": "tematizar",
    "tematizámos": "tematizar",
    "tematizáramo": "tematizar",
    "tematizáramos": "tematizar",
    "tematizárei": "tematizar",
    "tematizáreis": "tematizar",
    "tematizásseis": "tematizar",
    "tematizássemos": "tematizar",
    "tematizávamo": "tematizar",
    "tematizávamos": "tematizar",
    "tematizávei": "tematizar",
    "tematizáveis": "tematizar",
    "tematologias": "tematologia",
    "tematológica": "tematológico",
    "tematológicas": "tematológico",
    "tematológicos": "tematológico",
    "teme": "temer",
    "temedoira": "temedoiro",
    "temedoiras": "temedoiro",
    "temedoiros": "temedoiro",
    "temedoura": "temedouro",
    "temedouras": "temedouro",
    "temedouros": "temedouro",
    "temei": "temer",
    "temeis": "temer",
    "temem": "temer",
    "tememo": "temer",
    "tememos": "temer",
    "temendo": "temer",
    "tementes": "temente",
    "temera": "temerar",
    "temerada": "temerar",
    "temeradas": "temerar",
    "temerado": "temerar",
    "temerados": "temerar",
    "temerai": "temerar",
    "temerais": "temerar",
    "temeram": "temerar",
    "temeramo": "temerar",
    "temeramos": "temerar",
    "temerando": "temerar",
    "temerara": "temerar",
    "temeraram": "temerar",
    "temeraras": "temerar",
    "temerarde": "temerar",
    "temerardes": "temerar",
    "temerare": "temerar",
    "temerarei": "temerar",
    "temerareis": "temerar",
    "temerarem": "temerar",
    "temeraremos": "temerar",
    "temerares": "temerar",
    "temeraria": "temerar",
    "temerariam": "temerar",
    "temerarias": "temerar",
    "temerarmo": "temerar",
    "temerarmos": "temerar",
    "temerará": "temerar",
    "temerarás": "temerar",
    "temerarão": "temerar",
    "temeraríamos": "temerar",
    "temeraríeis": "temerar",
    "temeras": "temerar",
    "temerasse": "temerar",
    "temerassem": "temerar",
    "temerasses": "temerar",
    "temeraste": "temerar",
    "temerastes": "temerar",
    "temerata": "temerato",
    "temeratas": "temerato",
    "temeratos": "temerato",
    "temerava": "temerar",
    "temeravam": "temerar",
    "temeravas": "temerar",
    "temerde": "temer",
    "temerdes": "temer",
    "temere": "temerar",
    "temerei": "temerar",
    "temereis": "temerar",
    "temerem": "temerar",
    "temeremo": "temerar",
    "temeremos": "temerar",
    "temeres": "temerar",
    "temeria": "temer",
    "temeriam": "temer",
    "temerias": "temer",
    "temeridades": "temeridade",
    "temermo": "temer",
    "temermos": "temer",
    "temero": "temerar",
    "temerosa": "temeroso",
    "temerosas": "temeroso",
    "temerosos": "temeroso",
    "temerou": "temerar",
    "temerá": "temerar",
    "temerámo": "temerar",
    "temerámos": "temerar",
    "temeráramo": "temerar",
    "temeráramos": "temerar",
    "temerárei": "temerar",
    "temeráreis": "temerar",
    "temerária": "temerário",
    "temerárias": "temerário",
    "temerários": "temerário",
    "temerás": "temer",
    "temerásseis": "temerar",
    "temerássemos": "temerar",
    "temerávamo": "temerar",
    "temerávamos": "temerar",
    "temerávei": "temerar",
    "temeráveis": "temerável",
    "temerão": "temer",
    "temeríamos": "temer",
    "temeríeis": "temer",
    "temes": "temer",
    "temesse": "temer",
    "temessem": "temer",
    "temesses": "temer",
    "temeste": "temer",
    "temestes": "temer",
    "temeu": "temer",
    "temi": "temer",
    "temia": "temer",
    "temiam": "temer",
    "temias": "temer",
    "temibilidades": "temibilidade",
    "temida": "temido",
    "temidas": "temido",
    "temido": "temer",
    "temidos": "temido",
    "temidíssima": "temido",
    "temidíssimas": "temido",
    "temidíssimo": "temido",
    "temidíssimos": "temido",
    "temo": "ter",
    "temoeiros": "temoeiro",
    "temona": "temonar",
    "temonada": "temonar",
    "temonadas": "temonar",
    "temonado": "temonar",
    "temonados": "temonar",
    "temonai": "temonar",
    "temonais": "temonar",
    "temonam": "temonar",
    "temonamo": "temonar",
    "temonamos": "temonar",
    "temonando": "temonar",
    "temonara": "temonar",
    "temonaram": "temonar",
    "temonaras": "temonar",
    "temonarde": "temonar",
    "temonardes": "temonar",
    "temonare": "temonar",
    "temonarei": "temonar",
    "temonareis": "temonar",
    "temonarem": "temonar",
    "temonaremos": "temonar",
    "temonares": "temonar",
    "temonaria": "temonar",
    "temonariam": "temonar",
    "temonarias": "temonar",
    "temonarmo": "temonar",
    "temonarmos": "temonar",
    "temonará": "temonar",
    "temonarás": "temonar",
    "temonarão": "temonar",
    "temonaríamos": "temonar",
    "temonaríeis": "temonar",
    "temonas": "temonar",
    "temonasse": "temonar",
    "temonassem": "temonar",
    "temonasses": "temonar",
    "temonaste": "temonar",
    "temonastes": "temonar",
    "temonava": "temonar",
    "temonavam": "temonar",
    "temonavas": "temonar",
    "temone": "temonar",
    "temonei": "temonar",
    "temoneira": "temoneiro",
    "temoneiras": "temoneiro",
    "temoneiros": "temoneiro",
    "temoneis": "temonar",
    "temonem": "temonar",
    "temonemo": "temonar",
    "temonemos": "temonar",
    "temones": "temonar",
    "temono": "temonar",
    "temonou": "temonar",
    "temoná": "temonar",
    "temonámo": "temonar",
    "temonámos": "temonar",
    "temonáramo": "temonar",
    "temonáramos": "temonar",
    "temonárei": "temonar",
    "temonáreis": "temonar",
    "temonásseis": "temonar",
    "temonássemos": "temonar",
    "temonávamo": "temonar",
    "temonávamos": "temonar",
    "temonávei": "temonar",
    "temonáveis": "temonável",
    "temores": "temor",
    "temorosa": "temoroso",
    "temorosas": "temoroso",
    "temorosos": "temoroso",
    "temos": "ter",
    "tempera": "temperar",
    "temperada": "temperar",
    "temperadas": "temperar",
    "temperadinha": "temperado",
    "temperadinhas": "temperado",
    "temperadinho": "temperado",
    "temperadinhos": "temperado",
    "temperadita": "temperado",
    "temperaditas": "temperado",
    "temperadito": "temperado",
    "temperaditos": "temperado",
    "temperado": "temperar",
    "temperadora": "temperador",
    "temperadoras": "temperador",
    "temperadores": "temperador",
    "temperados": "temperar",
    "temperadíssima": "temperado",
    "temperadíssimas": "temperado",
    "temperadíssimo": "temperado",
    "temperadíssimos": "temperado",
    "temperai": "temperar",
    "temperais": "temperar",
    "temperam": "temperar",
    "temperamentais": "temperamental",
    "temperamentos": "temperamento",
    "temperamo": "temperar",
    "temperamos": "temperar",
    "temperando": "temperar",
    "temperantes": "temperante",
    "temperanças": "temperança",
    "temperara": "temperar",
    "temperaram": "temperar",
    "temperaras": "temperar",
    "temperarde": "temperar",
    "temperardes": "temperar",
    "temperare": "temperar",
    "temperarei": "temperar",
    "temperareis": "temperar",
    "temperarem": "temperar",
    "temperaremos": "temperar",
    "temperares": "temperar",
    "temperaria": "temperar",
    "temperariam": "temperar",
    "temperarias": "temperar",
    "temperarmo": "temperar",
    "temperarmos": "temperar",
    "temperará": "temperar",
    "temperarás": "temperar",
    "temperarão": "temperar",
    "temperaríamos": "temperar",
    "temperaríeis": "temperar",
    "temperas": "temperar",
    "temperasse": "temperar",
    "temperassem": "temperar",
    "temperasses": "temperar",
    "temperaste": "temperar",
    "temperastes": "temperar",
    "temperatuais": "temperatual",
    "temperaturas": "temperatura",
    "temperava": "temperar",
    "temperavam": "temperar",
    "temperavas": "temperar",
    "tempere": "temperar",
    "temperei": "temperar",
    "tempereiros": "tempereiro",
    "tempereis": "temperar",
    "temperem": "temperar",
    "temperemo": "temperar",
    "temperemos": "temperar",
    "temperes": "temperar",
    "temperilhas": "temperilha",
    "temperilhos": "temperilho",
    "tempero": "temperar",
    "temperos": "tempero",
    "temperou": "temperar",
    "temperá": "temperar",
    "temperámo": "temperar",
    "temperámos": "temperar",
    "temperáramo": "temperar",
    "temperáramos": "temperar",
    "temperárei": "temperar",
    "temperáreis": "temperar",
    "temperásseis": "temperar",
    "temperássemos": "temperar",
    "temperávamo": "temperar",
    "temperávamos": "temperar",
    "temperávei": "temperar",
    "temperáveis": "temperável",
    "tempestades": "tempestade",
    "tempesteada": "tempestear",
    "tempesteadas": "tempestear",
    "tempesteado": "tempestear",
    "tempesteados": "tempestear",
    "tempesteai": "tempestear",
    "tempesteais": "tempestear",
    "tempesteamo": "tempestear",
    "tempesteamos": "tempestear",
    "tempesteando": "tempestear",
    "tempesteara": "tempestear",
    "tempestearam": "tempestear",
    "tempestearas": "tempestear",
    "tempesteardes": "tempestear",
    "tempestearei": "tempestear",
    "tempesteareis": "tempestear",
    "tempestearem": "tempestear",
    "tempestearemos": "tempestear",
    "tempesteares": "tempestear",
    "tempestearia": "tempestear",
    "tempesteariam": "tempestear",
    "tempestearias": "tempestear",
    "tempestearmo": "tempestear",
    "tempestearmos": "tempestear",
    "tempesteará": "tempestear",
    "tempestearás": "tempestear",
    "tempestearão": "tempestear",
    "tempestearíamos": "tempestear",
    "tempestearíeis": "tempestear",
    "tempesteasse": "tempestear",
    "tempesteassem": "tempestear",
    "tempesteasses": "tempestear",
    "tempesteaste": "tempestear",
    "tempesteastes": "tempestear",
    "tempesteava": "tempestear",
    "tempesteavam": "tempestear",
    "tempesteavas": "tempestear",
    "tempesteei": "tempestear",
    "tempesteeis": "tempestear",
    "tempesteemo": "tempestear",
    "tempesteemos": "tempestear",
    "tempesteia": "tempestear",
    "tempesteiam": "tempestear",
    "tempesteias": "tempestear",
    "tempesteie": "tempestear",
    "tempesteiem": "tempestear",
    "tempesteies": "tempestear",
    "tempesteio": "tempestear",
    "tempesteou": "tempestear",
    "tempesteámo": "tempestear",
    "tempesteámos": "tempestear",
    "tempesteáramo": "tempestear",
    "tempesteáramos": "tempestear",
    "tempesteáreis": "tempestear",
    "tempesteásseis": "tempestear",
    "tempesteássemos": "tempestear",
    "tempesteávamo": "tempestear",
    "tempesteávamos": "tempestear",
    "tempesteáveis": "tempestear",
    "tempestiva": "tempestivo",
    "tempestivas": "tempestivo",
    "tempestivos": "tempestivo",
    "tempestua": "tempestuar",
    "tempestuada": "tempestuar",
    "tempestuadas": "tempestuar",
    "tempestuado": "tempestuar",
    "tempestuados": "tempestuar",
    "tempestuai": "tempestuar",
    "tempestuais": "tempestuar",
    "tempestuam": "tempestuar",
    "tempestuamo": "tempestuar",
    "tempestuamos": "tempestuar",
    "tempestuando": "tempestuar",
    "tempestuara": "tempestuar",
    "tempestuaram": "tempestuar",
    "tempestuaras": "tempestuar",
    "tempestuardes": "tempestuar",
    "tempestuarei": "tempestuar",
    "tempestuareis": "tempestuar",
    "tempestuarem": "tempestuar",
    "tempestuaremos": "tempestuar",
    "tempestuares": "tempestuar",
    "tempestuaria": "tempestuar",
    "tempestuariam": "tempestuar",
    "tempestuarias": "tempestuar",
    "tempestuarmo": "tempestuar",
    "tempestuarmos": "tempestuar",
    "tempestuará": "tempestuar",
    "tempestuarás": "tempestuar",
    "tempestuarão": "tempestuar",
    "tempestuaríamos": "tempestuar",
    "tempestuaríeis": "tempestuar",
    "tempestuas": "tempestuar",
    "tempestuasse": "tempestuar",
    "tempestuassem": "tempestuar",
    "tempestuasses": "tempestuar",
    "tempestuaste": "tempestuar",
    "tempestuastes": "tempestuar",
    "tempestuava": "tempestuar",
    "tempestuavam": "tempestuar",
    "tempestuavas": "tempestuar",
    "tempestue": "tempestuar",
    "tempestuei": "tempestuar",
    "tempestueis": "tempestuar",
    "tempestuem": "tempestuar",
    "tempestuemo": "tempestuar",
    "tempestuemos": "tempestuar",
    "tempestues": "tempestuar",
    "tempestuo": "tempestuar",
    "tempestuosa": "tempestuoso",
    "tempestuosas": "tempestuoso",
    "tempestuosidades": "tempestuosidade",
    "tempestuosos": "tempestuoso",
    "tempestuou": "tempestuar",
    "tempestuámo": "tempestuar",
    "tempestuámos": "tempestuar",
    "tempestuáramo": "tempestuar",
    "tempestuáramos": "tempestuar",
    "tempestuáreis": "tempestuar",
    "tempestuásseis": "tempestuar",
    "tempestuássemos": "tempestuar",
    "tempestuávamo": "tempestuar",
    "tempestuávamos": "tempestuar",
    "tempestuáveis": "tempestuar",
    "tempinho": "tempo",
    "tempinhos": "tempo",
    "tempito": "tempo",
    "tempitos": "tempo",
    "templos": "templo",
    "templária": "templário",
    "templárias": "templário",
    "templários": "templário",
    "temponânea": "temponâneo",
    "temponâneas": "temponâneo",
    "temponâneos": "temponâneo",
    "temporadas": "temporada",
    "temporais": "temporal",
    "temporalidades": "temporalidade",
    "temporaliza": "temporalizar",
    "temporalizada": "temporalizar",
    "temporalizadas": "temporalizar",
    "temporalizado": "temporalizar",
    "temporalizados": "temporalizar",
    "temporalizai": "temporalizar",
    "temporalizais": "temporalizar",
    "temporalizam": "temporalizar",
    "temporalizamo": "temporalizar",
    "temporalizamos": "temporalizar",
    "temporalizando": "temporalizar",
    "temporalizara": "temporalizar",
    "temporalizaram": "temporalizar",
    "temporalizaras": "temporalizar",
    "temporalizarde": "temporalizar",
    "temporalizardes": "temporalizar",
    "temporalizare": "temporalizar",
    "temporalizarei": "temporalizar",
    "temporalizareis": "temporalizar",
    "temporalizarem": "temporalizar",
    "temporalizaremos": "temporalizar",
    "temporalizares": "temporalizar",
    "temporalizaria": "temporalizar",
    "temporalizariam": "temporalizar",
    "temporalizarias": "temporalizar",
    "temporalizarmo": "temporalizar",
    "temporalizarmos": "temporalizar",
    "temporalizará": "temporalizar",
    "temporalizarás": "temporalizar",
    "temporalizarão": "temporalizar",
    "temporalizaríamos": "temporalizar",
    "temporalizaríeis": "temporalizar",
    "temporalizas": "temporalizar",
    "temporalizasse": "temporalizar",
    "temporalizassem": "temporalizar",
    "temporalizasses": "temporalizar",
    "temporalizaste": "temporalizar",
    "temporalizastes": "temporalizar",
    "temporalizava": "temporalizar",
    "temporalizavam": "temporalizar",
    "temporalizavas": "temporalizar",
    "temporalize": "temporalizar",
    "temporalizei": "temporalizar",
    "temporalizeis": "temporalizar",
    "temporalizem": "temporalizar",
    "temporalizemo": "temporalizar",
    "temporalizemos": "temporalizar",
    "temporalizes": "temporalizar",
    "temporalizo": "temporalizar",
    "temporalizou": "temporalizar",
    "temporalizá": "temporalizar",
    "temporalizámo": "temporalizar",
    "temporalizámos": "temporalizar",
    "temporalizáramo": "temporalizar",
    "temporalizáramos": "temporalizar",
    "temporalizárei": "temporalizar",
    "temporalizáreis": "temporalizar",
    "temporalizásseis": "temporalizar",
    "temporalizássemos": "temporalizar",
    "temporalizávamo": "temporalizar",
    "temporalizávamos": "temporalizar",
    "temporalizávei": "temporalizar",
    "temporalizáveis": "temporalizável",
    "temporaneidades": "temporaneidade",
    "temporeja": "temporejar",
    "temporejada": "temporejar",
    "temporejadas": "temporejar",
    "temporejado": "temporejar",
    "temporejados": "temporejar",
    "temporejai": "temporejar",
    "temporejais": "temporejar",
    "temporejam": "temporejar",
    "temporejamo": "temporejar",
    "temporejamos": "temporejar",
    "temporejando": "temporejar",
    "temporejara": "temporejar",
    "temporejaram": "temporejar",
    "temporejaras": "temporejar",
    "temporejardes": "temporejar",
    "temporejarei": "temporejar",
    "temporejareis": "temporejar",
    "temporejarem": "temporejar",
    "temporejaremos": "temporejar",
    "temporejares": "temporejar",
    "temporejaria": "temporejar",
    "temporejariam": "temporejar",
    "temporejarias": "temporejar",
    "temporejarmo": "temporejar",
    "temporejarmos": "temporejar",
    "temporejará": "temporejar",
    "temporejarás": "temporejar",
    "temporejarão": "temporejar",
    "temporejaríamos": "temporejar",
    "temporejaríeis": "temporejar",
    "temporejas": "temporejar",
    "temporejasse": "temporejar",
    "temporejassem": "temporejar",
    "temporejasses": "temporejar",
    "temporejaste": "temporejar",
    "temporejastes": "temporejar",
    "temporejava": "temporejar",
    "temporejavam": "temporejar",
    "temporejavas": "temporejar",
    "temporeje": "temporejar",
    "temporejei": "temporejar",
    "temporejeis": "temporejar",
    "temporejem": "temporejar",
    "temporejemo": "temporejar",
    "temporejemos": "temporejar",
    "temporejes": "temporejar",
    "temporejo": "temporejar",
    "temporejou": "temporejar",
    "temporejámo": "temporejar",
    "temporejámos": "temporejar",
    "temporejáramo": "temporejar",
    "temporejáramos": "temporejar",
    "temporejáreis": "temporejar",
    "temporejásseis": "temporejar",
    "temporejássemos": "temporejar",
    "temporejávamo": "temporejar",
    "temporejávamos": "temporejar",
    "temporejáveis": "temporejar",
    "temporiza": "temporizar",
    "temporizada": "temporizar",
    "temporizadas": "temporizar",
    "temporizado": "temporizar",
    "temporizadora": "temporizador",
    "temporizadoras": "temporizador",
    "temporizadores": "temporizador",
    "temporizados": "temporizar",
    "temporizai": "temporizar",
    "temporizais": "temporizar",
    "temporizam": "temporizar",
    "temporizamo": "temporizar",
    "temporizamos": "temporizar",
    "temporizando": "temporizar",
    "temporizara": "temporizar",
    "temporizaram": "temporizar",
    "temporizaras": "temporizar",
    "temporizarde": "temporizar",
    "temporizardes": "temporizar",
    "temporizare": "temporizar",
    "temporizarei": "temporizar",
    "temporizareis": "temporizar",
    "temporizarem": "temporizar",
    "temporizaremos": "temporizar",
    "temporizares": "temporizar",
    "temporizaria": "temporizar",
    "temporizariam": "temporizar",
    "temporizarias": "temporizar",
    "temporizarmo": "temporizar",
    "temporizarmos": "temporizar",
    "temporizará": "temporizar",
    "temporizarás": "temporizar",
    "temporizarão": "temporizar",
    "temporizaríamos": "temporizar",
    "temporizaríeis": "temporizar",
    "temporizas": "temporizar",
    "temporizasse": "temporizar",
    "temporizassem": "temporizar",
    "temporizasses": "temporizar",
    "temporizaste": "temporizar",
    "temporizastes": "temporizar",
    "temporizava": "temporizar",
    "temporizavam": "temporizar",
    "temporizavas": "temporizar",
    "temporizações": "temporização",
    "temporize": "temporizar",
    "temporizei": "temporizar",
    "temporizeis": "temporizar",
    "temporizem": "temporizar",
    "temporizemo": "temporizar",
    "temporizemos": "temporizar",
    "temporizes": "temporizar",
    "temporizo": "temporizar",
    "temporizou": "temporizar",
    "temporizá": "temporizar",
    "temporizámo": "temporizar",
    "temporizámos": "temporizar",
    "temporizáramo": "temporizar",
    "temporizáramos": "temporizar",
    "temporizárei": "temporizar",
    "temporizáreis": "temporizar",
    "temporizásseis": "temporizar",
    "temporizássemos": "temporizar",
    "temporizávamo": "temporizar",
    "temporizávamos": "temporizar",
    "temporizávei": "temporizar",
    "temporizáveis": "temporizável",
    "temporoccipitais": "temporoccipital",
    "temporária": "temporário",
    "temporárias": "temporário",
    "temporários": "temporário",
    "temporã": "temporão",
    "temporãs": "temporão",
    "temporões": "temporão",
    "tempos": "tempo",
    "tempéries": "tempérie",
    "tempíssimos": "tempíssimo",
    "temuda": "temudo",
    "temudas": "temudo",
    "temudos": "temudo",
    "temulenta": "temulento",
    "temulentas": "temulento",
    "temulentos": "temulento",
    "temulências": "temulência",
    "temática": "temático",
    "temáticas": "temático",
    "temáticos": "temático",
    "temê": "temer",
    "temêramo": "temer",
    "temêramos": "temer",
    "temêrei": "temer",
    "temêreis": "temer",
    "temêsseis": "temer",
    "temêssemos": "temer",
    "temíamo": "temer",
    "temíamos": "temer",
    "temíei": "temer",
    "temíeis": "temer",
    "temíveis": "temível",
    "temões": "temão",
    "tenacidades": "tenacidade",
    "tenais": "tenal",
    "tenalgias": "tenalgia",
    "tenalhas": "tenalha",
    "tenantites": "tenantite",
    "tenazes": "tenaz",
    "tencas": "tenca",
    "tenciona": "tencionar",
    "tencionada": "tencionar",
    "tencionadas": "tencionar",
    "tencionado": "tencionar",
    "tencionados": "tencionar",
    "tencionai": "tencionar",
    "tencionais": "tencionar",
    "tencionam": "tencionar",
    "tencionamo": "tencionar",
    "tencionamos": "tencionar",
    "tencionando": "tencionar",
    "tencionara": "tencionar",
    "tencionaram": "tencionar",
    "tencionaras": "tencionar",
    "tencionarde": "tencionar",
    "tencionardes": "tencionar",
    "tencionare": "tencionar",
    "tencionarei": "tencionar",
    "tencionareis": "tencionar",
    "tencionarem": "tencionar",
    "tencionaremos": "tencionar",
    "tencionares": "tencionar",
    "tencionaria": "tencionar",
    "tencionariam": "tencionar",
    "tencionarias": "tencionar",
    "tencionarmo": "tencionar",
    "tencionarmos": "tencionar",
    "tencionará": "tencionar",
    "tencionarás": "tencionar",
    "tencionarão": "tencionar",
    "tencionaríamos": "tencionar",
    "tencionaríeis": "tencionar",
    "tencionas": "tencionar",
    "tencionasse": "tencionar",
    "tencionassem": "tencionar",
    "tencionasses": "tencionar",
    "tencionaste": "tencionar",
    "tencionastes": "tencionar",
    "tencionava": "tencionar",
    "tencionavam": "tencionar",
    "tencionavas": "tencionar",
    "tencione": "tencionar",
    "tencionei": "tencionar",
    "tencioneis": "tencionar",
    "tencionem": "tencionar",
    "tencionemo": "tencionar",
    "tencionemos": "tencionar",
    "tenciones": "tencionar",
    "tenciono": "tencionar",
    "tencionou": "tencionar",
    "tencioná": "tencionar",
    "tencionámo": "tencionar",
    "tencionámos": "tencionar",
    "tencionáramo": "tencionar",
    "tencionáramos": "tencionar",
    "tencionárei": "tencionar",
    "tencionáreis": "tencionar",
    "tencionária": "tencionário",
    "tencionárias": "tencionário",
    "tencionários": "tencionário",
    "tencionásseis": "tencionar",
    "tencionássemos": "tencionar",
    "tencionávamo": "tencionar",
    "tencionávamos": "tencionar",
    "tencionávei": "tencionar",
    "tencionáveis": "tencionável",
    "tencrática": "tencrático",
    "tencráticas": "tencrático",
    "tencráticos": "tencrático",
    "tenda": "tender",
    "tendais": "tender",
    "tendam": "tender",
    "tendamo": "tender",
    "tendamos": "tender",
    "tendas": "tender",
    "tende": "ter",
    "tendedeiras": "tendedeira",
    "tendeduras": "tendedura",
    "tendei": "tender",
    "tendeira": "tendeiro",
    "tendeiras": "tendeiro",
    "tendeiros": "tendeiro",
    "tendeis": "tender",
    "tendem": "tender",
    "tendemo": "tender",
    "tendemos": "tender",
    "tendenciais": "tendencial",
    "tendenciosa": "tendencioso",
    "tendenciosas": "tendencioso",
    "tendenciosidades": "tendenciosidade",
    "tendenciosos": "tendencioso",
    "tendendo": "tender",
    "tendentes": "tendente",
    "tendera": "tender",
    "tenderam": "tender",
    "tenderas": "tender",
    "tenderde": "tender",
    "tenderdes": "tender",
    "tendere": "tender",
    "tenderei": "tender",
    "tendereis": "tender",
    "tenderem": "tender",
    "tenderemos": "tender",
    "tenderes": "tender",
    "tenderia": "tender",
    "tenderiam": "tender",
    "tenderias": "tender",
    "tendermo": "tender",
    "tendermos": "tender",
    "tenderá": "tender",
    "tenderás": "tender",
    "tenderão": "tender",
    "tenderíamos": "tender",
    "tenderíeis": "tender",
    "tendes": "ter",
    "tendesse": "tender",
    "tendessem": "tender",
    "tendesses": "tender",
    "tendeste": "tender",
    "tendestes": "tender",
    "tendeu": "tender",
    "tendi": "tender",
    "tendia": "tender",
    "tendiam": "tender",
    "tendias": "tender",
    "tendida": "tendido",
    "tendidas": "tendido",
    "tendido": "tender",
    "tendidos": "tendido",
    "tendilhas": "tendilha",
    "tendilhões": "tendilhão",
    "tendinha": "tenda",
    "tendinhas": "tenda",
    "tendinites": "tendinite",
    "tendinosa": "tendinoso",
    "tendinosas": "tendinoso",
    "tendinosos": "tendinoso",
    "tendita": "tenda",
    "tenditas": "tenda",
    "tendo": "ter",
    "tendolas": "tendola",
    "tendê": "tender",
    "tendências": "tendência",
    "tendêramo": "tender",
    "tendêramos": "tender",
    "tendêrei": "tender",
    "tendêreis": "tender",
    "tendêsseis": "tender",
    "tendêssemos": "tender",
    "tendíamo": "tender",
    "tendíamos": "tender",
    "tendíei": "tender",
    "tendíeis": "tender",
    "tendíveis": "tendível",
    "tendões": "tendão",
    "tenebricosa": "tenebricoso",
    "tenebricosas": "tenebricoso",
    "tenebricosidades": "tenebricosidade",
    "tenebricosos": "tenebricoso",
    "tenebrionídeos": "tenebrionídeo",
    "tenebriza": "tenebrizar",
    "tenebrizada": "tenebrizar",
    "tenebrizadas": "tenebrizar",
    "tenebrizado": "tenebrizar",
    "tenebrizadores": "tenebrizador",
    "tenebrizados": "tenebrizar",
    "tenebrizai": "tenebrizar",
    "tenebrizais": "tenebrizar",
    "tenebrizam": "tenebrizar",
    "tenebrizamo": "tenebrizar",
    "tenebrizamos": "tenebrizar",
    "tenebrizando": "tenebrizar",
    "tenebrizara": "tenebrizar",
    "tenebrizaram": "tenebrizar",
    "tenebrizaras": "tenebrizar",
    "tenebrizarde": "tenebrizar",
    "tenebrizardes": "tenebrizar",
    "tenebrizare": "tenebrizar",
    "tenebrizarei": "tenebrizar",
    "tenebrizareis": "tenebrizar",
    "tenebrizarem": "tenebrizar",
    "tenebrizaremos": "tenebrizar",
    "tenebrizares": "tenebrizar",
    "tenebrizaria": "tenebrizar",
    "tenebrizariam": "tenebrizar",
    "tenebrizarias": "tenebrizar",
    "tenebrizarmo": "tenebrizar",
    "tenebrizarmos": "tenebrizar",
    "tenebrizará": "tenebrizar",
    "tenebrizarás": "tenebrizar",
    "tenebrizarão": "tenebrizar",
    "tenebrizaríamos": "tenebrizar",
    "tenebrizaríeis": "tenebrizar",
    "tenebrizas": "tenebrizar",
    "tenebrizasse": "tenebrizar",
    "tenebrizassem": "tenebrizar",
    "tenebrizasses": "tenebrizar",
    "tenebrizaste": "tenebrizar",
    "tenebrizastes": "tenebrizar",
    "tenebrizava": "tenebrizar",
    "tenebrizavam": "tenebrizar",
    "tenebrizavas": "tenebrizar",
    "tenebrize": "tenebrizar",
    "tenebrizei": "tenebrizar",
    "tenebrizeis": "tenebrizar",
    "tenebrizem": "tenebrizar",
    "tenebrizemo": "tenebrizar",
    "tenebrizemos": "tenebrizar",
    "tenebrizes": "tenebrizar",
    "tenebrizo": "tenebrizar",
    "tenebrizou": "tenebrizar",
    "tenebrizá": "tenebrizar",
    "tenebrizámo": "tenebrizar",
    "tenebrizámos": "tenebrizar",
    "tenebrizáramo": "tenebrizar",
    "tenebrizáramos": "tenebrizar",
    "tenebrizárei": "tenebrizar",
    "tenebrizáreis": "tenebrizar",
    "tenebrizásseis": "tenebrizar",
    "tenebrizássemos": "tenebrizar",
    "tenebrizávamo": "tenebrizar",
    "tenebrizávamos": "tenebrizar",
    "tenebrizávei": "tenebrizar",
    "tenebrizáveis": "tenebrizar",
    "tenebriónidas": "tenebriónida",
    "tenebriões": "tenebrião",
    "tenebrosa": "tenebroso",
    "tenebrosas": "tenebroso",
    "tenebrosidades": "tenebrosidade",
    "tenebrosos": "tenebroso",
    "tenebrários": "tenebrário",
    "tenectomias": "tenectomia",
    "tenentes": "tenente",
    "tenesmos": "tenesmo",
    "tenesmódica": "tenesmódico",
    "tenesmódicas": "tenesmódico",
    "tenesmódicos": "tenesmódico",
    "tenha": "ter",
    "tenhais": "ter",
    "tenham": "ter",
    "tenhamo": "ter",
    "tenhamos": "ter",
    "tenhas": "ter",
    "tenho": "ter",
    "tenilhas": "tenilha",
    "teniobrânquia": "teniobrânquio",
    "teniobrânquias": "teniobrânquio",
    "teniobrânquios": "teniobrânquio",
    "teniopes": "teniope",
    "teniossomos": "teniossomo",
    "teniota": "tenioto",
    "teniotas": "tenioto",
    "teniotos": "tenioto",
    "tenistas": "tenista",
    "teniídeos": "teniídeo",
    "tenióides": "tenióide",
    "tenióptera": "tenióptero",
    "teniópteras": "tenióptero",
    "teniópteros": "tenióptero",
    "tenjarros": "tenjarro",
    "tenopatias": "tenopatia",
    "tenores": "tenor",
    "tenorinos": "tenorino",
    "tenorites": "tenorite",
    "tenotomias": "tenotomia",
    "tenoísmos": "tenoísmo",
    "tenra": "tenro",
    "tenras": "tenro",
    "tenreira": "tenreiro",
    "tenreiras": "tenreiro",
    "tenreiros": "tenreiro",
    "tenrinha": "tenro",
    "tenrinhas": "tenro",
    "tenrinho": "tenro",
    "tenrinhos": "tenro",
    "tenrita": "tenro",
    "tenritas": "tenro",
    "tenrito": "tenro",
    "tenritos": "tenro",
    "tenros": "tenro",
    "tenruras": "tenrura",
    "tenríssima": "tenro",
    "tenríssimas": "tenro",
    "tenríssimo": "tenro",
    "tenríssimos": "tenro",
    "tens": "ter",
    "tensa": "tenso",
    "tensas": "tenso",
    "tensazinha": "tenso",
    "tensazinhas": "tenso",
    "tensazita": "tenso",
    "tensazitas": "tenso",
    "tensioactiva": "tensioactivo",
    "tensioactivas": "tensioactivo",
    "tensioactivos": "tensioactivo",
    "tensiva": "tensivo",
    "tensivas": "tensivo",
    "tensivos": "tensivo",
    "tensora": "tensor",
    "tensoras": "tensor",
    "tensores": "tensor",
    "tensoriais": "tensorial",
    "tensos": "tenso",
    "tensozinho": "tenso",
    "tensozinhos": "tenso",
    "tensozito": "tenso",
    "tensozitos": "tenso",
    "tensímetros": "tensímetro",
    "tensíssima": "tenso",
    "tensíssimas": "tenso",
    "tensíssimo": "tenso",
    "tensíssimos": "tenso",
    "tensões": "tensão",
    "tenta": "tentar",
    "tentaculada": "tentaculado",
    "tentaculadas": "tentaculado",
    "tentaculados": "tentaculado",
    "tentaculares": "tentacular",
    "tentaculiformes": "tentaculiforme",
    "tentaculífera": "tentaculífero",
    "tentaculíferas": "tentaculífero",
    "tentaculíferos": "tentaculífero",
    "tentada": "tentar",
    "tentadas": "tentar",
    "tentadiça": "tentadiço",
    "tentadiças": "tentadiço",
    "tentadiços": "tentadiço",
    "tentado": "tentar",
    "tentadora": "tentador",
    "tentadoras": "tentador",
    "tentadores": "tentador",
    "tentados": "tentar",
    "tentadíssima": "tentado",
    "tentadíssimas": "tentado",
    "tentadíssimo": "tentado",
    "tentadíssimos": "tentado",
    "tentai": "tentar",
    "tentais": "tentar",
    "tentam": "tentar",
    "tentamentos": "tentamento",
    "tentames": "tentame",
    "tentamo": "tentar",
    "tentamos": "tentar",
    "tentando": "tentar",
    "tentantes": "tentante",
    "tentara": "tentar",
    "tentaram": "tentar",
    "tentaras": "tentar",
    "tentarde": "tentar",
    "tentardes": "tentar",
    "tentare": "tentar",
    "tentarei": "tentar",
    "tentareis": "tentar",
    "tentarem": "tentar",
    "tentaremos": "tentar",
    "tentares": "tentar",
    "tentaria": "tentar",
    "tentariam": "tentar",
    "tentarias": "tentar",
    "tentarmo": "tentar",
    "tentarmos": "tentar",
    "tentarraizes": "tentarraiz",
    "tentará": "tentar",
    "tentarás": "tentar",
    "tentarão": "tentar",
    "tentaríamos": "tentar",
    "tentaríeis": "tentar",
    "tentas": "tentar",
    "tentasse": "tentar",
    "tentassem": "tentar",
    "tentasses": "tentar",
    "tentaste": "tentar",
    "tentastes": "tentar",
    "tentativa": "tentativo",
    "tentativas": "tentativo",
    "tentativazeca": "tentativa",
    "tentativazecas": "tentativa",
    "tentativazinha": "tentativa",
    "tentativazinhas": "tentativa",
    "tentativazita": "tentativa",
    "tentativazitas": "tentativa",
    "tentativos": "tentativo",
    "tentava": "tentar",
    "tentavam": "tentar",
    "tentavas": "tentar",
    "tentações": "tentação",
    "tente": "tentar",
    "tenteada": "tentear",
    "tenteadas": "tentear",
    "tenteado": "tentear",
    "tenteadora": "tenteador",
    "tenteadoras": "tenteador",
    "tenteadores": "tenteador",
    "tenteados": "tentear",
    "tenteai": "tentear",
    "tenteais": "tentear",
    "tenteamo": "tentear",
    "tenteamos": "tentear",
    "tenteando": "tentear",
    "tenteara": "tentear",
    "tentearam": "tentear",
    "tentearas": "tentear",
    "tentearde": "tentear",
    "tenteardes": "tentear",
    "tenteare": "tentear",
    "tentearei": "tentear",
    "tenteareis": "tentear",
    "tentearem": "tentear",
    "tentearemos": "tentear",
    "tenteares": "tentear",
    "tentearia": "tentear",
    "tenteariam": "tentear",
    "tentearias": "tentear",
    "tentearmo": "tentear",
    "tentearmos": "tentear",
    "tenteará": "tentear",
    "tentearás": "tentear",
    "tentearão": "tentear",
    "tentearíamos": "tentear",
    "tentearíeis": "tentear",
    "tenteasse": "tentear",
    "tenteassem": "tentear",
    "tenteasses": "tentear",
    "tenteaste": "tentear",
    "tenteastes": "tentear",
    "tenteava": "tentear",
    "tenteavam": "tentear",
    "tenteavas": "tentear",
    "tenteaveis": "tenteavel",
    "tenteei": "tentear",
    "tenteeis": "tentear",
    "tenteemo": "tentear",
    "tenteemos": "tentear",
    "tentei": "tentar",
    "tenteia": "tentear",
    "tenteiam": "tentear",
    "tenteias": "tentear",
    "tenteie": "tentear",
    "tenteiem": "tentear",
    "tenteies": "tentear",
    "tenteio": "tentear",
    "tenteios": "tenteio",
    "tenteis": "tentar",
    "tentem": "tentar",
    "tentemo": "tentar",
    "tentemos": "tentar",
    "tenteou": "tentear",
    "tentes": "tentar",
    "tenteá": "tentear",
    "tenteámo": "tentear",
    "tenteámos": "tentear",
    "tenteáramo": "tentear",
    "tenteáramos": "tentear",
    "tenteárei": "tentear",
    "tenteáreis": "tentear",
    "tenteásseis": "tentear",
    "tenteássemos": "tentear",
    "tenteávamo": "tentear",
    "tenteávamos": "tentear",
    "tenteávei": "tentear",
    "tenteáveis": "tentear",
    "tentilhões": "tentilhão",
    "tentilás": "tentilá",
    "tento": "tentar",
    "tentos": "tento",
    "tentou": "tentar",
    "tentá": "tentar",
    "tentáculos": "tentáculo",
    "tentámo": "tentar",
    "tentámos": "tentar",
    "tentáramo": "tentar",
    "tentáramos": "tentar",
    "tentárei": "tentar",
    "tentáreis": "tentar",
    "tentásseis": "tentar",
    "tentássemos": "tentar",
    "tentávamo": "tentar",
    "tentávamos": "tentar",
    "tentávei": "tentar",
    "tentáveis": "tentável",
    "tentâmens": "tentâmen",
    "tentórios": "tentório",
    "tenuicornes": "tenuicorne",
    "tenuicórnea": "tenuicórneo",
    "tenuicórneas": "tenuicórneo",
    "tenuicórneos": "tenuicórneo",
    "tenuidades": "tenuidade",
    "tenuiflora": "tenuifloro",
    "tenuifloras": "tenuifloro",
    "tenuifloros": "tenuifloro",
    "tenuifoliada": "tenuifoliado",
    "tenuifoliadas": "tenuifoliado",
    "tenuifoliados": "tenuifoliado",
    "tenuirrostra": "tenuirrostro",
    "tenuirrostras": "tenuirrostro",
    "tenuirrostros": "tenuirrostro",
    "tenuípedes": "tenuípede",
    "tenuípenes": "tenuípene",
    "tenças": "tença",
    "tenções": "tenção",
    "tenências": "tenência",
    "teníases": "teníase",
    "tenífugos": "tenífugo",
    "teníidas": "teníida",
    "tenística": "tenístico",
    "tenísticas": "tenístico",
    "tenísticos": "tenístico",
    "tenótomos": "tenótomo",
    "teobrominas": "teobromina",
    "teocalis": "teocali",
    "teocracias": "teocracia",
    "teocratas": "teocrata",
    "teocraticismos": "teocraticismo",
    "teocratiza": "teocratizar",
    "teocratizada": "teocratizar",
    "teocratizadas": "teocratizar",
    "teocratizado": "teocratizar",
    "teocratizados": "teocratizar",
    "teocratizai": "teocratizar",
    "teocratizais": "teocratizar",
    "teocratizam": "teocratizar",
    "teocratizamo": "teocratizar",
    "teocratizamos": "teocratizar",
    "teocratizando": "teocratizar",
    "teocratizara": "teocratizar",
    "teocratizaram": "teocratizar",
    "teocratizaras": "teocratizar",
    "teocratizarde": "teocratizar",
    "teocratizardes": "teocratizar",
    "teocratizare": "teocratizar",
    "teocratizarei": "teocratizar",
    "teocratizareis": "teocratizar",
    "teocratizarem": "teocratizar",
    "teocratizaremos": "teocratizar",
    "teocratizares": "teocratizar",
    "teocratizaria": "teocratizar",
    "teocratizariam": "teocratizar",
    "teocratizarias": "teocratizar",
    "teocratizarmo": "teocratizar",
    "teocratizarmos": "teocratizar",
    "teocratizará": "teocratizar",
    "teocratizarás": "teocratizar",
    "teocratizarão": "teocratizar",
    "teocratizaríamos": "teocratizar",
    "teocratizaríeis": "teocratizar",
    "teocratizas": "teocratizar",
    "teocratizasse": "teocratizar",
    "teocratizassem": "teocratizar",
    "teocratizasses": "teocratizar",
    "teocratizaste": "teocratizar",
    "teocratizastes": "teocratizar",
    "teocratizava": "teocratizar",
    "teocratizavam": "teocratizar",
    "teocratizavas": "teocratizar",
    "teocratizações": "teocratização",
    "teocratize": "teocratizar",
    "teocratizei": "teocratizar",
    "teocratizeis": "teocratizar",
    "teocratizem": "teocratizar",
    "teocratizemo": "teocratizar",
    "teocratizemos": "teocratizar",
    "teocratizes": "teocratizar",
    "teocratizo": "teocratizar",
    "teocratizou": "teocratizar",
    "teocratizá": "teocratizar",
    "teocratizámo": "teocratizar",
    "teocratizámos": "teocratizar",
    "teocratizáramo": "teocratizar",
    "teocratizáramos": "teocratizar",
    "teocratizárei": "teocratizar",
    "teocratizáreis": "teocratizar",
    "teocratizásseis": "teocratizar",
    "teocratizássemos": "teocratizar",
    "teocratizávamo": "teocratizar",
    "teocratizávamos": "teocratizar",
    "teocratizávei": "teocratizar",
    "teocratizáveis": "teocratizável",
    "teocêntrica": "teocêntrico",
    "teocêntricas": "teocêntrico",
    "teocêntricos": "teocêntrico",
    "teodiceias": "teodiceia",
    "teodolitos": "teodolito",
    "teofanias": "teofania",
    "teofilantropias": "teofilantropia",
    "teofilinas": "teofilina",
    "teofobias": "teofobia",
    "teogenesias": "teogenesia",
    "teogonias": "teogonia",
    "teogonistas": "teogonista",
    "teogónica": "teogónico",
    "teogónicas": "teogónico",
    "teogónicos": "teogónico",
    "teologais": "teologal",
    "teologastros": "teologastro",
    "teologias": "teologia",
    "teologismos": "teologismo",
    "teologiza": "teologizar",
    "teologizada": "teologizar",
    "teologizadas": "teologizar",
    "teologizado": "teologizar",
    "teologizados": "teologizar",
    "teologizai": "teologizar",
    "teologizais": "teologizar",
    "teologizam": "teologizar",
    "teologizamo": "teologizar",
    "teologizamos": "teologizar",
    "teologizando": "teologizar",
    "teologizara": "teologizar",
    "teologizaram": "teologizar",
    "teologizaras": "teologizar",
    "teologizardes": "teologizar",
    "teologizarei": "teologizar",
    "teologizareis": "teologizar",
    "teologizarem": "teologizar",
    "teologizaremos": "teologizar",
    "teologizares": "teologizar",
    "teologizaria": "teologizar",
    "teologizariam": "teologizar",
    "teologizarias": "teologizar",
    "teologizarmo": "teologizar",
    "teologizarmos": "teologizar",
    "teologizará": "teologizar",
    "teologizarás": "teologizar",
    "teologizarão": "teologizar",
    "teologizaríamos": "teologizar",
    "teologizaríeis": "teologizar",
    "teologizas": "teologizar",
    "teologizasse": "teologizar",
    "teologizassem": "teologizar",
    "teologizasses": "teologizar",
    "teologizaste": "teologizar",
    "teologizastes": "teologizar",
    "teologizava": "teologizar",
    "teologizavam": "teologizar",
    "teologizavas": "teologizar",
    "teologize": "teologizar",
    "teologizei": "teologizar",
    "teologizeis": "teologizar",
    "teologizem": "teologizar",
    "teologizemo": "teologizar",
    "teologizemos": "teologizar",
    "teologizes": "teologizar",
    "teologizo": "teologizar",
    "teologizou": "teologizar",
    "teologizámo": "teologizar",
    "teologizámos": "teologizar",
    "teologizáramo": "teologizar",
    "teologizáramos": "teologizar",
    "teologizáreis": "teologizar",
    "teologizásseis": "teologizar",
    "teologizássemos": "teologizar",
    "teologizávamo": "teologizar",
    "teologizávamos": "teologizar",
    "teologizáveis": "teologizar",
    "teológica": "teológico",
    "teológicas": "teológico",
    "teológicos": "teológico",
    "teomancias": "teomancia",
    "teomanias": "teomania",
    "teomantes": "teomante",
    "teomaníaca": "teomaníaco",
    "teomaníacas": "teomaníaco",
    "teomaníacos": "teomaníaco",
    "teomitias": "teomitia",
    "teomitologias": "teomitologia",
    "teomitológica": "teomitológico",
    "teomitológicas": "teomitológico",
    "teomitológicos": "teomitológico",
    "teonímias": "teonímia",
    "teonímos": "teonímo",
    "teopsias": "teopsia",
    "teoremas": "teorema",
    "teores": "teor",
    "teorias": "teoria",
    "teoricistas": "teoricista",
    "teorismos": "teorismo",
    "teoristas": "teorista",
    "teoriza": "teorizar",
    "teorizada": "teorizar",
    "teorizadas": "teorizar",
    "teorizadinha": "teorizado",
    "teorizadinhas": "teorizado",
    "teorizadinho": "teorizado",
    "teorizadinhos": "teorizado",
    "teorizadita": "teorizado",
    "teorizaditas": "teorizado",
    "teorizadito": "teorizado",
    "teorizaditos": "teorizado",
    "teorizado": "teorizar",
    "teorizados": "teorizar",
    "teorizadíssima": "teorizado",
    "teorizadíssimas": "teorizado",
    "teorizadíssimo": "teorizado",
    "teorizadíssimos": "teorizado",
    "teorizai": "teorizar",
    "teorizais": "teorizar",
    "teorizam": "teorizar",
    "teorizamo": "teorizar",
    "teorizamos": "teorizar",
    "teorizando": "teorizar",
    "teorizara": "teorizar",
    "teorizaram": "teorizar",
    "teorizaras": "teorizar",
    "teorizarde": "teorizar",
    "teorizardes": "teorizar",
    "teorizare": "teorizar",
    "teorizarei": "teorizar",
    "teorizareis": "teorizar",
    "teorizarem": "teorizar",
    "teorizaremos": "teorizar",
    "teorizares": "teorizar",
    "teorizaria": "teorizar",
    "teorizariam": "teorizar",
    "teorizarias": "teorizar",
    "teorizarmo": "teorizar",
    "teorizarmos": "teorizar",
    "teorizará": "teorizar",
    "teorizarás": "teorizar",
    "teorizarão": "teorizar",
    "teorizaríamos": "teorizar",
    "teorizaríeis": "teorizar",
    "teorizas": "teorizar",
    "teorizasse": "teorizar",
    "teorizassem": "teorizar",
    "teorizasses": "teorizar",
    "teorizaste": "teorizar",
    "teorizastes": "teorizar",
    "teorizava": "teorizar",
    "teorizavam": "teorizar",
    "teorizavas": "teorizar",
    "teorizações": "teorização",
    "teorize": "teorizar",
    "teorizei": "teorizar",
    "teorizeis": "teorizar",
    "teorizem": "teorizar",
    "teorizemo": "teorizar",
    "teorizemos": "teorizar",
    "teorizes": "teorizar",
    "teorizo": "teorizar",
    "teorizou": "teorizar",
    "teorizá": "teorizar",
    "teorizámo": "teorizar",
    "teorizámos": "teorizar",
    "teorizáramo": "teorizar",
    "teorizáramos": "teorizar",
    "teorizárei": "teorizar",
    "teorizáreis": "teorizar",
    "teorizásseis": "teorizar",
    "teorizássemos": "teorizar",
    "teorizávamo": "teorizar",
    "teorizávamos": "teorizar",
    "teorizávei": "teorizar",
    "teorizáveis": "teorizável",
    "teorética": "teorético",
    "teoréticas": "teorético",
    "teoréticos": "teorético",
    "teosebias": "teosebia",
    "teoses": "teose",
    "teosofismos": "teosofismo",
    "teosofistas": "teosofista",
    "teosófica": "teosófico",
    "teosóficas": "teosófico",
    "teosóficos": "teosófico",
    "tepalóides": "tepalóide",
    "tepes": "tepe",
    "tepesa": "tepês",
    "tepesas": "tepês",
    "tepeses": "tepês",
    "tepidezes": "tepidez",
    "tepidários": "tepidário",
    "tepores": "tepor",
    "terapeutas": "terapeuta",
    "terapias": "terapia",
    "teraponídeos": "teraponídeo",
    "terapêutica": "terapêutico",
    "terapêuticas": "terapêutico",
    "terapêuticos": "terapêutico",
    "terarcas": "terarca",
    "teratogenesias": "teratogenesia",
    "teratogenias": "teratogenia",
    "teratogéneses": "teratogénese",
    "teratogénica": "teratogénico",
    "teratogénicas": "teratogénico",
    "teratogénicos": "teratogénico",
    "teratologias": "teratologia",
    "teratologistas": "teratologista",
    "teratológica": "teratológico",
    "teratológicas": "teratológico",
    "teratológicos": "teratológico",
    "teratopagias": "teratopagia",
    "teratotomias": "teratotomia",
    "teratógena": "teratógeno",
    "teratógenas": "teratógeno",
    "teratógenos": "teratógeno",
    "teratóloga": "teratólogo",
    "teratólogas": "teratólogo",
    "teratólogos": "teratólogo",
    "teratópagos": "teratópago",
    "terce": "terçar",
    "tercei": "terçar",
    "terceira": "terceiro",
    "terceirada": "terceirar",
    "terceiradas": "terceirar",
    "terceirado": "terceirar",
    "terceirados": "terceirar",
    "terceirai": "terceirar",
    "terceirais": "terceirar",
    "terceiram": "terceirar",
    "terceiramo": "terceirar",
    "terceiramos": "terceirar",
    "terceirando": "terceirar",
    "terceiranistas": "terceiranista",
    "terceirara": "terceirar",
    "terceiraram": "terceirar",
    "terceiraras": "terceirar",
    "terceirarde": "terceirar",
    "terceirardes": "terceirar",
    "terceirare": "terceirar",
    "terceirarei": "terceirar",
    "terceirareis": "terceirar",
    "terceirarem": "terceirar",
    "terceiraremos": "terceirar",
    "terceirares": "terceirar",
    "terceiraria": "terceirar",
    "terceirariam": "terceirar",
    "terceirarias": "terceirar",
    "terceirarmo": "terceirar",
    "terceirarmos": "terceirar",
    "terceirará": "terceirar",
    "terceirarás": "terceirar",
    "terceirarão": "terceirar",
    "terceiraríamos": "terceirar",
    "terceiraríeis": "terceirar",
    "terceiras": "terceiro",
    "terceirasse": "terceirar",
    "terceirassem": "terceirar",
    "terceirasses": "terceirar",
    "terceiraste": "terceirar",
    "terceirastes": "terceirar",
    "terceirava": "terceirar",
    "terceiravam": "terceirar",
    "terceiravas": "terceirar",
    "terceire": "terceirar",
    "terceirei": "terceirar",
    "terceireis": "terceirar",
    "terceirem": "terceirar",
    "terceiremo": "terceirar",
    "terceiremos": "terceirar",
    "terceirenses": "terceirense",
    "terceires": "terceirar",
    "terceiro": "terceirar",
    "terceiros": "terceiro",
    "terceirou": "terceirar",
    "terceirá": "terceirar",
    "terceirámo": "terceirar",
    "terceirámos": "terceirar",
    "terceiráramo": "terceirar",
    "terceiráramos": "terceirar",
    "terceirárei": "terceirar",
    "terceiráreis": "terceirar",
    "terceirásseis": "terceirar",
    "terceirássemos": "terceirar",
    "terceirávamo": "terceirar",
    "terceirávamos": "terceirar",
    "terceirávei": "terceirar",
    "terceiráveis": "terceirável",
    "terceis": "terçar",
    "tercem": "terçar",
    "tercemo": "terçar",
    "tercemos": "terçar",
    "tercenária": "tercenário",
    "tercenárias": "tercenário",
    "tercenários": "tercenário",
    "terces": "terçar",
    "tercetos": "terceto",
    "terciada": "terciado",
    "terciadas": "terciado",
    "terciados": "terciado",
    "terciarões": "terciarão",
    "tercinas": "tercina",
    "tercionária": "tercionário",
    "tercionárias": "tercionário",
    "tercionários": "tercionário",
    "terciopelos": "terciopelo",
    "terciopeluda": "terciopeludo",
    "terciopeludas": "terciopeludo",
    "terciopeludos": "terciopeludo",
    "terciária": "terciário",
    "terciárias": "terciário",
    "terciários": "terciário",
    "terde": "ter",
    "terdes": "ter",
    "tere": "ter",
    "terebintina": "terebintinar",
    "terebintinada": "terebintinar",
    "terebintinadas": "terebintinar",
    "terebintinado": "terebintinar",
    "terebintinados": "terebintinar",
    "terebintinai": "terebintinar",
    "terebintinais": "terebintinar",
    "terebintinam": "terebintinar",
    "terebintinamo": "terebintinar",
    "terebintinamos": "terebintinar",
    "terebintinando": "terebintinar",
    "terebintinara": "terebintinar",
    "terebintinaram": "terebintinar",
    "terebintinaras": "terebintinar",
    "terebintinarde": "terebintinar",
    "terebintinardes": "terebintinar",
    "terebintinare": "terebintinar",
    "terebintinarei": "terebintinar",
    "terebintinareis": "terebintinar",
    "terebintinarem": "terebintinar",
    "terebintinaremos": "terebintinar",
    "terebintinares": "terebintinar",
    "terebintinaria": "terebintinar",
    "terebintinariam": "terebintinar",
    "terebintinarias": "terebintinar",
    "terebintinarmo": "terebintinar",
    "terebintinarmos": "terebintinar",
    "terebintinará": "terebintinar",
    "terebintinarás": "terebintinar",
    "terebintinarão": "terebintinar",
    "terebintinaríamos": "terebintinar",
    "terebintinaríeis": "terebintinar",
    "terebintinas": "terebintinar",
    "terebintinasse": "terebintinar",
    "terebintinassem": "terebintinar",
    "terebintinasses": "terebintinar",
    "terebintinaste": "terebintinar",
    "terebintinastes": "terebintinar",
    "terebintinava": "terebintinar",
    "terebintinavam": "terebintinar",
    "terebintinavas": "terebintinar",
    "terebintine": "terebintinar",
    "terebintinei": "terebintinar",
    "terebintineis": "terebintinar",
    "terebintinem": "terebintinar",
    "terebintinemo": "terebintinar",
    "terebintinemos": "terebintinar",
    "terebintines": "terebintinar",
    "terebintino": "terebintinar",
    "terebintinou": "terebintinar",
    "terebintiná": "terebintinar",
    "terebintinámo": "terebintinar",
    "terebintinámos": "terebintinar",
    "terebintináramo": "terebintinar",
    "terebintináramos": "terebintinar",
    "terebintinárei": "terebintinar",
    "terebintináreis": "terebintinar",
    "terebintinásseis": "terebintinar",
    "terebintinássemos": "terebintinar",
    "terebintinávamo": "terebintinar",
    "terebintinávamos": "terebintinar",
    "terebintinávei": "terebintinar",
    "terebintináveis": "terebintinável",
    "terebintos": "terebinto",
    "terebintáceas": "terebintácea",
    "terebra": "terebrar",
    "terebrada": "terebrar",
    "terebradas": "terebrar",
    "terebrado": "terebrar",
    "terebrados": "terebrar",
    "terebrai": "terebrar",
    "terebrais": "terebrar",
    "terebram": "terebrar",
    "terebramo": "terebrar",
    "terebramos": "terebrar",
    "terebrando": "terebrar",
    "terebrantes": "terebrante",
    "terebrara": "terebrar",
    "terebraram": "terebrar",
    "terebraras": "terebrar",
    "terebrarde": "terebrar",
    "terebrardes": "terebrar",
    "terebrare": "terebrar",
    "terebrarei": "terebrar",
    "terebrareis": "terebrar",
    "terebrarem": "terebrar",
    "terebraremos": "terebrar",
    "terebrares": "terebrar",
    "terebraria": "terebrar",
    "terebrariam": "terebrar",
    "terebrarias": "terebrar",
    "terebrarmo": "terebrar",
    "terebrarmos": "terebrar",
    "terebrará": "terebrar",
    "terebrarás": "terebrar",
    "terebrarão": "terebrar",
    "terebraríamos": "terebrar",
    "terebraríeis": "terebrar",
    "terebras": "terebrar",
    "terebrasse": "terebrar",
    "terebrassem": "terebrar",
    "terebrasses": "terebrar",
    "terebraste": "terebrar",
    "terebrastes": "terebrar",
    "terebrava": "terebrar",
    "terebravam": "terebrar",
    "terebravas": "terebrar",
    "terebrações": "terebração",
    "terebre": "terebrar",
    "terebrei": "terebrar",
    "terebreis": "terebrar",
    "terebrem": "terebrar",
    "terebremo": "terebrar",
    "terebremos": "terebrar",
    "terebres": "terebrar",
    "terebro": "terebrar",
    "terebrou": "terebrar",
    "terebrá": "terebrar",
    "terebrámo": "terebrar",
    "terebrámos": "terebrar",
    "terebráramo": "terebrar",
    "terebráramos": "terebrar",
    "terebrárei": "terebrar",
    "terebráreis": "terebrar",
    "terebrásseis": "terebrar",
    "terebrássemos": "terebrar",
    "terebrátulas": "terebrátula",
    "terebrávamo": "terebrar",
    "terebrávamos": "terebrar",
    "terebrávei": "terebrar",
    "terebráveis": "terebrável",
    "teredens": "teredem",
    "teredinídeos": "teredinídeo",
    "teredos": "teredo",
    "teredínidas": "teredínida",
    "terei": "ter",
    "tereis": "ter",
    "terem": "ter",
    "teremos": "ter",
    "teres": "ter",
    "teresopolitana": "teresopolitano",
    "teresopolitanas": "teresopolitano",
    "teresopolitanos": "teresopolitano",
    "teresos": "tereso",
    "tereticaudes": "tereticaude",
    "tereticaules": "tereticaule",
    "tereticola": "tereticolo",
    "tereticolas": "tereticolo",
    "tereticolos": "tereticolo",
    "teretiformes": "teretiforme",
    "teretirrostra": "teretirrostro",
    "teretirrostras": "teretirrostro",
    "teretirrostros": "teretirrostro",
    "tergais": "tergal",
    "tergeminada": "tergeminado",
    "tergeminadas": "tergeminado",
    "tergeminados": "tergeminado",
    "tergites": "tergite",
    "tergito": "tergite",
    "tergitos": "tergite",
    "tergiversa": "tergiversar",
    "tergiversada": "tergiversar",
    "tergiversadas": "tergiversar",
    "tergiversado": "tergiversar",
    "tergiversadora": "tergiversador",
    "tergiversadoras": "tergiversador",
    "tergiversadores": "tergiversador",
    "tergiversados": "tergiversar",
    "tergiversai": "tergiversar",
    "tergiversais": "tergiversar",
    "tergiversam": "tergiversar",
    "tergiversamo": "tergiversar",
    "tergiversamos": "tergiversar",
    "tergiversando": "tergiversar",
    "tergiversantes": "tergiversante",
    "tergiversara": "tergiversar",
    "tergiversaram": "tergiversar",
    "tergiversaras": "tergiversar",
    "tergiversardes": "tergiversar",
    "tergiversarei": "tergiversar",
    "tergiversareis": "tergiversar",
    "tergiversarem": "tergiversar",
    "tergiversaremos": "tergiversar",
    "tergiversares": "tergiversar",
    "tergiversaria": "tergiversar",
    "tergiversariam": "tergiversar",
    "tergiversarias": "tergiversar",
    "tergiversarmo": "tergiversar",
    "tergiversarmos": "tergiversar",
    "tergiversará": "tergiversar",
    "tergiversarás": "tergiversar",
    "tergiversarão": "tergiversar",
    "tergiversaríamos": "tergiversar",
    "tergiversaríeis": "tergiversar",
    "tergiversas": "tergiversar",
    "tergiversasse": "tergiversar",
    "tergiversassem": "tergiversar",
    "tergiversasses": "tergiversar",
    "tergiversaste": "tergiversar",
    "tergiversastes": "tergiversar",
    "tergiversatória": "tergiversatório",
    "tergiversatórias": "tergiversatório",
    "tergiversatórios": "tergiversatório",
    "tergiversava": "tergiversar",
    "tergiversavam": "tergiversar",
    "tergiversavas": "tergiversar",
    "tergiversações": "tergiversação",
    "tergiverse": "tergiversar",
    "tergiversei": "tergiversar",
    "tergiverseis": "tergiversar",
    "tergiversem": "tergiversar",
    "tergiversemo": "tergiversar",
    "tergiversemos": "tergiversar",
    "tergiverses": "tergiversar",
    "tergiverso": "tergiversar",
    "tergiversou": "tergiversar",
    "tergiversámo": "tergiversar",
    "tergiversámos": "tergiversar",
    "tergiversáramo": "tergiversar",
    "tergiversáramos": "tergiversar",
    "tergiversáreis": "tergiversar",
    "tergiversásseis": "tergiversar",
    "tergiversássemos": "tergiversar",
    "tergiversávamo": "tergiversar",
    "tergiversávamos": "tergiversar",
    "tergiversáveis": "tergiversável",
    "tergos": "tergo",
    "tergémina": "tergémino",
    "tergéminas": "tergémino",
    "tergéminos": "tergémino",
    "teria": "ter",
    "teriacais": "teriacal",
    "teriacologias": "teriacologia",
    "teriagas": "teriaga",
    "teriam": "ter",
    "terias": "ter",
    "teriodontes": "teriodonte",
    "terlinta": "terlintar",
    "terlintada": "terlintar",
    "terlintadas": "terlintar",
    "terlintado": "terlintar",
    "terlintados": "terlintar",
    "terlintai": "terlintar",
    "terlintais": "terlintar",
    "terlintam": "terlintar",
    "terlintamo": "terlintar",
    "terlintamos": "terlintar",
    "terlintando": "terlintar",
    "terlintara": "terlintar",
    "terlintaram": "terlintar",
    "terlintaras": "terlintar",
    "terlintarde": "terlintar",
    "terlintardes": "terlintar",
    "terlintare": "terlintar",
    "terlintarei": "terlintar",
    "terlintareis": "terlintar",
    "terlintarem": "terlintar",
    "terlintaremos": "terlintar",
    "terlintares": "terlintar",
    "terlintaria": "terlintar",
    "terlintariam": "terlintar",
    "terlintarias": "terlintar",
    "terlintarmo": "terlintar",
    "terlintarmos": "terlintar",
    "terlintará": "terlintar",
    "terlintarás": "terlintar",
    "terlintarão": "terlintar",
    "terlintaríamos": "terlintar",
    "terlintaríeis": "terlintar",
    "terlintas": "terlintar",
    "terlintasse": "terlintar",
    "terlintassem": "terlintar",
    "terlintasses": "terlintar",
    "terlintaste": "terlintar",
    "terlintastes": "terlintar",
    "terlintava": "terlintar",
    "terlintavam": "terlintar",
    "terlintavas": "terlintar",
    "terlinte": "terlintar",
    "terlintei": "terlintar",
    "terlinteis": "terlintar",
    "terlintem": "terlintar",
    "terlintemo": "terlintar",
    "terlintemos": "terlintar",
    "terlintes": "terlintar",
    "terlintins": "terlintim",
    "terlinto": "terlintar",
    "terlintou": "terlintar",
    "terlintá": "terlintar",
    "terlintámo": "terlintar",
    "terlintámos": "terlintar",
    "terlintáramo": "terlintar",
    "terlintáramos": "terlintar",
    "terlintárei": "terlintar",
    "terlintáreis": "terlintar",
    "terlintásseis": "terlintar",
    "terlintássemos": "terlintar",
    "terlintávamo": "terlintar",
    "terlintávamos": "terlintar",
    "terlintávei": "terlintar",
    "terlintáveis": "terlintar",
    "termais": "termal",
    "termalgias": "termalgia",
    "termalidades": "termalidade",
    "termalismos": "termalismo",
    "termas": "terma",
    "termestesias": "termestesia",
    "termias": "termia",
    "termiatrias": "termiatria",
    "termidores": "termidor",
    "termina": "terminar",
    "terminada": "terminar",
    "terminadas": "terminar",
    "terminado": "terminar",
    "terminados": "terminar",
    "terminai": "terminar",
    "terminais": "terminar",
    "terminam": "terminar",
    "terminamo": "terminar",
    "terminamos": "terminar",
    "terminando": "terminar",
    "terminantes": "terminante",
    "terminara": "terminar",
    "terminaram": "terminar",
    "terminaras": "terminar",
    "terminarde": "terminar",
    "terminardes": "terminar",
    "terminare": "terminar",
    "terminarei": "terminar",
    "terminareis": "terminar",
    "terminarem": "terminar",
    "terminaremos": "terminar",
    "terminares": "terminar",
    "terminaria": "terminar",
    "terminariam": "terminar",
    "terminarias": "terminar",
    "terminarmo": "terminar",
    "terminarmos": "terminar",
    "terminará": "terminar",
    "terminarás": "terminar",
    "terminarão": "terminar",
    "terminaríamos": "terminar",
    "terminaríeis": "terminar",
    "terminas": "terminar",
    "terminasse": "terminar",
    "terminassem": "terminar",
    "terminasses": "terminar",
    "terminaste": "terminar",
    "terminastes": "terminar",
    "terminativa": "terminativo",
    "terminativas": "terminativo",
    "terminativos": "terminativo",
    "terminava": "terminar",
    "terminavam": "terminar",
    "terminavas": "terminar",
    "terminações": "terminação",
    "termine": "terminar",
    "terminei": "terminar",
    "termineis": "terminar",
    "terminem": "terminar",
    "terminemo": "terminar",
    "terminemos": "terminar",
    "termines": "terminar",
    "termino": "terminar",
    "terminologias": "terminologia",
    "terminologistas": "terminologista",
    "terminológica": "terminológico",
    "terminológicas": "terminológico",
    "terminológicos": "terminológico",
    "terminou": "terminar",
    "terminá": "terminar",
    "terminámo": "terminar",
    "terminámos": "terminar",
    "termináramo": "terminar",
    "termináramos": "terminar",
    "terminárei": "terminar",
    "termináreis": "terminar",
    "terminásseis": "terminar",
    "terminássemos": "terminar",
    "terminávamo": "terminar",
    "terminávamos": "terminar",
    "terminávei": "terminar",
    "termináveis": "terminável",
    "termistores": "termistor",
    "termiteiras": "termiteira",
    "termiteiros": "termiteiro",
    "termitófila": "termitófilo",
    "termitófilas": "termitófilo",
    "termitófilos": "termitófilo",
    "termiónica": "termiónico",
    "termiónicas": "termiónico",
    "termiónicos": "termiónico",
    "termiões": "termião",
    "termo": "ter",
    "termoacumuladores": "termoacumulador",
    "termobarómetros": "termobarómetro",
    "termocautérios": "termocautério",
    "termocópias": "termocópia",
    "termodieléctica": "termodieléctico",
    "termodielécticas": "termodieléctico",
    "termodielécticos": "termodieléctico",
    "termodinâmica": "termodinâmico",
    "termodinâmicas": "termodinâmico",
    "termodinâmicos": "termodinâmico",
    "termoelectricidades": "termoelectricidade",
    "termoeléctrica": "termoeléctrico",
    "termoeléctricas": "termoeléctrico",
    "termoeléctricos": "termoeléctrico",
    "termofobias": "termofobia",
    "termogenias": "termogenia",
    "termogramas": "termograma",
    "termogénea": "termogéneo",
    "termogéneas": "termogéneo",
    "termogéneos": "termogéneo",
    "termogéneses": "termogénese",
    "termolacagens": "termolacagem",
    "termologias": "termologia",
    "termológica": "termológico",
    "termológicas": "termológico",
    "termológicos": "termológico",
    "termomagnetismos": "termomagnetismo",
    "termomagnética": "termomagnético",
    "termomagnéticas": "termomagnético",
    "termomagnéticos": "termomagnético",
    "termomanómetros": "termomanómetro",
    "termometrias": "termometria",
    "termometrógrafos": "termometrógrafo",
    "termomultiplicadores": "termomultiplicador",
    "termométrica": "termométrico",
    "termométricas": "termométrico",
    "termométricos": "termométrico",
    "termonucleares": "termonuclear",
    "termopares": "termopar",
    "termopilhas": "termopilha",
    "termoplásticos": "termoplástico",
    "termoquímica": "termoquímico",
    "termoquímicas": "termoquímico",
    "termoquímicos": "termoquímico",
    "termos": "termo",
    "termoscopias": "termoscopia",
    "termoscópica": "termoscópico",
    "termoscópicas": "termoscópico",
    "termoscópicos": "termoscópico",
    "termossifões": "termossifão",
    "termostatos": "termostato",
    "termotactismos": "termotactismo",
    "termotaxias": "termotaxia",
    "termoterapias": "termoterapia",
    "termotropismos": "termotropismo",
    "termântica": "termântico",
    "termânticas": "termântico",
    "termânticos": "termântico",
    "termítica": "termítico",
    "termíticas": "termítico",
    "termíticos": "termítico",
    "termófila": "termófilo",
    "termófilas": "termófilo",
    "termófilos": "termófilo",
    "termóforos": "termóforo",
    "termógrafos": "termógrafo",
    "termólises": "termólise",
    "termómetros": "termómetro",
    "termóstatos": "termóstato",
    "terna": "terno",
    "ternada": "ternado",
    "ternadas": "ternado",
    "ternados": "ternado",
    "ternas": "terno",
    "ternazinha": "terno",
    "ternazinhas": "terno",
    "ternazita": "terno",
    "ternazitas": "terno",
    "terneiros": "terneiro",
    "ternos": "terno",
    "ternozinho": "terno",
    "ternozinhos": "terno",
    "ternozito": "terno",
    "ternozitos": "terno",
    "ternuras": "ternura",
    "ternurenta": "ternurento",
    "ternurentas": "ternurento",
    "ternurentos": "ternurento",
    "ternária": "ternário",
    "ternárias": "ternário",
    "ternários": "ternário",
    "teromorfos": "teromorfo",
    "terpenos": "terpeno",
    "terpinas": "terpina",
    "terpsicórica": "terpsicórico",
    "terpsicóricas": "terpsicórico",
    "terpsicóricos": "terpsicórico",
    "terracotas": "terracota",
    "terradas": "terrada",
    "terradegueira": "terradegueiro",
    "terradegueiras": "terradegueiro",
    "terradegueiros": "terradegueiro",
    "terrados": "terrado",
    "terrais": "terral",
    "terramicinas": "terramicina",
    "terramotadas": "terramotada",
    "terramotos": "terramoto",
    "terranoveira": "terranoveiro",
    "terranoveiras": "terranoveiro",
    "terranoveiros": "terranoveiro",
    "terranquins": "terranquim",
    "terrantesa": "terrantês",
    "terrantesas": "terrantês",
    "terranteses": "terrantês",
    "terraplana": "terraplanar",
    "terraplanada": "terraplanar",
    "terraplanadas": "terraplanar",
    "terraplanado": "terraplanar",
    "terraplanados": "terraplanar",
    "terraplanagens": "terraplanagem",
    "terraplanai": "terraplanar",
    "terraplanais": "terraplanar",
    "terraplanam": "terraplanar",
    "terraplanamo": "terraplanar",
    "terraplanamos": "terraplanar",
    "terraplanando": "terraplanar",
    "terraplanara": "terraplanar",
    "terraplanaram": "terraplanar",
    "terraplanaras": "terraplanar",
    "terraplanarde": "terraplanar",
    "terraplanardes": "terraplanar",
    "terraplanare": "terraplanar",
    "terraplanarei": "terraplanar",
    "terraplanareis": "terraplanar",
    "terraplanarem": "terraplanar",
    "terraplanaremos": "terraplanar",
    "terraplanares": "terraplanar",
    "terraplanaria": "terraplanar",
    "terraplanariam": "terraplanar",
    "terraplanarias": "terraplanar",
    "terraplanarmo": "terraplanar",
    "terraplanarmos": "terraplanar",
    "terraplanará": "terraplanar",
    "terraplanarás": "terraplanar",
    "terraplanarão": "terraplanar",
    "terraplanaríamos": "terraplanar",
    "terraplanaríeis": "terraplanar",
    "terraplanas": "terraplanar",
    "terraplanasse": "terraplanar",
    "terraplanassem": "terraplanar",
    "terraplanasses": "terraplanar",
    "terraplanaste": "terraplanar",
    "terraplanastes": "terraplanar",
    "terraplanava": "terraplanar",
    "terraplanavam": "terraplanar",
    "terraplanavas": "terraplanar",
    "terraplane": "terraplanar",
    "terraplanei": "terraplanar",
    "terraplaneis": "terraplanar",
    "terraplanem": "terraplanar",
    "terraplanemo": "terraplanar",
    "terraplanemos": "terraplanar",
    "terraplanes": "terraplanar",
    "terraplano": "terraplanar",
    "terraplanou": "terraplanar",
    "terraplaná": "terraplanar",
    "terraplanámo": "terraplanar",
    "terraplanámos": "terraplanar",
    "terraplanáramo": "terraplanar",
    "terraplanáramos": "terraplanar",
    "terraplanárei": "terraplanar",
    "terraplanáreis": "terraplanar",
    "terraplanásseis": "terraplanar",
    "terraplanássemos": "terraplanar",
    "terraplanávamo": "terraplanar",
    "terraplanávamos": "terraplanar",
    "terraplanávei": "terraplanar",
    "terraplanáveis": "terraplanar",
    "terraplena": "terraplenar",
    "terraplenada": "terraplenar",
    "terraplenadas": "terraplenar",
    "terraplenado": "terraplenar",
    "terraplenados": "terraplenar",
    "terraplenagens": "terraplenagem",
    "terraplenai": "terraplenar",
    "terraplenais": "terraplenar",
    "terraplenam": "terraplenar",
    "terraplenamo": "terraplenar",
    "terraplenamos": "terraplenar",
    "terraplenando": "terraplenar",
    "terraplenara": "terraplenar",
    "terraplenaram": "terraplenar",
    "terraplenaras": "terraplenar",
    "terraplenarde": "terraplenar",
    "terraplenardes": "terraplenar",
    "terraplenare": "terraplenar",
    "terraplenarei": "terraplenar",
    "terraplenareis": "terraplenar",
    "terraplenarem": "terraplenar",
    "terraplenaremos": "terraplenar",
    "terraplenares": "terraplenar",
    "terraplenaria": "terraplenar",
    "terraplenariam": "terraplenar",
    "terraplenarias": "terraplenar",
    "terraplenarmo": "terraplenar",
    "terraplenarmos": "terraplenar",
    "terraplenará": "terraplenar",
    "terraplenarás": "terraplenar",
    "terraplenarão": "terraplenar",
    "terraplenaríamos": "terraplenar",
    "terraplenaríeis": "terraplenar",
    "terraplenas": "terraplenar",
    "terraplenasse": "terraplenar",
    "terraplenassem": "terraplenar",
    "terraplenasses": "terraplenar",
    "terraplenaste": "terraplenar",
    "terraplenastes": "terraplenar",
    "terraplenava": "terraplenar",
    "terraplenavam": "terraplenar",
    "terraplenavas": "terraplenar",
    "terraplene": "terraplenar",
    "terraplenei": "terraplenar",
    "terrapleneis": "terraplenar",
    "terraplenem": "terraplenar",
    "terraplenemo": "terraplenar",
    "terraplenemos": "terraplenar",
    "terraplenes": "terraplenar",
    "terrapleno": "terraplenar",
    "terraplenos": "terrapleno",
    "terraplenou": "terraplenar",
    "terraplená": "terraplenar",
    "terraplenámo": "terraplenar",
    "terraplenámos": "terraplenar",
    "terraplenáramo": "terraplenar",
    "terraplenáramos": "terraplenar",
    "terraplenárei": "terraplenar",
    "terraplenáreis": "terraplenar",
    "terraplenásseis": "terraplenar",
    "terraplenássemos": "terraplenar",
    "terraplenávamo": "terraplenar",
    "terraplenávamos": "terraplenar",
    "terraplenávei": "terraplenar",
    "terraplenáveis": "terraplenável",
    "terras": "terra",
    "terratenentes": "terratenente",
    "terraços": "terraço",
    "terreada": "terrear",
    "terreadas": "terrear",
    "terreado": "terrear",
    "terreados": "terrear",
    "terreai": "terrear",
    "terreais": "terrear",
    "terreamo": "terrear",
    "terreamos": "terrear",
    "terreando": "terrear",
    "terreara": "terrear",
    "terrearam": "terrear",
    "terrearas": "terrear",
    "terreardes": "terrear",
    "terrearei": "terrear",
    "terreareis": "terrear",
    "terrearem": "terrear",
    "terrearemos": "terrear",
    "terreares": "terrear",
    "terrearia": "terrear",
    "terreariam": "terrear",
    "terrearias": "terrear",
    "terrearmo": "terrear",
    "terrearmos": "terrear",
    "terreará": "terrear",
    "terrearás": "terrear",
    "terrearão": "terrear",
    "terrearíamos": "terrear",
    "terrearíeis": "terrear",
    "terreasse": "terrear",
    "terreassem": "terrear",
    "terreasses": "terrear",
    "terreaste": "terrear",
    "terreastes": "terrear",
    "terreava": "terrear",
    "terreavam": "terrear",
    "terreavas": "terrear",
    "terreei": "terrear",
    "terreeis": "terrear",
    "terreemo": "terrear",
    "terreemos": "terrear",
    "terreia": "terrear",
    "terreiam": "terrear",
    "terreias": "terrear",
    "terreie": "terrear",
    "terreiem": "terrear",
    "terreies": "terrear",
    "terreio": "terrear",
    "terreiros": "terreiro",
    "terreja": "terrejar",
    "terrejada": "terrejar",
    "terrejadas": "terrejar",
    "terrejado": "terrejar",
    "terrejados": "terrejar",
    "terrejai": "terrejar",
    "terrejais": "terrejar",
    "terrejam": "terrejar",
    "terrejamo": "terrejar",
    "terrejamos": "terrejar",
    "terrejando": "terrejar",
    "terrejara": "terrejar",
    "terrejaram": "terrejar",
    "terrejaras": "terrejar",
    "terrejardes": "terrejar",
    "terrejarei": "terrejar",
    "terrejareis": "terrejar",
    "terrejarem": "terrejar",
    "terrejaremos": "terrejar",
    "terrejares": "terrejar",
    "terrejaria": "terrejar",
    "terrejariam": "terrejar",
    "terrejarias": "terrejar",
    "terrejarmo": "terrejar",
    "terrejarmos": "terrejar",
    "terrejará": "terrejar",
    "terrejarás": "terrejar",
    "terrejarão": "terrejar",
    "terrejaríamos": "terrejar",
    "terrejaríeis": "terrejar",
    "terrejas": "terrejar",
    "terrejasse": "terrejar",
    "terrejassem": "terrejar",
    "terrejasses": "terrejar",
    "terrejaste": "terrejar",
    "terrejastes": "terrejar",
    "terrejava": "terrejar",
    "terrejavam": "terrejar",
    "terrejavas": "terrejar",
    "terreje": "terrejar",
    "terrejei": "terrejar",
    "terrejeis": "terrejar",
    "terrejem": "terrejar",
    "terrejemo": "terrejar",
    "terrejemos": "terrejar",
    "terrejes": "terrejar",
    "terrejo": "terrejar",
    "terrejolas": "terrejola",
    "terrejou": "terrejar",
    "terrejámo": "terrejar",
    "terrejámos": "terrejar",
    "terrejáramo": "terrejar",
    "terrejáramos": "terrejar",
    "terrejáreis": "terrejar",
    "terrejásseis": "terrejar",
    "terrejássemos": "terrejar",
    "terrejávamo": "terrejar",
    "terrejávamos": "terrejar",
    "terrejáveis": "terrejar",
    "terremotos": "terremoto",
    "terrena": "terreno",
    "terrenais": "terrenal",
    "terrenas": "terreno",
    "terrenha": "terrenho",
    "terrenhas": "terrenho",
    "terrenhos": "terrenho",
    "terrenos": "terreno",
    "terrenta": "terrento",
    "terrentas": "terrento",
    "terrentos": "terrento",
    "terreou": "terrear",
    "terrestres": "terrestre",
    "terreámo": "terrear",
    "terreámos": "terrear",
    "terreáramo": "terrear",
    "terreáramos": "terrear",
    "terreáreis": "terrear",
    "terreásseis": "terrear",
    "terreássemos": "terrear",
    "terreávamo": "terrear",
    "terreávamos": "terrear",
    "terreáveis": "terrear",
    "terribilidades": "terribilidade",
    "terribilíssima": "terrível",
    "terribilíssimas": "terrível",
    "terribilíssimo": "terrível",
    "terribilíssimos": "terrível",
    "terricantes": "terricante",
    "terrifica": "terrificar",
    "terrificada": "terrificar",
    "terrificadas": "terrificar",
    "terrificado": "terrificar",
    "terrificadora": "terrificador",
    "terrificadoras": "terrificador",
    "terrificadores": "terrificador",
    "terrificados": "terrificar",
    "terrificai": "terrificar",
    "terrificais": "terrificar",
    "terrificam": "terrificar",
    "terrificamo": "terrificar",
    "terrificamos": "terrificar",
    "terrificando": "terrificar",
    "terrificara": "terrificar",
    "terrificaram": "terrificar",
    "terrificaras": "terrificar",
    "terrificarde": "terrificar",
    "terrificardes": "terrificar",
    "terrificare": "terrificar",
    "terrificarei": "terrificar",
    "terrificareis": "terrificar",
    "terrificarem": "terrificar",
    "terrificaremos": "terrificar",
    "terrificares": "terrificar",
    "terrificaria": "terrificar",
    "terrificariam": "terrificar",
    "terrificarias": "terrificar",
    "terrificarmo": "terrificar",
    "terrificarmos": "terrificar",
    "terrificará": "terrificar",
    "terrificarás": "terrificar",
    "terrificarão": "terrificar",
    "terrificaríamos": "terrificar",
    "terrificaríeis": "terrificar",
    "terrificas": "terrificar",
    "terrificasse": "terrificar",
    "terrificassem": "terrificar",
    "terrificasses": "terrificar",
    "terrificaste": "terrificar",
    "terrificastes": "terrificar",
    "terrificava": "terrificar",
    "terrificavam": "terrificar",
    "terrificavas": "terrificar",
    "terrifico": "terrificar",
    "terrificou": "terrificar",
    "terrificá": "terrificar",
    "terrificámo": "terrificar",
    "terrificámos": "terrificar",
    "terrificáramo": "terrificar",
    "terrificáramos": "terrificar",
    "terrificárei": "terrificar",
    "terrificáreis": "terrificar",
    "terrificásseis": "terrificar",
    "terrificássemos": "terrificar",
    "terrificávamo": "terrificar",
    "terrificávamos": "terrificar",
    "terrificávei": "terrificar",
    "terrificáveis": "terrificável",
    "terrifique": "terrificar",
    "terrifiquei": "terrificar",
    "terrifiqueis": "terrificar",
    "terrifiquem": "terrificar",
    "terrifiquemo": "terrificar",
    "terrifiquemos": "terrificar",
    "terrifiques": "terrificar",
    "terrinas": "terrina",
    "terrinca": "terrincar",
    "terrincada": "terrincar",
    "terrincadas": "terrincar",
    "terrincado": "terrincar",
    "terrincados": "terrincar",
    "terrincai": "terrincar",
    "terrincais": "terrincar",
    "terrincam": "terrincar",
    "terrincamo": "terrincar",
    "terrincamos": "terrincar",
    "terrincando": "terrincar",
    "terrincara": "terrincar",
    "terrincaram": "terrincar",
    "terrincaras": "terrincar",
    "terrincarde": "terrincar",
    "terrincardes": "terrincar",
    "terrincare": "terrincar",
    "terrincarei": "terrincar",
    "terrincareis": "terrincar",
    "terrincarem": "terrincar",
    "terrincaremos": "terrincar",
    "terrincares": "terrincar",
    "terrincaria": "terrincar",
    "terrincariam": "terrincar",
    "terrincarias": "terrincar",
    "terrincarmo": "terrincar",
    "terrincarmos": "terrincar",
    "terrincará": "terrincar",
    "terrincarás": "terrincar",
    "terrincarão": "terrincar",
    "terrincaríamos": "terrincar",
    "terrincaríeis": "terrincar",
    "terrincas": "terrincar",
    "terrincasse": "terrincar",
    "terrincassem": "terrincar",
    "terrincasses": "terrincar",
    "terrincaste": "terrincar",
    "terrincastes": "terrincar",
    "terrincava": "terrincar",
    "terrincavam": "terrincar",
    "terrincavas": "terrincar",
    "terrinco": "terrincar",
    "terrincou": "terrincar",
    "terrincá": "terrincar",
    "terrincámo": "terrincar",
    "terrincámos": "terrincar",
    "terrincáramo": "terrincar",
    "terrincáramos": "terrincar",
    "terrincárei": "terrincar",
    "terrincáreis": "terrincar",
    "terrincásseis": "terrincar",
    "terrincássemos": "terrincar",
    "terrincávamo": "terrincar",
    "terrincávamos": "terrincar",
    "terrincávei": "terrincar",
    "terrincáveis": "terrincável",
    "terrinha": "terra",
    "terrinhas": "terra",
    "terrinque": "terrincar",
    "terrinquei": "terrincar",
    "terrinqueis": "terrincar",
    "terrinquem": "terrincar",
    "terrinquemo": "terrincar",
    "terrinquemos": "terrincar",
    "terrinques": "terrincar",
    "terriolas": "terriola",
    "territa": "terra",
    "territas": "terra",
    "territoriais": "territorial",
    "territorialidades": "territorialidade",
    "territórios": "território",
    "terriças": "terriça",
    "terriços": "terriço",
    "terroadas": "terroada",
    "terroeiros": "terroeiro",
    "terrolas": "terrola",
    "terrora": "terrorar",
    "terrorada": "terrorar",
    "terroradas": "terrorar",
    "terrorado": "terrorar",
    "terrorados": "terrorar",
    "terrorai": "terrorar",
    "terrorais": "terrorar",
    "terroram": "terrorar",
    "terroramo": "terrorar",
    "terroramos": "terrorar",
    "terrorando": "terrorar",
    "terrorara": "terrorar",
    "terroraram": "terrorar",
    "terroraras": "terrorar",
    "terrorarde": "terrorar",
    "terrorardes": "terrorar",
    "terrorare": "terrorar",
    "terrorarei": "terrorar",
    "terrorareis": "terrorar",
    "terrorarem": "terrorar",
    "terroraremos": "terrorar",
    "terrorares": "terrorar",
    "terroraria": "terrorar",
    "terrorariam": "terrorar",
    "terrorarias": "terrorar",
    "terrorarmo": "terrorar",
    "terrorarmos": "terrorar",
    "terrorará": "terrorar",
    "terrorarás": "terrorar",
    "terrorarão": "terrorar",
    "terroraríamos": "terrorar",
    "terroraríeis": "terrorar",
    "terroras": "terrorar",
    "terrorasse": "terrorar",
    "terrorassem": "terrorar",
    "terrorasses": "terrorar",
    "terroraste": "terrorar",
    "terrorastes": "terrorar",
    "terrorava": "terrorar",
    "terroravam": "terrorar",
    "terroravas": "terrorar",
    "terrore": "terrorar",
    "terrorei": "terrorar",
    "terroreis": "terrorar",
    "terrorem": "terrorar",
    "terroremo": "terrorar",
    "terroremos": "terrorar",
    "terrores": "terrorar",
    "terrorismos": "terrorismo",
    "terroristas": "terrorista",
    "terroriza": "terrorizar",
    "terrorizada": "terrorizar",
    "terrorizadas": "terrorizar",
    "terrorizado": "terrorizar",
    "terrorizados": "terrorizar",
    "terrorizai": "terrorizar",
    "terrorizais": "terrorizar",
    "terrorizam": "terrorizar",
    "terrorizamo": "terrorizar",
    "terrorizamos": "terrorizar",
    "terrorizando": "terrorizar",
    "terrorizara": "terrorizar",
    "terrorizaram": "terrorizar",
    "terrorizaras": "terrorizar",
    "terrorizarde": "terrorizar",
    "terrorizardes": "terrorizar",
    "terrorizare": "terrorizar",
    "terrorizarei": "terrorizar",
    "terrorizareis": "terrorizar",
    "terrorizarem": "terrorizar",
    "terrorizaremos": "terrorizar",
    "terrorizares": "terrorizar",
    "terrorizaria": "terrorizar",
    "terrorizariam": "terrorizar",
    "terrorizarias": "terrorizar",
    "terrorizarmo": "terrorizar",
    "terrorizarmos": "terrorizar",
    "terrorizará": "terrorizar",
    "terrorizarás": "terrorizar",
    "terrorizarão": "terrorizar",
    "terrorizaríamos": "terrorizar",
    "terrorizaríeis": "terrorizar",
    "terrorizas": "terrorizar",
    "terrorizasse": "terrorizar",
    "terrorizassem": "terrorizar",
    "terrorizasses": "terrorizar",
    "terrorizaste": "terrorizar",
    "terrorizastes": "terrorizar",
    "terrorizava": "terrorizar",
    "terrorizavam": "terrorizar",
    "terrorizavas": "terrorizar",
    "terrorize": "terrorizar",
    "terrorizei": "terrorizar",
    "terrorizeis": "terrorizar",
    "terrorizem": "terrorizar",
    "terrorizemo": "terrorizar",
    "terrorizemos": "terrorizar",
    "terrorizes": "terrorizar",
    "terrorizo": "terrorizar",
    "terrorizou": "terrorizar",
    "terrorizá": "terrorizar",
    "terrorizámo": "terrorizar",
    "terrorizámos": "terrorizar",
    "terrorizáramo": "terrorizar",
    "terrorizáramos": "terrorizar",
    "terrorizárei": "terrorizar",
    "terrorizáreis": "terrorizar",
    "terrorizásseis": "terrorizar",
    "terrorizássemos": "terrorizar",
    "terrorizávamo": "terrorizar",
    "terrorizávamos": "terrorizar",
    "terrorizávei": "terrorizar",
    "terrorizáveis": "terrorizável",
    "terroro": "terrorar",
    "terrorou": "terrorar",
    "terrorá": "terrorar",
    "terrorámo": "terrorar",
    "terrorámos": "terrorar",
    "terroráramo": "terrorar",
    "terroráramos": "terrorar",
    "terrorárei": "terrorar",
    "terroráreis": "terrorar",
    "terrorásseis": "terrorar",
    "terrorássemos": "terrorar",
    "terrorávamo": "terrorar",
    "terrorávamos": "terrorar",
    "terrorávei": "terrorar",
    "terroráveis": "terrorável",
    "terrorífica": "terrorífico",
    "terroríficas": "terrorífico",
    "terroríficos": "terrorífico",
    "terrosa": "terroso",
    "terrosas": "terroso",
    "terrosos": "terroso",
    "terrulenta": "terrulento",
    "terrulentas": "terrulento",
    "terrulentos": "terrulento",
    "terrunhos": "terrunho",
    "terrádegos": "terrádego",
    "terrádigos": "terrádigo",
    "terráquea": "terráqueo",
    "terráqueas": "terráqueo",
    "terráqueos": "terráqueo",
    "terrários": "terrário",
    "terréus": "terréu",
    "terríbeis": "terríbil",
    "terrícolas": "terrícola",
    "terrículas": "terrícula",
    "terrífica": "terrífico",
    "terríficas": "terrífico",
    "terríficos": "terrífico",
    "terrígena": "terrígeno",
    "terrígenas": "terrígeno",
    "terrígenos": "terrígeno",
    "terríssona": "terríssono",
    "terríssonas": "terríssono",
    "terríssonos": "terríssono",
    "terríveis": "terrível",
    "terrívoma": "terrívomo",
    "terrívomas": "terrívomo",
    "terrívomos": "terrívomo",
    "terrões": "terrão",
    "tersa": "terso",
    "tersas": "terso",
    "tersos": "terso",
    "tersóis": "tersol",
    "tertúlias": "tertúlia",
    "terá": "ter",
    "terás": "ter",
    "terão": "ter",
    "terça": "terço",
    "terçada": "terçar",
    "terçadas": "terçar",
    "terçado": "terçar",
    "terçadora": "terçador",
    "terçadoras": "terçador",
    "terçadores": "terçador",
    "terçados": "terçar",
    "terçai": "terçar",
    "terçais": "terçar",
    "terçam": "terçar",
    "terçamo": "terçar",
    "terçamos": "terçar",
    "terçando": "terçar",
    "terçara": "terçar",
    "terçaram": "terçar",
    "terçaras": "terçar",
    "terçarde": "terçar",
    "terçardes": "terçar",
    "terçare": "terçar",
    "terçarei": "terçar",
    "terçareis": "terçar",
    "terçarem": "terçar",
    "terçaremos": "terçar",
    "terçares": "terçar",
    "terçaria": "terçar",
    "terçariam": "terçar",
    "terçarias": "terçar",
    "terçarmo": "terçar",
    "terçarmos": "terçar",
    "terçará": "terçar",
    "terçarás": "terçar",
    "terçarão": "terçar",
    "terçaríamos": "terçar",
    "terçaríeis": "terçar",
    "terças": "terço",
    "terçasse": "terçar",
    "terçassem": "terçar",
    "terçasses": "terçar",
    "terçaste": "terçar",
    "terçastes": "terçar",
    "terçava": "terçar",
    "terçavam": "terçar",
    "terçavas": "terçar",
    "terço": "terçar",
    "terçogos": "terçogo",
    "terçois": "terçol",
    "terçolhos": "terçolho",
    "terços": "terço",
    "terçou": "terçar",
    "terçá": "terçar",
    "terçámo": "terçar",
    "terçámos": "terçar",
    "terçáramo": "terçar",
    "terçáramos": "terçar",
    "terçárei": "terçar",
    "terçáreis": "terçar",
    "terçásseis": "terçar",
    "terçássemos": "terçar",
    "terçávamo": "terçar",
    "terçávamos": "terçar",
    "terçávei": "terçar",
    "terçáveis": "terçável",
    "terçãs": "terçã",
    "terçôs": "terçô",
    "teríacas": "teríaca",
    "teríamos": "ter",
    "teríeis": "ter",
    "terófitos": "terófito",
    "terósporos": "terósporo",
    "tesa": "teso",
    "tesada": "tesar",
    "tesadas": "tesar",
    "tesadeiras": "tesadeira",
    "tesado": "tesar",
    "tesados": "tesar",
    "tesai": "tesar",
    "tesais": "tesar",
    "tesam": "tesar",
    "tesamo": "tesar",
    "tesamos": "tesar",
    "tesando": "tesar",
    "tesara": "tesar",
    "tesaram": "tesar",
    "tesaras": "tesar",
    "tesarde": "tesar",
    "tesardes": "tesar",
    "tesare": "tesar",
    "tesarei": "tesar",
    "tesareis": "tesar",
    "tesarem": "tesar",
    "tesaremos": "tesar",
    "tesares": "tesar",
    "tesaria": "tesar",
    "tesariam": "tesar",
    "tesarias": "tesar",
    "tesarmo": "tesar",
    "tesarmos": "tesar",
    "tesará": "tesar",
    "tesarás": "tesar",
    "tesarão": "tesar",
    "tesaríamos": "tesar",
    "tesaríeis": "tesar",
    "tesas": "teso",
    "tesasse": "tesar",
    "tesassem": "tesar",
    "tesasses": "tesar",
    "tesaste": "tesar",
    "tesastes": "tesar",
    "tesava": "tesar",
    "tesavam": "tesar",
    "tesavas": "tesar",
    "tese": "tesar",
    "tesei": "tesar",
    "teseis": "tesar",
    "tesem": "tesar",
    "tesemo": "tesar",
    "tesemos": "tesar",
    "teses": "tese",
    "tesmofórias": "tesmofória",
    "tesmótetas": "tesmóteta",
    "teso": "tesar",
    "tesoirada": "tesoirado",
    "tesoiradas": "tesoirado",
    "tesoirados": "tesoirado",
    "tesoiras": "tesoira",
    "tesoiros": "tesoiro",
    "tesoiráveis": "tesoirável",
    "tesos": "teso",
    "tesou": "tesar",
    "tesoura": "tesourar",
    "tesourada": "tesourar",
    "tesouradas": "tesourar",
    "tesourado": "tesourar",
    "tesourados": "tesourar",
    "tesourai": "tesourar",
    "tesourais": "tesourar",
    "tesouram": "tesourar",
    "tesouramo": "tesourar",
    "tesouramos": "tesourar",
    "tesourando": "tesourar",
    "tesourara": "tesourar",
    "tesouraram": "tesourar",
    "tesouraras": "tesourar",
    "tesourarde": "tesourar",
    "tesourardes": "tesourar",
    "tesourare": "tesourar",
    "tesourarei": "tesourar",
    "tesourareis": "tesourar",
    "tesourarem": "tesourar",
    "tesouraremos": "tesourar",
    "tesourares": "tesourar",
    "tesouraria": "tesourar",
    "tesourariam": "tesourar",
    "tesourarias": "tesouraria",
    "tesourarmo": "tesourar",
    "tesourarmos": "tesourar",
    "tesourará": "tesourar",
    "tesourarás": "tesourar",
    "tesourarão": "tesourar",
    "tesouraríamos": "tesourar",
    "tesouraríeis": "tesourar",
    "tesouras": "tesourar",
    "tesourasse": "tesourar",
    "tesourassem": "tesourar",
    "tesourasses": "tesourar",
    "tesouraste": "tesourar",
    "tesourastes": "tesourar",
    "tesourava": "tesourar",
    "tesouravam": "tesourar",
    "tesouravas": "tesourar",
    "tesoure": "tesourar",
    "tesourei": "tesourar",
    "tesoureira": "tesoureiro",
    "tesoureiras": "tesoureiro",
    "tesoureiros": "tesoureiro",
    "tesoureis": "tesourar",
    "tesourem": "tesourar",
    "tesouremo": "tesourar",
    "tesouremos": "tesourar",
    "tesoures": "tesourar",
    "tesourinha": "tesoura",
    "tesourinhas": "tesoura",
    "tesourita": "tesoura",
    "tesouritas": "tesoura",
    "tesouro": "tesourar",
    "tesouros": "tesouro",
    "tesourou": "tesourar",
    "tesourá": "tesourar",
    "tesourámo": "tesourar",
    "tesourámos": "tesourar",
    "tesouráramo": "tesourar",
    "tesouráramos": "tesourar",
    "tesourárei": "tesourar",
    "tesouráreis": "tesourar",
    "tesourásseis": "tesourar",
    "tesourássemos": "tesourar",
    "tesourávamo": "tesourar",
    "tesourávamos": "tesourar",
    "tesourávei": "tesourar",
    "tesouráveis": "tesourável",
    "tessalonicenses": "tessalonicense",
    "tesselas": "tessela",
    "tesselária": "tesselário",
    "tesselárias": "tesselário",
    "tesselários": "tesselário",
    "tesses": "tesse",
    "tessituras": "tessitura",
    "tessália": "tessálio",
    "tessálias": "tessálio",
    "tessálica": "tessálico",
    "tessálicas": "tessálico",
    "tessálicos": "tessálico",
    "tessálios": "tessálio",
    "testa": "testo",
    "testaceiformes": "testaceiforme",
    "testacelas": "testacela",
    "testaceografias": "testaceografia",
    "testaceologias": "testaceologia",
    "testada": "testar",
    "testadas": "testar",
    "testadinha": "testado",
    "testadinhas": "testado",
    "testadinho": "testado",
    "testadinhos": "testado",
    "testadita": "testado",
    "testaditas": "testado",
    "testadito": "testado",
    "testaditos": "testado",
    "testado": "testar",
    "testadora": "testador",
    "testadoras": "testador",
    "testadores": "testador",
    "testados": "testar",
    "testadíssima": "testado",
    "testadíssimas": "testado",
    "testadíssimo": "testado",
    "testadíssimos": "testado",
    "testai": "testar",
    "testais": "testar",
    "testam": "testar",
    "testamentais": "testamental",
    "testamentarias": "testamentaria",
    "testamenteira": "testamenteiro",
    "testamenteiras": "testamenteiro",
    "testamenteiros": "testamenteiro",
    "testamentos": "testamento",
    "testamentária": "testamentário",
    "testamentárias": "testamentário",
    "testamentários": "testamentário",
    "testamo": "testar",
    "testamos": "testar",
    "testando": "testar",
    "testantes": "testante",
    "testara": "testar",
    "testaram": "testar",
    "testaras": "testar",
    "testarde": "testar",
    "testardes": "testar",
    "testare": "testar",
    "testarei": "testar",
    "testareis": "testar",
    "testarem": "testar",
    "testaremos": "testar",
    "testares": "testar",
    "testaria": "testar",
    "testariam": "testar",
    "testarias": "testar",
    "testarmo": "testar",
    "testarmos": "testar",
    "testará": "testar",
    "testarás": "testar",
    "testarão": "testar",
    "testaríamos": "testar",
    "testaríeis": "testar",
    "testas": "testo",
    "testasse": "testar",
    "testassem": "testar",
    "testasses": "testar",
    "testaste": "testar",
    "testastes": "testar",
    "testava": "testar",
    "testavam": "testar",
    "testavas": "testar",
    "testazinha": "testa",
    "testazinhas": "testa",
    "testazita": "testa",
    "testazitas": "testa",
    "testaças": "testaça",
    "testaçuda": "testaçudo",
    "testaçudas": "testaçudo",
    "testaçudos": "testaçudo",
    "teste": "testar",
    "testei": "testar",
    "testeira": "testeiro",
    "testeiras": "testeiro",
    "testeiros": "testeiro",
    "testeis": "testar",
    "testem": "testar",
    "testemo": "testar",
    "testemos": "testar",
    "testemunha": "testemunhar",
    "testemunhada": "testemunhar",
    "testemunhadas": "testemunhar",
    "testemunhadeira": "testemunhador",
    "testemunhadeiras": "testemunhador",
    "testemunhado": "testemunhar",
    "testemunhadores": "testemunhador",
    "testemunhados": "testemunhar",
    "testemunhai": "testemunhar",
    "testemunhais": "testemunhar",
    "testemunham": "testemunhar",
    "testemunhamo": "testemunhar",
    "testemunhamos": "testemunhar",
    "testemunhando": "testemunhar",
    "testemunhara": "testemunhar",
    "testemunharam": "testemunhar",
    "testemunharas": "testemunhar",
    "testemunharde": "testemunhar",
    "testemunhardes": "testemunhar",
    "testemunhare": "testemunhar",
    "testemunharei": "testemunhar",
    "testemunhareis": "testemunhar",
    "testemunharem": "testemunhar",
    "testemunharemos": "testemunhar",
    "testemunhares": "testemunhar",
    "testemunharia": "testemunhar",
    "testemunhariam": "testemunhar",
    "testemunharias": "testemunhar",
    "testemunharmo": "testemunhar",
    "testemunharmos": "testemunhar",
    "testemunhará": "testemunhar",
    "testemunharás": "testemunhar",
    "testemunharão": "testemunhar",
    "testemunharíamos": "testemunhar",
    "testemunharíeis": "testemunhar",
    "testemunhas": "testemunhar",
    "testemunhasse": "testemunhar",
    "testemunhassem": "testemunhar",
    "testemunhasses": "testemunhar",
    "testemunhaste": "testemunhar",
    "testemunhastes": "testemunhar",
    "testemunhava": "testemunhar",
    "testemunhavam": "testemunhar",
    "testemunhavas": "testemunhar",
    "testemunhe": "testemunhar",
    "testemunhei": "testemunhar",
    "testemunheis": "testemunhar",
    "testemunhem": "testemunhar",
    "testemunhemo": "testemunhar",
    "testemunhemos": "testemunhar",
    "testemunhes": "testemunhar",
    "testemunho": "testemunhar",
    "testemunhos": "testemunho",
    "testemunhou": "testemunhar",
    "testemunhá": "testemunhar",
    "testemunhámo": "testemunhar",
    "testemunhámos": "testemunhar",
    "testemunháramo": "testemunhar",
    "testemunháramos": "testemunhar",
    "testemunhárei": "testemunhar",
    "testemunháreis": "testemunhar",
    "testemunhásseis": "testemunhar",
    "testemunhássemos": "testemunhar",
    "testemunhávamo": "testemunhar",
    "testemunhávamos": "testemunhar",
    "testemunhávei": "testemunhar",
    "testemunháveis": "testemunhável",
    "testes": "teste",
    "testiconda": "testicondo",
    "testicondas": "testicondo",
    "testicondos": "testicondo",
    "testicos": "testico",
    "testiculares": "testicular",
    "testiculações": "testiculação",
    "testiculosa": "testiculoso",
    "testiculosas": "testiculoso",
    "testiculosos": "testiculoso",
    "testifica": "testificar",
    "testificada": "testificar",
    "testificadas": "testificar",
    "testificado": "testificar",
    "testificadora": "testificador",
    "testificadoras": "testificador",
    "testificadores": "testificador",
    "testificados": "testificar",
    "testificai": "testificar",
    "testificais": "testificar",
    "testificam": "testificar",
    "testificamo": "testificar",
    "testificamos": "testificar",
    "testificando": "testificar",
    "testificantes": "testificante",
    "testificara": "testificar",
    "testificaram": "testificar",
    "testificaras": "testificar",
    "testificarde": "testificar",
    "testificardes": "testificar",
    "testificare": "testificar",
    "testificarei": "testificar",
    "testificareis": "testificar",
    "testificarem": "testificar",
    "testificaremos": "testificar",
    "testificares": "testificar",
    "testificaria": "testificar",
    "testificariam": "testificar",
    "testificarias": "testificar",
    "testificarmo": "testificar",
    "testificarmos": "testificar",
    "testificará": "testificar",
    "testificarás": "testificar",
    "testificarão": "testificar",
    "testificaríamos": "testificar",
    "testificaríeis": "testificar",
    "testificas": "testificar",
    "testificasse": "testificar",
    "testificassem": "testificar",
    "testificasses": "testificar",
    "testificaste": "testificar",
    "testificastes": "testificar",
    "testificava": "testificar",
    "testificavam": "testificar",
    "testificavas": "testificar",
    "testifico": "testificar",
    "testificou": "testificar",
    "testificá": "testificar",
    "testificámo": "testificar",
    "testificámos": "testificar",
    "testificáramo": "testificar",
    "testificáramos": "testificar",
    "testificárei": "testificar",
    "testificáreis": "testificar",
    "testificásseis": "testificar",
    "testificássemos": "testificar",
    "testificávamo": "testificar",
    "testificávamos": "testificar",
    "testificávei": "testificar",
    "testificáveis": "testificável",
    "testifique": "testificar",
    "testifiquei": "testificar",
    "testifiqueis": "testificar",
    "testifiquem": "testificar",
    "testifiquemo": "testificar",
    "testifiquemos": "testificar",
    "testifiques": "testificar",
    "testilha": "testilhar",
    "testilhada": "testilhar",
    "testilhadas": "testilhar",
    "testilhado": "testilhar",
    "testilhados": "testilhar",
    "testilhai": "testilhar",
    "testilhais": "testilhar",
    "testilham": "testilhar",
    "testilhamo": "testilhar",
    "testilhamos": "testilhar",
    "testilhando": "testilhar",
    "testilhantes": "testilhante",
    "testilhara": "testilhar",
    "testilharam": "testilhar",
    "testilharas": "testilhar",
    "testilhardes": "testilhar",
    "testilharei": "testilhar",
    "testilhareis": "testilhar",
    "testilharem": "testilhar",
    "testilharemos": "testilhar",
    "testilhares": "testilhar",
    "testilharia": "testilhar",
    "testilhariam": "testilhar",
    "testilharias": "testilhar",
    "testilharmo": "testilhar",
    "testilharmos": "testilhar",
    "testilhará": "testilhar",
    "testilharás": "testilhar",
    "testilharão": "testilhar",
    "testilharíamos": "testilhar",
    "testilharíeis": "testilhar",
    "testilhas": "testilhar",
    "testilhasse": "testilhar",
    "testilhassem": "testilhar",
    "testilhasses": "testilhar",
    "testilhaste": "testilhar",
    "testilhastes": "testilhar",
    "testilhava": "testilhar",
    "testilhavam": "testilhar",
    "testilhavas": "testilhar",
    "testilhe": "testilhar",
    "testilhei": "testilhar",
    "testilheis": "testilhar",
    "testilhem": "testilhar",
    "testilhemo": "testilhar",
    "testilhemos": "testilhar",
    "testilhes": "testilhar",
    "testilho": "testilhar",
    "testilhos": "testilho",
    "testilhou": "testilhar",
    "testilhámo": "testilhar",
    "testilhámos": "testilhar",
    "testilháramo": "testilhar",
    "testilháramos": "testilhar",
    "testilháreis": "testilhar",
    "testilhásseis": "testilhar",
    "testilhássemos": "testilhar",
    "testilhávamo": "testilhar",
    "testilhávamos": "testilhar",
    "testilháveis": "testilhar",
    "testinha": "testa",
    "testinhas": "testa",
    "testita": "testa",
    "testitas": "testa",
    "testo": "testar",
    "testos": "testo",
    "testosteronas": "testosterona",
    "testou": "testar",
    "testuda": "testudo",
    "testudas": "testudo",
    "testudaça": "testudaço",
    "testudaças": "testudaço",
    "testudaços": "testudaço",
    "testudos": "testudo",
    "testá": "testar",
    "testácea": "testáceo",
    "testáceas": "testáceo",
    "testáceos": "testáceo",
    "testámo": "testar",
    "testámos": "testar",
    "testáramo": "testar",
    "testáramos": "testar",
    "testárei": "testar",
    "testáreis": "testar",
    "testásseis": "testar",
    "testássemos": "testar",
    "testávamo": "testar",
    "testávamos": "testar",
    "testávei": "testar",
    "testáveis": "testável",
    "testículos": "testículo",
    "tesuras": "tesura",
    "tesá": "tesar",
    "tesámo": "tesar",
    "tesámos": "tesar",
    "tesáramo": "tesar",
    "tesáramos": "tesar",
    "tesárei": "tesar",
    "tesáreis": "tesar",
    "tesásseis": "tesar",
    "tesássemos": "tesar",
    "tesávamo": "tesar",
    "tesávamos": "tesar",
    "tesávei": "tesar",
    "tesáveis": "tesável",
    "tesões": "tesão",
    "tetanias": "tetania",
    "tetaniformes": "tetaniforme",
    "tetanismos": "tetanismo",
    "tetaniza": "tetanizar",
    "tetanizada": "tetanizar",
    "tetanizadas": "tetanizar",
    "tetanizado": "tetanizar",
    "tetanizados": "tetanizar",
    "tetanizai": "tetanizar",
    "tetanizais": "tetanizar",
    "tetanizam": "tetanizar",
    "tetanizamo": "tetanizar",
    "tetanizamos": "tetanizar",
    "tetanizando": "tetanizar",
    "tetanizara": "tetanizar",
    "tetanizaram": "tetanizar",
    "tetanizaras": "tetanizar",
    "tetanizarde": "tetanizar",
    "tetanizardes": "tetanizar",
    "tetanizare": "tetanizar",
    "tetanizarei": "tetanizar",
    "tetanizareis": "tetanizar",
    "tetanizarem": "tetanizar",
    "tetanizaremos": "tetanizar",
    "tetanizares": "tetanizar",
    "tetanizaria": "tetanizar",
    "tetanizariam": "tetanizar",
    "tetanizarias": "tetanizar",
    "tetanizarmo": "tetanizar",
    "tetanizarmos": "tetanizar",
    "tetanizará": "tetanizar",
    "tetanizarás": "tetanizar",
    "tetanizarão": "tetanizar",
    "tetanizaríamos": "tetanizar",
    "tetanizaríeis": "tetanizar",
    "tetanizas": "tetanizar",
    "tetanizasse": "tetanizar",
    "tetanizassem": "tetanizar",
    "tetanizasses": "tetanizar",
    "tetanizaste": "tetanizar",
    "tetanizastes": "tetanizar",
    "tetanizava": "tetanizar",
    "tetanizavam": "tetanizar",
    "tetanizavas": "tetanizar",
    "tetanizações": "tetanização",
    "tetanize": "tetanizar",
    "tetanizei": "tetanizar",
    "tetanizeis": "tetanizar",
    "tetanizem": "tetanizar",
    "tetanizemo": "tetanizar",
    "tetanizemos": "tetanizar",
    "tetanizes": "tetanizar",
    "tetanizo": "tetanizar",
    "tetanizou": "tetanizar",
    "tetanizá": "tetanizar",
    "tetanizámo": "tetanizar",
    "tetanizámos": "tetanizar",
    "tetanizáramo": "tetanizar",
    "tetanizáramos": "tetanizar",
    "tetanizárei": "tetanizar",
    "tetanizáreis": "tetanizar",
    "tetanizásseis": "tetanizar",
    "tetanizássemos": "tetanizar",
    "tetanizávamo": "tetanizar",
    "tetanizávamos": "tetanizar",
    "tetanizávei": "tetanizar",
    "tetanizáveis": "tetanizável",
    "tetartoedrias": "tetartoedria",
    "tetartoédrica": "tetartoédrico",
    "tetartoédricas": "tetartoédrico",
    "tetartoédricos": "tetartoédrico",
    "tetas": "teta",
    "teteias": "teteia",
    "teteiras": "teteira",
    "tetenses": "tetense",
    "tetes": "tete",
    "tetinas": "tetina",
    "tetins": "tetim",
    "tetra": "tetro",
    "tetrabrânquios": "tetrabrânquio",
    "tetracampeã": "tetracampeão",
    "tetracampeãs": "tetracampeão",
    "tetracampeões": "tetracampeão",
    "tetracarpa": "tetracarpo",
    "tetracarpas": "tetracarpo",
    "tetracarpos": "tetracarpo",
    "tetracentráceas": "tetracentrácea",
    "tetraciclinas": "tetraciclina",
    "tetracorda": "tetracordo",
    "tetracordas": "tetracordo",
    "tetracordes": "tetracorde",
    "tetracordo": "tetracorde",
    "tetracordos": "tetracordo",
    "tetractinélidos": "tetractinélido",
    "tetracórdios": "tetracórdio",
    "tetradactilias": "tetradactilia",
    "tetradinâmica": "tetradinâmico",
    "tetradinâmicas": "tetradinâmico",
    "tetradinâmicos": "tetradinâmico",
    "tetradáctila": "tetradáctilo",
    "tetradáctilas": "tetradáctilo",
    "tetradáctilos": "tetradáctilo",
    "tetraedrites": "tetraedrite",
    "tetraedros": "tetraedro",
    "tetrafila": "tetrafilo",
    "tetrafilas": "tetrafilo",
    "tetrafilos": "tetrafilo",
    "tetragonais": "tetragonal",
    "tetragonocéfala": "tetragonocéfalo",
    "tetragonocéfalas": "tetragonocéfalo",
    "tetragonocéfalos": "tetragonocéfalo",
    "tetragramas": "tetragrama",
    "tetragónios": "tetragónio",
    "tetralogias": "tetralogia",
    "tetrandra": "tetrandro",
    "tetrandras": "tetrandro",
    "tetrandrias": "tetrandria",
    "tetrandros": "tetrandro",
    "tetraneta": "tetraneto",
    "tetranetas": "tetraneto",
    "tetranetos": "tetraneto",
    "tetraplegias": "tetraplegia",
    "tetraploidias": "tetraploidia",
    "tetraploóides": "tetraploóide",
    "tetraplégica": "tetraplégico",
    "tetraplégicas": "tetraplégico",
    "tetraplégicos": "tetraplégico",
    "tetraporângios": "tetraporângio",
    "tetrapétala": "tetrapétalo",
    "tetrapétalas": "tetrapétalo",
    "tetrapétalos": "tetrapétalo",
    "tetraquénios": "tetraquénio",
    "tetrarcados": "tetrarcado",
    "tetrarcas": "tetrarca",
    "tetrarquias": "tetrarquia",
    "tetras": "tetro",
    "tetrasperma": "tetraspermo",
    "tetraspermas": "tetraspermo",
    "tetraspermos": "tetraspermo",
    "tetrasporáceas": "tetrasporácea",
    "tetrasporófitas": "tetrasporófita",
    "tetrasporófitos": "tetrasporófito",
    "tetrassilábica": "tetrassilábico",
    "tetrassilábicas": "tetrassilábico",
    "tetrassilábicos": "tetrassilábico",
    "tetrassépala": "tetrassépalo",
    "tetrassépalas": "tetrassépalo",
    "tetrassépalos": "tetrassépalo",
    "tetrassílaba": "tetrassílabo",
    "tetrassílabas": "tetrassílabo",
    "tetrassílabos": "tetrassílabo",
    "tetrastémones": "tetrastémone",
    "tetratómica": "tetratómico",
    "tetratómicas": "tetratómico",
    "tetratómicos": "tetratómico",
    "tetravalentes": "tetravalente",
    "tetravozinha": "tetravô",
    "tetravozinhas": "tetravô",
    "tetravozinho": "tetravô",
    "tetravozinhos": "tetravô",
    "tetravozita": "tetravô",
    "tetravozitas": "tetravô",
    "tetravozito": "tetravô",
    "tetravozitos": "tetravô",
    "tetravó": "tetravô",
    "tetravós": "tetravô",
    "tetravôs": "tetravô",
    "tetraédrica": "tetraédrico",
    "tetraédricas": "tetraédrico",
    "tetraédricos": "tetraédrico",
    "tetricidades": "tetricidade",
    "tetroftalma": "tetroftalmo",
    "tetroftalmas": "tetroftalmo",
    "tetroftalmos": "tetroftalmo",
    "tetros": "tetro",
    "tetráfida": "tetráfido",
    "tetráfidas": "tetráfido",
    "tetráfidos": "tetráfido",
    "tetrágina": "tetrágino",
    "tetráginas": "tetrágino",
    "tetráginos": "tetrágino",
    "tetrágonos": "tetrágono",
    "tetrápodes": "tetrápode",
    "tetrápoles": "tetrápole",
    "tetráptera": "tetráptero",
    "tetrápteras": "tetráptero",
    "tetrápteros": "tetráptero",
    "tetrásporos": "tetrásporo",
    "tetrástica": "tetrástico",
    "tetrásticas": "tetrástico",
    "tetrásticos": "tetrástico",
    "tetrâmera": "tetrâmero",
    "tetrâmeras": "tetrâmero",
    "tetrâmeros": "tetrâmero",
    "tetrâmetros": "tetrâmetro",
    "tetrândrias": "tetrândria",
    "tetuda": "tetudo",
    "tetudas": "tetudo",
    "tetudos": "tetudo",
    "tetânica": "tetânico",
    "tetânicas": "tetânico",
    "tetânicos": "tetânico",
    "tetérrima": "tetro",
    "tetérrimas": "tetro",
    "tetérrimo": "tetro",
    "tetérrimos": "tetro",
    "tetés": "teté",
    "teucra": "teucro",
    "teucras": "teucro",
    "teucrietas": "teucrieta",
    "teucros": "teucro",
    "teurga": "teurgo",
    "teurgas": "teurgo",
    "teurgias": "teurgia",
    "teurgismos": "teurgismo",
    "teurgistas": "teurgista",
    "teurgos": "teurgo",
    "teus": "teu",
    "teutoa": "teutão",
    "teutoas": "teutão",
    "teutomanias": "teutomania",
    "teutonismos": "teutonismo",
    "teutonistas": "teutonista",
    "teutónica": "teutónico",
    "teutónicas": "teutónico",
    "teutónicos": "teutónico",
    "teutões": "teutão",
    "teve": "ter",
    "texana": "texano",
    "texanas": "texano",
    "texanos": "texano",
    "textiformes": "textiforme",
    "textos": "texto",
    "textozinho": "texto",
    "textozinhos": "texto",
    "textozito": "texto",
    "textozitos": "texto",
    "textuais": "textual",
    "textualidades": "textualidade",
    "textualistas": "textualista",
    "textura": "texturar",
    "texturada": "texturar",
    "texturadas": "texturar",
    "texturado": "texturar",
    "texturados": "texturar",
    "texturai": "texturar",
    "texturais": "texturar",
    "texturam": "texturar",
    "texturamo": "texturar",
    "texturamos": "texturar",
    "texturando": "texturar",
    "texturara": "texturar",
    "texturaram": "texturar",
    "texturaras": "texturar",
    "texturarde": "texturar",
    "texturardes": "texturar",
    "texturare": "texturar",
    "texturarei": "texturar",
    "texturareis": "texturar",
    "texturarem": "texturar",
    "texturaremos": "texturar",
    "texturares": "texturar",
    "texturaria": "texturar",
    "texturariam": "texturar",
    "texturarias": "texturar",
    "texturarmo": "texturar",
    "texturarmos": "texturar",
    "texturará": "texturar",
    "texturarás": "texturar",
    "texturarão": "texturar",
    "texturaríamos": "texturar",
    "texturaríeis": "texturar",
    "texturas": "texturar",
    "texturasse": "texturar",
    "texturassem": "texturar",
    "texturasses": "texturar",
    "texturaste": "texturar",
    "texturastes": "texturar",
    "texturava": "texturar",
    "texturavam": "texturar",
    "texturavas": "texturar",
    "texture": "texturar",
    "texturei": "texturar",
    "textureis": "texturar",
    "texturem": "texturar",
    "texturemo": "texturar",
    "texturemos": "texturar",
    "textures": "texturar",
    "texturo": "texturar",
    "texturou": "texturar",
    "texturá": "texturar",
    "texturámo": "texturar",
    "texturámos": "texturar",
    "texturáramo": "texturar",
    "texturáramos": "texturar",
    "texturárei": "texturar",
    "texturáreis": "texturar",
    "texturásseis": "texturar",
    "texturássemos": "texturar",
    "texturávamo": "texturar",
    "texturávamos": "texturar",
    "texturávei": "texturar",
    "texturáveis": "texturar",
    "textuários": "textuário",
    "textória": "textório",
    "textórias": "textório",
    "textórios": "textório",
    "texuga": "texugo",
    "texugas": "texugo",
    "texugos": "texugo",
    "tezes": "tez",
    "teácea": "teáceo",
    "teáceas": "teáceo",
    "teáceos": "teáceo",
    "teátrica": "teátrico",
    "teátricas": "teátrico",
    "teátricos": "teátrico",
    "teândrica": "teândrico",
    "teândricas": "teândrico",
    "teândricos": "teândrico",
    "teça": "tecer",
    "teçais": "tecer",
    "teçam": "tecer",
    "teçamo": "tecer",
    "teçamos": "tecer",
    "teçarias": "teçaria",
    "teças": "tecer",
    "teço": "tecer",
    "teínas": "teína",
    "teísmos": "teísmo",
    "teístas": "teísta",
    "teíus": "teíu",
    "teófoba": "teófobo",
    "teófobas": "teófobo",
    "teófobos": "teófobo",
    "teóloga": "teólogo",
    "teólogas": "teólogo",
    "teólogos": "teólogo",
    "teórica": "teórico",
    "teóricas": "teórico",
    "teóricos": "teórico",
    "teósofa": "teósofo",
    "teósofas": "teósofo",
    "teósofos": "teósofo",
    "teúbas": "teúba",
    "teúda": "teúdo",
    "teúdas": "teúdo",
    "teúdos": "teúdo",
    "teúrgica": "teúrgico",
    "teúrgicas": "teúrgico",
    "teúrgicos": "teúrgico",
    "thesaura": "thesaurus",
    "thrillers": "thriller",
    "tia": "tio",
    "tiaminas": "tiamina",
    "tiaras": "tiara",
    "tias": "tio",
    "tiberina": "tiberino",
    "tiberinas": "tiberino",
    "tiberinos": "tiberino",
    "tibetana": "tibetano",
    "tibetanas": "tibetano",
    "tibetanos": "tibetano",
    "tibiais": "tibial",
    "tibiez": "tibieza",
    "tibiezas": "tibieza",
    "tibiezes": "tibiez",
    "tibiotarsiana": "tibiotarsiano",
    "tibiotarsianas": "tibiotarsiano",
    "tibiotarsianos": "tibiotarsiano",
    "tibiotársica": "tibiotársico",
    "tibiotársicas": "tibiotársico",
    "tibiotársicos": "tibiotársico",
    "tibornices": "tibornice",
    "ticais": "tical",
    "ticas": "tica",
    "ticos": "tico",
    "ticoticos": "ticotico",
    "ticracias": "ticracia",
    "tics": "tic",
    "ticunas": "ticuna",
    "ticuns": "ticum",
    "tida": "tido",
    "tidas": "tido",
    "tido": "ter",
    "tidos": "tido",
    "tifemias": "tifemia",
    "tifismos": "tifismo",
    "tiflites": "tiflite",
    "tiflografias": "tiflografia",
    "tiflologias": "tiflologia",
    "tiflológica": "tiflológico",
    "tiflológicas": "tiflológico",
    "tiflológicos": "tiflológico",
    "tiflostomias": "tiflostomia",
    "tiflógrafos": "tiflógrafo",
    "tiflóloga": "tiflólogo",
    "tiflólogas": "tiflólogo",
    "tiflólogos": "tiflólogo",
    "tifobaciloses": "tifobacilose",
    "tifomanias": "tifomania",
    "tifos": "tifo",
    "tifosa": "tifoso",
    "tifosas": "tifoso",
    "tifosos": "tifoso",
    "tifotuberculoses": "tifotuberculose",
    "tifáceas": "tifácea",
    "tifóidea": "tifóideo",
    "tifóideas": "tifóideo",
    "tifóideos": "tifóideo",
    "tifóides": "tifóide",
    "tifões": "tifão",
    "tigeladas": "tigelada",
    "tigelas": "tigela",
    "tigelinha": "tigela",
    "tigelinhas": "tigela",
    "tigelita": "tigela",
    "tigelitas": "tigela",
    "tigmotactismos": "tigmotactismo",
    "tigmotropismos": "tigmotropismo",
    "tigmotrópica": "tigmotrópico",
    "tigmotrópicas": "tigmotrópico",
    "tigmotrópicos": "tigmotrópico",
    "tigmotáctica": "tigmotáctico",
    "tigmotácticas": "tigmotáctico",
    "tigmotácticos": "tigmotáctico",
    "tigrada": "tigrado",
    "tigradas": "tigrado",
    "tigrados": "tigrado",
    "tigres": "tigre",
    "tigresa": "tigre",
    "tigresas": "tigre",
    "tigrina": "tigrino",
    "tigrinas": "tigrino",
    "tigrinos": "tigrino",
    "tigrés": "tigré",
    "tigróides": "tigróide",
    "tijoladas": "tijolada",
    "tijolarias": "tijolaria",
    "tijoleira": "tijoleiro",
    "tijoleiras": "tijoleiro",
    "tijoleiros": "tijoleiro",
    "tijolinho": "tijolo",
    "tijolinhos": "tijolo",
    "tijolito": "tijolo",
    "tijolitos": "tijolo",
    "tijolos": "tijolo",
    "tijucais": "tijucal",
    "tijucana": "tijucano",
    "tijucanas": "tijucano",
    "tijucanos": "tijucano",
    "tijucas": "tijuca",
    "tijucos": "tijuco",
    "tijupares": "tijupar",
    "tijupás": "tijupá",
    "tila": "tilar",
    "tilada": "tilar",
    "tiladas": "tilar",
    "tilado": "tilar",
    "tilados": "tilar",
    "tilai": "tilar",
    "tilais": "tilar",
    "tilam": "tilar",
    "tilamo": "tilar",
    "tilamos": "tilar",
    "tilando": "tilar",
    "tilara": "tilar",
    "tilaram": "tilar",
    "tilaras": "tilar",
    "tilarde": "tilar",
    "tilardes": "tilar",
    "tilare": "tilar",
    "tilarei": "tilar",
    "tilareis": "tilar",
    "tilarem": "tilar",
    "tilaremos": "tilar",
    "tilares": "tilar",
    "tilaria": "tilar",
    "tilariam": "tilar",
    "tilarias": "tilar",
    "tilarmo": "tilar",
    "tilarmos": "tilar",
    "tilará": "tilar",
    "tilarás": "tilar",
    "tilarão": "tilar",
    "tilaríamos": "tilar",
    "tilaríeis": "tilar",
    "tilas": "tilar",
    "tilasse": "tilar",
    "tilassem": "tilar",
    "tilasses": "tilar",
    "tilaste": "tilar",
    "tilastes": "tilar",
    "tilava": "tilar",
    "tilavam": "tilar",
    "tilavas": "tilar",
    "tilda": "tildar",
    "tildada": "tildar",
    "tildadas": "tildar",
    "tildado": "tildar",
    "tildados": "tildar",
    "tildai": "tildar",
    "tildais": "tildar",
    "tildam": "tildar",
    "tildamo": "tildar",
    "tildamos": "tildar",
    "tildando": "tildar",
    "tildara": "tildar",
    "tildaram": "tildar",
    "tildaras": "tildar",
    "tildarde": "tildar",
    "tildardes": "tildar",
    "tildare": "tildar",
    "tildarei": "tildar",
    "tildareis": "tildar",
    "tildarem": "tildar",
    "tildaremos": "tildar",
    "tildares": "tildar",
    "tildaria": "tildar",
    "tildariam": "tildar",
    "tildarias": "tildar",
    "tildarmo": "tildar",
    "tildarmos": "tildar",
    "tildará": "tildar",
    "tildarás": "tildar",
    "tildarão": "tildar",
    "tildaríamos": "tildar",
    "tildaríeis": "tildar",
    "tildas": "tildar",
    "tildasse": "tildar",
    "tildassem": "tildar",
    "tildasses": "tildar",
    "tildaste": "tildar",
    "tildastes": "tildar",
    "tildava": "tildar",
    "tildavam": "tildar",
    "tildavas": "tildar",
    "tilde": "tildar",
    "tildei": "tildar",
    "tildeis": "tildar",
    "tildem": "tildar",
    "tildemo": "tildar",
    "tildemos": "tildar",
    "tildes": "tilde",
    "tildo": "tildar",
    "tildou": "tildar",
    "tildá": "tildar",
    "tildámo": "tildar",
    "tildámos": "tildar",
    "tildáramo": "tildar",
    "tildáramos": "tildar",
    "tildárei": "tildar",
    "tildáreis": "tildar",
    "tildásseis": "tildar",
    "tildássemos": "tildar",
    "tildávamo": "tildar",
    "tildávamos": "tildar",
    "tildávei": "tildar",
    "tildáveis": "tildar",
    "tile": "tilar",
    "tilei": "tilar",
    "tileis": "tilar",
    "tilem": "tilar",
    "tilemo": "tilar",
    "tilemos": "tilar",
    "tiles": "tilar",
    "tilhados": "tilhado",
    "tilhas": "tilha",
    "tilinta": "tilintar",
    "tilintada": "tilintar",
    "tilintadas": "tilintar",
    "tilintado": "tilintar",
    "tilintados": "tilintar",
    "tilintai": "tilintar",
    "tilintais": "tilintar",
    "tilintam": "tilintar",
    "tilintamo": "tilintar",
    "tilintamos": "tilintar",
    "tilintando": "tilintar",
    "tilintantes": "tilintante",
    "tilintara": "tilintar",
    "tilintaram": "tilintar",
    "tilintaras": "tilintar",
    "tilintardes": "tilintar",
    "tilintarei": "tilintar",
    "tilintareis": "tilintar",
    "tilintarem": "tilintar",
    "tilintaremos": "tilintar",
    "tilintares": "tilintar",
    "tilintaria": "tilintar",
    "tilintariam": "tilintar",
    "tilintarias": "tilintar",
    "tilintarmo": "tilintar",
    "tilintarmos": "tilintar",
    "tilintará": "tilintar",
    "tilintarás": "tilintar",
    "tilintarão": "tilintar",
    "tilintaríamos": "tilintar",
    "tilintaríeis": "tilintar",
    "tilintas": "tilintar",
    "tilintasse": "tilintar",
    "tilintassem": "tilintar",
    "tilintasses": "tilintar",
    "tilintaste": "tilintar",
    "tilintastes": "tilintar",
    "tilintava": "tilintar",
    "tilintavam": "tilintar",
    "tilintavas": "tilintar",
    "tilinte": "tilintar",
    "tilintei": "tilintar",
    "tilinteis": "tilintar",
    "tilintem": "tilintar",
    "tilintemo": "tilintar",
    "tilintemos": "tilintar",
    "tilintes": "tilintar",
    "tilinto": "tilintar",
    "tilintou": "tilintar",
    "tilintámo": "tilintar",
    "tilintámos": "tilintar",
    "tilintáramo": "tilintar",
    "tilintáramos": "tilintar",
    "tilintáreis": "tilintar",
    "tilintásseis": "tilintar",
    "tilintássemos": "tilintar",
    "tilintávamo": "tilintar",
    "tilintávamos": "tilintar",
    "tilintáveis": "tilintar",
    "tilitos": "tilito",
    "tiliáceas": "tiliácea",
    "tilo": "tilar",
    "tilomas": "tiloma",
    "tilos": "tilo",
    "tiloses": "tilose",
    "tilou": "tilar",
    "tilá": "tilar",
    "tilámo": "tilar",
    "tilámos": "tilar",
    "tiláramo": "tilar",
    "tiláramos": "tilar",
    "tilárei": "tilar",
    "tiláreis": "tilar",
    "tilásseis": "tilar",
    "tilássemos": "tilar",
    "tilávamo": "tilar",
    "tilávamos": "tilar",
    "tilávei": "tilar",
    "tiláveis": "tilar",
    "tilópodes": "tilópode",
    "timbaleada": "timbalear",
    "timbaleadas": "timbalear",
    "timbaleado": "timbalear",
    "timbaleados": "timbalear",
    "timbaleai": "timbalear",
    "timbaleais": "timbalear",
    "timbaleamo": "timbalear",
    "timbaleamos": "timbalear",
    "timbaleando": "timbalear",
    "timbaleara": "timbalear",
    "timbalearam": "timbalear",
    "timbalearas": "timbalear",
    "timbaleardes": "timbalear",
    "timbalearei": "timbalear",
    "timbaleareis": "timbalear",
    "timbalearem": "timbalear",
    "timbalearemos": "timbalear",
    "timbaleares": "timbalear",
    "timbalearia": "timbalear",
    "timbaleariam": "timbalear",
    "timbalearias": "timbalear",
    "timbalearmo": "timbalear",
    "timbalearmos": "timbalear",
    "timbaleará": "timbalear",
    "timbalearás": "timbalear",
    "timbalearão": "timbalear",
    "timbalearíamos": "timbalear",
    "timbalearíeis": "timbalear",
    "timbaleasse": "timbalear",
    "timbaleassem": "timbalear",
    "timbaleasses": "timbalear",
    "timbaleaste": "timbalear",
    "timbaleastes": "timbalear",
    "timbaleava": "timbalear",
    "timbaleavam": "timbalear",
    "timbaleavas": "timbalear",
    "timbaleei": "timbalear",
    "timbaleeis": "timbalear",
    "timbaleemo": "timbalear",
    "timbaleemos": "timbalear",
    "timbaleia": "timbalear",
    "timbaleiam": "timbalear",
    "timbaleias": "timbalear",
    "timbaleie": "timbalear",
    "timbaleiem": "timbalear",
    "timbaleies": "timbalear",
    "timbaleio": "timbalear",
    "timbaleiros": "timbaleiro",
    "timbaleou": "timbalear",
    "timbales": "timbale",
    "timbaleámo": "timbalear",
    "timbaleámos": "timbalear",
    "timbaleáramo": "timbalear",
    "timbaleáramos": "timbalear",
    "timbaleáreis": "timbalear",
    "timbaleásseis": "timbalear",
    "timbaleássemos": "timbalear",
    "timbaleávamo": "timbalear",
    "timbaleávamos": "timbalear",
    "timbaleáveis": "timbalear",
    "timbaúbas": "timbaúba",
    "timbiras": "timbira",
    "timborés": "timboré",
    "timbra": "timbrar",
    "timbrada": "timbrar",
    "timbradas": "timbrar",
    "timbrado": "timbrar",
    "timbradora": "timbrador",
    "timbradoras": "timbrador",
    "timbradores": "timbrador",
    "timbrados": "timbrar",
    "timbragens": "timbragem",
    "timbrai": "timbrar",
    "timbrais": "timbrar",
    "timbram": "timbrar",
    "timbramo": "timbrar",
    "timbramos": "timbrar",
    "timbrando": "timbrar",
    "timbrara": "timbrar",
    "timbraram": "timbrar",
    "timbraras": "timbrar",
    "timbrarde": "timbrar",
    "timbrardes": "timbrar",
    "timbrare": "timbrar",
    "timbrarei": "timbrar",
    "timbrareis": "timbrar",
    "timbrarem": "timbrar",
    "timbraremos": "timbrar",
    "timbrares": "timbrar",
    "timbraria": "timbrar",
    "timbrariam": "timbrar",
    "timbrarias": "timbrar",
    "timbrarmo": "timbrar",
    "timbrarmos": "timbrar",
    "timbrará": "timbrar",
    "timbrarás": "timbrar",
    "timbrarão": "timbrar",
    "timbraríamos": "timbrar",
    "timbraríeis": "timbrar",
    "timbras": "timbrar",
    "timbrasse": "timbrar",
    "timbrassem": "timbrar",
    "timbrasses": "timbrar",
    "timbraste": "timbrar",
    "timbrastes": "timbrar",
    "timbrava": "timbrar",
    "timbravam": "timbrar",
    "timbravas": "timbrar",
    "timbre": "timbrar",
    "timbrei": "timbrar",
    "timbreis": "timbrar",
    "timbrem": "timbrar",
    "timbremo": "timbrar",
    "timbremos": "timbrar",
    "timbres": "timbre",
    "timbro": "timbrar",
    "timbrosa": "timbroso",
    "timbrosas": "timbroso",
    "timbrosos": "timbroso",
    "timbrou": "timbrar",
    "timbrá": "timbrar",
    "timbrámo": "timbrar",
    "timbrámos": "timbrar",
    "timbráramo": "timbrar",
    "timbráramos": "timbrar",
    "timbrárei": "timbrar",
    "timbráreis": "timbrar",
    "timbrásseis": "timbrar",
    "timbrássemos": "timbrar",
    "timbrávamo": "timbrar",
    "timbrávamos": "timbrar",
    "timbrávei": "timbrar",
    "timbráveis": "timbrar",
    "timburis": "timburi",
    "timbus": "timbu",
    "timbós": "timbó",
    "timectomias": "timectomia",
    "timeleáceas": "timeleácea",
    "timias": "timia",
    "timiatecnias": "timiatecnia",
    "timidezes": "timidez",
    "timocratas": "timocrata",
    "timocrática": "timocrático",
    "timocráticas": "timocrático",
    "timocráticos": "timocrático",
    "timona": "timonar",
    "timonada": "timonar",
    "timonadas": "timonar",
    "timonado": "timonar",
    "timonados": "timonar",
    "timonai": "timonar",
    "timonais": "timonar",
    "timonam": "timonar",
    "timonamo": "timonar",
    "timonamos": "timonar",
    "timonando": "timonar",
    "timonara": "timonar",
    "timonaram": "timonar",
    "timonaras": "timonar",
    "timonarde": "timonar",
    "timonardes": "timonar",
    "timonare": "timonar",
    "timonarei": "timonar",
    "timonareis": "timonar",
    "timonarem": "timonar",
    "timonaremos": "timonar",
    "timonares": "timonar",
    "timonaria": "timonar",
    "timonariam": "timonar",
    "timonarias": "timonar",
    "timonarmo": "timonar",
    "timonarmos": "timonar",
    "timonará": "timonar",
    "timonarás": "timonar",
    "timonarão": "timonar",
    "timonaríamos": "timonar",
    "timonaríeis": "timonar",
    "timonas": "timonar",
    "timonasse": "timonar",
    "timonassem": "timonar",
    "timonasses": "timonar",
    "timonaste": "timonar",
    "timonastes": "timonar",
    "timonava": "timonar",
    "timonavam": "timonar",
    "timonavas": "timonar",
    "timone": "timonar",
    "timonei": "timonar",
    "timoneira": "timoneiro",
    "timoneiras": "timoneiro",
    "timoneiros": "timoneiro",
    "timoneis": "timonar",
    "timonem": "timonar",
    "timonemo": "timonar",
    "timonemos": "timonar",
    "timones": "timonar",
    "timono": "timonar",
    "timonou": "timonar",
    "timoná": "timonar",
    "timonámo": "timonar",
    "timonámos": "timonar",
    "timonáramo": "timonar",
    "timonáramos": "timonar",
    "timonárei": "timonar",
    "timonáreis": "timonar",
    "timonásseis": "timonar",
    "timonássemos": "timonar",
    "timonávamo": "timonar",
    "timonávamos": "timonar",
    "timonávei": "timonar",
    "timonáveis": "timonar",
    "timopsiquias": "timopsiquia",
    "timorata": "timorato",
    "timoratas": "timorato",
    "timoratos": "timorato",
    "timorenses": "timorense",
    "timores": "timor",
    "timors": "timor",
    "timos": "timo",
    "timpanais": "timpanal",
    "timpanectomias": "timpanectomia",
    "timpanilhos": "timpanilho",
    "timpanismos": "timpanismo",
    "timpaniza": "timpanizar",
    "timpanizada": "timpanizar",
    "timpanizadas": "timpanizar",
    "timpanizado": "timpanizar",
    "timpanizados": "timpanizar",
    "timpanizai": "timpanizar",
    "timpanizais": "timpanizar",
    "timpanizam": "timpanizar",
    "timpanizamo": "timpanizar",
    "timpanizamos": "timpanizar",
    "timpanizando": "timpanizar",
    "timpanizara": "timpanizar",
    "timpanizaram": "timpanizar",
    "timpanizaras": "timpanizar",
    "timpanizarde": "timpanizar",
    "timpanizardes": "timpanizar",
    "timpanizare": "timpanizar",
    "timpanizarei": "timpanizar",
    "timpanizareis": "timpanizar",
    "timpanizarem": "timpanizar",
    "timpanizaremos": "timpanizar",
    "timpanizares": "timpanizar",
    "timpanizaria": "timpanizar",
    "timpanizariam": "timpanizar",
    "timpanizarias": "timpanizar",
    "timpanizarmo": "timpanizar",
    "timpanizarmos": "timpanizar",
    "timpanizará": "timpanizar",
    "timpanizarás": "timpanizar",
    "timpanizarão": "timpanizar",
    "timpanizaríamos": "timpanizar",
    "timpanizaríeis": "timpanizar",
    "timpanizas": "timpanizar",
    "timpanizasse": "timpanizar",
    "timpanizassem": "timpanizar",
    "timpanizasses": "timpanizar",
    "timpanizaste": "timpanizar",
    "timpanizastes": "timpanizar",
    "timpanizava": "timpanizar",
    "timpanizavam": "timpanizar",
    "timpanizavas": "timpanizar",
    "timpanizações": "timpanização",
    "timpanize": "timpanizar",
    "timpanizei": "timpanizar",
    "timpanizeis": "timpanizar",
    "timpanizem": "timpanizar",
    "timpanizemo": "timpanizar",
    "timpanizemos": "timpanizar",
    "timpanizes": "timpanizar",
    "timpanizo": "timpanizar",
    "timpanizou": "timpanizar",
    "timpanizá": "timpanizar",
    "timpanizámo": "timpanizar",
    "timpanizámos": "timpanizar",
    "timpanizáramo": "timpanizar",
    "timpanizáramos": "timpanizar",
    "timpanizárei": "timpanizar",
    "timpanizáreis": "timpanizar",
    "timpanizásseis": "timpanizar",
    "timpanizássemos": "timpanizar",
    "timpanizávamo": "timpanizar",
    "timpanizávamos": "timpanizar",
    "timpanizávei": "timpanizar",
    "timpanizáveis": "timpanizar",
    "timpanítica": "timpanítico",
    "timpaníticas": "timpanítico",
    "timpaníticos": "timpanítico",
    "timpânica": "timpânico",
    "timpânicas": "timpânico",
    "timpânicos": "timpânico",
    "timtins": "timtim",
    "timóis": "timol",
    "timões": "timão",
    "tina": "tinir",
    "tinadas": "tinada",
    "tinais": "tinir",
    "tinalhas": "tinalha",
    "tinam": "tinir",
    "tinamo": "tinir",
    "tinamos": "tinir",
    "tinamus": "tinamu",
    "tinamídeos": "tinamídeo",
    "tinas": "tinir",
    "tincais": "tincal",
    "tincaleiras": "tincaleira",
    "tincas": "tinca",
    "tine": "tinir",
    "tineidas": "tineida",
    "tineiras": "tineira",
    "tineleira": "tineleiro",
    "tineleiras": "tineleiro",
    "tineleiros": "tineleiro",
    "tinelos": "tinelo",
    "tinem": "tinir",
    "tines": "tinir",
    "tinetas": "tineta",
    "tineídeos": "tineídeo",
    "tinfa": "tinfar",
    "tinfada": "tinfar",
    "tinfadas": "tinfar",
    "tinfado": "tinfar",
    "tinfados": "tinfar",
    "tinfai": "tinfar",
    "tinfais": "tinfar",
    "tinfam": "tinfar",
    "tinfamo": "tinfar",
    "tinfamos": "tinfar",
    "tinfando": "tinfar",
    "tinfara": "tinfar",
    "tinfaram": "tinfar",
    "tinfaras": "tinfar",
    "tinfardes": "tinfar",
    "tinfarei": "tinfar",
    "tinfareis": "tinfar",
    "tinfarem": "tinfar",
    "tinfaremos": "tinfar",
    "tinfares": "tinfar",
    "tinfaria": "tinfar",
    "tinfariam": "tinfar",
    "tinfarias": "tinfar",
    "tinfarmo": "tinfar",
    "tinfarmos": "tinfar",
    "tinfará": "tinfar",
    "tinfarás": "tinfar",
    "tinfarão": "tinfar",
    "tinfaríamos": "tinfar",
    "tinfaríeis": "tinfar",
    "tinfas": "tinfar",
    "tinfasse": "tinfar",
    "tinfassem": "tinfar",
    "tinfasses": "tinfar",
    "tinfaste": "tinfar",
    "tinfastes": "tinfar",
    "tinfava": "tinfar",
    "tinfavam": "tinfar",
    "tinfavas": "tinfar",
    "tinfe": "tinfar",
    "tinfei": "tinfar",
    "tinfeis": "tinfar",
    "tinfem": "tinfar",
    "tinfemo": "tinfar",
    "tinfemos": "tinfar",
    "tinfes": "tinfar",
    "tinfo": "tinfar",
    "tinfou": "tinfar",
    "tinfámo": "tinfar",
    "tinfámos": "tinfar",
    "tinfáramo": "tinfar",
    "tinfáramos": "tinfar",
    "tinfáreis": "tinfar",
    "tinfásseis": "tinfar",
    "tinfássemos": "tinfar",
    "tinfávamo": "tinfar",
    "tinfávamos": "tinfar",
    "tinfáveis": "tinfar",
    "tinga": "tingar",
    "tingada": "tingar",
    "tingadas": "tingar",
    "tingado": "tingar",
    "tingados": "tingar",
    "tingai": "tingar",
    "tingais": "tingar",
    "tingam": "tingar",
    "tingamo": "tingar",
    "tingamos": "tingar",
    "tingando": "tingar",
    "tingara": "tingar",
    "tingaram": "tingar",
    "tingaras": "tingar",
    "tingarde": "tingar",
    "tingardes": "tingar",
    "tingare": "tingar",
    "tingarei": "tingar",
    "tingareis": "tingar",
    "tingarem": "tingar",
    "tingaremos": "tingar",
    "tingares": "tingar",
    "tingaria": "tingar",
    "tingariam": "tingar",
    "tingarias": "tingar",
    "tingarmo": "tingar",
    "tingarmos": "tingar",
    "tingará": "tingar",
    "tingarás": "tingar",
    "tingarão": "tingar",
    "tingaríamos": "tingar",
    "tingaríeis": "tingar",
    "tingas": "tingar",
    "tingasse": "tingar",
    "tingassem": "tingar",
    "tingasses": "tingar",
    "tingaste": "tingar",
    "tingastes": "tingar",
    "tingava": "tingar",
    "tingavam": "tingar",
    "tingavas": "tingar",
    "tinge": "tingir",
    "tingem": "tingir",
    "tinges": "tingir",
    "tingi": "tingir",
    "tingia": "tingir",
    "tingiam": "tingir",
    "tingias": "tingir",
    "tingida": "tingir",
    "tingidas": "tingir",
    "tingido": "tingir",
    "tingidora": "tingidor",
    "tingidoras": "tingidor",
    "tingidores": "tingidor",
    "tingidos": "tingir",
    "tingiduras": "tingidura",
    "tingimo": "tingir",
    "tingimos": "tingir",
    "tingindo": "tingir",
    "tingira": "tingir",
    "tingiram": "tingir",
    "tingiras": "tingir",
    "tingirde": "tingir",
    "tingirdes": "tingir",
    "tingire": "tingir",
    "tingirei": "tingir",
    "tingireis": "tingir",
    "tingirem": "tingir",
    "tingiremos": "tingir",
    "tingires": "tingir",
    "tingiria": "tingir",
    "tingiriam": "tingir",
    "tingirias": "tingir",
    "tingirmo": "tingir",
    "tingirmos": "tingir",
    "tingirá": "tingir",
    "tingirás": "tingir",
    "tingirão": "tingir",
    "tingiríamos": "tingir",
    "tingiríeis": "tingir",
    "tingis": "tingir",
    "tingisse": "tingir",
    "tingissem": "tingir",
    "tingisses": "tingir",
    "tingiste": "tingir",
    "tingistes": "tingir",
    "tingitana": "tingitano",
    "tingitanas": "tingitano",
    "tingitanos": "tingitano",
    "tingiu": "tingir",
    "tingo": "tingar",
    "tingou": "tingar",
    "tingue": "tingar",
    "tinguei": "tingar",
    "tingueira": "tingueiro",
    "tingueiras": "tingueiro",
    "tingueiros": "tingueiro",
    "tingueis": "tingar",
    "tinguem": "tingar",
    "tinguemo": "tingar",
    "tinguemos": "tingar",
    "tingues": "tingar",
    "tinguija": "tinguijar",
    "tinguijada": "tinguijar",
    "tinguijadas": "tinguijar",
    "tinguijado": "tinguijar",
    "tinguijados": "tinguijar",
    "tinguijai": "tinguijar",
    "tinguijais": "tinguijar",
    "tinguijam": "tinguijar",
    "tinguijamo": "tinguijar",
    "tinguijamos": "tinguijar",
    "tinguijando": "tinguijar",
    "tinguijara": "tinguijar",
    "tinguijaram": "tinguijar",
    "tinguijaras": "tinguijar",
    "tinguijarde": "tinguijar",
    "tinguijardes": "tinguijar",
    "tinguijare": "tinguijar",
    "tinguijarei": "tinguijar",
    "tinguijareis": "tinguijar",
    "tinguijarem": "tinguijar",
    "tinguijaremos": "tinguijar",
    "tinguijares": "tinguijar",
    "tinguijaria": "tinguijar",
    "tinguijariam": "tinguijar",
    "tinguijarias": "tinguijar",
    "tinguijarmo": "tinguijar",
    "tinguijarmos": "tinguijar",
    "tinguijará": "tinguijar",
    "tinguijarás": "tinguijar",
    "tinguijarão": "tinguijar",
    "tinguijaríamos": "tinguijar",
    "tinguijaríeis": "tinguijar",
    "tinguijas": "tinguijar",
    "tinguijasse": "tinguijar",
    "tinguijassem": "tinguijar",
    "tinguijasses": "tinguijar",
    "tinguijaste": "tinguijar",
    "tinguijastes": "tinguijar",
    "tinguijava": "tinguijar",
    "tinguijavam": "tinguijar",
    "tinguijavas": "tinguijar",
    "tinguije": "tinguijar",
    "tinguijei": "tinguijar",
    "tinguijeis": "tinguijar",
    "tinguijem": "tinguijar",
    "tinguijemo": "tinguijar",
    "tinguijemos": "tinguijar",
    "tinguijes": "tinguijar",
    "tinguijo": "tinguijar",
    "tinguijou": "tinguijar",
    "tinguijá": "tinguijar",
    "tinguijámo": "tinguijar",
    "tinguijámos": "tinguijar",
    "tinguijáramo": "tinguijar",
    "tinguijáramos": "tinguijar",
    "tinguijárei": "tinguijar",
    "tinguijáreis": "tinguijar",
    "tinguijásseis": "tinguijar",
    "tinguijássemos": "tinguijar",
    "tinguijávamo": "tinguijar",
    "tinguijávamos": "tinguijar",
    "tinguijávei": "tinguijar",
    "tinguijáveis": "tinguijar",
    "tinguis": "tingui",
    "tingá": "tingar",
    "tingámo": "tingar",
    "tingámos": "tingar",
    "tingáramo": "tingar",
    "tingáramos": "tingar",
    "tingárei": "tingar",
    "tingáreis": "tingar",
    "tingásseis": "tingar",
    "tingássemos": "tingar",
    "tingávamo": "tingar",
    "tingávamos": "tingar",
    "tingávei": "tingar",
    "tingáveis": "tingar",
    "tingíamo": "tingir",
    "tingíamos": "tingir",
    "tingíei": "tingir",
    "tingíeis": "tingir",
    "tingíramo": "tingir",
    "tingíramos": "tingir",
    "tingírei": "tingir",
    "tingíreis": "tingir",
    "tingísseis": "tingir",
    "tingíssemos": "tingir",
    "tinha": "ter",
    "tinham": "ter",
    "tinhas": "tinha",
    "tinhorões": "tinhorão",
    "tinhosa": "tinhoso",
    "tinhosas": "tinhoso",
    "tinhosos": "tinhoso",
    "tini": "tinir",
    "tinia": "tinir",
    "tiniam": "tinir",
    "tinias": "tinir",
    "tinida": "tinir",
    "tinidas": "tinir",
    "tinido": "tinir",
    "tinidora": "tinidor",
    "tinidoras": "tinidor",
    "tinidores": "tinidor",
    "tinidos": "tinir",
    "tinimo": "tinir",
    "tinimos": "tinir",
    "tinindo": "tinir",
    "tinintes": "tininte",
    "tinira": "tinir",
    "tiniram": "tinir",
    "tiniras": "tinir",
    "tinirdes": "tinir",
    "tinirei": "tinir",
    "tinireis": "tinir",
    "tinirem": "tinir",
    "tiniremos": "tinir",
    "tinires": "tinir",
    "tiniria": "tinir",
    "tiniriam": "tinir",
    "tinirias": "tinir",
    "tinirmo": "tinir",
    "tinirmos": "tinir",
    "tinirá": "tinir",
    "tinirás": "tinir",
    "tinirão": "tinir",
    "tiniríamos": "tinir",
    "tiniríeis": "tinir",
    "tinis": "tinir",
    "tinisse": "tinir",
    "tinissem": "tinir",
    "tinisses": "tinir",
    "tiniste": "tinir",
    "tinistes": "tinir",
    "tiniu": "tinir",
    "tinja": "tingir",
    "tinjais": "tingir",
    "tinjam": "tingir",
    "tinjamo": "tingir",
    "tinjamos": "tingir",
    "tinjas": "tingir",
    "tinjo": "tingir",
    "tino": "tinir",
    "tinocas": "tinoca",
    "tinos": "tino",
    "tinotes": "tinote",
    "tinta": "tinto",
    "tintagens": "tintagem",
    "tintas": "tinto",
    "tintazinha": "tinto",
    "tintazinhas": "tinto",
    "tintazita": "tinto",
    "tintazitas": "tinto",
    "tinteirinho": "tinteiro",
    "tinteirinhos": "tinteiro",
    "tinteirito": "tinteiro",
    "tinteiritos": "tinteiro",
    "tinteiros": "tinteiro",
    "tintina": "tintinir",
    "tintinabula": "tintinabular",
    "tintinabulada": "tintinabular",
    "tintinabuladas": "tintinabular",
    "tintinabulado": "tintinabular",
    "tintinabulados": "tintinabular",
    "tintinabulai": "tintinabular",
    "tintinabulais": "tintinabular",
    "tintinabulam": "tintinabular",
    "tintinabulamo": "tintinabular",
    "tintinabulamos": "tintinabular",
    "tintinabulando": "tintinabular",
    "tintinabulara": "tintinabular",
    "tintinabularam": "tintinabular",
    "tintinabularas": "tintinabular",
    "tintinabularde": "tintinabular",
    "tintinabulardes": "tintinabular",
    "tintinabulare": "tintinabular",
    "tintinabularei": "tintinabular",
    "tintinabulareis": "tintinabular",
    "tintinabularem": "tintinabular",
    "tintinabularemos": "tintinabular",
    "tintinabulares": "tintinabular",
    "tintinabularia": "tintinabular",
    "tintinabulariam": "tintinabular",
    "tintinabularias": "tintinabular",
    "tintinabularmo": "tintinabular",
    "tintinabularmos": "tintinabular",
    "tintinabulará": "tintinabular",
    "tintinabularás": "tintinabular",
    "tintinabularão": "tintinabular",
    "tintinabularíamos": "tintinabular",
    "tintinabularíeis": "tintinabular",
    "tintinabulas": "tintinabular",
    "tintinabulasse": "tintinabular",
    "tintinabulassem": "tintinabular",
    "tintinabulasses": "tintinabular",
    "tintinabulaste": "tintinabular",
    "tintinabulastes": "tintinabular",
    "tintinabulava": "tintinabular",
    "tintinabulavam": "tintinabular",
    "tintinabulavas": "tintinabular",
    "tintinabule": "tintinabular",
    "tintinabulei": "tintinabular",
    "tintinabuleis": "tintinabular",
    "tintinabulem": "tintinabular",
    "tintinabulemo": "tintinabular",
    "tintinabulemos": "tintinabular",
    "tintinabules": "tintinabular",
    "tintinabulo": "tintinabular",
    "tintinabulou": "tintinabular",
    "tintinabulá": "tintinabular",
    "tintinabulámo": "tintinabular",
    "tintinabulámos": "tintinabular",
    "tintinabuláramo": "tintinabular",
    "tintinabuláramos": "tintinabular",
    "tintinabulárei": "tintinabular",
    "tintinabuláreis": "tintinabular",
    "tintinabulásseis": "tintinabular",
    "tintinabulássemos": "tintinabular",
    "tintinabulávamo": "tintinabular",
    "tintinabulávamos": "tintinabular",
    "tintinabulávei": "tintinabular",
    "tintinabuláveis": "tintinabular",
    "tintinada": "tintinar",
    "tintinadas": "tintinar",
    "tintinado": "tintinar",
    "tintinados": "tintinar",
    "tintinai": "tintinar",
    "tintinais": "tintinir",
    "tintinam": "tintinir",
    "tintinamo": "tintinir",
    "tintinamos": "tintinir",
    "tintinando": "tintinar",
    "tintinantes": "tintinante",
    "tintinara": "tintinar",
    "tintinaram": "tintinar",
    "tintinaras": "tintinar",
    "tintinardes": "tintinar",
    "tintinarei": "tintinar",
    "tintinareis": "tintinar",
    "tintinarem": "tintinar",
    "tintinaremos": "tintinar",
    "tintinares": "tintinar",
    "tintinaria": "tintinar",
    "tintinariam": "tintinar",
    "tintinarias": "tintinar",
    "tintinarmo": "tintinar",
    "tintinarmos": "tintinar",
    "tintinará": "tintinar",
    "tintinarás": "tintinar",
    "tintinarão": "tintinar",
    "tintinaríamos": "tintinar",
    "tintinaríeis": "tintinar",
    "tintinas": "tintinir",
    "tintinasse": "tintinar",
    "tintinassem": "tintinar",
    "tintinasses": "tintinar",
    "tintinaste": "tintinar",
    "tintinastes": "tintinar",
    "tintinava": "tintinar",
    "tintinavam": "tintinar",
    "tintinavas": "tintinar",
    "tintine": "tintinir",
    "tintinei": "tintinar",
    "tintineis": "tintinar",
    "tintinem": "tintinir",
    "tintinemo": "tintinar",
    "tintinemos": "tintinar",
    "tintines": "tintinir",
    "tintinha": "tinto",
    "tintinhas": "tinto",
    "tintinho": "tinto",
    "tintinhos": "tinto",
    "tintini": "tintinir",
    "tintinia": "tintinir",
    "tintiniam": "tintinir",
    "tintinias": "tintinir",
    "tintinida": "tintinir",
    "tintinidas": "tintinir",
    "tintinido": "tintinir",
    "tintinidos": "tintinir",
    "tintinimo": "tintinir",
    "tintinimos": "tintinir",
    "tintinindo": "tintinir",
    "tintinira": "tintinir",
    "tintiniram": "tintinir",
    "tintiniras": "tintinir",
    "tintinirdes": "tintinir",
    "tintinirei": "tintinir",
    "tintinireis": "tintinir",
    "tintinirem": "tintinir",
    "tintiniremos": "tintinir",
    "tintinires": "tintinir",
    "tintiniria": "tintinir",
    "tintiniriam": "tintinir",
    "tintinirias": "tintinir",
    "tintinirmo": "tintinir",
    "tintinirmos": "tintinir",
    "tintinirá": "tintinir",
    "tintinirás": "tintinir",
    "tintinirão": "tintinir",
    "tintiniríamos": "tintinir",
    "tintiniríeis": "tintinir",
    "tintinis": "tintinir",
    "tintinisse": "tintinir",
    "tintinissem": "tintinir",
    "tintinisses": "tintinir",
    "tintiniste": "tintinir",
    "tintinistes": "tintinir",
    "tintiniu": "tintinir",
    "tintino": "tintinir",
    "tintinou": "tintinar",
    "tintinábulos": "tintinábulo",
    "tintinámo": "tintinar",
    "tintinámos": "tintinar",
    "tintináramo": "tintinar",
    "tintináramos": "tintinar",
    "tintináreis": "tintinar",
    "tintinásseis": "tintinar",
    "tintinássemos": "tintinar",
    "tintinávamo": "tintinar",
    "tintinávamos": "tintinar",
    "tintináveis": "tintinar",
    "tintiníamo": "tintinir",
    "tintiníamos": "tintinir",
    "tintiníeis": "tintinir",
    "tintiníramo": "tintinir",
    "tintiníramos": "tintinir",
    "tintiníreis": "tintinir",
    "tintinísseis": "tintinir",
    "tintiníssemos": "tintinir",
    "tintita": "tinto",
    "tintitas": "tinto",
    "tintito": "tinto",
    "tintitos": "tinto",
    "tintora": "tintor",
    "tintoras": "tintor",
    "tintores": "tintor",
    "tintoriais": "tintorial",
    "tintos": "tinto",
    "tintozinho": "tinto",
    "tintozinhos": "tinto",
    "tintozito": "tinto",
    "tintozitos": "tinto",
    "tinturarias": "tinturaria",
    "tinturas": "tintura",
    "tintureiros": "tintureiro",
    "tinturona": "tinturão",
    "tinturonas": "tinturão",
    "tinturões": "tinturão",
    "tintória": "tintório",
    "tintórias": "tintório",
    "tintórios": "tintório",
    "tinâmidas": "tinâmida",
    "tinções": "tinção",
    "tiníamo": "tinir",
    "tiníamos": "tinir",
    "tiníeis": "tinir",
    "tiníramo": "tinir",
    "tiníramos": "tinir",
    "tiníreis": "tinir",
    "tinísseis": "tinir",
    "tiníssemos": "tinir",
    "tiobactérias": "tiobactéria",
    "tiocinatos": "tiocinato",
    "tiorbas": "tiorba",
    "tiorgas": "tiorga",
    "tios": "tio",
    "tiossais": "tiossal",
    "tiossulfatos": "tiossulfato",
    "tiossulfúrica": "tiossulfúrico",
    "tiossulfúricas": "tiossulfúrico",
    "tiossulfúricos": "tiossulfúrico",
    "tipa": "tipo",
    "tipanites": "tipanite",
    "tipas": "tipo",
    "tipazinha": "tipo",
    "tipazinhas": "tipo",
    "tipazita": "tipo",
    "tipazitas": "tipo",
    "tipicidades": "tipicidade",
    "tipifica": "tipificar",
    "tipificada": "tipificar",
    "tipificadas": "tipificar",
    "tipificado": "tipificar",
    "tipificadora": "tipificador",
    "tipificadoras": "tipificador",
    "tipificadores": "tipificador",
    "tipificados": "tipificar",
    "tipificai": "tipificar",
    "tipificais": "tipificar",
    "tipificam": "tipificar",
    "tipificamo": "tipificar",
    "tipificamos": "tipificar",
    "tipificando": "tipificar",
    "tipificara": "tipificar",
    "tipificaram": "tipificar",
    "tipificaras": "tipificar",
    "tipificarde": "tipificar",
    "tipificardes": "tipificar",
    "tipificare": "tipificar",
    "tipificarei": "tipificar",
    "tipificareis": "tipificar",
    "tipificarem": "tipificar",
    "tipificaremos": "tipificar",
    "tipificares": "tipificar",
    "tipificaria": "tipificar",
    "tipificariam": "tipificar",
    "tipificarias": "tipificar",
    "tipificarmo": "tipificar",
    "tipificarmos": "tipificar",
    "tipificará": "tipificar",
    "tipificarás": "tipificar",
    "tipificarão": "tipificar",
    "tipificaríamos": "tipificar",
    "tipificaríeis": "tipificar",
    "tipificas": "tipificar",
    "tipificasse": "tipificar",
    "tipificassem": "tipificar",
    "tipificasses": "tipificar",
    "tipificaste": "tipificar",
    "tipificastes": "tipificar",
    "tipificava": "tipificar",
    "tipificavam": "tipificar",
    "tipificavas": "tipificar",
    "tipificações": "tipificação",
    "tipifico": "tipificar",
    "tipificou": "tipificar",
    "tipificá": "tipificar",
    "tipificámo": "tipificar",
    "tipificámos": "tipificar",
    "tipificáramo": "tipificar",
    "tipificáramos": "tipificar",
    "tipificárei": "tipificar",
    "tipificáreis": "tipificar",
    "tipificásseis": "tipificar",
    "tipificássemos": "tipificar",
    "tipificávamo": "tipificar",
    "tipificávamos": "tipificar",
    "tipificávei": "tipificar",
    "tipificáveis": "tipificar",
    "tipifique": "tipificar",
    "tipifiquei": "tipificar",
    "tipifiqueis": "tipificar",
    "tipifiquem": "tipificar",
    "tipifiquemo": "tipificar",
    "tipifiquemos": "tipificar",
    "tipifiques": "tipificar",
    "tipinha": "tipo",
    "tipinhas": "tipo",
    "tipinho": "tipo",
    "tipinhos": "tipo",
    "tipiris": "tipiri",
    "tipita": "tipo",
    "tipitas": "tipo",
    "tipito": "tipo",
    "tipitos": "tipo",
    "tipocromias": "tipocromia",
    "tipografa": "tipografar",
    "tipografada": "tipografar",
    "tipografadas": "tipografar",
    "tipografado": "tipografar",
    "tipografados": "tipografar",
    "tipografai": "tipografar",
    "tipografais": "tipografar",
    "tipografam": "tipografar",
    "tipografamo": "tipografar",
    "tipografamos": "tipografar",
    "tipografando": "tipografar",
    "tipografara": "tipografar",
    "tipografaram": "tipografar",
    "tipografaras": "tipografar",
    "tipografarde": "tipografar",
    "tipografardes": "tipografar",
    "tipografare": "tipografar",
    "tipografarei": "tipografar",
    "tipografareis": "tipografar",
    "tipografarem": "tipografar",
    "tipografaremos": "tipografar",
    "tipografares": "tipografar",
    "tipografaria": "tipografar",
    "tipografariam": "tipografar",
    "tipografarias": "tipografar",
    "tipografarmo": "tipografar",
    "tipografarmos": "tipografar",
    "tipografará": "tipografar",
    "tipografarás": "tipografar",
    "tipografarão": "tipografar",
    "tipografaríamos": "tipografar",
    "tipografaríeis": "tipografar",
    "tipografas": "tipografar",
    "tipografasse": "tipografar",
    "tipografassem": "tipografar",
    "tipografasses": "tipografar",
    "tipografaste": "tipografar",
    "tipografastes": "tipografar",
    "tipografava": "tipografar",
    "tipografavam": "tipografar",
    "tipografavas": "tipografar",
    "tipografe": "tipografar",
    "tipografei": "tipografar",
    "tipografeis": "tipografar",
    "tipografem": "tipografar",
    "tipografemo": "tipografar",
    "tipografemos": "tipografar",
    "tipografes": "tipografar",
    "tipografias": "tipografia",
    "tipografo": "tipografar",
    "tipografou": "tipografar",
    "tipografá": "tipografar",
    "tipografámo": "tipografar",
    "tipografámos": "tipografar",
    "tipografáramo": "tipografar",
    "tipografáramos": "tipografar",
    "tipografárei": "tipografar",
    "tipografáreis": "tipografar",
    "tipografásseis": "tipografar",
    "tipografássemos": "tipografar",
    "tipografávamo": "tipografar",
    "tipografávamos": "tipografar",
    "tipografávei": "tipografar",
    "tipografáveis": "tipografar",
    "tipográfica": "tipográfico",
    "tipográficas": "tipográfico",
    "tipográficos": "tipográfico",
    "tipoideias": "tipoideia",
    "tipolitografias": "tipolitografia",
    "tipologias": "tipologia",
    "tipometrias": "tipometria",
    "tipos": "tipo",
    "tipotelegrafias": "tipotelegrafia",
    "tipozinho": "tipo",
    "tipozinhos": "tipo",
    "tipozito": "tipo",
    "tipozitos": "tipo",
    "tiptologias": "tiptologia",
    "tiptólogos": "tiptólogo",
    "tipuanas": "tipuana",
    "tipulídeos": "tipulídeo",
    "tipus": "tipu",
    "tipógrafa": "tipógrafo",
    "tipógrafas": "tipógrafo",
    "tipógrafos": "tipógrafo",
    "tipóias": "tipóia",
    "tipómetros": "tipómetro",
    "tipótonos": "tipótono",
    "tipúlidas": "tipúlida",
    "tiques": "tique",
    "tiquetaqueada": "tiquetaquear",
    "tiquetaqueadas": "tiquetaquear",
    "tiquetaqueado": "tiquetaquear",
    "tiquetaqueados": "tiquetaquear",
    "tiquetaqueai": "tiquetaquear",
    "tiquetaqueais": "tiquetaquear",
    "tiquetaqueamo": "tiquetaquear",
    "tiquetaqueamos": "tiquetaquear",
    "tiquetaqueando": "tiquetaquear",
    "tiquetaqueara": "tiquetaquear",
    "tiquetaquearam": "tiquetaquear",
    "tiquetaquearas": "tiquetaquear",
    "tiquetaqueardes": "tiquetaquear",
    "tiquetaquearei": "tiquetaquear",
    "tiquetaqueareis": "tiquetaquear",
    "tiquetaquearem": "tiquetaquear",
    "tiquetaquearemos": "tiquetaquear",
    "tiquetaqueares": "tiquetaquear",
    "tiquetaquearia": "tiquetaquear",
    "tiquetaqueariam": "tiquetaquear",
    "tiquetaquearias": "tiquetaquear",
    "tiquetaquearmo": "tiquetaquear",
    "tiquetaquearmos": "tiquetaquear",
    "tiquetaqueará": "tiquetaquear",
    "tiquetaquearás": "tiquetaquear",
    "tiquetaquearão": "tiquetaquear",
    "tiquetaquearíamos": "tiquetaquear",
    "tiquetaquearíeis": "tiquetaquear",
    "tiquetaqueasse": "tiquetaquear",
    "tiquetaqueassem": "tiquetaquear",
    "tiquetaqueasses": "tiquetaquear",
    "tiquetaqueaste": "tiquetaquear",
    "tiquetaqueastes": "tiquetaquear",
    "tiquetaqueava": "tiquetaquear",
    "tiquetaqueavam": "tiquetaquear",
    "tiquetaqueavas": "tiquetaquear",
    "tiquetaqueei": "tiquetaquear",
    "tiquetaqueeis": "tiquetaquear",
    "tiquetaqueemo": "tiquetaquear",
    "tiquetaqueemos": "tiquetaquear",
    "tiquetaqueia": "tiquetaquear",
    "tiquetaqueiam": "tiquetaquear",
    "tiquetaqueias": "tiquetaquear",
    "tiquetaqueie": "tiquetaquear",
    "tiquetaqueiem": "tiquetaquear",
    "tiquetaqueies": "tiquetaquear",
    "tiquetaqueio": "tiquetaquear",
    "tiquetaqueou": "tiquetaquear",
    "tiquetaques": "tiquetaque",
    "tiquetaqueámo": "tiquetaquear",
    "tiquetaqueámos": "tiquetaquear",
    "tiquetaqueáramo": "tiquetaquear",
    "tiquetaqueáramos": "tiquetaquear",
    "tiquetaqueáreis": "tiquetaquear",
    "tiquetaqueásseis": "tiquetaquear",
    "tiquetaqueássemos": "tiquetaquear",
    "tiquetaqueávamo": "tiquetaquear",
    "tiquetaqueávamos": "tiquetaquear",
    "tiquetaqueáveis": "tiquetaquear",
    "tiquetiques": "tiquetique",
    "tiquistas": "tiquista",
    "tira": "tirar",
    "tiracolos": "tiracolo",
    "tirada": "tirar",
    "tiradas": "tirar",
    "tiradeiras": "tiradeira",
    "tirado": "tirar",
    "tiradoiras": "tiradoira",
    "tiradora": "tirador",
    "tiradoras": "tirador",
    "tiradores": "tirador",
    "tirados": "tirar",
    "tiradouras": "tiradoura",
    "tiraduras": "tiradura",
    "tiragens": "tiragem",
    "tirai": "tirar",
    "tirais": "tirar",
    "tiram": "tirar",
    "tiramentos": "tiramento",
    "tiramo": "tirar",
    "tiramos": "tirar",
    "tirana": "tirano",
    "tiranas": "tirano",
    "tirando": "tirar",
    "tiraneta": "tiranete",
    "tiranetas": "tiranete",
    "tiranetes": "tiranete",
    "tiranias": "tirania",
    "tiranicidas": "tiranicida",
    "tiranicídios": "tiranicídio",
    "tiranismos": "tiranismo",
    "tiraniza": "tiranizar",
    "tiranizada": "tiranizar",
    "tiranizadas": "tiranizar",
    "tiranizado": "tiranizar",
    "tiranizadora": "tiranizador",
    "tiranizadoras": "tiranizador",
    "tiranizadores": "tiranizador",
    "tiranizados": "tiranizar",
    "tiranizai": "tiranizar",
    "tiranizais": "tiranizar",
    "tiranizam": "tiranizar",
    "tiranizamo": "tiranizar",
    "tiranizamos": "tiranizar",
    "tiranizando": "tiranizar",
    "tiranizara": "tiranizar",
    "tiranizaram": "tiranizar",
    "tiranizaras": "tiranizar",
    "tiranizarde": "tiranizar",
    "tiranizardes": "tiranizar",
    "tiranizare": "tiranizar",
    "tiranizarei": "tiranizar",
    "tiranizareis": "tiranizar",
    "tiranizarem": "tiranizar",
    "tiranizaremos": "tiranizar",
    "tiranizares": "tiranizar",
    "tiranizaria": "tiranizar",
    "tiranizariam": "tiranizar",
    "tiranizarias": "tiranizar",
    "tiranizarmo": "tiranizar",
    "tiranizarmos": "tiranizar",
    "tiranizará": "tiranizar",
    "tiranizarás": "tiranizar",
    "tiranizarão": "tiranizar",
    "tiranizaríamos": "tiranizar",
    "tiranizaríeis": "tiranizar",
    "tiranizas": "tiranizar",
    "tiranizasse": "tiranizar",
    "tiranizassem": "tiranizar",
    "tiranizasses": "tiranizar",
    "tiranizaste": "tiranizar",
    "tiranizastes": "tiranizar",
    "tiranizava": "tiranizar",
    "tiranizavam": "tiranizar",
    "tiranizavas": "tiranizar",
    "tiranize": "tiranizar",
    "tiranizei": "tiranizar",
    "tiranizeis": "tiranizar",
    "tiranizem": "tiranizar",
    "tiranizemo": "tiranizar",
    "tiranizemos": "tiranizar",
    "tiranizes": "tiranizar",
    "tiranizo": "tiranizar",
    "tiranizou": "tiranizar",
    "tiranizá": "tiranizar",
    "tiranizámo": "tiranizar",
    "tiranizámos": "tiranizar",
    "tiranizáramo": "tiranizar",
    "tiranizáramos": "tiranizar",
    "tiranizárei": "tiranizar",
    "tiranizáreis": "tiranizar",
    "tiranizásseis": "tiranizar",
    "tiranizássemos": "tiranizar",
    "tiranizávamo": "tiranizar",
    "tiranizávamos": "tiranizar",
    "tiranizávei": "tiranizar",
    "tiranizáveis": "tiranizar",
    "tiranos": "tirano",
    "tiranossauros": "tiranossauro",
    "tirantes": "tirante",
    "tiranídeos": "tiranídeo",
    "tirapés": "tirapé",
    "tirara": "tirar",
    "tiraram": "tirar",
    "tiraras": "tirar",
    "tirarde": "tirar",
    "tirardes": "tirar",
    "tirare": "tirar",
    "tirarei": "tirar",
    "tirareis": "tirar",
    "tirarem": "tirar",
    "tiraremos": "tirar",
    "tirares": "tirar",
    "tiraria": "tirar",
    "tirariam": "tirar",
    "tirarias": "tirar",
    "tirarmo": "tirar",
    "tirarmos": "tirar",
    "tirará": "tirar",
    "tirarás": "tirar",
    "tirarão": "tirar",
    "tiraríamos": "tirar",
    "tiraríeis": "tirar",
    "tiras": "tirar",
    "tirasse": "tirar",
    "tirassem": "tirar",
    "tirasses": "tirar",
    "tiraste": "tirar",
    "tirastes": "tirar",
    "tiratrões": "tiratrão",
    "tirava": "tirar",
    "tiravam": "tirar",
    "tiravas": "tirar",
    "tirazinha": "tira",
    "tirazinhas": "tira",
    "tirazita": "tira",
    "tirazitas": "tira",
    "tirações": "tiração",
    "tire": "tirar",
    "tirei": "tirar",
    "tireis": "tirar",
    "tirem": "tirar",
    "tiremo": "tirar",
    "tiremos": "tirar",
    "tireoidectomias": "tireoidectomia",
    "tireoideia": "tireoideu",
    "tireoideias": "tireoideu",
    "tireoideus": "tireoideu",
    "tireoidiana": "tireoidiano",
    "tireoidianas": "tireoidiano",
    "tireoidianos": "tireoidiano",
    "tireoidismos": "tireoidismo",
    "tireoidites": "tireoidite",
    "tireoidoterapias": "tireoidoterapia",
    "tireoidotomias": "tireoidotomia",
    "tireotomias": "tireotomia",
    "tires": "tirar",
    "tiretes": "tirete",
    "tireóidea": "tireóideo",
    "tireóideas": "tireóideo",
    "tireóideos": "tireóideo",
    "tireóides": "tireóide",
    "tirinha": "tira",
    "tirinhas": "tira",
    "tirinho": "tiro",
    "tirinhos": "tiro",
    "tirintintins": "tirintintim",
    "tiriricas": "tiririca",
    "tirita": "tiritar",
    "tiritada": "tiritar",
    "tiritadas": "tiritar",
    "tiritado": "tiritar",
    "tiritados": "tiritar",
    "tiritai": "tiritar",
    "tiritais": "tiritar",
    "tiritam": "tiritar",
    "tiritamo": "tiritar",
    "tiritamos": "tiritar",
    "tiritanas": "tiritana",
    "tiritando": "tiritar",
    "tiritantes": "tiritante",
    "tiritara": "tiritar",
    "tiritaram": "tiritar",
    "tiritaras": "tiritar",
    "tiritardes": "tiritar",
    "tiritarei": "tiritar",
    "tiritareis": "tiritar",
    "tiritarem": "tiritar",
    "tiritaremos": "tiritar",
    "tiritares": "tiritar",
    "tiritaria": "tiritar",
    "tiritariam": "tiritar",
    "tiritarias": "tiritar",
    "tiritarmo": "tiritar",
    "tiritarmos": "tiritar",
    "tiritará": "tiritar",
    "tiritarás": "tiritar",
    "tiritarão": "tiritar",
    "tiritaríamos": "tiritar",
    "tiritaríeis": "tiritar",
    "tiritas": "tiritar",
    "tiritasse": "tiritar",
    "tiritassem": "tiritar",
    "tiritasses": "tiritar",
    "tiritaste": "tiritar",
    "tiritastes": "tiritar",
    "tiritava": "tiritar",
    "tiritavam": "tiritar",
    "tiritavas": "tiritar",
    "tiritações": "tiritação",
    "tirite": "tiritar",
    "tiritei": "tiritar",
    "tiriteis": "tiritar",
    "tiritem": "tiritar",
    "tiritemo": "tiritar",
    "tiritemos": "tiritar",
    "tirites": "tiritar",
    "tirito": "tiro",
    "tiritos": "tiro",
    "tiritou": "tiritar",
    "tiritámo": "tiritar",
    "tiritámos": "tiritar",
    "tiritáramo": "tiritar",
    "tiritáramos": "tiritar",
    "tiritáreis": "tiritar",
    "tiritásseis": "tiritar",
    "tiritássemos": "tiritar",
    "tiritávamo": "tiritar",
    "tiritávamos": "tiritar",
    "tiritáveis": "tiritar",
    "tiro": "tirar",
    "tirocina": "tirocinar",
    "tirocinada": "tirocinar",
    "tirocinadas": "tirocinar",
    "tirocinado": "tirocinar",
    "tirocinados": "tirocinar",
    "tirocinai": "tirocinar",
    "tirocinais": "tirocinar",
    "tirocinam": "tirocinar",
    "tirocinamo": "tirocinar",
    "tirocinamos": "tirocinar",
    "tirocinando": "tirocinar",
    "tirocinantes": "tirocinante",
    "tirocinara": "tirocinar",
    "tirocinaram": "tirocinar",
    "tirocinaras": "tirocinar",
    "tirocinarde": "tirocinar",
    "tirocinardes": "tirocinar",
    "tirocinare": "tirocinar",
    "tirocinarei": "tirocinar",
    "tirocinareis": "tirocinar",
    "tirocinarem": "tirocinar",
    "tirocinaremos": "tirocinar",
    "tirocinares": "tirocinar",
    "tirocinaria": "tirocinar",
    "tirocinariam": "tirocinar",
    "tirocinarias": "tirocinar",
    "tirocinarmo": "tirocinar",
    "tirocinarmos": "tirocinar",
    "tirocinará": "tirocinar",
    "tirocinarás": "tirocinar",
    "tirocinarão": "tirocinar",
    "tirocinaríamos": "tirocinar",
    "tirocinaríeis": "tirocinar",
    "tirocinas": "tirocinar",
    "tirocinasse": "tirocinar",
    "tirocinassem": "tirocinar",
    "tirocinasses": "tirocinar",
    "tirocinaste": "tirocinar",
    "tirocinastes": "tirocinar",
    "tirocinava": "tirocinar",
    "tirocinavam": "tirocinar",
    "tirocinavas": "tirocinar",
    "tirocine": "tirocinar",
    "tirocinei": "tirocinar",
    "tirocineis": "tirocinar",
    "tirocinem": "tirocinar",
    "tirocinemo": "tirocinar",
    "tirocinemos": "tirocinar",
    "tirocines": "tirocinar",
    "tirocino": "tirocinar",
    "tirocinou": "tirocinar",
    "tirociná": "tirocinar",
    "tirocinámo": "tirocinar",
    "tirocinámos": "tirocinar",
    "tirocináramo": "tirocinar",
    "tirocináramos": "tirocinar",
    "tirocinárei": "tirocinar",
    "tirocináreis": "tirocinar",
    "tirocinásseis": "tirocinar",
    "tirocinássemos": "tirocinar",
    "tirocinávamo": "tirocinar",
    "tirocinávamos": "tirocinar",
    "tirocinávei": "tirocinar",
    "tirocináveis": "tirocinar",
    "tirocínios": "tirocínio",
    "tiroidectomias": "tiroidectomia",
    "tiroideia": "tiroideu",
    "tiroideias": "tiroideu",
    "tiroideus": "tiroideu",
    "tiroidiana": "tiroidiano",
    "tiroidianas": "tiroidiano",
    "tiroidianos": "tiroidiano",
    "tiroidismos": "tiroidismo",
    "tiroidites": "tiroidite",
    "tiroidoterapias": "tiroidoterapia",
    "tiroidotomias": "tiroidotomia",
    "tirolesa": "tirolês",
    "tirolesas": "tirolês",
    "tiroleses": "tirolês",
    "tiroliros": "tiroliro",
    "tiromancias": "tiromancia",
    "tiromantes": "tiromante",
    "tiromântica": "tiromântico",
    "tiromânticas": "tiromântico",
    "tiromânticos": "tiromântico",
    "tironeada": "tironear",
    "tironeadas": "tironear",
    "tironeado": "tironear",
    "tironeados": "tironear",
    "tironeai": "tironear",
    "tironeais": "tironear",
    "tironeamo": "tironear",
    "tironeamos": "tironear",
    "tironeando": "tironear",
    "tironeara": "tironear",
    "tironearam": "tironear",
    "tironearas": "tironear",
    "tironearde": "tironear",
    "tironeardes": "tironear",
    "tironeare": "tironear",
    "tironearei": "tironear",
    "tironeareis": "tironear",
    "tironearem": "tironear",
    "tironearemos": "tironear",
    "tironeares": "tironear",
    "tironearia": "tironear",
    "tironeariam": "tironear",
    "tironearias": "tironear",
    "tironearmo": "tironear",
    "tironearmos": "tironear",
    "tironeará": "tironear",
    "tironearás": "tironear",
    "tironearão": "tironear",
    "tironearíamos": "tironear",
    "tironearíeis": "tironear",
    "tironeasse": "tironear",
    "tironeassem": "tironear",
    "tironeasses": "tironear",
    "tironeaste": "tironear",
    "tironeastes": "tironear",
    "tironeava": "tironear",
    "tironeavam": "tironear",
    "tironeavas": "tironear",
    "tironeei": "tironear",
    "tironeeis": "tironear",
    "tironeemo": "tironear",
    "tironeemos": "tironear",
    "tironeia": "tironear",
    "tironeiam": "tironear",
    "tironeias": "tironear",
    "tironeie": "tironear",
    "tironeiem": "tironear",
    "tironeies": "tironear",
    "tironeio": "tironear",
    "tironeou": "tironear",
    "tironeá": "tironear",
    "tironeámo": "tironear",
    "tironeámos": "tironear",
    "tironeáramo": "tironear",
    "tironeáramos": "tironear",
    "tironeárei": "tironear",
    "tironeáreis": "tironear",
    "tironeásseis": "tironear",
    "tironeássemos": "tironear",
    "tironeávamo": "tironear",
    "tironeávamos": "tironear",
    "tironeávei": "tironear",
    "tironeáveis": "tironear",
    "tiros": "tiro",
    "tiroteada": "tirotear",
    "tiroteadas": "tirotear",
    "tiroteado": "tirotear",
    "tiroteados": "tirotear",
    "tiroteai": "tirotear",
    "tiroteais": "tirotear",
    "tiroteamo": "tirotear",
    "tiroteamos": "tirotear",
    "tiroteando": "tirotear",
    "tiroteara": "tirotear",
    "tirotearam": "tirotear",
    "tirotearas": "tirotear",
    "tiroteardes": "tirotear",
    "tirotearei": "tirotear",
    "tiroteareis": "tirotear",
    "tirotearem": "tirotear",
    "tirotearemos": "tirotear",
    "tiroteares": "tirotear",
    "tirotearia": "tirotear",
    "tiroteariam": "tirotear",
    "tirotearias": "tirotear",
    "tirotearmo": "tirotear",
    "tirotearmos": "tirotear",
    "tiroteará": "tirotear",
    "tirotearás": "tirotear",
    "tirotearão": "tirotear",
    "tirotearíamos": "tirotear",
    "tirotearíeis": "tirotear",
    "tiroteasse": "tirotear",
    "tiroteassem": "tirotear",
    "tiroteasses": "tirotear",
    "tiroteaste": "tirotear",
    "tiroteastes": "tirotear",
    "tiroteava": "tirotear",
    "tiroteavam": "tirotear",
    "tiroteavas": "tirotear",
    "tiroteei": "tirotear",
    "tiroteeis": "tirotear",
    "tiroteemo": "tirotear",
    "tiroteemos": "tirotear",
    "tiroteia": "tirotear",
    "tiroteiam": "tirotear",
    "tiroteias": "tirotear",
    "tiroteie": "tirotear",
    "tiroteiem": "tirotear",
    "tiroteies": "tirotear",
    "tiroteio": "tirotear",
    "tiroteios": "tiroteio",
    "tiroteou": "tirotear",
    "tiroteámo": "tirotear",
    "tiroteámos": "tirotear",
    "tiroteáramo": "tirotear",
    "tiroteáramos": "tirotear",
    "tiroteáreis": "tirotear",
    "tiroteásseis": "tirotear",
    "tiroteássemos": "tirotear",
    "tiroteávamo": "tirotear",
    "tiroteávamos": "tirotear",
    "tiroteáveis": "tirotear",
    "tirotomias": "tirotomia",
    "tirou": "tirar",
    "tirrena": "tirreno",
    "tirrenas": "tirreno",
    "tirrenos": "tirreno",
    "tirrénia": "tirrénio",
    "tirrénias": "tirrénio",
    "tirrénios": "tirrénio",
    "tirsenses": "tirsense",
    "tirsos": "tirso",
    "tirsosa": "tirsoso",
    "tirsosas": "tirsoso",
    "tirsosos": "tirsoso",
    "tirsígera": "tirsígero",
    "tirsígeras": "tirsígero",
    "tirsígeros": "tirsígero",
    "tirá": "tirar",
    "tirámo": "tirar",
    "tirámos": "tirar",
    "tiráramo": "tirar",
    "tiráramos": "tirar",
    "tirárei": "tirar",
    "tiráreis": "tirar",
    "tirásseis": "tirar",
    "tirássemos": "tirar",
    "tirávamo": "tirar",
    "tirávamos": "tirar",
    "tirávei": "tirar",
    "tiráveis": "tirar",
    "tirázios": "tirázio",
    "tirânica": "tirânico",
    "tirânicas": "tirânico",
    "tirânicos": "tirânico",
    "tirânidas": "tirânida",
    "tiróides": "tiróide",
    "tirões": "tirão",
    "tis": "til",
    "tisanas": "tisana",
    "tisanuros": "tisanuro",
    "tisialogistas": "tisialogista",
    "tisica": "tisicar",
    "tisicada": "tisicar",
    "tisicadas": "tisicar",
    "tisicado": "tisicar",
    "tisicados": "tisicar",
    "tisicai": "tisicar",
    "tisicais": "tisicar",
    "tisicam": "tisicar",
    "tisicamo": "tisicar",
    "tisicamos": "tisicar",
    "tisicando": "tisicar",
    "tisicara": "tisicar",
    "tisicaram": "tisicar",
    "tisicaras": "tisicar",
    "tisicarde": "tisicar",
    "tisicardes": "tisicar",
    "tisicare": "tisicar",
    "tisicarei": "tisicar",
    "tisicareis": "tisicar",
    "tisicarem": "tisicar",
    "tisicaremos": "tisicar",
    "tisicares": "tisicar",
    "tisicaria": "tisicar",
    "tisicariam": "tisicar",
    "tisicarias": "tisicar",
    "tisicarmo": "tisicar",
    "tisicarmos": "tisicar",
    "tisicará": "tisicar",
    "tisicarás": "tisicar",
    "tisicarão": "tisicar",
    "tisicaríamos": "tisicar",
    "tisicaríeis": "tisicar",
    "tisicas": "tisicar",
    "tisicasse": "tisicar",
    "tisicassem": "tisicar",
    "tisicasses": "tisicar",
    "tisicaste": "tisicar",
    "tisicastes": "tisicar",
    "tisicava": "tisicar",
    "tisicavam": "tisicar",
    "tisicavas": "tisicar",
    "tisico": "tisicar",
    "tisicou": "tisicar",
    "tisicá": "tisicar",
    "tisicámo": "tisicar",
    "tisicámos": "tisicar",
    "tisicáramo": "tisicar",
    "tisicáramos": "tisicar",
    "tisicárei": "tisicar",
    "tisicáreis": "tisicar",
    "tisicásseis": "tisicar",
    "tisicássemos": "tisicar",
    "tisicávamo": "tisicar",
    "tisicávamos": "tisicar",
    "tisicávei": "tisicar",
    "tisicáveis": "tisicar",
    "tisiologias": "tisiologia",
    "tisios": "tisio",
    "tisioterapias": "tisioterapia",
    "tisique": "tisicar",
    "tisiquei": "tisicar",
    "tisiqueis": "tisicar",
    "tisiquem": "tisicar",
    "tisiquemo": "tisicar",
    "tisiquemos": "tisicar",
    "tisiques": "tisicar",
    "tisiólogos": "tisiólogo",
    "tisna": "tisnar",
    "tisnada": "tisnar",
    "tisnadas": "tisnar",
    "tisnado": "tisnar",
    "tisnados": "tisnar",
    "tisnaduras": "tisnadura",
    "tisnai": "tisnar",
    "tisnais": "tisnar",
    "tisnam": "tisnar",
    "tisnamo": "tisnar",
    "tisnamos": "tisnar",
    "tisnando": "tisnar",
    "tisnara": "tisnar",
    "tisnaram": "tisnar",
    "tisnaras": "tisnar",
    "tisnarde": "tisnar",
    "tisnardes": "tisnar",
    "tisnare": "tisnar",
    "tisnarei": "tisnar",
    "tisnareis": "tisnar",
    "tisnarem": "tisnar",
    "tisnaremos": "tisnar",
    "tisnares": "tisnar",
    "tisnaria": "tisnar",
    "tisnariam": "tisnar",
    "tisnarias": "tisnar",
    "tisnarmo": "tisnar",
    "tisnarmos": "tisnar",
    "tisnará": "tisnar",
    "tisnarás": "tisnar",
    "tisnarão": "tisnar",
    "tisnaríamos": "tisnar",
    "tisnaríeis": "tisnar",
    "tisnas": "tisnar",
    "tisnasse": "tisnar",
    "tisnassem": "tisnar",
    "tisnasses": "tisnar",
    "tisnaste": "tisnar",
    "tisnastes": "tisnar",
    "tisnava": "tisnar",
    "tisnavam": "tisnar",
    "tisnavas": "tisnar",
    "tisne": "tisnar",
    "tisnei": "tisnar",
    "tisneiras": "tisneira",
    "tisneis": "tisnar",
    "tisnem": "tisnar",
    "tisnemo": "tisnar",
    "tisnemos": "tisnar",
    "tisnes": "tisne",
    "tisno": "tisnar",
    "tisnou": "tisnar",
    "tisná": "tisnar",
    "tisnámo": "tisnar",
    "tisnámos": "tisnar",
    "tisnáramo": "tisnar",
    "tisnáramos": "tisnar",
    "tisnárei": "tisnar",
    "tisnáreis": "tisnar",
    "tisnásseis": "tisnar",
    "tisnássemos": "tisnar",
    "tisnávamo": "tisnar",
    "tisnávamos": "tisnar",
    "tisnávei": "tisnar",
    "tisnáveis": "tisnar",
    "tisúrias": "tisúria",
    "titanites": "titanite",
    "titanífera": "titanífero",
    "titaníferas": "titanífero",
    "titaníferos": "titanífero",
    "titelas": "titela",
    "titereada": "titerear",
    "titereadas": "titerear",
    "titereado": "titerear",
    "titereados": "titerear",
    "titereai": "titerear",
    "titereais": "titerear",
    "titereamo": "titerear",
    "titereamos": "titerear",
    "titereando": "titerear",
    "titereara": "titerear",
    "titerearam": "titerear",
    "titerearas": "titerear",
    "titereardes": "titerear",
    "titerearei": "titerear",
    "titereareis": "titerear",
    "titerearem": "titerear",
    "titerearemos": "titerear",
    "titereares": "titerear",
    "titerearia": "titerear",
    "titereariam": "titerear",
    "titerearias": "titerear",
    "titerearmo": "titerear",
    "titerearmos": "titerear",
    "titereará": "titerear",
    "titerearás": "titerear",
    "titerearão": "titerear",
    "titerearíamos": "titerear",
    "titerearíeis": "titerear",
    "titereasse": "titerear",
    "titereassem": "titerear",
    "titereasses": "titerear",
    "titereaste": "titerear",
    "titereastes": "titerear",
    "titereava": "titerear",
    "titereavam": "titerear",
    "titereavas": "titerear",
    "titereei": "titerear",
    "titereeis": "titerear",
    "titereemo": "titerear",
    "titereemos": "titerear",
    "titereia": "titerear",
    "titereiam": "titerear",
    "titereias": "titerear",
    "titereie": "titerear",
    "titereiem": "titerear",
    "titereies": "titerear",
    "titereio": "titerear",
    "titereira": "titereiro",
    "titereiras": "titereiro",
    "titereiros": "titereiro",
    "titereou": "titerear",
    "titereámo": "titerear",
    "titereámos": "titerear",
    "titereáramo": "titerear",
    "titereáramos": "titerear",
    "titereáreis": "titerear",
    "titereásseis": "titerear",
    "titereássemos": "titerear",
    "titereávamo": "titerear",
    "titereávamos": "titerear",
    "titereáveis": "titerear",
    "titila": "titilar",
    "titilada": "titilar",
    "titiladas": "titilar",
    "titilado": "titilar",
    "titilados": "titilar",
    "titilai": "titilar",
    "titilais": "titilar",
    "titilam": "titilar",
    "titilamentos": "titilamento",
    "titilamo": "titilar",
    "titilamos": "titilar",
    "titilando": "titilar",
    "titilantes": "titilante",
    "titilara": "titilar",
    "titilaram": "titilar",
    "titilaras": "titilar",
    "titilarde": "titilar",
    "titilardes": "titilar",
    "titilare": "titilar",
    "titilarei": "titilar",
    "titilareis": "titilar",
    "titilarem": "titilar",
    "titilaremos": "titilar",
    "titilares": "titilar",
    "titilaria": "titilar",
    "titilariam": "titilar",
    "titilarias": "titilar",
    "titilarmo": "titilar",
    "titilarmos": "titilar",
    "titilará": "titilar",
    "titilarás": "titilar",
    "titilarão": "titilar",
    "titilaríamos": "titilar",
    "titilaríeis": "titilar",
    "titilas": "titilar",
    "titilasse": "titilar",
    "titilassem": "titilar",
    "titilasses": "titilar",
    "titilaste": "titilar",
    "titilastes": "titilar",
    "titilava": "titilar",
    "titilavam": "titilar",
    "titilavas": "titilar",
    "titilações": "titilação",
    "titile": "titilar",
    "titilei": "titilar",
    "titileis": "titilar",
    "titilem": "titilar",
    "titilemo": "titilar",
    "titilemos": "titilar",
    "titiles": "titilar",
    "titilo": "titilar",
    "titilomanias": "titilomania",
    "titilosa": "titiloso",
    "titilosas": "titiloso",
    "titilosos": "titiloso",
    "titilou": "titilar",
    "titilá": "titilar",
    "titilámo": "titilar",
    "titilámos": "titilar",
    "titiláramo": "titilar",
    "titiláramos": "titilar",
    "titilárei": "titilar",
    "titiláreis": "titilar",
    "titilásseis": "titilar",
    "titilássemos": "titilar",
    "titilávamo": "titilar",
    "titilávamos": "titilar",
    "titilávei": "titilar",
    "titiláveis": "titilar",
    "titis": "titi",
    "titubeada": "titubear",
    "titubeadas": "titubear",
    "titubeado": "titubear",
    "titubeados": "titubear",
    "titubeai": "titubear",
    "titubeais": "titubear",
    "titubeamo": "titubear",
    "titubeamos": "titubear",
    "titubeando": "titubear",
    "titubeantes": "titubeante",
    "titubeara": "titubear",
    "titubearam": "titubear",
    "titubearas": "titubear",
    "titubeardes": "titubear",
    "titubearei": "titubear",
    "titubeareis": "titubear",
    "titubearem": "titubear",
    "titubearemos": "titubear",
    "titubeares": "titubear",
    "titubearia": "titubear",
    "titubeariam": "titubear",
    "titubearias": "titubear",
    "titubearmo": "titubear",
    "titubearmos": "titubear",
    "titubeará": "titubear",
    "titubearás": "titubear",
    "titubearão": "titubear",
    "titubearíamos": "titubear",
    "titubearíeis": "titubear",
    "titubeasse": "titubear",
    "titubeassem": "titubear",
    "titubeasses": "titubear",
    "titubeaste": "titubear",
    "titubeastes": "titubear",
    "titubeava": "titubear",
    "titubeavam": "titubear",
    "titubeavas": "titubear",
    "titubeações": "titubeação",
    "titubeei": "titubear",
    "titubeeis": "titubear",
    "titubeemo": "titubear",
    "titubeemos": "titubear",
    "titubeia": "titubear",
    "titubeiam": "titubear",
    "titubeias": "titubear",
    "titubeie": "titubear",
    "titubeiem": "titubear",
    "titubeies": "titubear",
    "titubeio": "titubear",
    "titubeou": "titubear",
    "titubeámo": "titubear",
    "titubeámos": "titubear",
    "titubeáramo": "titubear",
    "titubeáramos": "titubear",
    "titubeáreis": "titubear",
    "titubeásseis": "titubear",
    "titubeássemos": "titubear",
    "titubeávamo": "titubear",
    "titubeávamos": "titubear",
    "titubeáveis": "titubear",
    "titulada": "titulado",
    "tituladas": "titulado",
    "titulados": "titulado",
    "titulares": "titular",
    "titularidades": "titularidade",
    "titulações": "titulação",
    "titânica": "titânico",
    "titânicas": "titânico",
    "titânicos": "titânico",
    "titânios": "titânio",
    "titãs": "titã",
    "titímalos": "titímalo",
    "titónia": "titónio",
    "titónias": "titónio",
    "titónica": "titónico",
    "titónicas": "titónico",
    "titónicos": "titónico",
    "titónios": "titónio",
    "tiufadias": "tiufadia",
    "tiufados": "tiufado",
    "tive": "ter",
    "tivemo": "ter",
    "tivemos": "ter",
    "tiver": "ter",
    "tivera": "ter",
    "tiveram": "ter",
    "tiveras": "ter",
    "tiverdes": "ter",
    "tiverem": "ter",
    "tiveres": "ter",
    "tivermos": "ter",
    "tivesse": "ter",
    "tivessem": "ter",
    "tivesses": "ter",
    "tiveste": "ter",
    "tivestes": "ter",
    "tivéramo": "ter",
    "tivéramos": "ter",
    "tivérei": "ter",
    "tivéreis": "ter",
    "tivésseis": "ter",
    "tivéssemos": "ter",
    "tixotropias": "tixotropia",
    "tixotrópica": "tixotrópico",
    "tixotrópicas": "tixotrópico",
    "tixotrópicos": "tixotrópico",
    "tiçoadas": "tiçoada",
    "tiçoeiros": "tiçoeiro",
    "tiçonada": "tiçonado",
    "tiçonadas": "tiçonado",
    "tiçonados": "tiçonado",
    "tições": "tição",
    "tiófila": "tiófilo",
    "tiófilas": "tiófilo",
    "tiófilos": "tiófilo",
    "tióis": "tiol",
    "tiónica": "tiónico",
    "tiónicas": "tiónico",
    "tiónicos": "tiónico",
    "tiús": "tiú",
    "tlaspiáceas": "tlaspiácea",
    "tlins": "tlim",
    "tlinta": "tlintar",
    "tlintada": "tlintar",
    "tlintadas": "tlintar",
    "tlintado": "tlintar",
    "tlintados": "tlintar",
    "tlintai": "tlintar",
    "tlintais": "tlintar",
    "tlintam": "tlintar",
    "tlintamo": "tlintar",
    "tlintamos": "tlintar",
    "tlintando": "tlintar",
    "tlintara": "tlintar",
    "tlintaram": "tlintar",
    "tlintaras": "tlintar",
    "tlintardes": "tlintar",
    "tlintarei": "tlintar",
    "tlintareis": "tlintar",
    "tlintarem": "tlintar",
    "tlintaremos": "tlintar",
    "tlintares": "tlintar",
    "tlintaria": "tlintar",
    "tlintariam": "tlintar",
    "tlintarias": "tlintar",
    "tlintarmo": "tlintar",
    "tlintarmos": "tlintar",
    "tlintará": "tlintar",
    "tlintarás": "tlintar",
    "tlintarão": "tlintar",
    "tlintaríamos": "tlintar",
    "tlintaríeis": "tlintar",
    "tlintas": "tlintar",
    "tlintasse": "tlintar",
    "tlintassem": "tlintar",
    "tlintasses": "tlintar",
    "tlintaste": "tlintar",
    "tlintastes": "tlintar",
    "tlintava": "tlintar",
    "tlintavam": "tlintar",
    "tlintavas": "tlintar",
    "tlinte": "tlintar",
    "tlintei": "tlintar",
    "tlinteis": "tlintar",
    "tlintem": "tlintar",
    "tlintemo": "tlintar",
    "tlintemos": "tlintar",
    "tlintes": "tlintar",
    "tlintlins": "tlintlim",
    "tlinto": "tlintar",
    "tlintou": "tlintar",
    "tlintámo": "tlintar",
    "tlintámos": "tlintar",
    "tlintáramo": "tlintar",
    "tlintáramos": "tlintar",
    "tlintáreis": "tlintar",
    "tlintásseis": "tlintar",
    "tlintássemos": "tlintar",
    "tlintávamo": "tlintar",
    "tlintávamos": "tlintar",
    "tlintáveis": "tlintar",
    "tlipsencefalias": "tlipsencefalia",
    "tlipsias": "tlipsia",
    "tmeses": "tmese",
    "toa": "toar",
    "toada": "toar",
    "toadas": "toar",
    "toadilhas": "toadilha",
    "toado": "toar",
    "toados": "toar",
    "toai": "toar",
    "toais": "toar",
    "toalhas": "toalha",
    "toalheiros": "toalheiro",
    "toalhetes": "toalhete",
    "toalhinha": "toalha",
    "toalhinhas": "toalha",
    "toalhita": "toalha",
    "toalhitas": "toalha",
    "toam": "toar",
    "toamo": "toar",
    "toamos": "toar",
    "toando": "toar",
    "toantes": "toante",
    "toara": "toar",
    "toaram": "toar",
    "toaras": "toar",
    "toarciana": "toarciano",
    "toarcianas": "toarciano",
    "toarcianos": "toarciano",
    "toardes": "toar",
    "toarei": "toar",
    "toareis": "toar",
    "toarem": "toar",
    "toaremos": "toar",
    "toares": "toar",
    "toaria": "toar",
    "toariam": "toar",
    "toarias": "toar",
    "toarmo": "toar",
    "toarmos": "toar",
    "toará": "toar",
    "toarás": "toar",
    "toarão": "toar",
    "toaríamos": "toar",
    "toaríeis": "toar",
    "toas": "toar",
    "toasse": "toar",
    "toassem": "toar",
    "toasses": "toar",
    "toaste": "toar",
    "toastes": "toar",
    "toava": "toar",
    "toavam": "toar",
    "toavas": "toar",
    "toca": "tocar",
    "tocada": "tocar",
    "tocadas": "tocar",
    "tocadelas": "tocadela",
    "tocadilhos": "tocadilho",
    "tocado": "tocar",
    "tocadora": "tocador",
    "tocadoras": "tocador",
    "tocadores": "tocador",
    "tocados": "tocar",
    "tocai": "tocar",
    "tocaia": "tocaio",
    "tocaiada": "tocaiar",
    "tocaiadas": "tocaiar",
    "tocaiado": "tocaiar",
    "tocaiados": "tocaiar",
    "tocaiai": "tocaiar",
    "tocaiais": "tocaiar",
    "tocaiam": "tocaiar",
    "tocaiamo": "tocaiar",
    "tocaiamos": "tocaiar",
    "tocaiando": "tocaiar",
    "tocaiara": "tocaiar",
    "tocaiaram": "tocaiar",
    "tocaiaras": "tocaiar",
    "tocaiardes": "tocaiar",
    "tocaiarei": "tocaiar",
    "tocaiareis": "tocaiar",
    "tocaiarem": "tocaiar",
    "tocaiaremos": "tocaiar",
    "tocaiares": "tocaiar",
    "tocaiaria": "tocaiar",
    "tocaiariam": "tocaiar",
    "tocaiarias": "tocaiar",
    "tocaiarmo": "tocaiar",
    "tocaiarmos": "tocaiar",
    "tocaiará": "tocaiar",
    "tocaiarás": "tocaiar",
    "tocaiarão": "tocaiar",
    "tocaiaríamos": "tocaiar",
    "tocaiaríeis": "tocaiar",
    "tocaias": "tocaio",
    "tocaiasse": "tocaiar",
    "tocaiassem": "tocaiar",
    "tocaiasses": "tocaiar",
    "tocaiaste": "tocaiar",
    "tocaiastes": "tocaiar",
    "tocaiava": "tocaiar",
    "tocaiavam": "tocaiar",
    "tocaiavas": "tocaiar",
    "tocaie": "tocaiar",
    "tocaiei": "tocaiar",
    "tocaieis": "tocaiar",
    "tocaiem": "tocaiar",
    "tocaiemo": "tocaiar",
    "tocaiemos": "tocaiar",
    "tocaies": "tocaiar",
    "tocaio": "tocaiar",
    "tocaios": "tocaio",
    "tocaiou": "tocaiar",
    "tocais": "tocar",
    "tocaiámo": "tocaiar",
    "tocaiámos": "tocaiar",
    "tocaiáramo": "tocaiar",
    "tocaiáramos": "tocaiar",
    "tocaiáreis": "tocaiar",
    "tocaiásseis": "tocaiar",
    "tocaiássemos": "tocaiar",
    "tocaiávamo": "tocaiar",
    "tocaiávamos": "tocaiar",
    "tocaiáveis": "tocaiar",
    "tocam": "tocar",
    "tocamo": "tocar",
    "tocamos": "tocar",
    "tocando": "tocar",
    "tocantes": "tocante",
    "tocantima": "tocantim",
    "tocantimas": "tocantim",
    "tocantins": "tocantim",
    "tocara": "tocar",
    "tocaram": "tocar",
    "tocaras": "tocar",
    "tocarde": "tocar",
    "tocardes": "tocar",
    "tocare": "tocar",
    "tocarei": "tocar",
    "tocareis": "tocar",
    "tocarem": "tocar",
    "tocaremos": "tocar",
    "tocares": "tocar",
    "tocaria": "tocar",
    "tocariam": "tocar",
    "tocarias": "tocar",
    "tocarmo": "tocar",
    "tocarmos": "tocar",
    "tocarolas": "tocarola",
    "tocará": "tocar",
    "tocarás": "tocar",
    "tocarão": "tocar",
    "tocaríamos": "tocar",
    "tocaríeis": "tocar",
    "tocas": "tocar",
    "tocasse": "tocar",
    "tocassem": "tocar",
    "tocasses": "tocar",
    "tocaste": "tocar",
    "tocastes": "tocar",
    "tocatas": "tocata",
    "tocatinas": "tocatina",
    "tocava": "tocar",
    "tocavam": "tocar",
    "tocavas": "tocar",
    "tochas": "tocha",
    "tocheiras": "tocheira",
    "tocheiros": "tocheiro",
    "toco": "tocar",
    "tocologias": "tocologia",
    "tocológica": "tocológico",
    "tocológicas": "tocológico",
    "tocológicos": "tocológico",
    "tocomáticos": "tocomático",
    "tocos": "toco",
    "tocou": "tocar",
    "tocá": "tocar",
    "tocámo": "tocar",
    "tocámos": "tocar",
    "tocáramo": "tocar",
    "tocáramos": "tocar",
    "tocárei": "tocar",
    "tocáreis": "tocar",
    "tocásseis": "tocar",
    "tocássemos": "tocar",
    "tocávamo": "tocar",
    "tocávamos": "tocar",
    "tocávei": "tocar",
    "tocáveis": "tocável",
    "tocóstomas": "tocóstoma",
    "toda": "todo",
    "todas": "todo",
    "todeiros": "todeiro",
    "todinha": "todo",
    "todinhas": "todo",
    "todinho": "todo",
    "todinhos": "todo",
    "todos": "todo",
    "todídeos": "todídeo",
    "toe": "toar",
    "toei": "toar",
    "toeiras": "toeira",
    "toeis": "toar",
    "toem": "toar",
    "toemo": "toar",
    "toemos": "toar",
    "toes": "toar",
    "toesas": "toesa",
    "tofos": "tofo",
    "toga": "togar",
    "togada": "togar",
    "togadas": "togar",
    "togado": "togar",
    "togados": "togar",
    "togai": "togar",
    "togais": "togar",
    "togam": "togar",
    "togamo": "togar",
    "togamos": "togar",
    "togando": "togar",
    "togara": "togar",
    "togaram": "togar",
    "togaras": "togar",
    "togarde": "togar",
    "togardes": "togar",
    "togare": "togar",
    "togarei": "togar",
    "togareis": "togar",
    "togarem": "togar",
    "togaremos": "togar",
    "togares": "togar",
    "togaria": "togar",
    "togariam": "togar",
    "togarias": "togar",
    "togarmo": "togar",
    "togarmos": "togar",
    "togará": "togar",
    "togarás": "togar",
    "togarão": "togar",
    "togaríamos": "togar",
    "togaríeis": "togar",
    "togas": "togar",
    "togasse": "togar",
    "togassem": "togar",
    "togasses": "togar",
    "togaste": "togar",
    "togastes": "togar",
    "togava": "togar",
    "togavam": "togar",
    "togavas": "togar",
    "togo": "togar",
    "togou": "togar",
    "togue": "togar",
    "toguei": "togar",
    "togueis": "togar",
    "toguem": "togar",
    "toguemo": "togar",
    "toguemos": "togar",
    "togues": "togar",
    "togá": "togar",
    "togámo": "togar",
    "togámos": "togar",
    "togáramo": "togar",
    "togáramos": "togar",
    "togárei": "togar",
    "togáreis": "togar",
    "togásseis": "togar",
    "togássemos": "togar",
    "togávamo": "togar",
    "togávamos": "togar",
    "togávei": "togar",
    "togáveis": "togar",
    "toiceiras": "toiceira",
    "toicinhos": "toicinho",
    "toilets": "toilet",
    "toilettes": "toilette",
    "toinha": "toa",
    "toinhas": "toa",
    "toira": "toiro",
    "toiradas": "toirada",
    "toirais": "toiral",
    "toiras": "toiro",
    "toireada": "toirear",
    "toireadas": "toirear",
    "toireado": "toirear",
    "toireadores": "toireador",
    "toireados": "toirear",
    "toireai": "toirear",
    "toireais": "toirear",
    "toireamo": "toirear",
    "toireamos": "toirear",
    "toireando": "toirear",
    "toireara": "toirear",
    "toirearam": "toirear",
    "toirearas": "toirear",
    "toirearde": "toirear",
    "toireardes": "toirear",
    "toireare": "toirear",
    "toirearei": "toirear",
    "toireareis": "toirear",
    "toirearem": "toirear",
    "toirearemos": "toirear",
    "toireares": "toirear",
    "toirearia": "toirear",
    "toireariam": "toirear",
    "toirearias": "toirear",
    "toirearmo": "toirear",
    "toirearmos": "toirear",
    "toireará": "toirear",
    "toirearás": "toirear",
    "toirearão": "toirear",
    "toirearíamos": "toirear",
    "toirearíeis": "toirear",
    "toireasse": "toirear",
    "toireassem": "toirear",
    "toireasses": "toirear",
    "toireaste": "toirear",
    "toireastes": "toirear",
    "toireava": "toirear",
    "toireavam": "toirear",
    "toireavas": "toirear",
    "toireei": "toirear",
    "toireeis": "toirear",
    "toireemo": "toirear",
    "toireemos": "toirear",
    "toireia": "toirear",
    "toireiam": "toirear",
    "toireias": "toirear",
    "toireie": "toirear",
    "toireiem": "toirear",
    "toireies": "toirear",
    "toireio": "toirear",
    "toireios": "toireio",
    "toireira": "toireiro",
    "toireiras": "toireiro",
    "toireiros": "toireiro",
    "toireja": "toirejar",
    "toirejada": "toirejar",
    "toirejadas": "toirejar",
    "toirejado": "toirejar",
    "toirejados": "toirejar",
    "toirejai": "toirejar",
    "toirejais": "toirejar",
    "toirejam": "toirejar",
    "toirejamo": "toirejar",
    "toirejamos": "toirejar",
    "toirejando": "toirejar",
    "toirejara": "toirejar",
    "toirejaram": "toirejar",
    "toirejaras": "toirejar",
    "toirejarde": "toirejar",
    "toirejardes": "toirejar",
    "toirejare": "toirejar",
    "toirejarei": "toirejar",
    "toirejareis": "toirejar",
    "toirejarem": "toirejar",
    "toirejaremos": "toirejar",
    "toirejares": "toirejar",
    "toirejaria": "toirejar",
    "toirejariam": "toirejar",
    "toirejarias": "toirejar",
    "toirejarmo": "toirejar",
    "toirejarmos": "toirejar",
    "toirejará": "toirejar",
    "toirejarás": "toirejar",
    "toirejarão": "toirejar",
    "toirejaríamos": "toirejar",
    "toirejaríeis": "toirejar",
    "toirejas": "toirejar",
    "toirejasse": "toirejar",
    "toirejassem": "toirejar",
    "toirejasses": "toirejar",
    "toirejaste": "toirejar",
    "toirejastes": "toirejar",
    "toirejava": "toirejar",
    "toirejavam": "toirejar",
    "toirejavas": "toirejar",
    "toireje": "toirejar",
    "toirejei": "toirejar",
    "toirejeis": "toirejar",
    "toirejem": "toirejar",
    "toirejemo": "toirejar",
    "toirejemos": "toirejar",
    "toirejes": "toirejar",
    "toirejo": "toirejar",
    "toirejou": "toirejar",
    "toirejá": "toirejar",
    "toirejámo": "toirejar",
    "toirejámos": "toirejar",
    "toirejáramo": "toirejar",
    "toirejáramos": "toirejar",
    "toirejárei": "toirejar",
    "toirejáreis": "toirejar",
    "toirejásseis": "toirejar",
    "toirejássemos": "toirejar",
    "toirejávamo": "toirejar",
    "toirejávamos": "toirejar",
    "toirejávei": "toirejar",
    "toirejáveis": "toirejar",
    "toireou": "toirear",
    "toireá": "toirear",
    "toireámo": "toirear",
    "toireámos": "toirear",
    "toireáramo": "toirear",
    "toireáramos": "toirear",
    "toireárei": "toirear",
    "toireáreis": "toirear",
    "toireásseis": "toirear",
    "toireássemos": "toirear",
    "toireávamo": "toirear",
    "toireávamos": "toirear",
    "toireávei": "toirear",
    "toireáveis": "toireável",
    "toiriadora": "toiriador",
    "toiriadoras": "toiriador",
    "toiriadores": "toiriador",
    "toiris": "toiril",
    "toiros": "toiro",
    "toirões": "toirão",
    "toita": "toa",
    "toitas": "toa",
    "toiças": "toiça",
    "tojais": "tojal",
    "tojeiras": "tojeira",
    "tojos": "tojo",
    "tokamaks": "tokamak",
    "tola": "tolo",
    "tolarias": "tolaria",
    "tolas": "tolo",
    "tolazes": "tolaz",
    "tolda": "toldar",
    "toldada": "toldar",
    "toldadas": "toldar",
    "toldado": "toldar",
    "toldados": "toldar",
    "toldai": "toldar",
    "toldais": "toldar",
    "toldam": "toldar",
    "toldamo": "toldar",
    "toldamos": "toldar",
    "toldando": "toldar",
    "toldara": "toldar",
    "toldaram": "toldar",
    "toldaras": "toldar",
    "toldarde": "toldar",
    "toldardes": "toldar",
    "toldare": "toldar",
    "toldarei": "toldar",
    "toldareis": "toldar",
    "toldarem": "toldar",
    "toldaremos": "toldar",
    "toldares": "toldar",
    "toldaria": "toldar",
    "toldariam": "toldar",
    "toldarias": "toldar",
    "toldarmo": "toldar",
    "toldarmos": "toldar",
    "toldará": "toldar",
    "toldarás": "toldar",
    "toldarão": "toldar",
    "toldaríamos": "toldar",
    "toldaríeis": "toldar",
    "toldas": "toldar",
    "toldasse": "toldar",
    "toldassem": "toldar",
    "toldasses": "toldar",
    "toldaste": "toldar",
    "toldastes": "toldar",
    "toldava": "toldar",
    "toldavam": "toldar",
    "toldavas": "toldar",
    "tolde": "toldar",
    "toldei": "toldar",
    "toldeias": "toldeia",
    "toldeis": "toldar",
    "toldem": "toldar",
    "toldemo": "toldar",
    "toldemos": "toldar",
    "toldes": "toldar",
    "toldo": "toldar",
    "toldos": "toldo",
    "toldou": "toldar",
    "toldá": "toldar",
    "toldámo": "toldar",
    "toldámos": "toldar",
    "toldáramo": "toldar",
    "toldáramos": "toldar",
    "toldárei": "toldar",
    "toldáreis": "toldar",
    "toldásseis": "toldar",
    "toldássemos": "toldar",
    "toldávamo": "toldar",
    "toldávamos": "toldar",
    "toldávei": "toldar",
    "toldáveis": "toldar",
    "toledana": "toledano",
    "toledanas": "toledano",
    "toledanos": "toledano",
    "toleimas": "toleima",
    "toleirona": "toleirão",
    "toleironas": "toleirão",
    "toleironazinha": "toleirão",
    "toleironazinhas": "toleirão",
    "toleironazita": "toleirão",
    "toleironazitas": "toleirão",
    "toleirãozinho": "toleirão",
    "toleirãozito": "toleirão",
    "toleirões": "toleirão",
    "toleirõezinhos": "toleirão",
    "toleirõezitos": "toleirão",
    "toleja": "tolejar",
    "tolejada": "tolejar",
    "tolejadas": "tolejar",
    "tolejado": "tolejar",
    "tolejados": "tolejar",
    "tolejai": "tolejar",
    "tolejais": "tolejar",
    "tolejam": "tolejar",
    "tolejamo": "tolejar",
    "tolejamos": "tolejar",
    "tolejando": "tolejar",
    "tolejara": "tolejar",
    "tolejaram": "tolejar",
    "tolejaras": "tolejar",
    "tolejardes": "tolejar",
    "tolejarei": "tolejar",
    "tolejareis": "tolejar",
    "tolejarem": "tolejar",
    "tolejaremos": "tolejar",
    "tolejares": "tolejar",
    "tolejaria": "tolejar",
    "tolejariam": "tolejar",
    "tolejarias": "tolejar",
    "tolejarmo": "tolejar",
    "tolejarmos": "tolejar",
    "tolejará": "tolejar",
    "tolejarás": "tolejar",
    "tolejarão": "tolejar",
    "tolejaríamos": "tolejar",
    "tolejaríeis": "tolejar",
    "tolejas": "tolejar",
    "tolejasse": "tolejar",
    "tolejassem": "tolejar",
    "tolejasses": "tolejar",
    "tolejaste": "tolejar",
    "tolejastes": "tolejar",
    "tolejava": "tolejar",
    "tolejavam": "tolejar",
    "tolejavas": "tolejar",
    "toleje": "tolejar",
    "tolejei": "tolejar",
    "tolejeis": "tolejar",
    "tolejem": "tolejar",
    "tolejemo": "tolejar",
    "tolejemos": "tolejar",
    "tolejes": "tolejar",
    "tolejo": "tolejar",
    "tolejou": "tolejar",
    "tolejámo": "tolejar",
    "tolejámos": "tolejar",
    "tolejáramo": "tolejar",
    "tolejáramos": "tolejar",
    "tolejáreis": "tolejar",
    "tolejásseis": "tolejar",
    "tolejássemos": "tolejar",
    "tolejávamo": "tolejar",
    "tolejávamos": "tolejar",
    "tolejáveis": "tolejar",
    "tolenos": "toleno",
    "tolentiniana": "tolentiniano",
    "tolentinianas": "tolentiniano",
    "tolentinianos": "tolentiniano",
    "tolera": "tolerar",
    "tolerabilidades": "tolerabilidade",
    "tolerada": "tolerar",
    "toleradas": "tolerar",
    "toleradinha": "tolerado",
    "toleradinhas": "tolerado",
    "toleradinho": "tolerado",
    "toleradinhos": "tolerado",
    "toleradita": "tolerado",
    "toleraditas": "tolerado",
    "toleradito": "tolerado",
    "toleraditos": "tolerado",
    "tolerado": "tolerar",
    "tolerados": "tolerar",
    "toleradíssima": "tolerado",
    "toleradíssimas": "tolerado",
    "toleradíssimo": "tolerado",
    "toleradíssimos": "tolerado",
    "tolerai": "tolerar",
    "tolerais": "tolerar",
    "toleram": "tolerar",
    "toleramo": "tolerar",
    "toleramos": "tolerar",
    "tolerando": "tolerar",
    "tolerantes": "tolerante",
    "tolerantismos": "tolerantismo",
    "tolerara": "tolerar",
    "toleraram": "tolerar",
    "toleraras": "tolerar",
    "tolerarde": "tolerar",
    "tolerardes": "tolerar",
    "tolerare": "tolerar",
    "tolerarei": "tolerar",
    "tolerareis": "tolerar",
    "tolerarem": "tolerar",
    "toleraremos": "tolerar",
    "tolerares": "tolerar",
    "toleraria": "tolerar",
    "tolerariam": "tolerar",
    "tolerarias": "tolerar",
    "tolerarmo": "tolerar",
    "tolerarmos": "tolerar",
    "tolerará": "tolerar",
    "tolerarás": "tolerar",
    "tolerarão": "tolerar",
    "toleraríamos": "tolerar",
    "toleraríeis": "tolerar",
    "toleras": "tolerar",
    "tolerasse": "tolerar",
    "tolerassem": "tolerar",
    "tolerasses": "tolerar",
    "toleraste": "tolerar",
    "tolerastes": "tolerar",
    "tolerava": "tolerar",
    "toleravam": "tolerar",
    "toleravas": "tolerar",
    "tolere": "tolerar",
    "tolerei": "tolerar",
    "tolereis": "tolerar",
    "tolerem": "tolerar",
    "toleremo": "tolerar",
    "toleremos": "tolerar",
    "toleres": "tolerar",
    "tolero": "tolerar",
    "tolerou": "tolerar",
    "tolerá": "tolerar",
    "tolerámo": "tolerar",
    "tolerámos": "tolerar",
    "toleráramo": "tolerar",
    "toleráramos": "tolerar",
    "tolerárei": "tolerar",
    "toleráreis": "tolerar",
    "tolerásseis": "tolerar",
    "tolerássemos": "tolerar",
    "tolerávamo": "tolerar",
    "tolerávamos": "tolerar",
    "tolerávei": "tolerar",
    "toleráveis": "tolerável",
    "tolerâncias": "tolerância",
    "toletana": "toletano",
    "toletanas": "toletano",
    "toletanos": "toletano",
    "toletas": "toleta",
    "toleteiras": "toleteira",
    "toletes": "tolete",
    "tolha": "tolher",
    "tolhais": "tolher",
    "tolham": "tolher",
    "tolhamo": "tolher",
    "tolhamos": "tolher",
    "tolhas": "tolher",
    "tolhe": "tolher",
    "tolhedouros": "tolhedouro",
    "tolheduras": "tolhedura",
    "tolhei": "tolher",
    "tolheis": "tolher",
    "tolhem": "tolher",
    "tolhemo": "tolher",
    "tolhemos": "tolher",
    "tolhendo": "tolher",
    "tolhera": "tolher",
    "tolheram": "tolher",
    "tolheras": "tolher",
    "tolherde": "tolher",
    "tolherdes": "tolher",
    "tolhere": "tolher",
    "tolherei": "tolher",
    "tolhereis": "tolher",
    "tolherem": "tolher",
    "tolheremos": "tolher",
    "tolheres": "tolher",
    "tolheria": "tolher",
    "tolheriam": "tolher",
    "tolherias": "tolher",
    "tolhermo": "tolher",
    "tolhermos": "tolher",
    "tolherá": "tolher",
    "tolherás": "tolher",
    "tolherão": "tolher",
    "tolheríamos": "tolher",
    "tolheríeis": "tolher",
    "tolhes": "tolher",
    "tolhesse": "tolher",
    "tolhessem": "tolher",
    "tolhesses": "tolher",
    "tolheste": "tolher",
    "tolhestes": "tolher",
    "tolheu": "tolher",
    "tolhi": "tolher",
    "tolhia": "tolher",
    "tolhiam": "tolher",
    "tolhias": "tolher",
    "tolhida": "tolhido",
    "tolhidas": "tolhido",
    "tolhido": "tolher",
    "tolhidos": "tolhido",
    "tolhimentos": "tolhimento",
    "tolhiços": "tolhiço",
    "tolho": "tolher",
    "tolhos": "tolho",
    "tolhê": "tolher",
    "tolhêramo": "tolher",
    "tolhêramos": "tolher",
    "tolhêrei": "tolher",
    "tolhêreis": "tolher",
    "tolhêsseis": "tolher",
    "tolhêssemos": "tolher",
    "tolhíamo": "tolher",
    "tolhíamos": "tolher",
    "tolhíei": "tolher",
    "tolhíeis": "tolher",
    "tolices": "tolice",
    "tolina": "tolinar",
    "tolinada": "tolinar",
    "tolinadas": "tolinar",
    "tolinado": "tolinar",
    "tolinados": "tolinar",
    "tolinai": "tolinar",
    "tolinais": "tolinar",
    "tolinam": "tolinar",
    "tolinamo": "tolinar",
    "tolinamos": "tolinar",
    "tolinando": "tolinar",
    "tolinara": "tolinar",
    "tolinaram": "tolinar",
    "tolinaras": "tolinar",
    "tolinarde": "tolinar",
    "tolinardes": "tolinar",
    "tolinare": "tolinar",
    "tolinarei": "tolinar",
    "tolinareis": "tolinar",
    "tolinarem": "tolinar",
    "tolinaremos": "tolinar",
    "tolinares": "tolinar",
    "tolinaria": "tolinar",
    "tolinariam": "tolinar",
    "tolinarias": "tolinar",
    "tolinarmo": "tolinar",
    "tolinarmos": "tolinar",
    "tolinará": "tolinar",
    "tolinarás": "tolinar",
    "tolinarão": "tolinar",
    "tolinaríamos": "tolinar",
    "tolinaríeis": "tolinar",
    "tolinas": "tolinar",
    "tolinasse": "tolinar",
    "tolinassem": "tolinar",
    "tolinasses": "tolinar",
    "tolinaste": "tolinar",
    "tolinastes": "tolinar",
    "tolinava": "tolinar",
    "tolinavam": "tolinar",
    "tolinavas": "tolinar",
    "toline": "tolinar",
    "tolinei": "tolinar",
    "tolineira": "tolineiro",
    "tolineiras": "tolineiro",
    "tolineiros": "tolineiro",
    "tolineis": "tolinar",
    "tolinem": "tolinar",
    "tolinemo": "tolinar",
    "tolinemos": "tolinar",
    "tolines": "tolinar",
    "tolinhas": "tolinha",
    "tolino": "tolinar",
    "tolinou": "tolinar",
    "toliná": "tolinar",
    "tolinámo": "tolinar",
    "tolinámos": "tolinar",
    "tolináramo": "tolinar",
    "tolináramos": "tolinar",
    "tolinárei": "tolinar",
    "tolináreis": "tolinar",
    "tolinásseis": "tolinar",
    "tolinássemos": "tolinar",
    "tolinávamo": "tolinar",
    "tolinávamos": "tolinar",
    "tolinávei": "tolinar",
    "tolináveis": "tolinar",
    "tolontros": "tolontro",
    "tolos": "tolo",
    "tolosana": "tolosano",
    "tolosanas": "tolosano",
    "tolosanos": "tolosano",
    "tolstoiismos": "tolstoiismo",
    "tolstoistas": "tolstoista",
    "toluenos": "tolueno",
    "toluica": "toluico",
    "toluicas": "toluico",
    "toluicos": "toluico",
    "toluidinas": "toluidina",
    "tolus": "tolu",
    "toluífera": "toluífero",
    "toluíferas": "toluífero",
    "toluíferos": "toluífero",
    "toluóis": "toluol",
    "tolãs": "tolã",
    "toma": "tomar",
    "tomada": "tomar",
    "tomadas": "tomar",
    "tomadinha": "tomado",
    "tomadinhas": "tomado",
    "tomadinho": "tomado",
    "tomadinhos": "tomado",
    "tomadita": "tomado",
    "tomaditas": "tomado",
    "tomadito": "tomado",
    "tomaditos": "tomado",
    "tomadiça": "tomadiço",
    "tomadiças": "tomadiço",
    "tomadiços": "tomadiço",
    "tomado": "tomar",
    "tomadora": "tomador",
    "tomadoras": "tomador",
    "tomadores": "tomador",
    "tomados": "tomar",
    "tomaduras": "tomadura",
    "tomadíssima": "tomado",
    "tomadíssimas": "tomado",
    "tomadíssimo": "tomado",
    "tomadíssimos": "tomado",
    "tomai": "tomar",
    "tomais": "tomar",
    "tomam": "tomar",
    "tomamo": "tomar",
    "tomamos": "tomar",
    "tomando": "tomar",
    "tomantos": "tomanto",
    "tomara": "tomar",
    "tomaram": "tomar",
    "tomaras": "tomar",
    "tomarde": "tomar",
    "tomardes": "tomar",
    "tomare": "tomar",
    "tomarei": "tomar",
    "tomareis": "tomar",
    "tomarem": "tomar",
    "tomaremos": "tomar",
    "tomarenses": "tomarense",
    "tomares": "tomar",
    "tomaria": "tomar",
    "tomariam": "tomar",
    "tomarias": "tomar",
    "tomarmo": "tomar",
    "tomarmos": "tomar",
    "tomará": "tomar",
    "tomarás": "tomar",
    "tomarão": "tomar",
    "tomaríamos": "tomar",
    "tomaríeis": "tomar",
    "tomas": "tomar",
    "tomasse": "tomar",
    "tomassem": "tomar",
    "tomasses": "tomar",
    "tomaste": "tomar",
    "tomastes": "tomar",
    "tomatadas": "tomatada",
    "tomatais": "tomatal",
    "tomatas": "tomata",
    "tomateiras": "tomateira",
    "tomateiros": "tomateiro",
    "tomates": "tomate",
    "tomava": "tomar",
    "tomavam": "tomar",
    "tomavas": "tomar",
    "tomba": "tombar",
    "tombada": "tombar",
    "tombadas": "tombar",
    "tombadilhos": "tombadilho",
    "tombado": "tombar",
    "tombadora": "tombador",
    "tombadoras": "tombador",
    "tombadores": "tombador",
    "tombados": "tombar",
    "tombai": "tombar",
    "tombais": "tombar",
    "tombam": "tombar",
    "tombamo": "tombar",
    "tombamos": "tombar",
    "tombando": "tombar",
    "tombara": "tombar",
    "tombaram": "tombar",
    "tombaras": "tombar",
    "tombarde": "tombar",
    "tombardes": "tombar",
    "tombare": "tombar",
    "tombarei": "tombar",
    "tombareis": "tombar",
    "tombarem": "tombar",
    "tombaremos": "tombar",
    "tombares": "tombar",
    "tombaria": "tombar",
    "tombariam": "tombar",
    "tombarias": "tombar",
    "tombarmo": "tombar",
    "tombarmos": "tombar",
    "tombará": "tombar",
    "tombarás": "tombar",
    "tombarão": "tombar",
    "tombaríamos": "tombar",
    "tombaríeis": "tombar",
    "tombas": "tombar",
    "tombasse": "tombar",
    "tombassem": "tombar",
    "tombasses": "tombar",
    "tombaste": "tombar",
    "tombastes": "tombar",
    "tombava": "tombar",
    "tombavam": "tombar",
    "tombavas": "tombar",
    "tombe": "tombar",
    "tombei": "tombar",
    "tombeis": "tombar",
    "tombem": "tombar",
    "tombemo": "tombar",
    "tombemos": "tombar",
    "tombes": "tombar",
    "tombo": "tombar",
    "tombola": "tombolar",
    "tombolada": "tombolar",
    "tomboladas": "tombolar",
    "tombolado": "tombolar",
    "tombolados": "tombolar",
    "tombolai": "tombolar",
    "tombolais": "tombolar",
    "tombolam": "tombolar",
    "tombolamo": "tombolar",
    "tombolamos": "tombolar",
    "tombolando": "tombolar",
    "tombolara": "tombolar",
    "tombolaram": "tombolar",
    "tombolaras": "tombolar",
    "tombolardes": "tombolar",
    "tombolarei": "tombolar",
    "tombolareis": "tombolar",
    "tombolarem": "tombolar",
    "tombolaremos": "tombolar",
    "tombolares": "tombolar",
    "tombolaria": "tombolar",
    "tombolariam": "tombolar",
    "tombolarias": "tombolar",
    "tombolarmo": "tombolar",
    "tombolarmos": "tombolar",
    "tombolará": "tombolar",
    "tombolarás": "tombolar",
    "tombolarão": "tombolar",
    "tombolaríamos": "tombolar",
    "tombolaríeis": "tombolar",
    "tombolas": "tombolar",
    "tombolasse": "tombolar",
    "tombolassem": "tombolar",
    "tombolasses": "tombolar",
    "tombolaste": "tombolar",
    "tombolastes": "tombolar",
    "tombolava": "tombolar",
    "tombolavam": "tombolar",
    "tombolavas": "tombolar",
    "tombole": "tombolar",
    "tombolei": "tombolar",
    "tomboleis": "tombolar",
    "tombolem": "tombolar",
    "tombolemo": "tombolar",
    "tombolemos": "tombolar",
    "tomboles": "tombolar",
    "tombolo": "tombolar",
    "tombolou": "tombolar",
    "tombolámo": "tombolar",
    "tombolámos": "tombolar",
    "tomboláramo": "tombolar",
    "tomboláramos": "tombolar",
    "tomboláreis": "tombolar",
    "tombolásseis": "tombolar",
    "tombolássemos": "tombolar",
    "tombolávamo": "tombolar",
    "tombolávamos": "tombolar",
    "tomboláveis": "tombolar",
    "tombos": "tombo",
    "tombou": "tombar",
    "tombá": "tombar",
    "tombámo": "tombar",
    "tombámos": "tombar",
    "tombáramo": "tombar",
    "tombáramos": "tombar",
    "tombárei": "tombar",
    "tombáreis": "tombar",
    "tombásseis": "tombar",
    "tombássemos": "tombar",
    "tombávamo": "tombar",
    "tombávamos": "tombar",
    "tombávei": "tombar",
    "tombáveis": "tombar",
    "tome": "tomar",
    "tomei": "tomar",
    "tomeis": "tomar",
    "tomem": "tomar",
    "tomemo": "tomar",
    "tomemos": "tomar",
    "tomenses": "tomense",
    "tomentelhos": "tomentelho",
    "tomentelos": "tomentelo",
    "tomentilhos": "tomentilho",
    "tomentosa": "tomentoso",
    "tomentosas": "tomentoso",
    "tomentosos": "tomentoso",
    "tomes": "tomar",
    "tomilhais": "tomilhal",
    "tomilhinhas": "tomilhinha",
    "tomilhos": "tomilho",
    "tomismos": "tomismo",
    "tomistas": "tomista",
    "tomo": "tomar",
    "tomografias": "tomografia",
    "tomos": "tomo",
    "tomou": "tomar",
    "tomá": "tomar",
    "tomámo": "tomar",
    "tomámos": "tomar",
    "tomáramo": "tomar",
    "tomáramos": "tomar",
    "tomárei": "tomar",
    "tomáreis": "tomar",
    "tomásseis": "tomar",
    "tomássemos": "tomar",
    "tomávamo": "tomar",
    "tomávamos": "tomar",
    "tomávei": "tomar",
    "tomáveis": "tomar",
    "tona": "tonar",
    "tonada": "tonar",
    "tonadas": "tonar",
    "tonadilhas": "tonadilha",
    "tonado": "tonar",
    "tonados": "tonar",
    "tonai": "tonar",
    "tonais": "tonar",
    "tonalidades": "tonalidade",
    "tonalilitos": "tonalilito",
    "tonaliza": "tonalizar",
    "tonalizada": "tonalizar",
    "tonalizadas": "tonalizar",
    "tonalizado": "tonalizar",
    "tonalizados": "tonalizar",
    "tonalizai": "tonalizar",
    "tonalizais": "tonalizar",
    "tonalizam": "tonalizar",
    "tonalizamo": "tonalizar",
    "tonalizamos": "tonalizar",
    "tonalizando": "tonalizar",
    "tonalizara": "tonalizar",
    "tonalizaram": "tonalizar",
    "tonalizaras": "tonalizar",
    "tonalizarde": "tonalizar",
    "tonalizardes": "tonalizar",
    "tonalizare": "tonalizar",
    "tonalizarei": "tonalizar",
    "tonalizareis": "tonalizar",
    "tonalizarem": "tonalizar",
    "tonalizaremos": "tonalizar",
    "tonalizares": "tonalizar",
    "tonalizaria": "tonalizar",
    "tonalizariam": "tonalizar",
    "tonalizarias": "tonalizar",
    "tonalizarmo": "tonalizar",
    "tonalizarmos": "tonalizar",
    "tonalizará": "tonalizar",
    "tonalizarás": "tonalizar",
    "tonalizarão": "tonalizar",
    "tonalizaríamos": "tonalizar",
    "tonalizaríeis": "tonalizar",
    "tonalizas": "tonalizar",
    "tonalizasse": "tonalizar",
    "tonalizassem": "tonalizar",
    "tonalizasses": "tonalizar",
    "tonalizaste": "tonalizar",
    "tonalizastes": "tonalizar",
    "tonalizava": "tonalizar",
    "tonalizavam": "tonalizar",
    "tonalizavas": "tonalizar",
    "tonalize": "tonalizar",
    "tonalizei": "tonalizar",
    "tonalizeis": "tonalizar",
    "tonalizem": "tonalizar",
    "tonalizemo": "tonalizar",
    "tonalizemos": "tonalizar",
    "tonalizes": "tonalizar",
    "tonalizo": "tonalizar",
    "tonalizou": "tonalizar",
    "tonalizá": "tonalizar",
    "tonalizámo": "tonalizar",
    "tonalizámos": "tonalizar",
    "tonalizáramo": "tonalizar",
    "tonalizáramos": "tonalizar",
    "tonalizárei": "tonalizar",
    "tonalizáreis": "tonalizar",
    "tonalizásseis": "tonalizar",
    "tonalizássemos": "tonalizar",
    "tonalizávamo": "tonalizar",
    "tonalizávamos": "tonalizar",
    "tonalizávei": "tonalizar",
    "tonalizáveis": "tonalizar",
    "tonam": "tonar",
    "tonamo": "tonar",
    "tonamos": "tonar",
    "tonando": "tonar",
    "tonantes": "tonante",
    "tonara": "tonar",
    "tonaram": "tonar",
    "tonaras": "tonar",
    "tonardes": "tonar",
    "tonarei": "tonar",
    "tonareis": "tonar",
    "tonarem": "tonar",
    "tonaremos": "tonar",
    "tonares": "tonar",
    "tonaria": "tonar",
    "tonariam": "tonar",
    "tonarias": "tonar",
    "tonarmo": "tonar",
    "tonarmos": "tonar",
    "tonará": "tonar",
    "tonarás": "tonar",
    "tonarão": "tonar",
    "tonaríamos": "tonar",
    "tonaríeis": "tonar",
    "tonas": "tonar",
    "tonasse": "tonar",
    "tonassem": "tonar",
    "tonasses": "tonar",
    "tonaste": "tonar",
    "tonastes": "tonar",
    "tonava": "tonar",
    "tonavam": "tonar",
    "tonavas": "tonar",
    "tondelenses": "tondelense",
    "tondinhos": "tondinho",
    "tone": "tonar",
    "tonei": "tonar",
    "toneis": "tonel",
    "toneladas": "tonelada",
    "tonelagens": "tonelagem",
    "tonelarias": "tonelaria",
    "toneletes": "tonelete",
    "tonem": "tonar",
    "tonemo": "tonar",
    "tonemos": "tonar",
    "tones": "tone",
    "tonfes": "tonfe",
    "tongrianos": "tongriano",
    "tonias": "tonia",
    "tonicidades": "tonicidade",
    "tonifica": "tonificar",
    "tonificada": "tonificar",
    "tonificadas": "tonificar",
    "tonificado": "tonificar",
    "tonificadora": "tonificador",
    "tonificadoras": "tonificador",
    "tonificadores": "tonificador",
    "tonificados": "tonificar",
    "tonificai": "tonificar",
    "tonificais": "tonificar",
    "tonificam": "tonificar",
    "tonificamo": "tonificar",
    "tonificamos": "tonificar",
    "tonificando": "tonificar",
    "tonificantes": "tonificante",
    "tonificara": "tonificar",
    "tonificaram": "tonificar",
    "tonificaras": "tonificar",
    "tonificarde": "tonificar",
    "tonificardes": "tonificar",
    "tonificare": "tonificar",
    "tonificarei": "tonificar",
    "tonificareis": "tonificar",
    "tonificarem": "tonificar",
    "tonificaremos": "tonificar",
    "tonificares": "tonificar",
    "tonificaria": "tonificar",
    "tonificariam": "tonificar",
    "tonificarias": "tonificar",
    "tonificarmo": "tonificar",
    "tonificarmos": "tonificar",
    "tonificará": "tonificar",
    "tonificarás": "tonificar",
    "tonificarão": "tonificar",
    "tonificaríamos": "tonificar",
    "tonificaríeis": "tonificar",
    "tonificas": "tonificar",
    "tonificasse": "tonificar",
    "tonificassem": "tonificar",
    "tonificasses": "tonificar",
    "tonificaste": "tonificar",
    "tonificastes": "tonificar",
    "tonificava": "tonificar",
    "tonificavam": "tonificar",
    "tonificavas": "tonificar",
    "tonificações": "tonificação",
    "tonifico": "tonificar",
    "tonificou": "tonificar",
    "tonificá": "tonificar",
    "tonificámo": "tonificar",
    "tonificámos": "tonificar",
    "tonificáramo": "tonificar",
    "tonificáramos": "tonificar",
    "tonificárei": "tonificar",
    "tonificáreis": "tonificar",
    "tonificásseis": "tonificar",
    "tonificássemos": "tonificar",
    "tonificávamo": "tonificar",
    "tonificávamos": "tonificar",
    "tonificávei": "tonificar",
    "tonificáveis": "tonificar",
    "tonifique": "tonificar",
    "tonifiquei": "tonificar",
    "tonifiqueis": "tonificar",
    "tonifiquem": "tonificar",
    "tonifiquemo": "tonificar",
    "tonifiquemos": "tonificar",
    "tonifiques": "tonificar",
    "tonilhos": "tonilho",
    "toninas": "tonina",
    "toninhas": "toninha",
    "toninhos": "toninho",
    "tonismos": "tonismo",
    "tonitrua": "tonitruo",
    "tonitruada": "tonitruar",
    "tonitruadas": "tonitruar",
    "tonitruado": "tonitruar",
    "tonitruados": "tonitruar",
    "tonitruai": "tonitruar",
    "tonitruais": "tonitruar",
    "tonitruam": "tonitruar",
    "tonitruamo": "tonitruar",
    "tonitruamos": "tonitruar",
    "tonitruando": "tonitruar",
    "tonitruantes": "tonitruante",
    "tonitruara": "tonitruar",
    "tonitruaram": "tonitruar",
    "tonitruaras": "tonitruar",
    "tonitruardes": "tonitruar",
    "tonitruarei": "tonitruar",
    "tonitruareis": "tonitruar",
    "tonitruarem": "tonitruar",
    "tonitruaremos": "tonitruar",
    "tonitruares": "tonitruar",
    "tonitruaria": "tonitruar",
    "tonitruariam": "tonitruar",
    "tonitruarias": "tonitruar",
    "tonitruarmo": "tonitruar",
    "tonitruarmos": "tonitruar",
    "tonitruará": "tonitruar",
    "tonitruarás": "tonitruar",
    "tonitruarão": "tonitruar",
    "tonitruaríamos": "tonitruar",
    "tonitruaríeis": "tonitruar",
    "tonitruas": "tonitruo",
    "tonitruasse": "tonitruar",
    "tonitruassem": "tonitruar",
    "tonitruasses": "tonitruar",
    "tonitruaste": "tonitruar",
    "tonitruastes": "tonitruar",
    "tonitruava": "tonitruar",
    "tonitruavam": "tonitruar",
    "tonitruavas": "tonitruar",
    "tonitrue": "tonitruar",
    "tonitruei": "tonitruar",
    "tonitrueis": "tonitruar",
    "tonitruem": "tonitruar",
    "tonitruemo": "tonitruar",
    "tonitruemos": "tonitruar",
    "tonitrues": "tonitruar",
    "tonitruo": "tonitruar",
    "tonitruos": "tonitruo",
    "tonitruosa": "tonitruoso",
    "tonitruosas": "tonitruoso",
    "tonitruosos": "tonitruoso",
    "tonitruou": "tonitruar",
    "tonitruámo": "tonitruar",
    "tonitruámos": "tonitruar",
    "tonitruáramo": "tonitruar",
    "tonitruáramos": "tonitruar",
    "tonitruáreis": "tonitruar",
    "tonitruásseis": "tonitruar",
    "tonitruássemos": "tonitruar",
    "tonitruávamo": "tonitruar",
    "tonitruávamos": "tonitruar",
    "tonitruáveis": "tonitruar",
    "tono": "tonar",
    "tonoas": "tonoa",
    "tonometrias": "tonometria",
    "tonometros": "tonometro",
    "tonos": "tono",
    "tonotecnias": "tonotecnia",
    "tonou": "tonar",
    "tonquinesa": "tonquinês",
    "tonquinesas": "tonquinês",
    "tonquineses": "tonquinês",
    "tonquins": "tonquim",
    "tons": "tom",
    "tonsilas": "tonsila",
    "tonsilites": "tonsilite",
    "tonsura": "tonsurar",
    "tonsurada": "tonsurar",
    "tonsuradas": "tonsurar",
    "tonsurado": "tonsurar",
    "tonsurados": "tonsurar",
    "tonsurai": "tonsurar",
    "tonsurais": "tonsurar",
    "tonsuram": "tonsurar",
    "tonsuramo": "tonsurar",
    "tonsuramos": "tonsurar",
    "tonsurando": "tonsurar",
    "tonsurara": "tonsurar",
    "tonsuraram": "tonsurar",
    "tonsuraras": "tonsurar",
    "tonsurarde": "tonsurar",
    "tonsurardes": "tonsurar",
    "tonsurare": "tonsurar",
    "tonsurarei": "tonsurar",
    "tonsurareis": "tonsurar",
    "tonsurarem": "tonsurar",
    "tonsuraremos": "tonsurar",
    "tonsurares": "tonsurar",
    "tonsuraria": "tonsurar",
    "tonsurariam": "tonsurar",
    "tonsurarias": "tonsurar",
    "tonsurarmo": "tonsurar",
    "tonsurarmos": "tonsurar",
    "tonsurará": "tonsurar",
    "tonsurarás": "tonsurar",
    "tonsurarão": "tonsurar",
    "tonsuraríamos": "tonsurar",
    "tonsuraríeis": "tonsurar",
    "tonsuras": "tonsurar",
    "tonsurasse": "tonsurar",
    "tonsurassem": "tonsurar",
    "tonsurasses": "tonsurar",
    "tonsuraste": "tonsurar",
    "tonsurastes": "tonsurar",
    "tonsurava": "tonsurar",
    "tonsuravam": "tonsurar",
    "tonsuravas": "tonsurar",
    "tonsure": "tonsurar",
    "tonsurei": "tonsurar",
    "tonsureis": "tonsurar",
    "tonsurem": "tonsurar",
    "tonsuremo": "tonsurar",
    "tonsuremos": "tonsurar",
    "tonsures": "tonsurar",
    "tonsuro": "tonsurar",
    "tonsurou": "tonsurar",
    "tonsurá": "tonsurar",
    "tonsurámo": "tonsurar",
    "tonsurámos": "tonsurar",
    "tonsuráramo": "tonsurar",
    "tonsuráramos": "tonsurar",
    "tonsurárei": "tonsurar",
    "tonsuráreis": "tonsurar",
    "tonsurásseis": "tonsurar",
    "tonsurássemos": "tonsurar",
    "tonsurávamo": "tonsurar",
    "tonsurávamos": "tonsurar",
    "tonsurávei": "tonsurar",
    "tonsuráveis": "tonsurar",
    "tonta": "tonto",
    "tontarias": "tontaria",
    "tontas": "tonto",
    "tontazinha": "tonto",
    "tontazinhas": "tonto",
    "tontazita": "tonto",
    "tontazitas": "tonto",
    "tonteada": "tontear",
    "tonteadas": "tontear",
    "tonteado": "tontear",
    "tonteados": "tontear",
    "tonteai": "tontear",
    "tonteais": "tontear",
    "tonteamo": "tontear",
    "tonteamos": "tontear",
    "tonteando": "tontear",
    "tonteara": "tontear",
    "tontearam": "tontear",
    "tontearas": "tontear",
    "tonteardes": "tontear",
    "tontearei": "tontear",
    "tonteareis": "tontear",
    "tontearem": "tontear",
    "tontearemos": "tontear",
    "tonteares": "tontear",
    "tontearia": "tontear",
    "tonteariam": "tontear",
    "tontearias": "tontear",
    "tontearmo": "tontear",
    "tontearmos": "tontear",
    "tonteará": "tontear",
    "tontearás": "tontear",
    "tontearão": "tontear",
    "tontearíamos": "tontear",
    "tontearíeis": "tontear",
    "tonteasse": "tontear",
    "tonteassem": "tontear",
    "tonteasses": "tontear",
    "tonteaste": "tontear",
    "tonteastes": "tontear",
    "tonteava": "tontear",
    "tonteavam": "tontear",
    "tonteavas": "tontear",
    "tonteei": "tontear",
    "tonteeis": "tontear",
    "tonteemo": "tontear",
    "tonteemos": "tontear",
    "tonteia": "tontear",
    "tonteiam": "tontear",
    "tonteias": "tontear",
    "tonteie": "tontear",
    "tonteiem": "tontear",
    "tonteies": "tontear",
    "tonteio": "tontear",
    "tonteiras": "tonteira",
    "tonteou": "tontear",
    "tonteámo": "tontear",
    "tonteámos": "tontear",
    "tonteáramo": "tontear",
    "tonteáramos": "tontear",
    "tonteáreis": "tontear",
    "tonteásseis": "tontear",
    "tonteássemos": "tontear",
    "tonteávamo": "tontear",
    "tonteávamos": "tontear",
    "tonteáveis": "tontear",
    "tontices": "tontice",
    "tontinas": "tontina",
    "tontinha": "tonto",
    "tontinhas": "tonto",
    "tontinho": "tonto",
    "tontinhos": "tonto",
    "tontita": "tonto",
    "tontitas": "tonto",
    "tontito": "tonto",
    "tontitos": "tonto",
    "tontos": "tonto",
    "tontozinho": "tonto",
    "tontozinhos": "tonto",
    "tontozito": "tonto",
    "tontozitos": "tonto",
    "tonturas": "tontura",
    "tonámo": "tonar",
    "tonámos": "tonar",
    "tonáramo": "tonar",
    "tonáramos": "tonar",
    "tonáreis": "tonar",
    "tonários": "tonário",
    "tonásseis": "tonar",
    "tonássemos": "tonar",
    "tonávamo": "tonar",
    "tonávamos": "tonar",
    "tonáveis": "tonar",
    "too": "toar",
    "toou": "toar",
    "topa": "topar",
    "topada": "topar",
    "topadas": "topar",
    "topado": "topar",
    "topados": "topar",
    "topai": "topar",
    "topais": "topar",
    "topam": "topar",
    "topamo": "topar",
    "topamos": "topar",
    "topando": "topar",
    "topara": "topar",
    "toparam": "topar",
    "toparas": "topar",
    "toparcas": "toparca",
    "toparde": "topar",
    "topardes": "topar",
    "topare": "topar",
    "toparei": "topar",
    "topareis": "topar",
    "toparem": "topar",
    "toparemos": "topar",
    "topares": "topar",
    "toparia": "topar",
    "topariam": "topar",
    "toparias": "topar",
    "toparmo": "topar",
    "toparmos": "topar",
    "toparquias": "toparquia",
    "topará": "topar",
    "toparás": "topar",
    "toparão": "topar",
    "toparíamos": "topar",
    "toparíeis": "topar",
    "topas": "topar",
    "topasse": "topar",
    "topassem": "topar",
    "topasses": "topar",
    "topaste": "topar",
    "topastes": "topar",
    "topava": "topar",
    "topavam": "topar",
    "topavas": "topar",
    "topazes": "topaz",
    "tope": "topar",
    "topei": "topar",
    "topeis": "topar",
    "topeja": "topejar",
    "topejada": "topejar",
    "topejadas": "topejar",
    "topejadeiras": "topejadeira",
    "topejado": "topejar",
    "topejados": "topejar",
    "topejai": "topejar",
    "topejais": "topejar",
    "topejam": "topejar",
    "topejamo": "topejar",
    "topejamos": "topejar",
    "topejando": "topejar",
    "topejara": "topejar",
    "topejaram": "topejar",
    "topejaras": "topejar",
    "topejarde": "topejar",
    "topejardes": "topejar",
    "topejare": "topejar",
    "topejarei": "topejar",
    "topejareis": "topejar",
    "topejarem": "topejar",
    "topejaremos": "topejar",
    "topejares": "topejar",
    "topejaria": "topejar",
    "topejariam": "topejar",
    "topejarias": "topejar",
    "topejarmo": "topejar",
    "topejarmos": "topejar",
    "topejará": "topejar",
    "topejarás": "topejar",
    "topejarão": "topejar",
    "topejaríamos": "topejar",
    "topejaríeis": "topejar",
    "topejas": "topejar",
    "topejasse": "topejar",
    "topejassem": "topejar",
    "topejasses": "topejar",
    "topejaste": "topejar",
    "topejastes": "topejar",
    "topejava": "topejar",
    "topejavam": "topejar",
    "topejavas": "topejar",
    "topeje": "topejar",
    "topejei": "topejar",
    "topejeis": "topejar",
    "topejem": "topejar",
    "topejemo": "topejar",
    "topejemos": "topejar",
    "topejes": "topejar",
    "topejo": "topejar",
    "topejou": "topejar",
    "topejá": "topejar",
    "topejámo": "topejar",
    "topejámos": "topejar",
    "topejáramo": "topejar",
    "topejáramos": "topejar",
    "topejárei": "topejar",
    "topejáreis": "topejar",
    "topejásseis": "topejar",
    "topejássemos": "topejar",
    "topejávamo": "topejar",
    "topejávamos": "topejar",
    "topejávei": "topejar",
    "topejáveis": "topejar",
    "topem": "topar",
    "topemo": "topar",
    "topemos": "topar",
    "topes": "tope",
    "topeta": "topetar",
    "topetada": "topetar",
    "topetadas": "topetar",
    "topetado": "topetar",
    "topetados": "topetar",
    "topetai": "topetar",
    "topetais": "topetar",
    "topetam": "topetar",
    "topetamo": "topetar",
    "topetamos": "topetar",
    "topetando": "topetar",
    "topetara": "topetar",
    "topetaram": "topetar",
    "topetaras": "topetar",
    "topetarde": "topetar",
    "topetardes": "topetar",
    "topetare": "topetar",
    "topetarei": "topetar",
    "topetareis": "topetar",
    "topetarem": "topetar",
    "topetaremos": "topetar",
    "topetares": "topetar",
    "topetaria": "topetar",
    "topetariam": "topetar",
    "topetarias": "topetar",
    "topetarmo": "topetar",
    "topetarmos": "topetar",
    "topetará": "topetar",
    "topetarás": "topetar",
    "topetarão": "topetar",
    "topetaríamos": "topetar",
    "topetaríeis": "topetar",
    "topetas": "topetar",
    "topetasse": "topetar",
    "topetassem": "topetar",
    "topetasses": "topetar",
    "topetaste": "topetar",
    "topetastes": "topetar",
    "topetava": "topetar",
    "topetavam": "topetar",
    "topetavas": "topetar",
    "topete": "topetar",
    "topetei": "topetar",
    "topeteiras": "topeteira",
    "topeteis": "topetar",
    "topetem": "topetar",
    "topetemo": "topetar",
    "topetemos": "topetar",
    "topetes": "topete",
    "topeto": "topetar",
    "topetou": "topetar",
    "topetá": "topetar",
    "topetámo": "topetar",
    "topetámos": "topetar",
    "topetáramo": "topetar",
    "topetáramos": "topetar",
    "topetárei": "topetar",
    "topetáreis": "topetar",
    "topetásseis": "topetar",
    "topetássemos": "topetar",
    "topetávamo": "topetar",
    "topetávamos": "topetar",
    "topetávei": "topetar",
    "topetáveis": "topetar",
    "topiarias": "topiaria",
    "topinambos": "topinambo",
    "topinha": "topinho",
    "topinhas": "topinho",
    "topinhos": "topinho",
    "topiárias": "topiária",
    "toplesses": "topless",
    "topo": "topar",
    "topoalgias": "topoalgia",
    "topofilias": "topofilia",
    "topofobias": "topofobia",
    "topografa": "topografar",
    "topografada": "topografar",
    "topografadas": "topografar",
    "topografado": "topografar",
    "topografados": "topografar",
    "topografai": "topografar",
    "topografais": "topografar",
    "topografam": "topografar",
    "topografamo": "topografar",
    "topografamos": "topografar",
    "topografando": "topografar",
    "topografara": "topografar",
    "topografaram": "topografar",
    "topografaras": "topografar",
    "topografarde": "topografar",
    "topografardes": "topografar",
    "topografare": "topografar",
    "topografarei": "topografar",
    "topografareis": "topografar",
    "topografarem": "topografar",
    "topografaremos": "topografar",
    "topografares": "topografar",
    "topografaria": "topografar",
    "topografariam": "topografar",
    "topografarias": "topografar",
    "topografarmo": "topografar",
    "topografarmos": "topografar",
    "topografará": "topografar",
    "topografarás": "topografar",
    "topografarão": "topografar",
    "topografaríamos": "topografar",
    "topografaríeis": "topografar",
    "topografas": "topografar",
    "topografasse": "topografar",
    "topografassem": "topografar",
    "topografasses": "topografar",
    "topografaste": "topografar",
    "topografastes": "topografar",
    "topografava": "topografar",
    "topografavam": "topografar",
    "topografavas": "topografar",
    "topografe": "topografar",
    "topografei": "topografar",
    "topografeis": "topografar",
    "topografem": "topografar",
    "topografemo": "topografar",
    "topografemos": "topografar",
    "topografes": "topografar",
    "topografias": "topografia",
    "topografo": "topografar",
    "topografou": "topografar",
    "topografá": "topografar",
    "topografámo": "topografar",
    "topografámos": "topografar",
    "topografáramo": "topografar",
    "topografáramos": "topografar",
    "topografárei": "topografar",
    "topografáreis": "topografar",
    "topografásseis": "topografar",
    "topografássemos": "topografar",
    "topografávamo": "topografar",
    "topografávamos": "topografar",
    "topografávei": "topografar",
    "topografáveis": "topografar",
    "topográfica": "topográfico",
    "topográficas": "topográfico",
    "topográficos": "topográfico",
    "topologias": "topologia",
    "topológica": "topológico",
    "topológicas": "topológico",
    "topológicos": "topológico",
    "toponomástica": "toponomástico",
    "toponomásticas": "toponomástico",
    "toponomásticos": "toponomástico",
    "topononásticas": "topononástica",
    "toponímias": "toponímia",
    "toponímica": "toponímico",
    "toponímicas": "toponímico",
    "toponímicos": "toponímico",
    "topos": "topo",
    "topou": "topar",
    "tops": "top",
    "topá": "topar",
    "topámo": "topar",
    "topámos": "topar",
    "topáramo": "topar",
    "topáramos": "topar",
    "topárei": "topar",
    "topáreis": "topar",
    "topásseis": "topar",
    "topássemos": "topar",
    "topávamo": "topar",
    "topávamos": "topar",
    "topávei": "topar",
    "topáveis": "topar",
    "topázios": "topázio",
    "topófila": "topófilo",
    "topófilas": "topófilo",
    "topófilos": "topófilo",
    "topófoba": "topófobo",
    "topófobas": "topófobo",
    "topófobos": "topófobo",
    "topógrafa": "topógrafo",
    "topógrafas": "topógrafo",
    "topógrafos": "topógrafo",
    "topónimos": "topónimo",
    "toque": "tocar",
    "toquei": "tocar",
    "toqueiras": "toqueira",
    "toqueiros": "toqueiro",
    "toqueis": "tocar",
    "toquem": "tocar",
    "toquemo": "tocar",
    "toquemos": "tocar",
    "toques": "toque",
    "toquezinho": "toque",
    "toquezinhos": "toque",
    "toquezito": "toque",
    "toquezitos": "toque",
    "tora": "torar",
    "toracadelfias": "toracadelfia",
    "toracadelfos": "toracadelfo",
    "toracenteses": "toracentese",
    "toraces": "torace",
    "toracocenteses": "toracocentese",
    "toracofaciais": "toracofacial",
    "toracolombares": "toracolombar",
    "toracoplastias": "toracoplastia",
    "toracoscopias": "toracoscopia",
    "toracotomias": "toracotomia",
    "torada": "torar",
    "toradas": "torar",
    "toradelfias": "toradelfia",
    "toradelfos": "toradelfo",
    "torado": "torar",
    "torados": "torar",
    "torai": "torar",
    "torais": "torar",
    "toram": "torar",
    "toramo": "torar",
    "toramos": "torar",
    "torando": "torar",
    "toranjas": "toranja",
    "toranjeiras": "toranjeira",
    "torara": "torar",
    "toraram": "torar",
    "toraras": "torar",
    "torarde": "torar",
    "torardes": "torar",
    "torare": "torar",
    "torarei": "torar",
    "torareis": "torar",
    "torarem": "torar",
    "toraremos": "torar",
    "torares": "torar",
    "toraria": "torar",
    "torariam": "torar",
    "torarias": "torar",
    "torarmo": "torar",
    "torarmos": "torar",
    "torará": "torar",
    "torarás": "torar",
    "torarão": "torar",
    "toraríamos": "torar",
    "toraríeis": "torar",
    "toras": "torar",
    "torasse": "torar",
    "torassem": "torar",
    "torasses": "torar",
    "toraste": "torar",
    "torastes": "torar",
    "torava": "torar",
    "toravam": "torar",
    "toravas": "torar",
    "torbernites": "torbernite",
    "torcazes": "torcaz",
    "torce": "torcer",
    "torcedeira": "torcedor",
    "torcedeiras": "torcedor",
    "torcedelas": "torcedela",
    "torcedora": "torcedor",
    "torcedoras": "torcedor",
    "torcedores": "torcedor",
    "torceduras": "torcedura",
    "torcega": "torcegar",
    "torcegada": "torcegar",
    "torcegadas": "torcegar",
    "torcegado": "torcegar",
    "torcegados": "torcegar",
    "torcegai": "torcegar",
    "torcegais": "torcegar",
    "torcegam": "torcegar",
    "torcegamo": "torcegar",
    "torcegamos": "torcegar",
    "torcegando": "torcegar",
    "torcegara": "torcegar",
    "torcegaram": "torcegar",
    "torcegaras": "torcegar",
    "torcegarde": "torcegar",
    "torcegardes": "torcegar",
    "torcegare": "torcegar",
    "torcegarei": "torcegar",
    "torcegareis": "torcegar",
    "torcegarem": "torcegar",
    "torcegaremos": "torcegar",
    "torcegares": "torcegar",
    "torcegaria": "torcegar",
    "torcegariam": "torcegar",
    "torcegarias": "torcegar",
    "torcegarmo": "torcegar",
    "torcegarmos": "torcegar",
    "torcegará": "torcegar",
    "torcegarás": "torcegar",
    "torcegarão": "torcegar",
    "torcegaríamos": "torcegar",
    "torcegaríeis": "torcegar",
    "torcegas": "torcegar",
    "torcegasse": "torcegar",
    "torcegassem": "torcegar",
    "torcegasses": "torcegar",
    "torcegaste": "torcegar",
    "torcegastes": "torcegar",
    "torcegava": "torcegar",
    "torcegavam": "torcegar",
    "torcegavas": "torcegar",
    "torcego": "torcegar",
    "torcegou": "torcegar",
    "torcegue": "torcegar",
    "torceguei": "torcegar",
    "torcegueis": "torcegar",
    "torceguem": "torcegar",
    "torceguemo": "torcegar",
    "torceguemos": "torcegar",
    "torcegues": "torcegar",
    "torcegá": "torcegar",
    "torcegámo": "torcegar",
    "torcegámos": "torcegar",
    "torcegáramo": "torcegar",
    "torcegáramos": "torcegar",
    "torcegárei": "torcegar",
    "torcegáreis": "torcegar",
    "torcegásseis": "torcegar",
    "torcegássemos": "torcegar",
    "torcegávamo": "torcegar",
    "torcegávamos": "torcegar",
    "torcegávei": "torcegar",
    "torcegáveis": "torcegar",
    "torcegões": "torcegão",
    "torcei": "torcer",
    "torceis": "torcer",
    "torcem": "torcer",
    "torcemo": "torcer",
    "torcemos": "torcer",
    "torcendo": "torcer",
    "torcera": "torcer",
    "torceram": "torcer",
    "torceras": "torcer",
    "torcerde": "torcer",
    "torcerdes": "torcer",
    "torcere": "torcer",
    "torcerei": "torcer",
    "torcereis": "torcer",
    "torcerem": "torcer",
    "torceremos": "torcer",
    "torceres": "torcer",
    "torceria": "torcer",
    "torceriam": "torcer",
    "torcerias": "torcer",
    "torcermo": "torcer",
    "torcermos": "torcer",
    "torcerá": "torcer",
    "torcerás": "torcer",
    "torcerão": "torcer",
    "torceríamos": "torcer",
    "torceríeis": "torcer",
    "torces": "torcer",
    "torcesse": "torcer",
    "torcessem": "torcer",
    "torcesses": "torcer",
    "torceste": "torcer",
    "torcestes": "torcer",
    "torceu": "torcer",
    "torci": "torcer",
    "torcia": "torcer",
    "torciam": "torcer",
    "torcias": "torcer",
    "torcicola": "torcicolar",
    "torcicolada": "torcicolar",
    "torcicoladas": "torcicolar",
    "torcicolado": "torcicolar",
    "torcicolados": "torcicolar",
    "torcicolai": "torcicolar",
    "torcicolais": "torcicolar",
    "torcicolam": "torcicolar",
    "torcicolamo": "torcicolar",
    "torcicolamos": "torcicolar",
    "torcicolando": "torcicolar",
    "torcicolara": "torcicolar",
    "torcicolaram": "torcicolar",
    "torcicolaras": "torcicolar",
    "torcicolardes": "torcicolar",
    "torcicolarei": "torcicolar",
    "torcicolareis": "torcicolar",
    "torcicolarem": "torcicolar",
    "torcicolaremos": "torcicolar",
    "torcicolares": "torcicolar",
    "torcicolaria": "torcicolar",
    "torcicolariam": "torcicolar",
    "torcicolarias": "torcicolar",
    "torcicolarmo": "torcicolar",
    "torcicolarmos": "torcicolar",
    "torcicolará": "torcicolar",
    "torcicolarás": "torcicolar",
    "torcicolarão": "torcicolar",
    "torcicolaríamos": "torcicolar",
    "torcicolaríeis": "torcicolar",
    "torcicolas": "torcicolar",
    "torcicolasse": "torcicolar",
    "torcicolassem": "torcicolar",
    "torcicolasses": "torcicolar",
    "torcicolaste": "torcicolar",
    "torcicolastes": "torcicolar",
    "torcicolava": "torcicolar",
    "torcicolavam": "torcicolar",
    "torcicolavas": "torcicolar",
    "torcicole": "torcicolar",
    "torcicolei": "torcicolar",
    "torcicoleis": "torcicolar",
    "torcicolem": "torcicolar",
    "torcicolemo": "torcicolar",
    "torcicolemos": "torcicolar",
    "torcicoles": "torcicolar",
    "torcicolo": "torcicolar",
    "torcicolos": "torcicolo",
    "torcicolou": "torcicolar",
    "torcicolámo": "torcicolar",
    "torcicolámos": "torcicolar",
    "torcicoláramo": "torcicolar",
    "torcicoláramos": "torcicolar",
    "torcicoláreis": "torcicolar",
    "torcicolásseis": "torcicolar",
    "torcicolássemos": "torcicolar",
    "torcicolávamo": "torcicolar",
    "torcicolávamos": "torcicolar",
    "torcicoláveis": "torcicolar",
    "torcida": "torcido",
    "torcidas": "torcido",
    "torcido": "torcer",
    "torcidos": "torcido",
    "torcidíssima": "torcido",
    "torcidíssimas": "torcido",
    "torcidíssimo": "torcido",
    "torcidíssimos": "torcido",
    "torcilhões": "torcilhão",
    "torcimentos": "torcimento",
    "torcionários": "torcionário",
    "torculares": "torcular",
    "torcázios": "torcázio",
    "torcê": "torcer",
    "torcêramo": "torcer",
    "torcêramos": "torcer",
    "torcêrei": "torcer",
    "torcêreis": "torcer",
    "torcêsseis": "torcer",
    "torcêssemos": "torcer",
    "torcíamo": "torcer",
    "torcíamos": "torcer",
    "torcíei": "torcer",
    "torcíeis": "torcer",
    "torda": "tordo",
    "tordas": "tordo",
    "tordeiras": "tordeira",
    "tordeiros": "tordeiro",
    "tordilha": "tordilho",
    "tordilhas": "tordilho",
    "tordilhos": "tordilho",
    "tordinhos": "tordinho",
    "tordonhas": "tordonha",
    "tordos": "tordo",
    "tore": "torar",
    "torei": "torar",
    "toreis": "torar",
    "torem": "torar",
    "toremo": "torar",
    "toremos": "torar",
    "tores": "torar",
    "toreumatografias": "toreumatografia",
    "toreumatógrafos": "toreumatógrafo",
    "toreutas": "toreuta",
    "toreutica": "toreutico",
    "toreuticas": "toreutico",
    "toreuticos": "toreutico",
    "torgais": "torgal",
    "torgalhos": "torgalho",
    "torgas": "torga",
    "torgueiras": "torgueira",
    "torgões": "torgão",
    "torianites": "torianite",
    "tories": "tory",
    "torites": "torite",
    "tormentas": "tormenta",
    "tormentelhos": "tormentelho",
    "tormentelo": "tormentelho",
    "tormentelos": "tormentelho",
    "tormentila": "tormentilha",
    "tormentilas": "tormentilha",
    "tormentilhas": "tormentilha",
    "tormentos": "tormento",
    "tormentosa": "tormentoso",
    "tormentosas": "tormentoso",
    "tormentosos": "tormentoso",
    "tormentória": "tormentório",
    "tormentórias": "tormentório",
    "tormentórios": "tormentório",
    "torna": "tornar",
    "tornada": "tornar",
    "tornadas": "tornar",
    "tornadiça": "tornadiço",
    "tornadiças": "tornadiço",
    "tornadiços": "tornadiço",
    "tornado": "tornar",
    "tornadoiras": "tornadoira",
    "tornadoiros": "tornadoiro",
    "tornadora": "tornador",
    "tornadoras": "tornador",
    "tornadores": "tornador",
    "tornados": "tornar",
    "tornadouras": "tornadoura",
    "tornadouros": "tornadouro",
    "tornaduras": "tornadura",
    "tornai": "tornar",
    "tornais": "tornar",
    "tornam": "tornar",
    "tornamo": "tornar",
    "tornamos": "tornar",
    "tornando": "tornar",
    "tornara": "tornar",
    "tornaram": "tornar",
    "tornaras": "tornar",
    "tornardes": "tornar",
    "tornarei": "tornar",
    "tornareis": "tornar",
    "tornarem": "tornar",
    "tornaremos": "tornar",
    "tornares": "tornar",
    "tornaria": "tornar",
    "tornariam": "tornar",
    "tornarias": "tornar",
    "tornarmo": "tornar",
    "tornarmos": "tornar",
    "tornará": "tornar",
    "tornarás": "tornar",
    "tornarão": "tornar",
    "tornaríamos": "tornar",
    "tornaríeis": "tornar",
    "tornas": "tornar",
    "tornasse": "tornar",
    "tornassem": "tornar",
    "tornasses": "tornar",
    "tornassóis": "tornassol",
    "tornaste": "tornar",
    "tornastes": "tornar",
    "tornava": "tornar",
    "tornavam": "tornar",
    "tornavas": "tornar",
    "torne": "tornar",
    "torneada": "tornear",
    "torneadas": "tornear",
    "torneadinha": "torneado",
    "torneadinhas": "torneado",
    "torneadinho": "torneado",
    "torneadinhos": "torneado",
    "torneadita": "torneado",
    "torneaditas": "torneado",
    "torneadito": "torneado",
    "torneaditos": "torneado",
    "torneado": "tornear",
    "torneadora": "torneador",
    "torneadoras": "torneador",
    "torneadores": "torneador",
    "torneados": "tornear",
    "torneadíssima": "torneado",
    "torneadíssimas": "torneado",
    "torneadíssimo": "torneado",
    "torneadíssimos": "torneado",
    "torneai": "tornear",
    "torneais": "tornear",
    "torneamentos": "torneamento",
    "torneamo": "tornear",
    "torneamos": "tornear",
    "torneando": "tornear",
    "torneara": "tornear",
    "tornearam": "tornear",
    "tornearas": "tornear",
    "tornearde": "tornear",
    "torneardes": "tornear",
    "torneare": "tornear",
    "tornearei": "tornear",
    "torneareis": "tornear",
    "tornearem": "tornear",
    "tornearemos": "tornear",
    "torneares": "tornear",
    "tornearia": "tornear",
    "torneariam": "tornear",
    "tornearias": "tornearia",
    "tornearmo": "tornear",
    "tornearmos": "tornear",
    "torneará": "tornear",
    "tornearás": "tornear",
    "tornearão": "tornear",
    "tornearíamos": "tornear",
    "tornearíeis": "tornear",
    "torneasse": "tornear",
    "torneassem": "tornear",
    "torneasses": "tornear",
    "torneaste": "tornear",
    "torneastes": "tornear",
    "torneava": "tornear",
    "torneavam": "tornear",
    "torneavas": "tornear",
    "torneei": "tornear",
    "torneeis": "tornear",
    "torneemo": "tornear",
    "torneemos": "tornear",
    "tornei": "tornar",
    "torneia": "tornear",
    "torneiam": "tornear",
    "torneias": "tornear",
    "torneie": "tornear",
    "torneiem": "tornear",
    "torneies": "tornear",
    "torneio": "tornear",
    "torneios": "torneio",
    "torneiras": "torneira",
    "torneiros": "torneiro",
    "torneis": "tornel",
    "torneja": "tornejar",
    "tornejada": "tornejar",
    "tornejadas": "tornejar",
    "tornejado": "tornejar",
    "tornejados": "tornejar",
    "tornejai": "tornejar",
    "tornejais": "tornejar",
    "tornejam": "tornejar",
    "tornejamentos": "tornejamento",
    "tornejamo": "tornejar",
    "tornejamos": "tornejar",
    "tornejando": "tornejar",
    "tornejara": "tornejar",
    "tornejaram": "tornejar",
    "tornejaras": "tornejar",
    "tornejarde": "tornejar",
    "tornejardes": "tornejar",
    "tornejare": "tornejar",
    "tornejarei": "tornejar",
    "tornejareis": "tornejar",
    "tornejarem": "tornejar",
    "tornejaremos": "tornejar",
    "tornejares": "tornejar",
    "tornejaria": "tornejar",
    "tornejariam": "tornejar",
    "tornejarias": "tornejar",
    "tornejarmo": "tornejar",
    "tornejarmos": "tornejar",
    "tornejará": "tornejar",
    "tornejarás": "tornejar",
    "tornejarão": "tornejar",
    "tornejaríamos": "tornejar",
    "tornejaríeis": "tornejar",
    "tornejas": "tornejar",
    "tornejasse": "tornejar",
    "tornejassem": "tornejar",
    "tornejasses": "tornejar",
    "tornejaste": "tornejar",
    "tornejastes": "tornejar",
    "tornejava": "tornejar",
    "tornejavam": "tornejar",
    "tornejavas": "tornejar",
    "torneje": "tornejar",
    "tornejei": "tornejar",
    "tornejeis": "tornejar",
    "tornejem": "tornejar",
    "tornejemo": "tornejar",
    "tornejemos": "tornejar",
    "tornejes": "tornejar",
    "tornejo": "tornejar",
    "tornejou": "tornejar",
    "tornejá": "tornejar",
    "tornejámo": "tornejar",
    "tornejámos": "tornejar",
    "tornejáramo": "tornejar",
    "tornejáramos": "tornejar",
    "tornejárei": "tornejar",
    "tornejáreis": "tornejar",
    "tornejásseis": "tornejar",
    "tornejássemos": "tornejar",
    "tornejávamo": "tornejar",
    "tornejávamos": "tornejar",
    "tornejávei": "tornejar",
    "tornejáveis": "tornejar",
    "tornejões": "tornejão",
    "tornem": "tornar",
    "tornemo": "tornar",
    "tornemos": "tornar",
    "torneou": "tornear",
    "tornes": "tornar",
    "tornesóis": "tornesol",
    "tornezelos": "tornezelo",
    "tornezes": "tornez",
    "torneá": "tornear",
    "torneámo": "tornear",
    "torneámos": "tornear",
    "torneáramo": "tornear",
    "torneáramos": "tornear",
    "torneárei": "tornear",
    "torneáreis": "tornear",
    "torneásseis": "tornear",
    "torneássemos": "tornear",
    "torneávamo": "tornear",
    "torneávamos": "tornear",
    "torneávei": "tornear",
    "torneáveis": "torneável",
    "tornilhos": "tornilho",
    "torninho": "torno",
    "torninhos": "torno",
    "torniquetes": "torniquete",
    "tornito": "torno",
    "tornitos": "torno",
    "torno": "tornar",
    "tornos": "torno",
    "tornou": "tornar",
    "tornozelos": "tornozelo",
    "torná": "tornar",
    "tornámo": "tornar",
    "tornámos": "tornar",
    "tornáramo": "tornar",
    "tornáramos": "tornar",
    "tornáreis": "tornar",
    "tornásseis": "tornar",
    "tornássemos": "tornar",
    "tornávamo": "tornar",
    "tornávamos": "tornar",
    "tornáveis": "tornar",
    "toro": "torar",
    "toroidais": "toroidal",
    "toros": "toro",
    "torosa": "toroso",
    "torosas": "toroso",
    "torosos": "toroso",
    "torou": "torar",
    "torpece": "torpecer",
    "torpecei": "torpecer",
    "torpeceis": "torpecer",
    "torpecem": "torpecer",
    "torpecemo": "torpecer",
    "torpecemos": "torpecer",
    "torpecendo": "torpecer",
    "torpecera": "torpecer",
    "torpeceram": "torpecer",
    "torpeceras": "torpecer",
    "torpecerdes": "torpecer",
    "torpecerei": "torpecer",
    "torpecereis": "torpecer",
    "torpecerem": "torpecer",
    "torpeceremos": "torpecer",
    "torpeceres": "torpecer",
    "torpeceria": "torpecer",
    "torpeceriam": "torpecer",
    "torpecerias": "torpecer",
    "torpecermo": "torpecer",
    "torpecermos": "torpecer",
    "torpecerá": "torpecer",
    "torpecerás": "torpecer",
    "torpecerão": "torpecer",
    "torpeceríamos": "torpecer",
    "torpeceríeis": "torpecer",
    "torpeces": "torpecer",
    "torpecesse": "torpecer",
    "torpecessem": "torpecer",
    "torpecesses": "torpecer",
    "torpeceste": "torpecer",
    "torpecestes": "torpecer",
    "torpeceu": "torpecer",
    "torpeci": "torpecer",
    "torpecia": "torpecer",
    "torpeciam": "torpecer",
    "torpecias": "torpecer",
    "torpecida": "torpecer",
    "torpecidas": "torpecer",
    "torpecido": "torpecer",
    "torpecidos": "torpecer",
    "torpecêramo": "torpecer",
    "torpecêramos": "torpecer",
    "torpecêreis": "torpecer",
    "torpecêsseis": "torpecer",
    "torpecêssemos": "torpecer",
    "torpecíamo": "torpecer",
    "torpecíamos": "torpecer",
    "torpecíeis": "torpecer",
    "torpedeada": "torpedear",
    "torpedeadas": "torpedear",
    "torpedeado": "torpedear",
    "torpedeados": "torpedear",
    "torpedeai": "torpedear",
    "torpedeais": "torpedear",
    "torpedeamentos": "torpedeamento",
    "torpedeamo": "torpedear",
    "torpedeamos": "torpedear",
    "torpedeando": "torpedear",
    "torpedeara": "torpedear",
    "torpedearam": "torpedear",
    "torpedearas": "torpedear",
    "torpedearde": "torpedear",
    "torpedeardes": "torpedear",
    "torpedeare": "torpedear",
    "torpedearei": "torpedear",
    "torpedeareis": "torpedear",
    "torpedearem": "torpedear",
    "torpedearemos": "torpedear",
    "torpedeares": "torpedear",
    "torpedearia": "torpedear",
    "torpedeariam": "torpedear",
    "torpedearias": "torpedear",
    "torpedearmo": "torpedear",
    "torpedearmos": "torpedear",
    "torpedeará": "torpedear",
    "torpedearás": "torpedear",
    "torpedearão": "torpedear",
    "torpedearíamos": "torpedear",
    "torpedearíeis": "torpedear",
    "torpedeasse": "torpedear",
    "torpedeassem": "torpedear",
    "torpedeasses": "torpedear",
    "torpedeaste": "torpedear",
    "torpedeastes": "torpedear",
    "torpedeava": "torpedear",
    "torpedeavam": "torpedear",
    "torpedeavas": "torpedear",
    "torpedeei": "torpedear",
    "torpedeeis": "torpedear",
    "torpedeemo": "torpedear",
    "torpedeemos": "torpedear",
    "torpedeia": "torpedear",
    "torpedeiam": "torpedear",
    "torpedeias": "torpedear",
    "torpedeie": "torpedear",
    "torpedeiem": "torpedear",
    "torpedeies": "torpedear",
    "torpedeio": "torpedear",
    "torpedeiros": "torpedeiro",
    "torpedeou": "torpedear",
    "torpedeá": "torpedear",
    "torpedeámo": "torpedear",
    "torpedeámos": "torpedear",
    "torpedeáramo": "torpedear",
    "torpedeáramos": "torpedear",
    "torpedeárei": "torpedear",
    "torpedeáreis": "torpedear",
    "torpedeásseis": "torpedear",
    "torpedeássemos": "torpedear",
    "torpedeávamo": "torpedear",
    "torpedeávamos": "torpedear",
    "torpedeávei": "torpedear",
    "torpedeáveis": "torpedear",
    "torpedinídeos": "torpedinídeo",
    "torpedos": "torpedo",
    "torpedínidas": "torpedínida",
    "torpes": "torpe",
    "torpezas": "torpeza",
    "torpeça": "torpecer",
    "torpeçais": "torpecer",
    "torpeçam": "torpecer",
    "torpeçamo": "torpecer",
    "torpeçamos": "torpecer",
    "torpeças": "torpecer",
    "torpeço": "torpecer",
    "torpidades": "torpidade",
    "torpilhas": "torpilha",
    "torpores": "torpor",
    "torquaza": "torquaz",
    "torquazas": "torquaz",
    "torquazes": "torquaz",
    "torqueses": "torquês",
    "torra": "torrar",
    "torrada": "torrar",
    "torradas": "torrar",
    "torradeiras": "torradeira",
    "torradinha": "torrado",
    "torradinhas": "torrado",
    "torradinho": "torrado",
    "torradinhos": "torrado",
    "torradita": "torrado",
    "torraditas": "torrado",
    "torradito": "torrado",
    "torraditos": "torrado",
    "torrado": "torrar",
    "torradora": "torrador",
    "torradoras": "torrador",
    "torradores": "torrador",
    "torrados": "torrar",
    "torradíssima": "torrado",
    "torradíssimas": "torrado",
    "torradíssimo": "torrado",
    "torradíssimos": "torrado",
    "torragens": "torragem",
    "torrai": "torrar",
    "torrais": "torrar",
    "torralhões": "torralhão",
    "torram": "torrar",
    "torramo": "torrar",
    "torramos": "torrar",
    "torrando": "torrar",
    "torrara": "torrar",
    "torraram": "torrar",
    "torraras": "torrar",
    "torrarde": "torrar",
    "torrardes": "torrar",
    "torrare": "torrar",
    "torrarei": "torrar",
    "torrareis": "torrar",
    "torrarem": "torrar",
    "torraremos": "torrar",
    "torrares": "torrar",
    "torraria": "torrar",
    "torrariam": "torrar",
    "torrarias": "torrar",
    "torrarmo": "torrar",
    "torrarmos": "torrar",
    "torrará": "torrar",
    "torrarás": "torrar",
    "torrarão": "torrar",
    "torraríamos": "torrar",
    "torraríeis": "torrar",
    "torras": "torrar",
    "torrasse": "torrar",
    "torrassem": "torrar",
    "torrasses": "torrar",
    "torraste": "torrar",
    "torrastes": "torrar",
    "torrava": "torrar",
    "torravam": "torrar",
    "torravas": "torrar",
    "torrações": "torração",
    "torre": "torrar",
    "torreada": "torrear",
    "torreadas": "torrear",
    "torreado": "torrear",
    "torreados": "torrear",
    "torreai": "torrear",
    "torreais": "torrear",
    "torreames": "torreame",
    "torreamo": "torrear",
    "torreamos": "torrear",
    "torreando": "torrear",
    "torreantes": "torreante",
    "torreara": "torrear",
    "torrearam": "torrear",
    "torrearas": "torrear",
    "torrearde": "torrear",
    "torreardes": "torrear",
    "torreare": "torrear",
    "torrearei": "torrear",
    "torreareis": "torrear",
    "torrearem": "torrear",
    "torrearemos": "torrear",
    "torreares": "torrear",
    "torrearia": "torrear",
    "torreariam": "torrear",
    "torrearias": "torrear",
    "torrearmo": "torrear",
    "torrearmos": "torrear",
    "torreará": "torrear",
    "torrearás": "torrear",
    "torrearão": "torrear",
    "torrearíamos": "torrear",
    "torrearíeis": "torrear",
    "torreasse": "torrear",
    "torreassem": "torrear",
    "torreasses": "torrear",
    "torreaste": "torrear",
    "torreastes": "torrear",
    "torreava": "torrear",
    "torreavam": "torrear",
    "torreavas": "torrear",
    "torreei": "torrear",
    "torreeis": "torrear",
    "torreemo": "torrear",
    "torreemos": "torrear",
    "torrefacta": "torrefacto",
    "torrefactas": "torrefacto",
    "torrefactos": "torrefacto",
    "torrefacções": "torrefacção",
    "torrefarei": "torrefazer",
    "torrefareis": "torrefazer",
    "torrefaremos": "torrefazer",
    "torrefaria": "torrefazer",
    "torrefariam": "torrefazer",
    "torrefarias": "torrefazer",
    "torrefará": "torrefazer",
    "torrefarás": "torrefazer",
    "torrefarão": "torrefazer",
    "torrefaríamos": "torrefazer",
    "torrefaríeis": "torrefazer",
    "torrefaz": "torrefazer",
    "torrefaze": "torrefazer",
    "torrefazei": "torrefazer",
    "torrefazeis": "torrefazer",
    "torrefazem": "torrefazer",
    "torrefazemo": "torrefazer",
    "torrefazemos": "torrefazer",
    "torrefazendo": "torrefazer",
    "torrefazerde": "torrefazer",
    "torrefazerdes": "torrefazer",
    "torrefazere": "torrefazer",
    "torrefazerem": "torrefazer",
    "torrefazeres": "torrefazer",
    "torrefazermo": "torrefazer",
    "torrefazermos": "torrefazer",
    "torrefazes": "torrefazer",
    "torrefazia": "torrefazer",
    "torrefaziam": "torrefazer",
    "torrefazias": "torrefazer",
    "torrefazê": "torrefazer",
    "torrefazíamo": "torrefazer",
    "torrefazíamos": "torrefazer",
    "torrefazíei": "torrefazer",
    "torrefazíeis": "torrefazer",
    "torrefaça": "torrefazer",
    "torrefaçais": "torrefazer",
    "torrefaçam": "torrefazer",
    "torrefaçamo": "torrefazer",
    "torrefaçamos": "torrefazer",
    "torrefaças": "torrefazer",
    "torrefaço": "torrefazer",
    "torrefeita": "torrefeito",
    "torrefeitas": "torrefeito",
    "torrefeito": "torrefazer",
    "torrefeitos": "torrefeito",
    "torrefez": "torrefazer",
    "torrefi": "torrefazer",
    "torrefiz": "torrefazer",
    "torrefizemo": "torrefazer",
    "torrefizemos": "torrefazer",
    "torrefizer": "torrefazer",
    "torrefizera": "torrefazer",
    "torrefizeram": "torrefazer",
    "torrefizeras": "torrefazer",
    "torrefizerdes": "torrefazer",
    "torrefizerem": "torrefazer",
    "torrefizeres": "torrefazer",
    "torrefizermos": "torrefazer",
    "torrefizesse": "torrefazer",
    "torrefizessem": "torrefazer",
    "torrefizesses": "torrefazer",
    "torrefizeste": "torrefazer",
    "torrefizestes": "torrefazer",
    "torrefizéramo": "torrefazer",
    "torrefizéramos": "torrefazer",
    "torrefizérei": "torrefazer",
    "torrefizéreis": "torrefazer",
    "torrefizésseis": "torrefazer",
    "torrefizéssemos": "torrefazer",
    "torrefá": "torrefazer",
    "torrefê": "torrefazer",
    "torrei": "torrar",
    "torreia": "torrear",
    "torreiam": "torrear",
    "torreias": "torrear",
    "torreie": "torrear",
    "torreiem": "torrear",
    "torreies": "torrear",
    "torreifelesca": "torreifelesco",
    "torreifelescas": "torreifelesco",
    "torreifelescos": "torreifelesco",
    "torreio": "torrear",
    "torreiras": "torreira",
    "torreis": "torrar",
    "torreja": "torrejar",
    "torrejada": "torrejar",
    "torrejadas": "torrejar",
    "torrejado": "torrejar",
    "torrejados": "torrejar",
    "torrejai": "torrejar",
    "torrejais": "torrejar",
    "torrejam": "torrejar",
    "torrejamo": "torrejar",
    "torrejamos": "torrejar",
    "torrejana": "torrejano",
    "torrejanas": "torrejano",
    "torrejando": "torrejar",
    "torrejanos": "torrejano",
    "torrejara": "torrejar",
    "torrejaram": "torrejar",
    "torrejaras": "torrejar",
    "torrejarde": "torrejar",
    "torrejardes": "torrejar",
    "torrejare": "torrejar",
    "torrejarei": "torrejar",
    "torrejareis": "torrejar",
    "torrejarem": "torrejar",
    "torrejaremos": "torrejar",
    "torrejares": "torrejar",
    "torrejaria": "torrejar",
    "torrejariam": "torrejar",
    "torrejarias": "torrejar",
    "torrejarmo": "torrejar",
    "torrejarmos": "torrejar",
    "torrejará": "torrejar",
    "torrejarás": "torrejar",
    "torrejarão": "torrejar",
    "torrejaríamos": "torrejar",
    "torrejaríeis": "torrejar",
    "torrejas": "torrejar",
    "torrejasse": "torrejar",
    "torrejassem": "torrejar",
    "torrejasses": "torrejar",
    "torrejaste": "torrejar",
    "torrejastes": "torrejar",
    "torrejava": "torrejar",
    "torrejavam": "torrejar",
    "torrejavas": "torrejar",
    "torreje": "torrejar",
    "torrejei": "torrejar",
    "torrejeis": "torrejar",
    "torrejem": "torrejar",
    "torrejemo": "torrejar",
    "torrejemos": "torrejar",
    "torrejes": "torrejar",
    "torrejo": "torrejar",
    "torrejou": "torrejar",
    "torrejá": "torrejar",
    "torrejámo": "torrejar",
    "torrejámos": "torrejar",
    "torrejáramo": "torrejar",
    "torrejáramos": "torrejar",
    "torrejárei": "torrejar",
    "torrejáreis": "torrejar",
    "torrejásseis": "torrejar",
    "torrejássemos": "torrejar",
    "torrejávamo": "torrejar",
    "torrejávamos": "torrejar",
    "torrejávei": "torrejar",
    "torrejáveis": "torrejar",
    "torrem": "torrar",
    "torremo": "torrar",
    "torremos": "torrar",
    "torrenciais": "torrencial",
    "torrencialidades": "torrencialidade",
    "torrentes": "torrente",
    "torrentosa": "torrentoso",
    "torrentosas": "torrentoso",
    "torrentosos": "torrentoso",
    "torreou": "torrear",
    "torres": "torre",
    "torresmadas": "torresmada",
    "torresmos": "torresmo",
    "torresona": "torresão",
    "torresonas": "torresão",
    "torresã": "torresão",
    "torresãos": "torresão",
    "torresãs": "torresão",
    "torresões": "torresão",
    "torretas": "torreta",
    "torrezões": "torrezão",
    "torreá": "torrear",
    "torreámo": "torrear",
    "torreámos": "torrear",
    "torreáramo": "torrear",
    "torreáramos": "torrear",
    "torreárei": "torrear",
    "torreáreis": "torrear",
    "torreásseis": "torrear",
    "torreássemos": "torrear",
    "torreávamo": "torrear",
    "torreávamos": "torrear",
    "torreávei": "torrear",
    "torreáveis": "torrear",
    "torreões": "torreão",
    "torriana": "torriano",
    "torrianas": "torriano",
    "torrianos": "torriano",
    "torrienses": "torriense",
    "torrifica": "torrificar",
    "torrificada": "torrificar",
    "torrificadas": "torrificar",
    "torrificado": "torrificar",
    "torrificados": "torrificar",
    "torrificai": "torrificar",
    "torrificais": "torrificar",
    "torrificam": "torrificar",
    "torrificamo": "torrificar",
    "torrificamos": "torrificar",
    "torrificando": "torrificar",
    "torrificara": "torrificar",
    "torrificaram": "torrificar",
    "torrificaras": "torrificar",
    "torrificarde": "torrificar",
    "torrificardes": "torrificar",
    "torrificare": "torrificar",
    "torrificarei": "torrificar",
    "torrificareis": "torrificar",
    "torrificarem": "torrificar",
    "torrificaremos": "torrificar",
    "torrificares": "torrificar",
    "torrificaria": "torrificar",
    "torrificariam": "torrificar",
    "torrificarias": "torrificar",
    "torrificarmo": "torrificar",
    "torrificarmos": "torrificar",
    "torrificará": "torrificar",
    "torrificarás": "torrificar",
    "torrificarão": "torrificar",
    "torrificaríamos": "torrificar",
    "torrificaríeis": "torrificar",
    "torrificas": "torrificar",
    "torrificasse": "torrificar",
    "torrificassem": "torrificar",
    "torrificasses": "torrificar",
    "torrificaste": "torrificar",
    "torrificastes": "torrificar",
    "torrificava": "torrificar",
    "torrificavam": "torrificar",
    "torrificavas": "torrificar",
    "torrificações": "torrificação",
    "torrifico": "torrificar",
    "torrificou": "torrificar",
    "torrificá": "torrificar",
    "torrificámo": "torrificar",
    "torrificámos": "torrificar",
    "torrificáramo": "torrificar",
    "torrificáramos": "torrificar",
    "torrificárei": "torrificar",
    "torrificáreis": "torrificar",
    "torrificásseis": "torrificar",
    "torrificássemos": "torrificar",
    "torrificávamo": "torrificar",
    "torrificávamos": "torrificar",
    "torrificávei": "torrificar",
    "torrificáveis": "torrificável",
    "torrifique": "torrificar",
    "torrifiquei": "torrificar",
    "torrifiqueis": "torrificar",
    "torrifiquem": "torrificar",
    "torrifiquemo": "torrificar",
    "torrifiquemos": "torrificar",
    "torrifiques": "torrificar",
    "torrijas": "torrija",
    "torrisca": "torriscar",
    "torriscada": "torriscar",
    "torriscadas": "torriscar",
    "torriscado": "torriscar",
    "torriscados": "torriscar",
    "torriscai": "torriscar",
    "torriscais": "torriscar",
    "torriscam": "torriscar",
    "torriscamo": "torriscar",
    "torriscamos": "torriscar",
    "torriscando": "torriscar",
    "torriscara": "torriscar",
    "torriscaram": "torriscar",
    "torriscaras": "torriscar",
    "torriscarde": "torriscar",
    "torriscardes": "torriscar",
    "torriscare": "torriscar",
    "torriscarei": "torriscar",
    "torriscareis": "torriscar",
    "torriscarem": "torriscar",
    "torriscaremos": "torriscar",
    "torriscares": "torriscar",
    "torriscaria": "torriscar",
    "torriscariam": "torriscar",
    "torriscarias": "torriscar",
    "torriscarmo": "torriscar",
    "torriscarmos": "torriscar",
    "torriscará": "torriscar",
    "torriscarás": "torriscar",
    "torriscarão": "torriscar",
    "torriscaríamos": "torriscar",
    "torriscaríeis": "torriscar",
    "torriscas": "torriscar",
    "torriscasse": "torriscar",
    "torriscassem": "torriscar",
    "torriscasses": "torriscar",
    "torriscaste": "torriscar",
    "torriscastes": "torriscar",
    "torriscava": "torriscar",
    "torriscavam": "torriscar",
    "torriscavas": "torriscar",
    "torrisco": "torriscar",
    "torriscou": "torriscar",
    "torriscá": "torriscar",
    "torriscámo": "torriscar",
    "torriscámos": "torriscar",
    "torriscáramo": "torriscar",
    "torriscáramos": "torriscar",
    "torriscárei": "torriscar",
    "torriscáreis": "torriscar",
    "torriscásseis": "torriscar",
    "torriscássemos": "torriscar",
    "torriscávamo": "torriscar",
    "torriscávamos": "torriscar",
    "torriscávei": "torriscar",
    "torriscáveis": "torriscar",
    "torrisque": "torriscar",
    "torrisquei": "torriscar",
    "torrisqueis": "torriscar",
    "torrisquem": "torriscar",
    "torrisquemo": "torriscar",
    "torrisquemos": "torriscar",
    "torrisques": "torriscar",
    "torro": "torrar",
    "torroadas": "torroada",
    "torroeiros": "torroeiro",
    "torrou": "torrar",
    "torrá": "torrar",
    "torrámo": "torrar",
    "torrámos": "torrar",
    "torráramo": "torrar",
    "torráramos": "torrar",
    "torrárei": "torrar",
    "torráreis": "torrar",
    "torrásseis": "torrar",
    "torrássemos": "torrar",
    "torrávamo": "torrar",
    "torrávamos": "torrar",
    "torrávei": "torrar",
    "torráveis": "torrar",
    "torrãozinho": "torrão",
    "torrãozito": "torrão",
    "torrígera": "torrígero",
    "torrígeras": "torrígero",
    "torrígeros": "torrígero",
    "torrões": "torrão",
    "torrõezinhos": "torrão",
    "torrõezitos": "torrão",
    "torsa": "torso",
    "torsas": "torso",
    "torsos": "torso",
    "torta": "torto",
    "tortas": "torto",
    "torteiras": "torteira",
    "torticeira": "torticeiro",
    "torticeiras": "torticeiro",
    "torticeiros": "torticeiro",
    "torticolos": "torticolo",
    "tortilhas": "tortilha",
    "tortinha": "torto",
    "tortinhas": "torto",
    "tortinho": "torto",
    "tortinhos": "torto",
    "tortita": "torto",
    "tortitas": "torto",
    "tortito": "torto",
    "tortitos": "torto",
    "tortonianos": "tortoniano",
    "tortos": "torto",
    "tortuais": "tortual",
    "tortueirais": "tortueiral",
    "tortulheiras": "tortulheira",
    "tortulhos": "tortulho",
    "tortumelos": "tortumelo",
    "tortuosa": "tortuoso",
    "tortuosas": "tortuoso",
    "tortuosidades": "tortuosidade",
    "tortuosos": "tortuoso",
    "tortura": "torturar",
    "torturada": "torturar",
    "torturadas": "torturar",
    "torturado": "torturar",
    "torturadora": "torturador",
    "torturadoras": "torturador",
    "torturadores": "torturador",
    "torturados": "torturar",
    "torturai": "torturar",
    "torturais": "torturar",
    "torturam": "torturar",
    "torturamo": "torturar",
    "torturamos": "torturar",
    "torturando": "torturar",
    "torturantes": "torturante",
    "torturara": "torturar",
    "torturaram": "torturar",
    "torturaras": "torturar",
    "torturarde": "torturar",
    "torturardes": "torturar",
    "torturare": "torturar",
    "torturarei": "torturar",
    "torturareis": "torturar",
    "torturarem": "torturar",
    "torturaremos": "torturar",
    "torturares": "torturar",
    "torturaria": "torturar",
    "torturariam": "torturar",
    "torturarias": "torturar",
    "torturarmo": "torturar",
    "torturarmos": "torturar",
    "torturará": "torturar",
    "torturarás": "torturar",
    "torturarão": "torturar",
    "torturaríamos": "torturar",
    "torturaríeis": "torturar",
    "torturas": "torturar",
    "torturasse": "torturar",
    "torturassem": "torturar",
    "torturasses": "torturar",
    "torturaste": "torturar",
    "torturastes": "torturar",
    "torturava": "torturar",
    "torturavam": "torturar",
    "torturavas": "torturar",
    "torture": "torturar",
    "torturei": "torturar",
    "tortureis": "torturar",
    "torturem": "torturar",
    "torturemo": "torturar",
    "torturemos": "torturar",
    "tortures": "torturar",
    "torturo": "torturar",
    "torturou": "torturar",
    "torturá": "torturar",
    "torturámo": "torturar",
    "torturámos": "torturar",
    "torturáramo": "torturar",
    "torturáramos": "torturar",
    "torturárei": "torturar",
    "torturáreis": "torturar",
    "torturásseis": "torturar",
    "torturássemos": "torturar",
    "torturávamo": "torturar",
    "torturávamos": "torturar",
    "torturávei": "torturar",
    "torturáveis": "torturar",
    "tortíssima": "torto",
    "tortíssimas": "torto",
    "tortíssimo": "torto",
    "tortíssimos": "torto",
    "tortões": "tortão",
    "torulosa": "toruloso",
    "torulosas": "toruloso",
    "torulosos": "toruloso",
    "torva": "torvo",
    "torvada": "torvar",
    "torvadas": "torvar",
    "torvado": "torvar",
    "torvados": "torvar",
    "torvai": "torvar",
    "torvais": "torvar",
    "torvam": "torvar",
    "torvamentos": "torvamento",
    "torvamo": "torvar",
    "torvamos": "torvar",
    "torvando": "torvar",
    "torvara": "torvar",
    "torvaram": "torvar",
    "torvaras": "torvar",
    "torvarde": "torvar",
    "torvardes": "torvar",
    "torvare": "torvar",
    "torvarei": "torvar",
    "torvareis": "torvar",
    "torvarem": "torvar",
    "torvaremos": "torvar",
    "torvares": "torvar",
    "torvaria": "torvar",
    "torvariam": "torvar",
    "torvarias": "torvar",
    "torvarmo": "torvar",
    "torvarmos": "torvar",
    "torvará": "torvar",
    "torvarás": "torvar",
    "torvarão": "torvar",
    "torvaríamos": "torvar",
    "torvaríeis": "torvar",
    "torvas": "torvo",
    "torvasse": "torvar",
    "torvassem": "torvar",
    "torvasses": "torvar",
    "torvaste": "torvar",
    "torvastes": "torvar",
    "torvava": "torvar",
    "torvavam": "torvar",
    "torvavas": "torvar",
    "torvações": "torvação",
    "torve": "torvar",
    "torvei": "torvar",
    "torveis": "torvar",
    "torvelinha": "torvelinhar",
    "torvelinhada": "torvelinhar",
    "torvelinhadas": "torvelinhar",
    "torvelinhado": "torvelinhar",
    "torvelinhados": "torvelinhar",
    "torvelinhai": "torvelinhar",
    "torvelinhais": "torvelinhar",
    "torvelinham": "torvelinhar",
    "torvelinhamo": "torvelinhar",
    "torvelinhamos": "torvelinhar",
    "torvelinhando": "torvelinhar",
    "torvelinhara": "torvelinhar",
    "torvelinharam": "torvelinhar",
    "torvelinharas": "torvelinhar",
    "torvelinhardes": "torvelinhar",
    "torvelinharei": "torvelinhar",
    "torvelinhareis": "torvelinhar",
    "torvelinharem": "torvelinhar",
    "torvelinharemos": "torvelinhar",
    "torvelinhares": "torvelinhar",
    "torvelinharia": "torvelinhar",
    "torvelinhariam": "torvelinhar",
    "torvelinharias": "torvelinhar",
    "torvelinharmo": "torvelinhar",
    "torvelinharmos": "torvelinhar",
    "torvelinhará": "torvelinhar",
    "torvelinharás": "torvelinhar",
    "torvelinharão": "torvelinhar",
    "torvelinharíamos": "torvelinhar",
    "torvelinharíeis": "torvelinhar",
    "torvelinhas": "torvelinhar",
    "torvelinhasse": "torvelinhar",
    "torvelinhassem": "torvelinhar",
    "torvelinhasses": "torvelinhar",
    "torvelinhaste": "torvelinhar",
    "torvelinhastes": "torvelinhar",
    "torvelinhava": "torvelinhar",
    "torvelinhavam": "torvelinhar",
    "torvelinhavas": "torvelinhar",
    "torvelinhe": "torvelinhar",
    "torvelinhei": "torvelinhar",
    "torvelinheis": "torvelinhar",
    "torvelinhem": "torvelinhar",
    "torvelinhemo": "torvelinhar",
    "torvelinhemos": "torvelinhar",
    "torvelinhes": "torvelinhar",
    "torvelinho": "torvelinhar",
    "torvelinhos": "torvelinho",
    "torvelinhou": "torvelinhar",
    "torvelinhámo": "torvelinhar",
    "torvelinhámos": "torvelinhar",
    "torvelinháramo": "torvelinhar",
    "torvelinháramos": "torvelinhar",
    "torvelinháreis": "torvelinhar",
    "torvelinhásseis": "torvelinhar",
    "torvelinhássemos": "torvelinhar",
    "torvelinhávamo": "torvelinhar",
    "torvelinhávamos": "torvelinhar",
    "torvelinháveis": "torvelinhar",
    "torvelinos": "torvelino",
    "torvem": "torvar",
    "torvemo": "torvar",
    "torvemos": "torvar",
    "torves": "torvar",
    "torvidades": "torvidade",
    "torvo": "torvar",
    "torvos": "torvo",
    "torvou": "torvar",
    "torvá": "torvar",
    "torvámo": "torvar",
    "torvámos": "torvar",
    "torváramo": "torvar",
    "torváramos": "torvar",
    "torvárei": "torvar",
    "torváreis": "torvar",
    "torvásseis": "torvar",
    "torvássemos": "torvar",
    "torvávamo": "torvar",
    "torvávamos": "torvar",
    "torvávei": "torvar",
    "torváveis": "torvar",
    "torá": "torar",
    "torácica": "torácico",
    "torácicas": "torácico",
    "torácicos": "torácico",
    "torámo": "torar",
    "torámos": "torar",
    "toráramo": "torar",
    "toráramos": "torar",
    "torárei": "torar",
    "toráreis": "torar",
    "torásseis": "torar",
    "torássemos": "torar",
    "torávamo": "torar",
    "torávamos": "torar",
    "torávei": "torar",
    "toráveis": "torar",
    "toráxica": "toráxico",
    "toráxicas": "toráxico",
    "toráxicos": "toráxico",
    "torça": "torcer",
    "torçais": "torcer",
    "torçalada": "torçalado",
    "torçaladas": "torçalado",
    "torçalados": "torçalado",
    "torçam": "torcer",
    "torçamo": "torcer",
    "torçamos": "torcer",
    "torças": "torcer",
    "torço": "torcer",
    "torços": "torço",
    "torções": "torção",
    "torêuticas": "torêutica",
    "toríbios": "toríbio",
    "tosa": "tosar",
    "tosada": "tosar",
    "tosadas": "tosar",
    "tosado": "tosar",
    "tosadora": "tosador",
    "tosadoras": "tosador",
    "tosadores": "tosador",
    "tosados": "tosar",
    "tosai": "tosar",
    "tosais": "tosar",
    "tosam": "tosar",
    "tosamo": "tosar",
    "tosamos": "tosar",
    "tosando": "tosar",
    "tosara": "tosar",
    "tosaram": "tosar",
    "tosaras": "tosar",
    "tosarde": "tosar",
    "tosardes": "tosar",
    "tosare": "tosar",
    "tosarei": "tosar",
    "tosareis": "tosar",
    "tosarem": "tosar",
    "tosaremos": "tosar",
    "tosares": "tosar",
    "tosaria": "tosar",
    "tosariam": "tosar",
    "tosarias": "tosar",
    "tosarmo": "tosar",
    "tosarmos": "tosar",
    "tosará": "tosar",
    "tosarás": "tosar",
    "tosarão": "tosar",
    "tosaríamos": "tosar",
    "tosaríeis": "tosar",
    "tosas": "tosar",
    "tosasse": "tosar",
    "tosassem": "tosar",
    "tosasses": "tosar",
    "tosaste": "tosar",
    "tosastes": "tosar",
    "tosava": "tosar",
    "tosavam": "tosar",
    "tosavas": "tosar",
    "tosca": "tosco",
    "toscada": "toscar",
    "toscadas": "toscar",
    "toscado": "toscar",
    "toscados": "toscar",
    "toscai": "toscar",
    "toscais": "toscar",
    "toscam": "toscar",
    "toscamo": "toscar",
    "toscamos": "toscar",
    "toscana": "toscano",
    "toscanas": "toscano",
    "toscando": "toscar",
    "toscaneja": "toscanejar",
    "toscanejada": "toscanejar",
    "toscanejadas": "toscanejar",
    "toscanejado": "toscanejar",
    "toscanejados": "toscanejar",
    "toscanejai": "toscanejar",
    "toscanejais": "toscanejar",
    "toscanejam": "toscanejar",
    "toscanejamo": "toscanejar",
    "toscanejamos": "toscanejar",
    "toscanejando": "toscanejar",
    "toscanejara": "toscanejar",
    "toscanejaram": "toscanejar",
    "toscanejaras": "toscanejar",
    "toscanejardes": "toscanejar",
    "toscanejarei": "toscanejar",
    "toscanejareis": "toscanejar",
    "toscanejarem": "toscanejar",
    "toscanejaremos": "toscanejar",
    "toscanejares": "toscanejar",
    "toscanejaria": "toscanejar",
    "toscanejariam": "toscanejar",
    "toscanejarias": "toscanejar",
    "toscanejarmo": "toscanejar",
    "toscanejarmos": "toscanejar",
    "toscanejará": "toscanejar",
    "toscanejarás": "toscanejar",
    "toscanejarão": "toscanejar",
    "toscanejaríamos": "toscanejar",
    "toscanejaríeis": "toscanejar",
    "toscanejas": "toscanejar",
    "toscanejasse": "toscanejar",
    "toscanejassem": "toscanejar",
    "toscanejasses": "toscanejar",
    "toscanejaste": "toscanejar",
    "toscanejastes": "toscanejar",
    "toscanejava": "toscanejar",
    "toscanejavam": "toscanejar",
    "toscanejavas": "toscanejar",
    "toscaneje": "toscanejar",
    "toscanejei": "toscanejar",
    "toscanejeis": "toscanejar",
    "toscanejem": "toscanejar",
    "toscanejemo": "toscanejar",
    "toscanejemos": "toscanejar",
    "toscanejes": "toscanejar",
    "toscanejo": "toscanejar",
    "toscanejou": "toscanejar",
    "toscanejámo": "toscanejar",
    "toscanejámos": "toscanejar",
    "toscanejáramo": "toscanejar",
    "toscanejáramos": "toscanejar",
    "toscanejáreis": "toscanejar",
    "toscanejásseis": "toscanejar",
    "toscanejássemos": "toscanejar",
    "toscanejávamo": "toscanejar",
    "toscanejávamos": "toscanejar",
    "toscanejáveis": "toscanejar",
    "toscanos": "toscano",
    "toscara": "toscar",
    "toscaram": "toscar",
    "toscaras": "toscar",
    "toscarde": "toscar",
    "toscardes": "toscar",
    "toscare": "toscar",
    "toscarei": "toscar",
    "toscareis": "toscar",
    "toscarem": "toscar",
    "toscaremos": "toscar",
    "toscares": "toscar",
    "toscaria": "toscar",
    "toscariam": "toscar",
    "toscarias": "toscar",
    "toscarmo": "toscar",
    "toscarmos": "toscar",
    "toscará": "toscar",
    "toscarás": "toscar",
    "toscarão": "toscar",
    "toscaríamos": "toscar",
    "toscaríeis": "toscar",
    "toscas": "tosco",
    "toscasse": "toscar",
    "toscassem": "toscar",
    "toscasses": "toscar",
    "toscaste": "toscar",
    "toscastes": "toscar",
    "toscava": "toscar",
    "toscavam": "toscar",
    "toscavas": "toscar",
    "tosco": "toscar",
    "toscos": "tosco",
    "toscou": "toscar",
    "toscá": "toscar",
    "toscámo": "toscar",
    "toscámos": "toscar",
    "toscáramo": "toscar",
    "toscáramos": "toscar",
    "toscárei": "toscar",
    "toscáreis": "toscar",
    "toscásseis": "toscar",
    "toscássemos": "toscar",
    "toscávamo": "toscar",
    "toscávamos": "toscar",
    "toscávei": "toscar",
    "toscáveis": "toscar",
    "tose": "tosar",
    "tosei": "tosar",
    "toseis": "tosar",
    "tosem": "tosar",
    "tosemo": "tosar",
    "tosemos": "tosar",
    "toses": "tosar",
    "toso": "tosar",
    "tosou": "tosar",
    "tosque": "toscar",
    "tosquei": "toscar",
    "tosqueis": "toscar",
    "tosquem": "toscar",
    "tosquemo": "toscar",
    "tosquemos": "toscar",
    "tosqueneja": "tosquenejar",
    "tosquenejada": "tosquenejar",
    "tosquenejadas": "tosquenejar",
    "tosquenejado": "tosquenejar",
    "tosquenejados": "tosquenejar",
    "tosquenejai": "tosquenejar",
    "tosquenejais": "tosquenejar",
    "tosquenejam": "tosquenejar",
    "tosquenejamo": "tosquenejar",
    "tosquenejamos": "tosquenejar",
    "tosquenejando": "tosquenejar",
    "tosquenejara": "tosquenejar",
    "tosquenejaram": "tosquenejar",
    "tosquenejaras": "tosquenejar",
    "tosquenejardes": "tosquenejar",
    "tosquenejarei": "tosquenejar",
    "tosquenejareis": "tosquenejar",
    "tosquenejarem": "tosquenejar",
    "tosquenejaremos": "tosquenejar",
    "tosquenejares": "tosquenejar",
    "tosquenejaria": "tosquenejar",
    "tosquenejariam": "tosquenejar",
    "tosquenejarias": "tosquenejar",
    "tosquenejarmo": "tosquenejar",
    "tosquenejarmos": "tosquenejar",
    "tosquenejará": "tosquenejar",
    "tosquenejarás": "tosquenejar",
    "tosquenejarão": "tosquenejar",
    "tosquenejaríamos": "tosquenejar",
    "tosquenejaríeis": "tosquenejar",
    "tosquenejas": "tosquenejar",
    "tosquenejasse": "tosquenejar",
    "tosquenejassem": "tosquenejar",
    "tosquenejasses": "tosquenejar",
    "tosquenejaste": "tosquenejar",
    "tosquenejastes": "tosquenejar",
    "tosquenejava": "tosquenejar",
    "tosquenejavam": "tosquenejar",
    "tosquenejavas": "tosquenejar",
    "tosqueneje": "tosquenejar",
    "tosquenejei": "tosquenejar",
    "tosquenejeis": "tosquenejar",
    "tosquenejem": "tosquenejar",
    "tosquenejemo": "tosquenejar",
    "tosquenejemos": "tosquenejar",
    "tosquenejes": "tosquenejar",
    "tosquenejo": "tosquenejar",
    "tosquenejou": "tosquenejar",
    "tosquenejámo": "tosquenejar",
    "tosquenejámos": "tosquenejar",
    "tosquenejáramo": "tosquenejar",
    "tosquenejáramos": "tosquenejar",
    "tosquenejáreis": "tosquenejar",
    "tosquenejásseis": "tosquenejar",
    "tosquenejássemos": "tosquenejar",
    "tosquenejávamo": "tosquenejar",
    "tosquenejávamos": "tosquenejar",
    "tosquenejáveis": "tosquenejar",
    "tosques": "toscar",
    "tosquia": "tosquiar",
    "tosquiada": "tosquiar",
    "tosquiadas": "tosquiar",
    "tosquiadeiras": "tosquiadeira",
    "tosquiadelas": "tosquiadela",
    "tosquiado": "tosquiar",
    "tosquiadora": "tosquiador",
    "tosquiadoras": "tosquiador",
    "tosquiadores": "tosquiador",
    "tosquiados": "tosquiar",
    "tosquiaduras": "tosquiadura",
    "tosquiai": "tosquiar",
    "tosquiais": "tosquiar",
    "tosquiam": "tosquiar",
    "tosquiamo": "tosquiar",
    "tosquiamos": "tosquiar",
    "tosquiando": "tosquiar",
    "tosquiara": "tosquiar",
    "tosquiaram": "tosquiar",
    "tosquiaras": "tosquiar",
    "tosquiarde": "tosquiar",
    "tosquiardes": "tosquiar",
    "tosquiare": "tosquiar",
    "tosquiarei": "tosquiar",
    "tosquiareis": "tosquiar",
    "tosquiarem": "tosquiar",
    "tosquiaremos": "tosquiar",
    "tosquiares": "tosquiar",
    "tosquiaria": "tosquiar",
    "tosquiariam": "tosquiar",
    "tosquiarias": "tosquiar",
    "tosquiarmo": "tosquiar",
    "tosquiarmos": "tosquiar",
    "tosquiará": "tosquiar",
    "tosquiarás": "tosquiar",
    "tosquiarão": "tosquiar",
    "tosquiaríamos": "tosquiar",
    "tosquiaríeis": "tosquiar",
    "tosquias": "tosquiar",
    "tosquiasse": "tosquiar",
    "tosquiassem": "tosquiar",
    "tosquiasses": "tosquiar",
    "tosquiaste": "tosquiar",
    "tosquiastes": "tosquiar",
    "tosquiava": "tosquiar",
    "tosquiavam": "tosquiar",
    "tosquiavas": "tosquiar",
    "tosquie": "tosquiar",
    "tosquiei": "tosquiar",
    "tosquieis": "tosquiar",
    "tosquiem": "tosquiar",
    "tosquiemo": "tosquiar",
    "tosquiemos": "tosquiar",
    "tosquies": "tosquiar",
    "tosquio": "tosquiar",
    "tosquiou": "tosquiar",
    "tosquiá": "tosquiar",
    "tosquiámo": "tosquiar",
    "tosquiámos": "tosquiar",
    "tosquiáramo": "tosquiar",
    "tosquiáramos": "tosquiar",
    "tosquiárei": "tosquiar",
    "tosquiáreis": "tosquiar",
    "tosquiásseis": "tosquiar",
    "tosquiássemos": "tosquiar",
    "tosquiávamo": "tosquiar",
    "tosquiávamos": "tosquiar",
    "tosquiávei": "tosquiar",
    "tosquiáveis": "tosquiar",
    "tossduras": "tossdura",
    "tosse": "tossir",
    "tossegosa": "tossegoso",
    "tossegosas": "tossegoso",
    "tossegosos": "tossegoso",
    "tossegueiras": "tossegueira",
    "tosseguenta": "tosseguento",
    "tosseguentas": "tosseguento",
    "tosseguentos": "tosseguento",
    "tosseiras": "tosseira",
    "tossem": "tossir",
    "tosses": "tossir",
    "tossi": "tossir",
    "tossia": "tossir",
    "tossiam": "tossir",
    "tossias": "tossir",
    "tossica": "tossicar",
    "tossicada": "tossicar",
    "tossicadas": "tossicar",
    "tossicado": "tossicar",
    "tossicados": "tossicar",
    "tossicai": "tossicar",
    "tossicais": "tossicar",
    "tossicam": "tossicar",
    "tossicamo": "tossicar",
    "tossicamos": "tossicar",
    "tossicando": "tossicar",
    "tossicara": "tossicar",
    "tossicaram": "tossicar",
    "tossicaras": "tossicar",
    "tossicardes": "tossicar",
    "tossicarei": "tossicar",
    "tossicareis": "tossicar",
    "tossicarem": "tossicar",
    "tossicaremos": "tossicar",
    "tossicares": "tossicar",
    "tossicaria": "tossicar",
    "tossicariam": "tossicar",
    "tossicarias": "tossicar",
    "tossicarmo": "tossicar",
    "tossicarmos": "tossicar",
    "tossicará": "tossicar",
    "tossicarás": "tossicar",
    "tossicarão": "tossicar",
    "tossicaríamos": "tossicar",
    "tossicaríeis": "tossicar",
    "tossicas": "tossicar",
    "tossicasse": "tossicar",
    "tossicassem": "tossicar",
    "tossicasses": "tossicar",
    "tossicaste": "tossicar",
    "tossicastes": "tossicar",
    "tossicava": "tossicar",
    "tossicavam": "tossicar",
    "tossicavas": "tossicar",
    "tossicou": "tossicar",
    "tossicámo": "tossicar",
    "tossicámos": "tossicar",
    "tossicáramo": "tossicar",
    "tossicáramos": "tossicar",
    "tossicáreis": "tossicar",
    "tossicásseis": "tossicar",
    "tossicássemos": "tossicar",
    "tossicávamo": "tossicar",
    "tossicávamos": "tossicar",
    "tossicáveis": "tossicar",
    "tossida": "tossir",
    "tossidas": "tossir",
    "tossidelas": "tossidela",
    "tossido": "tossir",
    "tossidos": "tossir",
    "tossimo": "tossir",
    "tossimos": "tossir",
    "tossindo": "tossir",
    "tossiquei": "tossicar",
    "tossiquenta": "tossiquento",
    "tossiquentas": "tossiquento",
    "tossiquentos": "tossiquento",
    "tossira": "tossir",
    "tossiram": "tossir",
    "tossiras": "tossir",
    "tossirdes": "tossir",
    "tossirei": "tossir",
    "tossireis": "tossir",
    "tossirem": "tossir",
    "tossiremos": "tossir",
    "tossires": "tossir",
    "tossiria": "tossir",
    "tossiriam": "tossir",
    "tossirias": "tossir",
    "tossirmo": "tossir",
    "tossirmos": "tossir",
    "tossirá": "tossir",
    "tossirás": "tossir",
    "tossirão": "tossir",
    "tossiríamos": "tossir",
    "tossiríeis": "tossir",
    "tossis": "tossir",
    "tossisse": "tossir",
    "tossissem": "tossir",
    "tossisses": "tossir",
    "tossiste": "tossir",
    "tossistes": "tossir",
    "tossiu": "tossir",
    "tossíamo": "tossir",
    "tossíamos": "tossir",
    "tossíeis": "tossir",
    "tossíramo": "tossir",
    "tossíramos": "tossir",
    "tossíreis": "tossir",
    "tossísseis": "tossir",
    "tossíssemos": "tossir",
    "tosta": "tostar",
    "tostada": "tostar",
    "tostadas": "tostar",
    "tostadelas": "tostadela",
    "tostado": "tostar",
    "tostados": "tostar",
    "tostaduras": "tostadura",
    "tostai": "tostar",
    "tostais": "tostar",
    "tostam": "tostar",
    "tostamo": "tostar",
    "tostamos": "tostar",
    "tostando": "tostar",
    "tostara": "tostar",
    "tostaram": "tostar",
    "tostaras": "tostar",
    "tostarde": "tostar",
    "tostardes": "tostar",
    "tostare": "tostar",
    "tostarei": "tostar",
    "tostareis": "tostar",
    "tostarem": "tostar",
    "tostaremos": "tostar",
    "tostares": "tostar",
    "tostaria": "tostar",
    "tostariam": "tostar",
    "tostarias": "tostar",
    "tostarmo": "tostar",
    "tostarmos": "tostar",
    "tostará": "tostar",
    "tostarás": "tostar",
    "tostarão": "tostar",
    "tostaríamos": "tostar",
    "tostaríeis": "tostar",
    "tostas": "tostar",
    "tostasse": "tostar",
    "tostassem": "tostar",
    "tostasses": "tostar",
    "tostaste": "tostar",
    "tostastes": "tostar",
    "tostava": "tostar",
    "tostavam": "tostar",
    "tostavas": "tostar",
    "toste": "tostar",
    "tostei": "tostar",
    "tosteis": "tostar",
    "tostem": "tostar",
    "tostemo": "tostar",
    "tostemos": "tostar",
    "tostes": "toste",
    "tosto": "tostar",
    "tostou": "tostar",
    "tostá": "tostar",
    "tostámo": "tostar",
    "tostámos": "tostar",
    "tostáramo": "tostar",
    "tostáramos": "tostar",
    "tostárei": "tostar",
    "tostáreis": "tostar",
    "tostásseis": "tostar",
    "tostássemos": "tostar",
    "tostávamo": "tostar",
    "tostávamos": "tostar",
    "tostávei": "tostar",
    "tostáveis": "tostar",
    "tostãozinho": "tostão",
    "tostãozito": "tostão",
    "tostões": "tostão",
    "tostõezinhos": "tostão",
    "tostõezitos": "tostão",
    "tosá": "tosar",
    "tosámo": "tosar",
    "tosámos": "tosar",
    "tosáramo": "tosar",
    "tosáramos": "tosar",
    "tosárei": "tosar",
    "tosáreis": "tosar",
    "tosásseis": "tosar",
    "tosássemos": "tosar",
    "tosávamo": "tosar",
    "tosávamos": "tosar",
    "tosávei": "tosar",
    "tosáveis": "tosar",
    "tosões": "tosão",
    "totais": "total",
    "totalidades": "totalidade",
    "totalistas": "totalista",
    "totalitarismos": "totalitarismo",
    "totalitária": "totalitário",
    "totalitárias": "totalitário",
    "totalitários": "totalitário",
    "totaliza": "totalizar",
    "totalizada": "totalizar",
    "totalizadas": "totalizar",
    "totalizado": "totalizar",
    "totalizadora": "totalizador",
    "totalizadoras": "totalizador",
    "totalizadores": "totalizador",
    "totalizados": "totalizar",
    "totalizai": "totalizar",
    "totalizais": "totalizar",
    "totalizam": "totalizar",
    "totalizamo": "totalizar",
    "totalizamos": "totalizar",
    "totalizando": "totalizar",
    "totalizara": "totalizar",
    "totalizaram": "totalizar",
    "totalizaras": "totalizar",
    "totalizarde": "totalizar",
    "totalizardes": "totalizar",
    "totalizare": "totalizar",
    "totalizarei": "totalizar",
    "totalizareis": "totalizar",
    "totalizarem": "totalizar",
    "totalizaremos": "totalizar",
    "totalizares": "totalizar",
    "totalizaria": "totalizar",
    "totalizariam": "totalizar",
    "totalizarias": "totalizar",
    "totalizarmo": "totalizar",
    "totalizarmos": "totalizar",
    "totalizará": "totalizar",
    "totalizarás": "totalizar",
    "totalizarão": "totalizar",
    "totalizaríamos": "totalizar",
    "totalizaríeis": "totalizar",
    "totalizas": "totalizar",
    "totalizasse": "totalizar",
    "totalizassem": "totalizar",
    "totalizasses": "totalizar",
    "totalizaste": "totalizar",
    "totalizastes": "totalizar",
    "totalizava": "totalizar",
    "totalizavam": "totalizar",
    "totalizavas": "totalizar",
    "totalizações": "totalização",
    "totalize": "totalizar",
    "totalizei": "totalizar",
    "totalizeis": "totalizar",
    "totalizem": "totalizar",
    "totalizemo": "totalizar",
    "totalizemos": "totalizar",
    "totalizes": "totalizar",
    "totalizo": "totalizar",
    "totalizou": "totalizar",
    "totalizá": "totalizar",
    "totalizámo": "totalizar",
    "totalizámos": "totalizar",
    "totalizáramo": "totalizar",
    "totalizáramos": "totalizar",
    "totalizárei": "totalizar",
    "totalizáreis": "totalizar",
    "totalizásseis": "totalizar",
    "totalizássemos": "totalizar",
    "totalizávamo": "totalizar",
    "totalizávamos": "totalizar",
    "totalizávei": "totalizar",
    "totalizáveis": "totalizável",
    "totelimúndis": "totelimúndi",
    "totemismos": "totemismo",
    "totens": "totem",
    "totipalmados": "totipalmado",
    "totipotentes": "totipotente",
    "totobolas": "totobola",
    "totoclubes": "totoclube",
    "totolotos": "totoloto",
    "totonegócios": "totonegócio",
    "totémica": "totémico",
    "totémicas": "totémico",
    "totémicos": "totémico",
    "totós": "totó",
    "touca": "toucar",
    "toucada": "toucar",
    "toucadas": "toucar",
    "toucado": "toucar",
    "toucadores": "toucador",
    "toucadorzinho": "toucador",
    "toucadorzinhos": "toucador",
    "toucadorzito": "toucador",
    "toucadorzitos": "toucador",
    "toucados": "toucar",
    "toucai": "toucar",
    "toucais": "toucar",
    "toucam": "toucar",
    "toucamo": "toucar",
    "toucamos": "toucar",
    "toucando": "toucar",
    "toucara": "toucar",
    "toucaram": "toucar",
    "toucaras": "toucar",
    "toucarde": "toucar",
    "toucardes": "toucar",
    "toucare": "toucar",
    "toucarei": "toucar",
    "toucareis": "toucar",
    "toucarem": "toucar",
    "toucaremos": "toucar",
    "toucares": "toucar",
    "toucaria": "toucar",
    "toucariam": "toucar",
    "toucarias": "toucar",
    "toucarmo": "toucar",
    "toucarmos": "toucar",
    "toucará": "toucar",
    "toucarás": "toucar",
    "toucarão": "toucar",
    "toucaríamos": "toucar",
    "toucaríeis": "toucar",
    "toucas": "toucar",
    "toucasse": "toucar",
    "toucassem": "toucar",
    "toucasses": "toucar",
    "toucaste": "toucar",
    "toucastes": "toucar",
    "toucava": "toucar",
    "toucavam": "toucar",
    "toucavas": "toucar",
    "touceirais": "touceiral",
    "touceiras": "touceira",
    "toucinheira": "toucinheiro",
    "toucinheiras": "toucinheiro",
    "toucinheiros": "toucinheiro",
    "toucinhos": "toucinho",
    "touco": "toucar",
    "toucou": "toucar",
    "toucá": "toucar",
    "toucámo": "toucar",
    "toucámos": "toucar",
    "toucáramo": "toucar",
    "toucáramos": "toucar",
    "toucárei": "toucar",
    "toucáreis": "toucar",
    "toucásseis": "toucar",
    "toucássemos": "toucar",
    "toucávamo": "toucar",
    "toucávamos": "toucar",
    "toucávei": "toucar",
    "toucáveis": "toucar",
    "tougues": "tougue",
    "toupeiras": "toupeira",
    "toupeirinhas": "toupeirinha",
    "toupeirões": "toupeirão",
    "touque": "toucar",
    "touquei": "toucar",
    "touqueis": "toucar",
    "touquem": "toucar",
    "touquemo": "toucar",
    "touquemos": "toucar",
    "touques": "toucar",
    "touquinha": "touca",
    "touquinhas": "touca",
    "touquita": "touca",
    "touquitas": "touca",
    "touradas": "tourada",
    "tourais": "toural",
    "tourarias": "touraria",
    "toureada": "tourear",
    "toureadas": "tourear",
    "toureado": "tourear",
    "toureadores": "toureador",
    "toureados": "tourear",
    "toureai": "tourear",
    "toureais": "tourear",
    "toureamo": "tourear",
    "toureamos": "tourear",
    "toureando": "tourear",
    "toureara": "tourear",
    "tourearam": "tourear",
    "tourearas": "tourear",
    "tourearde": "tourear",
    "toureardes": "tourear",
    "toureare": "tourear",
    "tourearei": "tourear",
    "toureareis": "tourear",
    "tourearem": "tourear",
    "tourearemos": "tourear",
    "toureares": "tourear",
    "tourearia": "tourear",
    "toureariam": "tourear",
    "tourearias": "tourear",
    "tourearmo": "tourear",
    "tourearmos": "tourear",
    "toureará": "tourear",
    "tourearás": "tourear",
    "tourearão": "tourear",
    "tourearíamos": "tourear",
    "tourearíeis": "tourear",
    "toureasse": "tourear",
    "toureassem": "tourear",
    "toureasses": "tourear",
    "toureaste": "tourear",
    "toureastes": "tourear",
    "toureava": "tourear",
    "toureavam": "tourear",
    "toureavas": "tourear",
    "toureei": "tourear",
    "toureeis": "tourear",
    "toureemo": "tourear",
    "toureemos": "tourear",
    "toureia": "tourear",
    "toureiam": "tourear",
    "toureias": "tourear",
    "toureie": "tourear",
    "toureiem": "tourear",
    "toureies": "tourear",
    "toureio": "tourear",
    "toureios": "toureio",
    "toureira": "toureiro",
    "toureiras": "toureiro",
    "toureiros": "toureiro",
    "toureja": "tourejar",
    "tourejada": "tourejar",
    "tourejadas": "tourejar",
    "tourejado": "tourejar",
    "tourejados": "tourejar",
    "tourejai": "tourejar",
    "tourejais": "tourejar",
    "tourejam": "tourejar",
    "tourejamo": "tourejar",
    "tourejamos": "tourejar",
    "tourejando": "tourejar",
    "tourejara": "tourejar",
    "tourejaram": "tourejar",
    "tourejaras": "tourejar",
    "tourejarde": "tourejar",
    "tourejardes": "tourejar",
    "tourejare": "tourejar",
    "tourejarei": "tourejar",
    "tourejareis": "tourejar",
    "tourejarem": "tourejar",
    "tourejaremos": "tourejar",
    "tourejares": "tourejar",
    "tourejaria": "tourejar",
    "tourejariam": "tourejar",
    "tourejarias": "tourejar",
    "tourejarmo": "tourejar",
    "tourejarmos": "tourejar",
    "tourejará": "tourejar",
    "tourejarás": "tourejar",
    "tourejarão": "tourejar",
    "tourejaríamos": "tourejar",
    "tourejaríeis": "tourejar",
    "tourejas": "tourejar",
    "tourejasse": "tourejar",
    "tourejassem": "tourejar",
    "tourejasses": "tourejar",
    "tourejaste": "tourejar",
    "tourejastes": "tourejar",
    "tourejava": "tourejar",
    "tourejavam": "tourejar",
    "tourejavas": "tourejar",
    "toureje": "tourejar",
    "tourejei": "tourejar",
    "tourejeis": "tourejar",
    "tourejem": "tourejar",
    "tourejemo": "tourejar",
    "tourejemos": "tourejar",
    "tourejes": "tourejar",
    "tourejo": "tourejar",
    "tourejou": "tourejar",
    "tourejá": "tourejar",
    "tourejámo": "tourejar",
    "tourejámos": "tourejar",
    "tourejáramo": "tourejar",
    "tourejáramos": "tourejar",
    "tourejárei": "tourejar",
    "tourejáreis": "tourejar",
    "tourejásseis": "tourejar",
    "tourejássemos": "tourejar",
    "tourejávamo": "tourejar",
    "tourejávamos": "tourejar",
    "tourejávei": "tourejar",
    "tourejáveis": "tourejar",
    "tourejões": "tourejão",
    "toureou": "tourear",
    "toureá": "tourear",
    "toureámo": "tourear",
    "toureámos": "tourear",
    "toureáramo": "tourear",
    "toureáramos": "tourear",
    "toureárei": "tourear",
    "toureáreis": "tourear",
    "toureásseis": "tourear",
    "toureássemos": "tourear",
    "toureávamo": "tourear",
    "toureávamos": "tourear",
    "toureávei": "tourear",
    "toureáveis": "tourear",
    "touriadora": "touriador",
    "touriadoras": "touriador",
    "touriadores": "touriador",
    "tourigas": "touriga",
    "tourinhas": "tourinha",
    "touris": "touril",
    "tournées": "tournée",
    "touros": "touro",
    "tourões": "tourão",
    "toutas": "touta",
    "touteada": "toutear",
    "touteadas": "toutear",
    "touteado": "toutear",
    "touteadora": "touteador",
    "touteadoras": "touteador",
    "touteadores": "touteador",
    "touteados": "toutear",
    "touteai": "toutear",
    "touteais": "toutear",
    "touteamo": "toutear",
    "touteamos": "toutear",
    "touteando": "toutear",
    "touteara": "toutear",
    "toutearam": "toutear",
    "toutearas": "toutear",
    "touteardes": "toutear",
    "toutearei": "toutear",
    "touteareis": "toutear",
    "toutearem": "toutear",
    "toutearemos": "toutear",
    "touteares": "toutear",
    "toutearia": "toutear",
    "touteariam": "toutear",
    "toutearias": "toutear",
    "toutearmo": "toutear",
    "toutearmos": "toutear",
    "touteará": "toutear",
    "toutearás": "toutear",
    "toutearão": "toutear",
    "toutearíamos": "toutear",
    "toutearíeis": "toutear",
    "touteasse": "toutear",
    "touteassem": "toutear",
    "touteasses": "toutear",
    "touteaste": "toutear",
    "touteastes": "toutear",
    "touteava": "toutear",
    "touteavam": "toutear",
    "touteavas": "toutear",
    "touteei": "toutear",
    "touteeis": "toutear",
    "touteemo": "toutear",
    "touteemos": "toutear",
    "touteia": "toutear",
    "touteiam": "toutear",
    "touteias": "toutear",
    "touteie": "toutear",
    "touteiem": "toutear",
    "touteies": "toutear",
    "touteio": "toutear",
    "toutela": "toutelo",
    "toutelas": "toutelo",
    "toutelos": "toutelo",
    "touteou": "toutear",
    "touteámo": "toutear",
    "touteámos": "toutear",
    "touteáramo": "toutear",
    "touteáramos": "toutear",
    "touteáreis": "toutear",
    "touteásseis": "toutear",
    "touteássemos": "toutear",
    "touteávamo": "toutear",
    "touteávamos": "toutear",
    "touteáveis": "toutear",
    "toutinegras": "toutinegra",
    "toutiçadas": "toutiçada",
    "toutiços": "toutiço",
    "touças": "touça",
    "touços": "touço",
    "toxemias": "toxemia",
    "toxica": "toxicar",
    "toxicada": "toxicar",
    "toxicadas": "toxicar",
    "toxicado": "toxicar",
    "toxicados": "toxicar",
    "toxicai": "toxicar",
    "toxicais": "toxicar",
    "toxicam": "toxicar",
    "toxicamo": "toxicar",
    "toxicamos": "toxicar",
    "toxicando": "toxicar",
    "toxicara": "toxicar",
    "toxicaram": "toxicar",
    "toxicaras": "toxicar",
    "toxicarde": "toxicar",
    "toxicardes": "toxicar",
    "toxicare": "toxicar",
    "toxicarei": "toxicar",
    "toxicareis": "toxicar",
    "toxicarem": "toxicar",
    "toxicaremos": "toxicar",
    "toxicares": "toxicar",
    "toxicaria": "toxicar",
    "toxicariam": "toxicar",
    "toxicarias": "toxicar",
    "toxicarmo": "toxicar",
    "toxicarmos": "toxicar",
    "toxicará": "toxicar",
    "toxicarás": "toxicar",
    "toxicarão": "toxicar",
    "toxicaríamos": "toxicar",
    "toxicaríeis": "toxicar",
    "toxicas": "toxicar",
    "toxicasse": "toxicar",
    "toxicassem": "toxicar",
    "toxicasses": "toxicar",
    "toxicaste": "toxicar",
    "toxicastes": "toxicar",
    "toxicava": "toxicar",
    "toxicavam": "toxicar",
    "toxicavas": "toxicar",
    "toxicemias": "toxicemia",
    "toxicidades": "toxicidade",
    "toxico": "toxicar",
    "toxicodependentes": "toxicodependente",
    "toxicodependências": "toxicodependência",
    "toxicofagias": "toxicofagia",
    "toxicofobias": "toxicofobia",
    "toxicologias": "toxicologia",
    "toxicologistas": "toxicologista",
    "toxicológica": "toxicológico",
    "toxicológicas": "toxicológico",
    "toxicológicos": "toxicológico",
    "toxicomanias": "toxicomania",
    "toxicomaníaca": "toxicomaníaco",
    "toxicomaníacas": "toxicomaníaco",
    "toxicomaníacos": "toxicomaníaco",
    "toxicopatias": "toxicopatia",
    "toxicoses": "toxicose",
    "toxicou": "toxicar",
    "toxicá": "toxicar",
    "toxicámo": "toxicar",
    "toxicámos": "toxicar",
    "toxicáramo": "toxicar",
    "toxicáramos": "toxicar",
    "toxicárei": "toxicar",
    "toxicáreis": "toxicar",
    "toxicásseis": "toxicar",
    "toxicássemos": "toxicar",
    "toxicávamo": "toxicar",
    "toxicávamos": "toxicar",
    "toxicávei": "toxicar",
    "toxicáveis": "toxicar",
    "toxicófagos": "toxicófago",
    "toxicófora": "toxicóforo",
    "toxicóforas": "toxicóforo",
    "toxicóforos": "toxicóforo",
    "toxicógena": "toxicógeno",
    "toxicógenas": "toxicógeno",
    "toxicógenos": "toxicógeno",
    "toxicóloga": "toxicólogo",
    "toxicólogas": "toxicólogo",
    "toxicólogos": "toxicólogo",
    "toxicómana": "toxicómano",
    "toxicómanas": "toxicómano",
    "toxicómanos": "toxicómano",
    "toxidades": "toxidade",
    "toxidermias": "toxidermia",
    "toxidérmica": "toxidérmico",
    "toxidérmicas": "toxidérmico",
    "toxidérmicos": "toxidérmico",
    "toxinas": "toxina",
    "toxinoses": "toxinose",
    "toxique": "toxicar",
    "toxiquei": "toxicar",
    "toxiqueis": "toxicar",
    "toxiquem": "toxicar",
    "toxiquemo": "toxicar",
    "toxiquemos": "toxicar",
    "toxiques": "toxicar",
    "toxiterapias": "toxiterapia",
    "toxodontes": "toxodonte",
    "toxofila": "toxofilo",
    "toxofilas": "toxofilo",
    "toxofilos": "toxofilo",
    "toxoplasmoses": "toxoplasmose",
    "toxotídeos": "toxotídeo",
    "toxígena": "toxígeno",
    "toxígenas": "toxígeno",
    "toxígenos": "toxígeno",
    "toámo": "toar",
    "toámos": "toar",
    "toáramo": "toar",
    "toáramos": "toar",
    "toáreis": "toar",
    "toásseis": "toar",
    "toássemos": "toar",
    "toávamo": "toar",
    "toávamos": "toar",
    "toáveis": "toar",
    "trabais": "trabal",
    "trabalha": "trabalhar",
    "trabalhada": "trabalhar",
    "trabalhadas": "trabalhar",
    "trabalhadeira": "trabalhador",
    "trabalhadeiras": "trabalhador",
    "trabalhadeirazinha": "trabalhador",
    "trabalhadeirazinhas": "trabalhador",
    "trabalhadeirazita": "trabalhador",
    "trabalhadeirazitas": "trabalhador",
    "trabalhado": "trabalhar",
    "trabalhadora": "trabalhador",
    "trabalhadoras": "trabalhador",
    "trabalhadorazinha": "trabalhador",
    "trabalhadorazinhas": "trabalhador",
    "trabalhadorazita": "trabalhador",
    "trabalhadorazitas": "trabalhador",
    "trabalhadores": "trabalhador",
    "trabalhadorzinho": "trabalhador",
    "trabalhadorzinhos": "trabalhador",
    "trabalhadorzito": "trabalhador",
    "trabalhadorzitos": "trabalhador",
    "trabalhados": "trabalhar",
    "trabalhai": "trabalhar",
    "trabalhais": "trabalhar",
    "trabalham": "trabalhar",
    "trabalhamo": "trabalhar",
    "trabalhamos": "trabalhar",
    "trabalhando": "trabalhar",
    "trabalhara": "trabalhar",
    "trabalharam": "trabalhar",
    "trabalharas": "trabalhar",
    "trabalharde": "trabalhar",
    "trabalhardes": "trabalhar",
    "trabalhare": "trabalhar",
    "trabalharei": "trabalhar",
    "trabalhareis": "trabalhar",
    "trabalharem": "trabalhar",
    "trabalharemos": "trabalhar",
    "trabalhares": "trabalhar",
    "trabalharia": "trabalhar",
    "trabalhariam": "trabalhar",
    "trabalharias": "trabalhar",
    "trabalharmo": "trabalhar",
    "trabalharmos": "trabalhar",
    "trabalhará": "trabalhar",
    "trabalharás": "trabalhar",
    "trabalharão": "trabalhar",
    "trabalharíamos": "trabalhar",
    "trabalharíeis": "trabalhar",
    "trabalhas": "trabalhar",
    "trabalhasse": "trabalhar",
    "trabalhassem": "trabalhar",
    "trabalhasses": "trabalhar",
    "trabalhaste": "trabalhar",
    "trabalhastes": "trabalhar",
    "trabalhava": "trabalhar",
    "trabalhavam": "trabalhar",
    "trabalhavas": "trabalhar",
    "trabalhe": "trabalhar",
    "trabalhei": "trabalhar",
    "trabalheiras": "trabalheira",
    "trabalheis": "trabalhar",
    "trabalhem": "trabalhar",
    "trabalhemo": "trabalhar",
    "trabalhemos": "trabalhar",
    "trabalhes": "trabalhar",
    "trabalhinho": "trabalho",
    "trabalhinhos": "trabalho",
    "trabalhismos": "trabalhismo",
    "trabalhistas": "trabalhista",
    "trabalhito": "trabalho",
    "trabalhitos": "trabalho",
    "trabalho": "trabalhar",
    "trabalhos": "trabalho",
    "trabalhosa": "trabalhoso",
    "trabalhosas": "trabalhoso",
    "trabalhosos": "trabalhoso",
    "trabalhou": "trabalhar",
    "trabalhá": "trabalhar",
    "trabalhámo": "trabalhar",
    "trabalhámos": "trabalhar",
    "trabalháramo": "trabalhar",
    "trabalháramos": "trabalhar",
    "trabalhárei": "trabalhar",
    "trabalháreis": "trabalhar",
    "trabalhásseis": "trabalhar",
    "trabalhássemos": "trabalhar",
    "trabalhávamo": "trabalhar",
    "trabalhávamos": "trabalhar",
    "trabalhávei": "trabalhar",
    "trabalháveis": "trabalhar",
    "trabalhões": "trabalhão",
    "trabeculada": "trabeculado",
    "trabeculadas": "trabeculado",
    "trabeculados": "trabeculado",
    "trabeculosa": "trabeculoso",
    "trabeculosas": "trabeculoso",
    "trabeculosos": "trabeculoso",
    "trabelhos": "trabelho",
    "trabuca": "trabucar",
    "trabucada": "trabucar",
    "trabucadas": "trabucar",
    "trabucado": "trabucar",
    "trabucadora": "trabucador",
    "trabucadoras": "trabucador",
    "trabucadores": "trabucador",
    "trabucados": "trabucar",
    "trabucai": "trabucar",
    "trabucais": "trabucar",
    "trabucam": "trabucar",
    "trabucamo": "trabucar",
    "trabucamos": "trabucar",
    "trabucando": "trabucar",
    "trabucara": "trabucar",
    "trabucaram": "trabucar",
    "trabucaras": "trabucar",
    "trabucarde": "trabucar",
    "trabucardes": "trabucar",
    "trabucare": "trabucar",
    "trabucarei": "trabucar",
    "trabucareis": "trabucar",
    "trabucarem": "trabucar",
    "trabucaremos": "trabucar",
    "trabucares": "trabucar",
    "trabucaria": "trabucar",
    "trabucariam": "trabucar",
    "trabucarias": "trabucar",
    "trabucarmo": "trabucar",
    "trabucarmos": "trabucar",
    "trabucará": "trabucar",
    "trabucarás": "trabucar",
    "trabucarão": "trabucar",
    "trabucaríamos": "trabucar",
    "trabucaríeis": "trabucar",
    "trabucas": "trabucar",
    "trabucasse": "trabucar",
    "trabucassem": "trabucar",
    "trabucasses": "trabucar",
    "trabucaste": "trabucar",
    "trabucastes": "trabucar",
    "trabucava": "trabucar",
    "trabucavam": "trabucar",
    "trabucavas": "trabucar",
    "trabuco": "trabucar",
    "trabucos": "trabuco",
    "trabucou": "trabucar",
    "trabucá": "trabucar",
    "trabucámo": "trabucar",
    "trabucámos": "trabucar",
    "trabucáramo": "trabucar",
    "trabucáramos": "trabucar",
    "trabucárei": "trabucar",
    "trabucáreis": "trabucar",
    "trabucásseis": "trabucar",
    "trabucássemos": "trabucar",
    "trabucávamo": "trabucar",
    "trabucávamos": "trabucar",
    "trabucávei": "trabucar",
    "trabucáveis": "trabucar",
    "trabula": "trabular",
    "trabulada": "trabular",
    "trabuladas": "trabular",
    "trabulado": "trabular",
    "trabulados": "trabular",
    "trabulai": "trabular",
    "trabulais": "trabular",
    "trabulam": "trabular",
    "trabulamo": "trabular",
    "trabulamos": "trabular",
    "trabulando": "trabular",
    "trabulara": "trabular",
    "trabularam": "trabular",
    "trabularas": "trabular",
    "trabularde": "trabular",
    "trabulardes": "trabular",
    "trabulare": "trabular",
    "trabularei": "trabular",
    "trabulareis": "trabular",
    "trabularem": "trabular",
    "trabularemos": "trabular",
    "trabulares": "trabular",
    "trabularia": "trabular",
    "trabulariam": "trabular",
    "trabularias": "trabular",
    "trabularmo": "trabular",
    "trabularmos": "trabular",
    "trabulará": "trabular",
    "trabularás": "trabular",
    "trabularão": "trabular",
    "trabularíamos": "trabular",
    "trabularíeis": "trabular",
    "trabulas": "trabular",
    "trabulasse": "trabular",
    "trabulassem": "trabular",
    "trabulasses": "trabular",
    "trabulaste": "trabular",
    "trabulastes": "trabular",
    "trabulava": "trabular",
    "trabulavam": "trabular",
    "trabulavas": "trabular",
    "trabule": "trabular",
    "trabulei": "trabular",
    "trabuleis": "trabular",
    "trabulem": "trabular",
    "trabulemo": "trabular",
    "trabulemos": "trabular",
    "trabules": "trabular",
    "trabulo": "trabular",
    "trabulos": "trabulo",
    "trabulou": "trabular",
    "trabulá": "trabular",
    "trabulámo": "trabular",
    "trabulámos": "trabular",
    "trabuláramo": "trabular",
    "trabuláramos": "trabular",
    "trabulárei": "trabular",
    "trabuláreis": "trabular",
    "trabulásseis": "trabular",
    "trabulássemos": "trabular",
    "trabulávamo": "trabular",
    "trabulávamos": "trabular",
    "trabulávei": "trabular",
    "trabuláveis": "trabular",
    "trabuque": "trabucar",
    "trabuquei": "trabucar",
    "trabuqueira": "trabuqueiro",
    "trabuqueiras": "trabuqueiro",
    "trabuqueiros": "trabuqueiro",
    "trabuqueis": "trabucar",
    "trabuquem": "trabucar",
    "trabuquemo": "trabucar",
    "trabuquemos": "trabucar",
    "trabuques": "trabucar",
    "trabuquetes": "trabuquete",
    "trabuzanadas": "trabuzanada",
    "trabuzanas": "trabuzana",
    "trabéculas": "trabécula",
    "tracalhazes": "tracalhaz",
    "tracanazes": "tracanaz",
    "tracanaços": "tracanaço",
    "trace": "traçar",
    "tracei": "traçar",
    "traceis": "traçar",
    "traceja": "tracejar",
    "tracejada": "tracejar",
    "tracejadas": "tracejar",
    "tracejado": "tracejar",
    "tracejados": "tracejar",
    "tracejai": "tracejar",
    "tracejais": "tracejar",
    "tracejam": "tracejar",
    "tracejamentos": "tracejamento",
    "tracejamo": "tracejar",
    "tracejamos": "tracejar",
    "tracejando": "tracejar",
    "tracejara": "tracejar",
    "tracejaram": "tracejar",
    "tracejaras": "tracejar",
    "tracejarde": "tracejar",
    "tracejardes": "tracejar",
    "tracejare": "tracejar",
    "tracejarei": "tracejar",
    "tracejareis": "tracejar",
    "tracejarem": "tracejar",
    "tracejaremos": "tracejar",
    "tracejares": "tracejar",
    "tracejaria": "tracejar",
    "tracejariam": "tracejar",
    "tracejarias": "tracejar",
    "tracejarmo": "tracejar",
    "tracejarmos": "tracejar",
    "tracejará": "tracejar",
    "tracejarás": "tracejar",
    "tracejarão": "tracejar",
    "tracejaríamos": "tracejar",
    "tracejaríeis": "tracejar",
    "tracejas": "tracejar",
    "tracejasse": "tracejar",
    "tracejassem": "tracejar",
    "tracejasses": "tracejar",
    "tracejaste": "tracejar",
    "tracejastes": "tracejar",
    "tracejava": "tracejar",
    "tracejavam": "tracejar",
    "tracejavas": "tracejar",
    "traceje": "tracejar",
    "tracejei": "tracejar",
    "tracejeis": "tracejar",
    "tracejem": "tracejar",
    "tracejemo": "tracejar",
    "tracejemos": "tracejar",
    "tracejes": "tracejar",
    "tracejo": "tracejar",
    "tracejou": "tracejar",
    "tracejá": "tracejar",
    "tracejámo": "tracejar",
    "tracejámos": "tracejar",
    "tracejáramo": "tracejar",
    "tracejáramos": "tracejar",
    "tracejárei": "tracejar",
    "tracejáreis": "tracejar",
    "tracejásseis": "tracejar",
    "tracejássemos": "tracejar",
    "tracejávamo": "tracejar",
    "tracejávamos": "tracejar",
    "tracejávei": "tracejar",
    "tracejáveis": "tracejar",
    "tracem": "traçar",
    "tracemo": "traçar",
    "tracemos": "traçar",
    "traces": "traçar",
    "tracinho": "traço",
    "tracinhos": "traço",
    "tracistas": "tracista",
    "tracito": "traço",
    "tracitos": "traço",
    "tracomas": "tracoma",
    "tracomatosa": "tracomatoso",
    "tracomatosas": "tracomatoso",
    "tracomatosos": "tracomatoso",
    "tractora": "tractor",
    "tractoras": "tractor",
    "tractores": "tractor",
    "tractoristas": "tractorista",
    "tractos": "tracto",
    "tractória": "tractório",
    "tractórias": "tractório",
    "tractórios": "tractório",
    "tracções": "tracção",
    "tracóides": "tracóide",
    "tradeada": "tradear",
    "tradeadas": "tradear",
    "tradeado": "tradear",
    "tradeados": "tradear",
    "tradeai": "tradear",
    "tradeais": "tradear",
    "tradeamo": "tradear",
    "tradeamos": "tradear",
    "tradeando": "tradear",
    "tradeara": "tradear",
    "tradearam": "tradear",
    "tradearas": "tradear",
    "tradearde": "tradear",
    "tradeardes": "tradear",
    "tradeare": "tradear",
    "tradearei": "tradear",
    "tradeareis": "tradear",
    "tradearem": "tradear",
    "tradearemos": "tradear",
    "tradeares": "tradear",
    "tradearia": "tradear",
    "tradeariam": "tradear",
    "tradearias": "tradear",
    "tradearmo": "tradear",
    "tradearmos": "tradear",
    "tradeará": "tradear",
    "tradearás": "tradear",
    "tradearão": "tradear",
    "tradearíamos": "tradear",
    "tradearíeis": "tradear",
    "tradeasse": "tradear",
    "tradeassem": "tradear",
    "tradeasses": "tradear",
    "tradeaste": "tradear",
    "tradeastes": "tradear",
    "tradeava": "tradear",
    "tradeavam": "tradear",
    "tradeavas": "tradear",
    "tradeei": "tradear",
    "tradeeis": "tradear",
    "tradeemo": "tradear",
    "tradeemos": "tradear",
    "tradeia": "tradear",
    "tradeiam": "tradear",
    "tradeias": "tradear",
    "tradeie": "tradear",
    "tradeiem": "tradear",
    "tradeies": "tradear",
    "tradeio": "tradear",
    "tradelas": "tradela",
    "tradeou": "tradear",
    "tradescâncias": "tradescância",
    "tradeá": "tradear",
    "tradeámo": "tradear",
    "tradeámos": "tradear",
    "tradeáramo": "tradear",
    "tradeáramos": "tradear",
    "tradeárei": "tradear",
    "tradeáreis": "tradear",
    "tradeásseis": "tradear",
    "tradeássemos": "tradear",
    "tradeávamo": "tradear",
    "tradeávamos": "tradear",
    "tradeávei": "tradear",
    "tradeáveis": "tradear",
    "tradicionais": "tradicional",
    "tradicionalidades": "tradicionalidade",
    "tradicionalismos": "tradicionalismo",
    "tradicionalistas": "tradicionalista",
    "tradicionária": "tradicionário",
    "tradicionárias": "tradicionário",
    "tradicionários": "tradicionário",
    "tradinhas": "tradinha",
    "tradições": "tradição",
    "trados": "trado",
    "traducianismos": "traducianismo",
    "tradutora": "tradutor",
    "tradutoras": "tradutor",
    "tradutores": "tradutor",
    "traduz": "traduzir",
    "traduza": "traduzir",
    "traduzais": "traduzir",
    "traduzam": "traduzir",
    "traduzamo": "traduzir",
    "traduzamos": "traduzir",
    "traduzas": "traduzir",
    "traduze": "traduzir",
    "traduzem": "traduzir",
    "traduzes": "traduzir",
    "traduzi": "traduzir",
    "traduzia": "traduzir",
    "traduziam": "traduzir",
    "traduzias": "traduzir",
    "traduzida": "traduzir",
    "traduzidas": "traduzir",
    "traduzideiros": "traduzideiro",
    "traduzido": "traduzir",
    "traduzidora": "traduzidor",
    "traduzidoras": "traduzidor",
    "traduzidores": "traduzidor",
    "traduzidos": "traduzir",
    "traduzimo": "traduzir",
    "traduzimos": "traduzir",
    "traduzindo": "traduzir",
    "traduzira": "traduzir",
    "traduziram": "traduzir",
    "traduziras": "traduzir",
    "traduzirde": "traduzir",
    "traduzirdes": "traduzir",
    "traduzire": "traduzir",
    "traduzirei": "traduzir",
    "traduzireis": "traduzir",
    "traduzirem": "traduzir",
    "traduziremos": "traduzir",
    "traduzires": "traduzir",
    "traduziria": "traduzir",
    "traduziriam": "traduzir",
    "traduzirias": "traduzir",
    "traduzirmo": "traduzir",
    "traduzirmos": "traduzir",
    "traduzirá": "traduzir",
    "traduzirás": "traduzir",
    "traduzirão": "traduzir",
    "traduziríamos": "traduzir",
    "traduziríeis": "traduzir",
    "traduzis": "traduzir",
    "traduzisse": "traduzir",
    "traduzissem": "traduzir",
    "traduzisses": "traduzir",
    "traduziste": "traduzir",
    "traduzistes": "traduzir",
    "traduziu": "traduzir",
    "traduzo": "traduzir",
    "traduzíamo": "traduzir",
    "traduzíamos": "traduzir",
    "traduzíei": "traduzir",
    "traduzíeis": "traduzir",
    "traduzíramo": "traduzir",
    "traduzíramos": "traduzir",
    "traduzírei": "traduzir",
    "traduzíreis": "traduzir",
    "traduzísseis": "traduzir",
    "traduzíssemos": "traduzir",
    "traduzíveis": "traduzível",
    "traduções": "tradução",
    "traem": "trair",
    "trafagueiros": "trafagueiro",
    "trafega": "trafegar",
    "trafegada": "trafegar",
    "trafegadas": "trafegar",
    "trafegado": "trafegar",
    "trafegados": "trafegar",
    "trafegai": "trafegar",
    "trafegais": "trafegar",
    "trafegam": "trafegar",
    "trafegamo": "trafegar",
    "trafegamos": "trafegar",
    "trafegando": "trafegar",
    "trafegara": "trafegar",
    "trafegaram": "trafegar",
    "trafegaras": "trafegar",
    "trafegardes": "trafegar",
    "trafegarei": "trafegar",
    "trafegareis": "trafegar",
    "trafegarem": "trafegar",
    "trafegaremos": "trafegar",
    "trafegares": "trafegar",
    "trafegaria": "trafegar",
    "trafegariam": "trafegar",
    "trafegarias": "trafegar",
    "trafegarmo": "trafegar",
    "trafegarmos": "trafegar",
    "trafegará": "trafegar",
    "trafegarás": "trafegar",
    "trafegarão": "trafegar",
    "trafegaríamos": "trafegar",
    "trafegaríeis": "trafegar",
    "trafegas": "trafegar",
    "trafegasse": "trafegar",
    "trafegassem": "trafegar",
    "trafegasses": "trafegar",
    "trafegaste": "trafegar",
    "trafegastes": "trafegar",
    "trafegava": "trafegar",
    "trafegavam": "trafegar",
    "trafegavas": "trafegar",
    "trafego": "trafegar",
    "trafegou": "trafegar",
    "trafegue": "trafegar",
    "trafegueada": "trafeguear",
    "trafegueadas": "trafeguear",
    "trafegueado": "trafeguear",
    "trafegueados": "trafeguear",
    "trafegueai": "trafeguear",
    "trafegueais": "trafeguear",
    "trafegueamo": "trafeguear",
    "trafegueamos": "trafeguear",
    "trafegueando": "trafeguear",
    "trafegueara": "trafeguear",
    "trafeguearam": "trafeguear",
    "trafeguearas": "trafeguear",
    "trafegueardes": "trafeguear",
    "trafeguearei": "trafeguear",
    "trafegueareis": "trafeguear",
    "trafeguearem": "trafeguear",
    "trafeguearemos": "trafeguear",
    "trafegueares": "trafeguear",
    "trafeguearia": "trafeguear",
    "trafegueariam": "trafeguear",
    "trafeguearias": "trafeguear",
    "trafeguearmo": "trafeguear",
    "trafeguearmos": "trafeguear",
    "trafegueará": "trafeguear",
    "trafeguearás": "trafeguear",
    "trafeguearão": "trafeguear",
    "trafeguearíamos": "trafeguear",
    "trafeguearíeis": "trafeguear",
    "trafegueasse": "trafeguear",
    "trafegueassem": "trafeguear",
    "trafegueasses": "trafeguear",
    "trafegueaste": "trafeguear",
    "trafegueastes": "trafeguear",
    "trafegueava": "trafeguear",
    "trafegueavam": "trafeguear",
    "trafegueavas": "trafeguear",
    "trafegueei": "trafeguear",
    "trafegueeis": "trafeguear",
    "trafegueemo": "trafeguear",
    "trafegueemos": "trafeguear",
    "trafeguei": "trafegar",
    "trafegueia": "trafeguear",
    "trafegueiam": "trafeguear",
    "trafegueias": "trafeguear",
    "trafegueie": "trafeguear",
    "trafegueiem": "trafeguear",
    "trafegueies": "trafeguear",
    "trafegueio": "trafeguear",
    "trafegueis": "trafegar",
    "trafeguem": "trafegar",
    "trafeguemo": "trafegar",
    "trafeguemos": "trafegar",
    "trafegueou": "trafeguear",
    "trafegues": "trafegar",
    "trafegueámo": "trafeguear",
    "trafegueámos": "trafeguear",
    "trafegueáramo": "trafeguear",
    "trafegueáramos": "trafeguear",
    "trafegueáreis": "trafeguear",
    "trafegueásseis": "trafeguear",
    "trafegueássemos": "trafeguear",
    "trafegueávamo": "trafeguear",
    "trafegueávamos": "trafeguear",
    "trafegueáveis": "trafeguear",
    "trafegámo": "trafegar",
    "trafegámos": "trafegar",
    "trafegáramo": "trafegar",
    "trafegáramos": "trafegar",
    "trafegáreis": "trafegar",
    "trafegásseis": "trafegar",
    "trafegássemos": "trafegar",
    "trafegávamo": "trafegar",
    "trafegávamos": "trafegar",
    "trafegáveis": "trafegar",
    "trafica": "traficar",
    "traficada": "traficar",
    "traficadas": "traficar",
    "traficado": "traficar",
    "traficados": "traficar",
    "traficai": "traficar",
    "traficais": "traficar",
    "traficam": "traficar",
    "traficamo": "traficar",
    "traficamos": "traficar",
    "traficando": "traficar",
    "traficantes": "traficante",
    "traficara": "traficar",
    "traficaram": "traficar",
    "traficaras": "traficar",
    "traficarde": "traficar",
    "traficardes": "traficar",
    "traficare": "traficar",
    "traficarei": "traficar",
    "traficareis": "traficar",
    "traficarem": "traficar",
    "traficaremos": "traficar",
    "traficares": "traficar",
    "traficaria": "traficar",
    "traficariam": "traficar",
    "traficarias": "traficar",
    "traficarmo": "traficar",
    "traficarmos": "traficar",
    "traficará": "traficar",
    "traficarás": "traficar",
    "traficarão": "traficar",
    "traficaríamos": "traficar",
    "traficaríeis": "traficar",
    "traficas": "traficar",
    "traficasse": "traficar",
    "traficassem": "traficar",
    "traficasses": "traficar",
    "traficaste": "traficar",
    "traficastes": "traficar",
    "traficava": "traficar",
    "traficavam": "traficar",
    "traficavas": "traficar",
    "trafico": "traficar",
    "traficou": "traficar",
    "traficá": "traficar",
    "traficámo": "traficar",
    "traficámos": "traficar",
    "traficáramo": "traficar",
    "traficáramos": "traficar",
    "traficárei": "traficar",
    "traficáreis": "traficar",
    "traficásseis": "traficar",
    "traficássemos": "traficar",
    "traficávamo": "traficar",
    "traficávamos": "traficar",
    "traficávei": "traficar",
    "traficáveis": "traficar",
    "traficâncias": "traficância",
    "trafique": "traficar",
    "trafiquei": "traficar",
    "trafiqueis": "traficar",
    "trafiquem": "traficar",
    "trafiquemo": "traficar",
    "trafiquemos": "traficar",
    "trafiques": "traficar",
    "trafogueiros": "trafogueiro",
    "trafulhas": "trafulha",
    "trafulhices": "trafulhice",
    "traga": "trazer",
    "tragada": "tragar",
    "tragadas": "tragar",
    "tragado": "tragar",
    "tragadoiros": "tragadoiro",
    "tragadora": "tragador",
    "tragadoras": "tragador",
    "tragadores": "tragador",
    "tragados": "tragar",
    "tragadouros": "tragadouro",
    "tragai": "tragar",
    "tragais": "trazer",
    "tragam": "trazer",
    "tragamentos": "tragamento",
    "tragamo": "trazer",
    "tragamos": "trazer",
    "tragando": "tragar",
    "tragara": "tragar",
    "tragaram": "tragar",
    "tragaras": "tragar",
    "tragarde": "tragar",
    "tragardes": "tragar",
    "tragare": "tragar",
    "tragarei": "tragar",
    "tragareis": "tragar",
    "tragarem": "tragar",
    "tragaremos": "tragar",
    "tragares": "tragar",
    "tragaria": "tragar",
    "tragariam": "tragar",
    "tragarias": "tragar",
    "tragarmo": "tragar",
    "tragarmos": "tragar",
    "tragará": "tragar",
    "tragarás": "tragar",
    "tragarão": "tragar",
    "tragaríamos": "tragar",
    "tragaríeis": "tragar",
    "tragas": "trazer",
    "tragasse": "tragar",
    "tragassem": "tragar",
    "tragasses": "tragar",
    "tragaste": "tragar",
    "tragastes": "tragar",
    "tragava": "tragar",
    "tragavam": "tragar",
    "tragavas": "tragar",
    "tragazes": "tragaz",
    "tragedia": "tragediar",
    "tragediada": "tragediar",
    "tragediadas": "tragediar",
    "tragediado": "tragediar",
    "tragediados": "tragediar",
    "tragediai": "tragediar",
    "tragediais": "tragediar",
    "tragediam": "tragediar",
    "tragediamo": "tragediar",
    "tragediamos": "tragediar",
    "tragediando": "tragediar",
    "tragediara": "tragediar",
    "tragediaram": "tragediar",
    "tragediaras": "tragediar",
    "tragediarde": "tragediar",
    "tragediardes": "tragediar",
    "tragediare": "tragediar",
    "tragediarei": "tragediar",
    "tragediareis": "tragediar",
    "tragediarem": "tragediar",
    "tragediaremos": "tragediar",
    "tragediares": "tragediar",
    "tragediaria": "tragediar",
    "tragediariam": "tragediar",
    "tragediarias": "tragediar",
    "tragediarmo": "tragediar",
    "tragediarmos": "tragediar",
    "tragediará": "tragediar",
    "tragediarás": "tragediar",
    "tragediarão": "tragediar",
    "tragediaríamos": "tragediar",
    "tragediaríeis": "tragediar",
    "tragedias": "tragediar",
    "tragediasse": "tragediar",
    "tragediassem": "tragediar",
    "tragediasses": "tragediar",
    "tragediaste": "tragediar",
    "tragediastes": "tragediar",
    "tragediava": "tragediar",
    "tragediavam": "tragediar",
    "tragediavas": "tragediar",
    "tragedie": "tragediar",
    "tragediei": "tragediar",
    "tragedieis": "tragediar",
    "tragediem": "tragediar",
    "tragediemo": "tragediar",
    "tragediemos": "tragediar",
    "tragedies": "tragediar",
    "tragedio": "tragediar",
    "tragediou": "tragediar",
    "tragediá": "tragediar",
    "tragediámo": "tragediar",
    "tragediámos": "tragediar",
    "tragediáramo": "tragediar",
    "tragediáramos": "tragediar",
    "tragediárei": "tragediar",
    "tragediáreis": "tragediar",
    "tragediásseis": "tragediar",
    "tragediássemos": "tragediar",
    "tragediávamo": "tragediar",
    "tragediávamos": "tragediar",
    "tragediávei": "tragediar",
    "tragediáveis": "tragediar",
    "tragediógrafos": "tragediógrafo",
    "tragicazinha": "trágico",
    "tragicazinhas": "trágico",
    "tragicazita": "trágico",
    "tragicazitas": "trágico",
    "tragicomédias": "tragicomédia",
    "tragicozinho": "trágico",
    "tragicozinhos": "trágico",
    "tragicozito": "trágico",
    "tragicozitos": "trágico",
    "tragicómica": "tragicómico",
    "tragicómicas": "tragicómico",
    "tragicómicos": "tragicómico",
    "tragifarsas": "tragifarsa",
    "trago": "trazer",
    "tragos": "trago",
    "tragou": "tragar",
    "trague": "tragar",
    "traguei": "tragar",
    "tragueis": "tragar",
    "traguem": "tragar",
    "traguemo": "tragar",
    "traguemos": "tragar",
    "tragues": "tragar",
    "tragulídeos": "tragulídeo",
    "tragá": "tragar",
    "tragámo": "tragar",
    "tragámos": "tragar",
    "tragáramo": "tragar",
    "tragáramos": "tragar",
    "tragárei": "tragar",
    "tragáreis": "tragar",
    "tragásseis": "tragar",
    "tragássemos": "tragar",
    "tragávamo": "tragar",
    "tragávamos": "tragar",
    "tragávei": "tragar",
    "tragáveis": "tragável",
    "tragédias": "tragédia",
    "trai": "trair",
    "traia": "trair",
    "traiais": "trair",
    "traiam": "trair",
    "traiamo": "trair",
    "traiamos": "trair",
    "traias": "trair",
    "traidora": "traidor",
    "traidoras": "traidor",
    "traidores": "traidor",
    "traimentos": "traimento",
    "trainas": "traina",
    "traindo": "trair",
    "traineiras": "traineira",
    "traineis": "trainel",
    "traio": "trair",
    "trairde": "trair",
    "trairdes": "trair",
    "trairei": "trair",
    "traireis": "trair",
    "trairemos": "trair",
    "trairia": "trair",
    "trairiam": "trair",
    "trairias": "trair",
    "trairmo": "trair",
    "trairmos": "trair",
    "trairá": "trair",
    "trairás": "trair",
    "trairão": "trair",
    "trairíamos": "trair",
    "trairíeis": "trair",
    "trais": "trair",
    "traites": "traite",
    "traiu": "trair",
    "traiçoeira": "traiçoeiro",
    "traiçoeiras": "traiçoeiro",
    "traiçoeiros": "traiçoeiro",
    "traições": "traição",
    "traja": "trajar",
    "trajada": "trajar",
    "trajadas": "trajar",
    "trajado": "trajar",
    "trajados": "trajar",
    "trajaduras": "trajadura",
    "trajai": "trajar",
    "trajais": "trajar",
    "trajam": "trajar",
    "trajamo": "trajar",
    "trajamos": "trajar",
    "trajando": "trajar",
    "trajara": "trajar",
    "trajaram": "trajar",
    "trajaras": "trajar",
    "trajarde": "trajar",
    "trajardes": "trajar",
    "trajare": "trajar",
    "trajarei": "trajar",
    "trajareis": "trajar",
    "trajarem": "trajar",
    "trajaremos": "trajar",
    "trajares": "trajar",
    "trajaria": "trajar",
    "trajariam": "trajar",
    "trajarias": "trajar",
    "trajarmo": "trajar",
    "trajarmos": "trajar",
    "trajará": "trajar",
    "trajarás": "trajar",
    "trajarão": "trajar",
    "trajaríamos": "trajar",
    "trajaríeis": "trajar",
    "trajas": "trajar",
    "trajasse": "trajar",
    "trajassem": "trajar",
    "trajasses": "trajar",
    "trajaste": "trajar",
    "trajastes": "trajar",
    "trajava": "trajar",
    "trajavam": "trajar",
    "trajavas": "trajar",
    "traje": "trajar",
    "trajectora": "trajector",
    "trajectoras": "trajector",
    "trajectores": "trajector",
    "trajectos": "trajecto",
    "trajectórias": "trajectória",
    "trajei": "trajar",
    "trajeis": "trajar",
    "trajem": "trajar",
    "trajemo": "trajar",
    "trajemos": "trajar",
    "trajes": "traje",
    "trajetórias": "trajetória",
    "trajo": "trajar",
    "trajos": "trajo",
    "trajou": "trajar",
    "trajá": "trajar",
    "trajámo": "trajar",
    "trajámos": "trajar",
    "trajáramo": "trajar",
    "trajáramos": "trajar",
    "trajárei": "trajar",
    "trajáreis": "trajar",
    "trajásseis": "trajar",
    "trajássemos": "trajar",
    "trajávamo": "trajar",
    "trajávamos": "trajar",
    "trajávei": "trajar",
    "trajáveis": "trajar",
    "tralha": "tralhar",
    "tralhada": "tralhar",
    "tralhadas": "tralhar",
    "tralhado": "tralhar",
    "tralhados": "tralhar",
    "tralhai": "tralhar",
    "tralhais": "tralhar",
    "tralham": "tralhar",
    "tralhamo": "tralhar",
    "tralhamos": "tralhar",
    "tralhando": "tralhar",
    "tralhara": "tralhar",
    "tralharam": "tralhar",
    "tralharas": "tralhar",
    "tralharde": "tralhar",
    "tralhardes": "tralhar",
    "tralhare": "tralhar",
    "tralharei": "tralhar",
    "tralhareis": "tralhar",
    "tralharem": "tralhar",
    "tralharemos": "tralhar",
    "tralhares": "tralhar",
    "tralharia": "tralhar",
    "tralhariam": "tralhar",
    "tralharias": "tralhar",
    "tralharmo": "tralhar",
    "tralharmos": "tralhar",
    "tralhará": "tralhar",
    "tralharás": "tralhar",
    "tralharão": "tralhar",
    "tralharíamos": "tralhar",
    "tralharíeis": "tralhar",
    "tralharões": "tralharão",
    "tralhas": "tralhar",
    "tralhasse": "tralhar",
    "tralhassem": "tralhar",
    "tralhasses": "tralhar",
    "tralhaste": "tralhar",
    "tralhastes": "tralhar",
    "tralhava": "tralhar",
    "tralhavam": "tralhar",
    "tralhavas": "tralhar",
    "tralhe": "tralhar",
    "tralhei": "tralhar",
    "tralheis": "tralhar",
    "tralhem": "tralhar",
    "tralhemo": "tralhar",
    "tralhemos": "tralhar",
    "tralhes": "tralhar",
    "tralhinha": "tralha",
    "tralhinhas": "tralha",
    "tralhita": "tralha",
    "tralhitas": "tralha",
    "tralho": "tralhar",
    "tralhoadas": "tralhoada",
    "tralhona": "tralhão",
    "tralhonas": "tralhão",
    "tralhos": "tralho",
    "tralhotos": "tralhoto",
    "tralhou": "tralhar",
    "tralhá": "tralhar",
    "tralhámo": "tralhar",
    "tralhámos": "tralhar",
    "tralháramo": "tralhar",
    "tralháramos": "tralhar",
    "tralhárei": "tralhar",
    "tralháreis": "tralhar",
    "tralhásseis": "tralhar",
    "tralhássemos": "tralhar",
    "tralhávamo": "tralhar",
    "tralhávamos": "tralhar",
    "tralhávei": "tralhar",
    "tralháveis": "tralhar",
    "tralhões": "tralhão",
    "trama": "tramar",
    "tramada": "tramar",
    "tramadas": "tramar",
    "tramadinha": "tramado",
    "tramadinhas": "tramado",
    "tramadinho": "tramado",
    "tramadinhos": "tramado",
    "tramadita": "tramado",
    "tramaditas": "tramado",
    "tramadito": "tramado",
    "tramaditos": "tramado",
    "tramado": "tramar",
    "tramadora": "tramador",
    "tramadoras": "tramador",
    "tramadores": "tramador",
    "tramados": "tramar",
    "tramadíssima": "tramado",
    "tramadíssimas": "tramado",
    "tramadíssimo": "tramado",
    "tramadíssimos": "tramado",
    "tramagais": "tramagal",
    "tramagas": "tramaga",
    "tramagueiras": "tramagueira",
    "tramai": "tramar",
    "tramais": "tramar",
    "tramam": "tramar",
    "tramamo": "tramar",
    "tramamos": "tramar",
    "tramando": "tramar",
    "tramara": "tramar",
    "tramaram": "tramar",
    "tramaras": "tramar",
    "tramarde": "tramar",
    "tramardes": "tramar",
    "tramare": "tramar",
    "tramarei": "tramar",
    "tramareis": "tramar",
    "tramarem": "tramar",
    "tramaremos": "tramar",
    "tramares": "tramar",
    "tramaria": "tramar",
    "tramariam": "tramar",
    "tramarias": "tramar",
    "tramarmo": "tramar",
    "tramarmos": "tramar",
    "tramará": "tramar",
    "tramarás": "tramar",
    "tramarão": "tramar",
    "tramaríamos": "tramar",
    "tramaríeis": "tramar",
    "tramas": "tramar",
    "tramasse": "tramar",
    "tramassem": "tramar",
    "tramasses": "tramar",
    "tramaste": "tramar",
    "tramastes": "tramar",
    "tramava": "tramar",
    "tramavam": "tramar",
    "tramavas": "tramar",
    "tramazeiras": "tramazeira",
    "tramações": "tramação",
    "trambalazanas": "trambalazana",
    "trambeca": "trambecar",
    "trambecada": "trambecar",
    "trambecadas": "trambecar",
    "trambecado": "trambecar",
    "trambecados": "trambecar",
    "trambecais": "trambecar",
    "trambecam": "trambecar",
    "trambecamo": "trambecar",
    "trambecamos": "trambecar",
    "trambecando": "trambecar",
    "trambecara": "trambecar",
    "trambecaram": "trambecar",
    "trambecaras": "trambecar",
    "trambecardes": "trambecar",
    "trambecarei": "trambecar",
    "trambecareis": "trambecar",
    "trambecarem": "trambecar",
    "trambecaremos": "trambecar",
    "trambecares": "trambecar",
    "trambecaria": "trambecar",
    "trambecariam": "trambecar",
    "trambecarias": "trambecar",
    "trambecarmo": "trambecar",
    "trambecarmos": "trambecar",
    "trambecará": "trambecar",
    "trambecarás": "trambecar",
    "trambecarão": "trambecar",
    "trambecaríamos": "trambecar",
    "trambecaríeis": "trambecar",
    "trambecas": "trambecar",
    "trambecasse": "trambecar",
    "trambecassem": "trambecar",
    "trambecasses": "trambecar",
    "trambecaste": "trambecar",
    "trambecastes": "trambecar",
    "trambecava": "trambecar",
    "trambecavam": "trambecar",
    "trambecavas": "trambecar",
    "trambeco": "trambecar",
    "trambecou": "trambecar",
    "trambecámo": "trambecar",
    "trambecámos": "trambecar",
    "trambecáramo": "trambecar",
    "trambecáramos": "trambecar",
    "trambecáreis": "trambecar",
    "trambecásseis": "trambecar",
    "trambecássemos": "trambecar",
    "trambecávamo": "trambecar",
    "trambecávamos": "trambecar",
    "trambecáveis": "trambecar",
    "trambelhos": "trambelho",
    "trambeque": "trambecar",
    "trambequei": "trambecar",
    "trambequeis": "trambecar",
    "trambequem": "trambecar",
    "trambequemos": "trambecar",
    "trambeques": "trambecar",
    "trambica": "trambicar",
    "trambicada": "trambicar",
    "trambicadas": "trambicar",
    "trambicado": "trambicar",
    "trambicados": "trambicar",
    "trambicai": "trambicar",
    "trambicais": "trambicar",
    "trambicam": "trambicar",
    "trambicamo": "trambicar",
    "trambicamos": "trambicar",
    "trambicando": "trambicar",
    "trambicara": "trambicar",
    "trambicaram": "trambicar",
    "trambicaras": "trambicar",
    "trambicarde": "trambicar",
    "trambicardes": "trambicar",
    "trambicare": "trambicar",
    "trambicarei": "trambicar",
    "trambicareis": "trambicar",
    "trambicarem": "trambicar",
    "trambicaremos": "trambicar",
    "trambicares": "trambicar",
    "trambicaria": "trambicar",
    "trambicariam": "trambicar",
    "trambicarias": "trambicar",
    "trambicarmo": "trambicar",
    "trambicarmos": "trambicar",
    "trambicará": "trambicar",
    "trambicarás": "trambicar",
    "trambicarão": "trambicar",
    "trambicaríamos": "trambicar",
    "trambicaríeis": "trambicar",
    "trambicas": "trambicar",
    "trambicasse": "trambicar",
    "trambicassem": "trambicar",
    "trambicasses": "trambicar",
    "trambicaste": "trambicar",
    "trambicastes": "trambicar",
    "trambicava": "trambicar",
    "trambicavam": "trambicar",
    "trambicavas": "trambicar",
    "trambico": "trambicar",
    "trambicou": "trambicar",
    "trambicá": "trambicar",
    "trambicámo": "trambicar",
    "trambicámos": "trambicar",
    "trambicáramo": "trambicar",
    "trambicáramos": "trambicar",
    "trambicárei": "trambicar",
    "trambicáreis": "trambicar",
    "trambicásseis": "trambicar",
    "trambicássemos": "trambicar",
    "trambicávamo": "trambicar",
    "trambicávamos": "trambicar",
    "trambicávei": "trambicar",
    "trambicáveis": "trambicar",
    "trambique": "trambicar",
    "trambiquei": "trambicar",
    "trambiqueis": "trambicar",
    "trambiquem": "trambicar",
    "trambiquemo": "trambicar",
    "trambiquemos": "trambicar",
    "trambiques": "trambicar",
    "trambolha": "trambolhar",
    "trambolhada": "trambolhar",
    "trambolhadas": "trambolhar",
    "trambolhado": "trambolhar",
    "trambolhados": "trambolhar",
    "trambolhai": "trambolhar",
    "trambolhais": "trambolhar",
    "trambolham": "trambolhar",
    "trambolhamo": "trambolhar",
    "trambolhamos": "trambolhar",
    "trambolhando": "trambolhar",
    "trambolhara": "trambolhar",
    "trambolharam": "trambolhar",
    "trambolharas": "trambolhar",
    "trambolhardes": "trambolhar",
    "trambolharei": "trambolhar",
    "trambolhareis": "trambolhar",
    "trambolharem": "trambolhar",
    "trambolharemos": "trambolhar",
    "trambolhares": "trambolhar",
    "trambolharia": "trambolhar",
    "trambolhariam": "trambolhar",
    "trambolharias": "trambolhar",
    "trambolharmo": "trambolhar",
    "trambolharmos": "trambolhar",
    "trambolhará": "trambolhar",
    "trambolharás": "trambolhar",
    "trambolharão": "trambolhar",
    "trambolharíamos": "trambolhar",
    "trambolharíeis": "trambolhar",
    "trambolhas": "trambolhar",
    "trambolhasse": "trambolhar",
    "trambolhassem": "trambolhar",
    "trambolhasses": "trambolhar",
    "trambolhaste": "trambolhar",
    "trambolhastes": "trambolhar",
    "trambolhava": "trambolhar",
    "trambolhavam": "trambolhar",
    "trambolhavas": "trambolhar",
    "trambolhe": "trambolhar",
    "trambolhei": "trambolhar",
    "trambolheis": "trambolhar",
    "trambolhem": "trambolhar",
    "trambolhemo": "trambolhar",
    "trambolhemos": "trambolhar",
    "trambolhes": "trambolhar",
    "trambolhias": "trambolhia",
    "trambolho": "trambolhar",
    "trambolhos": "trambolho",
    "trambolhou": "trambolhar",
    "trambolhámo": "trambolhar",
    "trambolhámos": "trambolhar",
    "trambolháramo": "trambolhar",
    "trambolháramos": "trambolhar",
    "trambolháreis": "trambolhar",
    "trambolhásseis": "trambolhar",
    "trambolhássemos": "trambolhar",
    "trambolhávamo": "trambolhar",
    "trambolhávamos": "trambolhar",
    "trambolháveis": "trambolhar",
    "trambolhões": "trambolhão",
    "trambuzanas": "trambuzana",
    "trame": "tramar",
    "tramei": "tramar",
    "trameis": "tramar",
    "tramelas": "tramela",
    "tramem": "tramar",
    "tramemo": "tramar",
    "tramemos": "tramar",
    "trames": "tramar",
    "tramita": "tramitar",
    "tramitada": "tramitar",
    "tramitadas": "tramitar",
    "tramitado": "tramitar",
    "tramitados": "tramitar",
    "tramitai": "tramitar",
    "tramitais": "tramitar",
    "tramitam": "tramitar",
    "tramitamo": "tramitar",
    "tramitamos": "tramitar",
    "tramitando": "tramitar",
    "tramitara": "tramitar",
    "tramitaram": "tramitar",
    "tramitaras": "tramitar",
    "tramitardes": "tramitar",
    "tramitarei": "tramitar",
    "tramitareis": "tramitar",
    "tramitarem": "tramitar",
    "tramitaremos": "tramitar",
    "tramitares": "tramitar",
    "tramitaria": "tramitar",
    "tramitariam": "tramitar",
    "tramitarias": "tramitar",
    "tramitarmo": "tramitar",
    "tramitarmos": "tramitar",
    "tramitará": "tramitar",
    "tramitarás": "tramitar",
    "tramitarão": "tramitar",
    "tramitaríamos": "tramitar",
    "tramitaríeis": "tramitar",
    "tramitas": "tramitar",
    "tramitasse": "tramitar",
    "tramitassem": "tramitar",
    "tramitasses": "tramitar",
    "tramitaste": "tramitar",
    "tramitastes": "tramitar",
    "tramitava": "tramitar",
    "tramitavam": "tramitar",
    "tramitavas": "tramitar",
    "tramitações": "tramitação",
    "tramite": "tramitar",
    "tramitei": "tramitar",
    "tramiteis": "tramitar",
    "tramitem": "tramitar",
    "tramitemo": "tramitar",
    "tramitemos": "tramitar",
    "tramites": "tramitar",
    "tramito": "tramitar",
    "tramitou": "tramitar",
    "tramitámo": "tramitar",
    "tramitámos": "tramitar",
    "tramitáramo": "tramitar",
    "tramitáramos": "tramitar",
    "tramitáreis": "tramitar",
    "tramitásseis": "tramitar",
    "tramitássemos": "tramitar",
    "tramitávamo": "tramitar",
    "tramitávamos": "tramitar",
    "tramitáveis": "tramitável",
    "tramo": "tramar",
    "tramolhadas": "tramolhada",
    "tramonta": "tramontar",
    "tramontada": "tramontar",
    "tramontadas": "tramontar",
    "tramontado": "tramontar",
    "tramontados": "tramontar",
    "tramontai": "tramontar",
    "tramontais": "tramontar",
    "tramontam": "tramontar",
    "tramontamo": "tramontar",
    "tramontamos": "tramontar",
    "tramontanas": "tramontana",
    "tramontando": "tramontar",
    "tramontara": "tramontar",
    "tramontaram": "tramontar",
    "tramontaras": "tramontar",
    "tramontardes": "tramontar",
    "tramontarei": "tramontar",
    "tramontareis": "tramontar",
    "tramontarem": "tramontar",
    "tramontaremos": "tramontar",
    "tramontares": "tramontar",
    "tramontaria": "tramontar",
    "tramontariam": "tramontar",
    "tramontarias": "tramontar",
    "tramontarmo": "tramontar",
    "tramontarmos": "tramontar",
    "tramontará": "tramontar",
    "tramontarás": "tramontar",
    "tramontarão": "tramontar",
    "tramontaríamos": "tramontar",
    "tramontaríeis": "tramontar",
    "tramontas": "tramontar",
    "tramontasse": "tramontar",
    "tramontassem": "tramontar",
    "tramontasses": "tramontar",
    "tramontaste": "tramontar",
    "tramontastes": "tramontar",
    "tramontava": "tramontar",
    "tramontavam": "tramontar",
    "tramontavas": "tramontar",
    "tramonte": "tramontar",
    "tramontei": "tramontar",
    "tramonteis": "tramontar",
    "tramontem": "tramontar",
    "tramontemo": "tramontar",
    "tramontemos": "tramontar",
    "tramontes": "tramontar",
    "tramonto": "tramontar",
    "tramontou": "tramontar",
    "tramontámo": "tramontar",
    "tramontámos": "tramontar",
    "tramontáramo": "tramontar",
    "tramontáramos": "tramontar",
    "tramontáreis": "tramontar",
    "tramontásseis": "tramontar",
    "tramontássemos": "tramontar",
    "tramontávamo": "tramontar",
    "tramontávamos": "tramontar",
    "tramontáveis": "tramontar",
    "tramos": "tramo",
    "tramou": "tramar",
    "tramouca": "tramouco",
    "tramoucas": "tramouco",
    "tramoucos": "tramouco",
    "trampalhos": "trampalho",
    "trampas": "trampa",
    "trampazinha": "trampa",
    "trampazinhas": "trampa",
    "trampazita": "trampa",
    "trampazitas": "trampa",
    "trampeada": "trampear",
    "trampeadas": "trampear",
    "trampeado": "trampear",
    "trampeados": "trampear",
    "trampeai": "trampear",
    "trampeais": "trampear",
    "trampeamo": "trampear",
    "trampeamos": "trampear",
    "trampeando": "trampear",
    "trampeara": "trampear",
    "trampearam": "trampear",
    "trampearas": "trampear",
    "trampearde": "trampear",
    "trampeardes": "trampear",
    "trampeare": "trampear",
    "trampearei": "trampear",
    "trampeareis": "trampear",
    "trampearem": "trampear",
    "trampearemos": "trampear",
    "trampeares": "trampear",
    "trampearia": "trampear",
    "trampeariam": "trampear",
    "trampearias": "trampear",
    "trampearmo": "trampear",
    "trampearmos": "trampear",
    "trampeará": "trampear",
    "trampearás": "trampear",
    "trampearão": "trampear",
    "trampearíamos": "trampear",
    "trampearíeis": "trampear",
    "trampeasse": "trampear",
    "trampeassem": "trampear",
    "trampeasses": "trampear",
    "trampeaste": "trampear",
    "trampeastes": "trampear",
    "trampeava": "trampear",
    "trampeavam": "trampear",
    "trampeavas": "trampear",
    "trampeei": "trampear",
    "trampeeis": "trampear",
    "trampeemo": "trampear",
    "trampeemos": "trampear",
    "trampeia": "trampear",
    "trampeiam": "trampear",
    "trampeias": "trampear",
    "trampeie": "trampear",
    "trampeiem": "trampear",
    "trampeies": "trampear",
    "trampeio": "trampear",
    "trampeou": "trampear",
    "trampeá": "trampear",
    "trampeámo": "trampear",
    "trampeámos": "trampear",
    "trampeáramo": "trampear",
    "trampeáramos": "trampear",
    "trampeárei": "trampear",
    "trampeáreis": "trampear",
    "trampeásseis": "trampear",
    "trampeássemos": "trampear",
    "trampeávamo": "trampear",
    "trampeávamos": "trampear",
    "trampeávei": "trampear",
    "trampeáveis": "trampear",
    "trampistas": "trampista",
    "trampolina": "trampolinar",
    "trampolinada": "trampolinar",
    "trampolinadas": "trampolinar",
    "trampolinado": "trampolinar",
    "trampolinados": "trampolinar",
    "trampolinagens": "trampolinagem",
    "trampolinai": "trampolinar",
    "trampolinais": "trampolinar",
    "trampolinam": "trampolinar",
    "trampolinamo": "trampolinar",
    "trampolinamos": "trampolinar",
    "trampolinando": "trampolinar",
    "trampolinara": "trampolinar",
    "trampolinaram": "trampolinar",
    "trampolinaras": "trampolinar",
    "trampolinardes": "trampolinar",
    "trampolinarei": "trampolinar",
    "trampolinareis": "trampolinar",
    "trampolinarem": "trampolinar",
    "trampolinaremos": "trampolinar",
    "trampolinares": "trampolinar",
    "trampolinaria": "trampolinar",
    "trampolinariam": "trampolinar",
    "trampolinarias": "trampolinar",
    "trampolinarmo": "trampolinar",
    "trampolinarmos": "trampolinar",
    "trampolinará": "trampolinar",
    "trampolinarás": "trampolinar",
    "trampolinarão": "trampolinar",
    "trampolinaríamos": "trampolinar",
    "trampolinaríeis": "trampolinar",
    "trampolinas": "trampolinar",
    "trampolinasse": "trampolinar",
    "trampolinassem": "trampolinar",
    "trampolinasses": "trampolinar",
    "trampolinaste": "trampolinar",
    "trampolinastes": "trampolinar",
    "trampolinava": "trampolinar",
    "trampolinavam": "trampolinar",
    "trampolinavas": "trampolinar",
    "trampoline": "trampolinar",
    "trampolinei": "trampolinar",
    "trampolineira": "trampolineiro",
    "trampolineiras": "trampolineiro",
    "trampolineiros": "trampolineiro",
    "trampolineis": "trampolinar",
    "trampolinem": "trampolinar",
    "trampolinemo": "trampolinar",
    "trampolinemos": "trampolinar",
    "trampolines": "trampolinar",
    "trampolinices": "trampolinice",
    "trampolinistas": "trampolinista",
    "trampolino": "trampolinar",
    "trampolinou": "trampolinar",
    "trampolins": "trampolim",
    "trampolinámo": "trampolinar",
    "trampolinámos": "trampolinar",
    "trampolináramo": "trampolinar",
    "trampolináramos": "trampolinar",
    "trampolináreis": "trampolinar",
    "trampolinásseis": "trampolinar",
    "trampolinássemos": "trampolinar",
    "trampolinávamo": "trampolinar",
    "trampolinávamos": "trampolinar",
    "trampolináveis": "trampolinar",
    "trampona": "trampão",
    "tramponas": "trampão",
    "tramposa": "tramposo",
    "tramposas": "tramposo",
    "tramposos": "tramposo",
    "trampões": "trampão",
    "tramá": "tramar",
    "tramámo": "tramar",
    "tramámos": "tramar",
    "tramáramo": "tramar",
    "tramáramos": "tramar",
    "tramárei": "tramar",
    "tramáreis": "tramar",
    "tramásseis": "tramar",
    "tramássemos": "tramar",
    "tramávamo": "tramar",
    "tramávamos": "tramar",
    "tramávei": "tramar",
    "tramáveis": "tramar",
    "tramóias": "tramóia",
    "trana": "tranar",
    "tranada": "tranar",
    "tranadas": "tranar",
    "tranado": "tranar",
    "tranados": "tranar",
    "tranai": "tranar",
    "tranais": "tranar",
    "tranam": "tranar",
    "tranamo": "tranar",
    "tranamos": "tranar",
    "tranando": "tranar",
    "tranara": "tranar",
    "tranaram": "tranar",
    "tranaras": "tranar",
    "tranarde": "tranar",
    "tranardes": "tranar",
    "tranare": "tranar",
    "tranarei": "tranar",
    "tranareis": "tranar",
    "tranarem": "tranar",
    "tranaremos": "tranar",
    "tranares": "tranar",
    "tranaria": "tranar",
    "tranariam": "tranar",
    "tranarias": "tranar",
    "tranarmo": "tranar",
    "tranarmos": "tranar",
    "tranará": "tranar",
    "tranarás": "tranar",
    "tranarão": "tranar",
    "tranaríamos": "tranar",
    "tranaríeis": "tranar",
    "tranas": "tranar",
    "tranasse": "tranar",
    "tranassem": "tranar",
    "tranasses": "tranar",
    "tranaste": "tranar",
    "tranastes": "tranar",
    "tranava": "tranar",
    "tranavam": "tranar",
    "tranavas": "tranar",
    "tranca": "trancar",
    "trancada": "trancar",
    "trancadas": "trancar",
    "trancadinha": "trancado",
    "trancadinhas": "trancado",
    "trancadinho": "trancado",
    "trancadinhos": "trancado",
    "trancadita": "trancado",
    "trancaditas": "trancado",
    "trancadito": "trancado",
    "trancaditos": "trancado",
    "trancado": "trancar",
    "trancados": "trancar",
    "trancadíssima": "trancado",
    "trancadíssimas": "trancado",
    "trancadíssimo": "trancado",
    "trancadíssimos": "trancado",
    "trancafios": "trancafio",
    "trancai": "trancar",
    "trancais": "trancar",
    "trancalhos": "trancalho",
    "trancam": "trancar",
    "trancamentos": "trancamento",
    "trancamo": "trancar",
    "trancamos": "trancar",
    "trancanazes": "trancanaz",
    "trancando": "trancar",
    "trancara": "trancar",
    "trancaram": "trancar",
    "trancaras": "trancar",
    "trancarde": "trancar",
    "trancardes": "trancar",
    "trancare": "trancar",
    "trancarei": "trancar",
    "trancareis": "trancar",
    "trancarem": "trancar",
    "trancaremos": "trancar",
    "trancares": "trancar",
    "trancaria": "trancar",
    "trancariam": "trancar",
    "trancarias": "trancaria",
    "trancarmo": "trancar",
    "trancarmos": "trancar",
    "trancará": "trancar",
    "trancarás": "trancar",
    "trancarão": "trancar",
    "trancaríamos": "trancar",
    "trancaríeis": "trancar",
    "trancas": "trancar",
    "trancasse": "trancar",
    "trancassem": "trancar",
    "trancasses": "trancar",
    "trancaste": "trancar",
    "trancastes": "trancar",
    "trancava": "trancar",
    "trancavam": "trancar",
    "trancavas": "trancar",
    "trance": "trançar",
    "trancei": "trançar",
    "tranceis": "trançar",
    "trancelins": "trancelim",
    "trancem": "trançar",
    "trancemo": "trançar",
    "trancemos": "trançar",
    "trances": "trançar",
    "trancha": "tranchar",
    "tranchada": "tranchar",
    "tranchadas": "tranchar",
    "tranchado": "tranchar",
    "tranchados": "tranchar",
    "tranchai": "tranchar",
    "tranchais": "tranchar",
    "trancham": "tranchar",
    "tranchamo": "tranchar",
    "tranchamos": "tranchar",
    "tranchando": "tranchar",
    "tranchara": "tranchar",
    "trancharam": "tranchar",
    "trancharas": "tranchar",
    "trancharde": "tranchar",
    "tranchardes": "tranchar",
    "tranchare": "tranchar",
    "trancharei": "tranchar",
    "tranchareis": "tranchar",
    "trancharem": "tranchar",
    "trancharemos": "tranchar",
    "tranchares": "tranchar",
    "trancharia": "tranchar",
    "tranchariam": "tranchar",
    "trancharias": "tranchar",
    "trancharmo": "tranchar",
    "trancharmos": "tranchar",
    "tranchará": "tranchar",
    "trancharás": "tranchar",
    "trancharão": "tranchar",
    "trancharíamos": "tranchar",
    "trancharíeis": "tranchar",
    "tranchas": "tranchar",
    "tranchasse": "tranchar",
    "tranchassem": "tranchar",
    "tranchasses": "tranchar",
    "tranchaste": "tranchar",
    "tranchastes": "tranchar",
    "tranchava": "tranchar",
    "tranchavam": "tranchar",
    "tranchavas": "tranchar",
    "tranche": "tranchar",
    "tranchei": "tranchar",
    "trancheis": "tranchar",
    "tranchem": "tranchar",
    "tranchemo": "tranchar",
    "tranchemos": "tranchar",
    "tranches": "tranchar",
    "trancho": "tranchar",
    "tranchou": "tranchar",
    "tranchá": "tranchar",
    "tranchámo": "tranchar",
    "tranchámos": "tranchar",
    "trancháramo": "tranchar",
    "trancháramos": "tranchar",
    "tranchárei": "tranchar",
    "trancháreis": "tranchar",
    "tranchásseis": "tranchar",
    "tranchássemos": "tranchar",
    "tranchávamo": "tranchar",
    "tranchávamos": "tranchar",
    "tranchávei": "tranchar",
    "trancháveis": "tranchar",
    "trancinha": "trança",
    "trancinhas": "trança",
    "trancita": "trança",
    "trancitas": "trança",
    "tranco": "trancar",
    "trancos": "tranco",
    "trancosana": "trancosano",
    "trancosanas": "trancosano",
    "trancosanos": "trancosano",
    "trancosenses": "trancosense",
    "trancou": "trancar",
    "trancá": "trancar",
    "trancámo": "trancar",
    "trancámos": "trancar",
    "trancáramo": "trancar",
    "trancáramos": "trancar",
    "trancárei": "trancar",
    "trancáreis": "trancar",
    "trancásseis": "trancar",
    "trancássemos": "trancar",
    "trancávamo": "trancar",
    "trancávamos": "trancar",
    "trancávei": "trancar",
    "trancáveis": "trancar",
    "trane": "tranar",
    "tranei": "tranar",
    "traneis": "tranar",
    "tranem": "tranar",
    "tranemo": "tranar",
    "tranemos": "tranar",
    "tranes": "tranar",
    "trangalhos": "trangalho",
    "trangalhões": "trangalhão",
    "trangalomangos": "trangalomango",
    "tranganhos": "tranganho",
    "trangolas": "trangola",
    "trangomangos": "trangomango",
    "trangulhos": "trangulho",
    "trano": "tranar",
    "tranou": "tranar",
    "tranque": "trancar",
    "tranqueada": "tranquear",
    "tranqueadas": "tranquear",
    "tranqueado": "tranquear",
    "tranqueados": "tranquear",
    "tranqueai": "tranquear",
    "tranqueais": "tranquear",
    "tranqueamo": "tranquear",
    "tranqueamos": "tranquear",
    "tranqueando": "tranquear",
    "tranqueara": "tranquear",
    "tranquearam": "tranquear",
    "tranquearas": "tranquear",
    "tranquearde": "tranquear",
    "tranqueardes": "tranquear",
    "tranqueare": "tranquear",
    "tranquearei": "tranquear",
    "tranqueareis": "tranquear",
    "tranquearem": "tranquear",
    "tranquearemos": "tranquear",
    "tranqueares": "tranquear",
    "tranquearia": "tranquear",
    "tranqueariam": "tranquear",
    "tranquearias": "tranquear",
    "tranquearmo": "tranquear",
    "tranquearmos": "tranquear",
    "tranqueará": "tranquear",
    "tranquearás": "tranquear",
    "tranquearão": "tranquear",
    "tranquearíamos": "tranquear",
    "tranquearíeis": "tranquear",
    "tranqueasse": "tranquear",
    "tranqueassem": "tranquear",
    "tranqueasses": "tranquear",
    "tranqueaste": "tranquear",
    "tranqueastes": "tranquear",
    "tranqueava": "tranquear",
    "tranqueavam": "tranquear",
    "tranqueavas": "tranquear",
    "tranqueei": "tranquear",
    "tranqueeis": "tranquear",
    "tranqueemo": "tranquear",
    "tranqueemos": "tranquear",
    "tranquei": "trancar",
    "tranqueia": "tranquear",
    "tranqueiam": "tranquear",
    "tranqueias": "tranquear",
    "tranqueie": "tranquear",
    "tranqueiem": "tranquear",
    "tranqueies": "tranquear",
    "tranqueio": "tranquear",
    "tranqueiras": "tranqueira",
    "tranqueiros": "tranqueiro",
    "tranqueis": "trancar",
    "tranquem": "trancar",
    "tranquemo": "trancar",
    "tranquemos": "trancar",
    "tranqueou": "tranquear",
    "tranques": "trancar",
    "tranquetas": "tranqueta",
    "tranqueá": "tranquear",
    "tranqueámo": "tranquear",
    "tranqueámos": "tranquear",
    "tranqueáramo": "tranquear",
    "tranqueáramos": "tranquear",
    "tranqueárei": "tranquear",
    "tranqueáreis": "tranquear",
    "tranqueásseis": "tranquear",
    "tranqueássemos": "tranquear",
    "tranqueávamo": "tranquear",
    "tranqueávamos": "tranquear",
    "tranqueávei": "tranquear",
    "tranqueáveis": "tranquear",
    "tranquias": "tranquia",
    "tranquiberna": "tranquibernar",
    "tranquibernada": "tranquibernar",
    "tranquibernadas": "tranquibernar",
    "tranquibernado": "tranquibernar",
    "tranquibernados": "tranquibernar",
    "tranquibernai": "tranquibernar",
    "tranquibernais": "tranquibernar",
    "tranquibernam": "tranquibernar",
    "tranquibernamo": "tranquibernar",
    "tranquibernamos": "tranquibernar",
    "tranquibernando": "tranquibernar",
    "tranquibernara": "tranquibernar",
    "tranquibernaram": "tranquibernar",
    "tranquibernaras": "tranquibernar",
    "tranquibernardes": "tranquibernar",
    "tranquibernarei": "tranquibernar",
    "tranquibernareis": "tranquibernar",
    "tranquibernarem": "tranquibernar",
    "tranquibernaremos": "tranquibernar",
    "tranquibernares": "tranquibernar",
    "tranquibernaria": "tranquibernar",
    "tranquibernariam": "tranquibernar",
    "tranquibernarias": "tranquibernar",
    "tranquibernarmo": "tranquibernar",
    "tranquibernarmos": "tranquibernar",
    "tranquibernará": "tranquibernar",
    "tranquibernarás": "tranquibernar",
    "tranquibernarão": "tranquibernar",
    "tranquibernaríamos": "tranquibernar",
    "tranquibernaríeis": "tranquibernar",
    "tranquibernas": "tranquibernar",
    "tranquibernasse": "tranquibernar",
    "tranquibernassem": "tranquibernar",
    "tranquibernasses": "tranquibernar",
    "tranquibernaste": "tranquibernar",
    "tranquibernastes": "tranquibernar",
    "tranquibernava": "tranquibernar",
    "tranquibernavam": "tranquibernar",
    "tranquibernavas": "tranquibernar",
    "tranquiberne": "tranquibernar",
    "tranquibernei": "tranquibernar",
    "tranquiberneira": "tranquiberneiro",
    "tranquiberneiras": "tranquiberneiro",
    "tranquiberneiros": "tranquiberneiro",
    "tranquiberneis": "tranquibernar",
    "tranquibernem": "tranquibernar",
    "tranquibernemo": "tranquibernar",
    "tranquibernemos": "tranquibernar",
    "tranquibernes": "tranquibernar",
    "tranquibernia": "tranquiberniar",
    "tranquiberniada": "tranquiberniar",
    "tranquiberniadas": "tranquiberniar",
    "tranquiberniado": "tranquiberniar",
    "tranquiberniados": "tranquiberniar",
    "tranquiberniai": "tranquiberniar",
    "tranquiberniais": "tranquiberniar",
    "tranquiberniam": "tranquiberniar",
    "tranquiberniamo": "tranquiberniar",
    "tranquiberniamos": "tranquiberniar",
    "tranquiberniando": "tranquiberniar",
    "tranquiberniara": "tranquiberniar",
    "tranquiberniaram": "tranquiberniar",
    "tranquiberniaras": "tranquiberniar",
    "tranquiberniardes": "tranquiberniar",
    "tranquiberniarei": "tranquiberniar",
    "tranquiberniareis": "tranquiberniar",
    "tranquiberniarem": "tranquiberniar",
    "tranquiberniaremos": "tranquiberniar",
    "tranquiberniares": "tranquiberniar",
    "tranquiberniaria": "tranquiberniar",
    "tranquiberniariam": "tranquiberniar",
    "tranquiberniarias": "tranquiberniar",
    "tranquiberniarmo": "tranquiberniar",
    "tranquiberniarmos": "tranquiberniar",
    "tranquiberniará": "tranquiberniar",
    "tranquiberniarás": "tranquiberniar",
    "tranquiberniarão": "tranquiberniar",
    "tranquiberniaríamos": "tranquiberniar",
    "tranquiberniaríeis": "tranquiberniar",
    "tranquibernias": "tranquiberniar",
    "tranquiberniasse": "tranquiberniar",
    "tranquiberniassem": "tranquiberniar",
    "tranquiberniasses": "tranquiberniar",
    "tranquiberniaste": "tranquiberniar",
    "tranquiberniastes": "tranquiberniar",
    "tranquiberniava": "tranquiberniar",
    "tranquiberniavam": "tranquiberniar",
    "tranquiberniavas": "tranquiberniar",
    "tranquibernices": "tranquibernice",
    "tranquibernie": "tranquiberniar",
    "tranquiberniei": "tranquiberniar",
    "tranquibernieis": "tranquiberniar",
    "tranquiberniem": "tranquiberniar",
    "tranquiberniemo": "tranquiberniar",
    "tranquiberniemos": "tranquiberniar",
    "tranquibernies": "tranquiberniar",
    "tranquibernio": "tranquiberniar",
    "tranquiberniou": "tranquiberniar",
    "tranquiberniámo": "tranquiberniar",
    "tranquiberniámos": "tranquiberniar",
    "tranquiberniáramo": "tranquiberniar",
    "tranquiberniáramos": "tranquiberniar",
    "tranquiberniáreis": "tranquiberniar",
    "tranquiberniásseis": "tranquiberniar",
    "tranquiberniássemos": "tranquiberniar",
    "tranquiberniávamo": "tranquiberniar",
    "tranquiberniávamos": "tranquiberniar",
    "tranquiberniáveis": "tranquiberniar",
    "tranquiberno": "tranquibernar",
    "tranquibernou": "tranquibernar",
    "tranquibernámo": "tranquibernar",
    "tranquibernámos": "tranquibernar",
    "tranquibernáramo": "tranquibernar",
    "tranquibernáramos": "tranquibernar",
    "tranquibernáreis": "tranquibernar",
    "tranquibernásseis": "tranquibernar",
    "tranquibernássemos": "tranquibernar",
    "tranquibernávamo": "tranquibernar",
    "tranquibernávamos": "tranquibernar",
    "tranquibernáveis": "tranquibernar",
    "tranquibérnias": "tranquibérnia",
    "tranquila": "tranquilo",
    "tranquilas": "tranquilo",
    "tranquilhas": "tranquilha",
    "tranquilhos": "tranquilho",
    "tranquilidades": "tranquilidade",
    "tranquiliza": "tranquilizar",
    "tranquilizada": "tranquilizar",
    "tranquilizadas": "tranquilizar",
    "tranquilizado": "tranquilizar",
    "tranquilizadora": "tranquilizador",
    "tranquilizadoras": "tranquilizador",
    "tranquilizadores": "tranquilizador",
    "tranquilizados": "tranquilizar",
    "tranquilizai": "tranquilizar",
    "tranquilizais": "tranquilizar",
    "tranquilizam": "tranquilizar",
    "tranquilizamo": "tranquilizar",
    "tranquilizamos": "tranquilizar",
    "tranquilizando": "tranquilizar",
    "tranquilizantes": "tranquilizante",
    "tranquilizara": "tranquilizar",
    "tranquilizaram": "tranquilizar",
    "tranquilizaras": "tranquilizar",
    "tranquilizarde": "tranquilizar",
    "tranquilizardes": "tranquilizar",
    "tranquilizare": "tranquilizar",
    "tranquilizarei": "tranquilizar",
    "tranquilizareis": "tranquilizar",
    "tranquilizarem": "tranquilizar",
    "tranquilizaremos": "tranquilizar",
    "tranquilizares": "tranquilizar",
    "tranquilizaria": "tranquilizar",
    "tranquilizariam": "tranquilizar",
    "tranquilizarias": "tranquilizar",
    "tranquilizarmo": "tranquilizar",
    "tranquilizarmos": "tranquilizar",
    "tranquilizará": "tranquilizar",
    "tranquilizarás": "tranquilizar",
    "tranquilizarão": "tranquilizar",
    "tranquilizaríamos": "tranquilizar",
    "tranquilizaríeis": "tranquilizar",
    "tranquilizas": "tranquilizar",
    "tranquilizasse": "tranquilizar",
    "tranquilizassem": "tranquilizar",
    "tranquilizasses": "tranquilizar",
    "tranquilizaste": "tranquilizar",
    "tranquilizastes": "tranquilizar",
    "tranquilizava": "tranquilizar",
    "tranquilizavam": "tranquilizar",
    "tranquilizavas": "tranquilizar",
    "tranquilize": "tranquilizar",
    "tranquilizei": "tranquilizar",
    "tranquilizeis": "tranquilizar",
    "tranquilizem": "tranquilizar",
    "tranquilizemo": "tranquilizar",
    "tranquilizemos": "tranquilizar",
    "tranquilizes": "tranquilizar",
    "tranquilizo": "tranquilizar",
    "tranquilizou": "tranquilizar",
    "tranquilizá": "tranquilizar",
    "tranquilizámo": "tranquilizar",
    "tranquilizámos": "tranquilizar",
    "tranquilizáramo": "tranquilizar",
    "tranquilizáramos": "tranquilizar",
    "tranquilizárei": "tranquilizar",
    "tranquilizáreis": "tranquilizar",
    "tranquilizásseis": "tranquilizar",
    "tranquilizássemos": "tranquilizar",
    "tranquilizávamo": "tranquilizar",
    "tranquilizávamos": "tranquilizar",
    "tranquilizávei": "tranquilizar",
    "tranquilizáveis": "tranquilizar",
    "tranquilos": "tranquilo",
    "tranquinha": "tranca",
    "tranquinhas": "tranca",
    "tranquita": "tranca",
    "tranquitanas": "tranquitana",
    "tranquitas": "tranca",
    "transa": "transir",
    "transacciona": "transaccionar",
    "transaccionada": "transaccionar",
    "transaccionadas": "transaccionar",
    "transaccionado": "transaccionar",
    "transaccionadora": "transaccionador",
    "transaccionadoras": "transaccionador",
    "transaccionadores": "transaccionador",
    "transaccionados": "transaccionar",
    "transaccionai": "transaccionar",
    "transaccionais": "transaccionar",
    "transaccionam": "transaccionar",
    "transaccionamo": "transaccionar",
    "transaccionamos": "transaccionar",
    "transaccionando": "transaccionar",
    "transaccionara": "transaccionar",
    "transaccionaram": "transaccionar",
    "transaccionaras": "transaccionar",
    "transaccionarde": "transaccionar",
    "transaccionardes": "transaccionar",
    "transaccionare": "transaccionar",
    "transaccionarei": "transaccionar",
    "transaccionareis": "transaccionar",
    "transaccionarem": "transaccionar",
    "transaccionaremos": "transaccionar",
    "transaccionares": "transaccionar",
    "transaccionaria": "transaccionar",
    "transaccionariam": "transaccionar",
    "transaccionarias": "transaccionar",
    "transaccionarmo": "transaccionar",
    "transaccionarmos": "transaccionar",
    "transaccionará": "transaccionar",
    "transaccionarás": "transaccionar",
    "transaccionarão": "transaccionar",
    "transaccionaríamos": "transaccionar",
    "transaccionaríeis": "transaccionar",
    "transaccionas": "transaccionar",
    "transaccionasse": "transaccionar",
    "transaccionassem": "transaccionar",
    "transaccionasses": "transaccionar",
    "transaccionaste": "transaccionar",
    "transaccionastes": "transaccionar",
    "transaccionava": "transaccionar",
    "transaccionavam": "transaccionar",
    "transaccionavas": "transaccionar",
    "transaccione": "transaccionar",
    "transaccionei": "transaccionar",
    "transaccioneis": "transaccionar",
    "transaccionem": "transaccionar",
    "transaccionemo": "transaccionar",
    "transaccionemos": "transaccionar",
    "transacciones": "transaccionar",
    "transaccionistas": "transaccionista",
    "transacciono": "transaccionar",
    "transaccionou": "transaccionar",
    "transaccioná": "transaccionar",
    "transaccionámo": "transaccionar",
    "transaccionámos": "transaccionar",
    "transaccionáramo": "transaccionar",
    "transaccionáramos": "transaccionar",
    "transaccionárei": "transaccionar",
    "transaccionáreis": "transaccionar",
    "transaccionásseis": "transaccionar",
    "transaccionássemos": "transaccionar",
    "transaccionávamo": "transaccionar",
    "transaccionávamos": "transaccionar",
    "transaccionávei": "transaccionar",
    "transaccionáveis": "transaccionável",
    "transacionadora": "transacionador",
    "transacionadoras": "transacionador",
    "transacionadores": "transacionador",
    "transacta": "transacto",
    "transactas": "transacto",
    "transactora": "transactor",
    "transactoras": "transactor",
    "transactores": "transactor",
    "transactos": "transacto",
    "transacções": "transacção",
    "transais": "transir",
    "transalpina": "transalpino",
    "transalpinas": "transalpino",
    "transalpinos": "transalpino",
    "transam": "transir",
    "transamo": "transir",
    "transamos": "transir",
    "transariana": "transariano",
    "transarianas": "transariano",
    "transarianos": "transariano",
    "transas": "transir",
    "transatlântica": "transatlântico",
    "transatlânticas": "transatlântico",
    "transatlânticos": "transatlântico",
    "transaustraliana": "transaustraliano",
    "transaustralianas": "transaustraliano",
    "transaustralianos": "transaustraliano",
    "transborda": "transbordar",
    "transbordada": "transbordar",
    "transbordadas": "transbordar",
    "transbordado": "transbordar",
    "transbordadores": "transbordador",
    "transbordados": "transbordar",
    "transbordai": "transbordar",
    "transbordais": "transbordar",
    "transbordam": "transbordar",
    "transbordamo": "transbordar",
    "transbordamos": "transbordar",
    "transbordando": "transbordar",
    "transbordantes": "transbordante",
    "transbordara": "transbordar",
    "transbordaram": "transbordar",
    "transbordaras": "transbordar",
    "transbordardes": "transbordar",
    "transbordarei": "transbordar",
    "transbordareis": "transbordar",
    "transbordarem": "transbordar",
    "transbordaremos": "transbordar",
    "transbordares": "transbordar",
    "transbordaria": "transbordar",
    "transbordariam": "transbordar",
    "transbordarias": "transbordar",
    "transbordarmo": "transbordar",
    "transbordarmos": "transbordar",
    "transbordará": "transbordar",
    "transbordarás": "transbordar",
    "transbordarão": "transbordar",
    "transbordaríamos": "transbordar",
    "transbordaríeis": "transbordar",
    "transbordas": "transbordar",
    "transbordasse": "transbordar",
    "transbordassem": "transbordar",
    "transbordasses": "transbordar",
    "transbordaste": "transbordar",
    "transbordastes": "transbordar",
    "transbordava": "transbordar",
    "transbordavam": "transbordar",
    "transbordavas": "transbordar",
    "transborde": "transbordar",
    "transbordei": "transbordar",
    "transbordeis": "transbordar",
    "transbordem": "transbordar",
    "transbordemo": "transbordar",
    "transbordemos": "transbordar",
    "transbordes": "transbordar",
    "transbordo": "transbordar",
    "transbordos": "transbordo",
    "transbordou": "transbordar",
    "transbordámo": "transbordar",
    "transbordámos": "transbordar",
    "transbordáramo": "transbordar",
    "transbordáramos": "transbordar",
    "transbordáreis": "transbordar",
    "transbordásseis": "transbordar",
    "transbordássemos": "transbordar",
    "transbordávamo": "transbordar",
    "transbordávamos": "transbordar",
    "transbordáveis": "transbordar",
    "transcaspiana": "transcaspiano",
    "transcaspianas": "transcaspiano",
    "transcaspianos": "transcaspiano",
    "transcaucasiana": "transcaucasiano",
    "transcaucasianas": "transcaucasiano",
    "transcaucasianos": "transcaucasiano",
    "transcaucásica": "transcaucásico",
    "transcaucásicas": "transcaucásico",
    "transcaucásicos": "transcaucásico",
    "transcencentes": "transcencente",
    "transcenda": "transcender",
    "transcendais": "transcender",
    "transcendam": "transcender",
    "transcendamo": "transcender",
    "transcendamos": "transcender",
    "transcendas": "transcender",
    "transcende": "transcender",
    "transcendei": "transcender",
    "transcendeis": "transcender",
    "transcendem": "transcender",
    "transcendemo": "transcender",
    "transcendemos": "transcender",
    "transcendendo": "transcender",
    "transcendentais": "transcendental",
    "transcendentalidades": "transcendentalidade",
    "transcendentalismos": "transcendentalismo",
    "transcendentalistas": "transcendentalista",
    "transcendentaliza": "transcendentalizar",
    "transcendentalizada": "transcendentalizar",
    "transcendentalizadas": "transcendentalizar",
    "transcendentalizado": "transcendentalizar",
    "transcendentalizados": "transcendentalizar",
    "transcendentalizai": "transcendentalizar",
    "transcendentalizais": "transcendentalizar",
    "transcendentalizam": "transcendentalizar",
    "transcendentalizamo": "transcendentalizar",
    "transcendentalizamos": "transcendentalizar",
    "transcendentalizando": "transcendentalizar",
    "transcendentalizara": "transcendentalizar",
    "transcendentalizaram": "transcendentalizar",
    "transcendentalizaras": "transcendentalizar",
    "transcendentalizarde": "transcendentalizar",
    "transcendentalizardes": "transcendentalizar",
    "transcendentalizare": "transcendentalizar",
    "transcendentalizarei": "transcendentalizar",
    "transcendentalizareis": "transcendentalizar",
    "transcendentalizarem": "transcendentalizar",
    "transcendentalizaremos": "transcendentalizar",
    "transcendentalizares": "transcendentalizar",
    "transcendentalizaria": "transcendentalizar",
    "transcendentalizariam": "transcendentalizar",
    "transcendentalizarias": "transcendentalizar",
    "transcendentalizarmo": "transcendentalizar",
    "transcendentalizarmos": "transcendentalizar",
    "transcendentalizará": "transcendentalizar",
    "transcendentalizarás": "transcendentalizar",
    "transcendentalizarão": "transcendentalizar",
    "transcendentalizaríamos": "transcendentalizar",
    "transcendentalizaríeis": "transcendentalizar",
    "transcendentalizas": "transcendentalizar",
    "transcendentalizasse": "transcendentalizar",
    "transcendentalizassem": "transcendentalizar",
    "transcendentalizasses": "transcendentalizar",
    "transcendentalizaste": "transcendentalizar",
    "transcendentalizastes": "transcendentalizar",
    "transcendentalizava": "transcendentalizar",
    "transcendentalizavam": "transcendentalizar",
    "transcendentalizavas": "transcendentalizar",
    "transcendentalize": "transcendentalizar",
    "transcendentalizei": "transcendentalizar",
    "transcendentalizeis": "transcendentalizar",
    "transcendentalizem": "transcendentalizar",
    "transcendentalizemo": "transcendentalizar",
    "transcendentalizemos": "transcendentalizar",
    "transcendentalizes": "transcendentalizar",
    "transcendentalizo": "transcendentalizar",
    "transcendentalizou": "transcendentalizar",
    "transcendentalizá": "transcendentalizar",
    "transcendentalizámo": "transcendentalizar",
    "transcendentalizámos": "transcendentalizar",
    "transcendentalizáramo": "transcendentalizar",
    "transcendentalizáramos": "transcendentalizar",
    "transcendentalizárei": "transcendentalizar",
    "transcendentalizáreis": "transcendentalizar",
    "transcendentalizásseis": "transcendentalizar",
    "transcendentalizássemos": "transcendentalizar",
    "transcendentalizávamo": "transcendentalizar",
    "transcendentalizávamos": "transcendentalizar",
    "transcendentalizávei": "transcendentalizar",
    "transcendentalizáveis": "transcendentalizar",
    "transcendentes": "transcendente",
    "transcendera": "transcender",
    "transcenderam": "transcender",
    "transcenderas": "transcender",
    "transcenderde": "transcender",
    "transcenderdes": "transcender",
    "transcendere": "transcender",
    "transcenderei": "transcender",
    "transcendereis": "transcender",
    "transcenderem": "transcender",
    "transcenderemos": "transcender",
    "transcenderes": "transcender",
    "transcenderia": "transcender",
    "transcenderiam": "transcender",
    "transcenderias": "transcender",
    "transcendermo": "transcender",
    "transcendermos": "transcender",
    "transcenderá": "transcender",
    "transcenderás": "transcender",
    "transcenderão": "transcender",
    "transcenderíamos": "transcender",
    "transcenderíeis": "transcender",
    "transcendes": "transcender",
    "transcendesse": "transcender",
    "transcendessem": "transcender",
    "transcendesses": "transcender",
    "transcendeste": "transcender",
    "transcendestes": "transcender",
    "transcendeu": "transcender",
    "transcendi": "transcender",
    "transcendia": "transcender",
    "transcendiam": "transcender",
    "transcendias": "transcender",
    "transcendida": "transcender",
    "transcendidas": "transcender",
    "transcendido": "transcender",
    "transcendidos": "transcender",
    "transcendo": "transcender",
    "transcendê": "transcender",
    "transcendências": "transcendência",
    "transcendêramo": "transcender",
    "transcendêramos": "transcender",
    "transcendêrei": "transcender",
    "transcendêreis": "transcender",
    "transcendêsseis": "transcender",
    "transcendêssemos": "transcender",
    "transcendíamo": "transcender",
    "transcendíamos": "transcender",
    "transcendíei": "transcender",
    "transcendíeis": "transcender",
    "transcensões": "transcensão",
    "transceptores": "transceptor",
    "transcoa": "transcoar",
    "transcoada": "transcoar",
    "transcoadas": "transcoar",
    "transcoado": "transcoar",
    "transcoados": "transcoar",
    "transcoai": "transcoar",
    "transcoais": "transcoar",
    "transcoam": "transcoar",
    "transcoamo": "transcoar",
    "transcoamos": "transcoar",
    "transcoando": "transcoar",
    "transcoara": "transcoar",
    "transcoaram": "transcoar",
    "transcoaras": "transcoar",
    "transcoarde": "transcoar",
    "transcoardes": "transcoar",
    "transcoare": "transcoar",
    "transcoarei": "transcoar",
    "transcoareis": "transcoar",
    "transcoarem": "transcoar",
    "transcoaremos": "transcoar",
    "transcoares": "transcoar",
    "transcoaria": "transcoar",
    "transcoariam": "transcoar",
    "transcoarias": "transcoar",
    "transcoarmo": "transcoar",
    "transcoarmos": "transcoar",
    "transcoará": "transcoar",
    "transcoarás": "transcoar",
    "transcoarão": "transcoar",
    "transcoaríamos": "transcoar",
    "transcoaríeis": "transcoar",
    "transcoas": "transcoar",
    "transcoasse": "transcoar",
    "transcoassem": "transcoar",
    "transcoasses": "transcoar",
    "transcoaste": "transcoar",
    "transcoastes": "transcoar",
    "transcoava": "transcoar",
    "transcoavam": "transcoar",
    "transcoavas": "transcoar",
    "transcoações": "transcoação",
    "transcoe": "transcoar",
    "transcoei": "transcoar",
    "transcoeis": "transcoar",
    "transcoem": "transcoar",
    "transcoemo": "transcoar",
    "transcoemos": "transcoar",
    "transcoes": "transcoar",
    "transcola": "transcolar",
    "transcolada": "transcolar",
    "transcoladas": "transcolar",
    "transcolado": "transcolar",
    "transcolados": "transcolar",
    "transcolai": "transcolar",
    "transcolais": "transcolar",
    "transcolam": "transcolar",
    "transcolamo": "transcolar",
    "transcolamos": "transcolar",
    "transcolando": "transcolar",
    "transcolara": "transcolar",
    "transcolaram": "transcolar",
    "transcolaras": "transcolar",
    "transcolarde": "transcolar",
    "transcolardes": "transcolar",
    "transcolare": "transcolar",
    "transcolarei": "transcolar",
    "transcolareis": "transcolar",
    "transcolarem": "transcolar",
    "transcolaremos": "transcolar",
    "transcolares": "transcolar",
    "transcolaria": "transcolar",
    "transcolariam": "transcolar",
    "transcolarias": "transcolar",
    "transcolarmo": "transcolar",
    "transcolarmos": "transcolar",
    "transcolará": "transcolar",
    "transcolarás": "transcolar",
    "transcolarão": "transcolar",
    "transcolaríamos": "transcolar",
    "transcolaríeis": "transcolar",
    "transcolas": "transcolar",
    "transcolasse": "transcolar",
    "transcolassem": "transcolar",
    "transcolasses": "transcolar",
    "transcolaste": "transcolar",
    "transcolastes": "transcolar",
    "transcolava": "transcolar",
    "transcolavam": "transcolar",
    "transcolavas": "transcolar",
    "transcolações": "transcolação",
    "transcole": "transcolar",
    "transcolei": "transcolar",
    "transcoleis": "transcolar",
    "transcolem": "transcolar",
    "transcolemo": "transcolar",
    "transcolemos": "transcolar",
    "transcoles": "transcolar",
    "transcolo": "transcolar",
    "transcolou": "transcolar",
    "transcolá": "transcolar",
    "transcolámo": "transcolar",
    "transcolámos": "transcolar",
    "transcoláramo": "transcolar",
    "transcoláramos": "transcolar",
    "transcolárei": "transcolar",
    "transcoláreis": "transcolar",
    "transcolásseis": "transcolar",
    "transcolássemos": "transcolar",
    "transcolávamo": "transcolar",
    "transcolávamos": "transcolar",
    "transcolávei": "transcolar",
    "transcoláveis": "transcolar",
    "transcomunicações": "transcomunicação",
    "transcondutâncias": "transcondutância",
    "transcontinentais": "transcontinental",
    "transcoo": "transcoar",
    "transcoou": "transcoar",
    "transcorra": "transcorrer",
    "transcorrais": "transcorrer",
    "transcorram": "transcorrer",
    "transcorramo": "transcorrer",
    "transcorramos": "transcorrer",
    "transcorras": "transcorrer",
    "transcorre": "transcorrer",
    "transcorrei": "transcorrer",
    "transcorreis": "transcorrer",
    "transcorrem": "transcorrer",
    "transcorremo": "transcorrer",
    "transcorremos": "transcorrer",
    "transcorrendo": "transcorrer",
    "transcorrentes": "transcorrente",
    "transcorrera": "transcorrer",
    "transcorreram": "transcorrer",
    "transcorreras": "transcorrer",
    "transcorrerde": "transcorrer",
    "transcorrerdes": "transcorrer",
    "transcorrere": "transcorrer",
    "transcorrerei": "transcorrer",
    "transcorrereis": "transcorrer",
    "transcorrerem": "transcorrer",
    "transcorreremos": "transcorrer",
    "transcorreres": "transcorrer",
    "transcorreria": "transcorrer",
    "transcorreriam": "transcorrer",
    "transcorrerias": "transcorrer",
    "transcorrermo": "transcorrer",
    "transcorrermos": "transcorrer",
    "transcorrerá": "transcorrer",
    "transcorrerás": "transcorrer",
    "transcorrerão": "transcorrer",
    "transcorreríamos": "transcorrer",
    "transcorreríeis": "transcorrer",
    "transcorres": "transcorrer",
    "transcorresse": "transcorrer",
    "transcorressem": "transcorrer",
    "transcorresses": "transcorrer",
    "transcorreste": "transcorrer",
    "transcorrestes": "transcorrer",
    "transcorreu": "transcorrer",
    "transcorri": "transcorrer",
    "transcorria": "transcorrer",
    "transcorriam": "transcorrer",
    "transcorrias": "transcorrer",
    "transcorrida": "transcorrido",
    "transcorridas": "transcorrido",
    "transcorrido": "transcorrer",
    "transcorridos": "transcorrido",
    "transcorro": "transcorrer",
    "transcorrê": "transcorrer",
    "transcorrências": "transcorrência",
    "transcorrêramo": "transcorrer",
    "transcorrêramos": "transcorrer",
    "transcorrêrei": "transcorrer",
    "transcorrêreis": "transcorrer",
    "transcorrêsseis": "transcorrer",
    "transcorrêssemos": "transcorrer",
    "transcorríamo": "transcorrer",
    "transcorríamos": "transcorrer",
    "transcorríei": "transcorrer",
    "transcorríeis": "transcorrer",
    "transcorva": "transcorvo",
    "transcorvas": "transcorvo",
    "transcorvos": "transcorvo",
    "transcoá": "transcoar",
    "transcoámo": "transcoar",
    "transcoámos": "transcoar",
    "transcoáramo": "transcoar",
    "transcoáramos": "transcoar",
    "transcoárei": "transcoar",
    "transcoáreis": "transcoar",
    "transcoásseis": "transcoar",
    "transcoássemos": "transcoar",
    "transcoávamo": "transcoar",
    "transcoávamos": "transcoar",
    "transcoávei": "transcoar",
    "transcoáveis": "transcoar",
    "transcreva": "transcrever",
    "transcrevais": "transcrever",
    "transcrevam": "transcrever",
    "transcrevamo": "transcrever",
    "transcrevamos": "transcrever",
    "transcrevas": "transcrever",
    "transcreve": "transcrever",
    "transcrevei": "transcrever",
    "transcreveis": "transcrever",
    "transcrevem": "transcrever",
    "transcrevemo": "transcrever",
    "transcrevemos": "transcrever",
    "transcrevendo": "transcrever",
    "transcrevera": "transcrever",
    "transcreveram": "transcrever",
    "transcreveras": "transcrever",
    "transcreverde": "transcrever",
    "transcreverdes": "transcrever",
    "transcrevere": "transcrever",
    "transcreverei": "transcrever",
    "transcrevereis": "transcrever",
    "transcreverem": "transcrever",
    "transcreveremos": "transcrever",
    "transcreveres": "transcrever",
    "transcreveria": "transcrever",
    "transcreveriam": "transcrever",
    "transcreverias": "transcrever",
    "transcrevermo": "transcrever",
    "transcrevermos": "transcrever",
    "transcreverá": "transcrever",
    "transcreverás": "transcrever",
    "transcreverão": "transcrever",
    "transcreveríamos": "transcrever",
    "transcreveríeis": "transcrever",
    "transcreves": "transcrever",
    "transcrevesse": "transcrever",
    "transcrevessem": "transcrever",
    "transcrevesses": "transcrever",
    "transcreveste": "transcrever",
    "transcrevestes": "transcrever",
    "transcreveu": "transcrever",
    "transcrevi": "transcrever",
    "transcrevia": "transcrever",
    "transcreviam": "transcrever",
    "transcrevias": "transcrever",
    "transcrevo": "transcrever",
    "transcrevê": "transcrever",
    "transcrevêramo": "transcrever",
    "transcrevêramos": "transcrever",
    "transcrevêrei": "transcrever",
    "transcrevêreis": "transcrever",
    "transcrevêsseis": "transcrever",
    "transcrevêssemos": "transcrever",
    "transcrevíamo": "transcrever",
    "transcrevíamos": "transcrever",
    "transcrevíei": "transcrever",
    "transcrevíeis": "transcrever",
    "transcriptases": "transcriptase",
    "transcrita": "transcrito",
    "transcritas": "transcrito",
    "transcrito": "transcrever",
    "transcritora": "transcritor",
    "transcritoras": "transcritor",
    "transcritores": "transcritor",
    "transcritos": "transcrito",
    "transcrições": "transcrição",
    "transcudana": "transcudano",
    "transcudanas": "transcudano",
    "transcudanos": "transcudano",
    "transcura": "transcurar",
    "transcurada": "transcurar",
    "transcuradas": "transcurar",
    "transcurado": "transcurar",
    "transcurados": "transcurar",
    "transcurai": "transcurar",
    "transcurais": "transcurar",
    "transcuram": "transcurar",
    "transcuramo": "transcurar",
    "transcuramos": "transcurar",
    "transcurando": "transcurar",
    "transcurara": "transcurar",
    "transcuraram": "transcurar",
    "transcuraras": "transcurar",
    "transcurarde": "transcurar",
    "transcurardes": "transcurar",
    "transcurare": "transcurar",
    "transcurarei": "transcurar",
    "transcurareis": "transcurar",
    "transcurarem": "transcurar",
    "transcuraremos": "transcurar",
    "transcurares": "transcurar",
    "transcuraria": "transcurar",
    "transcurariam": "transcurar",
    "transcurarias": "transcurar",
    "transcurarmo": "transcurar",
    "transcurarmos": "transcurar",
    "transcurará": "transcurar",
    "transcurarás": "transcurar",
    "transcurarão": "transcurar",
    "transcuraríamos": "transcurar",
    "transcuraríeis": "transcurar",
    "transcuras": "transcurar",
    "transcurasse": "transcurar",
    "transcurassem": "transcurar",
    "transcurasses": "transcurar",
    "transcuraste": "transcurar",
    "transcurastes": "transcurar",
    "transcurava": "transcurar",
    "transcuravam": "transcurar",
    "transcuravas": "transcurar",
    "transcure": "transcurar",
    "transcurei": "transcurar",
    "transcureis": "transcurar",
    "transcurem": "transcurar",
    "transcuremo": "transcurar",
    "transcuremos": "transcurar",
    "transcures": "transcurar",
    "transcuro": "transcurar",
    "transcurou": "transcurar",
    "transcursa": "transcursar",
    "transcursada": "transcursar",
    "transcursadas": "transcursar",
    "transcursado": "transcursar",
    "transcursados": "transcursar",
    "transcursai": "transcursar",
    "transcursais": "transcursar",
    "transcursam": "transcursar",
    "transcursamo": "transcursar",
    "transcursamos": "transcursar",
    "transcursando": "transcursar",
    "transcursara": "transcursar",
    "transcursaram": "transcursar",
    "transcursaras": "transcursar",
    "transcursarde": "transcursar",
    "transcursardes": "transcursar",
    "transcursare": "transcursar",
    "transcursarei": "transcursar",
    "transcursareis": "transcursar",
    "transcursarem": "transcursar",
    "transcursaremos": "transcursar",
    "transcursares": "transcursar",
    "transcursaria": "transcursar",
    "transcursariam": "transcursar",
    "transcursarias": "transcursar",
    "transcursarmo": "transcursar",
    "transcursarmos": "transcursar",
    "transcursará": "transcursar",
    "transcursarás": "transcursar",
    "transcursarão": "transcursar",
    "transcursaríamos": "transcursar",
    "transcursaríeis": "transcursar",
    "transcursas": "transcursar",
    "transcursasse": "transcursar",
    "transcursassem": "transcursar",
    "transcursasses": "transcursar",
    "transcursaste": "transcursar",
    "transcursastes": "transcursar",
    "transcursava": "transcursar",
    "transcursavam": "transcursar",
    "transcursavas": "transcursar",
    "transcurse": "transcursar",
    "transcursei": "transcursar",
    "transcurseis": "transcursar",
    "transcursem": "transcursar",
    "transcursemo": "transcursar",
    "transcursemos": "transcursar",
    "transcurses": "transcursar",
    "transcurso": "transcursar",
    "transcursos": "transcurso",
    "transcursou": "transcursar",
    "transcursá": "transcursar",
    "transcursámo": "transcursar",
    "transcursámos": "transcursar",
    "transcursáramo": "transcursar",
    "transcursáramos": "transcursar",
    "transcursárei": "transcursar",
    "transcursáreis": "transcursar",
    "transcursásseis": "transcursar",
    "transcursássemos": "transcursar",
    "transcursávamo": "transcursar",
    "transcursávamos": "transcursar",
    "transcursávei": "transcursar",
    "transcursáveis": "transcursar",
    "transcursões": "transcursão",
    "transcurva": "transcurvo",
    "transcurvas": "transcurvo",
    "transcurvos": "transcurvo",
    "transcurá": "transcurar",
    "transcurámo": "transcurar",
    "transcurámos": "transcurar",
    "transcuráramo": "transcurar",
    "transcuráramos": "transcurar",
    "transcurárei": "transcurar",
    "transcuráreis": "transcurar",
    "transcurásseis": "transcurar",
    "transcurássemos": "transcurar",
    "transcurávamo": "transcurar",
    "transcurávamos": "transcurar",
    "transcurávei": "transcurar",
    "transcuráveis": "transcurar",
    "transdanubiana": "transdanubiano",
    "transdanubianas": "transdanubiano",
    "transdanubianos": "transdanubiano",
    "transdisciplinaridades": "transdisciplinaridade",
    "transdutores": "transdutor",
    "transduções": "transdução",
    "transe": "transir",
    "transeculares": "transecular",
    "transem": "transir",
    "transenas": "transena",
    "transeptais": "transeptal",
    "transeptos": "transepto",
    "transequatoriais": "transequatorial",
    "transes": "transir",
    "transeuntes": "transeunte",
    "transeuropeia": "transeuropeu",
    "transeuropeias": "transeuropeu",
    "transeuropeus": "transeuropeu",
    "transexuais": "transexual",
    "transexualismos": "transexualismo",
    "transfega": "transfegar",
    "transfegada": "transfegar",
    "transfegadas": "transfegar",
    "transfegado": "transfegar",
    "transfegados": "transfegar",
    "transfegai": "transfegar",
    "transfegais": "transfegar",
    "transfegam": "transfegar",
    "transfegamo": "transfegar",
    "transfegamos": "transfegar",
    "transfegando": "transfegar",
    "transfegara": "transfegar",
    "transfegaram": "transfegar",
    "transfegaras": "transfegar",
    "transfegarde": "transfegar",
    "transfegardes": "transfegar",
    "transfegare": "transfegar",
    "transfegarei": "transfegar",
    "transfegareis": "transfegar",
    "transfegarem": "transfegar",
    "transfegaremos": "transfegar",
    "transfegares": "transfegar",
    "transfegaria": "transfegar",
    "transfegariam": "transfegar",
    "transfegarias": "transfegar",
    "transfegarmo": "transfegar",
    "transfegarmos": "transfegar",
    "transfegará": "transfegar",
    "transfegarás": "transfegar",
    "transfegarão": "transfegar",
    "transfegaríamos": "transfegar",
    "transfegaríeis": "transfegar",
    "transfegas": "transfegar",
    "transfegasse": "transfegar",
    "transfegassem": "transfegar",
    "transfegasses": "transfegar",
    "transfegaste": "transfegar",
    "transfegastes": "transfegar",
    "transfegava": "transfegar",
    "transfegavam": "transfegar",
    "transfegavas": "transfegar",
    "transfego": "transfegar",
    "transfegou": "transfegar",
    "transfegue": "transfegar",
    "transfeguei": "transfegar",
    "transfegueis": "transfegar",
    "transfeguem": "transfegar",
    "transfeguemo": "transfegar",
    "transfeguemos": "transfegar",
    "transfegues": "transfegar",
    "transfegá": "transfegar",
    "transfegámo": "transfegar",
    "transfegámos": "transfegar",
    "transfegáramo": "transfegar",
    "transfegáramos": "transfegar",
    "transfegárei": "transfegar",
    "transfegáreis": "transfegar",
    "transfegásseis": "transfegar",
    "transfegássemos": "transfegar",
    "transfegávamo": "transfegar",
    "transfegávamos": "transfegar",
    "transfegávei": "transfegar",
    "transfegáveis": "transfegar",
    "transfere": "transferir",
    "transferem": "transferir",
    "transferes": "transferir",
    "transferi": "transferir",
    "transferia": "transferir",
    "transferiam": "transferir",
    "transferias": "transferir",
    "transferida": "transferir",
    "transferidas": "transferir",
    "transferido": "transferir",
    "transferidora": "transferidor",
    "transferidoras": "transferidor",
    "transferidores": "transferidor",
    "transferidos": "transferir",
    "transferimo": "transferir",
    "transferimos": "transferir",
    "transferindo": "transferir",
    "transferira": "transferir",
    "transferiram": "transferir",
    "transferiras": "transferir",
    "transferirde": "transferir",
    "transferirdes": "transferir",
    "transferire": "transferir",
    "transferirei": "transferir",
    "transferireis": "transferir",
    "transferirem": "transferir",
    "transferiremos": "transferir",
    "transferires": "transferir",
    "transferiria": "transferir",
    "transfeririam": "transferir",
    "transferirias": "transferir",
    "transferirmo": "transferir",
    "transferirmos": "transferir",
    "transferirá": "transferir",
    "transferirás": "transferir",
    "transferirão": "transferir",
    "transferiríamos": "transferir",
    "transferiríeis": "transferir",
    "transferis": "transferir",
    "transferisse": "transferir",
    "transferissem": "transferir",
    "transferisses": "transferir",
    "transferiste": "transferir",
    "transferistes": "transferir",
    "transferiu": "transferir",
    "transferências": "transferência",
    "transferíamo": "transferir",
    "transferíamos": "transferir",
    "transferíei": "transferir",
    "transferíeis": "transferir",
    "transferíramo": "transferir",
    "transferíramos": "transferir",
    "transferírei": "transferir",
    "transferíreis": "transferir",
    "transferísseis": "transferir",
    "transferíssemos": "transferir",
    "transferíveis": "transferível",
    "transfigura": "transfigurar",
    "transfigurada": "transfigurar",
    "transfiguradas": "transfigurar",
    "transfigurado": "transfigurar",
    "transfiguradora": "transfigurador",
    "transfiguradoras": "transfigurador",
    "transfiguradores": "transfigurador",
    "transfigurados": "transfigurar",
    "transfigurai": "transfigurar",
    "transfigurais": "transfigurar",
    "transfiguram": "transfigurar",
    "transfiguramo": "transfigurar",
    "transfiguramos": "transfigurar",
    "transfigurando": "transfigurar",
    "transfigurara": "transfigurar",
    "transfiguraram": "transfigurar",
    "transfiguraras": "transfigurar",
    "transfigurarde": "transfigurar",
    "transfigurardes": "transfigurar",
    "transfigurare": "transfigurar",
    "transfigurarei": "transfigurar",
    "transfigurareis": "transfigurar",
    "transfigurarem": "transfigurar",
    "transfiguraremos": "transfigurar",
    "transfigurares": "transfigurar",
    "transfiguraria": "transfigurar",
    "transfigurariam": "transfigurar",
    "transfigurarias": "transfigurar",
    "transfigurarmo": "transfigurar",
    "transfigurarmos": "transfigurar",
    "transfigurará": "transfigurar",
    "transfigurarás": "transfigurar",
    "transfigurarão": "transfigurar",
    "transfiguraríamos": "transfigurar",
    "transfiguraríeis": "transfigurar",
    "transfiguras": "transfigurar",
    "transfigurasse": "transfigurar",
    "transfigurassem": "transfigurar",
    "transfigurasses": "transfigurar",
    "transfiguraste": "transfigurar",
    "transfigurastes": "transfigurar",
    "transfigurava": "transfigurar",
    "transfiguravam": "transfigurar",
    "transfiguravas": "transfigurar",
    "transfigurações": "transfiguração",
    "transfigure": "transfigurar",
    "transfigurei": "transfigurar",
    "transfigureis": "transfigurar",
    "transfigurem": "transfigurar",
    "transfiguremo": "transfigurar",
    "transfiguremos": "transfigurar",
    "transfigures": "transfigurar",
    "transfiguro": "transfigurar",
    "transfigurou": "transfigurar",
    "transfigurá": "transfigurar",
    "transfigurámo": "transfigurar",
    "transfigurámos": "transfigurar",
    "transfiguráramo": "transfigurar",
    "transfiguráramos": "transfigurar",
    "transfigurárei": "transfigurar",
    "transfiguráreis": "transfigurar",
    "transfigurásseis": "transfigurar",
    "transfigurássemos": "transfigurar",
    "transfigurávamo": "transfigurar",
    "transfigurávamos": "transfigurar",
    "transfigurávei": "transfigurar",
    "transfiguráveis": "transfigurável",
    "transfiltra": "transfiltrar",
    "transfiltrada": "transfiltrar",
    "transfiltradas": "transfiltrar",
    "transfiltrado": "transfiltrar",
    "transfiltrados": "transfiltrar",
    "transfiltrai": "transfiltrar",
    "transfiltrais": "transfiltrar",
    "transfiltram": "transfiltrar",
    "transfiltramo": "transfiltrar",
    "transfiltramos": "transfiltrar",
    "transfiltrando": "transfiltrar",
    "transfiltrara": "transfiltrar",
    "transfiltraram": "transfiltrar",
    "transfiltraras": "transfiltrar",
    "transfiltrarde": "transfiltrar",
    "transfiltrardes": "transfiltrar",
    "transfiltrare": "transfiltrar",
    "transfiltrarei": "transfiltrar",
    "transfiltrareis": "transfiltrar",
    "transfiltrarem": "transfiltrar",
    "transfiltraremos": "transfiltrar",
    "transfiltrares": "transfiltrar",
    "transfiltraria": "transfiltrar",
    "transfiltrariam": "transfiltrar",
    "transfiltrarias": "transfiltrar",
    "transfiltrarmo": "transfiltrar",
    "transfiltrarmos": "transfiltrar",
    "transfiltrará": "transfiltrar",
    "transfiltrarás": "transfiltrar",
    "transfiltrarão": "transfiltrar",
    "transfiltraríamos": "transfiltrar",
    "transfiltraríeis": "transfiltrar",
    "transfiltras": "transfiltrar",
    "transfiltrasse": "transfiltrar",
    "transfiltrassem": "transfiltrar",
    "transfiltrasses": "transfiltrar",
    "transfiltraste": "transfiltrar",
    "transfiltrastes": "transfiltrar",
    "transfiltrava": "transfiltrar",
    "transfiltravam": "transfiltrar",
    "transfiltravas": "transfiltrar",
    "transfiltre": "transfiltrar",
    "transfiltrei": "transfiltrar",
    "transfiltreis": "transfiltrar",
    "transfiltrem": "transfiltrar",
    "transfiltremo": "transfiltrar",
    "transfiltremos": "transfiltrar",
    "transfiltres": "transfiltrar",
    "transfiltro": "transfiltrar",
    "transfiltrou": "transfiltrar",
    "transfiltrá": "transfiltrar",
    "transfiltrámo": "transfiltrar",
    "transfiltrámos": "transfiltrar",
    "transfiltráramo": "transfiltrar",
    "transfiltráramos": "transfiltrar",
    "transfiltrárei": "transfiltrar",
    "transfiltráreis": "transfiltrar",
    "transfiltrásseis": "transfiltrar",
    "transfiltrássemos": "transfiltrar",
    "transfiltrávamo": "transfiltrar",
    "transfiltrávamos": "transfiltrar",
    "transfiltrávei": "transfiltrar",
    "transfiltráveis": "transfiltrar",
    "transfinita": "transfinito",
    "transfinitas": "transfinito",
    "transfinitos": "transfinito",
    "transfira": "transferir",
    "transfirais": "transferir",
    "transfiram": "transferir",
    "transfiramo": "transferir",
    "transfiramos": "transferir",
    "transfiras": "transferir",
    "transfiro": "transferir",
    "transfixa": "transfixar",
    "transfixada": "transfixar",
    "transfixadas": "transfixar",
    "transfixado": "transfixar",
    "transfixados": "transfixar",
    "transfixai": "transfixar",
    "transfixais": "transfixar",
    "transfixam": "transfixar",
    "transfixamo": "transfixar",
    "transfixamos": "transfixar",
    "transfixando": "transfixar",
    "transfixara": "transfixar",
    "transfixaram": "transfixar",
    "transfixaras": "transfixar",
    "transfixarde": "transfixar",
    "transfixardes": "transfixar",
    "transfixare": "transfixar",
    "transfixarei": "transfixar",
    "transfixareis": "transfixar",
    "transfixarem": "transfixar",
    "transfixaremos": "transfixar",
    "transfixares": "transfixar",
    "transfixaria": "transfixar",
    "transfixariam": "transfixar",
    "transfixarias": "transfixar",
    "transfixarmo": "transfixar",
    "transfixarmos": "transfixar",
    "transfixará": "transfixar",
    "transfixarás": "transfixar",
    "transfixarão": "transfixar",
    "transfixaríamos": "transfixar",
    "transfixaríeis": "transfixar",
    "transfixas": "transfixar",
    "transfixasse": "transfixar",
    "transfixassem": "transfixar",
    "transfixasses": "transfixar",
    "transfixaste": "transfixar",
    "transfixastes": "transfixar",
    "transfixava": "transfixar",
    "transfixavam": "transfixar",
    "transfixavas": "transfixar",
    "transfixações": "transfixação",
    "transfixe": "transfixar",
    "transfixei": "transfixar",
    "transfixeis": "transfixar",
    "transfixem": "transfixar",
    "transfixemo": "transfixar",
    "transfixemos": "transfixar",
    "transfixes": "transfixar",
    "transfixo": "transfixar",
    "transfixou": "transfixar",
    "transfixá": "transfixar",
    "transfixámo": "transfixar",
    "transfixámos": "transfixar",
    "transfixáramo": "transfixar",
    "transfixáramos": "transfixar",
    "transfixárei": "transfixar",
    "transfixáreis": "transfixar",
    "transfixásseis": "transfixar",
    "transfixássemos": "transfixar",
    "transfixávamo": "transfixar",
    "transfixávamos": "transfixar",
    "transfixávei": "transfixar",
    "transfixáveis": "transfixar",
    "transfixões": "transfixão",
    "transfoge": "transfugir",
    "transfogem": "transfugir",
    "transfoges": "transfugir",
    "transfolia": "transfoliar",
    "transfoliada": "transfoliar",
    "transfoliadas": "transfoliar",
    "transfoliado": "transfoliar",
    "transfoliados": "transfoliar",
    "transfoliai": "transfoliar",
    "transfoliais": "transfoliar",
    "transfoliam": "transfoliar",
    "transfoliamo": "transfoliar",
    "transfoliamos": "transfoliar",
    "transfoliando": "transfoliar",
    "transfoliara": "transfoliar",
    "transfoliaram": "transfoliar",
    "transfoliaras": "transfoliar",
    "transfoliarde": "transfoliar",
    "transfoliardes": "transfoliar",
    "transfoliare": "transfoliar",
    "transfoliarei": "transfoliar",
    "transfoliareis": "transfoliar",
    "transfoliarem": "transfoliar",
    "transfoliaremos": "transfoliar",
    "transfoliares": "transfoliar",
    "transfoliaria": "transfoliar",
    "transfoliariam": "transfoliar",
    "transfoliarias": "transfoliar",
    "transfoliarmo": "transfoliar",
    "transfoliarmos": "transfoliar",
    "transfoliará": "transfoliar",
    "transfoliarás": "transfoliar",
    "transfoliarão": "transfoliar",
    "transfoliaríamos": "transfoliar",
    "transfoliaríeis": "transfoliar",
    "transfolias": "transfoliar",
    "transfoliasse": "transfoliar",
    "transfoliassem": "transfoliar",
    "transfoliasses": "transfoliar",
    "transfoliaste": "transfoliar",
    "transfoliastes": "transfoliar",
    "transfoliava": "transfoliar",
    "transfoliavam": "transfoliar",
    "transfoliavas": "transfoliar",
    "transfolie": "transfoliar",
    "transfoliei": "transfoliar",
    "transfolieis": "transfoliar",
    "transfoliem": "transfoliar",
    "transfoliemo": "transfoliar",
    "transfoliemos": "transfoliar",
    "transfolies": "transfoliar",
    "transfolio": "transfoliar",
    "transfoliou": "transfoliar",
    "transfoliá": "transfoliar",
    "transfoliámo": "transfoliar",
    "transfoliámos": "transfoliar",
    "transfoliáramo": "transfoliar",
    "transfoliáramos": "transfoliar",
    "transfoliárei": "transfoliar",
    "transfoliáreis": "transfoliar",
    "transfoliásseis": "transfoliar",
    "transfoliássemos": "transfoliar",
    "transfoliávamo": "transfoliar",
    "transfoliávamos": "transfoliar",
    "transfoliávei": "transfoliar",
    "transfoliáveis": "transfoliar",
    "transforma": "transformar",
    "transformacionais": "transformacional",
    "transformada": "transformar",
    "transformadas": "transformar",
    "transformado": "transformar",
    "transformadora": "transformador",
    "transformadoras": "transformador",
    "transformadores": "transformador",
    "transformados": "transformar",
    "transformai": "transformar",
    "transformais": "transformar",
    "transformam": "transformar",
    "transformamo": "transformar",
    "transformamos": "transformar",
    "transformando": "transformar",
    "transformantes": "transformante",
    "transformara": "transformar",
    "transformaram": "transformar",
    "transformaras": "transformar",
    "transformarde": "transformar",
    "transformardes": "transformar",
    "transformare": "transformar",
    "transformarei": "transformar",
    "transformareis": "transformar",
    "transformarem": "transformar",
    "transformaremos": "transformar",
    "transformares": "transformar",
    "transformaria": "transformar",
    "transformariam": "transformar",
    "transformarias": "transformar",
    "transformarmo": "transformar",
    "transformarmos": "transformar",
    "transformará": "transformar",
    "transformarás": "transformar",
    "transformarão": "transformar",
    "transformaríamos": "transformar",
    "transformaríeis": "transformar",
    "transformas": "transformar",
    "transformasse": "transformar",
    "transformassem": "transformar",
    "transformasses": "transformar",
    "transformaste": "transformar",
    "transformastes": "transformar",
    "transformativa": "transformativo",
    "transformativas": "transformativo",
    "transformativos": "transformativo",
    "transformava": "transformar",
    "transformavam": "transformar",
    "transformavas": "transformar",
    "transformações": "transformação",
    "transforme": "transformar",
    "transformei": "transformar",
    "transformeis": "transformar",
    "transformem": "transformar",
    "transformemo": "transformar",
    "transformemos": "transformar",
    "transformes": "transformar",
    "transformismos": "transformismo",
    "transformistas": "transformista",
    "transformo": "transformar",
    "transformou": "transformar",
    "transformá": "transformar",
    "transformámo": "transformar",
    "transformámos": "transformar",
    "transformáramo": "transformar",
    "transformáramos": "transformar",
    "transformárei": "transformar",
    "transformáreis": "transformar",
    "transformásseis": "transformar",
    "transformássemos": "transformar",
    "transformávamo": "transformar",
    "transformávamos": "transformar",
    "transformávei": "transformar",
    "transformáveis": "transformável",
    "transfreta": "transfretar",
    "transfretada": "transfretar",
    "transfretadas": "transfretar",
    "transfretado": "transfretar",
    "transfretados": "transfretar",
    "transfretai": "transfretar",
    "transfretais": "transfretar",
    "transfretam": "transfretar",
    "transfretamo": "transfretar",
    "transfretamos": "transfretar",
    "transfretana": "transfretano",
    "transfretanas": "transfretano",
    "transfretando": "transfretar",
    "transfretanos": "transfretano",
    "transfretara": "transfretar",
    "transfretaram": "transfretar",
    "transfretaras": "transfretar",
    "transfretarde": "transfretar",
    "transfretardes": "transfretar",
    "transfretare": "transfretar",
    "transfretarei": "transfretar",
    "transfretareis": "transfretar",
    "transfretarem": "transfretar",
    "transfretaremos": "transfretar",
    "transfretares": "transfretar",
    "transfretaria": "transfretar",
    "transfretariam": "transfretar",
    "transfretarias": "transfretar",
    "transfretarmo": "transfretar",
    "transfretarmos": "transfretar",
    "transfretará": "transfretar",
    "transfretarás": "transfretar",
    "transfretarão": "transfretar",
    "transfretaríamos": "transfretar",
    "transfretaríeis": "transfretar",
    "transfretas": "transfretar",
    "transfretasse": "transfretar",
    "transfretassem": "transfretar",
    "transfretasses": "transfretar",
    "transfretaste": "transfretar",
    "transfretastes": "transfretar",
    "transfretava": "transfretar",
    "transfretavam": "transfretar",
    "transfretavas": "transfretar",
    "transfrete": "transfretar",
    "transfretei": "transfretar",
    "transfreteis": "transfretar",
    "transfretem": "transfretar",
    "transfretemo": "transfretar",
    "transfretemos": "transfretar",
    "transfretes": "transfretar",
    "transfreto": "transfretar",
    "transfretou": "transfretar",
    "transfretá": "transfretar",
    "transfretámo": "transfretar",
    "transfretámos": "transfretar",
    "transfretáramo": "transfretar",
    "transfretáramos": "transfretar",
    "transfretárei": "transfretar",
    "transfretáreis": "transfretar",
    "transfretásseis": "transfretar",
    "transfretássemos": "transfretar",
    "transfretávamo": "transfretar",
    "transfretávamos": "transfretar",
    "transfretávei": "transfretar",
    "transfretáveis": "transfretar",
    "transfronteiriça": "transfronteiriço",
    "transfronteiriças": "transfronteiriço",
    "transfronteiriços": "transfronteiriço",
    "transfugi": "transfugir",
    "transfugia": "transfugir",
    "transfugiam": "transfugir",
    "transfugias": "transfugir",
    "transfugida": "transfugir",
    "transfugidas": "transfugir",
    "transfugido": "transfugir",
    "transfugidos": "transfugir",
    "transfugimo": "transfugir",
    "transfugimos": "transfugir",
    "transfugindo": "transfugir",
    "transfugira": "transfugir",
    "transfugiram": "transfugir",
    "transfugiras": "transfugir",
    "transfugirdes": "transfugir",
    "transfugirei": "transfugir",
    "transfugireis": "transfugir",
    "transfugirem": "transfugir",
    "transfugiremos": "transfugir",
    "transfugires": "transfugir",
    "transfugiria": "transfugir",
    "transfugiriam": "transfugir",
    "transfugirias": "transfugir",
    "transfugirmo": "transfugir",
    "transfugirmos": "transfugir",
    "transfugirá": "transfugir",
    "transfugirás": "transfugir",
    "transfugirão": "transfugir",
    "transfugiríamos": "transfugir",
    "transfugiríeis": "transfugir",
    "transfugis": "transfugir",
    "transfugisse": "transfugir",
    "transfugissem": "transfugir",
    "transfugisses": "transfugir",
    "transfugiste": "transfugir",
    "transfugistes": "transfugir",
    "transfugiu": "transfugir",
    "transfugíamo": "transfugir",
    "transfugíamos": "transfugir",
    "transfugíeis": "transfugir",
    "transfugíramo": "transfugir",
    "transfugíramos": "transfugir",
    "transfugíreis": "transfugir",
    "transfugísseis": "transfugir",
    "transfugíssemos": "transfugir",
    "transfuja": "transfugir",
    "transfujais": "transfugir",
    "transfujam": "transfugir",
    "transfujamo": "transfugir",
    "transfujamos": "transfugir",
    "transfujas": "transfugir",
    "transfujo": "transfugir",
    "transfunctória": "transfunctório",
    "transfunctórias": "transfunctório",
    "transfunctórios": "transfunctório",
    "transfunda": "transfundir",
    "transfundais": "transfundir",
    "transfundam": "transfundir",
    "transfundamo": "transfundir",
    "transfundamos": "transfundir",
    "transfundas": "transfundir",
    "transfunde": "transfundir",
    "transfundem": "transfundir",
    "transfundes": "transfundir",
    "transfundi": "transfundir",
    "transfundia": "transfundir",
    "transfundiam": "transfundir",
    "transfundias": "transfundir",
    "transfundida": "transfundir",
    "transfundidas": "transfundir",
    "transfundido": "transfundir",
    "transfundidos": "transfundir",
    "transfundimo": "transfundir",
    "transfundimos": "transfundir",
    "transfundindo": "transfundir",
    "transfundira": "transfundir",
    "transfundiram": "transfundir",
    "transfundiras": "transfundir",
    "transfundirde": "transfundir",
    "transfundirdes": "transfundir",
    "transfundire": "transfundir",
    "transfundirei": "transfundir",
    "transfundireis": "transfundir",
    "transfundirem": "transfundir",
    "transfundiremos": "transfundir",
    "transfundires": "transfundir",
    "transfundiria": "transfundir",
    "transfundiriam": "transfundir",
    "transfundirias": "transfundir",
    "transfundirmo": "transfundir",
    "transfundirmos": "transfundir",
    "transfundirá": "transfundir",
    "transfundirás": "transfundir",
    "transfundirão": "transfundir",
    "transfundiríamos": "transfundir",
    "transfundiríeis": "transfundir",
    "transfundis": "transfundir",
    "transfundisse": "transfundir",
    "transfundissem": "transfundir",
    "transfundisses": "transfundir",
    "transfundiste": "transfundir",
    "transfundistes": "transfundir",
    "transfundiu": "transfundir",
    "transfundo": "transfundir",
    "transfundíamo": "transfundir",
    "transfundíamos": "transfundir",
    "transfundíei": "transfundir",
    "transfundíeis": "transfundir",
    "transfundíramo": "transfundir",
    "transfundíramos": "transfundir",
    "transfundírei": "transfundir",
    "transfundíreis": "transfundir",
    "transfundísseis": "transfundir",
    "transfundíssemos": "transfundir",
    "transfusões": "transfusão",
    "transfúgios": "transfúgio",
    "transgangética": "transgangético",
    "transgangéticas": "transgangético",
    "transgangéticos": "transgangético",
    "transgredi": "transgredir",
    "transgredia": "transgredir",
    "transgrediam": "transgredir",
    "transgredias": "transgredir",
    "transgredida": "transgredir",
    "transgredidas": "transgredir",
    "transgredido": "transgredir",
    "transgredidos": "transgredir",
    "transgredimo": "transgredir",
    "transgredimos": "transgredir",
    "transgredindo": "transgredir",
    "transgredira": "transgredir",
    "transgrediram": "transgredir",
    "transgrediras": "transgredir",
    "transgredirde": "transgredir",
    "transgredirdes": "transgredir",
    "transgredire": "transgredir",
    "transgredirei": "transgredir",
    "transgredireis": "transgredir",
    "transgredirem": "transgredir",
    "transgrediremos": "transgredir",
    "transgredires": "transgredir",
    "transgrediria": "transgredir",
    "transgrediriam": "transgredir",
    "transgredirias": "transgredir",
    "transgredirmo": "transgredir",
    "transgredirmos": "transgredir",
    "transgredirá": "transgredir",
    "transgredirás": "transgredir",
    "transgredirão": "transgredir",
    "transgrediríamos": "transgredir",
    "transgrediríeis": "transgredir",
    "transgredis": "transgredir",
    "transgredisse": "transgredir",
    "transgredissem": "transgredir",
    "transgredisses": "transgredir",
    "transgrediste": "transgredir",
    "transgredistes": "transgredir",
    "transgrediu": "transgredir",
    "transgredíamo": "transgredir",
    "transgredíamos": "transgredir",
    "transgredíei": "transgredir",
    "transgredíeis": "transgredir",
    "transgredíramo": "transgredir",
    "transgredíramos": "transgredir",
    "transgredírei": "transgredir",
    "transgredíreis": "transgredir",
    "transgredísseis": "transgredir",
    "transgredíssemos": "transgredir",
    "transgredíveis": "transgredível",
    "transgressiva": "transgressivo",
    "transgressivas": "transgressivo",
    "transgressivos": "transgressivo",
    "transgressora": "transgressor",
    "transgressoras": "transgressor",
    "transgressores": "transgressor",
    "transgressões": "transgressão",
    "transgrida": "transgredir",
    "transgridais": "transgredir",
    "transgridam": "transgredir",
    "transgridamo": "transgredir",
    "transgridamos": "transgredir",
    "transgridas": "transgredir",
    "transgride": "transgredir",
    "transgridem": "transgredir",
    "transgrides": "transgredir",
    "transgrido": "transgredir",
    "transgénica": "transgénico",
    "transgénicas": "transgénico",
    "transgénicos": "transgénico",
    "transi": "transir",
    "transia": "transir",
    "transiam": "transir",
    "transias": "transir",
    "transiberiana": "transiberiano",
    "transiberianas": "transiberiano",
    "transiberianos": "transiberiano",
    "transida": "transir",
    "transidas": "transir",
    "transido": "transir",
    "transidos": "transir",
    "transige": "transigir",
    "transigem": "transigir",
    "transigentes": "transigente",
    "transiges": "transigir",
    "transigi": "transigir",
    "transigia": "transigir",
    "transigiam": "transigir",
    "transigias": "transigir",
    "transigida": "transigir",
    "transigidas": "transigir",
    "transigido": "transigir",
    "transigidos": "transigir",
    "transigimo": "transigir",
    "transigimos": "transigir",
    "transigindo": "transigir",
    "transigira": "transigir",
    "transigiram": "transigir",
    "transigiras": "transigir",
    "transigirdes": "transigir",
    "transigirei": "transigir",
    "transigireis": "transigir",
    "transigirem": "transigir",
    "transigiremos": "transigir",
    "transigires": "transigir",
    "transigiria": "transigir",
    "transigiriam": "transigir",
    "transigirias": "transigir",
    "transigirmo": "transigir",
    "transigirmos": "transigir",
    "transigirá": "transigir",
    "transigirás": "transigir",
    "transigirão": "transigir",
    "transigiríamos": "transigir",
    "transigiríeis": "transigir",
    "transigis": "transigir",
    "transigisse": "transigir",
    "transigissem": "transigir",
    "transigisses": "transigir",
    "transigiste": "transigir",
    "transigistes": "transigir",
    "transigiu": "transigir",
    "transigências": "transigência",
    "transigíamo": "transigir",
    "transigíamos": "transigir",
    "transigíeis": "transigir",
    "transigíramo": "transigir",
    "transigíramos": "transigir",
    "transigíreis": "transigir",
    "transigísseis": "transigir",
    "transigíssemos": "transigir",
    "transigíveis": "transigível",
    "transija": "transigir",
    "transijais": "transigir",
    "transijam": "transigir",
    "transijamo": "transigir",
    "transijamos": "transigir",
    "transijas": "transigir",
    "transijo": "transigir",
    "transilvana": "transilvano",
    "transilvanas": "transilvano",
    "transilvanos": "transilvano",
    "transimo": "transir",
    "transimos": "transir",
    "transindo": "transir",
    "transira": "transir",
    "transiram": "transir",
    "transiras": "transir",
    "transirde": "transir",
    "transirdes": "transir",
    "transire": "transir",
    "transirei": "transir",
    "transireis": "transir",
    "transirem": "transir",
    "transiremos": "transir",
    "transires": "transir",
    "transiria": "transir",
    "transiriam": "transir",
    "transirias": "transir",
    "transirmo": "transir",
    "transirmos": "transir",
    "transirá": "transir",
    "transirás": "transir",
    "transirão": "transir",
    "transiríamos": "transir",
    "transiríeis": "transir",
    "transis": "transir",
    "transisse": "transir",
    "transissem": "transir",
    "transisses": "transir",
    "transiste": "transir",
    "transistes": "transir",
    "transita": "transitar",
    "transitabilidades": "transitabilidade",
    "transitada": "transitar",
    "transitadas": "transitar",
    "transitado": "transitar",
    "transitados": "transitar",
    "transitai": "transitar",
    "transitais": "transitar",
    "transitam": "transitar",
    "transitamo": "transitar",
    "transitamos": "transitar",
    "transitando": "transitar",
    "transitara": "transitar",
    "transitaram": "transitar",
    "transitaras": "transitar",
    "transitardes": "transitar",
    "transitarei": "transitar",
    "transitareis": "transitar",
    "transitarem": "transitar",
    "transitaremos": "transitar",
    "transitares": "transitar",
    "transitaria": "transitar",
    "transitariam": "transitar",
    "transitarias": "transitar",
    "transitarmo": "transitar",
    "transitarmos": "transitar",
    "transitará": "transitar",
    "transitarás": "transitar",
    "transitarão": "transitar",
    "transitaríamos": "transitar",
    "transitaríeis": "transitar",
    "transitas": "transitar",
    "transitasse": "transitar",
    "transitassem": "transitar",
    "transitasses": "transitar",
    "transitaste": "transitar",
    "transitastes": "transitar",
    "transitava": "transitar",
    "transitavam": "transitar",
    "transitavas": "transitar",
    "transite": "transitar",
    "transitei": "transitar",
    "transiteis": "transitar",
    "transitem": "transitar",
    "transitemo": "transitar",
    "transitemos": "transitar",
    "transites": "transitar",
    "transitiva": "transitivo",
    "transitivada": "transitivar",
    "transitivadas": "transitivar",
    "transitivado": "transitivar",
    "transitivados": "transitivar",
    "transitivai": "transitivar",
    "transitivais": "transitivar",
    "transitivam": "transitivar",
    "transitivamo": "transitivar",
    "transitivamos": "transitivar",
    "transitivando": "transitivar",
    "transitivara": "transitivar",
    "transitivaram": "transitivar",
    "transitivaras": "transitivar",
    "transitivarde": "transitivar",
    "transitivardes": "transitivar",
    "transitivare": "transitivar",
    "transitivarei": "transitivar",
    "transitivareis": "transitivar",
    "transitivarem": "transitivar",
    "transitivaremos": "transitivar",
    "transitivares": "transitivar",
    "transitivaria": "transitivar",
    "transitivariam": "transitivar",
    "transitivarias": "transitivar",
    "transitivarmo": "transitivar",
    "transitivarmos": "transitivar",
    "transitivará": "transitivar",
    "transitivarás": "transitivar",
    "transitivarão": "transitivar",
    "transitivaríamos": "transitivar",
    "transitivaríeis": "transitivar",
    "transitivas": "transitivo",
    "transitivasse": "transitivar",
    "transitivassem": "transitivar",
    "transitivasses": "transitivar",
    "transitivaste": "transitivar",
    "transitivastes": "transitivar",
    "transitivava": "transitivar",
    "transitivavam": "transitivar",
    "transitivavas": "transitivar",
    "transitive": "transitivar",
    "transitivei": "transitivar",
    "transitiveis": "transitivar",
    "transitivem": "transitivar",
    "transitivemo": "transitivar",
    "transitivemos": "transitivar",
    "transitives": "transitivar",
    "transitividades": "transitividade",
    "transitivo": "transitivar",
    "transitivos": "transitivo",
    "transitivou": "transitivar",
    "transitivá": "transitivar",
    "transitivámo": "transitivar",
    "transitivámos": "transitivar",
    "transitiváramo": "transitivar",
    "transitiváramos": "transitivar",
    "transitivárei": "transitivar",
    "transitiváreis": "transitivar",
    "transitivásseis": "transitivar",
    "transitivássemos": "transitivar",
    "transitivávamo": "transitivar",
    "transitivávamos": "transitivar",
    "transitivávei": "transitivar",
    "transitiváveis": "transitivar",
    "transito": "transitar",
    "transitoriedades": "transitoriedade",
    "transitou": "transitar",
    "transitámo": "transitar",
    "transitámos": "transitar",
    "transitáramo": "transitar",
    "transitáramos": "transitar",
    "transitáreis": "transitar",
    "transitária": "transitário",
    "transitárias": "transitário",
    "transitários": "transitário",
    "transitásseis": "transitar",
    "transitássemos": "transitar",
    "transitávamo": "transitar",
    "transitávamos": "transitar",
    "transitáveis": "transitável",
    "transitória": "transitório",
    "transitórias": "transitório",
    "transitórios": "transitório",
    "transiu": "transir",
    "transições": "transição",
    "transjordana": "transjordano",
    "transjordanas": "transjordano",
    "transjordanos": "transjordano",
    "transjordânica": "transjordânico",
    "transjordânicas": "transjordânico",
    "transjordânicos": "transjordânico",
    "transjuga": "transjugar",
    "transjugada": "transjugar",
    "transjugadas": "transjugar",
    "transjugado": "transjugar",
    "transjugados": "transjugar",
    "transjugai": "transjugar",
    "transjugais": "transjugar",
    "transjugam": "transjugar",
    "transjugamo": "transjugar",
    "transjugamos": "transjugar",
    "transjugando": "transjugar",
    "transjugara": "transjugar",
    "transjugaram": "transjugar",
    "transjugaras": "transjugar",
    "transjugarde": "transjugar",
    "transjugardes": "transjugar",
    "transjugare": "transjugar",
    "transjugarei": "transjugar",
    "transjugareis": "transjugar",
    "transjugarem": "transjugar",
    "transjugaremos": "transjugar",
    "transjugares": "transjugar",
    "transjugaria": "transjugar",
    "transjugariam": "transjugar",
    "transjugarias": "transjugar",
    "transjugarmo": "transjugar",
    "transjugarmos": "transjugar",
    "transjugará": "transjugar",
    "transjugarás": "transjugar",
    "transjugarão": "transjugar",
    "transjugaríamos": "transjugar",
    "transjugaríeis": "transjugar",
    "transjugas": "transjugar",
    "transjugasse": "transjugar",
    "transjugassem": "transjugar",
    "transjugasses": "transjugar",
    "transjugaste": "transjugar",
    "transjugastes": "transjugar",
    "transjugava": "transjugar",
    "transjugavam": "transjugar",
    "transjugavas": "transjugar",
    "transjugo": "transjugar",
    "transjugou": "transjugar",
    "transjugue": "transjugar",
    "transjuguei": "transjugar",
    "transjugueis": "transjugar",
    "transjuguem": "transjugar",
    "transjuguemo": "transjugar",
    "transjuguemos": "transjugar",
    "transjugues": "transjugar",
    "transjugá": "transjugar",
    "transjugámo": "transjugar",
    "transjugámos": "transjugar",
    "transjugáramo": "transjugar",
    "transjugáramos": "transjugar",
    "transjugárei": "transjugar",
    "transjugáreis": "transjugar",
    "transjugásseis": "transjugar",
    "transjugássemos": "transjugar",
    "transjugávamo": "transjugar",
    "transjugávamos": "transjugar",
    "transjugávei": "transjugar",
    "transjugáveis": "transjugar",
    "translada": "transladar",
    "transladada": "transladar",
    "transladadas": "transladar",
    "transladado": "transladar",
    "transladados": "transladar",
    "transladai": "transladar",
    "transladais": "transladar",
    "transladam": "transladar",
    "transladamo": "transladar",
    "transladamos": "transladar",
    "transladando": "transladar",
    "transladara": "transladar",
    "transladaram": "transladar",
    "transladaras": "transladar",
    "transladarde": "transladar",
    "transladardes": "transladar",
    "transladare": "transladar",
    "transladarei": "transladar",
    "transladareis": "transladar",
    "transladarem": "transladar",
    "transladaremos": "transladar",
    "transladares": "transladar",
    "transladaria": "transladar",
    "transladariam": "transladar",
    "transladarias": "transladar",
    "transladarmo": "transladar",
    "transladarmos": "transladar",
    "transladará": "transladar",
    "transladarás": "transladar",
    "transladarão": "transladar",
    "transladaríamos": "transladar",
    "transladaríeis": "transladar",
    "transladas": "transladar",
    "transladasse": "transladar",
    "transladassem": "transladar",
    "transladasses": "transladar",
    "transladaste": "transladar",
    "transladastes": "transladar",
    "transladava": "transladar",
    "transladavam": "transladar",
    "transladavas": "transladar",
    "transladações": "transladação",
    "translade": "transladar",
    "transladei": "transladar",
    "transladeis": "transladar",
    "transladem": "transladar",
    "translademo": "transladar",
    "translademos": "transladar",
    "translades": "transladar",
    "translado": "transladar",
    "transladou": "transladar",
    "transladá": "transladar",
    "transladámo": "transladar",
    "transladámos": "transladar",
    "transladáramo": "transladar",
    "transladáramos": "transladar",
    "transladárei": "transladar",
    "transladáreis": "transladar",
    "transladásseis": "transladar",
    "transladássemos": "transladar",
    "transladávamo": "transladar",
    "transladávamos": "transladar",
    "transladávei": "transladar",
    "transladáveis": "transladar",
    "translata": "translato",
    "translatas": "translato",
    "translativa": "translativo",
    "translativas": "translativo",
    "translativos": "translativo",
    "translatores": "translator",
    "translatos": "translato",
    "translatícia": "translatício",
    "translatícias": "translatício",
    "translatícios": "translatício",
    "translações": "translação",
    "translineada": "translinear",
    "translineadas": "translinear",
    "translineado": "translinear",
    "translineados": "translinear",
    "translineai": "translinear",
    "translineais": "translinear",
    "translineamo": "translinear",
    "translineamos": "translinear",
    "translineando": "translinear",
    "translineara": "translinear",
    "translinearam": "translinear",
    "translinearas": "translinear",
    "translinearde": "translinear",
    "translineardes": "translinear",
    "translineare": "translinear",
    "translinearei": "translinear",
    "translineareis": "translinear",
    "translinearem": "translinear",
    "translinearemos": "translinear",
    "translineares": "translinear",
    "translinearia": "translinear",
    "translineariam": "translinear",
    "translinearias": "translinear",
    "translinearmo": "translinear",
    "translinearmos": "translinear",
    "translineará": "translinear",
    "translinearás": "translinear",
    "translinearão": "translinear",
    "translinearíamos": "translinear",
    "translinearíeis": "translinear",
    "translineasse": "translinear",
    "translineassem": "translinear",
    "translineasses": "translinear",
    "translineaste": "translinear",
    "translineastes": "translinear",
    "translineava": "translinear",
    "translineavam": "translinear",
    "translineavas": "translinear",
    "translineações": "translineação",
    "translineei": "translinear",
    "translineeis": "translinear",
    "translineemo": "translinear",
    "translineemos": "translinear",
    "translineia": "translinear",
    "translineiam": "translinear",
    "translineias": "translinear",
    "translineie": "translinear",
    "translineiem": "translinear",
    "translineies": "translinear",
    "translineio": "translinear",
    "translineou": "translinear",
    "translineá": "translinear",
    "translineámo": "translinear",
    "translineámos": "translinear",
    "translineáramo": "translinear",
    "translineáramos": "translinear",
    "translineárei": "translinear",
    "translineáreis": "translinear",
    "translineásseis": "translinear",
    "translineássemos": "translinear",
    "translineávamo": "translinear",
    "translineávamos": "translinear",
    "translineávei": "translinear",
    "translineáveis": "translinear",
    "translitera": "transliterar",
    "transliterada": "transliterar",
    "transliteradas": "transliterar",
    "transliterado": "transliterar",
    "transliterados": "transliterar",
    "transliterai": "transliterar",
    "transliterais": "transliterar",
    "transliteram": "transliterar",
    "transliteramo": "transliterar",
    "transliteramos": "transliterar",
    "transliterando": "transliterar",
    "transliterara": "transliterar",
    "transliteraram": "transliterar",
    "transliteraras": "transliterar",
    "transliterarde": "transliterar",
    "transliterardes": "transliterar",
    "transliterare": "transliterar",
    "transliterarei": "transliterar",
    "transliterareis": "transliterar",
    "transliterarem": "transliterar",
    "transliteraremos": "transliterar",
    "transliterares": "transliterar",
    "transliteraria": "transliterar",
    "transliterariam": "transliterar",
    "transliterarias": "transliterar",
    "transliterarmo": "transliterar",
    "transliterarmos": "transliterar",
    "transliterará": "transliterar",
    "transliterarás": "transliterar",
    "transliterarão": "transliterar",
    "transliteraríamos": "transliterar",
    "transliteraríeis": "transliterar",
    "transliteras": "transliterar",
    "transliterasse": "transliterar",
    "transliterassem": "transliterar",
    "transliterasses": "transliterar",
    "transliteraste": "transliterar",
    "transliterastes": "transliterar",
    "transliterava": "transliterar",
    "transliteravam": "transliterar",
    "transliteravas": "transliterar",
    "transliterações": "transliteração",
    "translitere": "transliterar",
    "transliterei": "transliterar",
    "translitereis": "transliterar",
    "transliterem": "transliterar",
    "transliteremo": "transliterar",
    "transliteremos": "transliterar",
    "transliteres": "transliterar",
    "translitero": "transliterar",
    "transliterou": "transliterar",
    "transliterá": "transliterar",
    "transliterámo": "transliterar",
    "transliterámos": "transliterar",
    "transliteráramo": "transliterar",
    "transliteráramos": "transliterar",
    "transliterárei": "transliterar",
    "transliteráreis": "transliterar",
    "transliterásseis": "transliterar",
    "transliterássemos": "transliterar",
    "transliterávamo": "transliterar",
    "transliterávamos": "transliterar",
    "transliterávei": "transliterar",
    "transliteráveis": "transliterar",
    "translucida": "translucidar",
    "translucidada": "translucidar",
    "translucidadas": "translucidar",
    "translucidado": "translucidar",
    "translucidados": "translucidar",
    "translucidai": "translucidar",
    "translucidais": "translucidar",
    "translucidam": "translucidar",
    "translucidamo": "translucidar",
    "translucidamos": "translucidar",
    "translucidando": "translucidar",
    "translucidara": "translucidar",
    "translucidaram": "translucidar",
    "translucidaras": "translucidar",
    "translucidarde": "translucidar",
    "translucidardes": "translucidar",
    "translucidare": "translucidar",
    "translucidarei": "translucidar",
    "translucidareis": "translucidar",
    "translucidarem": "translucidar",
    "translucidaremos": "translucidar",
    "translucidares": "translucidar",
    "translucidaria": "translucidar",
    "translucidariam": "translucidar",
    "translucidarias": "translucidar",
    "translucidarmo": "translucidar",
    "translucidarmos": "translucidar",
    "translucidará": "translucidar",
    "translucidarás": "translucidar",
    "translucidarão": "translucidar",
    "translucidaríamos": "translucidar",
    "translucidaríeis": "translucidar",
    "translucidas": "translucidar",
    "translucidasse": "translucidar",
    "translucidassem": "translucidar",
    "translucidasses": "translucidar",
    "translucidaste": "translucidar",
    "translucidastes": "translucidar",
    "translucidava": "translucidar",
    "translucidavam": "translucidar",
    "translucidavas": "translucidar",
    "translucide": "translucidar",
    "translucidei": "translucidar",
    "translucideis": "translucidar",
    "translucidem": "translucidar",
    "translucidemo": "translucidar",
    "translucidemos": "translucidar",
    "translucides": "translucidar",
    "translucidezes": "translucidez",
    "translucido": "translucidar",
    "translucidou": "translucidar",
    "translucidá": "translucidar",
    "translucidámo": "translucidar",
    "translucidámos": "translucidar",
    "translucidáramo": "translucidar",
    "translucidáramos": "translucidar",
    "translucidárei": "translucidar",
    "translucidáreis": "translucidar",
    "translucidásseis": "translucidar",
    "translucidássemos": "translucidar",
    "translucidávamo": "translucidar",
    "translucidávamos": "translucidar",
    "translucidávei": "translucidar",
    "translucidáveis": "translucidar",
    "translumbra": "translumbrar",
    "translumbrada": "translumbrar",
    "translumbradas": "translumbrar",
    "translumbrado": "translumbrar",
    "translumbrados": "translumbrar",
    "translumbrai": "translumbrar",
    "translumbrais": "translumbrar",
    "translumbram": "translumbrar",
    "translumbramo": "translumbrar",
    "translumbramos": "translumbrar",
    "translumbrando": "translumbrar",
    "translumbrara": "translumbrar",
    "translumbraram": "translumbrar",
    "translumbraras": "translumbrar",
    "translumbrarde": "translumbrar",
    "translumbrardes": "translumbrar",
    "translumbrare": "translumbrar",
    "translumbrarei": "translumbrar",
    "translumbrareis": "translumbrar",
    "translumbrarem": "translumbrar",
    "translumbraremos": "translumbrar",
    "translumbrares": "translumbrar",
    "translumbraria": "translumbrar",
    "translumbrariam": "translumbrar",
    "translumbrarias": "translumbrar",
    "translumbrarmo": "translumbrar",
    "translumbrarmos": "translumbrar",
    "translumbrará": "translumbrar",
    "translumbrarás": "translumbrar",
    "translumbrarão": "translumbrar",
    "translumbraríamos": "translumbrar",
    "translumbraríeis": "translumbrar",
    "translumbras": "translumbrar",
    "translumbrasse": "translumbrar",
    "translumbrassem": "translumbrar",
    "translumbrasses": "translumbrar",
    "translumbraste": "translumbrar",
    "translumbrastes": "translumbrar",
    "translumbrava": "translumbrar",
    "translumbravam": "translumbrar",
    "translumbravas": "translumbrar",
    "translumbre": "translumbrar",
    "translumbrei": "translumbrar",
    "translumbreis": "translumbrar",
    "translumbrem": "translumbrar",
    "translumbremo": "translumbrar",
    "translumbremos": "translumbrar",
    "translumbres": "translumbrar",
    "translumbro": "translumbrar",
    "translumbrou": "translumbrar",
    "translumbrá": "translumbrar",
    "translumbrámo": "translumbrar",
    "translumbrámos": "translumbrar",
    "translumbráramo": "translumbrar",
    "translumbráramos": "translumbrar",
    "translumbrárei": "translumbrar",
    "translumbráreis": "translumbrar",
    "translumbrásseis": "translumbrar",
    "translumbrássemos": "translumbrar",
    "translumbrávamo": "translumbrar",
    "translumbrávamos": "translumbrar",
    "translumbrávei": "translumbrar",
    "translumbráveis": "translumbrar",
    "transluz": "transluzir",
    "transluza": "transluzir",
    "transluzais": "transluzir",
    "transluzam": "transluzir",
    "transluzamo": "transluzir",
    "transluzamos": "transluzir",
    "transluzas": "transluzir",
    "transluze": "transluzir",
    "transluzem": "transluzir",
    "transluzentes": "transluzente",
    "transluzes": "transluzir",
    "transluzi": "transluzir",
    "transluzia": "transluzir",
    "transluziam": "transluzir",
    "transluzias": "transluzir",
    "transluzida": "transluzir",
    "transluzidas": "transluzir",
    "transluzido": "transluzir",
    "transluzidos": "transluzir",
    "transluzimentos": "transluzimento",
    "transluzimo": "transluzir",
    "transluzimos": "transluzir",
    "transluzindo": "transluzir",
    "transluzira": "transluzir",
    "transluziram": "transluzir",
    "transluziras": "transluzir",
    "transluzirdes": "transluzir",
    "transluzirei": "transluzir",
    "transluzireis": "transluzir",
    "transluzirem": "transluzir",
    "transluziremos": "transluzir",
    "transluzires": "transluzir",
    "transluziria": "transluzir",
    "transluziriam": "transluzir",
    "transluzirias": "transluzir",
    "transluzirmo": "transluzir",
    "transluzirmos": "transluzir",
    "transluzirá": "transluzir",
    "transluzirás": "transluzir",
    "transluzirão": "transluzir",
    "transluziríamos": "transluzir",
    "transluziríeis": "transluzir",
    "transluzis": "transluzir",
    "transluzisse": "transluzir",
    "transluzissem": "transluzir",
    "transluzisses": "transluzir",
    "transluziste": "transluzir",
    "transluzistes": "transluzir",
    "transluziu": "transluzir",
    "transluzo": "transluzir",
    "transluzíamo": "transluzir",
    "transluzíamos": "transluzir",
    "transluzíeis": "transluzir",
    "transluzíramo": "transluzir",
    "transluzíramos": "transluzir",
    "transluzíreis": "transluzir",
    "transluzísseis": "transluzir",
    "transluzíssemos": "transluzir",
    "translúcida": "translúcido",
    "translúcidas": "translúcido",
    "translúcidos": "translúcido",
    "transmalha": "transmalhar",
    "transmalhada": "transmalhar",
    "transmalhadas": "transmalhar",
    "transmalhado": "transmalhar",
    "transmalhados": "transmalhar",
    "transmalhai": "transmalhar",
    "transmalhais": "transmalhar",
    "transmalham": "transmalhar",
    "transmalhamo": "transmalhar",
    "transmalhamos": "transmalhar",
    "transmalhando": "transmalhar",
    "transmalhara": "transmalhar",
    "transmalharam": "transmalhar",
    "transmalharas": "transmalhar",
    "transmalharde": "transmalhar",
    "transmalhardes": "transmalhar",
    "transmalhare": "transmalhar",
    "transmalharei": "transmalhar",
    "transmalhareis": "transmalhar",
    "transmalharem": "transmalhar",
    "transmalharemos": "transmalhar",
    "transmalhares": "transmalhar",
    "transmalharia": "transmalhar",
    "transmalhariam": "transmalhar",
    "transmalharias": "transmalhar",
    "transmalharmo": "transmalhar",
    "transmalharmos": "transmalhar",
    "transmalhará": "transmalhar",
    "transmalharás": "transmalhar",
    "transmalharão": "transmalhar",
    "transmalharíamos": "transmalhar",
    "transmalharíeis": "transmalhar",
    "transmalhas": "transmalhar",
    "transmalhasse": "transmalhar",
    "transmalhassem": "transmalhar",
    "transmalhasses": "transmalhar",
    "transmalhaste": "transmalhar",
    "transmalhastes": "transmalhar",
    "transmalhava": "transmalhar",
    "transmalhavam": "transmalhar",
    "transmalhavas": "transmalhar",
    "transmalhe": "transmalhar",
    "transmalhei": "transmalhar",
    "transmalheis": "transmalhar",
    "transmalhem": "transmalhar",
    "transmalhemo": "transmalhar",
    "transmalhemos": "transmalhar",
    "transmalhes": "transmalhar",
    "transmalho": "transmalhar",
    "transmalhou": "transmalhar",
    "transmalhá": "transmalhar",
    "transmalhámo": "transmalhar",
    "transmalhámos": "transmalhar",
    "transmalháramo": "transmalhar",
    "transmalháramos": "transmalhar",
    "transmalhárei": "transmalhar",
    "transmalháreis": "transmalhar",
    "transmalhásseis": "transmalhar",
    "transmalhássemos": "transmalhar",
    "transmalhávamo": "transmalhar",
    "transmalhávamos": "transmalhar",
    "transmalhávei": "transmalhar",
    "transmalháveis": "transmalhar",
    "transmarina": "transmarino",
    "transmarinas": "transmarino",
    "transmarinos": "transmarino",
    "transmeada": "transmear",
    "transmeadas": "transmear",
    "transmeado": "transmear",
    "transmeados": "transmear",
    "transmeai": "transmear",
    "transmeais": "transmear",
    "transmeamo": "transmear",
    "transmeamos": "transmear",
    "transmeando": "transmear",
    "transmeara": "transmear",
    "transmearam": "transmear",
    "transmearas": "transmear",
    "transmeardes": "transmear",
    "transmearei": "transmear",
    "transmeareis": "transmear",
    "transmearem": "transmear",
    "transmearemos": "transmear",
    "transmeares": "transmear",
    "transmearia": "transmear",
    "transmeariam": "transmear",
    "transmearias": "transmear",
    "transmearmo": "transmear",
    "transmearmos": "transmear",
    "transmeará": "transmear",
    "transmearás": "transmear",
    "transmearão": "transmear",
    "transmearíamos": "transmear",
    "transmearíeis": "transmear",
    "transmeasse": "transmear",
    "transmeassem": "transmear",
    "transmeasses": "transmear",
    "transmeaste": "transmear",
    "transmeastes": "transmear",
    "transmeava": "transmear",
    "transmeavam": "transmear",
    "transmeavas": "transmear",
    "transmediterrânica": "transmediterrânico",
    "transmediterrânicas": "transmediterrânico",
    "transmediterrânicos": "transmediterrânico",
    "transmeei": "transmear",
    "transmeeis": "transmear",
    "transmeemo": "transmear",
    "transmeemos": "transmear",
    "transmeia": "transmear",
    "transmeiam": "transmear",
    "transmeias": "transmear",
    "transmeie": "transmear",
    "transmeiem": "transmear",
    "transmeies": "transmear",
    "transmeio": "transmear",
    "transmeou": "transmear",
    "transmeámo": "transmear",
    "transmeámos": "transmear",
    "transmeáramo": "transmear",
    "transmeáramos": "transmear",
    "transmeáreis": "transmear",
    "transmeásseis": "transmear",
    "transmeássemos": "transmear",
    "transmeávamo": "transmear",
    "transmeávamos": "transmear",
    "transmeáveis": "transmeável",
    "transmigra": "transmigrar",
    "transmigrada": "transmigrar",
    "transmigradas": "transmigrar",
    "transmigrado": "transmigrar",
    "transmigradora": "transmigrador",
    "transmigradoras": "transmigrador",
    "transmigradores": "transmigrador",
    "transmigrados": "transmigrar",
    "transmigrai": "transmigrar",
    "transmigrais": "transmigrar",
    "transmigram": "transmigrar",
    "transmigramo": "transmigrar",
    "transmigramos": "transmigrar",
    "transmigrando": "transmigrar",
    "transmigrantes": "transmigrante",
    "transmigrara": "transmigrar",
    "transmigraram": "transmigrar",
    "transmigraras": "transmigrar",
    "transmigrardes": "transmigrar",
    "transmigrarei": "transmigrar",
    "transmigrareis": "transmigrar",
    "transmigrarem": "transmigrar",
    "transmigraremos": "transmigrar",
    "transmigrares": "transmigrar",
    "transmigraria": "transmigrar",
    "transmigrariam": "transmigrar",
    "transmigrarias": "transmigrar",
    "transmigrarmo": "transmigrar",
    "transmigrarmos": "transmigrar",
    "transmigrará": "transmigrar",
    "transmigrarás": "transmigrar",
    "transmigrarão": "transmigrar",
    "transmigraríamos": "transmigrar",
    "transmigraríeis": "transmigrar",
    "transmigras": "transmigrar",
    "transmigrasse": "transmigrar",
    "transmigrassem": "transmigrar",
    "transmigrasses": "transmigrar",
    "transmigraste": "transmigrar",
    "transmigrastes": "transmigrar",
    "transmigratória": "transmigratório",
    "transmigratórias": "transmigratório",
    "transmigratórios": "transmigratório",
    "transmigrava": "transmigrar",
    "transmigravam": "transmigrar",
    "transmigravas": "transmigrar",
    "transmigrações": "transmigração",
    "transmigre": "transmigrar",
    "transmigrei": "transmigrar",
    "transmigreis": "transmigrar",
    "transmigrem": "transmigrar",
    "transmigremo": "transmigrar",
    "transmigremos": "transmigrar",
    "transmigres": "transmigrar",
    "transmigro": "transmigrar",
    "transmigrou": "transmigrar",
    "transmigrámo": "transmigrar",
    "transmigrámos": "transmigrar",
    "transmigráramo": "transmigrar",
    "transmigráramos": "transmigrar",
    "transmigráreis": "transmigrar",
    "transmigrásseis": "transmigrar",
    "transmigrássemos": "transmigrar",
    "transmigrávamo": "transmigrar",
    "transmigrávamos": "transmigrar",
    "transmigráveis": "transmigrar",
    "transmissibilidades": "transmissibilidade",
    "transmissiva": "transmissivo",
    "transmissivas": "transmissivo",
    "transmissivos": "transmissivo",
    "transmissora": "transmissor",
    "transmissoras": "transmissor",
    "transmissores": "transmissor",
    "transmissíveis": "transmissível",
    "transmissória": "transmissório",
    "transmissórias": "transmissório",
    "transmissórios": "transmissório",
    "transmissões": "transmissão",
    "transmita": "transmitir",
    "transmitais": "transmitir",
    "transmitam": "transmitir",
    "transmitamo": "transmitir",
    "transmitamos": "transmitir",
    "transmitas": "transmitir",
    "transmite": "transmitir",
    "transmitem": "transmitir",
    "transmites": "transmitir",
    "transmiti": "transmitir",
    "transmitia": "transmitir",
    "transmitiam": "transmitir",
    "transmitias": "transmitir",
    "transmitida": "transmitir",
    "transmitidas": "transmitir",
    "transmitido": "transmitir",
    "transmitidos": "transmitir",
    "transmitimo": "transmitir",
    "transmitimos": "transmitir",
    "transmitindo": "transmitir",
    "transmitira": "transmitir",
    "transmitiram": "transmitir",
    "transmitiras": "transmitir",
    "transmitirde": "transmitir",
    "transmitirdes": "transmitir",
    "transmitire": "transmitir",
    "transmitirei": "transmitir",
    "transmitireis": "transmitir",
    "transmitirem": "transmitir",
    "transmitiremos": "transmitir",
    "transmitires": "transmitir",
    "transmitiria": "transmitir",
    "transmitiriam": "transmitir",
    "transmitirias": "transmitir",
    "transmitirmo": "transmitir",
    "transmitirmos": "transmitir",
    "transmitirá": "transmitir",
    "transmitirás": "transmitir",
    "transmitirão": "transmitir",
    "transmitiríamos": "transmitir",
    "transmitiríeis": "transmitir",
    "transmitis": "transmitir",
    "transmitisse": "transmitir",
    "transmitissem": "transmitir",
    "transmitisses": "transmitir",
    "transmitiste": "transmitir",
    "transmitistes": "transmitir",
    "transmitiu": "transmitir",
    "transmito": "transmitir",
    "transmitíamo": "transmitir",
    "transmitíamos": "transmitir",
    "transmitíei": "transmitir",
    "transmitíeis": "transmitir",
    "transmitíramo": "transmitir",
    "transmitíramos": "transmitir",
    "transmitírei": "transmitir",
    "transmitíreis": "transmitir",
    "transmitísseis": "transmitir",
    "transmitíssemos": "transmitir",
    "transmonta": "transmontar",
    "transmontada": "transmontar",
    "transmontadas": "transmontar",
    "transmontado": "transmontar",
    "transmontados": "transmontar",
    "transmontai": "transmontar",
    "transmontais": "transmontar",
    "transmontam": "transmontar",
    "transmontamo": "transmontar",
    "transmontamos": "transmontar",
    "transmontana": "transmontano",
    "transmontanas": "transmontano",
    "transmontando": "transmontar",
    "transmontanhismos": "transmontanhismo",
    "transmontanos": "transmontano",
    "transmontara": "transmontar",
    "transmontaram": "transmontar",
    "transmontaras": "transmontar",
    "transmontarde": "transmontar",
    "transmontardes": "transmontar",
    "transmontare": "transmontar",
    "transmontarei": "transmontar",
    "transmontareis": "transmontar",
    "transmontarem": "transmontar",
    "transmontaremos": "transmontar",
    "transmontares": "transmontar",
    "transmontaria": "transmontar",
    "transmontariam": "transmontar",
    "transmontarias": "transmontar",
    "transmontarmo": "transmontar",
    "transmontarmos": "transmontar",
    "transmontará": "transmontar",
    "transmontarás": "transmontar",
    "transmontarão": "transmontar",
    "transmontaríamos": "transmontar",
    "transmontaríeis": "transmontar",
    "transmontas": "transmontar",
    "transmontasse": "transmontar",
    "transmontassem": "transmontar",
    "transmontasses": "transmontar",
    "transmontaste": "transmontar",
    "transmontastes": "transmontar",
    "transmontava": "transmontar",
    "transmontavam": "transmontar",
    "transmontavas": "transmontar",
    "transmonte": "transmontar",
    "transmontei": "transmontar",
    "transmonteis": "transmontar",
    "transmontem": "transmontar",
    "transmontemo": "transmontar",
    "transmontemos": "transmontar",
    "transmontes": "transmontar",
    "transmonto": "transmontar",
    "transmontou": "transmontar",
    "transmontá": "transmontar",
    "transmontámo": "transmontar",
    "transmontámos": "transmontar",
    "transmontáramo": "transmontar",
    "transmontáramos": "transmontar",
    "transmontárei": "transmontar",
    "transmontáreis": "transmontar",
    "transmontásseis": "transmontar",
    "transmontássemos": "transmontar",
    "transmontávamo": "transmontar",
    "transmontávamos": "transmontar",
    "transmontávei": "transmontar",
    "transmontáveis": "transmontar",
    "transmova": "transmover",
    "transmovais": "transmover",
    "transmovam": "transmover",
    "transmovamo": "transmover",
    "transmovamos": "transmover",
    "transmovas": "transmover",
    "transmove": "transmover",
    "transmovei": "transmover",
    "transmoveis": "transmover",
    "transmovem": "transmover",
    "transmovemo": "transmover",
    "transmovemos": "transmover",
    "transmovendo": "transmover",
    "transmovera": "transmover",
    "transmoveram": "transmover",
    "transmoveras": "transmover",
    "transmoverde": "transmover",
    "transmoverdes": "transmover",
    "transmovere": "transmover",
    "transmoverei": "transmover",
    "transmovereis": "transmover",
    "transmoverem": "transmover",
    "transmoveremos": "transmover",
    "transmoveres": "transmover",
    "transmoveria": "transmover",
    "transmoveriam": "transmover",
    "transmoverias": "transmover",
    "transmovermo": "transmover",
    "transmovermos": "transmover",
    "transmoverá": "transmover",
    "transmoverás": "transmover",
    "transmoverão": "transmover",
    "transmoveríamos": "transmover",
    "transmoveríeis": "transmover",
    "transmoves": "transmover",
    "transmovesse": "transmover",
    "transmovessem": "transmover",
    "transmovesses": "transmover",
    "transmoveste": "transmover",
    "transmovestes": "transmover",
    "transmoveu": "transmover",
    "transmovi": "transmover",
    "transmovia": "transmover",
    "transmoviam": "transmover",
    "transmovias": "transmover",
    "transmovida": "transmover",
    "transmovidas": "transmover",
    "transmovido": "transmover",
    "transmovidos": "transmover",
    "transmovo": "transmover",
    "transmovê": "transmover",
    "transmovêramo": "transmover",
    "transmovêramos": "transmover",
    "transmovêrei": "transmover",
    "transmovêreis": "transmover",
    "transmovêsseis": "transmover",
    "transmovêssemos": "transmover",
    "transmovíamo": "transmover",
    "transmovíamos": "transmover",
    "transmovíei": "transmover",
    "transmovíeis": "transmover",
    "transmuda": "transmudar",
    "transmudada": "transmudar",
    "transmudadas": "transmudar",
    "transmudado": "transmudar",
    "transmudados": "transmudar",
    "transmudai": "transmudar",
    "transmudais": "transmudar",
    "transmudam": "transmudar",
    "transmudamo": "transmudar",
    "transmudamos": "transmudar",
    "transmudando": "transmudar",
    "transmudara": "transmudar",
    "transmudaram": "transmudar",
    "transmudaras": "transmudar",
    "transmudarde": "transmudar",
    "transmudardes": "transmudar",
    "transmudare": "transmudar",
    "transmudarei": "transmudar",
    "transmudareis": "transmudar",
    "transmudarem": "transmudar",
    "transmudaremos": "transmudar",
    "transmudares": "transmudar",
    "transmudaria": "transmudar",
    "transmudariam": "transmudar",
    "transmudarias": "transmudar",
    "transmudarmo": "transmudar",
    "transmudarmos": "transmudar",
    "transmudará": "transmudar",
    "transmudarás": "transmudar",
    "transmudarão": "transmudar",
    "transmudaríamos": "transmudar",
    "transmudaríeis": "transmudar",
    "transmudas": "transmudar",
    "transmudasse": "transmudar",
    "transmudassem": "transmudar",
    "transmudasses": "transmudar",
    "transmudaste": "transmudar",
    "transmudastes": "transmudar",
    "transmudava": "transmudar",
    "transmudavam": "transmudar",
    "transmudavas": "transmudar",
    "transmudações": "transmudação",
    "transmude": "transmudar",
    "transmudei": "transmudar",
    "transmudeis": "transmudar",
    "transmudem": "transmudar",
    "transmudemo": "transmudar",
    "transmudemos": "transmudar",
    "transmudes": "transmudar",
    "transmudo": "transmudar",
    "transmudou": "transmudar",
    "transmudá": "transmudar",
    "transmudámo": "transmudar",
    "transmudámos": "transmudar",
    "transmudáramo": "transmudar",
    "transmudáramos": "transmudar",
    "transmudárei": "transmudar",
    "transmudáreis": "transmudar",
    "transmudásseis": "transmudar",
    "transmudássemos": "transmudar",
    "transmudávamo": "transmudar",
    "transmudávamos": "transmudar",
    "transmudávei": "transmudar",
    "transmudáveis": "transmudável",
    "transmuta": "transmutar",
    "transmutabilidades": "transmutabilidade",
    "transmutada": "transmutar",
    "transmutadas": "transmutar",
    "transmutado": "transmutar",
    "transmutados": "transmutar",
    "transmutai": "transmutar",
    "transmutais": "transmutar",
    "transmutam": "transmutar",
    "transmutamo": "transmutar",
    "transmutamos": "transmutar",
    "transmutando": "transmutar",
    "transmutara": "transmutar",
    "transmutaram": "transmutar",
    "transmutaras": "transmutar",
    "transmutarde": "transmutar",
    "transmutardes": "transmutar",
    "transmutare": "transmutar",
    "transmutarei": "transmutar",
    "transmutareis": "transmutar",
    "transmutarem": "transmutar",
    "transmutaremos": "transmutar",
    "transmutares": "transmutar",
    "transmutaria": "transmutar",
    "transmutariam": "transmutar",
    "transmutarias": "transmutar",
    "transmutarmo": "transmutar",
    "transmutarmos": "transmutar",
    "transmutará": "transmutar",
    "transmutarás": "transmutar",
    "transmutarão": "transmutar",
    "transmutaríamos": "transmutar",
    "transmutaríeis": "transmutar",
    "transmutas": "transmutar",
    "transmutasse": "transmutar",
    "transmutassem": "transmutar",
    "transmutasses": "transmutar",
    "transmutaste": "transmutar",
    "transmutastes": "transmutar",
    "transmutativa": "transmutativo",
    "transmutativas": "transmutativo",
    "transmutativos": "transmutativo",
    "transmutava": "transmutar",
    "transmutavam": "transmutar",
    "transmutavas": "transmutar",
    "transmutações": "transmutação",
    "transmute": "transmutar",
    "transmutei": "transmutar",
    "transmuteis": "transmutar",
    "transmutem": "transmutar",
    "transmutemo": "transmutar",
    "transmutemos": "transmutar",
    "transmutes": "transmutar",
    "transmuto": "transmutar",
    "transmutou": "transmutar",
    "transmutá": "transmutar",
    "transmutámo": "transmutar",
    "transmutámos": "transmutar",
    "transmutáramo": "transmutar",
    "transmutáramos": "transmutar",
    "transmutárei": "transmutar",
    "transmutáreis": "transmutar",
    "transmutásseis": "transmutar",
    "transmutássemos": "transmutar",
    "transmutávamo": "transmutar",
    "transmutávamos": "transmutar",
    "transmutávei": "transmutar",
    "transmutáveis": "transmutável",
    "transnacionais": "transnacional",
    "transnada": "transnadar",
    "transnadada": "transnadar",
    "transnadadas": "transnadar",
    "transnadado": "transnadar",
    "transnadados": "transnadar",
    "transnadai": "transnadar",
    "transnadais": "transnadar",
    "transnadam": "transnadar",
    "transnadamo": "transnadar",
    "transnadamos": "transnadar",
    "transnadando": "transnadar",
    "transnadara": "transnadar",
    "transnadaram": "transnadar",
    "transnadaras": "transnadar",
    "transnadarde": "transnadar",
    "transnadardes": "transnadar",
    "transnadare": "transnadar",
    "transnadarei": "transnadar",
    "transnadareis": "transnadar",
    "transnadarem": "transnadar",
    "transnadaremos": "transnadar",
    "transnadares": "transnadar",
    "transnadaria": "transnadar",
    "transnadariam": "transnadar",
    "transnadarias": "transnadar",
    "transnadarmo": "transnadar",
    "transnadarmos": "transnadar",
    "transnadará": "transnadar",
    "transnadarás": "transnadar",
    "transnadarão": "transnadar",
    "transnadaríamos": "transnadar",
    "transnadaríeis": "transnadar",
    "transnadas": "transnadar",
    "transnadasse": "transnadar",
    "transnadassem": "transnadar",
    "transnadasses": "transnadar",
    "transnadaste": "transnadar",
    "transnadastes": "transnadar",
    "transnadava": "transnadar",
    "transnadavam": "transnadar",
    "transnadavas": "transnadar",
    "transnade": "transnadar",
    "transnadei": "transnadar",
    "transnadeis": "transnadar",
    "transnadem": "transnadar",
    "transnademo": "transnadar",
    "transnademos": "transnadar",
    "transnades": "transnadar",
    "transnado": "transnadar",
    "transnadou": "transnadar",
    "transnadá": "transnadar",
    "transnadámo": "transnadar",
    "transnadámos": "transnadar",
    "transnadáramo": "transnadar",
    "transnadáramos": "transnadar",
    "transnadárei": "transnadar",
    "transnadáreis": "transnadar",
    "transnadásseis": "transnadar",
    "transnadássemos": "transnadar",
    "transnadávamo": "transnadar",
    "transnadávamos": "transnadar",
    "transnadávei": "transnadar",
    "transnadáveis": "transnadar",
    "transnavega": "transnavegar",
    "transnavegada": "transnavegar",
    "transnavegadas": "transnavegar",
    "transnavegado": "transnavegar",
    "transnavegados": "transnavegar",
    "transnavegai": "transnavegar",
    "transnavegais": "transnavegar",
    "transnavegam": "transnavegar",
    "transnavegamo": "transnavegar",
    "transnavegamos": "transnavegar",
    "transnavegando": "transnavegar",
    "transnavegara": "transnavegar",
    "transnavegaram": "transnavegar",
    "transnavegaras": "transnavegar",
    "transnavegardes": "transnavegar",
    "transnavegarei": "transnavegar",
    "transnavegareis": "transnavegar",
    "transnavegarem": "transnavegar",
    "transnavegaremos": "transnavegar",
    "transnavegares": "transnavegar",
    "transnavegaria": "transnavegar",
    "transnavegariam": "transnavegar",
    "transnavegarias": "transnavegar",
    "transnavegarmo": "transnavegar",
    "transnavegarmos": "transnavegar",
    "transnavegará": "transnavegar",
    "transnavegarás": "transnavegar",
    "transnavegarão": "transnavegar",
    "transnavegaríamos": "transnavegar",
    "transnavegaríeis": "transnavegar",
    "transnavegas": "transnavegar",
    "transnavegasse": "transnavegar",
    "transnavegassem": "transnavegar",
    "transnavegasses": "transnavegar",
    "transnavegaste": "transnavegar",
    "transnavegastes": "transnavegar",
    "transnavegava": "transnavegar",
    "transnavegavam": "transnavegar",
    "transnavegavas": "transnavegar",
    "transnavego": "transnavegar",
    "transnavegou": "transnavegar",
    "transnavegue": "transnavegar",
    "transnaveguei": "transnavegar",
    "transnavegueis": "transnavegar",
    "transnaveguem": "transnavegar",
    "transnaveguemo": "transnavegar",
    "transnaveguemos": "transnavegar",
    "transnavegues": "transnavegar",
    "transnavegámo": "transnavegar",
    "transnavegámos": "transnavegar",
    "transnavegáramo": "transnavegar",
    "transnavegáramos": "transnavegar",
    "transnavegáreis": "transnavegar",
    "transnavegásseis": "transnavegar",
    "transnavegássemos": "transnavegar",
    "transnavegávamo": "transnavegar",
    "transnavegávamos": "transnavegar",
    "transnavegáveis": "transnavegar",
    "transnomina": "transnominar",
    "transnominada": "transnominar",
    "transnominadas": "transnominar",
    "transnominado": "transnominar",
    "transnominados": "transnominar",
    "transnominai": "transnominar",
    "transnominais": "transnominar",
    "transnominam": "transnominar",
    "transnominamo": "transnominar",
    "transnominamos": "transnominar",
    "transnominando": "transnominar",
    "transnominara": "transnominar",
    "transnominaram": "transnominar",
    "transnominaras": "transnominar",
    "transnominardes": "transnominar",
    "transnominarei": "transnominar",
    "transnominareis": "transnominar",
    "transnominarem": "transnominar",
    "transnominaremos": "transnominar",
    "transnominares": "transnominar",
    "transnominaria": "transnominar",
    "transnominariam": "transnominar",
    "transnominarias": "transnominar",
    "transnominarmo": "transnominar",
    "transnominarmos": "transnominar",
    "transnominará": "transnominar",
    "transnominarás": "transnominar",
    "transnominarão": "transnominar",
    "transnominaríamos": "transnominar",
    "transnominaríeis": "transnominar",
    "transnominas": "transnominar",
    "transnominasse": "transnominar",
    "transnominassem": "transnominar",
    "transnominasses": "transnominar",
    "transnominaste": "transnominar",
    "transnominastes": "transnominar",
    "transnominava": "transnominar",
    "transnominavam": "transnominar",
    "transnominavas": "transnominar",
    "transnominações": "transnominação",
    "transnomine": "transnominar",
    "transnominei": "transnominar",
    "transnomineis": "transnominar",
    "transnominem": "transnominar",
    "transnominemo": "transnominar",
    "transnominemos": "transnominar",
    "transnomines": "transnominar",
    "transnomino": "transnominar",
    "transnominou": "transnominar",
    "transnominámo": "transnominar",
    "transnominámos": "transnominar",
    "transnomináramo": "transnominar",
    "transnomináramos": "transnominar",
    "transnomináreis": "transnominar",
    "transnominásseis": "transnominar",
    "transnominássemos": "transnominar",
    "transnominávamo": "transnominar",
    "transnominávamos": "transnominar",
    "transnomináveis": "transnominar",
    "transnúpcias": "transnúpcia",
    "transo": "transir",
    "transobjectiva": "transobjectivo",
    "transobjectivas": "transobjectivo",
    "transobjectivos": "transobjectivo",
    "transoceânica": "transoceânico",
    "transoceânicas": "transoceânico",
    "transoceânicos": "transoceânico",
    "transome": "transumir",
    "transomem": "transumir",
    "transomes": "transumir",
    "transordinária": "transordinário",
    "transordinárias": "transordinário",
    "transordinários": "transordinário",
    "transpadana": "transpadano",
    "transpadanas": "transpadano",
    "transpadanos": "transpadano",
    "transparece": "transparecer",
    "transparecei": "transparecer",
    "transpareceis": "transparecer",
    "transparecem": "transparecer",
    "transparecemo": "transparecer",
    "transparecemos": "transparecer",
    "transparecendo": "transparecer",
    "transparecera": "transparecer",
    "transpareceram": "transparecer",
    "transpareceras": "transparecer",
    "transparecerde": "transparecer",
    "transparecerdes": "transparecer",
    "transparecere": "transparecer",
    "transparecerei": "transparecer",
    "transparecereis": "transparecer",
    "transparecerem": "transparecer",
    "transpareceremos": "transparecer",
    "transpareceres": "transparecer",
    "transpareceria": "transparecer",
    "transpareceriam": "transparecer",
    "transparecerias": "transparecer",
    "transparecermo": "transparecer",
    "transparecermos": "transparecer",
    "transparecerá": "transparecer",
    "transparecerás": "transparecer",
    "transparecerão": "transparecer",
    "transpareceríamos": "transparecer",
    "transpareceríeis": "transparecer",
    "transpareces": "transparecer",
    "transparecesse": "transparecer",
    "transparecessem": "transparecer",
    "transparecesses": "transparecer",
    "transpareceste": "transparecer",
    "transparecestes": "transparecer",
    "transpareceu": "transparecer",
    "transpareci": "transparecer",
    "transparecia": "transparecer",
    "transpareciam": "transparecer",
    "transparecias": "transparecer",
    "transparecida": "transparecer",
    "transparecidas": "transparecer",
    "transparecido": "transparecer",
    "transparecidos": "transparecer",
    "transparecê": "transparecer",
    "transparecêramo": "transparecer",
    "transparecêramos": "transparecer",
    "transparecêrei": "transparecer",
    "transparecêreis": "transparecer",
    "transparecêsseis": "transparecer",
    "transparecêssemos": "transparecer",
    "transparecíamo": "transparecer",
    "transparecíamos": "transparecer",
    "transparecíei": "transparecer",
    "transparecíeis": "transparecer",
    "transparenta": "transparentar",
    "transparentada": "transparentar",
    "transparentadas": "transparentar",
    "transparentado": "transparentar",
    "transparentados": "transparentar",
    "transparentai": "transparentar",
    "transparentais": "transparentar",
    "transparentam": "transparentar",
    "transparentamo": "transparentar",
    "transparentamos": "transparentar",
    "transparentando": "transparentar",
    "transparentara": "transparentar",
    "transparentaram": "transparentar",
    "transparentaras": "transparentar",
    "transparentarde": "transparentar",
    "transparentardes": "transparentar",
    "transparentare": "transparentar",
    "transparentarei": "transparentar",
    "transparentareis": "transparentar",
    "transparentarem": "transparentar",
    "transparentaremos": "transparentar",
    "transparentares": "transparentar",
    "transparentaria": "transparentar",
    "transparentariam": "transparentar",
    "transparentarias": "transparentar",
    "transparentarmo": "transparentar",
    "transparentarmos": "transparentar",
    "transparentará": "transparentar",
    "transparentarás": "transparentar",
    "transparentarão": "transparentar",
    "transparentaríamos": "transparentar",
    "transparentaríeis": "transparentar",
    "transparentas": "transparentar",
    "transparentasse": "transparentar",
    "transparentassem": "transparentar",
    "transparentasses": "transparentar",
    "transparentaste": "transparentar",
    "transparentastes": "transparentar",
    "transparentava": "transparentar",
    "transparentavam": "transparentar",
    "transparentavas": "transparentar",
    "transparente": "transparentar",
    "transparentei": "transparentar",
    "transparenteis": "transparentar",
    "transparentem": "transparentar",
    "transparentemo": "transparentar",
    "transparentemos": "transparentar",
    "transparentes": "transparente",
    "transparento": "transparentar",
    "transparentou": "transparentar",
    "transparentá": "transparentar",
    "transparentámo": "transparentar",
    "transparentámos": "transparentar",
    "transparentáramo": "transparentar",
    "transparentáramos": "transparentar",
    "transparentárei": "transparentar",
    "transparentáreis": "transparentar",
    "transparentásseis": "transparentar",
    "transparentássemos": "transparentar",
    "transparentávamo": "transparentar",
    "transparentávamos": "transparentar",
    "transparentávei": "transparentar",
    "transparentáveis": "transparentar",
    "transpareça": "transparecer",
    "transpareçais": "transparecer",
    "transpareçam": "transparecer",
    "transpareçamo": "transparecer",
    "transpareçamos": "transparecer",
    "transpareças": "transparecer",
    "transpareço": "transparecer",
    "transparências": "transparência",
    "transpassa": "transpassar",
    "transpassada": "transpassar",
    "transpassadas": "transpassar",
    "transpassado": "transpassar",
    "transpassados": "transpassar",
    "transpassai": "transpassar",
    "transpassais": "transpassar",
    "transpassam": "transpassar",
    "transpassamentos": "transpassamento",
    "transpassamo": "transpassar",
    "transpassamos": "transpassar",
    "transpassando": "transpassar",
    "transpassara": "transpassar",
    "transpassaram": "transpassar",
    "transpassaras": "transpassar",
    "transpassarde": "transpassar",
    "transpassardes": "transpassar",
    "transpassare": "transpassar",
    "transpassarei": "transpassar",
    "transpassareis": "transpassar",
    "transpassarem": "transpassar",
    "transpassaremos": "transpassar",
    "transpassares": "transpassar",
    "transpassaria": "transpassar",
    "transpassariam": "transpassar",
    "transpassarias": "transpassar",
    "transpassarmo": "transpassar",
    "transpassarmos": "transpassar",
    "transpassará": "transpassar",
    "transpassarás": "transpassar",
    "transpassarão": "transpassar",
    "transpassaríamos": "transpassar",
    "transpassaríeis": "transpassar",
    "transpassas": "transpassar",
    "transpassasse": "transpassar",
    "transpassassem": "transpassar",
    "transpassasses": "transpassar",
    "transpassaste": "transpassar",
    "transpassastes": "transpassar",
    "transpassava": "transpassar",
    "transpassavam": "transpassar",
    "transpassavas": "transpassar",
    "transpassações": "transpassação",
    "transpasse": "transpassar",
    "transpassei": "transpassar",
    "transpasseis": "transpassar",
    "transpassem": "transpassar",
    "transpassemo": "transpassar",
    "transpassemos": "transpassar",
    "transpasses": "transpassar",
    "transpasso": "transpassar",
    "transpassou": "transpassar",
    "transpassá": "transpassar",
    "transpassámo": "transpassar",
    "transpassámos": "transpassar",
    "transpassáramo": "transpassar",
    "transpassáramos": "transpassar",
    "transpassárei": "transpassar",
    "transpassáreis": "transpassar",
    "transpassásseis": "transpassar",
    "transpassássemos": "transpassar",
    "transpassávamo": "transpassar",
    "transpassávamos": "transpassar",
    "transpassávei": "transpassar",
    "transpassáveis": "transpassar",
    "transpira": "transpirar",
    "transpirada": "transpirar",
    "transpiradas": "transpirar",
    "transpiradeiros": "transpiradeiro",
    "transpirado": "transpirar",
    "transpirados": "transpirar",
    "transpirai": "transpirar",
    "transpirais": "transpirar",
    "transpiram": "transpirar",
    "transpiramo": "transpirar",
    "transpiramos": "transpirar",
    "transpirando": "transpirar",
    "transpirara": "transpirar",
    "transpiraram": "transpirar",
    "transpiraras": "transpirar",
    "transpirardes": "transpirar",
    "transpirarei": "transpirar",
    "transpirareis": "transpirar",
    "transpirarem": "transpirar",
    "transpiraremos": "transpirar",
    "transpirares": "transpirar",
    "transpiraria": "transpirar",
    "transpirariam": "transpirar",
    "transpirarias": "transpirar",
    "transpirarmo": "transpirar",
    "transpirarmos": "transpirar",
    "transpirará": "transpirar",
    "transpirarás": "transpirar",
    "transpirarão": "transpirar",
    "transpiraríamos": "transpirar",
    "transpiraríeis": "transpirar",
    "transpiras": "transpirar",
    "transpirasse": "transpirar",
    "transpirassem": "transpirar",
    "transpirasses": "transpirar",
    "transpiraste": "transpirar",
    "transpirastes": "transpirar",
    "transpiratória": "transpiratório",
    "transpiratórias": "transpiratório",
    "transpiratórios": "transpiratório",
    "transpirava": "transpirar",
    "transpiravam": "transpirar",
    "transpiravas": "transpirar",
    "transpirações": "transpiração",
    "transpire": "transpirar",
    "transpirei": "transpirar",
    "transpireis": "transpirar",
    "transpirem": "transpirar",
    "transpiremo": "transpirar",
    "transpiremos": "transpirar",
    "transpires": "transpirar",
    "transpiro": "transpirar",
    "transpirou": "transpirar",
    "transpirámo": "transpirar",
    "transpirámos": "transpirar",
    "transpiráramo": "transpirar",
    "transpiráramos": "transpirar",
    "transpiráreis": "transpirar",
    "transpirásseis": "transpirar",
    "transpirássemos": "transpirar",
    "transpirávamo": "transpirar",
    "transpirávamos": "transpirar",
    "transpiráveis": "transpirável",
    "transplanta": "transplantar",
    "transplantada": "transplantar",
    "transplantadas": "transplantar",
    "transplantado": "transplantar",
    "transplantadora": "transplantador",
    "transplantadoras": "transplantador",
    "transplantadores": "transplantador",
    "transplantados": "transplantar",
    "transplantai": "transplantar",
    "transplantais": "transplantar",
    "transplantam": "transplantar",
    "transplantamo": "transplantar",
    "transplantamos": "transplantar",
    "transplantando": "transplantar",
    "transplantara": "transplantar",
    "transplantaram": "transplantar",
    "transplantaras": "transplantar",
    "transplantarde": "transplantar",
    "transplantardes": "transplantar",
    "transplantare": "transplantar",
    "transplantarei": "transplantar",
    "transplantareis": "transplantar",
    "transplantarem": "transplantar",
    "transplantaremos": "transplantar",
    "transplantares": "transplantar",
    "transplantaria": "transplantar",
    "transplantariam": "transplantar",
    "transplantarias": "transplantar",
    "transplantarmo": "transplantar",
    "transplantarmos": "transplantar",
    "transplantará": "transplantar",
    "transplantarás": "transplantar",
    "transplantarão": "transplantar",
    "transplantaríamos": "transplantar",
    "transplantaríeis": "transplantar",
    "transplantas": "transplantar",
    "transplantasse": "transplantar",
    "transplantassem": "transplantar",
    "transplantasses": "transplantar",
    "transplantaste": "transplantar",
    "transplantastes": "transplantar",
    "transplantatória": "transplantatório",
    "transplantatórias": "transplantatório",
    "transplantatórios": "transplantatório",
    "transplantava": "transplantar",
    "transplantavam": "transplantar",
    "transplantavas": "transplantar",
    "transplantações": "transplantação",
    "transplante": "transplantar",
    "transplantei": "transplantar",
    "transplanteis": "transplantar",
    "transplantem": "transplantar",
    "transplantemo": "transplantar",
    "transplantemos": "transplantar",
    "transplantes": "transplantar",
    "transplanto": "transplantar",
    "transplantou": "transplantar",
    "transplantá": "transplantar",
    "transplantámo": "transplantar",
    "transplantámos": "transplantar",
    "transplantáramo": "transplantar",
    "transplantáramos": "transplantar",
    "transplantárei": "transplantar",
    "transplantáreis": "transplantar",
    "transplantásseis": "transplantar",
    "transplantássemos": "transplantar",
    "transplantávamo": "transplantar",
    "transplantávamos": "transplantar",
    "transplantávei": "transplantar",
    "transplantáveis": "transplantável",
    "transpomo": "transpor",
    "transpomos": "transpor",
    "transponde": "transpor",
    "transpondes": "transpor",
    "transpondo": "transpor",
    "transponha": "transpor",
    "transponhais": "transpor",
    "transponham": "transpor",
    "transponhamo": "transpor",
    "transponhamos": "transpor",
    "transponhas": "transpor",
    "transponho": "transpor",
    "transponíveis": "transponível",
    "transporde": "transpor",
    "transpordes": "transpor",
    "transpore": "transpor",
    "transporei": "transpor",
    "transporeis": "transpor",
    "transporem": "transpor",
    "transporemos": "transpor",
    "transpores": "transpor",
    "transporia": "transpor",
    "transporiam": "transpor",
    "transporias": "transpor",
    "transpormo": "transpor",
    "transpormos": "transpor",
    "transporta": "transportar",
    "transportada": "transportar",
    "transportadas": "transportar",
    "transportado": "transportar",
    "transportadora": "transportador",
    "transportadoras": "transportador",
    "transportadores": "transportador",
    "transportados": "transportar",
    "transportai": "transportar",
    "transportais": "transportar",
    "transportam": "transportar",
    "transportamentos": "transportamento",
    "transportamo": "transportar",
    "transportamos": "transportar",
    "transportando": "transportar",
    "transportara": "transportar",
    "transportaram": "transportar",
    "transportaras": "transportar",
    "transportarde": "transportar",
    "transportardes": "transportar",
    "transportare": "transportar",
    "transportarei": "transportar",
    "transportareis": "transportar",
    "transportarem": "transportar",
    "transportaremos": "transportar",
    "transportares": "transportar",
    "transportaria": "transportar",
    "transportariam": "transportar",
    "transportarias": "transportar",
    "transportarmo": "transportar",
    "transportarmos": "transportar",
    "transportará": "transportar",
    "transportarás": "transportar",
    "transportarão": "transportar",
    "transportaríamos": "transportar",
    "transportaríeis": "transportar",
    "transportas": "transportar",
    "transportasse": "transportar",
    "transportassem": "transportar",
    "transportasses": "transportar",
    "transportaste": "transportar",
    "transportastes": "transportar",
    "transportava": "transportar",
    "transportavam": "transportar",
    "transportavas": "transportar",
    "transportações": "transportação",
    "transporte": "transportar",
    "transportei": "transportar",
    "transporteis": "transportar",
    "transportem": "transportar",
    "transportemo": "transportar",
    "transportemos": "transportar",
    "transportes": "transporte",
    "transporto": "transportar",
    "transportou": "transportar",
    "transportá": "transportar",
    "transportámo": "transportar",
    "transportámos": "transportar",
    "transportáramo": "transportar",
    "transportáramos": "transportar",
    "transportárei": "transportar",
    "transportáreis": "transportar",
    "transportásseis": "transportar",
    "transportássemos": "transportar",
    "transportávamo": "transportar",
    "transportávamos": "transportar",
    "transportávei": "transportar",
    "transportáveis": "transportável",
    "transporá": "transpor",
    "transporás": "transpor",
    "transporão": "transpor",
    "transporíamos": "transpor",
    "transporíeis": "transpor",
    "transpositiva": "transpositivo",
    "transpositivas": "transpositivo",
    "transpositivos": "transpositivo",
    "transpositora": "transpositor",
    "transpositoras": "transpositor",
    "transpositores": "transpositor",
    "transposições": "transposição",
    "transposta": "transposto",
    "transpostas": "transposto",
    "transposto": "transpor",
    "transpostos": "transposto",
    "transpunha": "transpor",
    "transpunham": "transpor",
    "transpunhas": "transpor",
    "transpus": "transpor",
    "transpusemo": "transpor",
    "transpusemos": "transpor",
    "transpuser": "transpor",
    "transpusera": "transpor",
    "transpuseram": "transpor",
    "transpuseras": "transpor",
    "transpuserdes": "transpor",
    "transpuserem": "transpor",
    "transpuseres": "transpor",
    "transpusermos": "transpor",
    "transpusesse": "transpor",
    "transpusessem": "transpor",
    "transpusesses": "transpor",
    "transpuseste": "transpor",
    "transpusestes": "transpor",
    "transpuséramo": "transpor",
    "transpuséramos": "transpor",
    "transpusérei": "transpor",
    "transpuséreis": "transpor",
    "transpusésseis": "transpor",
    "transpuséssemos": "transpor",
    "transpô": "transpor",
    "transpôs": "transpor",
    "transpõe": "transpor",
    "transpõem": "transpor",
    "transpões": "transpor",
    "transpúnhamo": "transpor",
    "transpúnhamos": "transpor",
    "transpúnhei": "transpor",
    "transpúnheis": "transpor",
    "transrenana": "transrenano",
    "transrenanas": "transrenano",
    "transrenanos": "transrenano",
    "transsexuais": "transsexual",
    "transsexualismos": "transsexualismo",
    "transtagana": "transtagano",
    "transtaganas": "transtagano",
    "transtaganos": "transtagano",
    "transtiberina": "transtiberino",
    "transtiberinas": "transtiberino",
    "transtiberinos": "transtiberino",
    "transtoca": "transtocar",
    "transtocada": "transtocar",
    "transtocadas": "transtocar",
    "transtocado": "transtocar",
    "transtocados": "transtocar",
    "transtocai": "transtocar",
    "transtocais": "transtocar",
    "transtocam": "transtocar",
    "transtocamo": "transtocar",
    "transtocamos": "transtocar",
    "transtocando": "transtocar",
    "transtocara": "transtocar",
    "transtocaram": "transtocar",
    "transtocaras": "transtocar",
    "transtocarde": "transtocar",
    "transtocardes": "transtocar",
    "transtocare": "transtocar",
    "transtocarei": "transtocar",
    "transtocareis": "transtocar",
    "transtocarem": "transtocar",
    "transtocaremos": "transtocar",
    "transtocares": "transtocar",
    "transtocaria": "transtocar",
    "transtocariam": "transtocar",
    "transtocarias": "transtocar",
    "transtocarmo": "transtocar",
    "transtocarmos": "transtocar",
    "transtocará": "transtocar",
    "transtocarás": "transtocar",
    "transtocarão": "transtocar",
    "transtocaríamos": "transtocar",
    "transtocaríeis": "transtocar",
    "transtocas": "transtocar",
    "transtocasse": "transtocar",
    "transtocassem": "transtocar",
    "transtocasses": "transtocar",
    "transtocaste": "transtocar",
    "transtocastes": "transtocar",
    "transtocava": "transtocar",
    "transtocavam": "transtocar",
    "transtocavas": "transtocar",
    "transtoco": "transtocar",
    "transtocou": "transtocar",
    "transtocá": "transtocar",
    "transtocámo": "transtocar",
    "transtocámos": "transtocar",
    "transtocáramo": "transtocar",
    "transtocáramos": "transtocar",
    "transtocárei": "transtocar",
    "transtocáreis": "transtocar",
    "transtocásseis": "transtocar",
    "transtocássemos": "transtocar",
    "transtocávamo": "transtocar",
    "transtocávamos": "transtocar",
    "transtocávei": "transtocar",
    "transtocáveis": "transtocar",
    "transtoque": "transtocar",
    "transtoquei": "transtocar",
    "transtoqueis": "transtocar",
    "transtoquem": "transtocar",
    "transtoquemo": "transtocar",
    "transtoquemos": "transtocar",
    "transtoques": "transtocar",
    "transtorna": "transtornar",
    "transtornada": "transtornar",
    "transtornadas": "transtornar",
    "transtornado": "transtornar",
    "transtornadora": "transtornador",
    "transtornadoras": "transtornador",
    "transtornadores": "transtornador",
    "transtornados": "transtornar",
    "transtornai": "transtornar",
    "transtornais": "transtornar",
    "transtornam": "transtornar",
    "transtornamo": "transtornar",
    "transtornamos": "transtornar",
    "transtornando": "transtornar",
    "transtornara": "transtornar",
    "transtornaram": "transtornar",
    "transtornaras": "transtornar",
    "transtornarde": "transtornar",
    "transtornardes": "transtornar",
    "transtornare": "transtornar",
    "transtornarei": "transtornar",
    "transtornareis": "transtornar",
    "transtornarem": "transtornar",
    "transtornaremos": "transtornar",
    "transtornares": "transtornar",
    "transtornaria": "transtornar",
    "transtornariam": "transtornar",
    "transtornarias": "transtornar",
    "transtornarmo": "transtornar",
    "transtornarmos": "transtornar",
    "transtornará": "transtornar",
    "transtornarás": "transtornar",
    "transtornarão": "transtornar",
    "transtornaríamos": "transtornar",
    "transtornaríeis": "transtornar",
    "transtornas": "transtornar",
    "transtornasse": "transtornar",
    "transtornassem": "transtornar",
    "transtornasses": "transtornar",
    "transtornaste": "transtornar",
    "transtornastes": "transtornar",
    "transtornava": "transtornar",
    "transtornavam": "transtornar",
    "transtornavas": "transtornar",
    "transtorne": "transtornar",
    "transtornei": "transtornar",
    "transtorneis": "transtornar",
    "transtornem": "transtornar",
    "transtornemo": "transtornar",
    "transtornemos": "transtornar",
    "transtornes": "transtornar",
    "transtorno": "transtornar",
    "transtornos": "transtorno",
    "transtornou": "transtornar",
    "transtorná": "transtornar",
    "transtornámo": "transtornar",
    "transtornámos": "transtornar",
    "transtornáramo": "transtornar",
    "transtornáramos": "transtornar",
    "transtornárei": "transtornar",
    "transtornáreis": "transtornar",
    "transtornásseis": "transtornar",
    "transtornássemos": "transtornar",
    "transtornávamo": "transtornar",
    "transtornávamos": "transtornar",
    "transtornávei": "transtornar",
    "transtornáveis": "transtornável",
    "transtravada": "transtravado",
    "transtravadas": "transtravado",
    "transtravados": "transtravado",
    "transubstancia": "transubstanciar",
    "transubstanciada": "transubstanciar",
    "transubstanciadas": "transubstanciar",
    "transubstanciado": "transubstanciar",
    "transubstanciados": "transubstanciar",
    "transubstanciai": "transubstanciar",
    "transubstanciais": "transubstanciar",
    "transubstanciam": "transubstanciar",
    "transubstanciamo": "transubstanciar",
    "transubstanciamos": "transubstanciar",
    "transubstanciando": "transubstanciar",
    "transubstanciara": "transubstanciar",
    "transubstanciaram": "transubstanciar",
    "transubstanciaras": "transubstanciar",
    "transubstanciarde": "transubstanciar",
    "transubstanciardes": "transubstanciar",
    "transubstanciare": "transubstanciar",
    "transubstanciarei": "transubstanciar",
    "transubstanciareis": "transubstanciar",
    "transubstanciarem": "transubstanciar",
    "transubstanciaremos": "transubstanciar",
    "transubstanciares": "transubstanciar",
    "transubstanciaria": "transubstanciar",
    "transubstanciariam": "transubstanciar",
    "transubstanciarias": "transubstanciar",
    "transubstanciarmo": "transubstanciar",
    "transubstanciarmos": "transubstanciar",
    "transubstanciará": "transubstanciar",
    "transubstanciarás": "transubstanciar",
    "transubstanciarão": "transubstanciar",
    "transubstanciaríamos": "transubstanciar",
    "transubstanciaríeis": "transubstanciar",
    "transubstancias": "transubstanciar",
    "transubstanciasse": "transubstanciar",
    "transubstanciassem": "transubstanciar",
    "transubstanciasses": "transubstanciar",
    "transubstanciaste": "transubstanciar",
    "transubstanciastes": "transubstanciar",
    "transubstanciava": "transubstanciar",
    "transubstanciavam": "transubstanciar",
    "transubstanciavas": "transubstanciar",
    "transubstanciações": "transubstanciação",
    "transubstancie": "transubstanciar",
    "transubstanciei": "transubstanciar",
    "transubstancieis": "transubstanciar",
    "transubstanciem": "transubstanciar",
    "transubstanciemo": "transubstanciar",
    "transubstanciemos": "transubstanciar",
    "transubstancies": "transubstanciar",
    "transubstancio": "transubstanciar",
    "transubstanciou": "transubstanciar",
    "transubstanciá": "transubstanciar",
    "transubstanciámo": "transubstanciar",
    "transubstanciámos": "transubstanciar",
    "transubstanciáramo": "transubstanciar",
    "transubstanciáramos": "transubstanciar",
    "transubstanciárei": "transubstanciar",
    "transubstanciáreis": "transubstanciar",
    "transubstanciásseis": "transubstanciar",
    "transubstanciássemos": "transubstanciar",
    "transubstanciávamo": "transubstanciar",
    "transubstanciávamos": "transubstanciar",
    "transubstanciávei": "transubstanciar",
    "transubstanciáveis": "transubstanciar",
    "transuda": "transudar",
    "transudada": "transudar",
    "transudadas": "transudar",
    "transudado": "transudar",
    "transudados": "transudar",
    "transudai": "transudar",
    "transudais": "transudar",
    "transudam": "transudar",
    "transudamo": "transudar",
    "transudamos": "transudar",
    "transudando": "transudar",
    "transudara": "transudar",
    "transudaram": "transudar",
    "transudaras": "transudar",
    "transudardes": "transudar",
    "transudarei": "transudar",
    "transudareis": "transudar",
    "transudarem": "transudar",
    "transudaremos": "transudar",
    "transudares": "transudar",
    "transudaria": "transudar",
    "transudariam": "transudar",
    "transudarias": "transudar",
    "transudarmo": "transudar",
    "transudarmos": "transudar",
    "transudará": "transudar",
    "transudarás": "transudar",
    "transudarão": "transudar",
    "transudaríamos": "transudar",
    "transudaríeis": "transudar",
    "transudas": "transudar",
    "transudasse": "transudar",
    "transudassem": "transudar",
    "transudasses": "transudar",
    "transudaste": "transudar",
    "transudastes": "transudar",
    "transudava": "transudar",
    "transudavam": "transudar",
    "transudavas": "transudar",
    "transudações": "transudação",
    "transude": "transudar",
    "transudei": "transudar",
    "transudeis": "transudar",
    "transudem": "transudar",
    "transudemo": "transudar",
    "transudemos": "transudar",
    "transudes": "transudar",
    "transudo": "transudar",
    "transudou": "transudar",
    "transudámo": "transudar",
    "transudámos": "transudar",
    "transudáramo": "transudar",
    "transudáramos": "transudar",
    "transudáreis": "transudar",
    "transudásseis": "transudar",
    "transudássemos": "transudar",
    "transudávamo": "transudar",
    "transudávamos": "transudar",
    "transudáveis": "transudar",
    "transuma": "transumir",
    "transumada": "transumar",
    "transumadas": "transumar",
    "transumado": "transumar",
    "transumados": "transumar",
    "transumai": "transumar",
    "transumais": "transumir",
    "transumam": "transumir",
    "transumamo": "transumir",
    "transumamos": "transumir",
    "transumana": "transumano",
    "transumanada": "transumanar",
    "transumanadas": "transumanar",
    "transumanado": "transumanar",
    "transumanados": "transumanar",
    "transumanai": "transumanar",
    "transumanais": "transumanar",
    "transumanam": "transumanar",
    "transumanamo": "transumanar",
    "transumanamos": "transumanar",
    "transumanando": "transumanar",
    "transumanara": "transumanar",
    "transumanaram": "transumanar",
    "transumanaras": "transumanar",
    "transumanarde": "transumanar",
    "transumanardes": "transumanar",
    "transumanare": "transumanar",
    "transumanarei": "transumanar",
    "transumanareis": "transumanar",
    "transumanarem": "transumanar",
    "transumanaremos": "transumanar",
    "transumanares": "transumanar",
    "transumanaria": "transumanar",
    "transumanariam": "transumanar",
    "transumanarias": "transumanar",
    "transumanarmo": "transumanar",
    "transumanarmos": "transumanar",
    "transumanará": "transumanar",
    "transumanarás": "transumanar",
    "transumanarão": "transumanar",
    "transumanaríamos": "transumanar",
    "transumanaríeis": "transumanar",
    "transumanas": "transumano",
    "transumanasse": "transumanar",
    "transumanassem": "transumanar",
    "transumanasses": "transumanar",
    "transumanaste": "transumanar",
    "transumanastes": "transumanar",
    "transumanava": "transumanar",
    "transumanavam": "transumanar",
    "transumanavas": "transumanar",
    "transumando": "transumar",
    "transumane": "transumanar",
    "transumanei": "transumanar",
    "transumaneis": "transumanar",
    "transumanem": "transumanar",
    "transumanemo": "transumanar",
    "transumanemos": "transumanar",
    "transumanes": "transumanar",
    "transumano": "transumanar",
    "transumanos": "transumano",
    "transumanou": "transumanar",
    "transumantes": "transumante",
    "transumaná": "transumanar",
    "transumanámo": "transumanar",
    "transumanámos": "transumanar",
    "transumanáramo": "transumanar",
    "transumanáramos": "transumanar",
    "transumanárei": "transumanar",
    "transumanáreis": "transumanar",
    "transumanásseis": "transumanar",
    "transumanássemos": "transumanar",
    "transumanávamo": "transumanar",
    "transumanávamos": "transumanar",
    "transumanávei": "transumanar",
    "transumanáveis": "transumanar",
    "transumara": "transumar",
    "transumaram": "transumar",
    "transumaras": "transumar",
    "transumarde": "transumar",
    "transumardes": "transumar",
    "transumare": "transumar",
    "transumarei": "transumar",
    "transumareis": "transumar",
    "transumarem": "transumar",
    "transumaremos": "transumar",
    "transumares": "transumar",
    "transumaria": "transumar",
    "transumariam": "transumar",
    "transumarias": "transumar",
    "transumarmo": "transumar",
    "transumarmos": "transumar",
    "transumará": "transumar",
    "transumarás": "transumar",
    "transumarão": "transumar",
    "transumaríamos": "transumar",
    "transumaríeis": "transumar",
    "transumas": "transumir",
    "transumasse": "transumar",
    "transumassem": "transumar",
    "transumasses": "transumar",
    "transumaste": "transumar",
    "transumastes": "transumar",
    "transumava": "transumar",
    "transumavam": "transumar",
    "transumavas": "transumar",
    "transume": "transumar",
    "transumei": "transumar",
    "transumeis": "transumar",
    "transumem": "transumar",
    "transumemo": "transumar",
    "transumemos": "transumar",
    "transumes": "transumar",
    "transumi": "transumir",
    "transumia": "transumir",
    "transumiam": "transumir",
    "transumias": "transumir",
    "transumida": "transumir",
    "transumidas": "transumir",
    "transumido": "transumir",
    "transumidos": "transumir",
    "transumimo": "transumir",
    "transumimos": "transumir",
    "transumindo": "transumir",
    "transumira": "transumir",
    "transumiram": "transumir",
    "transumiras": "transumir",
    "transumirdes": "transumir",
    "transumirei": "transumir",
    "transumireis": "transumir",
    "transumirem": "transumir",
    "transumiremos": "transumir",
    "transumires": "transumir",
    "transumiria": "transumir",
    "transumiriam": "transumir",
    "transumirias": "transumir",
    "transumirmo": "transumir",
    "transumirmos": "transumir",
    "transumirá": "transumir",
    "transumirás": "transumir",
    "transumirão": "transumir",
    "transumiríamos": "transumir",
    "transumiríeis": "transumir",
    "transumis": "transumir",
    "transumisse": "transumir",
    "transumissem": "transumir",
    "transumisses": "transumir",
    "transumiste": "transumir",
    "transumistes": "transumir",
    "transumiu": "transumir",
    "transumo": "transumir",
    "transumou": "transumar",
    "transumá": "transumar",
    "transumámo": "transumar",
    "transumámos": "transumar",
    "transumáramo": "transumar",
    "transumáramos": "transumar",
    "transumárei": "transumar",
    "transumáreis": "transumar",
    "transumásseis": "transumar",
    "transumássemos": "transumar",
    "transumávamo": "transumar",
    "transumávamos": "transumar",
    "transumávei": "transumar",
    "transumáveis": "transumar",
    "transumâncias": "transumância",
    "transumíamo": "transumir",
    "transumíamos": "transumir",
    "transumíeis": "transumir",
    "transumíramo": "transumir",
    "transumíramos": "transumir",
    "transumíreis": "transumir",
    "transumísseis": "transumir",
    "transumíssemos": "transumir",
    "transuntos": "transunto",
    "transuraniana": "transuraniano",
    "transuranianas": "transuraniano",
    "transuranianos": "transuraniano",
    "transurânica": "transurânico",
    "transurânicas": "transurânico",
    "transurânicos": "transurânico",
    "transvaliana": "transvaliano",
    "transvalianas": "transvaliano",
    "transvalianos": "transvaliano",
    "transvasa": "transvasar",
    "transvasada": "transvasar",
    "transvasadas": "transvasar",
    "transvasado": "transvasar",
    "transvasados": "transvasar",
    "transvasai": "transvasar",
    "transvasais": "transvasar",
    "transvasam": "transvasar",
    "transvasamentos": "transvasamento",
    "transvasamo": "transvasar",
    "transvasamos": "transvasar",
    "transvasando": "transvasar",
    "transvasara": "transvasar",
    "transvasaram": "transvasar",
    "transvasaras": "transvasar",
    "transvasarde": "transvasar",
    "transvasardes": "transvasar",
    "transvasare": "transvasar",
    "transvasarei": "transvasar",
    "transvasareis": "transvasar",
    "transvasarem": "transvasar",
    "transvasaremos": "transvasar",
    "transvasares": "transvasar",
    "transvasaria": "transvasar",
    "transvasariam": "transvasar",
    "transvasarias": "transvasar",
    "transvasarmo": "transvasar",
    "transvasarmos": "transvasar",
    "transvasará": "transvasar",
    "transvasarás": "transvasar",
    "transvasarão": "transvasar",
    "transvasaríamos": "transvasar",
    "transvasaríeis": "transvasar",
    "transvasas": "transvasar",
    "transvasasse": "transvasar",
    "transvasassem": "transvasar",
    "transvasasses": "transvasar",
    "transvasaste": "transvasar",
    "transvasastes": "transvasar",
    "transvasava": "transvasar",
    "transvasavam": "transvasar",
    "transvasavas": "transvasar",
    "transvase": "transvasar",
    "transvasei": "transvasar",
    "transvaseis": "transvasar",
    "transvasem": "transvasar",
    "transvasemo": "transvasar",
    "transvasemos": "transvasar",
    "transvases": "transvase",
    "transvaso": "transvasar",
    "transvasou": "transvasar",
    "transvasá": "transvasar",
    "transvasámo": "transvasar",
    "transvasámos": "transvasar",
    "transvasáramo": "transvasar",
    "transvasáramos": "transvasar",
    "transvasárei": "transvasar",
    "transvasáreis": "transvasar",
    "transvasásseis": "transvasar",
    "transvasássemos": "transvasar",
    "transvasávamo": "transvasar",
    "transvasávamos": "transvasar",
    "transvasávei": "transvasar",
    "transvasáveis": "transvasável",
    "transvaza": "transvazar",
    "transvazada": "transvazar",
    "transvazadas": "transvazar",
    "transvazado": "transvazar",
    "transvazados": "transvazar",
    "transvazai": "transvazar",
    "transvazais": "transvazar",
    "transvazam": "transvazar",
    "transvazamo": "transvazar",
    "transvazamos": "transvazar",
    "transvazando": "transvazar",
    "transvazara": "transvazar",
    "transvazaram": "transvazar",
    "transvazaras": "transvazar",
    "transvazarde": "transvazar",
    "transvazardes": "transvazar",
    "transvazare": "transvazar",
    "transvazarei": "transvazar",
    "transvazareis": "transvazar",
    "transvazarem": "transvazar",
    "transvazaremos": "transvazar",
    "transvazares": "transvazar",
    "transvazaria": "transvazar",
    "transvazariam": "transvazar",
    "transvazarias": "transvazar",
    "transvazarmo": "transvazar",
    "transvazarmos": "transvazar",
    "transvazará": "transvazar",
    "transvazarás": "transvazar",
    "transvazarão": "transvazar",
    "transvazaríamos": "transvazar",
    "transvazaríeis": "transvazar",
    "transvazas": "transvazar",
    "transvazasse": "transvazar",
    "transvazassem": "transvazar",
    "transvazasses": "transvazar",
    "transvazaste": "transvazar",
    "transvazastes": "transvazar",
    "transvazava": "transvazar",
    "transvazavam": "transvazar",
    "transvazavas": "transvazar",
    "transvaze": "transvazar",
    "transvazei": "transvazar",
    "transvazeis": "transvazar",
    "transvazem": "transvazar",
    "transvazemo": "transvazar",
    "transvazemos": "transvazar",
    "transvazes": "transvazar",
    "transvazo": "transvazar",
    "transvazou": "transvazar",
    "transvazá": "transvazar",
    "transvazámo": "transvazar",
    "transvazámos": "transvazar",
    "transvazáramo": "transvazar",
    "transvazáramos": "transvazar",
    "transvazárei": "transvazar",
    "transvazáreis": "transvazar",
    "transvazásseis": "transvazar",
    "transvazássemos": "transvazar",
    "transvazávamo": "transvazar",
    "transvazávamos": "transvazar",
    "transvazávei": "transvazar",
    "transvazáveis": "transvazar",
    "transverbera": "transverberar",
    "transverberada": "transverberar",
    "transverberadas": "transverberar",
    "transverberado": "transverberar",
    "transverberados": "transverberar",
    "transverberai": "transverberar",
    "transverberais": "transverberar",
    "transverberam": "transverberar",
    "transverberamo": "transverberar",
    "transverberamos": "transverberar",
    "transverberando": "transverberar",
    "transverberara": "transverberar",
    "transverberaram": "transverberar",
    "transverberaras": "transverberar",
    "transverberarde": "transverberar",
    "transverberardes": "transverberar",
    "transverberare": "transverberar",
    "transverberarei": "transverberar",
    "transverberareis": "transverberar",
    "transverberarem": "transverberar",
    "transverberaremos": "transverberar",
    "transverberares": "transverberar",
    "transverberaria": "transverberar",
    "transverberariam": "transverberar",
    "transverberarias": "transverberar",
    "transverberarmo": "transverberar",
    "transverberarmos": "transverberar",
    "transverberará": "transverberar",
    "transverberarás": "transverberar",
    "transverberarão": "transverberar",
    "transverberaríamos": "transverberar",
    "transverberaríeis": "transverberar",
    "transverberas": "transverberar",
    "transverberasse": "transverberar",
    "transverberassem": "transverberar",
    "transverberasses": "transverberar",
    "transverberaste": "transverberar",
    "transverberastes": "transverberar",
    "transverberava": "transverberar",
    "transverberavam": "transverberar",
    "transverberavas": "transverberar",
    "transverberações": "transverberação",
    "transverbere": "transverberar",
    "transverberei": "transverberar",
    "transverbereis": "transverberar",
    "transverberem": "transverberar",
    "transverberemo": "transverberar",
    "transverberemos": "transverberar",
    "transverberes": "transverberar",
    "transverbero": "transverberar",
    "transverberou": "transverberar",
    "transverberá": "transverberar",
    "transverberámo": "transverberar",
    "transverberámos": "transverberar",
    "transverberáramo": "transverberar",
    "transverberáramos": "transverberar",
    "transverberárei": "transverberar",
    "transverberáreis": "transverberar",
    "transverberásseis": "transverberar",
    "transverberássemos": "transverberar",
    "transverberávamo": "transverberar",
    "transverberávamos": "transverberar",
    "transverberávei": "transverberar",
    "transverberáveis": "transverberar",
    "transversa": "transverso",
    "transversais": "transversal",
    "transversalidades": "transversalidade",
    "transversas": "transverso",
    "transversos": "transverso",
    "transversões": "transversão",
    "transverta": "transverter",
    "transvertais": "transverter",
    "transvertam": "transverter",
    "transvertamo": "transverter",
    "transvertamos": "transverter",
    "transvertas": "transverter",
    "transverte": "transverter",
    "transvertei": "transverter",
    "transverteis": "transverter",
    "transvertem": "transverter",
    "transvertemo": "transverter",
    "transvertemos": "transverter",
    "transvertendo": "transverter",
    "transvertera": "transverter",
    "transverteram": "transverter",
    "transverteras": "transverter",
    "transverterde": "transverter",
    "transverterdes": "transverter",
    "transvertere": "transverter",
    "transverterei": "transverter",
    "transvertereis": "transverter",
    "transverterem": "transverter",
    "transverteremos": "transverter",
    "transverteres": "transverter",
    "transverteria": "transverter",
    "transverteriam": "transverter",
    "transverterias": "transverter",
    "transvertermo": "transverter",
    "transvertermos": "transverter",
    "transverterá": "transverter",
    "transverterás": "transverter",
    "transverterão": "transverter",
    "transverteríamos": "transverter",
    "transverteríeis": "transverter",
    "transvertes": "transverter",
    "transvertesse": "transverter",
    "transvertessem": "transverter",
    "transvertesses": "transverter",
    "transverteste": "transverter",
    "transvertestes": "transverter",
    "transverteu": "transverter",
    "transverti": "transverter",
    "transvertia": "transverter",
    "transvertiam": "transverter",
    "transvertias": "transverter",
    "transvertida": "transverter",
    "transvertidas": "transverter",
    "transvertido": "transverter",
    "transvertidos": "transverter",
    "transverto": "transverter",
    "transvertê": "transverter",
    "transvertêramo": "transverter",
    "transvertêramos": "transverter",
    "transvertêrei": "transverter",
    "transvertêreis": "transverter",
    "transvertêsseis": "transverter",
    "transvertêssemos": "transverter",
    "transvertíamo": "transverter",
    "transvertíamos": "transverter",
    "transvertíei": "transverter",
    "transvertíeis": "transverter",
    "transvia": "transviar",
    "transviada": "transviar",
    "transviadas": "transviar",
    "transviado": "transviar",
    "transviadora": "transviador",
    "transviadoras": "transviador",
    "transviadores": "transviador",
    "transviados": "transviar",
    "transviai": "transviar",
    "transviais": "transviar",
    "transviam": "transviar",
    "transviamo": "transviar",
    "transviamos": "transviar",
    "transviando": "transviar",
    "transviara": "transviar",
    "transviaram": "transviar",
    "transviaras": "transviar",
    "transviarde": "transviar",
    "transviardes": "transviar",
    "transviare": "transviar",
    "transviarei": "transviar",
    "transviareis": "transviar",
    "transviarem": "transviar",
    "transviaremos": "transviar",
    "transviares": "transviar",
    "transviaria": "transviar",
    "transviariam": "transviar",
    "transviarias": "transviar",
    "transviarmo": "transviar",
    "transviarmos": "transviar",
    "transviará": "transviar",
    "transviarás": "transviar",
    "transviarão": "transviar",
    "transviaríamos": "transviar",
    "transviaríeis": "transviar",
    "transvias": "transviar",
    "transviasse": "transviar",
    "transviassem": "transviar",
    "transviasses": "transviar",
    "transviaste": "transviar",
    "transviastes": "transviar",
    "transviava": "transviar",
    "transviavam": "transviar",
    "transviavas": "transviar",
    "transvie": "transviar",
    "transviei": "transviar",
    "transvieis": "transviar",
    "transviem": "transviar",
    "transviemo": "transviar",
    "transviemos": "transviar",
    "transvies": "transviar",
    "transvio": "transviar",
    "transvios": "transvio",
    "transviou": "transviar",
    "transviá": "transviar",
    "transviámo": "transviar",
    "transviámos": "transviar",
    "transviáramo": "transviar",
    "transviáramos": "transviar",
    "transviárei": "transviar",
    "transviáreis": "transviar",
    "transviásseis": "transviar",
    "transviássemos": "transviar",
    "transviávamo": "transviar",
    "transviávamos": "transviar",
    "transviávei": "transviar",
    "transviáveis": "transviar",
    "transvoa": "transvoar",
    "transvoada": "transvoar",
    "transvoadas": "transvoar",
    "transvoado": "transvoar",
    "transvoados": "transvoar",
    "transvoai": "transvoar",
    "transvoais": "transvoar",
    "transvoam": "transvoar",
    "transvoamo": "transvoar",
    "transvoamos": "transvoar",
    "transvoando": "transvoar",
    "transvoara": "transvoar",
    "transvoaram": "transvoar",
    "transvoaras": "transvoar",
    "transvoarde": "transvoar",
    "transvoardes": "transvoar",
    "transvoare": "transvoar",
    "transvoarei": "transvoar",
    "transvoareis": "transvoar",
    "transvoarem": "transvoar",
    "transvoaremos": "transvoar",
    "transvoares": "transvoar",
    "transvoaria": "transvoar",
    "transvoariam": "transvoar",
    "transvoarias": "transvoar",
    "transvoarmo": "transvoar",
    "transvoarmos": "transvoar",
    "transvoará": "transvoar",
    "transvoarás": "transvoar",
    "transvoarão": "transvoar",
    "transvoaríamos": "transvoar",
    "transvoaríeis": "transvoar",
    "transvoas": "transvoar",
    "transvoasse": "transvoar",
    "transvoassem": "transvoar",
    "transvoasses": "transvoar",
    "transvoaste": "transvoar",
    "transvoastes": "transvoar",
    "transvoava": "transvoar",
    "transvoavam": "transvoar",
    "transvoavas": "transvoar",
    "transvoe": "transvoar",
    "transvoei": "transvoar",
    "transvoeis": "transvoar",
    "transvoem": "transvoar",
    "transvoemo": "transvoar",
    "transvoemos": "transvoar",
    "transvoes": "transvoar",
    "transvoo": "transvoar",
    "transvoos": "transvoo",
    "transvoou": "transvoar",
    "transvora": "transvorar",
    "transvorada": "transvorar",
    "transvoradas": "transvorar",
    "transvorado": "transvorar",
    "transvorados": "transvorar",
    "transvorai": "transvorar",
    "transvorais": "transvorar",
    "transvoram": "transvorar",
    "transvoramo": "transvorar",
    "transvoramos": "transvorar",
    "transvorando": "transvorar",
    "transvorara": "transvorar",
    "transvoraram": "transvorar",
    "transvoraras": "transvorar",
    "transvorarde": "transvorar",
    "transvorardes": "transvorar",
    "transvorare": "transvorar",
    "transvorarei": "transvorar",
    "transvorareis": "transvorar",
    "transvorarem": "transvorar",
    "transvoraremos": "transvorar",
    "transvorares": "transvorar",
    "transvoraria": "transvorar",
    "transvorariam": "transvorar",
    "transvorarias": "transvorar",
    "transvorarmo": "transvorar",
    "transvorarmos": "transvorar",
    "transvorará": "transvorar",
    "transvorarás": "transvorar",
    "transvorarão": "transvorar",
    "transvoraríamos": "transvorar",
    "transvoraríeis": "transvorar",
    "transvoras": "transvorar",
    "transvorasse": "transvorar",
    "transvorassem": "transvorar",
    "transvorasses": "transvorar",
    "transvoraste": "transvorar",
    "transvorastes": "transvorar",
    "transvorava": "transvorar",
    "transvoravam": "transvorar",
    "transvoravas": "transvorar",
    "transvore": "transvorar",
    "transvorei": "transvorar",
    "transvoreis": "transvorar",
    "transvorem": "transvorar",
    "transvoremo": "transvorar",
    "transvoremos": "transvorar",
    "transvores": "transvorar",
    "transvoro": "transvorar",
    "transvorou": "transvorar",
    "transvorá": "transvorar",
    "transvorámo": "transvorar",
    "transvorámos": "transvorar",
    "transvoráramo": "transvorar",
    "transvoráramos": "transvorar",
    "transvorárei": "transvorar",
    "transvoráreis": "transvorar",
    "transvorásseis": "transvorar",
    "transvorássemos": "transvorar",
    "transvorávamo": "transvorar",
    "transvorávamos": "transvorar",
    "transvorávei": "transvorar",
    "transvoráveis": "transvorar",
    "transvoá": "transvoar",
    "transvoámo": "transvoar",
    "transvoámos": "transvoar",
    "transvoáramo": "transvoar",
    "transvoáramos": "transvoar",
    "transvoárei": "transvoar",
    "transvoáreis": "transvoar",
    "transvoásseis": "transvoar",
    "transvoássemos": "transvoar",
    "transvoávamo": "transvoar",
    "transvoávamos": "transvoar",
    "transvoávei": "transvoar",
    "transvoáveis": "transvoar",
    "transíamo": "transir",
    "transíamos": "transir",
    "transíei": "transir",
    "transíeis": "transir",
    "transíramo": "transir",
    "transíramos": "transir",
    "transírei": "transir",
    "transíreis": "transir",
    "transísseis": "transir",
    "transíssemos": "transir",
    "transístores": "transístor",
    "transónica": "transónico",
    "transónicas": "transónico",
    "transónicos": "transónico",
    "traná": "tranar",
    "tranámo": "tranar",
    "tranámos": "tranar",
    "tranáramo": "tranar",
    "tranáramos": "tranar",
    "tranárei": "tranar",
    "tranáreis": "tranar",
    "tranásseis": "tranar",
    "tranássemos": "tranar",
    "tranávamo": "tranar",
    "tranávamos": "tranar",
    "tranávei": "tranar",
    "tranáveis": "tranar",
    "trança": "trançar",
    "trançada": "trançar",
    "trançadas": "trançar",
    "trançadeiras": "trançadeira",
    "trançado": "trançar",
    "trançados": "trançar",
    "trançai": "trançar",
    "trançais": "trançar",
    "trançam": "trançar",
    "trançamo": "trançar",
    "trançamos": "trançar",
    "trançando": "trançar",
    "trançara": "trançar",
    "trançaram": "trançar",
    "trançaras": "trançar",
    "trançarde": "trançar",
    "trançardes": "trançar",
    "trançare": "trançar",
    "trançarei": "trançar",
    "trançareis": "trançar",
    "trançarem": "trançar",
    "trançaremos": "trançar",
    "trançares": "trançar",
    "trançaria": "trançar",
    "trançariam": "trançar",
    "trançarias": "trançar",
    "trançarmo": "trançar",
    "trançarmos": "trançar",
    "trançará": "trançar",
    "trançarás": "trançar",
    "trançarão": "trançar",
    "trançaríamos": "trançar",
    "trançaríeis": "trançar",
    "tranças": "trançar",
    "trançasse": "trançar",
    "trançassem": "trançar",
    "trançasses": "trançar",
    "trançaste": "trançar",
    "trançastes": "trançar",
    "trançava": "trançar",
    "trançavam": "trançar",
    "trançavas": "trançar",
    "tranço": "trançar",
    "trançou": "trançar",
    "trançá": "trançar",
    "trançámo": "trançar",
    "trançámos": "trançar",
    "trançáramo": "trançar",
    "trançáramos": "trançar",
    "trançárei": "trançar",
    "trançáreis": "trançar",
    "trançásseis": "trançar",
    "trançássemos": "trançar",
    "trançávamo": "trançar",
    "trançávamos": "trançar",
    "trançávei": "trançar",
    "trançáveis": "trançar",
    "trapaceada": "trapacear",
    "trapaceadas": "trapacear",
    "trapaceado": "trapacear",
    "trapaceados": "trapacear",
    "trapaceai": "trapacear",
    "trapaceais": "trapacear",
    "trapaceamo": "trapacear",
    "trapaceamos": "trapacear",
    "trapaceando": "trapacear",
    "trapaceara": "trapacear",
    "trapacearam": "trapacear",
    "trapacearas": "trapacear",
    "trapacearde": "trapacear",
    "trapaceardes": "trapacear",
    "trapaceare": "trapacear",
    "trapacearei": "trapacear",
    "trapaceareis": "trapacear",
    "trapacearem": "trapacear",
    "trapacearemos": "trapacear",
    "trapaceares": "trapacear",
    "trapacearia": "trapacear",
    "trapaceariam": "trapacear",
    "trapacearias": "trapacear",
    "trapacearmo": "trapacear",
    "trapacearmos": "trapacear",
    "trapaceará": "trapacear",
    "trapacearás": "trapacear",
    "trapacearão": "trapacear",
    "trapacearíamos": "trapacear",
    "trapacearíeis": "trapacear",
    "trapaceasse": "trapacear",
    "trapaceassem": "trapacear",
    "trapaceasses": "trapacear",
    "trapaceaste": "trapacear",
    "trapaceastes": "trapacear",
    "trapaceava": "trapacear",
    "trapaceavam": "trapacear",
    "trapaceavas": "trapacear",
    "trapaceei": "trapacear",
    "trapaceeis": "trapacear",
    "trapaceemo": "trapacear",
    "trapaceemos": "trapacear",
    "trapaceia": "trapacear",
    "trapaceiam": "trapacear",
    "trapaceias": "trapacear",
    "trapaceie": "trapacear",
    "trapaceiem": "trapacear",
    "trapaceies": "trapacear",
    "trapaceio": "trapacear",
    "trapaceira": "trapaceiro",
    "trapaceiras": "trapaceiro",
    "trapaceiros": "trapaceiro",
    "trapacenta": "trapacento",
    "trapacentas": "trapacento",
    "trapacentos": "trapacento",
    "trapaceou": "trapacear",
    "trapaceá": "trapacear",
    "trapaceámo": "trapacear",
    "trapaceámos": "trapacear",
    "trapaceáramo": "trapacear",
    "trapaceáramos": "trapacear",
    "trapaceárei": "trapacear",
    "trapaceáreis": "trapacear",
    "trapaceásseis": "trapacear",
    "trapaceássemos": "trapacear",
    "trapaceávamo": "trapacear",
    "trapaceávamos": "trapacear",
    "trapaceávei": "trapacear",
    "trapaceáveis": "trapacear",
    "trapacices": "trapacice",
    "trapadas": "trapada",
    "trapalhada": "trapalhado",
    "trapalhadas": "trapalhado",
    "trapalhados": "trapalhado",
    "trapalhices": "trapalhice",
    "trapalhona": "trapalhão",
    "trapalhonas": "trapalhão",
    "trapalhonazinha": "trapalhão",
    "trapalhonazinhas": "trapalhão",
    "trapalhonazita": "trapalhão",
    "trapalhonazitas": "trapalhão",
    "trapalhos": "trapalho",
    "trapalhãozinho": "trapalhão",
    "trapalhãozito": "trapalhão",
    "trapalhões": "trapalhão",
    "trapalhõezinhos": "trapalhão",
    "trapalhõezitos": "trapalhão",
    "traparias": "traparia",
    "trapas": "trapa",
    "trapaçadora": "trapaçador",
    "trapaçadoras": "trapaçador",
    "trapaçadores": "trapaçador",
    "trapaçarias": "trapaçaria",
    "trapaças": "trapaça",
    "trapeada": "trapear",
    "trapeadas": "trapear",
    "trapeado": "trapear",
    "trapeados": "trapear",
    "trapeai": "trapear",
    "trapeais": "trapear",
    "trapeamo": "trapear",
    "trapeamos": "trapear",
    "trapeando": "trapear",
    "trapeara": "trapear",
    "trapearam": "trapear",
    "trapearas": "trapear",
    "trapeardes": "trapear",
    "trapearei": "trapear",
    "trapeareis": "trapear",
    "trapearem": "trapear",
    "trapearemos": "trapear",
    "trapeares": "trapear",
    "trapearia": "trapear",
    "trapeariam": "trapear",
    "trapearias": "trapear",
    "trapearmo": "trapear",
    "trapearmos": "trapear",
    "trapeará": "trapear",
    "trapearás": "trapear",
    "trapearão": "trapear",
    "trapearíamos": "trapear",
    "trapearíeis": "trapear",
    "trapeasse": "trapear",
    "trapeassem": "trapear",
    "trapeasses": "trapear",
    "trapeaste": "trapear",
    "trapeastes": "trapear",
    "trapeava": "trapear",
    "trapeavam": "trapear",
    "trapeavas": "trapear",
    "trapeei": "trapear",
    "trapeeis": "trapear",
    "trapeemo": "trapear",
    "trapeemos": "trapear",
    "trapeia": "trapear",
    "trapeiam": "trapear",
    "trapeias": "trapear",
    "trapeie": "trapear",
    "trapeiem": "trapear",
    "trapeies": "trapear",
    "trapeio": "trapear",
    "trapeira": "trapeiro",
    "trapeiras": "trapeiro",
    "trapeiros": "trapeiro",
    "trapeja": "trapejar",
    "trapejada": "trapejar",
    "trapejadas": "trapejar",
    "trapejado": "trapejar",
    "trapejados": "trapejar",
    "trapejai": "trapejar",
    "trapejais": "trapejar",
    "trapejam": "trapejar",
    "trapejamo": "trapejar",
    "trapejamos": "trapejar",
    "trapejando": "trapejar",
    "trapejantes": "trapejante",
    "trapejara": "trapejar",
    "trapejaram": "trapejar",
    "trapejaras": "trapejar",
    "trapejardes": "trapejar",
    "trapejarei": "trapejar",
    "trapejareis": "trapejar",
    "trapejarem": "trapejar",
    "trapejaremos": "trapejar",
    "trapejares": "trapejar",
    "trapejaria": "trapejar",
    "trapejariam": "trapejar",
    "trapejarias": "trapejar",
    "trapejarmo": "trapejar",
    "trapejarmos": "trapejar",
    "trapejará": "trapejar",
    "trapejarás": "trapejar",
    "trapejarão": "trapejar",
    "trapejaríamos": "trapejar",
    "trapejaríeis": "trapejar",
    "trapejas": "trapejar",
    "trapejasse": "trapejar",
    "trapejassem": "trapejar",
    "trapejasses": "trapejar",
    "trapejaste": "trapejar",
    "trapejastes": "trapejar",
    "trapejava": "trapejar",
    "trapejavam": "trapejar",
    "trapejavas": "trapejar",
    "trapeje": "trapejar",
    "trapejei": "trapejar",
    "trapejeis": "trapejar",
    "trapejem": "trapejar",
    "trapejemo": "trapejar",
    "trapejemos": "trapejar",
    "trapejes": "trapejar",
    "trapejo": "trapejar",
    "trapejou": "trapejar",
    "trapejámo": "trapejar",
    "trapejámos": "trapejar",
    "trapejáramo": "trapejar",
    "trapejáramos": "trapejar",
    "trapejáreis": "trapejar",
    "trapejásseis": "trapejar",
    "trapejássemos": "trapejar",
    "trapejávamo": "trapejar",
    "trapejávamos": "trapejar",
    "trapejáveis": "trapejar",
    "trapenta": "trapento",
    "trapentas": "trapento",
    "trapentos": "trapento",
    "trapeou": "trapear",
    "trapeziformes": "trapeziforme",
    "trapezistas": "trapezista",
    "trapezoedros": "trapezoedro",
    "trapezoidais": "trapezoidal",
    "trapezoédrica": "trapezoédrico",
    "trapezoédricas": "trapezoédrico",
    "trapezoédricos": "trapezoédrico",
    "trapezóides": "trapezóide",
    "trapeámo": "trapear",
    "trapeámos": "trapear",
    "trapeáramo": "trapear",
    "trapeáramos": "trapear",
    "trapeáreis": "trapear",
    "trapeásseis": "trapear",
    "trapeássemos": "trapear",
    "trapeávamo": "trapear",
    "trapeávamos": "trapear",
    "trapeáveis": "trapear",
    "trapicalhadas": "trapicalhada",
    "trapicalhos": "trapicalho",
    "trapicheira": "trapicheiro",
    "trapicheiras": "trapicheiro",
    "trapicheiros": "trapicheiro",
    "trapiches": "trapiche",
    "trapilhos": "trapilho",
    "trapinho": "trapo",
    "trapinhos": "trapo",
    "trapistas": "trapista",
    "trapito": "trapo",
    "trapitos": "trapo",
    "trapizondas": "trapizonda",
    "trapolas": "trapola",
    "trapos": "trapo",
    "trapozinho": "trapo",
    "trapozinhos": "trapo",
    "trapozito": "trapo",
    "trapozitos": "trapo",
    "trapézios": "trapézio",
    "traqueada": "traqueado",
    "traqueadas": "traqueado",
    "traqueados": "traqueado",
    "traqueais": "traqueal",
    "traqueana": "traqueano",
    "traqueanas": "traqueano",
    "traqueanos": "traqueano",
    "traqueias": "traqueia",
    "traqueja": "traquejar",
    "traquejada": "traquejar",
    "traquejadas": "traquejar",
    "traquejado": "traquejar",
    "traquejados": "traquejar",
    "traquejai": "traquejar",
    "traquejais": "traquejar",
    "traquejam": "traquejar",
    "traquejamo": "traquejar",
    "traquejamos": "traquejar",
    "traquejando": "traquejar",
    "traquejara": "traquejar",
    "traquejaram": "traquejar",
    "traquejaras": "traquejar",
    "traquejarde": "traquejar",
    "traquejardes": "traquejar",
    "traquejare": "traquejar",
    "traquejarei": "traquejar",
    "traquejareis": "traquejar",
    "traquejarem": "traquejar",
    "traquejaremos": "traquejar",
    "traquejares": "traquejar",
    "traquejaria": "traquejar",
    "traquejariam": "traquejar",
    "traquejarias": "traquejar",
    "traquejarmo": "traquejar",
    "traquejarmos": "traquejar",
    "traquejará": "traquejar",
    "traquejarás": "traquejar",
    "traquejarão": "traquejar",
    "traquejaríamos": "traquejar",
    "traquejaríeis": "traquejar",
    "traquejas": "traquejar",
    "traquejasse": "traquejar",
    "traquejassem": "traquejar",
    "traquejasses": "traquejar",
    "traquejaste": "traquejar",
    "traquejastes": "traquejar",
    "traquejava": "traquejar",
    "traquejavam": "traquejar",
    "traquejavas": "traquejar",
    "traqueje": "traquejar",
    "traquejei": "traquejar",
    "traquejeis": "traquejar",
    "traquejem": "traquejar",
    "traquejemo": "traquejar",
    "traquejemos": "traquejar",
    "traquejes": "traquejar",
    "traquejo": "traquejar",
    "traquejos": "traquejo",
    "traquejou": "traquejar",
    "traquejá": "traquejar",
    "traquejámo": "traquejar",
    "traquejámos": "traquejar",
    "traquejáramo": "traquejar",
    "traquejáramos": "traquejar",
    "traquejárei": "traquejar",
    "traquejáreis": "traquejar",
    "traquejásseis": "traquejar",
    "traquejássemos": "traquejar",
    "traquejávamo": "traquejar",
    "traquejávamos": "traquejar",
    "traquejávei": "traquejar",
    "traquejáveis": "traquejar",
    "traqueliana": "traqueliano",
    "traquelianas": "traqueliano",
    "traquelianos": "traqueliano",
    "traquelismos": "traquelismo",
    "traquelites": "traquelite",
    "traqueloceles": "traquelocele",
    "traquelópodes": "traquelópode",
    "traqueobronquites": "traqueobronquite",
    "traqueoceles": "traqueocele",
    "traqueorragias": "traqueorragia",
    "traqueoscopias": "traqueoscopia",
    "traqueoscópios": "traqueoscópio",
    "traqueostomias": "traqueostomia",
    "traqueotomias": "traqueotomia",
    "traques": "traque",
    "traquetes": "traquete",
    "traqueítes": "traqueíte",
    "traquimedusas": "traquimedusa",
    "traquina": "traquinas",
    "traquinada": "traquinar",
    "traquinadas": "traquinar",
    "traquinado": "traquinar",
    "traquinados": "traquinar",
    "traquinai": "traquinar",
    "traquinais": "traquinar",
    "traquinam": "traquinar",
    "traquinamo": "traquinar",
    "traquinamos": "traquinar",
    "traquinando": "traquinar",
    "traquinara": "traquinar",
    "traquinaram": "traquinar",
    "traquinaras": "traquinar",
    "traquinardes": "traquinar",
    "traquinarei": "traquinar",
    "traquinareis": "traquinar",
    "traquinarem": "traquinar",
    "traquinaremos": "traquinar",
    "traquinares": "traquinar",
    "traquinaria": "traquinar",
    "traquinariam": "traquinar",
    "traquinarias": "traquinar",
    "traquinarmo": "traquinar",
    "traquinarmos": "traquinar",
    "traquinará": "traquinar",
    "traquinarás": "traquinar",
    "traquinarão": "traquinar",
    "traquinaríamos": "traquinar",
    "traquinaríeis": "traquinar",
    "traquinas": "traquinar",
    "traquinasse": "traquinar",
    "traquinassem": "traquinar",
    "traquinasses": "traquinar",
    "traquinaste": "traquinar",
    "traquinastes": "traquinar",
    "traquinava": "traquinar",
    "traquinavam": "traquinar",
    "traquinavas": "traquinar",
    "traquine": "traquinar",
    "traquinei": "traquinar",
    "traquineis": "traquinar",
    "traquinem": "traquinar",
    "traquinemo": "traquinar",
    "traquinemos": "traquinar",
    "traquines": "traquinar",
    "traquinices": "traquinice",
    "traquino": "traquinar",
    "traquinotes": "traquinote",
    "traquinou": "traquinar",
    "traquinámo": "traquinar",
    "traquinámos": "traquinar",
    "traquináramo": "traquinar",
    "traquináramos": "traquinar",
    "traquináreis": "traquinar",
    "traquinásseis": "traquinar",
    "traquinássemos": "traquinar",
    "traquinávamo": "traquinar",
    "traquinávamos": "traquinar",
    "traquináveis": "traquinar",
    "traquinídeos": "traquinídeo",
    "traquitanas": "traquitana",
    "traquites": "traquite",
    "traquito": "traquite",
    "traquitos": "traquite",
    "traquitóides": "traquitóide",
    "traquéolas": "traquéola",
    "traquínidas": "traquínida",
    "traquíolas": "traquíola",
    "traquítica": "traquítico",
    "traquíticas": "traquítico",
    "traquíticos": "traquítico",
    "trarei": "trazer",
    "trareis": "trazer",
    "traremos": "trazer",
    "traria": "trazer",
    "trariam": "trazer",
    "trarias": "trazer",
    "trará": "trazer",
    "trarás": "trazer",
    "trarão": "trazer",
    "traríamos": "trazer",
    "traríeis": "trazer",
    "trasborbamentos": "trasborbamento",
    "trasborda": "trasbordar",
    "trasbordada": "trasbordar",
    "trasbordadas": "trasbordar",
    "trasbordado": "trasbordar",
    "trasbordados": "trasbordar",
    "trasbordai": "trasbordar",
    "trasbordais": "trasbordar",
    "trasbordam": "trasbordar",
    "trasbordamo": "trasbordar",
    "trasbordamos": "trasbordar",
    "trasbordando": "trasbordar",
    "trasbordantes": "trasbordante",
    "trasbordara": "trasbordar",
    "trasbordaram": "trasbordar",
    "trasbordaras": "trasbordar",
    "trasbordardes": "trasbordar",
    "trasbordarei": "trasbordar",
    "trasbordareis": "trasbordar",
    "trasbordarem": "trasbordar",
    "trasbordaremos": "trasbordar",
    "trasbordares": "trasbordar",
    "trasbordaria": "trasbordar",
    "trasbordariam": "trasbordar",
    "trasbordarias": "trasbordar",
    "trasbordarmo": "trasbordar",
    "trasbordarmos": "trasbordar",
    "trasbordará": "trasbordar",
    "trasbordarás": "trasbordar",
    "trasbordarão": "trasbordar",
    "trasbordaríamos": "trasbordar",
    "trasbordaríeis": "trasbordar",
    "trasbordas": "trasbordar",
    "trasbordasse": "trasbordar",
    "trasbordassem": "trasbordar",
    "trasbordasses": "trasbordar",
    "trasbordaste": "trasbordar",
    "trasbordastes": "trasbordar",
    "trasbordava": "trasbordar",
    "trasbordavam": "trasbordar",
    "trasbordavas": "trasbordar",
    "trasborde": "trasbordar",
    "trasbordei": "trasbordar",
    "trasbordeis": "trasbordar",
    "trasbordem": "trasbordar",
    "trasbordemo": "trasbordar",
    "trasbordemos": "trasbordar",
    "trasbordes": "trasbordar",
    "trasbordo": "trasbordar",
    "trasbordos": "trasbordo",
    "trasbordou": "trasbordar",
    "trasbordámo": "trasbordar",
    "trasbordámos": "trasbordar",
    "trasbordáramo": "trasbordar",
    "trasbordáramos": "trasbordar",
    "trasbordáreis": "trasbordar",
    "trasbordásseis": "trasbordar",
    "trasbordássemos": "trasbordar",
    "trasbordávamo": "trasbordar",
    "trasbordávamos": "trasbordar",
    "trasbordáveis": "trasbordar",
    "trascâmaras": "trascâmara",
    "traseira": "traseiro",
    "traseiras": "traseiro",
    "traseiros": "traseiro",
    "trasfegadora": "trasfegador",
    "trasfegadoras": "trasfegador",
    "trasfegadores": "trasfegador",
    "trasfegaduras": "trasfegadura",
    "trasfegas": "trasfega",
    "trasfegos": "trasfego",
    "trasfegueiros": "trasfegueiro",
    "trasflores": "trasflor",
    "trasfogueiros": "trasfogueiro",
    "trasgas": "trasga",
    "trasgos": "trasgo",
    "trasgueada": "trasguear",
    "trasgueadas": "trasguear",
    "trasgueado": "trasguear",
    "trasgueados": "trasguear",
    "trasgueai": "trasguear",
    "trasgueais": "trasguear",
    "trasgueamo": "trasguear",
    "trasgueamos": "trasguear",
    "trasgueando": "trasguear",
    "trasgueara": "trasguear",
    "trasguearam": "trasguear",
    "trasguearas": "trasguear",
    "trasgueardes": "trasguear",
    "trasguearei": "trasguear",
    "trasgueareis": "trasguear",
    "trasguearem": "trasguear",
    "trasguearemos": "trasguear",
    "trasgueares": "trasguear",
    "trasguearia": "trasguear",
    "trasgueariam": "trasguear",
    "trasguearias": "trasguear",
    "trasguearmo": "trasguear",
    "trasguearmos": "trasguear",
    "trasgueará": "trasguear",
    "trasguearás": "trasguear",
    "trasguearão": "trasguear",
    "trasguearíamos": "trasguear",
    "trasguearíeis": "trasguear",
    "trasgueasse": "trasguear",
    "trasgueassem": "trasguear",
    "trasgueasses": "trasguear",
    "trasgueaste": "trasguear",
    "trasgueastes": "trasguear",
    "trasgueava": "trasguear",
    "trasgueavam": "trasguear",
    "trasgueavas": "trasguear",
    "trasgueei": "trasguear",
    "trasgueeis": "trasguear",
    "trasgueemo": "trasguear",
    "trasgueemos": "trasguear",
    "trasgueia": "trasguear",
    "trasgueiam": "trasguear",
    "trasgueias": "trasguear",
    "trasgueie": "trasguear",
    "trasgueiem": "trasguear",
    "trasgueies": "trasguear",
    "trasgueio": "trasguear",
    "trasgueiros": "trasgueiro",
    "trasgueou": "trasguear",
    "trasgueámo": "trasguear",
    "trasgueámos": "trasguear",
    "trasgueáramo": "trasguear",
    "trasgueáramos": "trasguear",
    "trasgueáreis": "trasguear",
    "trasgueásseis": "trasguear",
    "trasgueássemos": "trasguear",
    "trasgueávamo": "trasguear",
    "trasgueávamos": "trasguear",
    "trasgueáveis": "trasguear",
    "traslada": "trasladar",
    "trasladada": "trasladar",
    "trasladadas": "trasladar",
    "trasladado": "trasladar",
    "trasladadora": "trasladador",
    "trasladadoras": "trasladador",
    "trasladadores": "trasladador",
    "trasladados": "trasladar",
    "trasladai": "trasladar",
    "trasladais": "trasladar",
    "trasladam": "trasladar",
    "trasladamo": "trasladar",
    "trasladamos": "trasladar",
    "trasladando": "trasladar",
    "trasladara": "trasladar",
    "trasladaram": "trasladar",
    "trasladaras": "trasladar",
    "trasladarde": "trasladar",
    "trasladardes": "trasladar",
    "trasladare": "trasladar",
    "trasladarei": "trasladar",
    "trasladareis": "trasladar",
    "trasladarem": "trasladar",
    "trasladaremos": "trasladar",
    "trasladares": "trasladar",
    "trasladaria": "trasladar",
    "trasladariam": "trasladar",
    "trasladarias": "trasladar",
    "trasladarmo": "trasladar",
    "trasladarmos": "trasladar",
    "trasladará": "trasladar",
    "trasladarás": "trasladar",
    "trasladarão": "trasladar",
    "trasladaríamos": "trasladar",
    "trasladaríeis": "trasladar",
    "trasladas": "trasladar",
    "trasladasse": "trasladar",
    "trasladassem": "trasladar",
    "trasladasses": "trasladar",
    "trasladaste": "trasladar",
    "trasladastes": "trasladar",
    "trasladava": "trasladar",
    "trasladavam": "trasladar",
    "trasladavas": "trasladar",
    "trasladações": "trasladação",
    "traslade": "trasladar",
    "trasladei": "trasladar",
    "trasladeis": "trasladar",
    "trasladem": "trasladar",
    "traslademo": "trasladar",
    "traslademos": "trasladar",
    "traslades": "trasladar",
    "traslado": "trasladar",
    "traslados": "traslado",
    "trasladou": "trasladar",
    "trasladá": "trasladar",
    "trasladámo": "trasladar",
    "trasladámos": "trasladar",
    "trasladáramo": "trasladar",
    "trasladáramos": "trasladar",
    "trasladárei": "trasladar",
    "trasladáreis": "trasladar",
    "trasladásseis": "trasladar",
    "trasladássemos": "trasladar",
    "trasladávamo": "trasladar",
    "trasladávamos": "trasladar",
    "trasladávei": "trasladar",
    "trasladáveis": "trasladável",
    "traslares": "traslar",
    "traslações": "traslação",
    "trasmonta": "trasmontar",
    "trasmontada": "trasmontar",
    "trasmontadas": "trasmontar",
    "trasmontado": "trasmontar",
    "trasmontados": "trasmontar",
    "trasmontai": "trasmontar",
    "trasmontais": "trasmontar",
    "trasmontam": "trasmontar",
    "trasmontamo": "trasmontar",
    "trasmontamos": "trasmontar",
    "trasmontana": "trasmontano",
    "trasmontanas": "trasmontano",
    "trasmontando": "trasmontar",
    "trasmontanismos": "trasmontanismo",
    "trasmontanos": "trasmontano",
    "trasmontara": "trasmontar",
    "trasmontaram": "trasmontar",
    "trasmontaras": "trasmontar",
    "trasmontardes": "trasmontar",
    "trasmontarei": "trasmontar",
    "trasmontareis": "trasmontar",
    "trasmontarem": "trasmontar",
    "trasmontaremos": "trasmontar",
    "trasmontares": "trasmontar",
    "trasmontaria": "trasmontar",
    "trasmontariam": "trasmontar",
    "trasmontarias": "trasmontar",
    "trasmontarmo": "trasmontar",
    "trasmontarmos": "trasmontar",
    "trasmontará": "trasmontar",
    "trasmontarás": "trasmontar",
    "trasmontarão": "trasmontar",
    "trasmontaríamos": "trasmontar",
    "trasmontaríeis": "trasmontar",
    "trasmontas": "trasmontar",
    "trasmontasse": "trasmontar",
    "trasmontassem": "trasmontar",
    "trasmontasses": "trasmontar",
    "trasmontaste": "trasmontar",
    "trasmontastes": "trasmontar",
    "trasmontava": "trasmontar",
    "trasmontavam": "trasmontar",
    "trasmontavas": "trasmontar",
    "trasmonte": "trasmontar",
    "trasmontei": "trasmontar",
    "trasmonteis": "trasmontar",
    "trasmontem": "trasmontar",
    "trasmontemo": "trasmontar",
    "trasmontemos": "trasmontar",
    "trasmontes": "trasmontar",
    "trasmonto": "trasmontar",
    "trasmontou": "trasmontar",
    "trasmontámo": "trasmontar",
    "trasmontámos": "trasmontar",
    "trasmontáramo": "trasmontar",
    "trasmontáramos": "trasmontar",
    "trasmontáreis": "trasmontar",
    "trasmontásseis": "trasmontar",
    "trasmontássemos": "trasmontar",
    "trasmontávamo": "trasmontar",
    "trasmontávamos": "trasmontar",
    "trasmontáveis": "trasmontar",
    "trasmuda": "trasmudar",
    "trasmudada": "trasmudar",
    "trasmudadas": "trasmudar",
    "trasmudado": "trasmudar",
    "trasmudados": "trasmudar",
    "trasmudai": "trasmudar",
    "trasmudais": "trasmudar",
    "trasmudam": "trasmudar",
    "trasmudamo": "trasmudar",
    "trasmudamos": "trasmudar",
    "trasmudando": "trasmudar",
    "trasmudara": "trasmudar",
    "trasmudaram": "trasmudar",
    "trasmudaras": "trasmudar",
    "trasmudarde": "trasmudar",
    "trasmudardes": "trasmudar",
    "trasmudare": "trasmudar",
    "trasmudarei": "trasmudar",
    "trasmudareis": "trasmudar",
    "trasmudarem": "trasmudar",
    "trasmudaremos": "trasmudar",
    "trasmudares": "trasmudar",
    "trasmudaria": "trasmudar",
    "trasmudariam": "trasmudar",
    "trasmudarias": "trasmudar",
    "trasmudarmo": "trasmudar",
    "trasmudarmos": "trasmudar",
    "trasmudará": "trasmudar",
    "trasmudarás": "trasmudar",
    "trasmudarão": "trasmudar",
    "trasmudaríamos": "trasmudar",
    "trasmudaríeis": "trasmudar",
    "trasmudas": "trasmudar",
    "trasmudasse": "trasmudar",
    "trasmudassem": "trasmudar",
    "trasmudasses": "trasmudar",
    "trasmudaste": "trasmudar",
    "trasmudastes": "trasmudar",
    "trasmudava": "trasmudar",
    "trasmudavam": "trasmudar",
    "trasmudavas": "trasmudar",
    "trasmude": "trasmudar",
    "trasmudei": "trasmudar",
    "trasmudeis": "trasmudar",
    "trasmudem": "trasmudar",
    "trasmudemo": "trasmudar",
    "trasmudemos": "trasmudar",
    "trasmudes": "trasmudar",
    "trasmudo": "trasmudar",
    "trasmudou": "trasmudar",
    "trasmudá": "trasmudar",
    "trasmudámo": "trasmudar",
    "trasmudámos": "trasmudar",
    "trasmudáramo": "trasmudar",
    "trasmudáramos": "trasmudar",
    "trasmudárei": "trasmudar",
    "trasmudáreis": "trasmudar",
    "trasmudásseis": "trasmudar",
    "trasmudássemos": "trasmudar",
    "trasmudávamo": "trasmudar",
    "trasmudávamos": "trasmudar",
    "trasmudávei": "trasmudar",
    "trasmudáveis": "trasmudar",
    "trasorelhos": "trasorelho",
    "traspassa": "traspassar",
    "traspassada": "traspassar",
    "traspassadas": "traspassar",
    "traspassado": "traspassar",
    "traspassados": "traspassar",
    "traspassai": "traspassar",
    "traspassais": "traspassar",
    "traspassam": "traspassar",
    "traspassamentos": "traspassamento",
    "traspassamo": "traspassar",
    "traspassamos": "traspassar",
    "traspassando": "traspassar",
    "traspassara": "traspassar",
    "traspassaram": "traspassar",
    "traspassaras": "traspassar",
    "traspassarde": "traspassar",
    "traspassardes": "traspassar",
    "traspassare": "traspassar",
    "traspassarei": "traspassar",
    "traspassareis": "traspassar",
    "traspassarem": "traspassar",
    "traspassaremos": "traspassar",
    "traspassares": "traspassar",
    "traspassaria": "traspassar",
    "traspassariam": "traspassar",
    "traspassarias": "traspassar",
    "traspassarmo": "traspassar",
    "traspassarmos": "traspassar",
    "traspassará": "traspassar",
    "traspassarás": "traspassar",
    "traspassarão": "traspassar",
    "traspassaríamos": "traspassar",
    "traspassaríeis": "traspassar",
    "traspassas": "traspassar",
    "traspassasse": "traspassar",
    "traspassassem": "traspassar",
    "traspassasses": "traspassar",
    "traspassaste": "traspassar",
    "traspassastes": "traspassar",
    "traspassava": "traspassar",
    "traspassavam": "traspassar",
    "traspassavas": "traspassar",
    "traspassações": "traspassação",
    "traspasse": "traspassar",
    "traspassei": "traspassar",
    "traspasseis": "traspassar",
    "traspassem": "traspassar",
    "traspassemo": "traspassar",
    "traspassemos": "traspassar",
    "traspasses": "traspasse",
    "traspasso": "traspassar",
    "traspassos": "traspasso",
    "traspassou": "traspassar",
    "traspassá": "traspassar",
    "traspassámo": "traspassar",
    "traspassámos": "traspassar",
    "traspassáramo": "traspassar",
    "traspassáramos": "traspassar",
    "traspassárei": "traspassar",
    "traspassáreis": "traspassar",
    "traspassásseis": "traspassar",
    "traspassássemos": "traspassar",
    "traspassávamo": "traspassar",
    "traspassávamos": "traspassar",
    "traspassávei": "traspassar",
    "traspassáveis": "traspassar",
    "traspilares": "traspilar",
    "traspomo": "traspor",
    "traspomos": "traspor",
    "trasponde": "traspor",
    "traspondes": "traspor",
    "traspondo": "traspor",
    "trasponha": "traspor",
    "trasponhais": "traspor",
    "trasponham": "traspor",
    "trasponhamo": "traspor",
    "trasponhamos": "traspor",
    "trasponhas": "traspor",
    "trasponho": "traspor",
    "trasporde": "traspor",
    "traspordes": "traspor",
    "traspore": "traspor",
    "trasporei": "traspor",
    "trasporeis": "traspor",
    "trasporem": "traspor",
    "trasporemos": "traspor",
    "traspores": "traspor",
    "trasporia": "traspor",
    "trasporiam": "traspor",
    "trasporias": "traspor",
    "traspormo": "traspor",
    "traspormos": "traspor",
    "trasporá": "traspor",
    "trasporás": "traspor",
    "trasporão": "traspor",
    "trasporíamos": "traspor",
    "trasporíeis": "traspor",
    "trasposta": "traspor",
    "traspostas": "traspor",
    "trasposto": "traspor",
    "traspostos": "traspor",
    "traspunha": "traspor",
    "traspunham": "traspor",
    "traspunhas": "traspor",
    "traspus": "traspor",
    "traspusemo": "traspor",
    "traspusemos": "traspor",
    "traspuser": "traspor",
    "traspusera": "traspor",
    "traspuseram": "traspor",
    "traspuseras": "traspor",
    "traspuserdes": "traspor",
    "traspuserem": "traspor",
    "traspuseres": "traspor",
    "traspusermos": "traspor",
    "traspusesse": "traspor",
    "traspusessem": "traspor",
    "traspusesses": "traspor",
    "traspuseste": "traspor",
    "traspusestes": "traspor",
    "traspuséramo": "traspor",
    "traspuséramos": "traspor",
    "traspusérei": "traspor",
    "traspuséreis": "traspor",
    "traspusésseis": "traspor",
    "traspuséssemos": "traspor",
    "traspô": "traspor",
    "traspôs": "traspor",
    "traspõe": "traspor",
    "traspõem": "traspor",
    "traspões": "traspor",
    "traspúnhamo": "traspor",
    "traspúnhamos": "traspor",
    "traspúnhei": "traspor",
    "traspúnheis": "traspor",
    "trastadas": "trastada",
    "trastagana": "trastagano",
    "trastaganas": "trastagano",
    "trastaganos": "trastagano",
    "trastalhadas": "trastalhada",
    "trastalhona": "trastalhão",
    "trastalhonas": "trastalhão",
    "trastalhões": "trastalhão",
    "trastarias": "trastaria",
    "trasteada": "trastear",
    "trasteadas": "trastear",
    "trasteado": "trastear",
    "trasteados": "trastear",
    "trasteai": "trastear",
    "trasteais": "trastear",
    "trasteamo": "trastear",
    "trasteamos": "trastear",
    "trasteando": "trastear",
    "trasteara": "trastear",
    "trastearam": "trastear",
    "trastearas": "trastear",
    "trastearde": "trastear",
    "trasteardes": "trastear",
    "trasteare": "trastear",
    "trastearei": "trastear",
    "trasteareis": "trastear",
    "trastearem": "trastear",
    "trastearemos": "trastear",
    "trasteares": "trastear",
    "trastearia": "trastear",
    "trasteariam": "trastear",
    "trastearias": "trastear",
    "trastearmo": "trastear",
    "trastearmos": "trastear",
    "trasteará": "trastear",
    "trastearás": "trastear",
    "trastearão": "trastear",
    "trastearíamos": "trastear",
    "trastearíeis": "trastear",
    "trasteasse": "trastear",
    "trasteassem": "trastear",
    "trasteasses": "trastear",
    "trasteaste": "trastear",
    "trasteastes": "trastear",
    "trasteava": "trastear",
    "trasteavam": "trastear",
    "trasteavas": "trastear",
    "trasteei": "trastear",
    "trasteeis": "trastear",
    "trasteemo": "trastear",
    "trasteemos": "trastear",
    "trasteia": "trastear",
    "trasteiam": "trastear",
    "trasteias": "trastear",
    "trasteie": "trastear",
    "trasteiem": "trastear",
    "trasteies": "trastear",
    "trasteio": "trastear",
    "trasteios": "trasteio",
    "trasteja": "trastejar",
    "trastejada": "trastejar",
    "trastejadas": "trastejar",
    "trastejado": "trastejar",
    "trastejados": "trastejar",
    "trastejai": "trastejar",
    "trastejais": "trastejar",
    "trastejam": "trastejar",
    "trastejamo": "trastejar",
    "trastejamos": "trastejar",
    "trastejando": "trastejar",
    "trastejara": "trastejar",
    "trastejaram": "trastejar",
    "trastejaras": "trastejar",
    "trastejardes": "trastejar",
    "trastejarei": "trastejar",
    "trastejareis": "trastejar",
    "trastejarem": "trastejar",
    "trastejaremos": "trastejar",
    "trastejares": "trastejar",
    "trastejaria": "trastejar",
    "trastejariam": "trastejar",
    "trastejarias": "trastejar",
    "trastejarmo": "trastejar",
    "trastejarmos": "trastejar",
    "trastejará": "trastejar",
    "trastejarás": "trastejar",
    "trastejarão": "trastejar",
    "trastejaríamos": "trastejar",
    "trastejaríeis": "trastejar",
    "trastejas": "trastejar",
    "trastejasse": "trastejar",
    "trastejassem": "trastejar",
    "trastejasses": "trastejar",
    "trastejaste": "trastejar",
    "trastejastes": "trastejar",
    "trastejava": "trastejar",
    "trastejavam": "trastejar",
    "trastejavas": "trastejar",
    "trasteje": "trastejar",
    "trastejei": "trastejar",
    "trastejeis": "trastejar",
    "trastejem": "trastejar",
    "trastejemo": "trastejar",
    "trastejemos": "trastejar",
    "trastejes": "trastejar",
    "trastejo": "trastejar",
    "trastejou": "trastejar",
    "trastejámo": "trastejar",
    "trastejámos": "trastejar",
    "trastejáramo": "trastejar",
    "trastejáramos": "trastejar",
    "trastejáreis": "trastejar",
    "trastejásseis": "trastejar",
    "trastejássemos": "trastejar",
    "trastejávamo": "trastejar",
    "trastejávamos": "trastejar",
    "trastejáveis": "trastejar",
    "trastempa": "trastempar",
    "trastempada": "trastempar",
    "trastempadas": "trastempar",
    "trastempado": "trastempar",
    "trastempados": "trastempar",
    "trastempai": "trastempar",
    "trastempais": "trastempar",
    "trastempam": "trastempar",
    "trastempamo": "trastempar",
    "trastempamos": "trastempar",
    "trastempando": "trastempar",
    "trastempara": "trastempar",
    "trastemparam": "trastempar",
    "trastemparas": "trastempar",
    "trastempardes": "trastempar",
    "trastemparei": "trastempar",
    "trastempareis": "trastempar",
    "trastemparem": "trastempar",
    "trastemparemos": "trastempar",
    "trastempares": "trastempar",
    "trastemparia": "trastempar",
    "trastempariam": "trastempar",
    "trastemparias": "trastempar",
    "trastemparmo": "trastempar",
    "trastemparmos": "trastempar",
    "trastempará": "trastempar",
    "trastemparás": "trastempar",
    "trastemparão": "trastempar",
    "trastemparíamos": "trastempar",
    "trastemparíeis": "trastempar",
    "trastempas": "trastempar",
    "trastempasse": "trastempar",
    "trastempassem": "trastempar",
    "trastempasses": "trastempar",
    "trastempaste": "trastempar",
    "trastempastes": "trastempar",
    "trastempava": "trastempar",
    "trastempavam": "trastempar",
    "trastempavas": "trastempar",
    "trastempe": "trastempar",
    "trastempei": "trastempar",
    "trastempeis": "trastempar",
    "trastempem": "trastempar",
    "trastempemo": "trastempar",
    "trastempemos": "trastempar",
    "trastempes": "trastempar",
    "trastempo": "trastempar",
    "trastempos": "trastempo",
    "trastempou": "trastempar",
    "trastempámo": "trastempar",
    "trastempámos": "trastempar",
    "trastempáramo": "trastempar",
    "trastempáramos": "trastempar",
    "trastempáreis": "trastempar",
    "trastempásseis": "trastempar",
    "trastempássemos": "trastempar",
    "trastempávamo": "trastempar",
    "trastempávamos": "trastempar",
    "trastempáveis": "trastempar",
    "trasteou": "trastear",
    "trastes": "traste",
    "trasteá": "trastear",
    "trasteámo": "trastear",
    "trasteámos": "trastear",
    "trasteáramo": "trastear",
    "trasteáramos": "trastear",
    "trasteárei": "trastear",
    "trasteáreis": "trastear",
    "trasteásseis": "trastear",
    "trasteássemos": "trastear",
    "trasteávamo": "trastear",
    "trasteávamos": "trastear",
    "trasteávei": "trastear",
    "trasteáveis": "trastear",
    "trastorna": "trastornar",
    "trastornada": "trastornar",
    "trastornadas": "trastornar",
    "trastornado": "trastornar",
    "trastornados": "trastornar",
    "trastornai": "trastornar",
    "trastornais": "trastornar",
    "trastornam": "trastornar",
    "trastornamo": "trastornar",
    "trastornamos": "trastornar",
    "trastornando": "trastornar",
    "trastornara": "trastornar",
    "trastornaram": "trastornar",
    "trastornaras": "trastornar",
    "trastornarde": "trastornar",
    "trastornardes": "trastornar",
    "trastornare": "trastornar",
    "trastornarei": "trastornar",
    "trastornareis": "trastornar",
    "trastornarem": "trastornar",
    "trastornaremos": "trastornar",
    "trastornares": "trastornar",
    "trastornaria": "trastornar",
    "trastornariam": "trastornar",
    "trastornarias": "trastornar",
    "trastornarmo": "trastornar",
    "trastornarmos": "trastornar",
    "trastornará": "trastornar",
    "trastornarás": "trastornar",
    "trastornarão": "trastornar",
    "trastornaríamos": "trastornar",
    "trastornaríeis": "trastornar",
    "trastornas": "trastornar",
    "trastornasse": "trastornar",
    "trastornassem": "trastornar",
    "trastornasses": "trastornar",
    "trastornaste": "trastornar",
    "trastornastes": "trastornar",
    "trastornava": "trastornar",
    "trastornavam": "trastornar",
    "trastornavas": "trastornar",
    "trastorne": "trastornar",
    "trastornei": "trastornar",
    "trastorneis": "trastornar",
    "trastornem": "trastornar",
    "trastornemo": "trastornar",
    "trastornemos": "trastornar",
    "trastornes": "trastornar",
    "trastorno": "trastornar",
    "trastornou": "trastornar",
    "trastorná": "trastornar",
    "trastornámo": "trastornar",
    "trastornámos": "trastornar",
    "trastornáramo": "trastornar",
    "trastornáramos": "trastornar",
    "trastornárei": "trastornar",
    "trastornáreis": "trastornar",
    "trastornásseis": "trastornar",
    "trastornássemos": "trastornar",
    "trastornávamo": "trastornar",
    "trastornávamos": "trastornar",
    "trastornávei": "trastornar",
    "trastornáveis": "trastornar",
    "trastos": "trasto",
    "trasvaza": "trasvazar",
    "trasvazada": "trasvazar",
    "trasvazadas": "trasvazar",
    "trasvazado": "trasvazar",
    "trasvazados": "trasvazar",
    "trasvazai": "trasvazar",
    "trasvazais": "trasvazar",
    "trasvazam": "trasvazar",
    "trasvazamo": "trasvazar",
    "trasvazamos": "trasvazar",
    "trasvazando": "trasvazar",
    "trasvazara": "trasvazar",
    "trasvazaram": "trasvazar",
    "trasvazaras": "trasvazar",
    "trasvazarde": "trasvazar",
    "trasvazardes": "trasvazar",
    "trasvazare": "trasvazar",
    "trasvazarei": "trasvazar",
    "trasvazareis": "trasvazar",
    "trasvazarem": "trasvazar",
    "trasvazaremos": "trasvazar",
    "trasvazares": "trasvazar",
    "trasvazaria": "trasvazar",
    "trasvazariam": "trasvazar",
    "trasvazarias": "trasvazar",
    "trasvazarmo": "trasvazar",
    "trasvazarmos": "trasvazar",
    "trasvazará": "trasvazar",
    "trasvazarás": "trasvazar",
    "trasvazarão": "trasvazar",
    "trasvazaríamos": "trasvazar",
    "trasvazaríeis": "trasvazar",
    "trasvazas": "trasvazar",
    "trasvazasse": "trasvazar",
    "trasvazassem": "trasvazar",
    "trasvazasses": "trasvazar",
    "trasvazaste": "trasvazar",
    "trasvazastes": "trasvazar",
    "trasvazava": "trasvazar",
    "trasvazavam": "trasvazar",
    "trasvazavas": "trasvazar",
    "trasvaze": "trasvazar",
    "trasvazei": "trasvazar",
    "trasvazeis": "trasvazar",
    "trasvazem": "trasvazar",
    "trasvazemo": "trasvazar",
    "trasvazemos": "trasvazar",
    "trasvazes": "trasvazar",
    "trasvazo": "trasvazar",
    "trasvazou": "trasvazar",
    "trasvazá": "trasvazar",
    "trasvazámo": "trasvazar",
    "trasvazámos": "trasvazar",
    "trasvazáramo": "trasvazar",
    "trasvazáramos": "trasvazar",
    "trasvazárei": "trasvazar",
    "trasvazáreis": "trasvazar",
    "trasvazásseis": "trasvazar",
    "trasvazássemos": "trasvazar",
    "trasvazávamo": "trasvazar",
    "trasvazávamos": "trasvazar",
    "trasvazávei": "trasvazar",
    "trasvazáveis": "trasvazar",
    "trasveste": "trasvestir",
    "trasvestem": "trasvestir",
    "trasvestes": "trasvestir",
    "trasvesti": "trasvestir",
    "trasvestia": "trasvestir",
    "trasvestiam": "trasvestir",
    "trasvestias": "trasvestir",
    "trasvestida": "trasvestir",
    "trasvestidas": "trasvestir",
    "trasvestido": "trasvestir",
    "trasvestidos": "trasvestir",
    "trasvestimo": "trasvestir",
    "trasvestimos": "trasvestir",
    "trasvestindo": "trasvestir",
    "trasvestira": "trasvestir",
    "trasvestiram": "trasvestir",
    "trasvestiras": "trasvestir",
    "trasvestirde": "trasvestir",
    "trasvestirdes": "trasvestir",
    "trasvestire": "trasvestir",
    "trasvestirei": "trasvestir",
    "trasvestireis": "trasvestir",
    "trasvestirem": "trasvestir",
    "trasvestiremos": "trasvestir",
    "trasvestires": "trasvestir",
    "trasvestiria": "trasvestir",
    "trasvestiriam": "trasvestir",
    "trasvestirias": "trasvestir",
    "trasvestirmo": "trasvestir",
    "trasvestirmos": "trasvestir",
    "trasvestirá": "trasvestir",
    "trasvestirás": "trasvestir",
    "trasvestirão": "trasvestir",
    "trasvestiríamos": "trasvestir",
    "trasvestiríeis": "trasvestir",
    "trasvestis": "trasvestir",
    "trasvestisse": "trasvestir",
    "trasvestissem": "trasvestir",
    "trasvestisses": "trasvestir",
    "trasvestiste": "trasvestir",
    "trasvestistes": "trasvestir",
    "trasvestiu": "trasvestir",
    "trasvestíamo": "trasvestir",
    "trasvestíamos": "trasvestir",
    "trasvestíei": "trasvestir",
    "trasvestíeis": "trasvestir",
    "trasvestíramo": "trasvestir",
    "trasvestíramos": "trasvestir",
    "trasvestírei": "trasvestir",
    "trasvestíreis": "trasvestir",
    "trasvestísseis": "trasvestir",
    "trasvestíssemos": "trasvestir",
    "trasvista": "trasvisto",
    "trasvistais": "trasvestir",
    "trasvistam": "trasvestir",
    "trasvistamo": "trasvestir",
    "trasvistamos": "trasvestir",
    "trasvistas": "trasvisto",
    "trasvisto": "trasvestir",
    "trasvistos": "trasvisto",
    "trata": "tratar",
    "tratada": "tratar",
    "tratadas": "tratar",
    "tratadinha": "tratado",
    "tratadinhas": "tratado",
    "tratadinho": "tratado",
    "tratadinhos": "tratado",
    "tratadistas": "tratadista",
    "tratadita": "tratado",
    "trataditas": "tratado",
    "tratadito": "tratado",
    "trataditos": "tratado",
    "tratado": "tratar",
    "tratadora": "tratador",
    "tratadoras": "tratador",
    "tratadores": "tratador",
    "tratados": "tratar",
    "tratadíssima": "tratado",
    "tratadíssimas": "tratado",
    "tratadíssimo": "tratado",
    "tratadíssimos": "tratado",
    "tratadística": "tratadístico",
    "tratadísticas": "tratadístico",
    "tratadísticos": "tratadístico",
    "tratai": "tratar",
    "tratais": "tratar",
    "tratam": "tratar",
    "tratamentos": "tratamento",
    "tratamo": "tratar",
    "tratamos": "tratar",
    "tratando": "tratar",
    "tratantadas": "tratantada",
    "tratanteada": "tratantear",
    "tratanteadas": "tratantear",
    "tratanteado": "tratantear",
    "tratanteados": "tratantear",
    "tratanteai": "tratantear",
    "tratanteais": "tratantear",
    "tratanteamo": "tratantear",
    "tratanteamos": "tratantear",
    "tratanteando": "tratantear",
    "tratanteara": "tratantear",
    "tratantearam": "tratantear",
    "tratantearas": "tratantear",
    "tratanteardes": "tratantear",
    "tratantearei": "tratantear",
    "tratanteareis": "tratantear",
    "tratantearem": "tratantear",
    "tratantearemos": "tratantear",
    "tratanteares": "tratantear",
    "tratantearia": "tratantear",
    "tratanteariam": "tratantear",
    "tratantearias": "tratantear",
    "tratantearmo": "tratantear",
    "tratantearmos": "tratantear",
    "tratanteará": "tratantear",
    "tratantearás": "tratantear",
    "tratantearão": "tratantear",
    "tratantearíamos": "tratantear",
    "tratantearíeis": "tratantear",
    "tratanteasse": "tratantear",
    "tratanteassem": "tratantear",
    "tratanteasses": "tratantear",
    "tratanteaste": "tratantear",
    "tratanteastes": "tratantear",
    "tratanteava": "tratantear",
    "tratanteavam": "tratantear",
    "tratanteavas": "tratantear",
    "tratanteei": "tratantear",
    "tratanteeis": "tratantear",
    "tratanteemo": "tratantear",
    "tratanteemos": "tratantear",
    "tratanteia": "tratantear",
    "tratanteiam": "tratantear",
    "tratanteias": "tratantear",
    "tratanteie": "tratantear",
    "tratanteiem": "tratantear",
    "tratanteies": "tratantear",
    "tratanteio": "tratantear",
    "tratanteou": "tratantear",
    "tratantes": "tratante",
    "tratanteámo": "tratantear",
    "tratanteámos": "tratantear",
    "tratanteáramo": "tratantear",
    "tratanteáramos": "tratantear",
    "tratanteáreis": "tratantear",
    "tratanteásseis": "tratantear",
    "tratanteássemos": "tratantear",
    "tratanteávamo": "tratantear",
    "tratanteávamos": "tratantear",
    "tratanteáveis": "tratantear",
    "tratantices": "tratantice",
    "tratantória": "tratantório",
    "tratantórias": "tratantório",
    "tratantórios": "tratantório",
    "tratara": "tratar",
    "trataram": "tratar",
    "trataras": "tratar",
    "tratarde": "tratar",
    "tratardes": "tratar",
    "tratare": "tratar",
    "tratarei": "tratar",
    "tratareis": "tratar",
    "tratarem": "tratar",
    "trataremos": "tratar",
    "tratares": "tratar",
    "trataria": "tratar",
    "tratariam": "tratar",
    "tratarias": "tratar",
    "tratarmo": "tratar",
    "tratarmos": "tratar",
    "tratará": "tratar",
    "tratarás": "tratar",
    "tratarão": "tratar",
    "trataríamos": "tratar",
    "trataríeis": "tratar",
    "tratas": "tratar",
    "tratasse": "tratar",
    "tratassem": "tratar",
    "tratasses": "tratar",
    "trataste": "tratar",
    "tratastes": "tratar",
    "tratava": "tratar",
    "tratavam": "tratar",
    "tratavas": "tratar",
    "trate": "tratar",
    "trateada": "tratear",
    "trateadas": "tratear",
    "trateado": "tratear",
    "trateados": "tratear",
    "trateai": "tratear",
    "trateais": "tratear",
    "trateamo": "tratear",
    "trateamos": "tratear",
    "trateando": "tratear",
    "trateara": "tratear",
    "tratearam": "tratear",
    "tratearas": "tratear",
    "tratearde": "tratear",
    "trateardes": "tratear",
    "trateare": "tratear",
    "tratearei": "tratear",
    "trateareis": "tratear",
    "tratearem": "tratear",
    "tratearemos": "tratear",
    "trateares": "tratear",
    "tratearia": "tratear",
    "trateariam": "tratear",
    "tratearias": "tratear",
    "tratearmo": "tratear",
    "tratearmos": "tratear",
    "trateará": "tratear",
    "tratearás": "tratear",
    "tratearão": "tratear",
    "tratearíamos": "tratear",
    "tratearíeis": "tratear",
    "trateasse": "tratear",
    "trateassem": "tratear",
    "trateasses": "tratear",
    "trateaste": "tratear",
    "trateastes": "tratear",
    "trateava": "tratear",
    "trateavam": "tratear",
    "trateavas": "tratear",
    "trateei": "tratear",
    "trateeis": "tratear",
    "trateemo": "tratear",
    "trateemos": "tratear",
    "tratei": "tratar",
    "trateia": "tratear",
    "trateiam": "tratear",
    "trateias": "tratear",
    "trateie": "tratear",
    "trateiem": "tratear",
    "trateies": "tratear",
    "trateio": "tratear",
    "trateis": "tratar",
    "tratem": "tratar",
    "tratemo": "tratar",
    "tratemos": "tratar",
    "trateou": "tratear",
    "trates": "tratar",
    "trateá": "tratear",
    "trateámo": "tratear",
    "trateámos": "tratear",
    "trateáramo": "tratear",
    "trateáramos": "tratear",
    "trateárei": "tratear",
    "trateáreis": "tratear",
    "trateásseis": "tratear",
    "trateássemos": "tratear",
    "trateávamo": "tratear",
    "trateávamos": "tratear",
    "trateávei": "tratear",
    "trateáveis": "tratear",
    "trato": "tratar",
    "tratos": "trato",
    "tratou": "tratar",
    "tratrados": "tratrado",
    "tratá": "tratar",
    "tratámo": "tratar",
    "tratámos": "tratar",
    "tratáramo": "tratar",
    "tratáramos": "tratar",
    "tratárei": "tratar",
    "tratáreis": "tratar",
    "tratásseis": "tratar",
    "tratássemos": "tratar",
    "tratávamo": "tratar",
    "tratávamos": "tratar",
    "tratávei": "tratar",
    "tratáveis": "tratável",
    "traulitadas": "traulitada",
    "trauliteira": "trauliteiro",
    "trauliteiras": "trauliteiro",
    "trauliteiros": "trauliteiro",
    "traulitos": "traulito",
    "traulitânias": "traulitânia",
    "traumas": "trauma",
    "traumatismos": "traumatismo",
    "traumatiza": "traumatizar",
    "traumatizada": "traumatizar",
    "traumatizadas": "traumatizar",
    "traumatizado": "traumatizar",
    "traumatizados": "traumatizar",
    "traumatizai": "traumatizar",
    "traumatizais": "traumatizar",
    "traumatizam": "traumatizar",
    "traumatizamo": "traumatizar",
    "traumatizamos": "traumatizar",
    "traumatizando": "traumatizar",
    "traumatizantes": "traumatizante",
    "traumatizara": "traumatizar",
    "traumatizaram": "traumatizar",
    "traumatizaras": "traumatizar",
    "traumatizarde": "traumatizar",
    "traumatizardes": "traumatizar",
    "traumatizare": "traumatizar",
    "traumatizarei": "traumatizar",
    "traumatizareis": "traumatizar",
    "traumatizarem": "traumatizar",
    "traumatizaremos": "traumatizar",
    "traumatizares": "traumatizar",
    "traumatizaria": "traumatizar",
    "traumatizariam": "traumatizar",
    "traumatizarias": "traumatizar",
    "traumatizarmo": "traumatizar",
    "traumatizarmos": "traumatizar",
    "traumatizará": "traumatizar",
    "traumatizarás": "traumatizar",
    "traumatizarão": "traumatizar",
    "traumatizaríamos": "traumatizar",
    "traumatizaríeis": "traumatizar",
    "traumatizas": "traumatizar",
    "traumatizasse": "traumatizar",
    "traumatizassem": "traumatizar",
    "traumatizasses": "traumatizar",
    "traumatizaste": "traumatizar",
    "traumatizastes": "traumatizar",
    "traumatizava": "traumatizar",
    "traumatizavam": "traumatizar",
    "traumatizavas": "traumatizar",
    "traumatize": "traumatizar",
    "traumatizei": "traumatizar",
    "traumatizeis": "traumatizar",
    "traumatizem": "traumatizar",
    "traumatizemo": "traumatizar",
    "traumatizemos": "traumatizar",
    "traumatizes": "traumatizar",
    "traumatizo": "traumatizar",
    "traumatizou": "traumatizar",
    "traumatizá": "traumatizar",
    "traumatizámo": "traumatizar",
    "traumatizámos": "traumatizar",
    "traumatizáramo": "traumatizar",
    "traumatizáramos": "traumatizar",
    "traumatizárei": "traumatizar",
    "traumatizáreis": "traumatizar",
    "traumatizásseis": "traumatizar",
    "traumatizássemos": "traumatizar",
    "traumatizávamo": "traumatizar",
    "traumatizávamos": "traumatizar",
    "traumatizávei": "traumatizar",
    "traumatizáveis": "traumatizar",
    "traumatologias": "traumatologia",
    "traumatológica": "traumatológico",
    "traumatológicas": "traumatológico",
    "traumatológicos": "traumatológico",
    "traumática": "traumático",
    "traumáticas": "traumático",
    "traumáticos": "traumático",
    "traupídeos": "traupídeo",
    "trautas": "trauta",
    "trauteada": "trautear",
    "trauteadas": "trautear",
    "trauteado": "trautear",
    "trauteados": "trautear",
    "trauteai": "trautear",
    "trauteais": "trautear",
    "trauteamo": "trautear",
    "trauteamos": "trautear",
    "trauteando": "trautear",
    "trauteara": "trautear",
    "trautearam": "trautear",
    "trautearas": "trautear",
    "trautearde": "trautear",
    "trauteardes": "trautear",
    "trauteare": "trautear",
    "trautearei": "trautear",
    "trauteareis": "trautear",
    "trautearem": "trautear",
    "trautearemos": "trautear",
    "trauteares": "trautear",
    "trautearia": "trautear",
    "trauteariam": "trautear",
    "trautearias": "trautear",
    "trautearmo": "trautear",
    "trautearmos": "trautear",
    "trauteará": "trautear",
    "trautearás": "trautear",
    "trautearão": "trautear",
    "trautearíamos": "trautear",
    "trautearíeis": "trautear",
    "trauteasse": "trautear",
    "trauteassem": "trautear",
    "trauteasses": "trautear",
    "trauteaste": "trautear",
    "trauteastes": "trautear",
    "trauteava": "trautear",
    "trauteavam": "trautear",
    "trauteavas": "trautear",
    "trauteei": "trautear",
    "trauteeis": "trautear",
    "trauteemo": "trautear",
    "trauteemos": "trautear",
    "trauteia": "trautear",
    "trauteiam": "trautear",
    "trauteias": "trautear",
    "trauteie": "trautear",
    "trauteiem": "trautear",
    "trauteies": "trautear",
    "trauteio": "trautear",
    "trauteios": "trauteio",
    "trauteou": "trautear",
    "trauteá": "trautear",
    "trauteámo": "trautear",
    "trauteámos": "trautear",
    "trauteáramo": "trautear",
    "trauteáramos": "trautear",
    "trauteárei": "trautear",
    "trauteáreis": "trautear",
    "trauteásseis": "trautear",
    "trauteássemos": "trautear",
    "trauteávamo": "trautear",
    "trauteávamos": "trautear",
    "trauteávei": "trautear",
    "trauteáveis": "trautear",
    "trava": "travar",
    "travada": "travar",
    "travadas": "travar",
    "travadeira": "travador",
    "travadeiras": "travador",
    "travadinha": "travado",
    "travadinhas": "travado",
    "travadinho": "travado",
    "travadinhos": "travado",
    "travadita": "travado",
    "travaditas": "travado",
    "travadito": "travado",
    "travaditos": "travado",
    "travado": "travar",
    "travadoira": "travadoiro",
    "travadoiras": "travadoiro",
    "travadoiros": "travadoiro",
    "travadora": "travador",
    "travadoras": "travador",
    "travadores": "travador",
    "travados": "travar",
    "travadoura": "travadouro",
    "travadouras": "travadouro",
    "travadouros": "travadouro",
    "travaduras": "travadura",
    "travadíssima": "travado",
    "travadíssimas": "travado",
    "travadíssimo": "travado",
    "travadíssimos": "travado",
    "travagens": "travagem",
    "travai": "travar",
    "travais": "travar",
    "travam": "travar",
    "travamentos": "travamento",
    "travamo": "travar",
    "travamos": "travar",
    "travancas": "travanca",
    "travancos": "travanco",
    "travando": "travar",
    "travara": "travar",
    "travaram": "travar",
    "travaras": "travar",
    "travarde": "travar",
    "travardes": "travar",
    "travare": "travar",
    "travarei": "travar",
    "travareis": "travar",
    "travarem": "travar",
    "travaremos": "travar",
    "travares": "travar",
    "travaria": "travar",
    "travariam": "travar",
    "travarias": "travar",
    "travarmo": "travar",
    "travarmos": "travar",
    "travará": "travar",
    "travarás": "travar",
    "travarão": "travar",
    "travaríamos": "travar",
    "travaríeis": "travar",
    "travas": "travar",
    "travasse": "travar",
    "travassem": "travar",
    "travasses": "travar",
    "travaste": "travar",
    "travastes": "travar",
    "travava": "travar",
    "travavam": "travar",
    "travavas": "travar",
    "trave": "travar",
    "travei": "travar",
    "traveis": "travar",
    "traveja": "travejar",
    "travejada": "travejar",
    "travejadas": "travejar",
    "travejado": "travejar",
    "travejados": "travejar",
    "travejai": "travejar",
    "travejais": "travejar",
    "travejam": "travejar",
    "travejamentos": "travejamento",
    "travejamo": "travejar",
    "travejamos": "travejar",
    "travejando": "travejar",
    "travejara": "travejar",
    "travejaram": "travejar",
    "travejaras": "travejar",
    "travejarde": "travejar",
    "travejardes": "travejar",
    "travejare": "travejar",
    "travejarei": "travejar",
    "travejareis": "travejar",
    "travejarem": "travejar",
    "travejaremos": "travejar",
    "travejares": "travejar",
    "travejaria": "travejar",
    "travejariam": "travejar",
    "travejarias": "travejar",
    "travejarmo": "travejar",
    "travejarmos": "travejar",
    "travejará": "travejar",
    "travejarás": "travejar",
    "travejarão": "travejar",
    "travejaríamos": "travejar",
    "travejaríeis": "travejar",
    "travejas": "travejar",
    "travejasse": "travejar",
    "travejassem": "travejar",
    "travejasses": "travejar",
    "travejaste": "travejar",
    "travejastes": "travejar",
    "travejava": "travejar",
    "travejavam": "travejar",
    "travejavas": "travejar",
    "traveje": "travejar",
    "travejei": "travejar",
    "travejeis": "travejar",
    "travejem": "travejar",
    "travejemo": "travejar",
    "travejemos": "travejar",
    "travejes": "travejar",
    "travejo": "travejar",
    "travejou": "travejar",
    "travejá": "travejar",
    "travejámo": "travejar",
    "travejámos": "travejar",
    "travejáramo": "travejar",
    "travejáramos": "travejar",
    "travejárei": "travejar",
    "travejáreis": "travejar",
    "travejásseis": "travejar",
    "travejássemos": "travejar",
    "travejávamo": "travejar",
    "travejávamos": "travejar",
    "travejávei": "travejar",
    "travejáveis": "travejar",
    "travelas": "travela",
    "travelhos": "travelho",
    "travem": "travar",
    "travemo": "travar",
    "travemos": "travar",
    "traventa": "travento",
    "traventas": "travento",
    "traventos": "travento",
    "travertinos": "travertino",
    "traves": "trave",
    "travessa": "travesso",
    "travessada": "travessar",
    "travessadas": "travessar",
    "travessado": "travessar",
    "travessados": "travessar",
    "travessai": "travessar",
    "travessais": "travessar",
    "travessam": "travessar",
    "travessamo": "travessar",
    "travessamos": "travessar",
    "travessando": "travessar",
    "travessanhos": "travessanho",
    "travessara": "travessar",
    "travessaram": "travessar",
    "travessaras": "travessar",
    "travessarde": "travessar",
    "travessardes": "travessar",
    "travessare": "travessar",
    "travessarei": "travessar",
    "travessareis": "travessar",
    "travessarem": "travessar",
    "travessaremos": "travessar",
    "travessares": "travessar",
    "travessaria": "travessar",
    "travessariam": "travessar",
    "travessarias": "travessar",
    "travessarmo": "travessar",
    "travessarmos": "travessar",
    "travessará": "travessar",
    "travessarás": "travessar",
    "travessarão": "travessar",
    "travessaríamos": "travessar",
    "travessaríeis": "travessar",
    "travessas": "travesso",
    "travessasse": "travessar",
    "travessassem": "travessar",
    "travessasses": "travessar",
    "travessaste": "travessar",
    "travessastes": "travessar",
    "travessava": "travessar",
    "travessavam": "travessar",
    "travessavas": "travessar",
    "travesse": "travessar",
    "travesseada": "travessear",
    "travesseadas": "travessear",
    "travesseado": "travessear",
    "travesseados": "travessear",
    "travesseai": "travessear",
    "travesseais": "travessear",
    "travesseamo": "travessear",
    "travesseamos": "travessear",
    "travesseando": "travessear",
    "travesseara": "travessear",
    "travessearam": "travessear",
    "travessearas": "travessear",
    "travesseardes": "travessear",
    "travessearei": "travessear",
    "travesseareis": "travessear",
    "travessearem": "travessear",
    "travessearemos": "travessear",
    "travesseares": "travessear",
    "travessearia": "travessear",
    "travesseariam": "travessear",
    "travessearias": "travessear",
    "travessearmo": "travessear",
    "travessearmos": "travessear",
    "travesseará": "travessear",
    "travessearás": "travessear",
    "travessearão": "travessear",
    "travessearíamos": "travessear",
    "travessearíeis": "travessear",
    "travesseasse": "travessear",
    "travesseassem": "travessear",
    "travesseasses": "travessear",
    "travesseaste": "travessear",
    "travesseastes": "travessear",
    "travesseava": "travessear",
    "travesseavam": "travessear",
    "travesseavas": "travessear",
    "travesseei": "travessear",
    "travesseeis": "travessear",
    "travesseemo": "travessear",
    "travesseemos": "travessear",
    "travessei": "travessar",
    "travesseia": "travessear",
    "travesseiam": "travessear",
    "travesseias": "travessear",
    "travesseie": "travessear",
    "travesseiem": "travessear",
    "travesseies": "travessear",
    "travesseio": "travessear",
    "travesseiras": "travesseira",
    "travesseirinha": "travesseira",
    "travesseirinhas": "travesseira",
    "travesseirinho": "travesseiro",
    "travesseirinhos": "travesseiro",
    "travesseirita": "travesseira",
    "travesseiritas": "travesseira",
    "travesseirito": "travesseiro",
    "travesseiritos": "travesseiro",
    "travesseiros": "travesseiro",
    "travesseis": "travessar",
    "travessem": "travessar",
    "travessemo": "travessar",
    "travessemos": "travessar",
    "travesseou": "travessear",
    "travesses": "travessar",
    "travesseámo": "travessear",
    "travesseámos": "travessear",
    "travesseáramo": "travessear",
    "travesseáramos": "travessear",
    "travesseáreis": "travessear",
    "travesseásseis": "travessear",
    "travesseássemos": "travessear",
    "travesseávamo": "travessear",
    "travesseávamos": "travessear",
    "travesseáveis": "travessear",
    "travessias": "travessia",
    "travesso": "travessar",
    "travessona": "travessão",
    "travessonas": "travessão",
    "travessos": "travesso",
    "travessou": "travessar",
    "travessuras": "travessura",
    "travessá": "travessar",
    "travessámo": "travessar",
    "travessámos": "travessar",
    "travessáramo": "travessar",
    "travessáramos": "travessar",
    "travessárei": "travessar",
    "travessáreis": "travessar",
    "travessásseis": "travessar",
    "travessássemos": "travessar",
    "travessávamo": "travessar",
    "travessávamos": "travessar",
    "travessávei": "travessar",
    "travessáveis": "travessar",
    "travessões": "travessão",
    "traveste": "travestir",
    "travestem": "travestir",
    "travestes": "travestir",
    "travesti": "travestir",
    "travestia": "travestir",
    "travestiam": "travestir",
    "travestias": "travestir",
    "travestida": "travestir",
    "travestidas": "travestir",
    "travestido": "travestir",
    "travestidos": "travestir",
    "travestimo": "travestir",
    "travestimos": "travestir",
    "travestindo": "travestir",
    "travestira": "travestir",
    "travestiram": "travestir",
    "travestiras": "travestir",
    "travestirde": "travestir",
    "travestirdes": "travestir",
    "travestire": "travestir",
    "travestirei": "travestir",
    "travestireis": "travestir",
    "travestirem": "travestir",
    "travestiremos": "travestir",
    "travestires": "travestir",
    "travestiria": "travestir",
    "travestiriam": "travestir",
    "travestirias": "travestir",
    "travestirmo": "travestir",
    "travestirmos": "travestir",
    "travestirá": "travestir",
    "travestirás": "travestir",
    "travestirão": "travestir",
    "travestiríamos": "travestir",
    "travestiríeis": "travestir",
    "travestis": "travestir",
    "travestismos": "travestismo",
    "travestisse": "travestir",
    "travestissem": "travestir",
    "travestisses": "travestir",
    "travestiste": "travestir",
    "travestistes": "travestir",
    "travestiu": "travestir",
    "travestíamo": "travestir",
    "travestíamos": "travestir",
    "travestíei": "travestir",
    "travestíeis": "travestir",
    "travestíramo": "travestir",
    "travestíramos": "travestir",
    "travestírei": "travestir",
    "travestíreis": "travestir",
    "travestísseis": "travestir",
    "travestíssemos": "travestir",
    "traviais": "travial",
    "travias": "travia",
    "travincas": "travinca",
    "travista": "travestir",
    "travistais": "travestir",
    "travistam": "travestir",
    "travistamo": "travestir",
    "travistamos": "travestir",
    "travistas": "travestir",
    "travisto": "travestir",
    "travo": "travar",
    "travores": "travor",
    "travos": "travo",
    "travosa": "travoso",
    "travosas": "travoso",
    "travosos": "travoso",
    "travou": "travar",
    "travá": "travar",
    "travámo": "travar",
    "travámos": "travar",
    "traváramo": "travar",
    "traváramos": "travar",
    "travárei": "travar",
    "traváreis": "travar",
    "travásseis": "travar",
    "travássemos": "travar",
    "travávamo": "travar",
    "travávamos": "travar",
    "travávei": "travar",
    "traváveis": "travar",
    "travões": "travão",
    "traz": "trazer",
    "traze": "trazer",
    "trazedeira": "trazedeiro",
    "trazedeiras": "trazedeiro",
    "trazedeiros": "trazedeiro",
    "trazedora": "trazedor",
    "trazedoras": "trazedor",
    "trazedores": "trazedor",
    "trazei": "trazer",
    "trazeis": "trazer",
    "trazem": "trazer",
    "trazemo": "trazer",
    "trazemos": "trazer",
    "trazendo": "trazer",
    "trazerde": "trazer",
    "trazerdes": "trazer",
    "trazere": "trazer",
    "trazerem": "trazer",
    "trazeres": "trazer",
    "trazermo": "trazer",
    "trazermos": "trazer",
    "trazes": "trazer",
    "trazia": "trazer",
    "traziam": "trazer",
    "trazias": "trazer",
    "trazida": "trazido",
    "trazidas": "trazido",
    "trazido": "trazer",
    "trazidos": "trazido",
    "trazê": "trazer",
    "trazíamo": "trazer",
    "trazíamos": "trazer",
    "trazíei": "trazer",
    "trazíeis": "trazer",
    "traça": "traçar",
    "traçada": "traçar",
    "traçadas": "traçar",
    "traçado": "traçar",
    "traçadora": "traçador",
    "traçadoras": "traçador",
    "traçadores": "traçador",
    "traçados": "traçar",
    "traçai": "traçar",
    "traçais": "traçar",
    "traçalhões": "traçalhão",
    "traçam": "traçar",
    "traçamentos": "traçamento",
    "traçamo": "traçar",
    "traçamos": "traçar",
    "traçando": "traçar",
    "traçara": "traçar",
    "traçaram": "traçar",
    "traçaras": "traçar",
    "traçarde": "traçar",
    "traçardes": "traçar",
    "traçare": "traçar",
    "traçarei": "traçar",
    "traçareis": "traçar",
    "traçarem": "traçar",
    "traçaremos": "traçar",
    "traçares": "traçar",
    "traçaria": "traçar",
    "traçariam": "traçar",
    "traçarias": "traçaria",
    "traçarmo": "traçar",
    "traçarmos": "traçar",
    "traçará": "traçar",
    "traçarás": "traçar",
    "traçarão": "traçar",
    "traçaríamos": "traçar",
    "traçaríeis": "traçar",
    "traças": "traçar",
    "traçasse": "traçar",
    "traçassem": "traçar",
    "traçasses": "traçar",
    "traçaste": "traçar",
    "traçastes": "traçar",
    "traçava": "traçar",
    "traçavam": "traçar",
    "traçavas": "traçar",
    "traço": "traçar",
    "traços": "traço",
    "traçou": "traçar",
    "traçá": "traçar",
    "traçámo": "traçar",
    "traçámos": "traçar",
    "traçáramo": "traçar",
    "traçáramos": "traçar",
    "traçárei": "traçar",
    "traçáreis": "traçar",
    "traçásseis": "traçar",
    "traçássemos": "traçar",
    "traçávamo": "traçar",
    "traçávamos": "traçar",
    "traçávei": "traçar",
    "traçáveis": "traçar",
    "traí": "trair",
    "traía": "trair",
    "traíam": "trair",
    "traíamo": "trair",
    "traíamos": "trair",
    "traías": "trair",
    "traída": "trair",
    "traídas": "trair",
    "traído": "trair",
    "traídos": "trair",
    "traíei": "trair",
    "traíeis": "trair",
    "traímo": "trair",
    "traímos": "trair",
    "traíra": "trair",
    "traíram": "trair",
    "traíramo": "trair",
    "traíramos": "trair",
    "traíras": "traíra",
    "traíre": "trair",
    "traírei": "trair",
    "traíreis": "trair",
    "traírem": "trair",
    "traíres": "trair",
    "traís": "trair",
    "traísse": "trair",
    "traísseis": "trair",
    "traíssem": "trair",
    "traíssemos": "trair",
    "traísses": "trair",
    "traíste": "trair",
    "traístes": "trair",
    "trebazes": "trebaz",
    "trebelha": "trebelhar",
    "trebelhada": "trebelhar",
    "trebelhadas": "trebelhar",
    "trebelhado": "trebelhar",
    "trebelhados": "trebelhar",
    "trebelhai": "trebelhar",
    "trebelhais": "trebelhar",
    "trebelham": "trebelhar",
    "trebelhamo": "trebelhar",
    "trebelhamos": "trebelhar",
    "trebelhando": "trebelhar",
    "trebelhara": "trebelhar",
    "trebelharam": "trebelhar",
    "trebelharas": "trebelhar",
    "trebelhardes": "trebelhar",
    "trebelharei": "trebelhar",
    "trebelhareis": "trebelhar",
    "trebelharem": "trebelhar",
    "trebelharemos": "trebelhar",
    "trebelhares": "trebelhar",
    "trebelharia": "trebelhar",
    "trebelhariam": "trebelhar",
    "trebelharias": "trebelhar",
    "trebelharmo": "trebelhar",
    "trebelharmos": "trebelhar",
    "trebelhará": "trebelhar",
    "trebelharás": "trebelhar",
    "trebelharão": "trebelhar",
    "trebelharíamos": "trebelhar",
    "trebelharíeis": "trebelhar",
    "trebelhas": "trebelhar",
    "trebelhasse": "trebelhar",
    "trebelhassem": "trebelhar",
    "trebelhasses": "trebelhar",
    "trebelhaste": "trebelhar",
    "trebelhastes": "trebelhar",
    "trebelhava": "trebelhar",
    "trebelhavam": "trebelhar",
    "trebelhavas": "trebelhar",
    "trebelhe": "trebelhar",
    "trebelhei": "trebelhar",
    "trebelheis": "trebelhar",
    "trebelhem": "trebelhar",
    "trebelhemo": "trebelhar",
    "trebelhemos": "trebelhar",
    "trebelhes": "trebelhar",
    "trebelho": "trebelhar",
    "trebelhos": "trebelho",
    "trebelhou": "trebelhar",
    "trebelhámo": "trebelhar",
    "trebelhámos": "trebelhar",
    "trebelháramo": "trebelhar",
    "trebelháramos": "trebelhar",
    "trebelháreis": "trebelhar",
    "trebelhásseis": "trebelhar",
    "trebelhássemos": "trebelhar",
    "trebelhávamo": "trebelhar",
    "trebelhávamos": "trebelhar",
    "trebelháveis": "trebelhar",
    "trebolas": "trebola",
    "trecentistas": "trecentista",
    "trecentésima": "trecentésimo",
    "trecentésimas": "trecentésimo",
    "trecentésimos": "trecentésimo",
    "trecheia": "trecheio",
    "trecheias": "trecheio",
    "trecheios": "trecheio",
    "trechos": "trecho",
    "trechozinho": "trecho",
    "trechozinhos": "trecho",
    "trechozito": "trecho",
    "trechozitos": "trecho",
    "treda": "tredo",
    "tredas": "tredo",
    "tredecénios": "tredecénio",
    "tredices": "tredice",
    "tredos": "tredo",
    "tredécima": "tredécimo",
    "tredécimas": "tredécimo",
    "tredécimos": "tredécimo",
    "trefa": "trefo",
    "trefas": "trefo",
    "trefila": "trefilar",
    "trefilada": "trefilar",
    "trefiladas": "trefilar",
    "trefilado": "trefilar",
    "trefilados": "trefilar",
    "trefilagens": "trefilagem",
    "trefilai": "trefilar",
    "trefilais": "trefilar",
    "trefilam": "trefilar",
    "trefilamo": "trefilar",
    "trefilamos": "trefilar",
    "trefilando": "trefilar",
    "trefilara": "trefilar",
    "trefilaram": "trefilar",
    "trefilaras": "trefilar",
    "trefilarde": "trefilar",
    "trefilardes": "trefilar",
    "trefilare": "trefilar",
    "trefilarei": "trefilar",
    "trefilareis": "trefilar",
    "trefilarem": "trefilar",
    "trefilaremos": "trefilar",
    "trefilares": "trefilar",
    "trefilaria": "trefilar",
    "trefilariam": "trefilar",
    "trefilarias": "trefilaria",
    "trefilarmo": "trefilar",
    "trefilarmos": "trefilar",
    "trefilará": "trefilar",
    "trefilarás": "trefilar",
    "trefilarão": "trefilar",
    "trefilaríamos": "trefilar",
    "trefilaríeis": "trefilar",
    "trefilas": "trefilar",
    "trefilasse": "trefilar",
    "trefilassem": "trefilar",
    "trefilasses": "trefilar",
    "trefilaste": "trefilar",
    "trefilastes": "trefilar",
    "trefilava": "trefilar",
    "trefilavam": "trefilar",
    "trefilavas": "trefilar",
    "trefile": "trefilar",
    "trefilei": "trefilar",
    "trefileis": "trefilar",
    "trefilem": "trefilar",
    "trefilemo": "trefilar",
    "trefilemos": "trefilar",
    "trefiles": "trefilar",
    "trefilo": "trefilar",
    "trefilou": "trefilar",
    "trefilá": "trefilar",
    "trefilámo": "trefilar",
    "trefilámos": "trefilar",
    "trefiláramo": "trefilar",
    "trefiláramos": "trefilar",
    "trefilárei": "trefilar",
    "trefiláreis": "trefilar",
    "trefilásseis": "trefilar",
    "trefilássemos": "trefilar",
    "trefilávamo": "trefilar",
    "trefilávamos": "trefilar",
    "trefilávei": "trefilar",
    "trefiláveis": "trefilar",
    "trefos": "trefo",
    "treguazinha": "trégua",
    "treguazinhas": "trégua",
    "treguazita": "trégua",
    "treguazitas": "trégua",
    "treina": "treinar",
    "treinada": "treinar",
    "treinadas": "treinar",
    "treinado": "treinar",
    "treinadora": "treinador",
    "treinadoras": "treinador",
    "treinadores": "treinador",
    "treinados": "treinar",
    "treinai": "treinar",
    "treinais": "treinar",
    "treinam": "treinar",
    "treinamentos": "treinamento",
    "treinamo": "treinar",
    "treinamos": "treinar",
    "treinando": "treinar",
    "treinara": "treinar",
    "treinaram": "treinar",
    "treinaras": "treinar",
    "treinarde": "treinar",
    "treinardes": "treinar",
    "treinare": "treinar",
    "treinarei": "treinar",
    "treinareis": "treinar",
    "treinarem": "treinar",
    "treinaremos": "treinar",
    "treinares": "treinar",
    "treinaria": "treinar",
    "treinariam": "treinar",
    "treinarias": "treinar",
    "treinarmo": "treinar",
    "treinarmos": "treinar",
    "treinará": "treinar",
    "treinarás": "treinar",
    "treinarão": "treinar",
    "treinaríamos": "treinar",
    "treinaríeis": "treinar",
    "treinas": "treinar",
    "treinasse": "treinar",
    "treinassem": "treinar",
    "treinasses": "treinar",
    "treinaste": "treinar",
    "treinastes": "treinar",
    "treinava": "treinar",
    "treinavam": "treinar",
    "treinavas": "treinar",
    "treine": "treinar",
    "treinei": "treinar",
    "treineis": "treinar",
    "treinem": "treinar",
    "treinemo": "treinar",
    "treinemos": "treinar",
    "treines": "treinar",
    "treino": "treinar",
    "treinos": "treino",
    "treinou": "treinar",
    "treiná": "treinar",
    "treinámo": "treinar",
    "treinámos": "treinar",
    "treináramo": "treinar",
    "treináramos": "treinar",
    "treinárei": "treinar",
    "treináreis": "treinar",
    "treinásseis": "treinar",
    "treinássemos": "treinar",
    "treinávamo": "treinar",
    "treinávamos": "treinar",
    "treinávei": "treinar",
    "treináveis": "treinar",
    "treita": "treito",
    "treitada": "treitar",
    "treitadas": "treitar",
    "treitado": "treitar",
    "treitados": "treitar",
    "treitai": "treitar",
    "treitais": "treitar",
    "treitam": "treitar",
    "treitamo": "treitar",
    "treitamos": "treitar",
    "treitando": "treitar",
    "treitara": "treitar",
    "treitaram": "treitar",
    "treitaras": "treitar",
    "treitarde": "treitar",
    "treitardes": "treitar",
    "treitare": "treitar",
    "treitarei": "treitar",
    "treitareis": "treitar",
    "treitarem": "treitar",
    "treitaremos": "treitar",
    "treitares": "treitar",
    "treitaria": "treitar",
    "treitariam": "treitar",
    "treitarias": "treitar",
    "treitarmo": "treitar",
    "treitarmos": "treitar",
    "treitará": "treitar",
    "treitarás": "treitar",
    "treitarão": "treitar",
    "treitaríamos": "treitar",
    "treitaríeis": "treitar",
    "treitas": "treito",
    "treitasse": "treitar",
    "treitassem": "treitar",
    "treitasses": "treitar",
    "treitaste": "treitar",
    "treitastes": "treitar",
    "treitava": "treitar",
    "treitavam": "treitar",
    "treitavas": "treitar",
    "treite": "treitar",
    "treitei": "treitar",
    "treiteira": "treiteiro",
    "treiteiras": "treiteiro",
    "treiteiros": "treiteiro",
    "treiteis": "treitar",
    "treitem": "treitar",
    "treitemo": "treitar",
    "treitemos": "treitar",
    "treitenta": "treitento",
    "treitentas": "treitento",
    "treitentos": "treitento",
    "treites": "treitar",
    "treito": "treitar",
    "treitoiras": "treitoira",
    "treitos": "treito",
    "treitou": "treitar",
    "treitouras": "treitoura",
    "treitá": "treitar",
    "treitámo": "treitar",
    "treitámos": "treitar",
    "treitáramo": "treitar",
    "treitáramos": "treitar",
    "treitárei": "treitar",
    "treitáreis": "treitar",
    "treitásseis": "treitar",
    "treitássemos": "treitar",
    "treitávamo": "treitar",
    "treitávamos": "treitar",
    "treitávei": "treitar",
    "treitáveis": "treitar",
    "trejeita": "trejeitar",
    "trejeitada": "trejeitar",
    "trejeitadas": "trejeitar",
    "trejeitado": "trejeitar",
    "trejeitados": "trejeitar",
    "trejeitai": "trejeitar",
    "trejeitais": "trejeitar",
    "trejeitam": "trejeitar",
    "trejeitamo": "trejeitar",
    "trejeitamos": "trejeitar",
    "trejeitando": "trejeitar",
    "trejeitara": "trejeitar",
    "trejeitaram": "trejeitar",
    "trejeitaras": "trejeitar",
    "trejeitardes": "trejeitar",
    "trejeitarei": "trejeitar",
    "trejeitareis": "trejeitar",
    "trejeitarem": "trejeitar",
    "trejeitaremos": "trejeitar",
    "trejeitares": "trejeitar",
    "trejeitaria": "trejeitar",
    "trejeitariam": "trejeitar",
    "trejeitarias": "trejeitar",
    "trejeitarmo": "trejeitar",
    "trejeitarmos": "trejeitar",
    "trejeitará": "trejeitar",
    "trejeitarás": "trejeitar",
    "trejeitarão": "trejeitar",
    "trejeitaríamos": "trejeitar",
    "trejeitaríeis": "trejeitar",
    "trejeitas": "trejeitar",
    "trejeitasse": "trejeitar",
    "trejeitassem": "trejeitar",
    "trejeitasses": "trejeitar",
    "trejeitaste": "trejeitar",
    "trejeitastes": "trejeitar",
    "trejeitava": "trejeitar",
    "trejeitavam": "trejeitar",
    "trejeitavas": "trejeitar",
    "trejeite": "trejeitar",
    "trejeiteada": "trejeitear",
    "trejeiteadas": "trejeitear",
    "trejeiteado": "trejeitear",
    "trejeiteados": "trejeitear",
    "trejeiteai": "trejeitear",
    "trejeiteais": "trejeitear",
    "trejeiteamo": "trejeitear",
    "trejeiteamos": "trejeitear",
    "trejeiteando": "trejeitear",
    "trejeiteara": "trejeitear",
    "trejeitearam": "trejeitear",
    "trejeitearas": "trejeitear",
    "trejeiteardes": "trejeitear",
    "trejeitearei": "trejeitear",
    "trejeiteareis": "trejeitear",
    "trejeitearem": "trejeitear",
    "trejeitearemos": "trejeitear",
    "trejeiteares": "trejeitear",
    "trejeitearia": "trejeitear",
    "trejeiteariam": "trejeitear",
    "trejeitearias": "trejeitear",
    "trejeitearmo": "trejeitear",
    "trejeitearmos": "trejeitear",
    "trejeiteará": "trejeitear",
    "trejeitearás": "trejeitear",
    "trejeitearão": "trejeitear",
    "trejeitearíamos": "trejeitear",
    "trejeitearíeis": "trejeitear",
    "trejeiteasse": "trejeitear",
    "trejeiteassem": "trejeitear",
    "trejeiteasses": "trejeitear",
    "trejeiteaste": "trejeitear",
    "trejeiteastes": "trejeitear",
    "trejeiteava": "trejeitear",
    "trejeiteavam": "trejeitear",
    "trejeiteavas": "trejeitear",
    "trejeiteei": "trejeitear",
    "trejeiteeis": "trejeitear",
    "trejeiteemo": "trejeitear",
    "trejeiteemos": "trejeitear",
    "trejeitei": "trejeitar",
    "trejeiteia": "trejeitear",
    "trejeiteiam": "trejeitear",
    "trejeiteias": "trejeitear",
    "trejeiteie": "trejeitear",
    "trejeiteiem": "trejeitear",
    "trejeiteies": "trejeitear",
    "trejeiteio": "trejeitear",
    "trejeiteiros": "trejeiteiro",
    "trejeiteis": "trejeitar",
    "trejeitem": "trejeitar",
    "trejeitemo": "trejeitar",
    "trejeitemos": "trejeitar",
    "trejeiteou": "trejeitear",
    "trejeites": "trejeitar",
    "trejeiteámo": "trejeitear",
    "trejeiteámos": "trejeitear",
    "trejeiteáramo": "trejeitear",
    "trejeiteáramos": "trejeitear",
    "trejeiteáreis": "trejeitear",
    "trejeiteásseis": "trejeitear",
    "trejeiteássemos": "trejeitear",
    "trejeiteávamo": "trejeitear",
    "trejeiteávamos": "trejeitear",
    "trejeiteáveis": "trejeitear",
    "trejeito": "trejeitar",
    "trejeitos": "trejeito",
    "trejeitou": "trejeitar",
    "trejeitámo": "trejeitar",
    "trejeitámos": "trejeitar",
    "trejeitáramo": "trejeitar",
    "trejeitáramos": "trejeitar",
    "trejeitáreis": "trejeitar",
    "trejeitásseis": "trejeitar",
    "trejeitássemos": "trejeitar",
    "trejeitávamo": "trejeitar",
    "trejeitávamos": "trejeitar",
    "trejeitáveis": "trejeitar",
    "trejura": "trejurar",
    "trejurada": "trejurar",
    "trejuradas": "trejurar",
    "trejurado": "trejurar",
    "trejurados": "trejurar",
    "trejurai": "trejurar",
    "trejurais": "trejurar",
    "trejuram": "trejurar",
    "trejuramo": "trejurar",
    "trejuramos": "trejurar",
    "trejurando": "trejurar",
    "trejurara": "trejurar",
    "trejuraram": "trejurar",
    "trejuraras": "trejurar",
    "trejurardes": "trejurar",
    "trejurarei": "trejurar",
    "trejurareis": "trejurar",
    "trejurarem": "trejurar",
    "trejuraremos": "trejurar",
    "trejurares": "trejurar",
    "trejuraria": "trejurar",
    "trejurariam": "trejurar",
    "trejurarias": "trejurar",
    "trejurarmo": "trejurar",
    "trejurarmos": "trejurar",
    "trejurará": "trejurar",
    "trejurarás": "trejurar",
    "trejurarão": "trejurar",
    "trejuraríamos": "trejurar",
    "trejuraríeis": "trejurar",
    "trejuras": "trejurar",
    "trejurasse": "trejurar",
    "trejurassem": "trejurar",
    "trejurasses": "trejurar",
    "trejuraste": "trejurar",
    "trejurastes": "trejurar",
    "trejurava": "trejurar",
    "trejuravam": "trejurar",
    "trejuravas": "trejurar",
    "trejure": "trejurar",
    "trejurei": "trejurar",
    "trejureis": "trejurar",
    "trejurem": "trejurar",
    "trejuremo": "trejurar",
    "trejuremos": "trejurar",
    "trejures": "trejurar",
    "trejuro": "trejurar",
    "trejurou": "trejurar",
    "trejurámo": "trejurar",
    "trejurámos": "trejurar",
    "trejuráramo": "trejurar",
    "trejuráramos": "trejurar",
    "trejuráreis": "trejurar",
    "trejurásseis": "trejurar",
    "trejurássemos": "trejurar",
    "trejurávamo": "trejurar",
    "trejurávamos": "trejurar",
    "trejuráveis": "trejurar",
    "trelas": "trela",
    "treleada": "trelear",
    "treleadas": "trelear",
    "treleado": "trelear",
    "treleados": "trelear",
    "treleai": "trelear",
    "treleais": "trelear",
    "treleamo": "trelear",
    "treleamos": "trelear",
    "treleando": "trelear",
    "treleara": "trelear",
    "trelearam": "trelear",
    "trelearas": "trelear",
    "treleardes": "trelear",
    "trelearei": "trelear",
    "treleareis": "trelear",
    "trelearem": "trelear",
    "trelearemos": "trelear",
    "treleares": "trelear",
    "trelearia": "trelear",
    "treleariam": "trelear",
    "trelearias": "trelear",
    "trelearmo": "trelear",
    "trelearmos": "trelear",
    "treleará": "trelear",
    "trelearás": "trelear",
    "trelearão": "trelear",
    "trelearíamos": "trelear",
    "trelearíeis": "trelear",
    "treleasse": "trelear",
    "treleassem": "trelear",
    "treleasses": "trelear",
    "treleaste": "trelear",
    "treleastes": "trelear",
    "treleava": "trelear",
    "treleavam": "trelear",
    "treleavas": "trelear",
    "treleei": "trelear",
    "treleeis": "trelear",
    "treleemo": "trelear",
    "treleemos": "trelear",
    "treleia": "trelear",
    "treleiam": "trelear",
    "treleias": "trelear",
    "treleie": "trelear",
    "treleiem": "trelear",
    "treleies": "trelear",
    "treleio": "trelear",
    "treleou": "trelear",
    "treleámo": "trelear",
    "treleámos": "trelear",
    "treleáramo": "trelear",
    "treleáramos": "trelear",
    "treleáreis": "trelear",
    "treleásseis": "trelear",
    "treleássemos": "trelear",
    "treleávamo": "trelear",
    "treleávamos": "trelear",
    "treleáveis": "trelear",
    "trelhos": "trelho",
    "trema": "tremer",
    "tremada": "tremar",
    "tremadas": "tremar",
    "tremado": "tremar",
    "tremados": "tremar",
    "tremadotes": "tremadote",
    "tremai": "tremar",
    "tremais": "tremer",
    "tremam": "tremer",
    "tremamo": "tremer",
    "tremamos": "tremer",
    "tremando": "tremar",
    "tremandráceas": "tremandrácea",
    "tremara": "tremar",
    "tremaram": "tremar",
    "tremaras": "tremar",
    "tremarde": "tremar",
    "tremardes": "tremar",
    "tremare": "tremar",
    "tremarei": "tremar",
    "tremareis": "tremar",
    "tremarem": "tremar",
    "tremaremos": "tremar",
    "tremares": "tremar",
    "tremaria": "tremar",
    "tremariam": "tremar",
    "tremarias": "tremar",
    "tremarmo": "tremar",
    "tremarmos": "tremar",
    "tremará": "tremar",
    "tremarás": "tremar",
    "tremarão": "tremar",
    "tremaríamos": "tremar",
    "tremaríeis": "tremar",
    "tremas": "tremer",
    "tremasse": "tremar",
    "tremassem": "tremar",
    "tremasses": "tremar",
    "tremaste": "tremar",
    "tremastes": "tremar",
    "trematódeos": "trematódeo",
    "tremava": "tremar",
    "tremavam": "tremar",
    "tremavas": "tremar",
    "treme": "tremer",
    "tremebunda": "tremebundo",
    "tremebundas": "tremebundo",
    "tremebundos": "tremebundo",
    "tremecéns": "tremecém",
    "tremedais": "tremedal",
    "tremedeiras": "tremedeira",
    "tremedoiros": "tremedoiro",
    "tremedora": "tremedor",
    "tremedoras": "tremedor",
    "tremedores": "tremedor",
    "tremedouros": "tremedouro",
    "tremeduras": "tremedura",
    "tremei": "tremer",
    "tremeis": "tremer",
    "tremeleada": "tremelear",
    "tremeleadas": "tremelear",
    "tremeleado": "tremelear",
    "tremeleados": "tremelear",
    "tremeleai": "tremelear",
    "tremeleais": "tremelear",
    "tremeleamo": "tremelear",
    "tremeleamos": "tremelear",
    "tremeleando": "tremelear",
    "tremeleara": "tremelear",
    "tremelearam": "tremelear",
    "tremelearas": "tremelear",
    "tremeleardes": "tremelear",
    "tremelearei": "tremelear",
    "tremeleareis": "tremelear",
    "tremelearem": "tremelear",
    "tremelearemos": "tremelear",
    "tremeleares": "tremelear",
    "tremelearia": "tremelear",
    "tremeleariam": "tremelear",
    "tremelearias": "tremelear",
    "tremelearmo": "tremelear",
    "tremelearmos": "tremelear",
    "tremeleará": "tremelear",
    "tremelearás": "tremelear",
    "tremelearão": "tremelear",
    "tremelearíamos": "tremelear",
    "tremelearíeis": "tremelear",
    "tremeleasse": "tremelear",
    "tremeleassem": "tremelear",
    "tremeleasses": "tremelear",
    "tremeleaste": "tremelear",
    "tremeleastes": "tremelear",
    "tremeleava": "tremelear",
    "tremeleavam": "tremelear",
    "tremeleavas": "tremelear",
    "tremeleei": "tremelear",
    "tremeleeis": "tremelear",
    "tremeleemo": "tremelear",
    "tremeleemos": "tremelear",
    "tremeleia": "tremelear",
    "tremeleiam": "tremelear",
    "tremeleias": "tremelear",
    "tremeleie": "tremelear",
    "tremeleiem": "tremelear",
    "tremeleies": "tremelear",
    "tremeleio": "tremelear",
    "tremeleja": "tremelejar",
    "tremelejada": "tremelejar",
    "tremelejadas": "tremelejar",
    "tremelejado": "tremelejar",
    "tremelejados": "tremelejar",
    "tremelejai": "tremelejar",
    "tremelejais": "tremelejar",
    "tremelejam": "tremelejar",
    "tremelejamo": "tremelejar",
    "tremelejamos": "tremelejar",
    "tremelejando": "tremelejar",
    "tremelejara": "tremelejar",
    "tremelejaram": "tremelejar",
    "tremelejaras": "tremelejar",
    "tremelejardes": "tremelejar",
    "tremelejarei": "tremelejar",
    "tremelejareis": "tremelejar",
    "tremelejarem": "tremelejar",
    "tremelejaremos": "tremelejar",
    "tremelejares": "tremelejar",
    "tremelejaria": "tremelejar",
    "tremelejariam": "tremelejar",
    "tremelejarias": "tremelejar",
    "tremelejarmo": "tremelejar",
    "tremelejarmos": "tremelejar",
    "tremelejará": "tremelejar",
    "tremelejarás": "tremelejar",
    "tremelejarão": "tremelejar",
    "tremelejaríamos": "tremelejar",
    "tremelejaríeis": "tremelejar",
    "tremelejas": "tremelejar",
    "tremelejasse": "tremelejar",
    "tremelejassem": "tremelejar",
    "tremelejasses": "tremelejar",
    "tremelejaste": "tremelejar",
    "tremelejastes": "tremelejar",
    "tremelejava": "tremelejar",
    "tremelejavam": "tremelejar",
    "tremelejavas": "tremelejar",
    "tremeleje": "tremelejar",
    "tremelejei": "tremelejar",
    "tremelejeis": "tremelejar",
    "tremelejem": "tremelejar",
    "tremelejemo": "tremelejar",
    "tremelejemos": "tremelejar",
    "tremelejes": "tremelejar",
    "tremelejo": "tremelejar",
    "tremelejos": "tremelejo",
    "tremelejou": "tremelejar",
    "tremelejámo": "tremelejar",
    "tremelejámos": "tremelejar",
    "tremelejáramo": "tremelejar",
    "tremelejáramos": "tremelejar",
    "tremelejáreis": "tremelejar",
    "tremelejásseis": "tremelejar",
    "tremelejássemos": "tremelejar",
    "tremelejávamo": "tremelejar",
    "tremelejávamos": "tremelejar",
    "tremelejáveis": "tremelejar",
    "tremeleou": "tremelear",
    "tremeleámo": "tremelear",
    "tremeleámos": "tremelear",
    "tremeleáramo": "tremelear",
    "tremeleáramos": "tremelear",
    "tremeleáreis": "tremelear",
    "tremeleásseis": "tremelear",
    "tremeleássemos": "tremelear",
    "tremeleávamo": "tremelear",
    "tremeleávamos": "tremelear",
    "tremeleáveis": "tremelear",
    "tremelgas": "tremelga",
    "tremelica": "tremelicas",
    "tremelicada": "tremelicar",
    "tremelicadas": "tremelicar",
    "tremelicado": "tremelicar",
    "tremelicados": "tremelicar",
    "tremelicais": "tremelicar",
    "tremelicam": "tremelicar",
    "tremelicamo": "tremelicar",
    "tremelicamos": "tremelicar",
    "tremelicando": "tremelicar",
    "tremelicara": "tremelicar",
    "tremelicaram": "tremelicar",
    "tremelicaras": "tremelicar",
    "tremelicardes": "tremelicar",
    "tremelicarei": "tremelicar",
    "tremelicareis": "tremelicar",
    "tremelicarem": "tremelicar",
    "tremelicaremos": "tremelicar",
    "tremelicares": "tremelicar",
    "tremelicaria": "tremelicar",
    "tremelicariam": "tremelicar",
    "tremelicarias": "tremelicar",
    "tremelicarmo": "tremelicar",
    "tremelicarmos": "tremelicar",
    "tremelicará": "tremelicar",
    "tremelicarás": "tremelicar",
    "tremelicarão": "tremelicar",
    "tremelicaríamos": "tremelicar",
    "tremelicaríeis": "tremelicar",
    "tremelicas": "tremelicar",
    "tremelicasse": "tremelicar",
    "tremelicassem": "tremelicar",
    "tremelicasses": "tremelicar",
    "tremelicaste": "tremelicar",
    "tremelicastes": "tremelicar",
    "tremelicava": "tremelicar",
    "tremelicavam": "tremelicar",
    "tremelicavas": "tremelicar",
    "tremelico": "tremelicar",
    "tremelicou": "tremelicar",
    "tremelicámo": "tremelicar",
    "tremelicámos": "tremelicar",
    "tremelicáramo": "tremelicar",
    "tremelicáramos": "tremelicar",
    "tremelicáreis": "tremelicar",
    "tremelicásseis": "tremelicar",
    "tremelicássemos": "tremelicar",
    "tremelicávamo": "tremelicar",
    "tremelicávamos": "tremelicar",
    "tremelicáveis": "tremelicar",
    "tremelique": "tremelicar",
    "tremeliquei": "tremelicar",
    "tremeliqueis": "tremelicar",
    "tremeliquem": "tremelicar",
    "tremeliquemos": "tremelicar",
    "tremeliquenta": "tremeliquento",
    "tremeliquentas": "tremeliquento",
    "tremeliquentos": "tremeliquento",
    "tremeliques": "tremelique",
    "tremeluz": "tremeluzir",
    "tremeluza": "tremeluzir",
    "tremeluzais": "tremeluzir",
    "tremeluzam": "tremeluzir",
    "tremeluzamo": "tremeluzir",
    "tremeluzamos": "tremeluzir",
    "tremeluzas": "tremeluzir",
    "tremeluze": "tremeluzir",
    "tremeluzem": "tremeluzir",
    "tremeluzentes": "tremeluzente",
    "tremeluzes": "tremeluzir",
    "tremeluzi": "tremeluzir",
    "tremeluzia": "tremeluzir",
    "tremeluziam": "tremeluzir",
    "tremeluzias": "tremeluzir",
    "tremeluzida": "tremeluzir",
    "tremeluzidas": "tremeluzir",
    "tremeluzido": "tremeluzir",
    "tremeluzidos": "tremeluzir",
    "tremeluzimo": "tremeluzir",
    "tremeluzimos": "tremeluzir",
    "tremeluzindo": "tremeluzir",
    "tremeluzira": "tremeluzir",
    "tremeluziram": "tremeluzir",
    "tremeluziras": "tremeluzir",
    "tremeluzirdes": "tremeluzir",
    "tremeluzirei": "tremeluzir",
    "tremeluzireis": "tremeluzir",
    "tremeluzirem": "tremeluzir",
    "tremeluziremos": "tremeluzir",
    "tremeluzires": "tremeluzir",
    "tremeluziria": "tremeluzir",
    "tremeluziriam": "tremeluzir",
    "tremeluzirias": "tremeluzir",
    "tremeluzirmo": "tremeluzir",
    "tremeluzirmos": "tremeluzir",
    "tremeluzirá": "tremeluzir",
    "tremeluzirás": "tremeluzir",
    "tremeluzirão": "tremeluzir",
    "tremeluziríamos": "tremeluzir",
    "tremeluziríeis": "tremeluzir",
    "tremeluzis": "tremeluzir",
    "tremeluzisse": "tremeluzir",
    "tremeluzissem": "tremeluzir",
    "tremeluzisses": "tremeluzir",
    "tremeluziste": "tremeluzir",
    "tremeluzistes": "tremeluzir",
    "tremeluziu": "tremeluzir",
    "tremeluzo": "tremeluzir",
    "tremeluzíamo": "tremeluzir",
    "tremeluzíamos": "tremeluzir",
    "tremeluzíeis": "tremeluzir",
    "tremeluzíramo": "tremeluzir",
    "tremeluzíramos": "tremeluzir",
    "tremeluzíreis": "tremeluzir",
    "tremeluzísseis": "tremeluzir",
    "tremeluzíssemos": "tremeluzir",
    "tremem": "tremer",
    "trememo": "tremer",
    "trememos": "tremer",
    "tremenda": "tremendo",
    "tremendas": "tremendo",
    "tremendo": "tremer",
    "tremendos": "tremendo",
    "tremenhos": "tremenho",
    "trementes": "tremente",
    "tremera": "tremer",
    "tremeram": "tremer",
    "tremeras": "tremer",
    "tremerdes": "tremer",
    "tremerei": "tremer",
    "tremereis": "tremer",
    "tremerem": "tremer",
    "tremeremos": "tremer",
    "tremeres": "tremer",
    "tremeria": "tremer",
    "tremeriam": "tremer",
    "tremerias": "tremer",
    "tremermo": "tremer",
    "tremermos": "tremer",
    "tremerá": "tremer",
    "tremerás": "tremer",
    "tremerão": "tremer",
    "tremeríamos": "tremer",
    "tremeríeis": "tremer",
    "tremes": "tremer",
    "tremesa": "tremês",
    "tremesas": "tremês",
    "tremeses": "tremês",
    "tremesinha": "tremesinho",
    "tremesinhas": "tremesinho",
    "tremesinhos": "tremesinho",
    "tremesse": "tremer",
    "tremessem": "tremer",
    "tremesses": "tremer",
    "tremeste": "tremer",
    "tremestes": "tremer",
    "tremeu": "tremer",
    "tremi": "tremer",
    "tremia": "tremer",
    "tremiam": "tremer",
    "tremias": "tremer",
    "tremida": "tremido",
    "tremidas": "tremido",
    "tremidinha": "tremido",
    "tremidinhas": "tremido",
    "tremidinho": "tremido",
    "tremidinhos": "tremido",
    "tremidita": "tremido",
    "tremiditas": "tremido",
    "tremidito": "tremido",
    "tremiditos": "tremido",
    "tremido": "tremer",
    "tremidos": "tremido",
    "tremidíssima": "tremido",
    "tremidíssimas": "tremido",
    "tremidíssimo": "tremido",
    "tremidíssimos": "tremido",
    "tremifusas": "tremifusa",
    "tremilongos": "tremilongo",
    "tremo": "tremer",
    "tremoce": "tremoçar",
    "tremocei": "tremoçar",
    "tremoceira": "tremoceiro",
    "tremoceiras": "tremoceiro",
    "tremoceiros": "tremoceiro",
    "tremoceis": "tremoçar",
    "tremocem": "tremoçar",
    "tremocemo": "tremoçar",
    "tremocemos": "tremoçar",
    "tremoces": "tremoçar",
    "tremocinho": "tremoço",
    "tremocinhos": "tremoço",
    "tremocito": "tremoço",
    "tremocitos": "tremoço",
    "tremolites": "tremolite",
    "tremonhados": "tremonhado",
    "tremonhais": "tremonhal",
    "tremonhas": "tremonha",
    "tremontelos": "tremontelo",
    "tremores": "tremor",
    "tremou": "tremar",
    "tremoça": "tremoçar",
    "tremoçada": "tremoçar",
    "tremoçadas": "tremoçar",
    "tremoçado": "tremoçar",
    "tremoçados": "tremoçar",
    "tremoçagens": "tremoçagem",
    "tremoçai": "tremoçar",
    "tremoçais": "tremoçar",
    "tremoçam": "tremoçar",
    "tremoçamo": "tremoçar",
    "tremoçamos": "tremoçar",
    "tremoçando": "tremoçar",
    "tremoçara": "tremoçar",
    "tremoçaram": "tremoçar",
    "tremoçaras": "tremoçar",
    "tremoçarde": "tremoçar",
    "tremoçardes": "tremoçar",
    "tremoçare": "tremoçar",
    "tremoçarei": "tremoçar",
    "tremoçareis": "tremoçar",
    "tremoçarem": "tremoçar",
    "tremoçaremos": "tremoçar",
    "tremoçares": "tremoçar",
    "tremoçaria": "tremoçar",
    "tremoçariam": "tremoçar",
    "tremoçarias": "tremoçar",
    "tremoçarmo": "tremoçar",
    "tremoçarmos": "tremoçar",
    "tremoçará": "tremoçar",
    "tremoçarás": "tremoçar",
    "tremoçarão": "tremoçar",
    "tremoçaríamos": "tremoçar",
    "tremoçaríeis": "tremoçar",
    "tremoças": "tremoçar",
    "tremoçasse": "tremoçar",
    "tremoçassem": "tremoçar",
    "tremoçasses": "tremoçar",
    "tremoçaste": "tremoçar",
    "tremoçastes": "tremoçar",
    "tremoçava": "tremoçar",
    "tremoçavam": "tremoçar",
    "tremoçavas": "tremoçar",
    "tremoço": "tremoçar",
    "tremoços": "tremoço",
    "tremoçou": "tremoçar",
    "tremoçá": "tremoçar",
    "tremoçámo": "tremoçar",
    "tremoçámos": "tremoçar",
    "tremoçáramo": "tremoçar",
    "tremoçáramos": "tremoçar",
    "tremoçárei": "tremoçar",
    "tremoçáreis": "tremoçar",
    "tremoçásseis": "tremoçar",
    "tremoçássemos": "tremoçar",
    "tremoçávamo": "tremoçar",
    "tremoçávamos": "tremoçar",
    "tremoçávei": "tremoçar",
    "tremoçáveis": "tremoçar",
    "tremoções": "tremoção",
    "trempes": "trempe",
    "tremula": "tremular",
    "tremulada": "tremular",
    "tremuladas": "tremular",
    "tremulado": "tremular",
    "tremulados": "tremular",
    "tremulai": "tremular",
    "tremulais": "tremular",
    "tremulam": "tremular",
    "tremulamo": "tremular",
    "tremulamos": "tremular",
    "tremulando": "tremular",
    "tremulantes": "tremulante",
    "tremulara": "tremular",
    "tremularam": "tremular",
    "tremularas": "tremular",
    "tremularde": "tremular",
    "tremulardes": "tremular",
    "tremulare": "tremular",
    "tremularei": "tremular",
    "tremulareis": "tremular",
    "tremularem": "tremular",
    "tremularemos": "tremular",
    "tremulares": "tremular",
    "tremularia": "tremular",
    "tremulariam": "tremular",
    "tremularias": "tremular",
    "tremularmo": "tremular",
    "tremularmos": "tremular",
    "tremulará": "tremular",
    "tremularás": "tremular",
    "tremularão": "tremular",
    "tremularíamos": "tremular",
    "tremularíeis": "tremular",
    "tremulas": "tremular",
    "tremulasse": "tremular",
    "tremulassem": "tremular",
    "tremulasses": "tremular",
    "tremulaste": "tremular",
    "tremulastes": "tremular",
    "tremulava": "tremular",
    "tremulavam": "tremular",
    "tremulavas": "tremular",
    "tremulações": "tremulação",
    "tremule": "tremular",
    "tremuleada": "tremulear",
    "tremuleadas": "tremulear",
    "tremuleado": "tremulear",
    "tremuleados": "tremulear",
    "tremuleai": "tremulear",
    "tremuleais": "tremulear",
    "tremuleamo": "tremulear",
    "tremuleamos": "tremulear",
    "tremuleando": "tremulear",
    "tremuleara": "tremulear",
    "tremulearam": "tremulear",
    "tremulearas": "tremulear",
    "tremulearde": "tremulear",
    "tremuleardes": "tremulear",
    "tremuleare": "tremulear",
    "tremulearei": "tremulear",
    "tremuleareis": "tremulear",
    "tremulearem": "tremulear",
    "tremulearemos": "tremulear",
    "tremuleares": "tremulear",
    "tremulearia": "tremulear",
    "tremuleariam": "tremulear",
    "tremulearias": "tremulear",
    "tremulearmo": "tremulear",
    "tremulearmos": "tremulear",
    "tremuleará": "tremulear",
    "tremulearás": "tremulear",
    "tremulearão": "tremulear",
    "tremulearíamos": "tremulear",
    "tremulearíeis": "tremulear",
    "tremuleasse": "tremulear",
    "tremuleassem": "tremulear",
    "tremuleasses": "tremulear",
    "tremuleaste": "tremulear",
    "tremuleastes": "tremulear",
    "tremuleava": "tremulear",
    "tremuleavam": "tremulear",
    "tremuleavas": "tremulear",
    "tremuleei": "tremulear",
    "tremuleeis": "tremulear",
    "tremuleemo": "tremulear",
    "tremuleemos": "tremulear",
    "tremulei": "tremular",
    "tremuleia": "tremulear",
    "tremuleiam": "tremulear",
    "tremuleias": "tremulear",
    "tremuleie": "tremulear",
    "tremuleiem": "tremulear",
    "tremuleies": "tremulear",
    "tremuleio": "tremulear",
    "tremuleis": "tremular",
    "tremulem": "tremular",
    "tremulemo": "tremular",
    "tremulemos": "tremular",
    "tremuleou": "tremulear",
    "tremules": "tremular",
    "tremuleá": "tremulear",
    "tremuleámo": "tremulear",
    "tremuleámos": "tremulear",
    "tremuleáramo": "tremulear",
    "tremuleáramos": "tremulear",
    "tremuleárei": "tremulear",
    "tremuleáreis": "tremulear",
    "tremuleásseis": "tremulear",
    "tremuleássemos": "tremulear",
    "tremuleávamo": "tremulear",
    "tremuleávamos": "tremulear",
    "tremuleávei": "tremulear",
    "tremuleáveis": "tremulear",
    "tremulina": "tremulinar",
    "tremulinada": "tremulinar",
    "tremulinadas": "tremulinar",
    "tremulinado": "tremulinar",
    "tremulinados": "tremulinar",
    "tremulinai": "tremulinar",
    "tremulinais": "tremulinar",
    "tremulinam": "tremulinar",
    "tremulinamo": "tremulinar",
    "tremulinamos": "tremulinar",
    "tremulinando": "tremulinar",
    "tremulinara": "tremulinar",
    "tremulinaram": "tremulinar",
    "tremulinaras": "tremulinar",
    "tremulinardes": "tremulinar",
    "tremulinarei": "tremulinar",
    "tremulinareis": "tremulinar",
    "tremulinarem": "tremulinar",
    "tremulinaremos": "tremulinar",
    "tremulinares": "tremulinar",
    "tremulinaria": "tremulinar",
    "tremulinariam": "tremulinar",
    "tremulinarias": "tremulinar",
    "tremulinarmo": "tremulinar",
    "tremulinarmos": "tremulinar",
    "tremulinará": "tremulinar",
    "tremulinarás": "tremulinar",
    "tremulinarão": "tremulinar",
    "tremulinaríamos": "tremulinar",
    "tremulinaríeis": "tremulinar",
    "tremulinas": "tremulinar",
    "tremulinasse": "tremulinar",
    "tremulinassem": "tremulinar",
    "tremulinasses": "tremulinar",
    "tremulinaste": "tremulinar",
    "tremulinastes": "tremulinar",
    "tremulinava": "tremulinar",
    "tremulinavam": "tremulinar",
    "tremulinavas": "tremulinar",
    "tremuline": "tremulinar",
    "tremulinei": "tremulinar",
    "tremulineis": "tremulinar",
    "tremulinem": "tremulinar",
    "tremulinemo": "tremulinar",
    "tremulinemos": "tremulinar",
    "tremulines": "tremulinar",
    "tremulino": "tremulinar",
    "tremulinou": "tremulinar",
    "tremulinámo": "tremulinar",
    "tremulinámos": "tremulinar",
    "tremulináramo": "tremulinar",
    "tremulináramos": "tremulinar",
    "tremulináreis": "tremulinar",
    "tremulinásseis": "tremulinar",
    "tremulinássemos": "tremulinar",
    "tremulinávamo": "tremulinar",
    "tremulinávamos": "tremulinar",
    "tremulináveis": "tremulinar",
    "tremulo": "tremular",
    "tremulosa": "tremuloso",
    "tremulosas": "tremuloso",
    "tremulosos": "tremuloso",
    "tremulou": "tremular",
    "tremulá": "tremular",
    "tremulámo": "tremular",
    "tremulámos": "tremular",
    "tremuláramo": "tremular",
    "tremuláramos": "tremular",
    "tremulárei": "tremular",
    "tremuláreis": "tremular",
    "tremulásseis": "tremular",
    "tremulássemos": "tremular",
    "tremulávamo": "tremular",
    "tremulávamos": "tremular",
    "tremulávei": "tremular",
    "tremuláveis": "tremular",
    "tremuras": "tremura",
    "tremá": "tremar",
    "tremámo": "tremar",
    "tremámos": "tremar",
    "tremáramo": "tremar",
    "tremáramos": "tremar",
    "tremárei": "tremar",
    "tremáreis": "tremar",
    "tremásseis": "tremar",
    "tremássemos": "tremar",
    "tremávamo": "tremar",
    "tremávamos": "tremar",
    "tremávei": "tremar",
    "tremáveis": "tremar",
    "tremêramo": "tremer",
    "tremêramos": "tremer",
    "tremêreis": "tremer",
    "tremêsseis": "tremer",
    "tremêssemos": "tremer",
    "tremíamo": "tremer",
    "tremíamos": "tremer",
    "tremíeis": "tremer",
    "tremós": "tremó",
    "tremões": "tremão",
    "trena": "trenar",
    "trenada": "trenar",
    "trenadas": "trenar",
    "trenado": "trenar",
    "trenados": "trenar",
    "trenai": "trenar",
    "trenais": "trenar",
    "trenam": "trenar",
    "trenamo": "trenar",
    "trenamos": "trenar",
    "trenando": "trenar",
    "trenara": "trenar",
    "trenaram": "trenar",
    "trenaras": "trenar",
    "trenarde": "trenar",
    "trenardes": "trenar",
    "trenare": "trenar",
    "trenarei": "trenar",
    "trenareis": "trenar",
    "trenarem": "trenar",
    "trenaremos": "trenar",
    "trenares": "trenar",
    "trenaria": "trenar",
    "trenariam": "trenar",
    "trenarias": "trenar",
    "trenarmo": "trenar",
    "trenarmos": "trenar",
    "trenará": "trenar",
    "trenarás": "trenar",
    "trenarão": "trenar",
    "trenaríamos": "trenar",
    "trenaríeis": "trenar",
    "trenas": "trenar",
    "trenasse": "trenar",
    "trenassem": "trenar",
    "trenasses": "trenar",
    "trenaste": "trenar",
    "trenastes": "trenar",
    "trenava": "trenar",
    "trenavam": "trenar",
    "trenavas": "trenar",
    "trene": "trenar",
    "trenei": "trenar",
    "treneis": "trenar",
    "trenem": "trenar",
    "trenemo": "trenar",
    "trenemos": "trenar",
    "trenes": "trenar",
    "treno": "trenar",
    "trenos": "treno",
    "trenou": "trenar",
    "trens": "trem",
    "trentina": "trentino",
    "trentinas": "trentino",
    "trentinos": "trentino",
    "trená": "trenar",
    "trenámo": "trenar",
    "trenámos": "trenar",
    "trenáramo": "trenar",
    "trenáramos": "trenar",
    "trenárei": "trenar",
    "trenáreis": "trenar",
    "trenásseis": "trenar",
    "trenássemos": "trenar",
    "trenávamo": "trenar",
    "trenávamos": "trenar",
    "trenávei": "trenar",
    "trenáveis": "trenar",
    "trenós": "trenó",
    "trepa": "trepar",
    "trepada": "trepar",
    "trepadas": "trepar",
    "trepadeira": "trepador",
    "trepadeiras": "trepador",
    "trepado": "trepar",
    "trepadoiros": "trepadoiro",
    "trepadora": "trepador",
    "trepadoras": "trepadora",
    "trepadores": "trepador",
    "trepados": "trepar",
    "trepadouros": "trepadouro",
    "trepai": "trepar",
    "trepais": "trepar",
    "trepam": "trepar",
    "trepamo": "trepar",
    "trepamos": "trepar",
    "trepana": "trepanar",
    "trepanada": "trepanar",
    "trepanadas": "trepanar",
    "trepanado": "trepanar",
    "trepanados": "trepanar",
    "trepanai": "trepanar",
    "trepanais": "trepanar",
    "trepanam": "trepanar",
    "trepanamo": "trepanar",
    "trepanamos": "trepanar",
    "trepanando": "trepanar",
    "trepanara": "trepanar",
    "trepanaram": "trepanar",
    "trepanaras": "trepanar",
    "trepanarde": "trepanar",
    "trepanardes": "trepanar",
    "trepanare": "trepanar",
    "trepanarei": "trepanar",
    "trepanareis": "trepanar",
    "trepanarem": "trepanar",
    "trepanaremos": "trepanar",
    "trepanares": "trepanar",
    "trepanaria": "trepanar",
    "trepanariam": "trepanar",
    "trepanarias": "trepanar",
    "trepanarmo": "trepanar",
    "trepanarmos": "trepanar",
    "trepanará": "trepanar",
    "trepanarás": "trepanar",
    "trepanarão": "trepanar",
    "trepanaríamos": "trepanar",
    "trepanaríeis": "trepanar",
    "trepanas": "trepanar",
    "trepanasse": "trepanar",
    "trepanassem": "trepanar",
    "trepanasses": "trepanar",
    "trepanaste": "trepanar",
    "trepanastes": "trepanar",
    "trepanava": "trepanar",
    "trepanavam": "trepanar",
    "trepanavas": "trepanar",
    "trepanações": "trepanação",
    "trepando": "trepar",
    "trepane": "trepanar",
    "trepanei": "trepanar",
    "trepaneis": "trepanar",
    "trepanem": "trepanar",
    "trepanemo": "trepanar",
    "trepanemos": "trepanar",
    "trepanes": "trepanar",
    "trepano": "trepanar",
    "trepanou": "trepanar",
    "trepantes": "trepante",
    "trepaná": "trepanar",
    "trepanámo": "trepanar",
    "trepanámos": "trepanar",
    "trepanáramo": "trepanar",
    "trepanáramos": "trepanar",
    "trepanárei": "trepanar",
    "trepanáreis": "trepanar",
    "trepanásseis": "trepanar",
    "trepanássemos": "trepanar",
    "trepanávamo": "trepanar",
    "trepanávamos": "trepanar",
    "trepanávei": "trepanar",
    "trepanáveis": "trepanar",
    "trepara": "trepar",
    "treparam": "trepar",
    "treparas": "trepar",
    "treparde": "trepar",
    "trepardes": "trepar",
    "trepare": "trepar",
    "treparei": "trepar",
    "trepareis": "trepar",
    "treparem": "trepar",
    "treparemos": "trepar",
    "trepares": "trepar",
    "treparia": "trepar",
    "trepariam": "trepar",
    "treparias": "trepar",
    "treparmo": "trepar",
    "treparmos": "trepar",
    "trepará": "trepar",
    "treparás": "trepar",
    "treparão": "trepar",
    "treparíamos": "trepar",
    "treparíeis": "trepar",
    "trepas": "trepar",
    "trepasse": "trepar",
    "trepassem": "trepar",
    "trepasses": "trepar",
    "trepaste": "trepar",
    "trepastes": "trepar",
    "trepava": "trepar",
    "trepavam": "trepar",
    "trepavas": "trepar",
    "trepe": "trepar",
    "trepei": "trepar",
    "trepeiras": "trepeira",
    "trepeis": "trepar",
    "trepem": "trepar",
    "trepemo": "trepar",
    "trepemos": "trepar",
    "trepes": "trepe",
    "trepica": "trepicar",
    "trepicada": "trepicar",
    "trepicadas": "trepicar",
    "trepicado": "trepicar",
    "trepicados": "trepicar",
    "trepicai": "trepicar",
    "trepicais": "trepicar",
    "trepicam": "trepicar",
    "trepicamo": "trepicar",
    "trepicamos": "trepicar",
    "trepicando": "trepicar",
    "trepicara": "trepicar",
    "trepicaram": "trepicar",
    "trepicaras": "trepicar",
    "trepicarde": "trepicar",
    "trepicardes": "trepicar",
    "trepicare": "trepicar",
    "trepicarei": "trepicar",
    "trepicareis": "trepicar",
    "trepicarem": "trepicar",
    "trepicaremos": "trepicar",
    "trepicares": "trepicar",
    "trepicaria": "trepicar",
    "trepicariam": "trepicar",
    "trepicarias": "trepicar",
    "trepicarmo": "trepicar",
    "trepicarmos": "trepicar",
    "trepicará": "trepicar",
    "trepicarás": "trepicar",
    "trepicarão": "trepicar",
    "trepicaríamos": "trepicar",
    "trepicaríeis": "trepicar",
    "trepicas": "trepicar",
    "trepicasse": "trepicar",
    "trepicassem": "trepicar",
    "trepicasses": "trepicar",
    "trepicaste": "trepicar",
    "trepicastes": "trepicar",
    "trepicava": "trepicar",
    "trepicavam": "trepicar",
    "trepicavas": "trepicar",
    "trepico": "trepicar",
    "trepicou": "trepicar",
    "trepicá": "trepicar",
    "trepicámo": "trepicar",
    "trepicámos": "trepicar",
    "trepicáramo": "trepicar",
    "trepicáramos": "trepicar",
    "trepicárei": "trepicar",
    "trepicáreis": "trepicar",
    "trepicásseis": "trepicar",
    "trepicássemos": "trepicar",
    "trepicávamo": "trepicar",
    "trepicávamos": "trepicar",
    "trepicávei": "trepicar",
    "trepicáveis": "trepicar",
    "trepida": "trepidar",
    "trepidada": "trepidar",
    "trepidadas": "trepidar",
    "trepidado": "trepidar",
    "trepidados": "trepidar",
    "trepidai": "trepidar",
    "trepidais": "trepidar",
    "trepidam": "trepidar",
    "trepidamo": "trepidar",
    "trepidamos": "trepidar",
    "trepidando": "trepidar",
    "trepidantes": "trepidante",
    "trepidara": "trepidar",
    "trepidaram": "trepidar",
    "trepidaras": "trepidar",
    "trepidardes": "trepidar",
    "trepidarei": "trepidar",
    "trepidareis": "trepidar",
    "trepidarem": "trepidar",
    "trepidaremos": "trepidar",
    "trepidares": "trepidar",
    "trepidaria": "trepidar",
    "trepidariam": "trepidar",
    "trepidarias": "trepidar",
    "trepidarmo": "trepidar",
    "trepidarmos": "trepidar",
    "trepidará": "trepidar",
    "trepidarás": "trepidar",
    "trepidarão": "trepidar",
    "trepidaríamos": "trepidar",
    "trepidaríeis": "trepidar",
    "trepidas": "trepidar",
    "trepidasse": "trepidar",
    "trepidassem": "trepidar",
    "trepidasses": "trepidar",
    "trepidaste": "trepidar",
    "trepidastes": "trepidar",
    "trepidava": "trepidar",
    "trepidavam": "trepidar",
    "trepidavas": "trepidar",
    "trepidações": "trepidação",
    "trepide": "trepidar",
    "trepidei": "trepidar",
    "trepideis": "trepidar",
    "trepidem": "trepidar",
    "trepidemo": "trepidar",
    "trepidemos": "trepidar",
    "trepides": "trepidar",
    "trepidezes": "trepidez",
    "trepido": "trepidar",
    "trepidou": "trepidar",
    "trepidámo": "trepidar",
    "trepidámos": "trepidar",
    "trepidáramo": "trepidar",
    "trepidáramos": "trepidar",
    "trepidáreis": "trepidar",
    "trepidásseis": "trepidar",
    "trepidássemos": "trepidar",
    "trepidávamo": "trepidar",
    "trepidávamos": "trepidar",
    "trepidáveis": "trepidar",
    "trepique": "trepicar",
    "trepiquei": "trepicar",
    "trepiqueis": "trepicar",
    "trepiquem": "trepicar",
    "trepiquemo": "trepicar",
    "trepiquemos": "trepicar",
    "trepiques": "trepicar",
    "treplica": "treplicar",
    "treplicada": "treplicar",
    "treplicadas": "treplicar",
    "treplicado": "treplicar",
    "treplicados": "treplicar",
    "treplicai": "treplicar",
    "treplicais": "treplicar",
    "treplicam": "treplicar",
    "treplicamo": "treplicar",
    "treplicamos": "treplicar",
    "treplicando": "treplicar",
    "treplicara": "treplicar",
    "treplicaram": "treplicar",
    "treplicaras": "treplicar",
    "treplicarde": "treplicar",
    "treplicardes": "treplicar",
    "treplicare": "treplicar",
    "treplicarei": "treplicar",
    "treplicareis": "treplicar",
    "treplicarem": "treplicar",
    "treplicaremos": "treplicar",
    "treplicares": "treplicar",
    "treplicaria": "treplicar",
    "treplicariam": "treplicar",
    "treplicarias": "treplicar",
    "treplicarmo": "treplicar",
    "treplicarmos": "treplicar",
    "treplicará": "treplicar",
    "treplicarás": "treplicar",
    "treplicarão": "treplicar",
    "treplicaríamos": "treplicar",
    "treplicaríeis": "treplicar",
    "treplicas": "treplicar",
    "treplicasse": "treplicar",
    "treplicassem": "treplicar",
    "treplicasses": "treplicar",
    "treplicaste": "treplicar",
    "treplicastes": "treplicar",
    "treplicava": "treplicar",
    "treplicavam": "treplicar",
    "treplicavas": "treplicar",
    "treplico": "treplicar",
    "treplicou": "treplicar",
    "treplicá": "treplicar",
    "treplicámo": "treplicar",
    "treplicámos": "treplicar",
    "treplicáramo": "treplicar",
    "treplicáramos": "treplicar",
    "treplicárei": "treplicar",
    "treplicáreis": "treplicar",
    "treplicásseis": "treplicar",
    "treplicássemos": "treplicar",
    "treplicávamo": "treplicar",
    "treplicávamos": "treplicar",
    "treplicávei": "treplicar",
    "treplicáveis": "treplicar",
    "treplique": "treplicar",
    "trepliquei": "treplicar",
    "trepliqueis": "treplicar",
    "trepliquem": "treplicar",
    "trepliquemo": "treplicar",
    "trepliquemos": "treplicar",
    "trepliques": "treplicar",
    "trepo": "trepar",
    "treponemas": "treponema",
    "trepou": "trepar",
    "trepá": "trepar",
    "trepámo": "trepar",
    "trepámos": "trepar",
    "trepáramo": "trepar",
    "trepáramos": "trepar",
    "trepárei": "trepar",
    "trepáreis": "trepar",
    "trepásseis": "trepar",
    "trepássemos": "trepar",
    "trepávamo": "trepar",
    "trepávamos": "trepar",
    "trepávei": "trepar",
    "trepáveis": "trepar",
    "tresanda": "tresandar",
    "tresandada": "tresandar",
    "tresandadas": "tresandar",
    "tresandado": "tresandar",
    "tresandados": "tresandar",
    "tresandai": "tresandar",
    "tresandais": "tresandar",
    "tresandam": "tresandar",
    "tresandamo": "tresandar",
    "tresandamos": "tresandar",
    "tresandando": "tresandar",
    "tresandara": "tresandar",
    "tresandaram": "tresandar",
    "tresandaras": "tresandar",
    "tresandarde": "tresandar",
    "tresandardes": "tresandar",
    "tresandare": "tresandar",
    "tresandarei": "tresandar",
    "tresandareis": "tresandar",
    "tresandarem": "tresandar",
    "tresandaremos": "tresandar",
    "tresandares": "tresandar",
    "tresandaria": "tresandar",
    "tresandariam": "tresandar",
    "tresandarias": "tresandar",
    "tresandarmo": "tresandar",
    "tresandarmos": "tresandar",
    "tresandará": "tresandar",
    "tresandarás": "tresandar",
    "tresandarão": "tresandar",
    "tresandaríamos": "tresandar",
    "tresandaríeis": "tresandar",
    "tresandas": "tresandar",
    "tresandasse": "tresandar",
    "tresandassem": "tresandar",
    "tresandasses": "tresandar",
    "tresandaste": "tresandar",
    "tresandastes": "tresandar",
    "tresandava": "tresandar",
    "tresandavam": "tresandar",
    "tresandavas": "tresandar",
    "tresande": "tresandar",
    "tresandei": "tresandar",
    "tresandeis": "tresandar",
    "tresandem": "tresandar",
    "tresandemo": "tresandar",
    "tresandemos": "tresandar",
    "tresandes": "tresandar",
    "tresando": "tresandar",
    "tresandou": "tresandar",
    "tresandá": "tresandar",
    "tresandámo": "tresandar",
    "tresandámos": "tresandar",
    "tresandáramo": "tresandar",
    "tresandáramos": "tresandar",
    "tresandárei": "tresandar",
    "tresandáreis": "tresandar",
    "tresandásseis": "tresandar",
    "tresandássemos": "tresandar",
    "tresandávamo": "tresandar",
    "tresandávamos": "tresandar",
    "tresandávei": "tresandar",
    "tresandáveis": "tresandar",
    "trescala": "trescalar",
    "trescalada": "trescalar",
    "trescaladas": "trescalar",
    "trescalado": "trescalar",
    "trescalados": "trescalar",
    "trescalai": "trescalar",
    "trescalais": "trescalar",
    "trescalam": "trescalar",
    "trescalamo": "trescalar",
    "trescalamos": "trescalar",
    "trescalando": "trescalar",
    "trescalantes": "trescalante",
    "trescalara": "trescalar",
    "trescalaram": "trescalar",
    "trescalaras": "trescalar",
    "trescalarde": "trescalar",
    "trescalardes": "trescalar",
    "trescalare": "trescalar",
    "trescalarei": "trescalar",
    "trescalareis": "trescalar",
    "trescalarem": "trescalar",
    "trescalaremos": "trescalar",
    "trescalares": "trescalar",
    "trescalaria": "trescalar",
    "trescalariam": "trescalar",
    "trescalarias": "trescalar",
    "trescalarmo": "trescalar",
    "trescalarmos": "trescalar",
    "trescalará": "trescalar",
    "trescalarás": "trescalar",
    "trescalarão": "trescalar",
    "trescalaríamos": "trescalar",
    "trescalaríeis": "trescalar",
    "trescalas": "trescalar",
    "trescalasse": "trescalar",
    "trescalassem": "trescalar",
    "trescalasses": "trescalar",
    "trescalaste": "trescalar",
    "trescalastes": "trescalar",
    "trescalava": "trescalar",
    "trescalavam": "trescalar",
    "trescalavas": "trescalar",
    "trescale": "trescalar",
    "trescalei": "trescalar",
    "trescaleis": "trescalar",
    "trescalem": "trescalar",
    "trescalemo": "trescalar",
    "trescalemos": "trescalar",
    "trescales": "trescalar",
    "trescalo": "trescalar",
    "trescalou": "trescalar",
    "trescalá": "trescalar",
    "trescalámo": "trescalar",
    "trescalámos": "trescalar",
    "trescaláramo": "trescalar",
    "trescaláramos": "trescalar",
    "trescalárei": "trescalar",
    "trescaláreis": "trescalar",
    "trescalásseis": "trescalar",
    "trescalássemos": "trescalar",
    "trescalávamo": "trescalar",
    "trescalávamos": "trescalar",
    "trescalávei": "trescalar",
    "trescaláveis": "trescalar",
    "trescalências": "trescalência",
    "tresdobra": "tresdobrar",
    "tresdobrada": "tresdobrar",
    "tresdobradas": "tresdobrar",
    "tresdobrado": "tresdobrar",
    "tresdobrados": "tresdobrar",
    "tresdobraduras": "tresdobradura",
    "tresdobrai": "tresdobrar",
    "tresdobrais": "tresdobrar",
    "tresdobram": "tresdobrar",
    "tresdobramo": "tresdobrar",
    "tresdobramos": "tresdobrar",
    "tresdobrando": "tresdobrar",
    "tresdobrara": "tresdobrar",
    "tresdobraram": "tresdobrar",
    "tresdobraras": "tresdobrar",
    "tresdobrarde": "tresdobrar",
    "tresdobrardes": "tresdobrar",
    "tresdobrare": "tresdobrar",
    "tresdobrarei": "tresdobrar",
    "tresdobrareis": "tresdobrar",
    "tresdobrarem": "tresdobrar",
    "tresdobraremos": "tresdobrar",
    "tresdobrares": "tresdobrar",
    "tresdobraria": "tresdobrar",
    "tresdobrariam": "tresdobrar",
    "tresdobrarias": "tresdobrar",
    "tresdobrarmo": "tresdobrar",
    "tresdobrarmos": "tresdobrar",
    "tresdobrará": "tresdobrar",
    "tresdobrarás": "tresdobrar",
    "tresdobrarão": "tresdobrar",
    "tresdobraríamos": "tresdobrar",
    "tresdobraríeis": "tresdobrar",
    "tresdobras": "tresdobrar",
    "tresdobrasse": "tresdobrar",
    "tresdobrassem": "tresdobrar",
    "tresdobrasses": "tresdobrar",
    "tresdobraste": "tresdobrar",
    "tresdobrastes": "tresdobrar",
    "tresdobrava": "tresdobrar",
    "tresdobravam": "tresdobrar",
    "tresdobravas": "tresdobrar",
    "tresdobre": "tresdobrar",
    "tresdobrei": "tresdobrar",
    "tresdobreis": "tresdobrar",
    "tresdobrem": "tresdobrar",
    "tresdobremo": "tresdobrar",
    "tresdobremos": "tresdobrar",
    "tresdobres": "tresdobre",
    "tresdobro": "tresdobrar",
    "tresdobrou": "tresdobrar",
    "tresdobrá": "tresdobrar",
    "tresdobrámo": "tresdobrar",
    "tresdobrámos": "tresdobrar",
    "tresdobráramo": "tresdobrar",
    "tresdobráramos": "tresdobrar",
    "tresdobrárei": "tresdobrar",
    "tresdobráreis": "tresdobrar",
    "tresdobrásseis": "tresdobrar",
    "tresdobrássemos": "tresdobrar",
    "tresdobrávamo": "tresdobrar",
    "tresdobrávamos": "tresdobrar",
    "tresdobrávei": "tresdobrar",
    "tresdobráveis": "tresdobrar",
    "tresfia": "tresfiar",
    "tresfiada": "tresfiar",
    "tresfiadas": "tresfiar",
    "tresfiado": "tresfiar",
    "tresfiados": "tresfiar",
    "tresfiai": "tresfiar",
    "tresfiais": "tresfiar",
    "tresfiam": "tresfiar",
    "tresfiamo": "tresfiar",
    "tresfiamos": "tresfiar",
    "tresfiando": "tresfiar",
    "tresfiara": "tresfiar",
    "tresfiaram": "tresfiar",
    "tresfiaras": "tresfiar",
    "tresfiardes": "tresfiar",
    "tresfiarei": "tresfiar",
    "tresfiareis": "tresfiar",
    "tresfiarem": "tresfiar",
    "tresfiaremos": "tresfiar",
    "tresfiares": "tresfiar",
    "tresfiaria": "tresfiar",
    "tresfiariam": "tresfiar",
    "tresfiarias": "tresfiar",
    "tresfiarmo": "tresfiar",
    "tresfiarmos": "tresfiar",
    "tresfiará": "tresfiar",
    "tresfiarás": "tresfiar",
    "tresfiarão": "tresfiar",
    "tresfiaríamos": "tresfiar",
    "tresfiaríeis": "tresfiar",
    "tresfias": "tresfiar",
    "tresfiasse": "tresfiar",
    "tresfiassem": "tresfiar",
    "tresfiasses": "tresfiar",
    "tresfiaste": "tresfiar",
    "tresfiastes": "tresfiar",
    "tresfiava": "tresfiar",
    "tresfiavam": "tresfiar",
    "tresfiavas": "tresfiar",
    "tresfie": "tresfiar",
    "tresfiei": "tresfiar",
    "tresfieis": "tresfiar",
    "tresfiem": "tresfiar",
    "tresfiemo": "tresfiar",
    "tresfiemos": "tresfiar",
    "tresfies": "tresfiar",
    "tresfio": "tresfiar",
    "tresfiou": "tresfiar",
    "tresfiámo": "tresfiar",
    "tresfiámos": "tresfiar",
    "tresfiáramo": "tresfiar",
    "tresfiáramos": "tresfiar",
    "tresfiáreis": "tresfiar",
    "tresfiásseis": "tresfiar",
    "tresfiássemos": "tresfiar",
    "tresfiávamo": "tresfiar",
    "tresfiávamos": "tresfiar",
    "tresfiáveis": "tresfiar",
    "tresfogueiros": "tresfogueiro",
    "tresfolega": "tresfolegar",
    "tresfolegada": "tresfolegar",
    "tresfolegadas": "tresfolegar",
    "tresfolegado": "tresfolegar",
    "tresfolegados": "tresfolegar",
    "tresfolegai": "tresfolegar",
    "tresfolegais": "tresfolegar",
    "tresfolegam": "tresfolegar",
    "tresfolegamo": "tresfolegar",
    "tresfolegamos": "tresfolegar",
    "tresfolegando": "tresfolegar",
    "tresfolegara": "tresfolegar",
    "tresfolegaram": "tresfolegar",
    "tresfolegaras": "tresfolegar",
    "tresfolegardes": "tresfolegar",
    "tresfolegarei": "tresfolegar",
    "tresfolegareis": "tresfolegar",
    "tresfolegarem": "tresfolegar",
    "tresfolegaremos": "tresfolegar",
    "tresfolegares": "tresfolegar",
    "tresfolegaria": "tresfolegar",
    "tresfolegariam": "tresfolegar",
    "tresfolegarias": "tresfolegar",
    "tresfolegarmo": "tresfolegar",
    "tresfolegarmos": "tresfolegar",
    "tresfolegará": "tresfolegar",
    "tresfolegarás": "tresfolegar",
    "tresfolegarão": "tresfolegar",
    "tresfolegaríamos": "tresfolegar",
    "tresfolegaríeis": "tresfolegar",
    "tresfolegas": "tresfolegar",
    "tresfolegasse": "tresfolegar",
    "tresfolegassem": "tresfolegar",
    "tresfolegasses": "tresfolegar",
    "tresfolegaste": "tresfolegar",
    "tresfolegastes": "tresfolegar",
    "tresfolegava": "tresfolegar",
    "tresfolegavam": "tresfolegar",
    "tresfolegavas": "tresfolegar",
    "tresfolego": "tresfolegar",
    "tresfolegou": "tresfolegar",
    "tresfolegue": "tresfolegar",
    "tresfoleguei": "tresfolegar",
    "tresfolegueis": "tresfolegar",
    "tresfoleguem": "tresfolegar",
    "tresfoleguemo": "tresfolegar",
    "tresfoleguemos": "tresfolegar",
    "tresfolegues": "tresfolegar",
    "tresfolegámo": "tresfolegar",
    "tresfolegámos": "tresfolegar",
    "tresfolegáramo": "tresfolegar",
    "tresfolegáramos": "tresfolegar",
    "tresfolegáreis": "tresfolegar",
    "tresfolegásseis": "tresfolegar",
    "tresfolegássemos": "tresfolegar",
    "tresfolegávamo": "tresfolegar",
    "tresfolegávamos": "tresfolegar",
    "tresfolegáveis": "tresfolegar",
    "tresfolga": "tresfolgar",
    "tresfolgada": "tresfolgar",
    "tresfolgadas": "tresfolgar",
    "tresfolgado": "tresfolgar",
    "tresfolgados": "tresfolgar",
    "tresfolgai": "tresfolgar",
    "tresfolgais": "tresfolgar",
    "tresfolgam": "tresfolgar",
    "tresfolgamo": "tresfolgar",
    "tresfolgamos": "tresfolgar",
    "tresfolgando": "tresfolgar",
    "tresfolgara": "tresfolgar",
    "tresfolgaram": "tresfolgar",
    "tresfolgaras": "tresfolgar",
    "tresfolgardes": "tresfolgar",
    "tresfolgarei": "tresfolgar",
    "tresfolgareis": "tresfolgar",
    "tresfolgarem": "tresfolgar",
    "tresfolgaremos": "tresfolgar",
    "tresfolgares": "tresfolgar",
    "tresfolgaria": "tresfolgar",
    "tresfolgariam": "tresfolgar",
    "tresfolgarias": "tresfolgar",
    "tresfolgarmo": "tresfolgar",
    "tresfolgarmos": "tresfolgar",
    "tresfolgará": "tresfolgar",
    "tresfolgarás": "tresfolgar",
    "tresfolgarão": "tresfolgar",
    "tresfolgaríamos": "tresfolgar",
    "tresfolgaríeis": "tresfolgar",
    "tresfolgas": "tresfolgar",
    "tresfolgasse": "tresfolgar",
    "tresfolgassem": "tresfolgar",
    "tresfolgasses": "tresfolgar",
    "tresfolgaste": "tresfolgar",
    "tresfolgastes": "tresfolgar",
    "tresfolgava": "tresfolgar",
    "tresfolgavam": "tresfolgar",
    "tresfolgavas": "tresfolgar",
    "tresfolgo": "tresfolgar",
    "tresfolgos": "tresfolgo",
    "tresfolgou": "tresfolgar",
    "tresfolgue": "tresfolgar",
    "tresfolguei": "tresfolgar",
    "tresfolgueis": "tresfolgar",
    "tresfolguem": "tresfolgar",
    "tresfolguemo": "tresfolgar",
    "tresfolguemos": "tresfolgar",
    "tresfolgues": "tresfolgar",
    "tresfolgámo": "tresfolgar",
    "tresfolgámos": "tresfolgar",
    "tresfolgáramo": "tresfolgar",
    "tresfolgáramos": "tresfolgar",
    "tresfolgáreis": "tresfolgar",
    "tresfolgásseis": "tresfolgar",
    "tresfolgássemos": "tresfolgar",
    "tresfolgávamo": "tresfolgar",
    "tresfolgávamos": "tresfolgar",
    "tresfolgáveis": "tresfolgar",
    "tresfolia": "tresfoliar",
    "tresfoliada": "tresfoliar",
    "tresfoliadas": "tresfoliar",
    "tresfoliado": "tresfoliar",
    "tresfoliados": "tresfoliar",
    "tresfoliai": "tresfoliar",
    "tresfoliais": "tresfoliar",
    "tresfoliam": "tresfoliar",
    "tresfoliamo": "tresfoliar",
    "tresfoliamos": "tresfoliar",
    "tresfoliando": "tresfoliar",
    "tresfoliara": "tresfoliar",
    "tresfoliaram": "tresfoliar",
    "tresfoliaras": "tresfoliar",
    "tresfoliardes": "tresfoliar",
    "tresfoliarei": "tresfoliar",
    "tresfoliareis": "tresfoliar",
    "tresfoliarem": "tresfoliar",
    "tresfoliaremos": "tresfoliar",
    "tresfoliares": "tresfoliar",
    "tresfoliaria": "tresfoliar",
    "tresfoliariam": "tresfoliar",
    "tresfoliarias": "tresfoliar",
    "tresfoliarmo": "tresfoliar",
    "tresfoliarmos": "tresfoliar",
    "tresfoliará": "tresfoliar",
    "tresfoliarás": "tresfoliar",
    "tresfoliarão": "tresfoliar",
    "tresfoliaríamos": "tresfoliar",
    "tresfoliaríeis": "tresfoliar",
    "tresfolias": "tresfoliar",
    "tresfoliasse": "tresfoliar",
    "tresfoliassem": "tresfoliar",
    "tresfoliasses": "tresfoliar",
    "tresfoliaste": "tresfoliar",
    "tresfoliastes": "tresfoliar",
    "tresfoliava": "tresfoliar",
    "tresfoliavam": "tresfoliar",
    "tresfoliavas": "tresfoliar",
    "tresfolie": "tresfoliar",
    "tresfoliei": "tresfoliar",
    "tresfolieis": "tresfoliar",
    "tresfoliem": "tresfoliar",
    "tresfoliemo": "tresfoliar",
    "tresfoliemos": "tresfoliar",
    "tresfolies": "tresfoliar",
    "tresfolio": "tresfoliar",
    "tresfoliou": "tresfoliar",
    "tresfoliámo": "tresfoliar",
    "tresfoliámos": "tresfoliar",
    "tresfoliáramo": "tresfoliar",
    "tresfoliáramos": "tresfoliar",
    "tresfoliáreis": "tresfoliar",
    "tresfoliásseis": "tresfoliar",
    "tresfoliássemos": "tresfoliar",
    "tresfoliávamo": "tresfoliar",
    "tresfoliávamos": "tresfoliar",
    "tresfoliáveis": "tresfoliar",
    "tresfôlegos": "tresfôlego",
    "tresgasta": "tresgastar",
    "tresgastada": "tresgastar",
    "tresgastadas": "tresgastar",
    "tresgastado": "tresgastar",
    "tresgastadora": "tresgastador",
    "tresgastadoras": "tresgastador",
    "tresgastadores": "tresgastador",
    "tresgastados": "tresgastar",
    "tresgastai": "tresgastar",
    "tresgastais": "tresgastar",
    "tresgastam": "tresgastar",
    "tresgastamo": "tresgastar",
    "tresgastamos": "tresgastar",
    "tresgastando": "tresgastar",
    "tresgastara": "tresgastar",
    "tresgastaram": "tresgastar",
    "tresgastaras": "tresgastar",
    "tresgastarde": "tresgastar",
    "tresgastardes": "tresgastar",
    "tresgastare": "tresgastar",
    "tresgastarei": "tresgastar",
    "tresgastareis": "tresgastar",
    "tresgastarem": "tresgastar",
    "tresgastaremos": "tresgastar",
    "tresgastares": "tresgastar",
    "tresgastaria": "tresgastar",
    "tresgastariam": "tresgastar",
    "tresgastarias": "tresgastar",
    "tresgastarmo": "tresgastar",
    "tresgastarmos": "tresgastar",
    "tresgastará": "tresgastar",
    "tresgastarás": "tresgastar",
    "tresgastarão": "tresgastar",
    "tresgastaríamos": "tresgastar",
    "tresgastaríeis": "tresgastar",
    "tresgastas": "tresgastar",
    "tresgastasse": "tresgastar",
    "tresgastassem": "tresgastar",
    "tresgastasses": "tresgastar",
    "tresgastaste": "tresgastar",
    "tresgastastes": "tresgastar",
    "tresgastava": "tresgastar",
    "tresgastavam": "tresgastar",
    "tresgastavas": "tresgastar",
    "tresgaste": "tresgastar",
    "tresgastei": "tresgastar",
    "tresgasteis": "tresgastar",
    "tresgastem": "tresgastar",
    "tresgastemo": "tresgastar",
    "tresgastemos": "tresgastar",
    "tresgastes": "tresgastar",
    "tresgasto": "tresgastar",
    "tresgastou": "tresgastar",
    "tresgastá": "tresgastar",
    "tresgastámo": "tresgastar",
    "tresgastámos": "tresgastar",
    "tresgastáramo": "tresgastar",
    "tresgastáramos": "tresgastar",
    "tresgastárei": "tresgastar",
    "tresgastáreis": "tresgastar",
    "tresgastásseis": "tresgastar",
    "tresgastássemos": "tresgastar",
    "tresgastávamo": "tresgastar",
    "tresgastávamos": "tresgastar",
    "tresgastávei": "tresgastar",
    "tresgastáveis": "tresgastar",
    "tresjura": "tresjurar",
    "tresjurada": "tresjurar",
    "tresjuradas": "tresjurar",
    "tresjurado": "tresjurar",
    "tresjurados": "tresjurar",
    "tresjurai": "tresjurar",
    "tresjurais": "tresjurar",
    "tresjuram": "tresjurar",
    "tresjuramo": "tresjurar",
    "tresjuramos": "tresjurar",
    "tresjurando": "tresjurar",
    "tresjurara": "tresjurar",
    "tresjuraram": "tresjurar",
    "tresjuraras": "tresjurar",
    "tresjurarde": "tresjurar",
    "tresjurardes": "tresjurar",
    "tresjurare": "tresjurar",
    "tresjurarei": "tresjurar",
    "tresjurareis": "tresjurar",
    "tresjurarem": "tresjurar",
    "tresjuraremos": "tresjurar",
    "tresjurares": "tresjurar",
    "tresjuraria": "tresjurar",
    "tresjurariam": "tresjurar",
    "tresjurarias": "tresjurar",
    "tresjurarmo": "tresjurar",
    "tresjurarmos": "tresjurar",
    "tresjurará": "tresjurar",
    "tresjurarás": "tresjurar",
    "tresjurarão": "tresjurar",
    "tresjuraríamos": "tresjurar",
    "tresjuraríeis": "tresjurar",
    "tresjuras": "tresjurar",
    "tresjurasse": "tresjurar",
    "tresjurassem": "tresjurar",
    "tresjurasses": "tresjurar",
    "tresjuraste": "tresjurar",
    "tresjurastes": "tresjurar",
    "tresjurava": "tresjurar",
    "tresjuravam": "tresjurar",
    "tresjuravas": "tresjurar",
    "tresjure": "tresjurar",
    "tresjurei": "tresjurar",
    "tresjureis": "tresjurar",
    "tresjurem": "tresjurar",
    "tresjuremo": "tresjurar",
    "tresjuremos": "tresjurar",
    "tresjures": "tresjurar",
    "tresjuro": "tresjurar",
    "tresjurou": "tresjurar",
    "tresjurá": "tresjurar",
    "tresjurámo": "tresjurar",
    "tresjurámos": "tresjurar",
    "tresjuráramo": "tresjurar",
    "tresjuráramos": "tresjurar",
    "tresjurárei": "tresjurar",
    "tresjuráreis": "tresjurar",
    "tresjurásseis": "tresjurar",
    "tresjurássemos": "tresjurar",
    "tresjurávamo": "tresjurar",
    "tresjurávamos": "tresjurar",
    "tresjurávei": "tresjurar",
    "tresjuráveis": "tresjurar",
    "treslede": "tresler",
    "tresledes": "tresler",
    "tresleia": "tresler",
    "tresleiais": "tresler",
    "tresleiam": "tresler",
    "tresleiamo": "tresler",
    "tresleiamos": "tresler",
    "tresleias": "tresler",
    "tresleio": "tresler",
    "treslemo": "tresler",
    "treslemos": "tresler",
    "treslendo": "tresler",
    "treslera": "tresler",
    "tresleram": "tresler",
    "tresleras": "tresler",
    "treslerde": "tresler",
    "treslerdes": "tresler",
    "treslere": "tresler",
    "treslerei": "tresler",
    "treslereis": "tresler",
    "treslerem": "tresler",
    "tresleremos": "tresler",
    "tresleres": "tresler",
    "tresleria": "tresler",
    "tresleriam": "tresler",
    "treslerias": "tresler",
    "treslermo": "tresler",
    "treslermos": "tresler",
    "treslerá": "tresler",
    "treslerás": "tresler",
    "treslerão": "tresler",
    "tresleríamos": "tresler",
    "tresleríeis": "tresler",
    "treslesse": "tresler",
    "treslessem": "tresler",
    "treslesses": "tresler",
    "tresleste": "tresler",
    "treslestes": "tresler",
    "tresleu": "tresler",
    "tresli": "tresler",
    "treslia": "tresler",
    "tresliam": "tresler",
    "treslias": "tresler",
    "treslida": "tresler",
    "treslidas": "tresler",
    "treslido": "tresler",
    "treslidos": "tresler",
    "treslouca": "tresloucar",
    "tresloucada": "tresloucar",
    "tresloucadas": "tresloucar",
    "tresloucado": "tresloucar",
    "tresloucados": "tresloucar",
    "tresloucais": "tresloucar",
    "tresloucam": "tresloucar",
    "tresloucamo": "tresloucar",
    "tresloucamos": "tresloucar",
    "tresloucando": "tresloucar",
    "tresloucara": "tresloucar",
    "tresloucaram": "tresloucar",
    "tresloucaras": "tresloucar",
    "tresloucardes": "tresloucar",
    "tresloucarei": "tresloucar",
    "tresloucareis": "tresloucar",
    "tresloucarem": "tresloucar",
    "tresloucaremos": "tresloucar",
    "tresloucares": "tresloucar",
    "tresloucaria": "tresloucar",
    "tresloucariam": "tresloucar",
    "tresloucarias": "tresloucar",
    "tresloucarmo": "tresloucar",
    "tresloucarmos": "tresloucar",
    "tresloucará": "tresloucar",
    "tresloucarás": "tresloucar",
    "tresloucarão": "tresloucar",
    "tresloucaríamos": "tresloucar",
    "tresloucaríeis": "tresloucar",
    "tresloucas": "tresloucar",
    "tresloucasse": "tresloucar",
    "tresloucassem": "tresloucar",
    "tresloucasses": "tresloucar",
    "tresloucaste": "tresloucar",
    "tresloucastes": "tresloucar",
    "tresloucava": "tresloucar",
    "tresloucavam": "tresloucar",
    "tresloucavas": "tresloucar",
    "treslouco": "tresloucar",
    "tresloucou": "tresloucar",
    "tresloucámo": "tresloucar",
    "tresloucámos": "tresloucar",
    "tresloucáramo": "tresloucar",
    "tresloucáramos": "tresloucar",
    "tresloucáreis": "tresloucar",
    "tresloucásseis": "tresloucar",
    "tresloucássemos": "tresloucar",
    "tresloucávamo": "tresloucar",
    "tresloucávamos": "tresloucar",
    "tresloucáveis": "tresloucar",
    "treslouque": "tresloucar",
    "treslouquei": "tresloucar",
    "treslouqueis": "tresloucar",
    "treslouquem": "tresloucar",
    "treslouquemos": "tresloucar",
    "treslouques": "tresloucar",
    "treslê": "tresler",
    "treslêem": "tresler",
    "treslêramo": "tresler",
    "treslêramos": "tresler",
    "treslêrei": "tresler",
    "treslêreis": "tresler",
    "treslês": "tresler",
    "treslêsseis": "tresler",
    "treslêssemos": "tresler",
    "treslíamo": "tresler",
    "treslíamos": "tresler",
    "treslíei": "tresler",
    "treslíeis": "tresler",
    "tresmalha": "tresmalhar",
    "tresmalhada": "tresmalhar",
    "tresmalhadas": "tresmalhar",
    "tresmalhado": "tresmalhar",
    "tresmalhados": "tresmalhar",
    "tresmalhai": "tresmalhar",
    "tresmalhais": "tresmalhar",
    "tresmalham": "tresmalhar",
    "tresmalhamo": "tresmalhar",
    "tresmalhamos": "tresmalhar",
    "tresmalhando": "tresmalhar",
    "tresmalhara": "tresmalhar",
    "tresmalharam": "tresmalhar",
    "tresmalharas": "tresmalhar",
    "tresmalharde": "tresmalhar",
    "tresmalhardes": "tresmalhar",
    "tresmalhare": "tresmalhar",
    "tresmalharei": "tresmalhar",
    "tresmalhareis": "tresmalhar",
    "tresmalharem": "tresmalhar",
    "tresmalharemos": "tresmalhar",
    "tresmalhares": "tresmalhar",
    "tresmalharia": "tresmalhar",
    "tresmalhariam": "tresmalhar",
    "tresmalharias": "tresmalhar",
    "tresmalharmo": "tresmalhar",
    "tresmalharmos": "tresmalhar",
    "tresmalhará": "tresmalhar",
    "tresmalharás": "tresmalhar",
    "tresmalharão": "tresmalhar",
    "tresmalharíamos": "tresmalhar",
    "tresmalharíeis": "tresmalhar",
    "tresmalhas": "tresmalhar",
    "tresmalhasse": "tresmalhar",
    "tresmalhassem": "tresmalhar",
    "tresmalhasses": "tresmalhar",
    "tresmalhaste": "tresmalhar",
    "tresmalhastes": "tresmalhar",
    "tresmalhava": "tresmalhar",
    "tresmalhavam": "tresmalhar",
    "tresmalhavas": "tresmalhar",
    "tresmalhe": "tresmalhar",
    "tresmalhei": "tresmalhar",
    "tresmalheis": "tresmalhar",
    "tresmalhem": "tresmalhar",
    "tresmalhemo": "tresmalhar",
    "tresmalhemos": "tresmalhar",
    "tresmalhes": "tresmalhar",
    "tresmalho": "tresmalhar",
    "tresmalhos": "tresmalho",
    "tresmalhou": "tresmalhar",
    "tresmalhá": "tresmalhar",
    "tresmalhámo": "tresmalhar",
    "tresmalhámos": "tresmalhar",
    "tresmalháramo": "tresmalhar",
    "tresmalháramos": "tresmalhar",
    "tresmalhárei": "tresmalhar",
    "tresmalháreis": "tresmalhar",
    "tresmalhásseis": "tresmalhar",
    "tresmalhássemos": "tresmalhar",
    "tresmalhávamo": "tresmalhar",
    "tresmalhávamos": "tresmalhar",
    "tresmalhávei": "tresmalhar",
    "tresmalháveis": "tresmalhar",
    "tresmonta": "tresmontar",
    "tresmontada": "tresmontar",
    "tresmontadas": "tresmontar",
    "tresmontado": "tresmontar",
    "tresmontados": "tresmontar",
    "tresmontai": "tresmontar",
    "tresmontais": "tresmontar",
    "tresmontam": "tresmontar",
    "tresmontamo": "tresmontar",
    "tresmontamos": "tresmontar",
    "tresmontando": "tresmontar",
    "tresmontara": "tresmontar",
    "tresmontaram": "tresmontar",
    "tresmontaras": "tresmontar",
    "tresmontardes": "tresmontar",
    "tresmontarei": "tresmontar",
    "tresmontareis": "tresmontar",
    "tresmontarem": "tresmontar",
    "tresmontaremos": "tresmontar",
    "tresmontares": "tresmontar",
    "tresmontaria": "tresmontar",
    "tresmontariam": "tresmontar",
    "tresmontarias": "tresmontar",
    "tresmontarmo": "tresmontar",
    "tresmontarmos": "tresmontar",
    "tresmontará": "tresmontar",
    "tresmontarás": "tresmontar",
    "tresmontarão": "tresmontar",
    "tresmontaríamos": "tresmontar",
    "tresmontaríeis": "tresmontar",
    "tresmontas": "tresmontar",
    "tresmontasse": "tresmontar",
    "tresmontassem": "tresmontar",
    "tresmontasses": "tresmontar",
    "tresmontaste": "tresmontar",
    "tresmontastes": "tresmontar",
    "tresmontava": "tresmontar",
    "tresmontavam": "tresmontar",
    "tresmontavas": "tresmontar",
    "tresmonte": "tresmontar",
    "tresmontei": "tresmontar",
    "tresmonteis": "tresmontar",
    "tresmontem": "tresmontar",
    "tresmontemo": "tresmontar",
    "tresmontemos": "tresmontar",
    "tresmontes": "tresmontar",
    "tresmonto": "tresmontar",
    "tresmontou": "tresmontar",
    "tresmontámo": "tresmontar",
    "tresmontámos": "tresmontar",
    "tresmontáramo": "tresmontar",
    "tresmontáramos": "tresmontar",
    "tresmontáreis": "tresmontar",
    "tresmontásseis": "tresmontar",
    "tresmontássemos": "tresmontar",
    "tresmontávamo": "tresmontar",
    "tresmontávamos": "tresmontar",
    "tresmontáveis": "tresmontar",
    "tresnoita": "tresnoitar",
    "tresnoitada": "tresnoitar",
    "tresnoitadas": "tresnoitar",
    "tresnoitado": "tresnoitar",
    "tresnoitados": "tresnoitar",
    "tresnoitai": "tresnoitar",
    "tresnoitais": "tresnoitar",
    "tresnoitam": "tresnoitar",
    "tresnoitamo": "tresnoitar",
    "tresnoitamos": "tresnoitar",
    "tresnoitando": "tresnoitar",
    "tresnoitara": "tresnoitar",
    "tresnoitaram": "tresnoitar",
    "tresnoitaras": "tresnoitar",
    "tresnoitardes": "tresnoitar",
    "tresnoitarei": "tresnoitar",
    "tresnoitareis": "tresnoitar",
    "tresnoitarem": "tresnoitar",
    "tresnoitaremos": "tresnoitar",
    "tresnoitares": "tresnoitar",
    "tresnoitaria": "tresnoitar",
    "tresnoitariam": "tresnoitar",
    "tresnoitarias": "tresnoitar",
    "tresnoitarmo": "tresnoitar",
    "tresnoitarmos": "tresnoitar",
    "tresnoitará": "tresnoitar",
    "tresnoitarás": "tresnoitar",
    "tresnoitarão": "tresnoitar",
    "tresnoitaríamos": "tresnoitar",
    "tresnoitaríeis": "tresnoitar",
    "tresnoitas": "tresnoitar",
    "tresnoitasse": "tresnoitar",
    "tresnoitassem": "tresnoitar",
    "tresnoitasses": "tresnoitar",
    "tresnoitaste": "tresnoitar",
    "tresnoitastes": "tresnoitar",
    "tresnoitava": "tresnoitar",
    "tresnoitavam": "tresnoitar",
    "tresnoitavas": "tresnoitar",
    "tresnoite": "tresnoitar",
    "tresnoitei": "tresnoitar",
    "tresnoiteis": "tresnoitar",
    "tresnoitem": "tresnoitar",
    "tresnoitemo": "tresnoitar",
    "tresnoitemos": "tresnoitar",
    "tresnoites": "tresnoitar",
    "tresnoito": "tresnoitar",
    "tresnoitou": "tresnoitar",
    "tresnoitámo": "tresnoitar",
    "tresnoitámos": "tresnoitar",
    "tresnoitáramo": "tresnoitar",
    "tresnoitáramos": "tresnoitar",
    "tresnoitáreis": "tresnoitar",
    "tresnoitásseis": "tresnoitar",
    "tresnoitássemos": "tresnoitar",
    "tresnoitávamo": "tresnoitar",
    "tresnoitávamos": "tresnoitar",
    "tresnoitáveis": "tresnoitar",
    "tresnouta": "tresnoutar",
    "tresnoutada": "tresnoutar",
    "tresnoutadas": "tresnoutar",
    "tresnoutado": "tresnoutar",
    "tresnoutados": "tresnoutar",
    "tresnoutai": "tresnoutar",
    "tresnoutais": "tresnoutar",
    "tresnoutam": "tresnoutar",
    "tresnoutamo": "tresnoutar",
    "tresnoutamos": "tresnoutar",
    "tresnoutando": "tresnoutar",
    "tresnoutara": "tresnoutar",
    "tresnoutaram": "tresnoutar",
    "tresnoutaras": "tresnoutar",
    "tresnoutardes": "tresnoutar",
    "tresnoutarei": "tresnoutar",
    "tresnoutareis": "tresnoutar",
    "tresnoutarem": "tresnoutar",
    "tresnoutaremos": "tresnoutar",
    "tresnoutares": "tresnoutar",
    "tresnoutaria": "tresnoutar",
    "tresnoutariam": "tresnoutar",
    "tresnoutarias": "tresnoutar",
    "tresnoutarmo": "tresnoutar",
    "tresnoutarmos": "tresnoutar",
    "tresnoutará": "tresnoutar",
    "tresnoutarás": "tresnoutar",
    "tresnoutarão": "tresnoutar",
    "tresnoutaríamos": "tresnoutar",
    "tresnoutaríeis": "tresnoutar",
    "tresnoutas": "tresnoutar",
    "tresnoutasse": "tresnoutar",
    "tresnoutassem": "tresnoutar",
    "tresnoutasses": "tresnoutar",
    "tresnoutaste": "tresnoutar",
    "tresnoutastes": "tresnoutar",
    "tresnoutava": "tresnoutar",
    "tresnoutavam": "tresnoutar",
    "tresnoutavas": "tresnoutar",
    "tresnoute": "tresnoutar",
    "tresnoutei": "tresnoutar",
    "tresnouteis": "tresnoutar",
    "tresnoutem": "tresnoutar",
    "tresnoutemo": "tresnoutar",
    "tresnoutemos": "tresnoutar",
    "tresnoutes": "tresnoutar",
    "tresnouto": "tresnoutar",
    "tresnoutou": "tresnoutar",
    "tresnoutámo": "tresnoutar",
    "tresnoutámos": "tresnoutar",
    "tresnoutáramo": "tresnoutar",
    "tresnoutáramos": "tresnoutar",
    "tresnoutáreis": "tresnoutar",
    "tresnoutásseis": "tresnoutar",
    "tresnoutássemos": "tresnoutar",
    "tresnoutávamo": "tresnoutar",
    "tresnoutávamos": "tresnoutar",
    "tresnoutáveis": "tresnoutar",
    "trespanos": "trespano",
    "trespassa": "trespassar",
    "trespassada": "trespassar",
    "trespassadas": "trespassar",
    "trespassado": "trespassar",
    "trespassados": "trespassar",
    "trespassai": "trespassar",
    "trespassais": "trespassar",
    "trespassam": "trespassar",
    "trespassamo": "trespassar",
    "trespassamos": "trespassar",
    "trespassando": "trespassar",
    "trespassara": "trespassar",
    "trespassaram": "trespassar",
    "trespassaras": "trespassar",
    "trespassarde": "trespassar",
    "trespassardes": "trespassar",
    "trespassare": "trespassar",
    "trespassarei": "trespassar",
    "trespassareis": "trespassar",
    "trespassarem": "trespassar",
    "trespassaremos": "trespassar",
    "trespassares": "trespassar",
    "trespassaria": "trespassar",
    "trespassariam": "trespassar",
    "trespassarias": "trespassar",
    "trespassarmo": "trespassar",
    "trespassarmos": "trespassar",
    "trespassará": "trespassar",
    "trespassarás": "trespassar",
    "trespassarão": "trespassar",
    "trespassaríamos": "trespassar",
    "trespassaríeis": "trespassar",
    "trespassas": "trespassar",
    "trespassasse": "trespassar",
    "trespassassem": "trespassar",
    "trespassasses": "trespassar",
    "trespassaste": "trespassar",
    "trespassastes": "trespassar",
    "trespassava": "trespassar",
    "trespassavam": "trespassar",
    "trespassavas": "trespassar",
    "trespassações": "trespassação",
    "trespasse": "trespassar",
    "trespassei": "trespassar",
    "trespasseis": "trespassar",
    "trespassem": "trespassar",
    "trespassemo": "trespassar",
    "trespassemos": "trespassar",
    "trespasses": "trespasse",
    "trespasso": "trespassar",
    "trespassos": "trespasso",
    "trespassou": "trespassar",
    "trespassá": "trespassar",
    "trespassámo": "trespassar",
    "trespassámos": "trespassar",
    "trespassáramo": "trespassar",
    "trespassáramos": "trespassar",
    "trespassárei": "trespassar",
    "trespassáreis": "trespassar",
    "trespassásseis": "trespassar",
    "trespassássemos": "trespassar",
    "trespassávamo": "trespassar",
    "trespassávamos": "trespassar",
    "trespassávei": "trespassar",
    "trespassáveis": "trespassar",
    "trespomo": "trespor",
    "trespomos": "trespor",
    "tresponde": "trespor",
    "trespondes": "trespor",
    "trespondo": "trespor",
    "tresponha": "trespor",
    "tresponhais": "trespor",
    "tresponham": "trespor",
    "tresponhamo": "trespor",
    "tresponhamos": "trespor",
    "tresponhas": "trespor",
    "tresponho": "trespor",
    "tresporde": "trespor",
    "trespordes": "trespor",
    "trespore": "trespor",
    "tresporei": "trespor",
    "tresporeis": "trespor",
    "tresporem": "trespor",
    "tresporemos": "trespor",
    "trespores": "trespor",
    "tresporia": "trespor",
    "tresporiam": "trespor",
    "tresporias": "trespor",
    "trespormo": "trespor",
    "trespormos": "trespor",
    "tresporá": "trespor",
    "tresporás": "trespor",
    "tresporão": "trespor",
    "tresporíamos": "trespor",
    "tresporíeis": "trespor",
    "tresposta": "trespor",
    "trespostas": "trespor",
    "tresposto": "trespor",
    "trespostos": "trespor",
    "trespunha": "trespor",
    "trespunham": "trespor",
    "trespunhas": "trespor",
    "trespus": "trespor",
    "trespusemo": "trespor",
    "trespusemos": "trespor",
    "trespuser": "trespor",
    "trespusera": "trespor",
    "trespuseram": "trespor",
    "trespuseras": "trespor",
    "trespuserdes": "trespor",
    "trespuserem": "trespor",
    "trespuseres": "trespor",
    "trespusermos": "trespor",
    "trespusesse": "trespor",
    "trespusessem": "trespor",
    "trespusesses": "trespor",
    "trespuseste": "trespor",
    "trespusestes": "trespor",
    "trespuséramo": "trespor",
    "trespuséramos": "trespor",
    "trespusérei": "trespor",
    "trespuséreis": "trespor",
    "trespusésseis": "trespor",
    "trespuséssemos": "trespor",
    "trespô": "trespor",
    "trespôs": "trespor",
    "trespõe": "trespor",
    "trespõem": "trespor",
    "trespões": "trespor",
    "trespúnhamo": "trespor",
    "trespúnhamos": "trespor",
    "trespúnhei": "trespor",
    "trespúnheis": "trespor",
    "tresquiálteras": "tresquiáltera",
    "tressua": "tressuar",
    "tressuada": "tressuar",
    "tressuadas": "tressuar",
    "tressuado": "tressuar",
    "tressuados": "tressuar",
    "tressuai": "tressuar",
    "tressuais": "tressuar",
    "tressuam": "tressuar",
    "tressuamo": "tressuar",
    "tressuamos": "tressuar",
    "tressuando": "tressuar",
    "tressuantes": "tressuante",
    "tressuara": "tressuar",
    "tressuaram": "tressuar",
    "tressuaras": "tressuar",
    "tressuardes": "tressuar",
    "tressuarei": "tressuar",
    "tressuareis": "tressuar",
    "tressuarem": "tressuar",
    "tressuaremos": "tressuar",
    "tressuares": "tressuar",
    "tressuaria": "tressuar",
    "tressuariam": "tressuar",
    "tressuarias": "tressuar",
    "tressuarmo": "tressuar",
    "tressuarmos": "tressuar",
    "tressuará": "tressuar",
    "tressuarás": "tressuar",
    "tressuarão": "tressuar",
    "tressuaríamos": "tressuar",
    "tressuaríeis": "tressuar",
    "tressuas": "tressuar",
    "tressuasse": "tressuar",
    "tressuassem": "tressuar",
    "tressuasses": "tressuar",
    "tressuaste": "tressuar",
    "tressuastes": "tressuar",
    "tressuava": "tressuar",
    "tressuavam": "tressuar",
    "tressuavas": "tressuar",
    "tressue": "tressuar",
    "tressuei": "tressuar",
    "tressueis": "tressuar",
    "tressuem": "tressuar",
    "tressuemo": "tressuar",
    "tressuemos": "tressuar",
    "tressues": "tressuar",
    "tressuo": "tressuar",
    "tressuou": "tressuar",
    "tressuámo": "tressuar",
    "tressuámos": "tressuar",
    "tressuáramo": "tressuar",
    "tressuáramos": "tressuar",
    "tressuáreis": "tressuar",
    "tressuásseis": "tressuar",
    "tressuássemos": "tressuar",
    "tressuávamo": "tressuar",
    "tressuávamos": "tressuar",
    "tressuáveis": "tressuar",
    "trestampa": "trestampar",
    "trestampada": "trestampar",
    "trestampadas": "trestampar",
    "trestampado": "trestampar",
    "trestampados": "trestampar",
    "trestampai": "trestampar",
    "trestampais": "trestampar",
    "trestampam": "trestampar",
    "trestampamo": "trestampar",
    "trestampamos": "trestampar",
    "trestampando": "trestampar",
    "trestampara": "trestampar",
    "trestamparam": "trestampar",
    "trestamparas": "trestampar",
    "trestampardes": "trestampar",
    "trestamparei": "trestampar",
    "trestampareis": "trestampar",
    "trestamparem": "trestampar",
    "trestamparemos": "trestampar",
    "trestampares": "trestampar",
    "trestamparia": "trestampar",
    "trestampariam": "trestampar",
    "trestamparias": "trestampar",
    "trestamparmo": "trestampar",
    "trestamparmos": "trestampar",
    "trestampará": "trestampar",
    "trestamparás": "trestampar",
    "trestamparão": "trestampar",
    "trestamparíamos": "trestampar",
    "trestamparíeis": "trestampar",
    "trestampas": "trestampar",
    "trestampasse": "trestampar",
    "trestampassem": "trestampar",
    "trestampasses": "trestampar",
    "trestampaste": "trestampar",
    "trestampastes": "trestampar",
    "trestampava": "trestampar",
    "trestampavam": "trestampar",
    "trestampavas": "trestampar",
    "trestampe": "trestampar",
    "trestampei": "trestampar",
    "trestampeis": "trestampar",
    "trestampem": "trestampar",
    "trestampemo": "trestampar",
    "trestampemos": "trestampar",
    "trestampes": "trestampar",
    "trestampo": "trestampar",
    "trestampou": "trestampar",
    "trestampámo": "trestampar",
    "trestampámos": "trestampar",
    "trestampáramo": "trestampar",
    "trestampáramos": "trestampar",
    "trestampáreis": "trestampar",
    "trestampásseis": "trestampar",
    "trestampássemos": "trestampar",
    "trestampávamo": "trestampar",
    "trestampávamos": "trestampar",
    "trestampáveis": "trestampar",
    "tresvairos": "tresvairo",
    "tresvaria": "tresvariar",
    "tresvariada": "tresvariar",
    "tresvariadas": "tresvariar",
    "tresvariado": "tresvariar",
    "tresvariados": "tresvariar",
    "tresvariai": "tresvariar",
    "tresvariais": "tresvariar",
    "tresvariam": "tresvariar",
    "tresvariamo": "tresvariar",
    "tresvariamos": "tresvariar",
    "tresvariando": "tresvariar",
    "tresvariara": "tresvariar",
    "tresvariaram": "tresvariar",
    "tresvariaras": "tresvariar",
    "tresvariardes": "tresvariar",
    "tresvariarei": "tresvariar",
    "tresvariareis": "tresvariar",
    "tresvariarem": "tresvariar",
    "tresvariaremos": "tresvariar",
    "tresvariares": "tresvariar",
    "tresvariaria": "tresvariar",
    "tresvariariam": "tresvariar",
    "tresvariarias": "tresvariar",
    "tresvariarmo": "tresvariar",
    "tresvariarmos": "tresvariar",
    "tresvariará": "tresvariar",
    "tresvariarás": "tresvariar",
    "tresvariarão": "tresvariar",
    "tresvariaríamos": "tresvariar",
    "tresvariaríeis": "tresvariar",
    "tresvarias": "tresvariar",
    "tresvariasse": "tresvariar",
    "tresvariassem": "tresvariar",
    "tresvariasses": "tresvariar",
    "tresvariaste": "tresvariar",
    "tresvariastes": "tresvariar",
    "tresvariava": "tresvariar",
    "tresvariavam": "tresvariar",
    "tresvariavas": "tresvariar",
    "tresvarie": "tresvariar",
    "tresvariei": "tresvariar",
    "tresvarieis": "tresvariar",
    "tresvariem": "tresvariar",
    "tresvariemo": "tresvariar",
    "tresvariemos": "tresvariar",
    "tresvaries": "tresvariar",
    "tresvario": "tresvariar",
    "tresvarios": "tresvario",
    "tresvariou": "tresvariar",
    "tresvariámo": "tresvariar",
    "tresvariámos": "tresvariar",
    "tresvariáramo": "tresvariar",
    "tresvariáramos": "tresvariar",
    "tresvariáreis": "tresvariar",
    "tresvariásseis": "tresvariar",
    "tresvariássemos": "tresvariar",
    "tresvariávamo": "tresvariar",
    "tresvariávamos": "tresvariar",
    "tresvariáveis": "tresvariar",
    "tresvolteada": "tresvoltear",
    "tresvolteadas": "tresvoltear",
    "tresvolteado": "tresvoltear",
    "tresvolteados": "tresvoltear",
    "tresvolteai": "tresvoltear",
    "tresvolteais": "tresvoltear",
    "tresvolteamo": "tresvoltear",
    "tresvolteamos": "tresvoltear",
    "tresvolteando": "tresvoltear",
    "tresvolteara": "tresvoltear",
    "tresvoltearam": "tresvoltear",
    "tresvoltearas": "tresvoltear",
    "tresvoltearde": "tresvoltear",
    "tresvolteardes": "tresvoltear",
    "tresvolteare": "tresvoltear",
    "tresvoltearei": "tresvoltear",
    "tresvolteareis": "tresvoltear",
    "tresvoltearem": "tresvoltear",
    "tresvoltearemos": "tresvoltear",
    "tresvolteares": "tresvoltear",
    "tresvoltearia": "tresvoltear",
    "tresvolteariam": "tresvoltear",
    "tresvoltearias": "tresvoltear",
    "tresvoltearmo": "tresvoltear",
    "tresvoltearmos": "tresvoltear",
    "tresvolteará": "tresvoltear",
    "tresvoltearás": "tresvoltear",
    "tresvoltearão": "tresvoltear",
    "tresvoltearíamos": "tresvoltear",
    "tresvoltearíeis": "tresvoltear",
    "tresvolteasse": "tresvoltear",
    "tresvolteassem": "tresvoltear",
    "tresvolteasses": "tresvoltear",
    "tresvolteaste": "tresvoltear",
    "tresvolteastes": "tresvoltear",
    "tresvolteava": "tresvoltear",
    "tresvolteavam": "tresvoltear",
    "tresvolteavas": "tresvoltear",
    "tresvolteei": "tresvoltear",
    "tresvolteeis": "tresvoltear",
    "tresvolteemo": "tresvoltear",
    "tresvolteemos": "tresvoltear",
    "tresvolteia": "tresvoltear",
    "tresvolteiam": "tresvoltear",
    "tresvolteias": "tresvoltear",
    "tresvolteie": "tresvoltear",
    "tresvolteiem": "tresvoltear",
    "tresvolteies": "tresvoltear",
    "tresvolteio": "tresvoltear",
    "tresvolteou": "tresvoltear",
    "tresvolteá": "tresvoltear",
    "tresvolteámo": "tresvoltear",
    "tresvolteámos": "tresvoltear",
    "tresvolteáramo": "tresvoltear",
    "tresvolteáramos": "tresvoltear",
    "tresvolteárei": "tresvoltear",
    "tresvolteáreis": "tresvoltear",
    "tresvolteásseis": "tresvoltear",
    "tresvolteássemos": "tresvoltear",
    "tresvolteávamo": "tresvoltear",
    "tresvolteávamos": "tresvoltear",
    "tresvolteávei": "tresvoltear",
    "tresvolteáveis": "tresvoltear",
    "tretas": "treta",
    "treteira": "treteiro",
    "treteiras": "treteiro",
    "treteiros": "treteiro",
    "trevagens": "trevagem",
    "trevas": "treva",
    "trevites": "trevite",
    "trevos": "trevo",
    "trevosa": "trevoso",
    "trevosas": "trevoso",
    "trevosos": "trevoso",
    "trezena": "trezeno",
    "trezenas": "trezeno",
    "trezenos": "trezeno",
    "trezentas": "trezentos",
    "trezénia": "trezénio",
    "trezénias": "trezénio",
    "trezénios": "trezénio",
    "treçolhos": "treçolho",
    "triada": "triado",
    "triadas": "triado",
    "triadelfa": "triadelfo",
    "triadelfas": "triadelfo",
    "triadelfos": "triadelfo",
    "triados": "triado",
    "triagas": "triaga",
    "triagens": "triagem",
    "triagueira": "triagueiro",
    "triagueiras": "triagueiro",
    "triagueiros": "triagueiro",
    "triandra": "triandro",
    "triandras": "triandro",
    "triandrias": "triandria",
    "triandros": "triandro",
    "trianguladora": "triangulador",
    "trianguladoras": "triangulador",
    "trianguladores": "triangulador",
    "triangulara": "triangular",
    "triangularas": "triangular",
    "triangulares": "triangular",
    "triangularidades": "triangularidade",
    "triangulações": "triangulação",
    "trianuais": "trianual",
    "triarcas": "triarca",
    "triarestada": "triarestado",
    "triarestadas": "triarestado",
    "triarestados": "triarestado",
    "triarquias": "triarquia",
    "triass": "trias",
    "triatlos": "triatlo",
    "triatomicidades": "triatomicidade",
    "triatómica": "triatómico",
    "triatómicas": "triatómico",
    "triatómicos": "triatómico",
    "triaxífera": "triaxífero",
    "triaxíferas": "triaxífero",
    "triaxíferos": "triaxífero",
    "tribadismos": "tribadismo",
    "tribais": "tribal",
    "tribala": "tribalo",
    "tribalas": "tribalo",
    "tribalismos": "tribalismo",
    "tribalos": "tribalo",
    "tribasicidades": "tribasicidade",
    "triboelectricidades": "triboelectricidade",
    "tribofes": "tribofe",
    "tribofísicas": "tribofísica",
    "triboluminescências": "triboluminescência",
    "tribometrias": "tribometria",
    "tribos": "tribo",
    "tribula": "tribular",
    "tribulada": "tribular",
    "tribuladas": "tribular",
    "tribulado": "tribular",
    "tribulados": "tribular",
    "tribulai": "tribular",
    "tribulais": "tribular",
    "tribulam": "tribular",
    "tribulamo": "tribular",
    "tribulamos": "tribular",
    "tribulando": "tribular",
    "tribulara": "tribular",
    "tribularam": "tribular",
    "tribularas": "tribular",
    "tribularde": "tribular",
    "tribulardes": "tribular",
    "tribulare": "tribular",
    "tribularei": "tribular",
    "tribulareis": "tribular",
    "tribularem": "tribular",
    "tribularemos": "tribular",
    "tribulares": "tribular",
    "tribularia": "tribular",
    "tribulariam": "tribular",
    "tribularias": "tribular",
    "tribularmo": "tribular",
    "tribularmos": "tribular",
    "tribulará": "tribular",
    "tribularás": "tribular",
    "tribularão": "tribular",
    "tribularíamos": "tribular",
    "tribularíeis": "tribular",
    "tribulas": "tribular",
    "tribulasse": "tribular",
    "tribulassem": "tribular",
    "tribulasses": "tribular",
    "tribulaste": "tribular",
    "tribulastes": "tribular",
    "tribulava": "tribular",
    "tribulavam": "tribular",
    "tribulavas": "tribular",
    "tribulações": "tribulação",
    "tribule": "tribular",
    "tribulei": "tribular",
    "tribuleis": "tribular",
    "tribulem": "tribular",
    "tribulemo": "tribular",
    "tribulemos": "tribular",
    "tribules": "tribular",
    "tribulo": "tribular",
    "tribulou": "tribular",
    "tribulá": "tribular",
    "tribulámo": "tribular",
    "tribulámos": "tribular",
    "tribuláramo": "tribular",
    "tribuláramos": "tribular",
    "tribulárei": "tribular",
    "tribuláreis": "tribular",
    "tribulásseis": "tribular",
    "tribulássemos": "tribular",
    "tribulávamo": "tribular",
    "tribulávamos": "tribular",
    "tribulávei": "tribular",
    "tribuláveis": "tribular",
    "tribunados": "tribunado",
    "tribunais": "tribunal",
    "tribunas": "tribuna",
    "tribunatos": "tribunato",
    "tribunecas": "tribuneca",
    "tribunocracias": "tribunocracia",
    "tribunos": "tribuno",
    "tribunícia": "tribunício",
    "tribunícias": "tribunício",
    "tribunícios": "tribunício",
    "tributa": "tributar",
    "tributada": "tributar",
    "tributadas": "tributar",
    "tributado": "tributar",
    "tributados": "tributar",
    "tributai": "tributar",
    "tributais": "tributar",
    "tributam": "tributar",
    "tributamo": "tributar",
    "tributamos": "tributar",
    "tributanda": "tributando",
    "tributandas": "tributando",
    "tributando": "tributar",
    "tributandos": "tributando",
    "tributara": "tributar",
    "tributaram": "tributar",
    "tributaras": "tributar",
    "tributarde": "tributar",
    "tributardes": "tributar",
    "tributare": "tributar",
    "tributarei": "tributar",
    "tributareis": "tributar",
    "tributarem": "tributar",
    "tributaremos": "tributar",
    "tributares": "tributar",
    "tributaria": "tributar",
    "tributariam": "tributar",
    "tributarias": "tributar",
    "tributarmo": "tributar",
    "tributarmos": "tributar",
    "tributará": "tributar",
    "tributarás": "tributar",
    "tributarão": "tributar",
    "tributaríamos": "tributar",
    "tributaríeis": "tributar",
    "tributas": "tributar",
    "tributasse": "tributar",
    "tributassem": "tributar",
    "tributasses": "tributar",
    "tributaste": "tributar",
    "tributastes": "tributar",
    "tributava": "tributar",
    "tributavam": "tributar",
    "tributavas": "tributar",
    "tributações": "tributação",
    "tribute": "tributar",
    "tributei": "tributar",
    "tributeis": "tributar",
    "tributem": "tributar",
    "tributemo": "tributar",
    "tributemos": "tributar",
    "tributes": "tributar",
    "tributo": "tributar",
    "tributos": "tributo",
    "tributou": "tributar",
    "tributá": "tributar",
    "tributámo": "tributar",
    "tributámos": "tributar",
    "tributáramo": "tributar",
    "tributáramos": "tributar",
    "tributárei": "tributar",
    "tributáreis": "tributar",
    "tributária": "tributário",
    "tributárias": "tributário",
    "tributários": "tributário",
    "tributásseis": "tributar",
    "tributássemos": "tributar",
    "tributávamo": "tributar",
    "tributávamos": "tributar",
    "tributávei": "tributar",
    "tributáveis": "tributável",
    "tribásica": "tribásico",
    "tribásicas": "tribásico",
    "tribásicos": "tribásico",
    "tribómetros": "tribómetro",
    "trica": "tricar",
    "tricada": "tricar",
    "tricadas": "tricar",
    "tricado": "tricar",
    "tricados": "tricar",
    "tricais": "tricar",
    "tricam": "tricar",
    "tricamo": "tricar",
    "tricamos": "tricar",
    "tricampeã": "tricampeão",
    "tricampeãs": "tricampeão",
    "tricampeões": "tricampeão",
    "tricampionatos": "tricampionato",
    "tricampiã": "tricampião",
    "tricampiãs": "tricampião",
    "tricampiões": "tricampião",
    "tricanas": "tricana",
    "tricando": "tricar",
    "tricanta": "tricanto",
    "tricantas": "tricanto",
    "tricantos": "tricanto",
    "tricapsulares": "tricapsular",
    "tricara": "tricar",
    "tricaram": "tricar",
    "tricaras": "tricar",
    "tricardes": "tricar",
    "tricarei": "tricar",
    "tricareis": "tricar",
    "tricarem": "tricar",
    "tricaremos": "tricar",
    "tricares": "tricar",
    "tricaria": "tricar",
    "tricariam": "tricar",
    "tricarias": "tricar",
    "tricarmo": "tricar",
    "tricarmos": "tricar",
    "tricará": "tricar",
    "tricarás": "tricar",
    "tricarão": "tricar",
    "tricaríamos": "tricar",
    "tricaríeis": "tricar",
    "tricas": "tricar",
    "tricasse": "tricar",
    "tricassem": "tricar",
    "tricasses": "tricar",
    "tricaste": "tricar",
    "tricastes": "tricar",
    "tricava": "tricar",
    "tricavam": "tricar",
    "tricavas": "tricar",
    "tricefalias": "tricefalia",
    "tricelulares": "tricelular",
    "tricenais": "tricenal",
    "tricentenária": "tricentenário",
    "tricentenárias": "tricentenário",
    "tricentenários": "tricentenário",
    "tricentésima": "tricentésimo",
    "tricentésimas": "tricentésimo",
    "tricentésimos": "tricentésimo",
    "trichetes": "trichete",
    "tricicletas": "tricicleta",
    "triciclos": "triciclo",
    "tricinquentenários": "tricinquentenário",
    "tricipais": "tricipal",
    "tricliniarcas": "tricliniarca",
    "triclinária": "triclinário",
    "triclinárias": "triclinário",
    "triclinários": "triclinário",
    "triclínica": "triclínico",
    "triclínicas": "triclínico",
    "triclínicos": "triclínico",
    "triclínios": "triclínio",
    "trico": "tricar",
    "tricoca": "tricoco",
    "tricocas": "tricoco",
    "tricocistes": "tricociste",
    "tricocos": "tricoco",
    "tricofitias": "tricofitia",
    "tricofitíases": "tricofitíase",
    "tricofobias": "tricofobia",
    "tricogínios": "tricogínio",
    "tricologias": "tricologia",
    "tricolores": "tricolor",
    "tricomas": "tricoma",
    "tricomatosa": "tricomatoso",
    "tricomatosas": "tricomatoso",
    "tricomatosos": "tricomatoso",
    "tricomonas": "tricomona",
    "tricopatias": "tricopatia",
    "tricorda": "tricordo",
    "tricordas": "tricordo",
    "tricordes": "tricorde",
    "tricordo": "tricorde",
    "tricordos": "tricordo",
    "tricornes": "tricorne",
    "tricosa": "tricoso",
    "tricosas": "tricoso",
    "tricoses": "tricose",
    "tricosos": "tricoso",
    "tricot": "tricô",
    "tricota": "tricotar",
    "tricotada": "tricotar",
    "tricotadas": "tricotar",
    "tricotado": "tricotar",
    "tricotados": "tricotar",
    "tricotai": "tricotar",
    "tricotais": "tricotar",
    "tricotam": "tricotar",
    "tricotamo": "tricotar",
    "tricotamos": "tricotar",
    "tricotando": "tricotar",
    "tricotara": "tricotar",
    "tricotaram": "tricotar",
    "tricotaras": "tricotar",
    "tricotarde": "tricotar",
    "tricotardes": "tricotar",
    "tricotare": "tricotar",
    "tricotarei": "tricotar",
    "tricotareis": "tricotar",
    "tricotarem": "tricotar",
    "tricotaremos": "tricotar",
    "tricotares": "tricotar",
    "tricotaria": "tricotar",
    "tricotariam": "tricotar",
    "tricotarias": "tricotar",
    "tricotarmo": "tricotar",
    "tricotarmos": "tricotar",
    "tricotará": "tricotar",
    "tricotarás": "tricotar",
    "tricotarão": "tricotar",
    "tricotaríamos": "tricotar",
    "tricotaríeis": "tricotar",
    "tricotas": "tricotar",
    "tricotasse": "tricotar",
    "tricotassem": "tricotar",
    "tricotasses": "tricotar",
    "tricotaste": "tricotar",
    "tricotastes": "tricotar",
    "tricotava": "tricotar",
    "tricotavam": "tricotar",
    "tricotavas": "tricotar",
    "tricote": "tricotar",
    "tricotei": "tricotar",
    "tricoteis": "tricotar",
    "tricotem": "tricotar",
    "tricotemo": "tricotar",
    "tricotemos": "tricotar",
    "tricotes": "tricotar",
    "tricoto": "tricotar",
    "tricotomias": "tricotomia",
    "tricotou": "tricotar",
    "tricots": "tricô",
    "tricotá": "tricotar",
    "tricotámo": "tricotar",
    "tricotámos": "tricotar",
    "tricotáramo": "tricotar",
    "tricotáramos": "tricotar",
    "tricotárei": "tricotar",
    "tricotáreis": "tricotar",
    "tricotásseis": "tricotar",
    "tricotássemos": "tricotar",
    "tricotávamo": "tricotar",
    "tricotávamos": "tricotar",
    "tricotávei": "tricotar",
    "tricotáveis": "tricotar",
    "tricotómica": "tricotómico",
    "tricotómicas": "tricotómico",
    "tricotómicos": "tricotómico",
    "tricou": "tricar",
    "tricromias": "tricromia",
    "tricroísmos": "tricroísmo",
    "tricámo": "tricar",
    "tricámos": "tricar",
    "tricáramo": "tricar",
    "tricáramos": "tricar",
    "tricáreis": "tricar",
    "tricásseis": "tricar",
    "tricássemos": "tricar",
    "tricávamo": "tricar",
    "tricávamos": "tricar",
    "tricáveis": "tricar",
    "tricâmara": "tricâmaro",
    "tricâmaras": "tricâmaro",
    "tricâmaros": "tricâmaro",
    "tricâmera": "tricâmero",
    "tricâmeras": "tricâmero",
    "tricâmeros": "tricâmero",
    "tricéfala": "tricéfalo",
    "tricéfalas": "tricéfalo",
    "tricéfalos": "tricéfalo",
    "tricénios": "tricénio",
    "tricêntrica": "tricêntrico",
    "tricêntricas": "tricêntrico",
    "tricêntricos": "tricêntrico",
    "tricípites": "tricípite",
    "tricófitos": "tricófito",
    "tricófoba": "tricófobo",
    "tricófobas": "tricófobo",
    "tricófobos": "tricófobo",
    "tricóginos": "tricógino",
    "tricóides": "tricóide",
    "tricórnios": "tricórnio",
    "tricôs": "tricô",
    "tricúspida": "tricúspide",
    "tricúspidas": "tricúspide",
    "tricúspides": "tricúspide",
    "tridentada": "tridentado",
    "tridentadas": "tridentado",
    "tridentados": "tridentado",
    "tridentes": "tridente",
    "tridentina": "tridentino",
    "tridentinas": "tridentino",
    "tridentinos": "tridentino",
    "tridentífera": "tridentífero",
    "tridentíferas": "tridentífero",
    "tridentíferos": "tridentífero",
    "tridentígera": "tridentígero",
    "tridentígeras": "tridentígero",
    "tridentígeros": "tridentígero",
    "tridigitada": "tridigitado",
    "tridigitadas": "tridigitado",
    "tridigitados": "tridigitado",
    "tridimensionais": "tridimensional",
    "tridimites": "tridimite",
    "triduana": "triduano",
    "triduanas": "triduano",
    "triduanos": "triduano",
    "tridáctila": "tridáctilo",
    "tridáctilas": "tridáctilo",
    "tridáctilos": "tridáctilo",
    "tridérmica": "tridérmico",
    "tridérmicas": "tridérmico",
    "tridérmicos": "tridérmico",
    "tridêntia": "tridêntio",
    "tridêntias": "tridêntio",
    "tridêntios": "tridêntio",
    "triebdomadária": "triebdomadário",
    "triebdomadárias": "triebdomadário",
    "triebdomadários": "triebdomadário",
    "trieca": "trieco",
    "triecas": "trieco",
    "triecos": "trieco",
    "triedra": "triedro",
    "triedras": "triedro",
    "triedros": "triedro",
    "triemímeres": "triemímere",
    "trienados": "trienado",
    "trienais": "trienal",
    "trierarcas": "trierarca",
    "trierarquias": "trierarquia",
    "triestina": "triestino",
    "triestinas": "triestino",
    "triestinos": "triestino",
    "trietéricos": "trietérico",
    "trietérides": "trietéride",
    "trifaciais": "trifacial",
    "trifauces": "trifauce",
    "triflora": "trifloro",
    "trifloras": "trifloro",
    "trifloros": "trifloro",
    "trifoliada": "trifoliado",
    "trifoliadas": "trifoliado",
    "trifoliados": "trifoliado",
    "trifoliolada": "trifoliolado",
    "trifolioladas": "trifoliolado",
    "trifoliolados": "trifoliolado",
    "trifolioses": "trifoliose",
    "trifoliáceas": "trifoliácea",
    "triformes": "triforme",
    "trifurca": "trifurcar",
    "trifurcada": "trifurcar",
    "trifurcadas": "trifurcar",
    "trifurcado": "trifurcar",
    "trifurcados": "trifurcar",
    "trifurcais": "trifurcar",
    "trifurcam": "trifurcar",
    "trifurcamo": "trifurcar",
    "trifurcamos": "trifurcar",
    "trifurcando": "trifurcar",
    "trifurcara": "trifurcar",
    "trifurcaram": "trifurcar",
    "trifurcaras": "trifurcar",
    "trifurcardes": "trifurcar",
    "trifurcarei": "trifurcar",
    "trifurcareis": "trifurcar",
    "trifurcarem": "trifurcar",
    "trifurcaremos": "trifurcar",
    "trifurcares": "trifurcar",
    "trifurcaria": "trifurcar",
    "trifurcariam": "trifurcar",
    "trifurcarias": "trifurcar",
    "trifurcarmo": "trifurcar",
    "trifurcarmos": "trifurcar",
    "trifurcará": "trifurcar",
    "trifurcarás": "trifurcar",
    "trifurcarão": "trifurcar",
    "trifurcaríamos": "trifurcar",
    "trifurcaríeis": "trifurcar",
    "trifurcas": "trifurcar",
    "trifurcasse": "trifurcar",
    "trifurcassem": "trifurcar",
    "trifurcasses": "trifurcar",
    "trifurcaste": "trifurcar",
    "trifurcastes": "trifurcar",
    "trifurcava": "trifurcar",
    "trifurcavam": "trifurcar",
    "trifurcavas": "trifurcar",
    "trifurcações": "trifurcação",
    "trifurco": "trifurcar",
    "trifurcou": "trifurcar",
    "trifurcámo": "trifurcar",
    "trifurcámos": "trifurcar",
    "trifurcáramo": "trifurcar",
    "trifurcáramos": "trifurcar",
    "trifurcáreis": "trifurcar",
    "trifurcásseis": "trifurcar",
    "trifurcássemos": "trifurcar",
    "trifurcávamo": "trifurcar",
    "trifurcávamos": "trifurcar",
    "trifurcáveis": "trifurcar",
    "trifurque": "trifurcar",
    "trifurquei": "trifurcar",
    "trifurqueis": "trifurcar",
    "trifurquem": "trifurcar",
    "trifurquemos": "trifurcar",
    "trifurques": "trifurcar",
    "trifusas": "trifusa",
    "trifásica": "trifásico",
    "trifásicas": "trifásico",
    "trifásicos": "trifásico",
    "trifólia": "trifólio",
    "trifólias": "trifólio",
    "trifólios": "trifólio",
    "trifórios": "trifório",
    "triga": "trigo",
    "trigada": "trigar",
    "trigadas": "trigar",
    "trigado": "trigar",
    "trigados": "trigar",
    "trigai": "trigar",
    "trigais": "trigar",
    "trigam": "trigar",
    "trigamias": "trigamia",
    "trigamo": "trigar",
    "trigamos": "trigar",
    "trigando": "trigar",
    "triganças": "trigança",
    "trigara": "trigar",
    "trigaram": "trigar",
    "trigaras": "trigar",
    "trigarde": "trigar",
    "trigardes": "trigar",
    "trigare": "trigar",
    "trigarei": "trigar",
    "trigareis": "trigar",
    "trigarem": "trigar",
    "trigaremos": "trigar",
    "trigares": "trigar",
    "trigaria": "trigar",
    "trigariam": "trigar",
    "trigarias": "trigar",
    "trigarmo": "trigar",
    "trigarmos": "trigar",
    "trigará": "trigar",
    "trigarás": "trigar",
    "trigarão": "trigar",
    "trigaríamos": "trigar",
    "trigaríeis": "trigar",
    "trigas": "trigo",
    "trigasse": "trigar",
    "trigassem": "trigar",
    "trigasses": "trigar",
    "trigaste": "trigar",
    "trigastes": "trigar",
    "trigava": "trigar",
    "trigavam": "trigar",
    "trigavas": "trigar",
    "trigeminada": "trigeminado",
    "trigeminadas": "trigeminado",
    "trigeminados": "trigeminado",
    "triginias": "triginia",
    "trigloquina": "trigloquino",
    "trigloquinas": "trigloquino",
    "trigloquines": "trigloquine",
    "trigloquinos": "trigloquino",
    "trigloquináceas": "trigloquinácea",
    "triglota": "trigloto",
    "triglotas": "trigloto",
    "triglotos": "trigloto",
    "triglídeos": "triglídeo",
    "trigo": "trigar",
    "trigonocarpa": "trigonocarpo",
    "trigonocarpas": "trigonocarpo",
    "trigonocarpos": "trigonocarpo",
    "trigonocefalias": "trigonocefalia",
    "trigonocéfala": "trigonocéfalo",
    "trigonocéfalas": "trigonocéfalo",
    "trigonocéfalos": "trigonocéfalo",
    "trigonometrias": "trigonometria",
    "trigonométrica": "trigonométrico",
    "trigonométricas": "trigonométrico",
    "trigonométricos": "trigonométrico",
    "trigonídeos": "trigonídeo",
    "trigos": "trigo",
    "trigosa": "trigoso",
    "trigosas": "trigoso",
    "trigosos": "trigoso",
    "trigou": "trigar",
    "trigramas": "trigrama",
    "trigue": "trigar",
    "triguei": "trigar",
    "trigueira": "trigueiro",
    "trigueiras": "trigueiro",
    "trigueirazinha": "trigueiro",
    "trigueirazinhas": "trigueiro",
    "trigueirazita": "trigueiro",
    "trigueirazitas": "trigueiro",
    "trigueirinha": "trigueiro",
    "trigueirinhas": "trigueiro",
    "trigueirinho": "trigueiro",
    "trigueirinhos": "trigueiro",
    "trigueirita": "trigueiro",
    "trigueiritas": "trigueiro",
    "trigueirito": "trigueiro",
    "trigueiritos": "trigueiro",
    "trigueiros": "trigueiro",
    "trigueirota": "trigueirote",
    "trigueirotas": "trigueirote",
    "trigueirotes": "trigueirote",
    "trigueirozinho": "trigueiro",
    "trigueirozinhos": "trigueiro",
    "trigueirozito": "trigueiro",
    "trigueirozitos": "trigueiro",
    "trigueis": "trigar",
    "triguem": "trigar",
    "triguemo": "trigar",
    "triguemos": "trigar",
    "triguenha": "triguenho",
    "triguenhas": "triguenho",
    "triguenhos": "triguenho",
    "trigues": "trigar",
    "triguilhos": "triguilho",
    "trigá": "trigar",
    "trigámo": "trigar",
    "trigámos": "trigar",
    "trigáramo": "trigar",
    "trigáramos": "trigar",
    "trigárei": "trigar",
    "trigáreis": "trigar",
    "trigários": "trigário",
    "trigásseis": "trigar",
    "trigássemos": "trigar",
    "trigávamo": "trigar",
    "trigávamos": "trigar",
    "trigávei": "trigar",
    "trigáveis": "trigar",
    "trigémea": "trigémeo",
    "trigémeas": "trigémeo",
    "trigémeos": "trigémeo",
    "trigémina": "trigémino",
    "trigéminas": "trigémino",
    "trigéminos": "trigémino",
    "trigésima": "trigésimo",
    "trigésimas": "trigésimo",
    "trigésimos": "trigésimo",
    "trigónias": "trigónia",
    "trigónidas": "trigónida",
    "trijugada": "trijugado",
    "trijugadas": "trijugado",
    "trijugados": "trijugado",
    "trila": "trilar",
    "trilada": "trilar",
    "triladas": "trilar",
    "trilado": "trilar",
    "trilados": "trilar",
    "trilai": "trilar",
    "trilais": "trilar",
    "trilam": "trilar",
    "trilamo": "trilar",
    "trilamos": "trilar",
    "trilando": "trilar",
    "trilara": "trilar",
    "trilaram": "trilar",
    "trilaras": "trilar",
    "trilarde": "trilar",
    "trilardes": "trilar",
    "trilare": "trilar",
    "trilarei": "trilar",
    "trilareis": "trilar",
    "trilarem": "trilar",
    "trilaremos": "trilar",
    "trilares": "trilar",
    "trilaria": "trilar",
    "trilariam": "trilar",
    "trilarias": "trilar",
    "trilarmo": "trilar",
    "trilarmos": "trilar",
    "trilará": "trilar",
    "trilarás": "trilar",
    "trilarão": "trilar",
    "trilaríamos": "trilar",
    "trilaríeis": "trilar",
    "trilas": "trilar",
    "trilasse": "trilar",
    "trilassem": "trilar",
    "trilasses": "trilar",
    "trilaste": "trilar",
    "trilastes": "trilar",
    "trilaterais": "trilateral",
    "trilava": "trilar",
    "trilavam": "trilar",
    "trilavas": "trilar",
    "trile": "trilar",
    "trilei": "trilar",
    "trileis": "trilar",
    "trilem": "trilar",
    "trilemas": "trilema",
    "trilemo": "trilar",
    "trilemos": "trilar",
    "triles": "trilar",
    "trilha": "trilhar",
    "trilhada": "trilhar",
    "trilhadas": "trilhar",
    "trilhadelas": "trilhadela",
    "trilhado": "trilhar",
    "trilhadora": "trilhador",
    "trilhadoras": "trilhador",
    "trilhadores": "trilhador",
    "trilhados": "trilhar",
    "trilhaduras": "trilhadura",
    "trilhai": "trilhar",
    "trilhais": "trilhar",
    "trilham": "trilhar",
    "trilhamentos": "trilhamento",
    "trilhamo": "trilhar",
    "trilhamos": "trilhar",
    "trilhando": "trilhar",
    "trilhara": "trilhar",
    "trilharam": "trilhar",
    "trilharas": "trilhar",
    "trilharde": "trilhar",
    "trilhardes": "trilhar",
    "trilhare": "trilhar",
    "trilharei": "trilhar",
    "trilhareis": "trilhar",
    "trilharem": "trilhar",
    "trilharemos": "trilhar",
    "trilhares": "trilhar",
    "trilharia": "trilhar",
    "trilhariam": "trilhar",
    "trilharias": "trilhar",
    "trilharmo": "trilhar",
    "trilharmos": "trilhar",
    "trilhará": "trilhar",
    "trilharás": "trilhar",
    "trilharão": "trilhar",
    "trilharíamos": "trilhar",
    "trilharíeis": "trilhar",
    "trilhas": "trilhar",
    "trilhasse": "trilhar",
    "trilhassem": "trilhar",
    "trilhasses": "trilhar",
    "trilhaste": "trilhar",
    "trilhastes": "trilhar",
    "trilhava": "trilhar",
    "trilhavam": "trilhar",
    "trilhavas": "trilhar",
    "trilhe": "trilhar",
    "trilhei": "trilhar",
    "trilheis": "trilhar",
    "trilhem": "trilhar",
    "trilhemo": "trilhar",
    "trilhemos": "trilhar",
    "trilhes": "trilhar",
    "trilho": "trilhar",
    "trilhoadas": "trilhoada",
    "trilhos": "trilho",
    "trilhou": "trilhar",
    "trilhá": "trilhar",
    "trilhámo": "trilhar",
    "trilhámos": "trilhar",
    "trilháramo": "trilhar",
    "trilháramos": "trilhar",
    "trilhárei": "trilhar",
    "trilháreis": "trilhar",
    "trilhásseis": "trilhar",
    "trilhássemos": "trilhar",
    "trilhávamo": "trilhar",
    "trilhávamos": "trilhar",
    "trilhávei": "trilhar",
    "trilháveis": "trilhar",
    "trilineares": "trilinear",
    "trilionésima": "trilionésimo",
    "trilionésimas": "trilionésimo",
    "trilionésimos": "trilionésimo",
    "triliterais": "triliteral",
    "triliões": "trilião",
    "trilo": "trilar",
    "trilobada": "trilobado",
    "trilobadas": "trilobado",
    "trilobados": "trilobado",
    "trilobites": "trilobite",
    "triloculada": "triloculado",
    "triloculadas": "triloculado",
    "triloculados": "triloculado",
    "triloculares": "trilocular",
    "trilogias": "trilogia",
    "trilonga": "trilongo",
    "trilongas": "trilongo",
    "trilongos": "trilongo",
    "triloquines": "triloquine",
    "trilos": "trilo",
    "trilou": "trilar",
    "trilá": "trilar",
    "trilámo": "trilar",
    "trilámos": "trilar",
    "triláramo": "trilar",
    "triláramos": "trilar",
    "trilárei": "trilar",
    "triláreis": "trilar",
    "trilásseis": "trilar",
    "trilássemos": "trilar",
    "trilátera": "trilátero",
    "triláteras": "trilátero",
    "triláteros": "trilátero",
    "trilávamo": "trilar",
    "trilávamos": "trilar",
    "trilávei": "trilar",
    "triláveis": "trilar",
    "trilíngues": "trilíngue",
    "trilítera": "trilítero",
    "trilíteras": "trilítero",
    "trilíteros": "trilítero",
    "trimaculada": "trimaculado",
    "trimaculadas": "trimaculado",
    "trimaculados": "trimaculado",
    "trimbolins": "trimbolim",
    "trimembres": "trimembre",
    "trimensais": "trimensal",
    "trimensários": "trimensário",
    "trimestrais": "trimestral",
    "trimestralidades": "trimestralidade",
    "trimestres": "trimestre",
    "trimilenária": "trimilenário",
    "trimilenárias": "trimilenário",
    "trimilenários": "trimilenário",
    "trimilénios": "trimilénio",
    "trimorfa": "trimorfo",
    "trimorfas": "trimorfo",
    "trimorfias": "trimorfia",
    "trimorfismos": "trimorfismo",
    "trimorfos": "trimorfo",
    "trimotora": "trimotor",
    "trimotoras": "trimotor",
    "trimotores": "trimotor",
    "trimétrica": "trimétrico",
    "trimétricas": "trimétrico",
    "trimétricos": "trimétrico",
    "trimúrtis": "trimúrti",
    "trina": "trino",
    "trinada": "trinar",
    "trinadas": "trinar",
    "trinado": "trinar",
    "trinadora": "trinador",
    "trinadoras": "trinador",
    "trinadores": "trinador",
    "trinados": "trinar",
    "trinai": "trinar",
    "trinais": "trinar",
    "trinalidades": "trinalidade",
    "trinam": "trinar",
    "trinamo": "trinar",
    "trinamos": "trinar",
    "trinando": "trinar",
    "trinara": "trinar",
    "trinaram": "trinar",
    "trinaras": "trinar",
    "trinarde": "trinar",
    "trinardes": "trinar",
    "trinare": "trinar",
    "trinarei": "trinar",
    "trinareis": "trinar",
    "trinarem": "trinar",
    "trinaremos": "trinar",
    "trinares": "trinar",
    "trinaria": "trinar",
    "trinariam": "trinar",
    "trinarias": "trinar",
    "trinarmo": "trinar",
    "trinarmos": "trinar",
    "trinará": "trinar",
    "trinarás": "trinar",
    "trinarão": "trinar",
    "trinaríamos": "trinar",
    "trinaríeis": "trinar",
    "trinas": "trino",
    "trinasse": "trinar",
    "trinassem": "trinar",
    "trinasses": "trinar",
    "trinaste": "trinar",
    "trinastes": "trinar",
    "trinava": "trinar",
    "trinavam": "trinar",
    "trinavas": "trinar",
    "trinca": "trincar",
    "trincada": "trincar",
    "trincadas": "trincar",
    "trincadelas": "trincadela",
    "trincado": "trincar",
    "trincados": "trincar",
    "trincaduras": "trincadura",
    "trincafia": "trincafiar",
    "trincafiada": "trincafiar",
    "trincafiadas": "trincafiar",
    "trincafiado": "trincafiar",
    "trincafiados": "trincafiar",
    "trincafiai": "trincafiar",
    "trincafiais": "trincafiar",
    "trincafiam": "trincafiar",
    "trincafiamo": "trincafiar",
    "trincafiamos": "trincafiar",
    "trincafiando": "trincafiar",
    "trincafiara": "trincafiar",
    "trincafiaram": "trincafiar",
    "trincafiaras": "trincafiar",
    "trincafiarde": "trincafiar",
    "trincafiardes": "trincafiar",
    "trincafiare": "trincafiar",
    "trincafiarei": "trincafiar",
    "trincafiareis": "trincafiar",
    "trincafiarem": "trincafiar",
    "trincafiaremos": "trincafiar",
    "trincafiares": "trincafiar",
    "trincafiaria": "trincafiar",
    "trincafiariam": "trincafiar",
    "trincafiarias": "trincafiar",
    "trincafiarmo": "trincafiar",
    "trincafiarmos": "trincafiar",
    "trincafiará": "trincafiar",
    "trincafiarás": "trincafiar",
    "trincafiarão": "trincafiar",
    "trincafiaríamos": "trincafiar",
    "trincafiaríeis": "trincafiar",
    "trincafias": "trincafiar",
    "trincafiasse": "trincafiar",
    "trincafiassem": "trincafiar",
    "trincafiasses": "trincafiar",
    "trincafiaste": "trincafiar",
    "trincafiastes": "trincafiar",
    "trincafiava": "trincafiar",
    "trincafiavam": "trincafiar",
    "trincafiavas": "trincafiar",
    "trincafie": "trincafiar",
    "trincafiei": "trincafiar",
    "trincafieis": "trincafiar",
    "trincafiem": "trincafiar",
    "trincafiemo": "trincafiar",
    "trincafiemos": "trincafiar",
    "trincafies": "trincafiar",
    "trincafio": "trincafiar",
    "trincafios": "trincafio",
    "trincafiou": "trincafiar",
    "trincafiá": "trincafiar",
    "trincafiámo": "trincafiar",
    "trincafiámos": "trincafiar",
    "trincafiáramo": "trincafiar",
    "trincafiáramos": "trincafiar",
    "trincafiárei": "trincafiar",
    "trincafiáreis": "trincafiar",
    "trincafiásseis": "trincafiar",
    "trincafiássemos": "trincafiar",
    "trincafiávamo": "trincafiar",
    "trincafiávamos": "trincafiar",
    "trincafiávei": "trincafiar",
    "trincafiáveis": "trincafiar",
    "trincai": "trincar",
    "trincais": "trincar",
    "trincam": "trincar",
    "trincamo": "trincar",
    "trincamos": "trincar",
    "trincando": "trincar",
    "trincara": "trincar",
    "trincaram": "trincar",
    "trincaras": "trincar",
    "trincarde": "trincar",
    "trincardes": "trincar",
    "trincare": "trincar",
    "trincarei": "trincar",
    "trincareis": "trincar",
    "trincarem": "trincar",
    "trincaremos": "trincar",
    "trincares": "trincar",
    "trincaria": "trincar",
    "trincariam": "trincar",
    "trincarias": "trincar",
    "trincarmo": "trincar",
    "trincarmos": "trincar",
    "trincará": "trincar",
    "trincarás": "trincar",
    "trincarão": "trincar",
    "trincaríamos": "trincar",
    "trincaríeis": "trincar",
    "trincas": "trincar",
    "trincasse": "trincar",
    "trincassem": "trincar",
    "trincasses": "trincar",
    "trincaste": "trincar",
    "trincastes": "trincar",
    "trincava": "trincar",
    "trincavam": "trincar",
    "trincavas": "trincar",
    "trincha": "trinchar",
    "trinchada": "trinchar",
    "trinchadas": "trinchar",
    "trinchado": "trinchar",
    "trinchadora": "trinchador",
    "trinchadoras": "trinchador",
    "trinchadores": "trinchador",
    "trinchados": "trinchar",
    "trinchai": "trinchar",
    "trinchais": "trinchar",
    "trincham": "trinchar",
    "trinchamo": "trinchar",
    "trinchamos": "trinchar",
    "trinchando": "trinchar",
    "trinchantes": "trinchante",
    "trinchara": "trinchar",
    "trincharam": "trinchar",
    "trincharas": "trinchar",
    "trincharde": "trinchar",
    "trinchardes": "trinchar",
    "trinchare": "trinchar",
    "trincharei": "trinchar",
    "trinchareis": "trinchar",
    "trincharem": "trinchar",
    "trincharemos": "trinchar",
    "trinchares": "trinchar",
    "trincharia": "trinchar",
    "trinchariam": "trinchar",
    "trincharias": "trinchar",
    "trincharmo": "trinchar",
    "trincharmos": "trinchar",
    "trinchará": "trinchar",
    "trincharás": "trinchar",
    "trincharão": "trinchar",
    "trincharíamos": "trinchar",
    "trincharíeis": "trinchar",
    "trinchas": "trinchar",
    "trinchasse": "trinchar",
    "trinchassem": "trinchar",
    "trinchasses": "trinchar",
    "trinchaste": "trinchar",
    "trinchastes": "trinchar",
    "trinchava": "trinchar",
    "trinchavam": "trinchar",
    "trinchavas": "trinchar",
    "trinche": "trinchar",
    "trinchei": "trinchar",
    "trincheiras": "trincheira",
    "trincheiros": "trincheiro",
    "trincheis": "trinchar",
    "trinchem": "trinchar",
    "trinchemo": "trinchar",
    "trinchemos": "trinchar",
    "trinches": "trinchar",
    "trincho": "trinchar",
    "trinchos": "trincho",
    "trinchou": "trinchar",
    "trinchá": "trinchar",
    "trinchámo": "trinchar",
    "trinchámos": "trinchar",
    "trincháramo": "trinchar",
    "trincháramos": "trinchar",
    "trinchárei": "trinchar",
    "trincháreis": "trinchar",
    "trinchásseis": "trinchar",
    "trinchássemos": "trinchar",
    "trinchávamo": "trinchar",
    "trinchávamos": "trinchar",
    "trinchávei": "trinchar",
    "trincháveis": "trinchável",
    "trinchões": "trinchão",
    "trinco": "trincar",
    "trincoleja": "trincolejar",
    "trincolejada": "trincolejar",
    "trincolejadas": "trincolejar",
    "trincolejado": "trincolejar",
    "trincolejados": "trincolejar",
    "trincolejai": "trincolejar",
    "trincolejais": "trincolejar",
    "trincolejam": "trincolejar",
    "trincolejamo": "trincolejar",
    "trincolejamos": "trincolejar",
    "trincolejando": "trincolejar",
    "trincolejara": "trincolejar",
    "trincolejaram": "trincolejar",
    "trincolejaras": "trincolejar",
    "trincolejardes": "trincolejar",
    "trincolejarei": "trincolejar",
    "trincolejareis": "trincolejar",
    "trincolejarem": "trincolejar",
    "trincolejaremos": "trincolejar",
    "trincolejares": "trincolejar",
    "trincolejaria": "trincolejar",
    "trincolejariam": "trincolejar",
    "trincolejarias": "trincolejar",
    "trincolejarmo": "trincolejar",
    "trincolejarmos": "trincolejar",
    "trincolejará": "trincolejar",
    "trincolejarás": "trincolejar",
    "trincolejarão": "trincolejar",
    "trincolejaríamos": "trincolejar",
    "trincolejaríeis": "trincolejar",
    "trincolejas": "trincolejar",
    "trincolejasse": "trincolejar",
    "trincolejassem": "trincolejar",
    "trincolejasses": "trincolejar",
    "trincolejaste": "trincolejar",
    "trincolejastes": "trincolejar",
    "trincolejava": "trincolejar",
    "trincolejavam": "trincolejar",
    "trincolejavas": "trincolejar",
    "trincoleje": "trincolejar",
    "trincolejei": "trincolejar",
    "trincolejeis": "trincolejar",
    "trincolejem": "trincolejar",
    "trincolejemo": "trincolejar",
    "trincolejemos": "trincolejar",
    "trincolejes": "trincolejar",
    "trincolejo": "trincolejar",
    "trincolejos": "trincolejo",
    "trincolejou": "trincolejar",
    "trincolejámo": "trincolejar",
    "trincolejámos": "trincolejar",
    "trincolejáramo": "trincolejar",
    "trincolejáramos": "trincolejar",
    "trincolejáreis": "trincolejar",
    "trincolejásseis": "trincolejar",
    "trincolejássemos": "trincolejar",
    "trincolejávamo": "trincolejar",
    "trincolejávamos": "trincolejar",
    "trincolejáveis": "trincolejar",
    "trincos": "trinco",
    "trincou": "trincar",
    "trincá": "trincar",
    "trincámo": "trincar",
    "trincámos": "trincar",
    "trincáramo": "trincar",
    "trincáramos": "trincar",
    "trincárei": "trincar",
    "trincáreis": "trincar",
    "trincásseis": "trincar",
    "trincássemos": "trincar",
    "trincávamo": "trincar",
    "trincávamos": "trincar",
    "trincávei": "trincar",
    "trincáveis": "trincável",
    "trindades": "trindade",
    "trine": "trinar",
    "trinei": "trinar",
    "trineis": "trinar",
    "trinem": "trinar",
    "trinemo": "trinar",
    "trinemos": "trinar",
    "trinervada": "trinervado",
    "trinervadas": "trinervado",
    "trinervados": "trinervado",
    "trines": "trinar",
    "trineta": "trineto",
    "trinetas": "trineto",
    "trinetos": "trineto",
    "trinfares": "trinfar",
    "trinitroglicerinas": "trinitroglicerina",
    "trinitrogliceróis": "trinitroglicerol",
    "trinitrototulenos": "trinitrototuleno",
    "trinitárioa": "trinitário",
    "trinitárioas": "trinitário",
    "trinitárioes": "trinitário",
    "trinitários": "trinitário",
    "trino": "trinar",
    "trinomiais": "trinomial",
    "trinominais": "trinominal",
    "trinos": "trino",
    "trinou": "trinar",
    "trinque": "trincar",
    "trinquei": "trincar",
    "trinqueis": "trincar",
    "trinquem": "trincar",
    "trinquemo": "trincar",
    "trinquemos": "trincar",
    "trinques": "trinque",
    "trinquevales": "trinquevale",
    "trinta": "trintar",
    "trintada": "trintar",
    "trintadas": "trintar",
    "trintado": "trintar",
    "trintados": "trintar",
    "trintai": "trintar",
    "trintais": "trintar",
    "trintam": "trintar",
    "trintamo": "trintar",
    "trintamos": "trintar",
    "trintando": "trintar",
    "trintaneira": "trintaneiro",
    "trintaneiras": "trintaneiro",
    "trintaneiros": "trintaneiro",
    "trintanária": "trintanário",
    "trintanárias": "trintanário",
    "trintanários": "trintanário",
    "trintara": "trintar",
    "trintaram": "trintar",
    "trintaras": "trintar",
    "trintardes": "trintar",
    "trintarei": "trintar",
    "trintareis": "trintar",
    "trintarem": "trintar",
    "trintaremos": "trintar",
    "trintares": "trintar",
    "trintaria": "trintar",
    "trintariam": "trintar",
    "trintarias": "trintar",
    "trintarmo": "trintar",
    "trintarmos": "trintar",
    "trintará": "trintar",
    "trintarás": "trintar",
    "trintarão": "trintar",
    "trintaríamos": "trintar",
    "trintaríeis": "trintar",
    "trintas": "trintar",
    "trintasse": "trintar",
    "trintassem": "trintar",
    "trintasses": "trintar",
    "trintaste": "trintar",
    "trintastes": "trintar",
    "trintava": "trintar",
    "trintavam": "trintar",
    "trintavas": "trintar",
    "trinte": "trintar",
    "trintei": "trintar",
    "trinteis": "trintar",
    "trintem": "trintar",
    "trintemo": "trintar",
    "trintemos": "trintar",
    "trintenas": "trintena",
    "trintenária": "trintenário",
    "trintenárias": "trintenário",
    "trintenários": "trintenário",
    "trintes": "trintar",
    "trinto": "trintar",
    "trintona": "trintão",
    "trintonas": "trintão",
    "trintou": "trintar",
    "trintámo": "trintar",
    "trintámos": "trintar",
    "trintáramo": "trintar",
    "trintáramos": "trintar",
    "trintáreis": "trintar",
    "trintários": "trintário",
    "trintásseis": "trintar",
    "trintássemos": "trintar",
    "trintávamo": "trintar",
    "trintávamos": "trintar",
    "trintáveis": "trintar",
    "trinténios": "trinténio",
    "trintões": "trintão",
    "triná": "trinar",
    "trinácria": "trinácrio",
    "trinácrias": "trinácrio",
    "trinácrios": "trinácrio",
    "trinámo": "trinar",
    "trinámos": "trinar",
    "trináramo": "trinar",
    "trináramos": "trinar",
    "trinárei": "trinar",
    "trináreis": "trinar",
    "trinásseis": "trinar",
    "trinássemos": "trinar",
    "trinávamo": "trinar",
    "trinávamos": "trinar",
    "trinávei": "trinar",
    "trináveis": "trinar",
    "trinérvea": "trinérveo",
    "trinérveas": "trinérveo",
    "trinérveos": "trinérveo",
    "trinómines": "trinómine",
    "trinómios": "trinómio",
    "trioleínas": "trioleína",
    "trios": "trio",
    "triovulada": "triovulado",
    "triovuladas": "triovulado",
    "triovulados": "triovulado",
    "tripagens": "tripagem",
    "tripalhadas": "tripalhada",
    "tripalmitrinas": "tripalmitrina",
    "tripanossomos": "tripanossomo",
    "tripanossomoses": "tripanossomose",
    "tripanossomíases": "tripanossomíase",
    "tripanossomídeos": "tripanossomídeo",
    "tripanossómidas": "tripanossómida",
    "triparca": "triparco",
    "triparcas": "triparco",
    "triparcos": "triparco",
    "triparias": "triparia",
    "triparta": "tripartir",
    "tripartais": "tripartir",
    "tripartam": "tripartir",
    "tripartamo": "tripartir",
    "tripartamos": "tripartir",
    "tripartas": "tripartir",
    "triparte": "tripartir",
    "tripartem": "tripartir",
    "tripartes": "tripartir",
    "triparti": "tripartir",
    "tripartia": "tripartir",
    "tripartiam": "tripartir",
    "tripartias": "tripartir",
    "tripartida": "tripartir",
    "tripartidas": "tripartir",
    "tripartido": "tripartir",
    "tripartidos": "tripartir",
    "tripartimo": "tripartir",
    "tripartimos": "tripartir",
    "tripartindo": "tripartir",
    "tripartira": "tripartir",
    "tripartiram": "tripartir",
    "tripartiras": "tripartir",
    "tripartirde": "tripartir",
    "tripartirdes": "tripartir",
    "tripartire": "tripartir",
    "tripartirei": "tripartir",
    "tripartireis": "tripartir",
    "tripartirem": "tripartir",
    "tripartiremos": "tripartir",
    "tripartires": "tripartir",
    "tripartiria": "tripartir",
    "tripartiriam": "tripartir",
    "tripartirias": "tripartir",
    "tripartirmo": "tripartir",
    "tripartirmos": "tripartir",
    "tripartirá": "tripartir",
    "tripartirás": "tripartir",
    "tripartirão": "tripartir",
    "tripartiríamos": "tripartir",
    "tripartiríeis": "tripartir",
    "tripartis": "tripartir",
    "tripartisse": "tripartir",
    "tripartissem": "tripartir",
    "tripartisses": "tripartir",
    "tripartiste": "tripartir",
    "tripartistes": "tripartir",
    "tripartiu": "tripartir",
    "tripartições": "tripartição",
    "triparto": "tripartir",
    "tripartíamo": "tripartir",
    "tripartíamos": "tripartir",
    "tripartíei": "tripartir",
    "tripartíeis": "tripartir",
    "tripartíramo": "tripartir",
    "tripartíramos": "tripartir",
    "tripartírei": "tripartir",
    "tripartíreis": "tripartir",
    "tripartísseis": "tripartir",
    "tripartíssemos": "tripartir",
    "tripartíveis": "tripartível",
    "tripas": "tripa",
    "tripeira": "tripeiro",
    "tripeiradas": "tripeirada",
    "tripeiras": "tripeiro",
    "tripeiros": "tripeiro",
    "tripessoais": "tripessoal",
    "tripeças": "tripeça",
    "tripla": "triplo",
    "triplas": "triplo",
    "triples": "triple",
    "tripletos": "tripleto",
    "triplica": "triplicar",
    "triplicada": "triplicar",
    "triplicadas": "triplicar",
    "triplicado": "triplicar",
    "triplicados": "triplicar",
    "triplicai": "triplicar",
    "triplicais": "triplicar",
    "triplicam": "triplicar",
    "triplicamo": "triplicar",
    "triplicamos": "triplicar",
    "triplicando": "triplicar",
    "triplicara": "triplicar",
    "triplicaram": "triplicar",
    "triplicaras": "triplicar",
    "triplicarde": "triplicar",
    "triplicardes": "triplicar",
    "triplicare": "triplicar",
    "triplicarei": "triplicar",
    "triplicareis": "triplicar",
    "triplicarem": "triplicar",
    "triplicaremos": "triplicar",
    "triplicares": "triplicar",
    "triplicaria": "triplicar",
    "triplicariam": "triplicar",
    "triplicarias": "triplicar",
    "triplicarmo": "triplicar",
    "triplicarmos": "triplicar",
    "triplicará": "triplicar",
    "triplicarás": "triplicar",
    "triplicarão": "triplicar",
    "triplicaríamos": "triplicar",
    "triplicaríeis": "triplicar",
    "triplicas": "triplicar",
    "triplicasse": "triplicar",
    "triplicassem": "triplicar",
    "triplicasses": "triplicar",
    "triplicaste": "triplicar",
    "triplicastes": "triplicar",
    "triplicatas": "triplicata",
    "triplicava": "triplicar",
    "triplicavam": "triplicar",
    "triplicavas": "triplicar",
    "triplicações": "triplicação",
    "triplicidades": "triplicidade",
    "triplico": "triplicar",
    "triplicou": "triplicar",
    "triplicá": "triplicar",
    "triplicámo": "triplicar",
    "triplicámos": "triplicar",
    "triplicáramo": "triplicar",
    "triplicáramos": "triplicar",
    "triplicárei": "triplicar",
    "triplicáreis": "triplicar",
    "triplicásseis": "triplicar",
    "triplicássemos": "triplicar",
    "triplicávamo": "triplicar",
    "triplicávamos": "triplicar",
    "triplicávei": "triplicar",
    "triplicáveis": "triplicável",
    "triplique": "triplicar",
    "tripliquei": "triplicar",
    "tripliqueis": "triplicar",
    "tripliquem": "triplicar",
    "tripliquemo": "triplicar",
    "tripliquemos": "triplicar",
    "tripliques": "triplicar",
    "triplopias": "triplopia",
    "triplos": "triplo",
    "triplostémones": "triplostémone",
    "triplóides": "triplóide",
    "tripodias": "tripodia",
    "tripolina": "tripolino",
    "tripolinas": "tripolino",
    "tripolinos": "tripolino",
    "tripolitana": "tripolitano",
    "tripolitanas": "tripolitano",
    "tripolitanos": "tripolitano",
    "tripsinas": "tripsina",
    "tripudia": "tripudiar",
    "tripudiada": "tripudiar",
    "tripudiadas": "tripudiar",
    "tripudiado": "tripudiar",
    "tripudiados": "tripudiar",
    "tripudiai": "tripudiar",
    "tripudiais": "tripudiar",
    "tripudiam": "tripudiar",
    "tripudiamo": "tripudiar",
    "tripudiamos": "tripudiar",
    "tripudiando": "tripudiar",
    "tripudiara": "tripudiar",
    "tripudiaram": "tripudiar",
    "tripudiaras": "tripudiar",
    "tripudiardes": "tripudiar",
    "tripudiarei": "tripudiar",
    "tripudiareis": "tripudiar",
    "tripudiarem": "tripudiar",
    "tripudiaremos": "tripudiar",
    "tripudiares": "tripudiar",
    "tripudiaria": "tripudiar",
    "tripudiariam": "tripudiar",
    "tripudiarias": "tripudiar",
    "tripudiarmo": "tripudiar",
    "tripudiarmos": "tripudiar",
    "tripudiará": "tripudiar",
    "tripudiarás": "tripudiar",
    "tripudiarão": "tripudiar",
    "tripudiaríamos": "tripudiar",
    "tripudiaríeis": "tripudiar",
    "tripudias": "tripudiar",
    "tripudiasse": "tripudiar",
    "tripudiassem": "tripudiar",
    "tripudiasses": "tripudiar",
    "tripudiaste": "tripudiar",
    "tripudiastes": "tripudiar",
    "tripudiava": "tripudiar",
    "tripudiavam": "tripudiar",
    "tripudiavas": "tripudiar",
    "tripudie": "tripudiar",
    "tripudiei": "tripudiar",
    "tripudieis": "tripudiar",
    "tripudiem": "tripudiar",
    "tripudiemo": "tripudiar",
    "tripudiemos": "tripudiar",
    "tripudies": "tripudiar",
    "tripudio": "tripudiar",
    "tripudiou": "tripudiar",
    "tripudiámo": "tripudiar",
    "tripudiámos": "tripudiar",
    "tripudiáramo": "tripudiar",
    "tripudiáramos": "tripudiar",
    "tripudiáreis": "tripudiar",
    "tripudiásseis": "tripudiar",
    "tripudiássemos": "tripudiar",
    "tripudiávamo": "tripudiar",
    "tripudiávamos": "tripudiar",
    "tripudiáveis": "tripudiar",
    "tripula": "tripular",
    "tripulada": "tripular",
    "tripuladas": "tripular",
    "tripulado": "tripular",
    "tripulados": "tripular",
    "tripulai": "tripular",
    "tripulais": "tripular",
    "tripulam": "tripular",
    "tripulamo": "tripular",
    "tripulamos": "tripular",
    "tripulando": "tripular",
    "tripulantes": "tripulante",
    "tripulara": "tripular",
    "tripularam": "tripular",
    "tripularas": "tripular",
    "tripularde": "tripular",
    "tripulardes": "tripular",
    "tripulare": "tripular",
    "tripularei": "tripular",
    "tripulareis": "tripular",
    "tripularem": "tripular",
    "tripularemos": "tripular",
    "tripulares": "tripular",
    "tripularia": "tripular",
    "tripulariam": "tripular",
    "tripularias": "tripular",
    "tripularmo": "tripular",
    "tripularmos": "tripular",
    "tripulará": "tripular",
    "tripularás": "tripular",
    "tripularão": "tripular",
    "tripularíamos": "tripular",
    "tripularíeis": "tripular",
    "tripulas": "tripular",
    "tripulasse": "tripular",
    "tripulassem": "tripular",
    "tripulasses": "tripular",
    "tripulaste": "tripular",
    "tripulastes": "tripular",
    "tripulava": "tripular",
    "tripulavam": "tripular",
    "tripulavas": "tripular",
    "tripulações": "tripulação",
    "tripule": "tripular",
    "tripulei": "tripular",
    "tripuleis": "tripular",
    "tripulem": "tripular",
    "tripulemo": "tripular",
    "tripulemos": "tripular",
    "tripules": "tripular",
    "tripulo": "tripular",
    "tripulou": "tripular",
    "tripulá": "tripular",
    "tripulámo": "tripular",
    "tripulámos": "tripular",
    "tripuláramo": "tripular",
    "tripuláramos": "tripular",
    "tripulárei": "tripular",
    "tripuláreis": "tripular",
    "tripulásseis": "tripular",
    "tripulássemos": "tripular",
    "tripulávamo": "tripular",
    "tripulávamos": "tripular",
    "tripulávei": "tripular",
    "tripuláveis": "tripulável",
    "tripés": "tripé",
    "tripétala": "tripétalo",
    "tripétalas": "tripétalo",
    "tripétalos": "tripétalo",
    "tripófaga": "tripófago",
    "tripófagas": "tripófago",
    "tripófagos": "tripófago",
    "tripós": "tripó",
    "tripúdios": "tripúdio",
    "trique": "tricar",
    "triquei": "tricar",
    "triqueis": "tricar",
    "triquem": "tricar",
    "triquemos": "tricar",
    "triquequídeos": "triquequídeo",
    "triques": "tricar",
    "triquetes": "triquete",
    "triquetraques": "triquetraque",
    "triquetrazes": "triquetraz",
    "triquinada": "triquinado",
    "triquinadas": "triquinado",
    "triquinados": "triquinado",
    "triquinas": "triquina",
    "triquinosa": "triquinoso",
    "triquinosas": "triquinoso",
    "triquinoses": "triquinose",
    "triquinosos": "triquinoso",
    "triquiníases": "triquiníase",
    "triquismos": "triquismo",
    "triquitos": "triquito",
    "triquéquidas": "triquéquida",
    "triquíases": "triquíase",
    "trirradiada": "trirradiado",
    "trirradiadas": "trirradiado",
    "trirradiados": "trirradiado",
    "trirramosa": "trirramoso",
    "trirramosas": "trirramoso",
    "trirramosos": "trirramoso",
    "trirrectângula": "trirrectângulo",
    "trirrectângulas": "trirrectângulo",
    "trirrectângulos": "trirrectângulo",
    "trirregnos": "trirregno",
    "trirremes": "trirreme",
    "trisanuais": "trisanual",
    "trisarquias": "trisarquia",
    "trisavozinha": "trisavô",
    "trisavozinhas": "trisavô",
    "trisavozinho": "trisavô",
    "trisavozinhos": "trisavô",
    "trisavozita": "trisavô",
    "trisavozitas": "trisavô",
    "trisavozito": "trisavô",
    "trisavozitos": "trisavô",
    "trisavó": "trisavô",
    "trisavós": "trisavô",
    "trisavôs": "trisavô",
    "trisca": "triscar",
    "triscada": "triscar",
    "triscadas": "triscar",
    "triscado": "triscar",
    "triscados": "triscar",
    "triscais": "triscar",
    "triscam": "triscar",
    "triscamo": "triscar",
    "triscamos": "triscar",
    "triscando": "triscar",
    "triscara": "triscar",
    "triscaram": "triscar",
    "triscaras": "triscar",
    "triscardes": "triscar",
    "triscarei": "triscar",
    "triscareis": "triscar",
    "triscarem": "triscar",
    "triscaremos": "triscar",
    "triscares": "triscar",
    "triscaria": "triscar",
    "triscariam": "triscar",
    "triscarias": "triscar",
    "triscarmo": "triscar",
    "triscarmos": "triscar",
    "triscará": "triscar",
    "triscarás": "triscar",
    "triscarão": "triscar",
    "triscaríamos": "triscar",
    "triscaríeis": "triscar",
    "triscas": "triscar",
    "triscasse": "triscar",
    "triscassem": "triscar",
    "triscasses": "triscar",
    "triscaste": "triscar",
    "triscastes": "triscar",
    "triscava": "triscar",
    "triscavam": "triscar",
    "triscavas": "triscar",
    "trisco": "triscar",
    "triscou": "triscar",
    "triscámo": "triscar",
    "triscámos": "triscar",
    "triscáramo": "triscar",
    "triscáramos": "triscar",
    "triscáreis": "triscar",
    "triscásseis": "triscar",
    "triscássemos": "triscar",
    "triscávamo": "triscar",
    "triscávamos": "triscar",
    "triscáveis": "triscar",
    "trises": "tris",
    "trismegistos": "trismegisto",
    "trisperma": "trispermo",
    "trispermas": "trispermo",
    "trispermos": "trispermo",
    "trisque": "triscar",
    "trisquei": "triscar",
    "trisqueis": "triscar",
    "trisquem": "triscar",
    "trisquemos": "triscar",
    "trisques": "triscar",
    "trissa": "trissar",
    "trissacramentais": "trissacramental",
    "trissada": "trissar",
    "trissadas": "trissar",
    "trissado": "trissar",
    "trissados": "trissar",
    "trissai": "trissar",
    "trissais": "trissar",
    "trissam": "trissar",
    "trissamo": "trissar",
    "trissamos": "trissar",
    "trissando": "trissar",
    "trissara": "trissar",
    "trissaram": "trissar",
    "trissaras": "trissar",
    "trissardes": "trissar",
    "trissarei": "trissar",
    "trissareis": "trissar",
    "trissarem": "trissar",
    "trissaremos": "trissar",
    "trissares": "trissar",
    "trissaria": "trissar",
    "trissariam": "trissar",
    "trissarias": "trissar",
    "trissarmo": "trissar",
    "trissarmos": "trissar",
    "trissará": "trissar",
    "trissarás": "trissar",
    "trissarão": "trissar",
    "trissaríamos": "trissar",
    "trissaríeis": "trissar",
    "trissas": "trissar",
    "trissasse": "trissar",
    "trissassem": "trissar",
    "trissasses": "trissar",
    "trissaste": "trissar",
    "trissastes": "trissar",
    "trissava": "trissar",
    "trissavam": "trissar",
    "trissavas": "trissar",
    "trisse": "trissar",
    "trisseca": "trissecar",
    "trissecada": "trissecar",
    "trissecadas": "trissecar",
    "trissecado": "trissecar",
    "trissecados": "trissecar",
    "trissecai": "trissecar",
    "trissecais": "trissecar",
    "trissecam": "trissecar",
    "trissecamo": "trissecar",
    "trissecamos": "trissecar",
    "trissecando": "trissecar",
    "trissecara": "trissecar",
    "trissecaram": "trissecar",
    "trissecaras": "trissecar",
    "trissecarde": "trissecar",
    "trissecardes": "trissecar",
    "trissecare": "trissecar",
    "trissecarei": "trissecar",
    "trissecareis": "trissecar",
    "trissecarem": "trissecar",
    "trissecaremos": "trissecar",
    "trissecares": "trissecar",
    "trissecaria": "trissecar",
    "trissecariam": "trissecar",
    "trissecarias": "trissecar",
    "trissecarmo": "trissecar",
    "trissecarmos": "trissecar",
    "trissecará": "trissecar",
    "trissecarás": "trissecar",
    "trissecarão": "trissecar",
    "trissecaríamos": "trissecar",
    "trissecaríeis": "trissecar",
    "trissecas": "trissecar",
    "trissecasse": "trissecar",
    "trissecassem": "trissecar",
    "trissecasses": "trissecar",
    "trissecaste": "trissecar",
    "trissecastes": "trissecar",
    "trissecava": "trissecar",
    "trissecavam": "trissecar",
    "trissecavas": "trissecar",
    "trisseco": "trissecar",
    "trissecou": "trissecar",
    "trissectores": "trissector",
    "trissectriz": "trissector",
    "trissectrizes": "trissector",
    "trisseculares": "trissecular",
    "trissecá": "trissecar",
    "trissecámo": "trissecar",
    "trissecámos": "trissecar",
    "trissecáramo": "trissecar",
    "trissecáramos": "trissecar",
    "trissecárei": "trissecar",
    "trissecáreis": "trissecar",
    "trissecásseis": "trissecar",
    "trissecássemos": "trissecar",
    "trissecávamo": "trissecar",
    "trissecávamos": "trissecar",
    "trissecávei": "trissecar",
    "trissecáveis": "trissecar",
    "trissecções": "trissecção",
    "trissei": "trissar",
    "trisseis": "trissar",
    "trissem": "trissar",
    "trissemanais": "trissemanal",
    "trissemanários": "trissemanário",
    "trissemestrais": "trissemestral",
    "trissemo": "trissar",
    "trissemos": "trissar",
    "trisseque": "trissecar",
    "trissequei": "trissecar",
    "trissequeis": "trissecar",
    "trissequem": "trissecar",
    "trissequemo": "trissecar",
    "trissequemos": "trissecar",
    "trisseques": "trissecar",
    "trisseriada": "trisseriado",
    "trisseriadas": "trisseriado",
    "trisseriados": "trisseriado",
    "trisses": "trissar",
    "trissilábica": "trissilábico",
    "trissilábicas": "trissilábico",
    "trissilábicos": "trissilábico",
    "trisso": "trissar",
    "trissomias": "trissomia",
    "trissos": "trisso",
    "trissou": "trissar",
    "trissulca": "trissulco",
    "trissulcada": "trissulcar",
    "trissulcadas": "trissulcar",
    "trissulcado": "trissulcar",
    "trissulcados": "trissulcar",
    "trissulcai": "trissulcar",
    "trissulcais": "trissulcar",
    "trissulcam": "trissulcar",
    "trissulcamo": "trissulcar",
    "trissulcamos": "trissulcar",
    "trissulcando": "trissulcar",
    "trissulcara": "trissulcar",
    "trissulcaram": "trissulcar",
    "trissulcaras": "trissulcar",
    "trissulcarde": "trissulcar",
    "trissulcardes": "trissulcar",
    "trissulcare": "trissulcar",
    "trissulcarei": "trissulcar",
    "trissulcareis": "trissulcar",
    "trissulcarem": "trissulcar",
    "trissulcaremos": "trissulcar",
    "trissulcares": "trissulcar",
    "trissulcaria": "trissulcar",
    "trissulcariam": "trissulcar",
    "trissulcarias": "trissulcar",
    "trissulcarmo": "trissulcar",
    "trissulcarmos": "trissulcar",
    "trissulcará": "trissulcar",
    "trissulcarás": "trissulcar",
    "trissulcarão": "trissulcar",
    "trissulcaríamos": "trissulcar",
    "trissulcaríeis": "trissulcar",
    "trissulcas": "trissulco",
    "trissulcasse": "trissulcar",
    "trissulcassem": "trissulcar",
    "trissulcasses": "trissulcar",
    "trissulcaste": "trissulcar",
    "trissulcastes": "trissulcar",
    "trissulcava": "trissulcar",
    "trissulcavam": "trissulcar",
    "trissulcavas": "trissulcar",
    "trissulco": "trissulcar",
    "trissulcos": "trissulco",
    "trissulcou": "trissulcar",
    "trissulcá": "trissulcar",
    "trissulcámo": "trissulcar",
    "trissulcámos": "trissulcar",
    "trissulcáramo": "trissulcar",
    "trissulcáramos": "trissulcar",
    "trissulcárei": "trissulcar",
    "trissulcáreis": "trissulcar",
    "trissulcásseis": "trissulcar",
    "trissulcássemos": "trissulcar",
    "trissulcávamo": "trissulcar",
    "trissulcávamos": "trissulcar",
    "trissulcávei": "trissulcar",
    "trissulcáveis": "trissulcar",
    "trissulque": "trissulcar",
    "trissulquei": "trissulcar",
    "trissulqueis": "trissulcar",
    "trissulquem": "trissulcar",
    "trissulquemo": "trissulcar",
    "trissulquemos": "trissulcar",
    "trissulques": "trissulcar",
    "trissámo": "trissar",
    "trissámos": "trissar",
    "trissáramo": "trissar",
    "trissáramos": "trissar",
    "trissáreis": "trissar",
    "trissásseis": "trissar",
    "trissássemos": "trissar",
    "trissávamo": "trissar",
    "trissávamos": "trissar",
    "trissáveis": "trissar",
    "trissépala": "trissépalo",
    "trissépalas": "trissépalo",
    "trissépalos": "trissépalo",
    "trissílaba": "trissílabo",
    "trissílabas": "trissílabo",
    "trissílabos": "trissílabo",
    "trissílados": "trissílado",
    "tristaminífera": "tristaminífero",
    "tristaminíferas": "tristaminífero",
    "tristaminíferos": "tristaminífero",
    "tristearinas": "tristearina",
    "tristes": "triste",
    "tristezas": "tristeza",
    "tristifica": "tristificar",
    "tristificada": "tristificar",
    "tristificadas": "tristificar",
    "tristificado": "tristificar",
    "tristificados": "tristificar",
    "tristificais": "tristificar",
    "tristificam": "tristificar",
    "tristificamo": "tristificar",
    "tristificamos": "tristificar",
    "tristificando": "tristificar",
    "tristificara": "tristificar",
    "tristificaram": "tristificar",
    "tristificaras": "tristificar",
    "tristificardes": "tristificar",
    "tristificarei": "tristificar",
    "tristificareis": "tristificar",
    "tristificarem": "tristificar",
    "tristificaremos": "tristificar",
    "tristificares": "tristificar",
    "tristificaria": "tristificar",
    "tristificariam": "tristificar",
    "tristificarias": "tristificar",
    "tristificarmo": "tristificar",
    "tristificarmos": "tristificar",
    "tristificará": "tristificar",
    "tristificarás": "tristificar",
    "tristificarão": "tristificar",
    "tristificaríamos": "tristificar",
    "tristificaríeis": "tristificar",
    "tristificas": "tristificar",
    "tristificasse": "tristificar",
    "tristificassem": "tristificar",
    "tristificasses": "tristificar",
    "tristificaste": "tristificar",
    "tristificastes": "tristificar",
    "tristificava": "tristificar",
    "tristificavam": "tristificar",
    "tristificavas": "tristificar",
    "tristifico": "tristificar",
    "tristificou": "tristificar",
    "tristificámo": "tristificar",
    "tristificámos": "tristificar",
    "tristificáramo": "tristificar",
    "tristificáramos": "tristificar",
    "tristificáreis": "tristificar",
    "tristificásseis": "tristificar",
    "tristificássemos": "tristificar",
    "tristificávamo": "tristificar",
    "tristificávamos": "tristificar",
    "tristificáveis": "tristificar",
    "tristifique": "tristificar",
    "tristifiquei": "tristificar",
    "tristifiqueis": "tristificar",
    "tristifiquem": "tristificar",
    "tristifiquemos": "tristificar",
    "tristifiques": "tristificar",
    "tristimanias": "tristimania",
    "tristimaníaca": "tristimaníaco",
    "tristimaníacas": "tristimaníaco",
    "tristimaníacos": "tristimaníaco",
    "tristinha": "triste",
    "tristinhas": "triste",
    "tristinho": "triste",
    "tristinhos": "triste",
    "tristita": "triste",
    "tristitas": "triste",
    "tristito": "triste",
    "tristitos": "triste",
    "tristonha": "tristonho",
    "tristonhas": "tristonho",
    "tristonhos": "tristonho",
    "tristuras": "tristura",
    "tristímana": "tristímano",
    "tristímanas": "tristímano",
    "tristímanos": "tristímano",
    "tristíssima": "triste",
    "tristíssimas": "triste",
    "tristíssimo": "triste",
    "tristíssimos": "triste",
    "triságios": "triságio",
    "trita": "trito",
    "tritas": "trito",
    "triteísmos": "triteísmo",
    "triteístas": "triteísta",
    "triticinas": "triticina",
    "tritiões": "tritião",
    "tritongos": "tritongo",
    "tritoniana": "tritoniano",
    "tritonianas": "tritoniano",
    "tritonianos": "tritoniano",
    "tritonídeos": "tritonídeo",
    "tritos": "trito",
    "tritura": "triturar",
    "triturada": "triturar",
    "trituradas": "triturar",
    "triturado": "triturar",
    "trituradora": "triturador",
    "trituradoras": "triturador",
    "trituradores": "triturador",
    "triturados": "triturar",
    "triturai": "triturar",
    "triturais": "triturar",
    "trituram": "triturar",
    "trituramentos": "trituramento",
    "trituramo": "triturar",
    "trituramos": "triturar",
    "triturando": "triturar",
    "triturantes": "triturante",
    "triturara": "triturar",
    "trituraram": "triturar",
    "trituraras": "triturar",
    "triturarde": "triturar",
    "triturardes": "triturar",
    "triturare": "triturar",
    "triturarei": "triturar",
    "triturareis": "triturar",
    "triturarem": "triturar",
    "trituraremos": "triturar",
    "triturares": "triturar",
    "trituraria": "triturar",
    "triturariam": "triturar",
    "triturarias": "triturar",
    "triturarmo": "triturar",
    "triturarmos": "triturar",
    "triturará": "triturar",
    "triturarás": "triturar",
    "triturarão": "triturar",
    "trituraríamos": "triturar",
    "trituraríeis": "triturar",
    "trituras": "triturar",
    "triturasse": "triturar",
    "triturassem": "triturar",
    "triturasses": "triturar",
    "trituraste": "triturar",
    "triturastes": "triturar",
    "triturava": "triturar",
    "trituravam": "triturar",
    "trituravas": "triturar",
    "triturações": "trituração",
    "triture": "triturar",
    "triturei": "triturar",
    "tritureis": "triturar",
    "triturem": "triturar",
    "trituremo": "triturar",
    "trituremos": "triturar",
    "tritures": "triturar",
    "trituro": "triturar",
    "triturou": "triturar",
    "triturá": "triturar",
    "triturámo": "triturar",
    "triturámos": "triturar",
    "trituráramo": "triturar",
    "trituráramos": "triturar",
    "triturárei": "triturar",
    "trituráreis": "triturar",
    "triturásseis": "triturar",
    "triturássemos": "triturar",
    "triturávamo": "triturar",
    "triturávamos": "triturar",
    "triturávei": "triturar",
    "trituráveis": "triturável",
    "tritícea": "tritíceo",
    "tritíceas": "tritíceo",
    "tritíceos": "tritíceo",
    "tritónidas": "tritónida",
    "tritões": "tritão",
    "triunfa": "triunfar",
    "triunfada": "triunfar",
    "triunfadas": "triunfar",
    "triunfado": "triunfar",
    "triunfadora": "triunfador",
    "triunfadoras": "triunfador",
    "triunfadores": "triunfador",
    "triunfados": "triunfar",
    "triunfai": "triunfar",
    "triunfais": "triunfar",
    "triunfalismos": "triunfalismo",
    "triunfalistas": "triunfalista",
    "triunfam": "triunfar",
    "triunfamo": "triunfar",
    "triunfamos": "triunfar",
    "triunfando": "triunfar",
    "triunfantes": "triunfante",
    "triunfara": "triunfar",
    "triunfaram": "triunfar",
    "triunfaras": "triunfar",
    "triunfardes": "triunfar",
    "triunfarei": "triunfar",
    "triunfareis": "triunfar",
    "triunfarem": "triunfar",
    "triunfaremos": "triunfar",
    "triunfares": "triunfar",
    "triunfaria": "triunfar",
    "triunfariam": "triunfar",
    "triunfarias": "triunfar",
    "triunfarmo": "triunfar",
    "triunfarmos": "triunfar",
    "triunfará": "triunfar",
    "triunfarás": "triunfar",
    "triunfarão": "triunfar",
    "triunfaríamos": "triunfar",
    "triunfaríeis": "triunfar",
    "triunfas": "triunfar",
    "triunfasse": "triunfar",
    "triunfassem": "triunfar",
    "triunfasses": "triunfar",
    "triunfaste": "triunfar",
    "triunfastes": "triunfar",
    "triunfava": "triunfar",
    "triunfavam": "triunfar",
    "triunfavas": "triunfar",
    "triunfe": "triunfar",
    "triunfei": "triunfar",
    "triunfeis": "triunfar",
    "triunfem": "triunfar",
    "triunfemo": "triunfar",
    "triunfemos": "triunfar",
    "triunfes": "triunfar",
    "triunfo": "triunfar",
    "triunfos": "triunfo",
    "triunfou": "triunfar",
    "triunfámo": "triunfar",
    "triunfámos": "triunfar",
    "triunfáramo": "triunfar",
    "triunfáramos": "triunfar",
    "triunfáreis": "triunfar",
    "triunfásseis": "triunfar",
    "triunfássemos": "triunfar",
    "triunfávamo": "triunfar",
    "triunfávamos": "triunfar",
    "triunfáveis": "triunfar",
    "triunvirados": "triunvirado",
    "triunvirais": "triunviral",
    "triunviratos": "triunvirato",
    "trivalentes": "trivalente",
    "trivalves": "trivalve",
    "trivalências": "trivalência",
    "triviais": "trivial",
    "trivialidades": "trivialidade",
    "trivializa": "trivializar",
    "trivializada": "trivializar",
    "trivializadas": "trivializar",
    "trivializado": "trivializar",
    "trivializados": "trivializar",
    "trivializai": "trivializar",
    "trivializais": "trivializar",
    "trivializam": "trivializar",
    "trivializamo": "trivializar",
    "trivializamos": "trivializar",
    "trivializando": "trivializar",
    "trivializara": "trivializar",
    "trivializaram": "trivializar",
    "trivializaras": "trivializar",
    "trivializarde": "trivializar",
    "trivializardes": "trivializar",
    "trivializare": "trivializar",
    "trivializarei": "trivializar",
    "trivializareis": "trivializar",
    "trivializarem": "trivializar",
    "trivializaremos": "trivializar",
    "trivializares": "trivializar",
    "trivializaria": "trivializar",
    "trivializariam": "trivializar",
    "trivializarias": "trivializar",
    "trivializarmo": "trivializar",
    "trivializarmos": "trivializar",
    "trivializará": "trivializar",
    "trivializarás": "trivializar",
    "trivializarão": "trivializar",
    "trivializaríamos": "trivializar",
    "trivializaríeis": "trivializar",
    "trivializas": "trivializar",
    "trivializasse": "trivializar",
    "trivializassem": "trivializar",
    "trivializasses": "trivializar",
    "trivializaste": "trivializar",
    "trivializastes": "trivializar",
    "trivializava": "trivializar",
    "trivializavam": "trivializar",
    "trivializavas": "trivializar",
    "trivialize": "trivializar",
    "trivializei": "trivializar",
    "trivializeis": "trivializar",
    "trivializem": "trivializar",
    "trivializemo": "trivializar",
    "trivializemos": "trivializar",
    "trivializes": "trivializar",
    "trivializo": "trivializar",
    "trivializou": "trivializar",
    "trivializá": "trivializar",
    "trivializámo": "trivializar",
    "trivializámos": "trivializar",
    "trivializáramo": "trivializar",
    "trivializáramos": "trivializar",
    "trivializárei": "trivializar",
    "trivializáreis": "trivializar",
    "trivializásseis": "trivializar",
    "trivializássemos": "trivializar",
    "trivializávamo": "trivializar",
    "trivializávamos": "trivializar",
    "trivializávei": "trivializar",
    "trivializáveis": "trivializar",
    "trivogais": "trivogal",
    "trizes": "triz",
    "triácidos": "triácido",
    "triádicos": "triádico",
    "triários": "triário",
    "triásica": "triásico",
    "triásicas": "triásico",
    "triásicos": "triásico",
    "triândrias": "triândria",
    "triândrica": "triândrico",
    "triândricas": "triândrico",
    "triândricos": "triândrico",
    "triângulos": "triângulo",
    "triénios": "triénio",
    "trióbolos": "trióbolo",
    "trióica": "trióico",
    "trióicas": "trióico",
    "trióicos": "trióico",
    "triúnvira": "triúnviro",
    "triúnviras": "triúnviro",
    "triúnviros": "triúnviro",
    "troa": "troar",
    "troada": "troar",
    "troadas": "troar",
    "troado": "troar",
    "troados": "troar",
    "troai": "troar",
    "troais": "troar",
    "troam": "troar",
    "troamo": "troar",
    "troamos": "troar",
    "troando": "troar",
    "troantes": "troante",
    "troara": "troar",
    "troaram": "troar",
    "troaras": "troar",
    "troardes": "troar",
    "troarei": "troar",
    "troareis": "troar",
    "troarem": "troar",
    "troaremos": "troar",
    "troares": "troar",
    "troaria": "troar",
    "troariam": "troar",
    "troarias": "troar",
    "troarmo": "troar",
    "troarmos": "troar",
    "troará": "troar",
    "troarás": "troar",
    "troarão": "troar",
    "troaríamos": "troar",
    "troaríeis": "troar",
    "troas": "troar",
    "troasse": "troar",
    "troassem": "troar",
    "troasses": "troar",
    "troaste": "troar",
    "troastes": "troar",
    "troava": "troar",
    "troavam": "troar",
    "troavas": "troar",
    "troca": "trocar",
    "trocada": "trocar",
    "trocadas": "trocar",
    "trocadilha": "trocadilhar",
    "trocadilhada": "trocadilhar",
    "trocadilhadas": "trocadilhar",
    "trocadilhado": "trocadilhar",
    "trocadilhados": "trocadilhar",
    "trocadilhai": "trocadilhar",
    "trocadilhais": "trocadilhar",
    "trocadilham": "trocadilhar",
    "trocadilhamo": "trocadilhar",
    "trocadilhamos": "trocadilhar",
    "trocadilhando": "trocadilhar",
    "trocadilhara": "trocadilhar",
    "trocadilharam": "trocadilhar",
    "trocadilharas": "trocadilhar",
    "trocadilhardes": "trocadilhar",
    "trocadilharei": "trocadilhar",
    "trocadilhareis": "trocadilhar",
    "trocadilharem": "trocadilhar",
    "trocadilharemos": "trocadilhar",
    "trocadilhares": "trocadilhar",
    "trocadilharia": "trocadilhar",
    "trocadilhariam": "trocadilhar",
    "trocadilharias": "trocadilhar",
    "trocadilharmo": "trocadilhar",
    "trocadilharmos": "trocadilhar",
    "trocadilhará": "trocadilhar",
    "trocadilharás": "trocadilhar",
    "trocadilharão": "trocadilhar",
    "trocadilharíamos": "trocadilhar",
    "trocadilharíeis": "trocadilhar",
    "trocadilhas": "trocadilhar",
    "trocadilhasse": "trocadilhar",
    "trocadilhassem": "trocadilhar",
    "trocadilhasses": "trocadilhar",
    "trocadilhaste": "trocadilhar",
    "trocadilhastes": "trocadilhar",
    "trocadilhava": "trocadilhar",
    "trocadilhavam": "trocadilhar",
    "trocadilhavas": "trocadilhar",
    "trocadilhe": "trocadilhar",
    "trocadilhei": "trocadilhar",
    "trocadilheis": "trocadilhar",
    "trocadilhem": "trocadilhar",
    "trocadilhemo": "trocadilhar",
    "trocadilhemos": "trocadilhar",
    "trocadilhes": "trocadilhar",
    "trocadilho": "trocadilhar",
    "trocadilhos": "trocadilho",
    "trocadilhou": "trocadilhar",
    "trocadilhámo": "trocadilhar",
    "trocadilhámos": "trocadilhar",
    "trocadilháramo": "trocadilhar",
    "trocadilháramos": "trocadilhar",
    "trocadilháreis": "trocadilhar",
    "trocadilhásseis": "trocadilhar",
    "trocadilhássemos": "trocadilhar",
    "trocadilhávamo": "trocadilhar",
    "trocadilhávamos": "trocadilhar",
    "trocadilháveis": "trocadilhar",
    "trocadinha": "trocado",
    "trocadinhas": "trocado",
    "trocadinho": "trocado",
    "trocadinhos": "trocado",
    "trocadita": "trocado",
    "trocaditas": "trocado",
    "trocadito": "trocado",
    "trocaditos": "trocado",
    "trocado": "trocar",
    "trocadora": "trocador",
    "trocadoras": "trocador",
    "trocadores": "trocador",
    "trocados": "trocar",
    "trocadíssima": "trocado",
    "trocadíssimas": "trocado",
    "trocadíssimo": "trocado",
    "trocadíssimos": "trocado",
    "trocai": "trocar",
    "trocaica": "trocaico",
    "trocaicas": "trocaico",
    "trocaicos": "trocaico",
    "trocais": "trocar",
    "trocalhistas": "trocalhista",
    "trocam": "trocar",
    "trocamo": "trocar",
    "trocamos": "trocar",
    "trocando": "trocar",
    "trocantinos": "trocantino",
    "trocara": "trocar",
    "trocaram": "trocar",
    "trocaras": "trocar",
    "trocarde": "trocar",
    "trocardes": "trocar",
    "trocare": "trocar",
    "trocarei": "trocar",
    "trocareis": "trocar",
    "trocarem": "trocar",
    "trocaremos": "trocar",
    "trocares": "trocar",
    "trocaria": "trocar",
    "trocariam": "trocar",
    "trocarias": "trocar",
    "trocarmo": "trocar",
    "trocarmos": "trocar",
    "trocartes": "trocarte",
    "trocará": "trocar",
    "trocarás": "trocar",
    "trocarão": "trocar",
    "trocaríamos": "trocar",
    "trocaríeis": "trocar",
    "trocas": "trocar",
    "trocasse": "trocar",
    "trocassem": "trocar",
    "trocasses": "trocar",
    "trocaste": "trocar",
    "trocastes": "trocar",
    "trocava": "trocar",
    "trocavam": "trocar",
    "trocavas": "trocar",
    "trocazes": "trocaz",
    "troce": "troçar",
    "trocei": "troçar",
    "troceis": "troçar",
    "trocem": "troçar",
    "trocemo": "troçar",
    "trocemos": "troçar",
    "troces": "troçar",
    "trocha": "trochar",
    "trochada": "trochar",
    "trochadas": "trochar",
    "trochado": "trochar",
    "trochados": "trochar",
    "trochai": "trochar",
    "trochais": "trochar",
    "trocham": "trochar",
    "trochamo": "trochar",
    "trochamos": "trochar",
    "trochando": "trochar",
    "trochara": "trochar",
    "trocharam": "trochar",
    "trocharas": "trochar",
    "trocharde": "trochar",
    "trochardes": "trochar",
    "trochare": "trochar",
    "trocharei": "trochar",
    "trochareis": "trochar",
    "trocharem": "trochar",
    "trocharemos": "trochar",
    "trochares": "trochar",
    "trocharia": "trochar",
    "trochariam": "trochar",
    "trocharias": "trochar",
    "trocharmo": "trochar",
    "trocharmos": "trochar",
    "trochará": "trochar",
    "trocharás": "trochar",
    "trocharão": "trochar",
    "trocharíamos": "trochar",
    "trocharíeis": "trochar",
    "trochas": "trochar",
    "trochasse": "trochar",
    "trochassem": "trochar",
    "trochasses": "trochar",
    "trochaste": "trochar",
    "trochastes": "trochar",
    "trochava": "trochar",
    "trochavam": "trochar",
    "trochavas": "trochar",
    "troche": "trochar",
    "trochei": "trochar",
    "trocheis": "trochar",
    "trochem": "trochar",
    "trochemo": "trochar",
    "trochemos": "trochar",
    "troches": "trochar",
    "trocho": "trochar",
    "trochos": "trocho",
    "trochou": "trochar",
    "trochá": "trochar",
    "trochámo": "trochar",
    "trochámos": "trochar",
    "trocháramo": "trochar",
    "trocháramos": "trochar",
    "trochárei": "trochar",
    "trocháreis": "trochar",
    "trochásseis": "trochar",
    "trochássemos": "trochar",
    "trochávamo": "trochar",
    "trochávamos": "trochar",
    "trochávei": "trochar",
    "trocháveis": "trochar",
    "trocisca": "trociscar",
    "trociscada": "trociscar",
    "trociscadas": "trociscar",
    "trociscado": "trociscar",
    "trociscados": "trociscar",
    "trociscai": "trociscar",
    "trociscais": "trociscar",
    "trociscam": "trociscar",
    "trociscamo": "trociscar",
    "trociscamos": "trociscar",
    "trociscando": "trociscar",
    "trociscara": "trociscar",
    "trociscaram": "trociscar",
    "trociscaras": "trociscar",
    "trociscarde": "trociscar",
    "trociscardes": "trociscar",
    "trociscare": "trociscar",
    "trociscarei": "trociscar",
    "trociscareis": "trociscar",
    "trociscarem": "trociscar",
    "trociscaremos": "trociscar",
    "trociscares": "trociscar",
    "trociscaria": "trociscar",
    "trociscariam": "trociscar",
    "trociscarias": "trociscar",
    "trociscarmo": "trociscar",
    "trociscarmos": "trociscar",
    "trociscará": "trociscar",
    "trociscarás": "trociscar",
    "trociscarão": "trociscar",
    "trociscaríamos": "trociscar",
    "trociscaríeis": "trociscar",
    "trociscas": "trociscar",
    "trociscasse": "trociscar",
    "trociscassem": "trociscar",
    "trociscasses": "trociscar",
    "trociscaste": "trociscar",
    "trociscastes": "trociscar",
    "trociscava": "trociscar",
    "trociscavam": "trociscar",
    "trociscavas": "trociscar",
    "trociscaçveis": "trociscaçvel",
    "trocisco": "trociscar",
    "trociscos": "trocisco",
    "trociscou": "trociscar",
    "trociscá": "trociscar",
    "trociscámo": "trociscar",
    "trociscámos": "trociscar",
    "trociscáramo": "trociscar",
    "trociscáramos": "trociscar",
    "trociscárei": "trociscar",
    "trociscáreis": "trociscar",
    "trociscásseis": "trociscar",
    "trociscássemos": "trociscar",
    "trociscávamo": "trociscar",
    "trociscávamos": "trociscar",
    "trociscávei": "trociscar",
    "trociscáveis": "trociscar",
    "trocisque": "trociscar",
    "trocisquei": "trociscar",
    "trocisqueis": "trociscar",
    "trocisquem": "trociscar",
    "trocisquemo": "trociscar",
    "trocisquemos": "trociscar",
    "trocisques": "trociscar",
    "trocistas": "trocista",
    "trocistazinha": "trocista",
    "trocistazinhas": "trocista",
    "trocistazinho": "trocista",
    "trocistazinhos": "trocista",
    "trocistazita": "trocista",
    "trocistazitas": "trocista",
    "trocistazito": "trocista",
    "trocistazitos": "trocista",
    "trocleares": "troclear",
    "troco": "trocar",
    "trocos": "troco",
    "trocosferas": "trocosfera",
    "trocou": "trocar",
    "trocá": "trocar",
    "trocámo": "trocar",
    "trocámos": "trocar",
    "trocáramo": "trocar",
    "trocáramos": "trocar",
    "trocárei": "trocar",
    "trocáreis": "trocar",
    "trocásseis": "trocar",
    "trocássemos": "trocar",
    "trocávamo": "trocar",
    "trocávamos": "trocar",
    "trocávei": "trocar",
    "trocáveis": "trocável",
    "trocânteres": "trocânter",
    "trocóforos": "trocóforo",
    "trocóidea": "trocóideo",
    "trocóideas": "trocóideo",
    "trocóideos": "trocóideo",
    "trocóides": "trocóide",
    "troe": "troar",
    "troei": "troar",
    "troeis": "troar",
    "troem": "troar",
    "troemo": "troar",
    "troemos": "troar",
    "troes": "troar",
    "trofas": "trofa",
    "trofeu": "troféu",
    "trofeus": "troféu",
    "trofobioses": "trofobiose",
    "trofoneuroses": "trofoneurose",
    "trofonúcleos": "trofonúcleo",
    "trofopatias": "trofopatia",
    "trofoplasmas": "trofoplasma",
    "trofospermas": "trofosperma",
    "trofospérmios": "trofospérmio",
    "trofotactismos": "trofotactismo",
    "trofotropismos": "trofotropismo",
    "troféus": "troféu",
    "trogalhos": "trogalho",
    "trogloditas": "troglodita",
    "trogloditídeos": "trogloditídeo",
    "troglodítica": "troglodítico",
    "troglodíticas": "troglodítico",
    "troglodíticos": "troglodítico",
    "troglóbia": "troglóbio",
    "troglóbias": "troglóbio",
    "troglóbios": "troglóbio",
    "troglófila": "troglófilo",
    "troglófilas": "troglófilo",
    "troglófilos": "troglófilo",
    "troiana": "troiano",
    "troianas": "troiano",
    "troianos": "troiano",
    "troikas": "troika",
    "troiles": "troile",
    "troilites": "troilite",
    "troixadas": "troixada",
    "troixas": "troixa",
    "troixos": "troixo",
    "trolarós": "trolaró",
    "troleibuss": "troleibus",
    "trolhas": "trolha",
    "trolhos": "trolho",
    "trololós": "trololó",
    "trombadas": "trombada",
    "trombadinha": "trombada",
    "trombadinhas": "trombada",
    "trombadita": "trombada",
    "trombaditas": "trombada",
    "trombalazanas": "trombalazana",
    "trombas": "tromba",
    "trombeiros": "trombeiro",
    "trombeja": "trombejar",
    "trombejada": "trombejar",
    "trombejadas": "trombejar",
    "trombejado": "trombejar",
    "trombejados": "trombejar",
    "trombejai": "trombejar",
    "trombejais": "trombejar",
    "trombejam": "trombejar",
    "trombejamo": "trombejar",
    "trombejamos": "trombejar",
    "trombejando": "trombejar",
    "trombejantes": "trombejante",
    "trombejara": "trombejar",
    "trombejaram": "trombejar",
    "trombejaras": "trombejar",
    "trombejardes": "trombejar",
    "trombejarei": "trombejar",
    "trombejareis": "trombejar",
    "trombejarem": "trombejar",
    "trombejaremos": "trombejar",
    "trombejares": "trombejar",
    "trombejaria": "trombejar",
    "trombejariam": "trombejar",
    "trombejarias": "trombejar",
    "trombejarmo": "trombejar",
    "trombejarmos": "trombejar",
    "trombejará": "trombejar",
    "trombejarás": "trombejar",
    "trombejarão": "trombejar",
    "trombejaríamos": "trombejar",
    "trombejaríeis": "trombejar",
    "trombejas": "trombejar",
    "trombejasse": "trombejar",
    "trombejassem": "trombejar",
    "trombejasses": "trombejar",
    "trombejaste": "trombejar",
    "trombejastes": "trombejar",
    "trombejava": "trombejar",
    "trombejavam": "trombejar",
    "trombejavas": "trombejar",
    "trombeje": "trombejar",
    "trombejei": "trombejar",
    "trombejeis": "trombejar",
    "trombejem": "trombejar",
    "trombejemo": "trombejar",
    "trombejemos": "trombejar",
    "trombejes": "trombejar",
    "trombejo": "trombejar",
    "trombejou": "trombejar",
    "trombejámo": "trombejar",
    "trombejámos": "trombejar",
    "trombejáramo": "trombejar",
    "trombejáramos": "trombejar",
    "trombejáreis": "trombejar",
    "trombejásseis": "trombejar",
    "trombejássemos": "trombejar",
    "trombejávamo": "trombejar",
    "trombejávamos": "trombejar",
    "trombejáveis": "trombejar",
    "trombetadas": "trombetada",
    "trombetas": "trombeta",
    "trombeteada": "trombetear",
    "trombeteadas": "trombetear",
    "trombeteado": "trombetear",
    "trombeteados": "trombetear",
    "trombeteai": "trombetear",
    "trombeteais": "trombetear",
    "trombeteamo": "trombetear",
    "trombeteamos": "trombetear",
    "trombeteando": "trombetear",
    "trombeteara": "trombetear",
    "trombetearam": "trombetear",
    "trombetearas": "trombetear",
    "trombeteardes": "trombetear",
    "trombetearei": "trombetear",
    "trombeteareis": "trombetear",
    "trombetearem": "trombetear",
    "trombetearemos": "trombetear",
    "trombeteares": "trombetear",
    "trombetearia": "trombetear",
    "trombeteariam": "trombetear",
    "trombetearias": "trombetear",
    "trombetearmo": "trombetear",
    "trombetearmos": "trombetear",
    "trombeteará": "trombetear",
    "trombetearás": "trombetear",
    "trombetearão": "trombetear",
    "trombetearíamos": "trombetear",
    "trombetearíeis": "trombetear",
    "trombeteasse": "trombetear",
    "trombeteassem": "trombetear",
    "trombeteasses": "trombetear",
    "trombeteaste": "trombetear",
    "trombeteastes": "trombetear",
    "trombeteava": "trombetear",
    "trombeteavam": "trombetear",
    "trombeteavas": "trombetear",
    "trombeteei": "trombetear",
    "trombeteeis": "trombetear",
    "trombeteemo": "trombetear",
    "trombeteemos": "trombetear",
    "trombeteia": "trombetear",
    "trombeteiam": "trombetear",
    "trombeteias": "trombetear",
    "trombeteie": "trombetear",
    "trombeteiem": "trombetear",
    "trombeteies": "trombetear",
    "trombeteio": "trombetear",
    "trombeteira": "trombeteiro",
    "trombeteiras": "trombeteiro",
    "trombeteiros": "trombeteiro",
    "trombeteou": "trombetear",
    "trombeteámo": "trombetear",
    "trombeteámos": "trombetear",
    "trombeteáramo": "trombetear",
    "trombeteáramos": "trombetear",
    "trombeteáreis": "trombetear",
    "trombeteásseis": "trombetear",
    "trombeteássemos": "trombetear",
    "trombeteávamo": "trombetear",
    "trombeteávamos": "trombetear",
    "trombeteáveis": "trombetear",
    "trombetistas": "trombetista",
    "trombetões": "trombetão",
    "trombica": "trombicar",
    "trombicada": "trombicar",
    "trombicadas": "trombicar",
    "trombicado": "trombicar",
    "trombicados": "trombicar",
    "trombicai": "trombicar",
    "trombicais": "trombicar",
    "trombicam": "trombicar",
    "trombicamo": "trombicar",
    "trombicamos": "trombicar",
    "trombicando": "trombicar",
    "trombicara": "trombicar",
    "trombicaram": "trombicar",
    "trombicaras": "trombicar",
    "trombicarde": "trombicar",
    "trombicardes": "trombicar",
    "trombicare": "trombicar",
    "trombicarei": "trombicar",
    "trombicareis": "trombicar",
    "trombicarem": "trombicar",
    "trombicaremos": "trombicar",
    "trombicares": "trombicar",
    "trombicaria": "trombicar",
    "trombicariam": "trombicar",
    "trombicarias": "trombicar",
    "trombicarmo": "trombicar",
    "trombicarmos": "trombicar",
    "trombicará": "trombicar",
    "trombicarás": "trombicar",
    "trombicarão": "trombicar",
    "trombicaríamos": "trombicar",
    "trombicaríeis": "trombicar",
    "trombicas": "trombicar",
    "trombicasse": "trombicar",
    "trombicassem": "trombicar",
    "trombicasses": "trombicar",
    "trombicaste": "trombicar",
    "trombicastes": "trombicar",
    "trombicava": "trombicar",
    "trombicavam": "trombicar",
    "trombicavas": "trombicar",
    "trombico": "trombicar",
    "trombicou": "trombicar",
    "trombicá": "trombicar",
    "trombicámo": "trombicar",
    "trombicámos": "trombicar",
    "trombicáramo": "trombicar",
    "trombicáramos": "trombicar",
    "trombicárei": "trombicar",
    "trombicáreis": "trombicar",
    "trombicásseis": "trombicar",
    "trombicássemos": "trombicar",
    "trombicávamo": "trombicar",
    "trombicávamos": "trombicar",
    "trombicávei": "trombicar",
    "trombicáveis": "trombicar",
    "trombidioses": "trombidiose",
    "trombidídeos": "trombidídeo",
    "trombinas": "trombina",
    "trombinha": "tromba",
    "trombinhas": "tromba",
    "trombinos": "trombino",
    "trombique": "trombicar",
    "trombiquei": "trombicar",
    "trombiqueis": "trombicar",
    "trombiquem": "trombicar",
    "trombiquemo": "trombicar",
    "trombiquemos": "trombicar",
    "trombiques": "trombicar",
    "trombita": "tromba",
    "trombitas": "tromba",
    "tromblons": "tromblom",
    "trombocitoses": "trombocitose",
    "tromboflebites": "tromboflebite",
    "trombolítica": "trombolítico",
    "trombolíticas": "trombolítico",
    "trombolíticos": "trombolítico",
    "trombones": "trombone",
    "trombonistas": "trombonista",
    "trombos": "trombo",
    "tromboses": "trombose",
    "trombuda": "trombudo",
    "trombudas": "trombudo",
    "trombudinho": "trombudo",
    "trombudinhos": "trombudo",
    "trombudito": "trombudo",
    "trombuditos": "trombudo",
    "trombudos": "trombudo",
    "trombudozinho": "trombudo",
    "trombudozinhos": "trombudo",
    "trombudozito": "trombudo",
    "trombudozitos": "trombudo",
    "trombídidas": "trombídida",
    "trombídios": "trombídio",
    "trombífera": "trombífero",
    "trombíferas": "trombífero",
    "trombíferos": "trombífero",
    "trombócitos": "trombócito",
    "trombóides": "trombóide",
    "trombões": "trombão",
    "trompadas": "trompada",
    "trompas": "trompa",
    "trompaços": "trompaço",
    "trompeja": "trompejar",
    "trompejada": "trompejar",
    "trompejadas": "trompejar",
    "trompejado": "trompejar",
    "trompejados": "trompejar",
    "trompejai": "trompejar",
    "trompejais": "trompejar",
    "trompejam": "trompejar",
    "trompejamo": "trompejar",
    "trompejamos": "trompejar",
    "trompejando": "trompejar",
    "trompejara": "trompejar",
    "trompejaram": "trompejar",
    "trompejaras": "trompejar",
    "trompejardes": "trompejar",
    "trompejarei": "trompejar",
    "trompejareis": "trompejar",
    "trompejarem": "trompejar",
    "trompejaremos": "trompejar",
    "trompejares": "trompejar",
    "trompejaria": "trompejar",
    "trompejariam": "trompejar",
    "trompejarias": "trompejar",
    "trompejarmo": "trompejar",
    "trompejarmos": "trompejar",
    "trompejará": "trompejar",
    "trompejarás": "trompejar",
    "trompejarão": "trompejar",
    "trompejaríamos": "trompejar",
    "trompejaríeis": "trompejar",
    "trompejas": "trompejar",
    "trompejasse": "trompejar",
    "trompejassem": "trompejar",
    "trompejasses": "trompejar",
    "trompejaste": "trompejar",
    "trompejastes": "trompejar",
    "trompejava": "trompejar",
    "trompejavam": "trompejar",
    "trompejavas": "trompejar",
    "trompeje": "trompejar",
    "trompejei": "trompejar",
    "trompejeis": "trompejar",
    "trompejem": "trompejar",
    "trompejemo": "trompejar",
    "trompejemos": "trompejar",
    "trompejes": "trompejar",
    "trompejo": "trompejar",
    "trompejou": "trompejar",
    "trompejámo": "trompejar",
    "trompejámos": "trompejar",
    "trompejáramo": "trompejar",
    "trompejáramos": "trompejar",
    "trompejáreis": "trompejar",
    "trompejásseis": "trompejar",
    "trompejássemos": "trompejar",
    "trompejávamo": "trompejar",
    "trompejávamos": "trompejar",
    "trompejáveis": "trompejar",
    "trompetas": "trompeta",
    "trompetes": "trompete",
    "trompetistas": "trompetista",
    "trompistas": "trompista",
    "trompázios": "trompázio",
    "trompões": "trompão",
    "trona": "tronar",
    "tronada": "tronar",
    "tronadas": "tronar",
    "tronado": "tronar",
    "tronados": "tronar",
    "tronai": "tronar",
    "tronais": "tronar",
    "tronam": "tronar",
    "tronamo": "tronar",
    "tronamos": "tronar",
    "tronando": "tronar",
    "tronantes": "tronante",
    "tronara": "tronar",
    "tronaram": "tronar",
    "tronaras": "tronar",
    "tronardes": "tronar",
    "tronarei": "tronar",
    "tronareis": "tronar",
    "tronarem": "tronar",
    "tronaremos": "tronar",
    "tronares": "tronar",
    "tronaria": "tronar",
    "tronariam": "tronar",
    "tronarias": "tronar",
    "tronarmo": "tronar",
    "tronarmos": "tronar",
    "tronará": "tronar",
    "tronarás": "tronar",
    "tronarão": "tronar",
    "tronaríamos": "tronar",
    "tronaríeis": "tronar",
    "tronas": "tronar",
    "tronasse": "tronar",
    "tronassem": "tronar",
    "tronasses": "tronar",
    "tronaste": "tronar",
    "tronastes": "tronar",
    "tronava": "tronar",
    "tronavam": "tronar",
    "tronavas": "tronar",
    "tronca": "tronco",
    "troncada": "troncar",
    "troncadas": "troncar",
    "troncado": "troncar",
    "troncados": "troncar",
    "troncai": "troncar",
    "troncais": "troncar",
    "troncam": "troncar",
    "troncamo": "troncar",
    "troncamos": "troncar",
    "troncando": "troncar",
    "troncara": "troncar",
    "troncaram": "troncar",
    "troncaras": "troncar",
    "troncarde": "troncar",
    "troncardes": "troncar",
    "troncare": "troncar",
    "troncarei": "troncar",
    "troncareis": "troncar",
    "troncarem": "troncar",
    "troncaremos": "troncar",
    "troncares": "troncar",
    "troncaria": "troncar",
    "troncariam": "troncar",
    "troncarias": "troncaria",
    "troncarmo": "troncar",
    "troncarmos": "troncar",
    "troncará": "troncar",
    "troncarás": "troncar",
    "troncarão": "troncar",
    "troncaríamos": "troncar",
    "troncaríeis": "troncar",
    "troncas": "tronco",
    "troncasse": "troncar",
    "troncassem": "troncar",
    "troncasses": "troncar",
    "troncaste": "troncar",
    "troncastes": "troncar",
    "troncava": "troncar",
    "troncavam": "troncar",
    "troncavas": "troncar",
    "troncha": "tronchar",
    "tronchada": "tronchar",
    "tronchadas": "tronchar",
    "tronchado": "tronchar",
    "tronchados": "tronchar",
    "tronchai": "tronchar",
    "tronchais": "tronchar",
    "troncham": "tronchar",
    "tronchamo": "tronchar",
    "tronchamos": "tronchar",
    "tronchando": "tronchar",
    "tronchara": "tronchar",
    "troncharam": "tronchar",
    "troncharas": "tronchar",
    "troncharde": "tronchar",
    "tronchardes": "tronchar",
    "tronchare": "tronchar",
    "troncharei": "tronchar",
    "tronchareis": "tronchar",
    "troncharem": "tronchar",
    "troncharemos": "tronchar",
    "tronchares": "tronchar",
    "troncharia": "tronchar",
    "tronchariam": "tronchar",
    "troncharias": "tronchar",
    "troncharmo": "tronchar",
    "troncharmos": "tronchar",
    "tronchará": "tronchar",
    "troncharás": "tronchar",
    "troncharão": "tronchar",
    "troncharíamos": "tronchar",
    "troncharíeis": "tronchar",
    "tronchas": "tronchar",
    "tronchasse": "tronchar",
    "tronchassem": "tronchar",
    "tronchasses": "tronchar",
    "tronchaste": "tronchar",
    "tronchastes": "tronchar",
    "tronchava": "tronchar",
    "tronchavam": "tronchar",
    "tronchavas": "tronchar",
    "tronche": "tronchar",
    "tronchei": "tronchar",
    "troncheis": "tronchar",
    "tronchem": "tronchar",
    "tronchemo": "tronchar",
    "tronchemos": "tronchar",
    "tronches": "tronchar",
    "troncho": "tronchar",
    "tronchos": "troncho",
    "tronchou": "tronchar",
    "tronchuda": "tronchudo",
    "tronchudas": "tronchudo",
    "tronchudos": "tronchudo",
    "tronchá": "tronchar",
    "tronchámo": "tronchar",
    "tronchámos": "tronchar",
    "troncháramo": "tronchar",
    "troncháramos": "tronchar",
    "tronchárei": "tronchar",
    "troncháreis": "tronchar",
    "tronchásseis": "tronchar",
    "tronchássemos": "tronchar",
    "tronchávamo": "tronchar",
    "tronchávamos": "tronchar",
    "tronchávei": "tronchar",
    "troncháveis": "tronchar",
    "tronco": "troncar",
    "troncos": "tronco",
    "troncou": "troncar",
    "troncuda": "troncudo",
    "troncudas": "troncudo",
    "troncudinha": "troncudo",
    "troncudinhas": "troncudo",
    "troncudinho": "troncudo",
    "troncudinhos": "troncudo",
    "troncudita": "troncudo",
    "troncuditas": "troncudo",
    "troncudito": "troncudo",
    "troncuditos": "troncudo",
    "troncudos": "troncudo",
    "troncudíssima": "troncudo",
    "troncudíssimas": "troncudo",
    "troncudíssimo": "troncudo",
    "troncudíssimos": "troncudo",
    "tronculares": "troncular",
    "troncá": "troncar",
    "troncámo": "troncar",
    "troncámos": "troncar",
    "troncáramo": "troncar",
    "troncáramos": "troncar",
    "troncárei": "troncar",
    "troncáreis": "troncar",
    "troncásseis": "troncar",
    "troncássemos": "troncar",
    "troncávamo": "troncar",
    "troncávamos": "troncar",
    "troncávei": "troncar",
    "troncáveis": "troncar",
    "trone": "tronar",
    "tronei": "tronar",
    "troneiras": "troneira",
    "troneis": "tronar",
    "tronem": "tronar",
    "tronemo": "tronar",
    "tronemos": "tronar",
    "trones": "tronar",
    "tronetos": "troneto",
    "trono": "tronar",
    "tronos": "trono",
    "tronou": "tronar",
    "tronque": "troncar",
    "tronquei": "troncar",
    "tronqueira": "tronqueiro",
    "tronqueiras": "tronqueiro",
    "tronqueiros": "tronqueiro",
    "tronqueis": "troncar",
    "tronquem": "troncar",
    "tronquemo": "troncar",
    "tronquemos": "troncar",
    "tronques": "troncar",
    "trons": "trom",
    "tronámo": "tronar",
    "tronámos": "tronar",
    "tronáramo": "tronar",
    "tronáramos": "tronar",
    "tronáreis": "tronar",
    "tronásseis": "tronar",
    "tronássemos": "tronar",
    "tronávamo": "tronar",
    "tronávamos": "tronar",
    "tronáveis": "tronar",
    "troo": "troar",
    "troou": "troar",
    "tropas": "tropa",
    "tropeada": "tropear",
    "tropeadas": "tropear",
    "tropeado": "tropear",
    "tropeados": "tropear",
    "tropeai": "tropear",
    "tropeais": "tropear",
    "tropeamo": "tropear",
    "tropeamos": "tropear",
    "tropeando": "tropear",
    "tropeara": "tropear",
    "tropearam": "tropear",
    "tropearas": "tropear",
    "tropeardes": "tropear",
    "tropearei": "tropear",
    "tropeareis": "tropear",
    "tropearem": "tropear",
    "tropearemos": "tropear",
    "tropeares": "tropear",
    "tropearia": "tropear",
    "tropeariam": "tropear",
    "tropearias": "tropear",
    "tropearmo": "tropear",
    "tropearmos": "tropear",
    "tropeará": "tropear",
    "tropearás": "tropear",
    "tropearão": "tropear",
    "tropearíamos": "tropear",
    "tropearíeis": "tropear",
    "tropeasse": "tropear",
    "tropeassem": "tropear",
    "tropeasses": "tropear",
    "tropeaste": "tropear",
    "tropeastes": "tropear",
    "tropeava": "tropear",
    "tropeavam": "tropear",
    "tropeavas": "tropear",
    "tropece": "tropeçar",
    "tropecei": "tropeçar",
    "tropeceis": "tropeçar",
    "tropecelhas": "tropecelha",
    "tropecem": "tropeçar",
    "tropecemo": "tropeçar",
    "tropecemos": "tropeçar",
    "tropeces": "tropeçar",
    "tropecilhos": "tropecilho",
    "tropeei": "tropear",
    "tropeeis": "tropear",
    "tropeemo": "tropear",
    "tropeemos": "tropear",
    "tropeia": "tropear",
    "tropeiam": "tropear",
    "tropeias": "tropear",
    "tropeie": "tropear",
    "tropeiem": "tropear",
    "tropeies": "tropear",
    "tropeio": "tropear",
    "tropeiradas": "tropeirada",
    "tropeiros": "tropeiro",
    "tropeja": "tropejar",
    "tropejada": "tropejar",
    "tropejadas": "tropejar",
    "tropejado": "tropejar",
    "tropejados": "tropejar",
    "tropejai": "tropejar",
    "tropejais": "tropejar",
    "tropejam": "tropejar",
    "tropejamo": "tropejar",
    "tropejamos": "tropejar",
    "tropejando": "tropejar",
    "tropejara": "tropejar",
    "tropejaram": "tropejar",
    "tropejaras": "tropejar",
    "tropejardes": "tropejar",
    "tropejarei": "tropejar",
    "tropejareis": "tropejar",
    "tropejarem": "tropejar",
    "tropejaremos": "tropejar",
    "tropejares": "tropejar",
    "tropejaria": "tropejar",
    "tropejariam": "tropejar",
    "tropejarias": "tropejar",
    "tropejarmo": "tropejar",
    "tropejarmos": "tropejar",
    "tropejará": "tropejar",
    "tropejarás": "tropejar",
    "tropejarão": "tropejar",
    "tropejaríamos": "tropejar",
    "tropejaríeis": "tropejar",
    "tropejas": "tropejar",
    "tropejasse": "tropejar",
    "tropejassem": "tropejar",
    "tropejasses": "tropejar",
    "tropejaste": "tropejar",
    "tropejastes": "tropejar",
    "tropejava": "tropejar",
    "tropejavam": "tropejar",
    "tropejavas": "tropejar",
    "tropeje": "tropejar",
    "tropejei": "tropejar",
    "tropejeis": "tropejar",
    "tropejem": "tropejar",
    "tropejemo": "tropejar",
    "tropejemos": "tropejar",
    "tropejes": "tropejar",
    "tropejo": "tropejar",
    "tropejou": "tropejar",
    "tropejámo": "tropejar",
    "tropejámos": "tropejar",
    "tropejáramo": "tropejar",
    "tropejáramos": "tropejar",
    "tropejáreis": "tropejar",
    "tropejásseis": "tropejar",
    "tropejássemos": "tropejar",
    "tropejávamo": "tropejar",
    "tropejávamos": "tropejar",
    "tropejáveis": "tropejar",
    "tropelias": "tropelia",
    "tropelona": "tropelão",
    "tropelonas": "tropelão",
    "tropelões": "tropelão",
    "tropeoláceas": "tropeolácea",
    "tropeou": "tropear",
    "tropeámo": "tropear",
    "tropeámos": "tropear",
    "tropeáramo": "tropear",
    "tropeáramos": "tropear",
    "tropeáreis": "tropear",
    "tropeásseis": "tropear",
    "tropeássemos": "tropear",
    "tropeávamo": "tropear",
    "tropeávamos": "tropear",
    "tropeáveis": "tropear",
    "tropeça": "tropeçar",
    "tropeçada": "tropeçar",
    "tropeçadas": "tropeçar",
    "tropeçado": "tropeçar",
    "tropeçados": "tropeçar",
    "tropeçai": "tropeçar",
    "tropeçais": "tropeçar",
    "tropeçam": "tropeçar",
    "tropeçamentos": "tropeçamento",
    "tropeçamo": "tropeçar",
    "tropeçamos": "tropeçar",
    "tropeçando": "tropeçar",
    "tropeçara": "tropeçar",
    "tropeçaram": "tropeçar",
    "tropeçaras": "tropeçar",
    "tropeçardes": "tropeçar",
    "tropeçarei": "tropeçar",
    "tropeçareis": "tropeçar",
    "tropeçarem": "tropeçar",
    "tropeçaremos": "tropeçar",
    "tropeçares": "tropeçar",
    "tropeçaria": "tropeçar",
    "tropeçariam": "tropeçar",
    "tropeçarias": "tropeçar",
    "tropeçarmo": "tropeçar",
    "tropeçarmos": "tropeçar",
    "tropeçará": "tropeçar",
    "tropeçarás": "tropeçar",
    "tropeçarão": "tropeçar",
    "tropeçaríamos": "tropeçar",
    "tropeçaríeis": "tropeçar",
    "tropeças": "tropeçar",
    "tropeçasse": "tropeçar",
    "tropeçassem": "tropeçar",
    "tropeçasses": "tropeçar",
    "tropeçaste": "tropeçar",
    "tropeçastes": "tropeçar",
    "tropeçava": "tropeçar",
    "tropeçavam": "tropeçar",
    "tropeçavas": "tropeçar",
    "tropeço": "tropeçar",
    "tropeços": "tropeço",
    "tropeçou": "tropeçar",
    "tropeçuda": "tropeçudo",
    "tropeçudas": "tropeçudo",
    "tropeçudos": "tropeçudo",
    "tropeçámo": "tropeçar",
    "tropeçámos": "tropeçar",
    "tropeçáramo": "tropeçar",
    "tropeçáramos": "tropeçar",
    "tropeçáreis": "tropeçar",
    "tropeçásseis": "tropeçar",
    "tropeçássemos": "tropeçar",
    "tropeçávamo": "tropeçar",
    "tropeçávamos": "tropeçar",
    "tropeçáveis": "tropeçar",
    "tropeções": "tropeção",
    "tropeólea": "tropeóleo",
    "tropeóleas": "tropeóleo",
    "tropeóleos": "tropeóleo",
    "tropias": "tropia",
    "tropica": "tropicar",
    "tropicada": "tropicar",
    "tropicadas": "tropicar",
    "tropicado": "tropicar",
    "tropicados": "tropicar",
    "tropicais": "tropicar",
    "tropicalistas": "tropicalista",
    "tropicam": "tropicar",
    "tropicamo": "tropicar",
    "tropicamos": "tropicar",
    "tropicando": "tropicar",
    "tropicara": "tropicar",
    "tropicaram": "tropicar",
    "tropicaras": "tropicar",
    "tropicardes": "tropicar",
    "tropicarei": "tropicar",
    "tropicareis": "tropicar",
    "tropicarem": "tropicar",
    "tropicaremos": "tropicar",
    "tropicares": "tropicar",
    "tropicaria": "tropicar",
    "tropicariam": "tropicar",
    "tropicarias": "tropicar",
    "tropicarmo": "tropicar",
    "tropicarmos": "tropicar",
    "tropicará": "tropicar",
    "tropicarás": "tropicar",
    "tropicarão": "tropicar",
    "tropicaríamos": "tropicar",
    "tropicaríeis": "tropicar",
    "tropicas": "tropicar",
    "tropicasse": "tropicar",
    "tropicassem": "tropicar",
    "tropicasses": "tropicar",
    "tropicaste": "tropicar",
    "tropicastes": "tropicar",
    "tropicava": "tropicar",
    "tropicavam": "tropicar",
    "tropicavas": "tropicar",
    "tropico": "tropicar",
    "tropicou": "tropicar",
    "tropicámo": "tropicar",
    "tropicámos": "tropicar",
    "tropicáramo": "tropicar",
    "tropicáramos": "tropicar",
    "tropicáreis": "tropicar",
    "tropicásseis": "tropicar",
    "tropicássemos": "tropicar",
    "tropicávamo": "tropicar",
    "tropicávamos": "tropicar",
    "tropicáveis": "tropicar",
    "tropicões": "tropicão",
    "tropidos": "tropido",
    "tropilhas": "tropilha",
    "tropique": "tropicar",
    "tropiquei": "tropicar",
    "tropiqueis": "tropicar",
    "tropiquem": "tropicar",
    "tropiquemos": "tropicar",
    "tropiques": "tropicar",
    "tropismos": "tropismo",
    "tropologias": "tropologia",
    "tropológica": "tropológico",
    "tropológicas": "tropológico",
    "tropológicos": "tropológico",
    "troponómica": "troponómico",
    "troponómicas": "troponómico",
    "troponómicos": "troponómico",
    "tropopausas": "tropopausa",
    "tropos": "tropo",
    "troposferas": "troposfera",
    "tropotaxias": "tropotaxia",
    "tropéis": "tropel",
    "troque": "trocar",
    "troquei": "trocar",
    "troqueis": "troquel",
    "troquelmintes": "troquelminte",
    "troquem": "trocar",
    "troquemo": "trocar",
    "troquemos": "trocar",
    "troques": "troque",
    "troqueus": "troqueu",
    "troquilhas": "troquilha",
    "troquilheiras": "troquilheira",
    "troquismos": "troquismo",
    "troquiteiras": "troquiteira",
    "troquiteres": "troquiter",
    "trota": "trotar",
    "trotada": "trotar",
    "trotadas": "trotar",
    "trotado": "trotar",
    "trotadora": "trotador",
    "trotadoras": "trotador",
    "trotadores": "trotador",
    "trotados": "trotar",
    "trotai": "trotar",
    "trotais": "trotar",
    "trotam": "trotar",
    "trotamo": "trotar",
    "trotamos": "trotar",
    "trotando": "trotar",
    "trotara": "trotar",
    "trotaram": "trotar",
    "trotaras": "trotar",
    "trotardes": "trotar",
    "trotarei": "trotar",
    "trotareis": "trotar",
    "trotarem": "trotar",
    "trotaremos": "trotar",
    "trotares": "trotar",
    "trotaria": "trotar",
    "trotariam": "trotar",
    "trotarias": "trotar",
    "trotarmo": "trotar",
    "trotarmos": "trotar",
    "trotará": "trotar",
    "trotarás": "trotar",
    "trotarão": "trotar",
    "trotaríamos": "trotar",
    "trotaríeis": "trotar",
    "trotas": "trotar",
    "trotasse": "trotar",
    "trotassem": "trotar",
    "trotasses": "trotar",
    "trotaste": "trotar",
    "trotastes": "trotar",
    "trotava": "trotar",
    "trotavam": "trotar",
    "trotavas": "trotar",
    "trote": "trotar",
    "troteada": "trotear",
    "troteadas": "trotear",
    "troteado": "trotear",
    "troteados": "trotear",
    "troteai": "trotear",
    "troteais": "trotear",
    "troteamo": "trotear",
    "troteamos": "trotear",
    "troteando": "trotear",
    "troteara": "trotear",
    "trotearam": "trotear",
    "trotearas": "trotear",
    "troteardes": "trotear",
    "trotearei": "trotear",
    "troteareis": "trotear",
    "trotearem": "trotear",
    "trotearemos": "trotear",
    "troteares": "trotear",
    "trotearia": "trotear",
    "troteariam": "trotear",
    "trotearias": "trotear",
    "trotearmo": "trotear",
    "trotearmos": "trotear",
    "troteará": "trotear",
    "trotearás": "trotear",
    "trotearão": "trotear",
    "trotearíamos": "trotear",
    "trotearíeis": "trotear",
    "troteasse": "trotear",
    "troteassem": "trotear",
    "troteasses": "trotear",
    "troteaste": "trotear",
    "troteastes": "trotear",
    "troteava": "trotear",
    "troteavam": "trotear",
    "troteavas": "trotear",
    "troteei": "trotear",
    "troteeis": "trotear",
    "troteemo": "trotear",
    "troteemos": "trotear",
    "trotei": "trotar",
    "troteia": "trotear",
    "troteiam": "trotear",
    "troteias": "trotear",
    "troteie": "trotear",
    "troteiem": "trotear",
    "troteies": "trotear",
    "troteio": "trotear",
    "troteira": "troteiro",
    "troteiras": "troteiro",
    "troteiros": "troteiro",
    "troteis": "trotar",
    "trotem": "trotar",
    "trotemo": "trotar",
    "trotemos": "trotar",
    "troteou": "trotear",
    "trotes": "trote",
    "troteámo": "trotear",
    "troteámos": "trotear",
    "troteáramo": "trotear",
    "troteáramos": "trotear",
    "troteáreis": "trotear",
    "troteásseis": "trotear",
    "troteássemos": "trotear",
    "troteávamo": "trotear",
    "troteávamos": "trotear",
    "troteáveis": "trotear",
    "trotinetes": "trotinete",
    "trotis": "trotil",
    "troto": "trotar",
    "trotou": "trotar",
    "trotskismos": "trotskismo",
    "trotskistas": "trotskista",
    "trotsquismos": "trotsquismo",
    "trotsquistas": "trotsquista",
    "trotámo": "trotar",
    "trotámos": "trotar",
    "trotáramo": "trotar",
    "trotáramos": "trotar",
    "trotáreis": "trotar",
    "trotásseis": "trotar",
    "trotássemos": "trotar",
    "trotávamo": "trotar",
    "trotávamos": "trotar",
    "trotáveis": "trotar",
    "trotões": "trotão",
    "trouce": "trouçar",
    "troucei": "trouçar",
    "trouceis": "trouçar",
    "troucem": "trouçar",
    "troucemo": "trouçar",
    "troucemos": "trouçar",
    "trouces": "trouçar",
    "troupes": "troupe",
    "trouxadas": "trouxada",
    "trouxas": "trouxa",
    "trouxazinha": "trouxa",
    "trouxazinhas": "trouxa",
    "trouxazita": "trouxa",
    "trouxazitas": "trouxa",
    "trouxe": "trazer",
    "trouxemo": "trazer",
    "trouxemos": "trazer",
    "trouxer": "trazer",
    "trouxera": "trazer",
    "trouxeram": "trazer",
    "trouxeras": "trazer",
    "trouxerdes": "trazer",
    "trouxerem": "trazer",
    "trouxeres": "trazer",
    "trouxermos": "trazer",
    "trouxesse": "trazer",
    "trouxessem": "trazer",
    "trouxesses": "trazer",
    "trouxeste": "trazer",
    "trouxestes": "trazer",
    "trouxinha": "trouxa",
    "trouxinhas": "trouxa",
    "trouxita": "trouxa",
    "trouxitas": "trouxa",
    "trouxos": "trouxo",
    "trouxéramo": "trazer",
    "trouxéramos": "trazer",
    "trouxérei": "trazer",
    "trouxéreis": "trazer",
    "trouxésseis": "trazer",
    "trouxéssemos": "trazer",
    "trouça": "trouçar",
    "trouçada": "trouçar",
    "trouçadas": "trouçar",
    "trouçado": "trouçar",
    "trouçados": "trouçar",
    "trouçai": "trouçar",
    "trouçais": "trouçar",
    "trouçam": "trouçar",
    "trouçamo": "trouçar",
    "trouçamos": "trouçar",
    "trouçando": "trouçar",
    "trouçara": "trouçar",
    "trouçaram": "trouçar",
    "trouçaras": "trouçar",
    "trouçarde": "trouçar",
    "trouçardes": "trouçar",
    "trouçare": "trouçar",
    "trouçarei": "trouçar",
    "trouçareis": "trouçar",
    "trouçarem": "trouçar",
    "trouçaremos": "trouçar",
    "trouçares": "trouçar",
    "trouçaria": "trouçar",
    "trouçariam": "trouçar",
    "trouçarias": "trouçar",
    "trouçarmo": "trouçar",
    "trouçarmos": "trouçar",
    "trouçará": "trouçar",
    "trouçarás": "trouçar",
    "trouçarão": "trouçar",
    "trouçaríamos": "trouçar",
    "trouçaríeis": "trouçar",
    "trouças": "trouçar",
    "trouçasse": "trouçar",
    "trouçassem": "trouçar",
    "trouçasses": "trouçar",
    "trouçaste": "trouçar",
    "trouçastes": "trouçar",
    "trouçava": "trouçar",
    "trouçavam": "trouçar",
    "trouçavas": "trouçar",
    "trouço": "trouçar",
    "trouçou": "trouçar",
    "trouçá": "trouçar",
    "trouçámo": "trouçar",
    "trouçámos": "trouçar",
    "trouçáramo": "trouçar",
    "trouçáramos": "trouçar",
    "trouçárei": "trouçar",
    "trouçáreis": "trouçar",
    "trouçásseis": "trouçar",
    "trouçássemos": "trouçar",
    "trouçávamo": "trouçar",
    "trouçávamos": "trouçar",
    "trouçávei": "trouçar",
    "trouçáveis": "trouçar",
    "trova": "trovar",
    "trovada": "trovar",
    "trovadas": "trovar",
    "trovado": "trovar",
    "trovadora": "trovador",
    "trovadoras": "trovador",
    "trovadores": "trovador",
    "trovadoresca": "trovadoresco",
    "trovadorescas": "trovadoresco",
    "trovadorescos": "trovadoresco",
    "trovados": "trovar",
    "trovai": "trovar",
    "trovais": "trovar",
    "trovam": "trovar",
    "trovamo": "trovar",
    "trovamos": "trovar",
    "trovando": "trovar",
    "trovantes": "trovante",
    "trovara": "trovar",
    "trovaram": "trovar",
    "trovaras": "trovar",
    "trovardes": "trovar",
    "trovarei": "trovar",
    "trovareis": "trovar",
    "trovarem": "trovar",
    "trovaremos": "trovar",
    "trovares": "trovar",
    "trovaria": "trovar",
    "trovariam": "trovar",
    "trovarias": "trovar",
    "trovarmo": "trovar",
    "trovarmos": "trovar",
    "trovará": "trovar",
    "trovarás": "trovar",
    "trovarão": "trovar",
    "trovaríamos": "trovar",
    "trovaríeis": "trovar",
    "trovas": "trovar",
    "trovasse": "trovar",
    "trovassem": "trovar",
    "trovasses": "trovar",
    "trovaste": "trovar",
    "trovastes": "trovar",
    "trovava": "trovar",
    "trovavam": "trovar",
    "trovavas": "trovar",
    "trove": "trovar",
    "trovei": "trovar",
    "troveiros": "troveiro",
    "troveis": "trovar",
    "troveja": "trovejar",
    "trovejada": "trovejar",
    "trovejadas": "trovejar",
    "trovejado": "trovejar",
    "trovejados": "trovejar",
    "trovejai": "trovejar",
    "trovejais": "trovejar",
    "trovejam": "trovejar",
    "trovejamo": "trovejar",
    "trovejamos": "trovejar",
    "trovejando": "trovejar",
    "trovejantes": "trovejante",
    "trovejara": "trovejar",
    "trovejaram": "trovejar",
    "trovejaras": "trovejar",
    "trovejardes": "trovejar",
    "trovejarei": "trovejar",
    "trovejareis": "trovejar",
    "trovejarem": "trovejar",
    "trovejaremos": "trovejar",
    "trovejares": "trovejar",
    "trovejaria": "trovejar",
    "trovejariam": "trovejar",
    "trovejarias": "trovejar",
    "trovejarmo": "trovejar",
    "trovejarmos": "trovejar",
    "trovejará": "trovejar",
    "trovejarás": "trovejar",
    "trovejarão": "trovejar",
    "trovejaríamos": "trovejar",
    "trovejaríeis": "trovejar",
    "trovejas": "trovejar",
    "trovejasse": "trovejar",
    "trovejassem": "trovejar",
    "trovejasses": "trovejar",
    "trovejaste": "trovejar",
    "trovejastes": "trovejar",
    "trovejava": "trovejar",
    "trovejavam": "trovejar",
    "trovejavas": "trovejar",
    "troveje": "trovejar",
    "trovejei": "trovejar",
    "trovejeis": "trovejar",
    "trovejem": "trovejar",
    "trovejemo": "trovejar",
    "trovejemos": "trovejar",
    "trovejes": "trovejar",
    "trovejo": "trovejar",
    "trovejou": "trovejar",
    "trovejámo": "trovejar",
    "trovejámos": "trovejar",
    "trovejáramo": "trovejar",
    "trovejáramos": "trovejar",
    "trovejáreis": "trovejar",
    "trovejásseis": "trovejar",
    "trovejássemos": "trovejar",
    "trovejávamo": "trovejar",
    "trovejávamos": "trovejar",
    "trovejáveis": "trovejar",
    "trovem": "trovar",
    "trovemo": "trovar",
    "trovemos": "trovar",
    "troventa": "trovento",
    "troventas": "trovento",
    "troventos": "trovento",
    "troves": "trovar",
    "trovisca": "troviscar",
    "troviscada": "troviscar",
    "troviscadas": "troviscar",
    "troviscado": "troviscar",
    "troviscados": "troviscar",
    "troviscais": "troviscar",
    "troviscam": "troviscar",
    "troviscamo": "troviscar",
    "troviscamos": "troviscar",
    "troviscando": "troviscar",
    "troviscara": "troviscar",
    "troviscaram": "troviscar",
    "troviscaras": "troviscar",
    "troviscardes": "troviscar",
    "troviscarei": "troviscar",
    "troviscareis": "troviscar",
    "troviscarem": "troviscar",
    "troviscaremos": "troviscar",
    "troviscares": "troviscar",
    "troviscaria": "troviscar",
    "troviscariam": "troviscar",
    "troviscarias": "troviscar",
    "troviscarmo": "troviscar",
    "troviscarmos": "troviscar",
    "troviscará": "troviscar",
    "troviscarás": "troviscar",
    "troviscarão": "troviscar",
    "troviscaríamos": "troviscar",
    "troviscaríeis": "troviscar",
    "troviscas": "troviscar",
    "troviscasse": "troviscar",
    "troviscassem": "troviscar",
    "troviscasses": "troviscar",
    "troviscaste": "troviscar",
    "troviscastes": "troviscar",
    "troviscava": "troviscar",
    "troviscavam": "troviscar",
    "troviscavas": "troviscar",
    "trovisco": "troviscar",
    "troviscos": "trovisco",
    "troviscosa": "troviscoso",
    "troviscosas": "troviscoso",
    "troviscosos": "troviscoso",
    "troviscou": "troviscar",
    "troviscámo": "troviscar",
    "troviscámos": "troviscar",
    "troviscáramo": "troviscar",
    "troviscáramos": "troviscar",
    "troviscáreis": "troviscar",
    "troviscásseis": "troviscar",
    "troviscássemos": "troviscar",
    "troviscávamo": "troviscar",
    "troviscávamos": "troviscar",
    "troviscáveis": "troviscar",
    "trovisque": "troviscar",
    "trovisquei": "troviscar",
    "trovisqueiras": "trovisqueira",
    "trovisqueis": "troviscar",
    "trovisquem": "troviscar",
    "trovisquemos": "troviscar",
    "trovisques": "troviscar",
    "trovistas": "trovista",
    "trovo": "trovar",
    "trovoa": "trovoar",
    "trovoada": "trovoar",
    "trovoadas": "trovoar",
    "trovoado": "trovoar",
    "trovoados": "trovoar",
    "trovoai": "trovoar",
    "trovoais": "trovoar",
    "trovoam": "trovoar",
    "trovoamo": "trovoar",
    "trovoamos": "trovoar",
    "trovoando": "trovoar",
    "trovoara": "trovoar",
    "trovoaram": "trovoar",
    "trovoaras": "trovoar",
    "trovoardes": "trovoar",
    "trovoarei": "trovoar",
    "trovoareis": "trovoar",
    "trovoarem": "trovoar",
    "trovoaremos": "trovoar",
    "trovoares": "trovoar",
    "trovoaria": "trovoar",
    "trovoariam": "trovoar",
    "trovoarias": "trovoar",
    "trovoarmo": "trovoar",
    "trovoarmos": "trovoar",
    "trovoará": "trovoar",
    "trovoarás": "trovoar",
    "trovoarão": "trovoar",
    "trovoaríamos": "trovoar",
    "trovoaríeis": "trovoar",
    "trovoas": "trovoar",
    "trovoasse": "trovoar",
    "trovoassem": "trovoar",
    "trovoasses": "trovoar",
    "trovoaste": "trovoar",
    "trovoastes": "trovoar",
    "trovoava": "trovoar",
    "trovoavam": "trovoar",
    "trovoavas": "trovoar",
    "trovoe": "trovoar",
    "trovoei": "trovoar",
    "trovoeis": "trovoar",
    "trovoem": "trovoar",
    "trovoemo": "trovoar",
    "trovoemos": "trovoar",
    "trovoes": "trovoar",
    "trovoo": "trovoar",
    "trovoou": "trovoar",
    "trovosa": "trovoso",
    "trovosas": "trovoso",
    "trovosos": "trovoso",
    "trovou": "trovar",
    "trovoámo": "trovoar",
    "trovoámos": "trovoar",
    "trovoáramo": "trovoar",
    "trovoáramos": "trovoar",
    "trovoáreis": "trovoar",
    "trovoásseis": "trovoar",
    "trovoássemos": "trovoar",
    "trovoávamo": "trovoar",
    "trovoávamos": "trovoar",
    "trovoáveis": "trovoar",
    "trovámo": "trovar",
    "trovámos": "trovar",
    "trováramo": "trovar",
    "trováramos": "trovar",
    "trováreis": "trovar",
    "trovásseis": "trovar",
    "trovássemos": "trovar",
    "trovávamo": "trovar",
    "trovávamos": "trovar",
    "trováveis": "trovar",
    "trovões": "trovão",
    "troámo": "troar",
    "troámos": "troar",
    "troáramo": "troar",
    "troáramos": "troar",
    "troáreis": "troar",
    "troásseis": "troar",
    "troássemos": "troar",
    "troávamo": "troar",
    "troávamos": "troar",
    "troáveis": "troar",
    "troça": "troçar",
    "troçada": "troçar",
    "troçadas": "troçar",
    "troçado": "troçar",
    "troçadora": "troçador",
    "troçadoras": "troçador",
    "troçadores": "troçador",
    "troçados": "troçar",
    "troçai": "troçar",
    "troçais": "troçar",
    "troçam": "troçar",
    "troçamo": "troçar",
    "troçamos": "troçar",
    "troçando": "troçar",
    "troçara": "troçar",
    "troçaram": "troçar",
    "troçaras": "troçar",
    "troçardes": "troçar",
    "troçarei": "troçar",
    "troçareis": "troçar",
    "troçarem": "troçar",
    "troçaremos": "troçar",
    "troçares": "troçar",
    "troçaria": "troçar",
    "troçariam": "troçar",
    "troçarias": "troçar",
    "troçarmo": "troçar",
    "troçarmos": "troçar",
    "troçará": "troçar",
    "troçarás": "troçar",
    "troçarão": "troçar",
    "troçaríamos": "troçar",
    "troçaríeis": "troçar",
    "troças": "troçar",
    "troçasse": "troçar",
    "troçassem": "troçar",
    "troçasses": "troçar",
    "troçaste": "troçar",
    "troçastes": "troçar",
    "troçava": "troçar",
    "troçavam": "troçar",
    "troçavas": "troçar",
    "troço": "troçar",
    "troços": "troço",
    "troçou": "troçar",
    "troçámo": "troçar",
    "troçámos": "troçar",
    "troçáramo": "troçar",
    "troçáramos": "troçar",
    "troçáreis": "troçar",
    "troçásseis": "troçar",
    "troçássemos": "troçar",
    "troçávamo": "troçar",
    "troçávamos": "troçar",
    "troçáveis": "troçar",
    "truanazes": "truanaz",
    "truaneada": "truanear",
    "truaneadas": "truanear",
    "truaneado": "truanear",
    "truaneados": "truanear",
    "truaneai": "truanear",
    "truaneais": "truanear",
    "truaneamo": "truanear",
    "truaneamos": "truanear",
    "truaneando": "truanear",
    "truaneara": "truanear",
    "truanearam": "truanear",
    "truanearas": "truanear",
    "truaneardes": "truanear",
    "truanearei": "truanear",
    "truaneareis": "truanear",
    "truanearem": "truanear",
    "truanearemos": "truanear",
    "truaneares": "truanear",
    "truanearia": "truanear",
    "truaneariam": "truanear",
    "truanearias": "truanear",
    "truanearmo": "truanear",
    "truanearmos": "truanear",
    "truaneará": "truanear",
    "truanearás": "truanear",
    "truanearão": "truanear",
    "truanearíamos": "truanear",
    "truanearíeis": "truanear",
    "truaneasse": "truanear",
    "truaneassem": "truanear",
    "truaneasses": "truanear",
    "truaneaste": "truanear",
    "truaneastes": "truanear",
    "truaneava": "truanear",
    "truaneavam": "truanear",
    "truaneavas": "truanear",
    "truaneei": "truanear",
    "truaneeis": "truanear",
    "truaneemo": "truanear",
    "truaneemos": "truanear",
    "truaneia": "truanear",
    "truaneiam": "truanear",
    "truaneias": "truanear",
    "truaneie": "truanear",
    "truaneiem": "truanear",
    "truaneies": "truanear",
    "truaneio": "truanear",
    "truaneou": "truanear",
    "truanesca": "truanesco",
    "truanescas": "truanesco",
    "truanescos": "truanesco",
    "truaneámo": "truanear",
    "truaneámos": "truanear",
    "truaneáramo": "truanear",
    "truaneáramos": "truanear",
    "truaneáreis": "truanear",
    "truaneásseis": "truanear",
    "truaneássemos": "truanear",
    "truaneávamo": "truanear",
    "truaneávamos": "truanear",
    "truaneáveis": "truanear",
    "truanias": "truania",
    "truanices": "truanice",
    "truca": "trucar",
    "trucada": "trucar",
    "trucadas": "trucar",
    "trucado": "trucar",
    "trucados": "trucar",
    "trucais": "trucar",
    "trucam": "trucar",
    "trucamo": "trucar",
    "trucamos": "trucar",
    "trucando": "trucar",
    "trucara": "trucar",
    "trucaram": "trucar",
    "trucaras": "trucar",
    "trucardes": "trucar",
    "trucarei": "trucar",
    "trucareis": "trucar",
    "trucarem": "trucar",
    "trucaremos": "trucar",
    "trucares": "trucar",
    "trucaria": "trucar",
    "trucariam": "trucar",
    "trucarias": "trucar",
    "trucarmo": "trucar",
    "trucarmos": "trucar",
    "trucará": "trucar",
    "trucarás": "trucar",
    "trucarão": "trucar",
    "trucaríamos": "trucar",
    "trucaríeis": "trucar",
    "trucas": "trucar",
    "trucasse": "trucar",
    "trucassem": "trucar",
    "trucasses": "trucar",
    "trucaste": "trucar",
    "trucastes": "trucar",
    "trucava": "trucar",
    "trucavam": "trucar",
    "trucavas": "trucar",
    "trucida": "trucidar",
    "trucidada": "trucidar",
    "trucidadas": "trucidar",
    "trucidado": "trucidar",
    "trucidadora": "trucidador",
    "trucidadoras": "trucidador",
    "trucidadores": "trucidador",
    "trucidados": "trucidar",
    "trucidai": "trucidar",
    "trucidais": "trucidar",
    "trucidam": "trucidar",
    "trucidamo": "trucidar",
    "trucidamos": "trucidar",
    "trucidando": "trucidar",
    "trucidantes": "trucidante",
    "trucidara": "trucidar",
    "trucidaram": "trucidar",
    "trucidaras": "trucidar",
    "trucidarde": "trucidar",
    "trucidardes": "trucidar",
    "trucidare": "trucidar",
    "trucidarei": "trucidar",
    "trucidareis": "trucidar",
    "trucidarem": "trucidar",
    "trucidaremos": "trucidar",
    "trucidares": "trucidar",
    "trucidaria": "trucidar",
    "trucidariam": "trucidar",
    "trucidarias": "trucidar",
    "trucidarmo": "trucidar",
    "trucidarmos": "trucidar",
    "trucidará": "trucidar",
    "trucidarás": "trucidar",
    "trucidarão": "trucidar",
    "trucidaríamos": "trucidar",
    "trucidaríeis": "trucidar",
    "trucidas": "trucidar",
    "trucidasse": "trucidar",
    "trucidassem": "trucidar",
    "trucidasses": "trucidar",
    "trucidaste": "trucidar",
    "trucidastes": "trucidar",
    "trucidava": "trucidar",
    "trucidavam": "trucidar",
    "trucidavas": "trucidar",
    "trucidações": "trucidação",
    "trucide": "trucidar",
    "trucidei": "trucidar",
    "trucideis": "trucidar",
    "trucidem": "trucidar",
    "trucidemo": "trucidar",
    "trucidemos": "trucidar",
    "trucides": "trucidar",
    "trucido": "trucidar",
    "trucidou": "trucidar",
    "trucidá": "trucidar",
    "trucidámo": "trucidar",
    "trucidámos": "trucidar",
    "trucidáramo": "trucidar",
    "trucidáramos": "trucidar",
    "trucidárei": "trucidar",
    "trucidáreis": "trucidar",
    "trucidásseis": "trucidar",
    "trucidássemos": "trucidar",
    "trucidávamo": "trucidar",
    "trucidávamos": "trucidar",
    "trucidávei": "trucidar",
    "trucidáveis": "trucidar",
    "trucila": "trucilar",
    "trucilada": "trucilar",
    "truciladas": "trucilar",
    "trucilado": "trucilar",
    "truciladora": "trucilador",
    "truciladoras": "trucilador",
    "truciladores": "trucilador",
    "trucilados": "trucilar",
    "trucilai": "trucilar",
    "trucilais": "trucilar",
    "trucilam": "trucilar",
    "trucilamo": "trucilar",
    "trucilamos": "trucilar",
    "trucilando": "trucilar",
    "trucilara": "trucilar",
    "trucilaram": "trucilar",
    "trucilaras": "trucilar",
    "trucilardes": "trucilar",
    "trucilarei": "trucilar",
    "trucilareis": "trucilar",
    "trucilarem": "trucilar",
    "trucilaremos": "trucilar",
    "trucilares": "trucilar",
    "trucilaria": "trucilar",
    "trucilariam": "trucilar",
    "trucilarias": "trucilar",
    "trucilarmo": "trucilar",
    "trucilarmos": "trucilar",
    "trucilará": "trucilar",
    "trucilarás": "trucilar",
    "trucilarão": "trucilar",
    "trucilaríamos": "trucilar",
    "trucilaríeis": "trucilar",
    "trucilas": "trucilar",
    "trucilasse": "trucilar",
    "trucilassem": "trucilar",
    "trucilasses": "trucilar",
    "trucilaste": "trucilar",
    "trucilastes": "trucilar",
    "trucilava": "trucilar",
    "trucilavam": "trucilar",
    "trucilavas": "trucilar",
    "trucile": "trucilar",
    "trucilei": "trucilar",
    "trucileis": "trucilar",
    "trucilem": "trucilar",
    "trucilemo": "trucilar",
    "trucilemos": "trucilar",
    "truciles": "trucilar",
    "trucilo": "trucilar",
    "trucilou": "trucilar",
    "trucilámo": "trucilar",
    "trucilámos": "trucilar",
    "truciláramo": "trucilar",
    "truciláramos": "trucilar",
    "truciláreis": "trucilar",
    "trucilásseis": "trucilar",
    "trucilássemos": "trucilar",
    "trucilávamo": "trucilar",
    "trucilávamos": "trucilar",
    "truciláveis": "trucilar",
    "truco": "trucar",
    "trucos": "truco",
    "trucou": "trucar",
    "truculenta": "truculento",
    "truculentas": "truculento",
    "truculentos": "truculento",
    "truculências": "truculência",
    "trucámo": "trucar",
    "trucámos": "trucar",
    "trucáramo": "trucar",
    "trucáramos": "trucar",
    "trucáreis": "trucar",
    "trucásseis": "trucar",
    "trucássemos": "trucar",
    "trucávamo": "trucar",
    "trucávamos": "trucar",
    "trucáveis": "trucar",
    "trufa": "trufar",
    "trufada": "trufar",
    "trufadas": "trufar",
    "trufado": "trufar",
    "trufados": "trufar",
    "trufai": "trufar",
    "trufais": "trufar",
    "trufam": "trufar",
    "trufamo": "trufar",
    "trufamos": "trufar",
    "trufando": "trufar",
    "trufara": "trufar",
    "trufaram": "trufar",
    "trufaras": "trufar",
    "trufarde": "trufar",
    "trufardes": "trufar",
    "trufare": "trufar",
    "trufarei": "trufar",
    "trufareis": "trufar",
    "trufarem": "trufar",
    "trufaremos": "trufar",
    "trufares": "trufar",
    "trufaria": "trufar",
    "trufariam": "trufar",
    "trufarias": "trufar",
    "trufarmo": "trufar",
    "trufarmos": "trufar",
    "trufará": "trufar",
    "trufarás": "trufar",
    "trufarão": "trufar",
    "trufaríamos": "trufar",
    "trufaríeis": "trufar",
    "trufas": "trufar",
    "trufasse": "trufar",
    "trufassem": "trufar",
    "trufasses": "trufar",
    "trufaste": "trufar",
    "trufastes": "trufar",
    "trufava": "trufar",
    "trufavam": "trufar",
    "trufavas": "trufar",
    "trufe": "trufar",
    "trufei": "trufar",
    "trufeira": "trufeiro",
    "trufeiras": "trufeiro",
    "trufeiros": "trufeiro",
    "trufeis": "trufar",
    "trufem": "trufar",
    "trufemo": "trufar",
    "trufemos": "trufar",
    "trufes": "trufar",
    "truficultora": "truficultor",
    "truficultoras": "truficultor",
    "truficultores": "truficultor",
    "truficulturas": "truficultura",
    "trufo": "trufar",
    "trufou": "trufar",
    "trufá": "trufar",
    "trufámo": "trufar",
    "trufámos": "trufar",
    "trufáramo": "trufar",
    "trufáramos": "trufar",
    "trufárei": "trufar",
    "trufáreis": "trufar",
    "trufásseis": "trufar",
    "trufássemos": "trufar",
    "trufávamo": "trufar",
    "trufávamos": "trufar",
    "trufávei": "trufar",
    "trufáveis": "trufar",
    "trugimões": "trugimão",
    "truitas": "truita",
    "truliformes": "truliforme",
    "trumatizada": "trumatizado",
    "trumatizadas": "trumatizado",
    "trumatizados": "trumatizado",
    "trunca": "truncar",
    "truncada": "truncar",
    "truncadas": "truncar",
    "truncado": "truncar",
    "truncados": "truncar",
    "truncagens": "truncagem",
    "truncai": "truncar",
    "truncais": "truncar",
    "truncam": "truncar",
    "truncamentos": "truncamento",
    "truncamo": "truncar",
    "truncamos": "truncar",
    "truncando": "truncar",
    "truncara": "truncar",
    "truncaram": "truncar",
    "truncaras": "truncar",
    "truncarde": "truncar",
    "truncardes": "truncar",
    "truncare": "truncar",
    "truncarei": "truncar",
    "truncareis": "truncar",
    "truncarem": "truncar",
    "truncaremos": "truncar",
    "truncares": "truncar",
    "truncaria": "truncar",
    "truncariam": "truncar",
    "truncarias": "truncar",
    "truncarmo": "truncar",
    "truncarmos": "truncar",
    "truncará": "truncar",
    "truncarás": "truncar",
    "truncarão": "truncar",
    "truncaríamos": "truncar",
    "truncaríeis": "truncar",
    "truncas": "truncar",
    "truncasse": "truncar",
    "truncassem": "truncar",
    "truncasses": "truncar",
    "truncaste": "truncar",
    "truncastes": "truncar",
    "truncava": "truncar",
    "truncavam": "truncar",
    "truncavas": "truncar",
    "trunco": "truncar",
    "truncou": "truncar",
    "truncá": "truncar",
    "truncámo": "truncar",
    "truncámos": "truncar",
    "truncáramo": "truncar",
    "truncáramos": "truncar",
    "truncárei": "truncar",
    "truncáreis": "truncar",
    "truncásseis": "truncar",
    "truncássemos": "truncar",
    "truncávamo": "truncar",
    "truncávamos": "truncar",
    "truncávei": "truncar",
    "truncáveis": "truncar",
    "trunfa": "trunfar",
    "trunfada": "trunfar",
    "trunfadas": "trunfar",
    "trunfado": "trunfar",
    "trunfados": "trunfar",
    "trunfai": "trunfar",
    "trunfais": "trunfar",
    "trunfam": "trunfar",
    "trunfamo": "trunfar",
    "trunfamos": "trunfar",
    "trunfando": "trunfar",
    "trunfara": "trunfar",
    "trunfaram": "trunfar",
    "trunfaras": "trunfar",
    "trunfardes": "trunfar",
    "trunfarei": "trunfar",
    "trunfareis": "trunfar",
    "trunfarem": "trunfar",
    "trunfaremos": "trunfar",
    "trunfares": "trunfar",
    "trunfaria": "trunfar",
    "trunfariam": "trunfar",
    "trunfarias": "trunfar",
    "trunfarmo": "trunfar",
    "trunfarmos": "trunfar",
    "trunfará": "trunfar",
    "trunfarás": "trunfar",
    "trunfarão": "trunfar",
    "trunfaríamos": "trunfar",
    "trunfaríeis": "trunfar",
    "trunfas": "trunfar",
    "trunfasse": "trunfar",
    "trunfassem": "trunfar",
    "trunfasses": "trunfar",
    "trunfaste": "trunfar",
    "trunfastes": "trunfar",
    "trunfava": "trunfar",
    "trunfavam": "trunfar",
    "trunfavas": "trunfar",
    "trunfe": "trunfar",
    "trunfei": "trunfar",
    "trunfeis": "trunfar",
    "trunfem": "trunfar",
    "trunfemo": "trunfar",
    "trunfemos": "trunfar",
    "trunfes": "trunfar",
    "trunfinho": "trunfo",
    "trunfinhos": "trunfo",
    "trunfito": "trunfo",
    "trunfitos": "trunfo",
    "trunfo": "trunfar",
    "trunfos": "trunfo",
    "trunfou": "trunfar",
    "trunfámo": "trunfar",
    "trunfámos": "trunfar",
    "trunfáramo": "trunfar",
    "trunfáramos": "trunfar",
    "trunfáreis": "trunfar",
    "trunfásseis": "trunfar",
    "trunfássemos": "trunfar",
    "trunfávamo": "trunfar",
    "trunfávamos": "trunfar",
    "trunfáveis": "trunfar",
    "trunque": "truncar",
    "trunquei": "truncar",
    "trunqueis": "truncar",
    "trunquem": "truncar",
    "trunquemo": "truncar",
    "trunquemos": "truncar",
    "trunques": "truncar",
    "trupa": "trupar",
    "trupada": "trupar",
    "trupadas": "trupar",
    "trupado": "trupar",
    "trupados": "trupar",
    "trupai": "trupar",
    "trupais": "trupar",
    "trupam": "trupar",
    "trupamo": "trupar",
    "trupamos": "trupar",
    "trupando": "trupar",
    "trupara": "trupar",
    "truparam": "trupar",
    "truparas": "trupar",
    "trupardes": "trupar",
    "truparei": "trupar",
    "trupareis": "trupar",
    "truparem": "trupar",
    "truparemos": "trupar",
    "trupares": "trupar",
    "truparia": "trupar",
    "trupariam": "trupar",
    "truparias": "trupar",
    "truparmo": "trupar",
    "truparmos": "trupar",
    "trupará": "trupar",
    "truparás": "trupar",
    "truparão": "trupar",
    "truparíamos": "trupar",
    "truparíeis": "trupar",
    "trupas": "trupar",
    "trupasse": "trupar",
    "trupassem": "trupar",
    "trupasses": "trupar",
    "trupaste": "trupar",
    "trupastes": "trupar",
    "trupava": "trupar",
    "trupavam": "trupar",
    "trupavas": "trupar",
    "trupe": "trupar",
    "trupei": "trupar",
    "trupeis": "trupar",
    "trupem": "trupar",
    "trupemo": "trupar",
    "trupemos": "trupar",
    "trupes": "trupe",
    "trupezupes": "trupezupe",
    "trupias": "trupia",
    "trupo": "trupar",
    "trupos": "trupo",
    "trupou": "trupar",
    "trupámo": "trupar",
    "trupámos": "trupar",
    "trupáramo": "trupar",
    "trupáramos": "trupar",
    "trupáreis": "trupar",
    "trupásseis": "trupar",
    "trupássemos": "trupar",
    "trupávamo": "trupar",
    "trupávamos": "trupar",
    "trupáveis": "trupar",
    "truque": "trucar",
    "truquei": "trucar",
    "truqueis": "trucar",
    "truquem": "trucar",
    "truquemos": "trucar",
    "truques": "truque",
    "trutas": "truta",
    "trutina": "trutinar",
    "trutinada": "trutinar",
    "trutinadas": "trutinar",
    "trutinado": "trutinar",
    "trutinados": "trutinar",
    "trutinai": "trutinar",
    "trutinais": "trutinar",
    "trutinam": "trutinar",
    "trutinamo": "trutinar",
    "trutinamos": "trutinar",
    "trutinando": "trutinar",
    "trutinara": "trutinar",
    "trutinaram": "trutinar",
    "trutinaras": "trutinar",
    "trutinarde": "trutinar",
    "trutinardes": "trutinar",
    "trutinare": "trutinar",
    "trutinarei": "trutinar",
    "trutinareis": "trutinar",
    "trutinarem": "trutinar",
    "trutinaremos": "trutinar",
    "trutinares": "trutinar",
    "trutinaria": "trutinar",
    "trutinariam": "trutinar",
    "trutinarias": "trutinar",
    "trutinarmo": "trutinar",
    "trutinarmos": "trutinar",
    "trutinará": "trutinar",
    "trutinarás": "trutinar",
    "trutinarão": "trutinar",
    "trutinaríamos": "trutinar",
    "trutinaríeis": "trutinar",
    "trutinas": "trutinar",
    "trutinasse": "trutinar",
    "trutinassem": "trutinar",
    "trutinasses": "trutinar",
    "trutinaste": "trutinar",
    "trutinastes": "trutinar",
    "trutinava": "trutinar",
    "trutinavam": "trutinar",
    "trutinavas": "trutinar",
    "trutine": "trutinar",
    "trutinei": "trutinar",
    "trutineis": "trutinar",
    "trutinem": "trutinar",
    "trutinemo": "trutinar",
    "trutinemos": "trutinar",
    "trutines": "trutinar",
    "trutino": "trutinar",
    "trutinou": "trutinar",
    "trutiná": "trutinar",
    "trutinámo": "trutinar",
    "trutinámos": "trutinar",
    "trutináramo": "trutinar",
    "trutináramos": "trutinar",
    "trutinárei": "trutinar",
    "trutináreis": "trutinar",
    "trutinásseis": "trutinar",
    "trutinássemos": "trutinar",
    "trutinávamo": "trutinar",
    "trutinávamos": "trutinar",
    "trutinávei": "trutinar",
    "trutináveis": "trutinar",
    "trutífera": "trutífero",
    "trutíferas": "trutífero",
    "trutíferos": "trutífero",
    "truísmos": "truísmo",
    "truões": "truão",
    "trá": "trazer",
    "trábeas": "trábea",
    "trácia": "trácio",
    "trácias": "trácio",
    "trácios": "trácio",
    "tráfegas": "tráfega",
    "tráfegos": "tráfego",
    "tráficos": "tráfico",
    "trágica": "trágico",
    "trágicas": "trágico",
    "trágicos": "trágico",
    "trápolas": "trápola",
    "tráupidas": "tráupida",
    "trâmites": "trâmite",
    "trânsfugas": "trânsfuga",
    "trânsitos": "trânsito",
    "tréculas": "trécula",
    "tréguas": "trégua",
    "trémitos": "trémito",
    "trémula": "trémulo",
    "trémulas": "trémulo",
    "trémulos": "trémulo",
    "trépanos": "trépano",
    "trépida": "trépido",
    "trépidas": "trépido",
    "trépidos": "trépido",
    "tréplicas": "tréplica",
    "trêfega": "trêfego",
    "trêfegas": "trêfego",
    "trêfegos": "trêfego",
    "tríada": "tríade",
    "tríadas": "tríade",
    "tríades": "tríade",
    "tríbades": "tríbade",
    "tríbracos": "tríbraco",
    "tríbulos": "tríbulo",
    "tríduos": "tríduo",
    "trífida": "trífido",
    "trífidas": "trífido",
    "trífidos": "trífido",
    "trígama": "trígamo",
    "trígamas": "trígamo",
    "trígamos": "trígamo",
    "trígina": "trígino",
    "tríginas": "trígino",
    "tríginos": "trígino",
    "tríglidas": "tríglida",
    "tríglifos": "tríglifo",
    "trígonos": "trígono",
    "trílogos": "trílogo",
    "trímera": "trímero",
    "trímeras": "trímero",
    "trímeros": "trímero",
    "trímetra": "trímetro",
    "trímetras": "trímetro",
    "trímetros": "trímetro",
    "trímoda": "trímodo",
    "trímodas": "trímodo",
    "trímodos": "trímodo",
    "tríodos": "tríodo",
    "trípara": "tríparo",
    "tríparas": "tríparo",
    "tríparos": "tríparo",
    "tríplexes": "tríplex",
    "tríplices": "tríplice",
    "trípodes": "trípode",
    "trípolis": "trípoli",
    "tríptera": "tríptero",
    "trípteras": "tríptero",
    "trípteros": "tríptero",
    "trípticos": "tríptico",
    "tríquetra": "tríquetro",
    "tríquetras": "tríquetro",
    "tríquetros": "tríquetro",
    "trítios": "trítio",
    "trítonos": "trítono",
    "trívios": "trívio",
    "trízias": "trízia",
    "trócleas": "tróclea",
    "trófica": "trófico",
    "tróficas": "trófico",
    "tróficos": "trófico",
    "tróias": "tróia",
    "tróleis": "trólei",
    "trónios": "trónio",
    "trópica": "trópico",
    "trópicas": "trópico",
    "trópicos": "trópico",
    "tróquilos": "tróquilo",
    "trônculos": "trônculo",
    "trôpega": "trôpego",
    "trôpegas": "trôpego",
    "trôpegos": "trôpego",
    "tsunamis": "tsunami",
    "tt": "t",
    "tua": "teu",
    "tuacas": "tuaca",
    "tuaregues": "tuaregue",
    "tuas": "teu",
    "tubagens": "tubagem",
    "tubarões": "tubarão",
    "tubas": "tuba",
    "tubações": "tubação",
    "tubeiras": "tubeira",
    "tubeis": "tubel",
    "tuberculada": "tuberculado",
    "tuberculadas": "tuberculado",
    "tuberculados": "tuberculado",
    "tuberculares": "tubercular",
    "tuberculiformes": "tuberculiforme",
    "tuberculinas": "tuberculina",
    "tuberculinizações": "tuberculinização",
    "tuberculiza": "tuberculizar",
    "tuberculizada": "tuberculizar",
    "tuberculizadas": "tuberculizar",
    "tuberculizado": "tuberculizar",
    "tuberculizados": "tuberculizar",
    "tuberculizai": "tuberculizar",
    "tuberculizais": "tuberculizar",
    "tuberculizam": "tuberculizar",
    "tuberculizamo": "tuberculizar",
    "tuberculizamos": "tuberculizar",
    "tuberculizando": "tuberculizar",
    "tuberculizara": "tuberculizar",
    "tuberculizaram": "tuberculizar",
    "tuberculizaras": "tuberculizar",
    "tuberculizardes": "tuberculizar",
    "tuberculizarei": "tuberculizar",
    "tuberculizareis": "tuberculizar",
    "tuberculizarem": "tuberculizar",
    "tuberculizaremos": "tuberculizar",
    "tuberculizares": "tuberculizar",
    "tuberculizaria": "tuberculizar",
    "tuberculizariam": "tuberculizar",
    "tuberculizarias": "tuberculizar",
    "tuberculizarmo": "tuberculizar",
    "tuberculizarmos": "tuberculizar",
    "tuberculizará": "tuberculizar",
    "tuberculizarás": "tuberculizar",
    "tuberculizarão": "tuberculizar",
    "tuberculizaríamos": "tuberculizar",
    "tuberculizaríeis": "tuberculizar",
    "tuberculizas": "tuberculizar",
    "tuberculizasse": "tuberculizar",
    "tuberculizassem": "tuberculizar",
    "tuberculizasses": "tuberculizar",
    "tuberculizaste": "tuberculizar",
    "tuberculizastes": "tuberculizar",
    "tuberculizava": "tuberculizar",
    "tuberculizavam": "tuberculizar",
    "tuberculizavas": "tuberculizar",
    "tuberculizações": "tuberculização",
    "tuberculize": "tuberculizar",
    "tuberculizei": "tuberculizar",
    "tuberculizeis": "tuberculizar",
    "tuberculizem": "tuberculizar",
    "tuberculizemo": "tuberculizar",
    "tuberculizemos": "tuberculizar",
    "tuberculizes": "tuberculizar",
    "tuberculizo": "tuberculizar",
    "tuberculizou": "tuberculizar",
    "tuberculizámo": "tuberculizar",
    "tuberculizámos": "tuberculizar",
    "tuberculizáramo": "tuberculizar",
    "tuberculizáramos": "tuberculizar",
    "tuberculizáreis": "tuberculizar",
    "tuberculizásseis": "tuberculizar",
    "tuberculizássemos": "tuberculizar",
    "tuberculizávamo": "tuberculizar",
    "tuberculizávamos": "tuberculizar",
    "tuberculizáveis": "tuberculizável",
    "tuberculosa": "tuberculoso",
    "tuberculosas": "tuberculoso",
    "tuberculosazinha": "tuberculoso",
    "tuberculosazinhas": "tuberculoso",
    "tuberculosazita": "tuberculoso",
    "tuberculosazitas": "tuberculoso",
    "tuberculoses": "tuberculose",
    "tuberculosidades": "tuberculosidade",
    "tuberculosos": "tuberculoso",
    "tuberculosozinho": "tuberculoso",
    "tuberculosozinhos": "tuberculoso",
    "tuberculosozito": "tuberculoso",
    "tuberculosozitos": "tuberculoso",
    "tuberculífera": "tuberculífero",
    "tuberculíferas": "tuberculífero",
    "tuberculíferos": "tuberculífero",
    "tuberiformes": "tuberiforme",
    "tuberosa": "tuberoso",
    "tuberosas": "tuberoso",
    "tuberosidades": "tuberosidade",
    "tuberosos": "tuberoso",
    "tuberáceas": "tuberácea",
    "tuberóides": "tuberóide",
    "tubiformes": "tubiforme",
    "tubinares": "tubinar",
    "tubinho": "tubo",
    "tubinhos": "tubo",
    "tubito": "tubo",
    "tubitos": "tubo",
    "tubos": "tubo",
    "tubotimpanites": "tubotimpanite",
    "tubulada": "tubulado",
    "tubuladas": "tubulado",
    "tubulados": "tubulado",
    "tubuladuras": "tubuladura",
    "tubulares": "tubular",
    "tubulações": "tubulação",
    "tubuliflora": "tubulifloro",
    "tubulifloras": "tubulifloro",
    "tubulifloros": "tubulifloro",
    "tubuliformes": "tubuliforme",
    "tubulosa": "tubuloso",
    "tubulosas": "tubuloso",
    "tubulosos": "tubuloso",
    "tubuluras": "tubulura",
    "tubulífera": "tubulífero",
    "tubulíferas": "tubulífero",
    "tubulíferos": "tubulífero",
    "tubácea": "tubáceo",
    "tubáceas": "tubáceo",
    "tubáceos": "tubáceo",
    "tubérculos": "tubérculo",
    "tubífera": "tubífero",
    "tubíferas": "tubífero",
    "tubíferos": "tubífero",
    "tucanabóias": "tucanabóia",
    "tucanos": "tucano",
    "tucas": "tuca",
    "tucumãs": "tucumã",
    "tucupis": "tucupi",
    "tudeis": "tudel",
    "tudenses": "tudense",
    "tudesca": "tudesco",
    "tudescas": "tudesco",
    "tudescos": "tudesco",
    "tudinha": "tudinho",
    "tudinhas": "tudinho",
    "tudinhos": "tudinho",
    "tudistas": "tudista",
    "tufa": "tufar",
    "tufada": "tufar",
    "tufadas": "tufar",
    "tufado": "tufar",
    "tufados": "tufar",
    "tufai": "tufar",
    "tufais": "tufar",
    "tufam": "tufar",
    "tufamo": "tufar",
    "tufamos": "tufar",
    "tufando": "tufar",
    "tufara": "tufar",
    "tufaram": "tufar",
    "tufaras": "tufar",
    "tufarde": "tufar",
    "tufardes": "tufar",
    "tufare": "tufar",
    "tufarei": "tufar",
    "tufareis": "tufar",
    "tufarem": "tufar",
    "tufaremos": "tufar",
    "tufares": "tufar",
    "tufaria": "tufar",
    "tufariam": "tufar",
    "tufarias": "tufar",
    "tufarmo": "tufar",
    "tufarmos": "tufar",
    "tufará": "tufar",
    "tufarás": "tufar",
    "tufarão": "tufar",
    "tufaríamos": "tufar",
    "tufaríeis": "tufar",
    "tufas": "tufar",
    "tufasse": "tufar",
    "tufassem": "tufar",
    "tufasses": "tufar",
    "tufaste": "tufar",
    "tufastes": "tufar",
    "tufava": "tufar",
    "tufavam": "tufar",
    "tufavas": "tufar",
    "tufe": "tufar",
    "tufei": "tufar",
    "tufeis": "tufar",
    "tufem": "tufar",
    "tufemo": "tufar",
    "tufemos": "tufar",
    "tufes": "tufar",
    "tufo": "tufar",
    "tufos": "tufo",
    "tufosa": "tufoso",
    "tufosas": "tufoso",
    "tufosos": "tufoso",
    "tufou": "tufar",
    "tufá": "tufar",
    "tufámo": "tufar",
    "tufámos": "tufar",
    "tufáramo": "tufar",
    "tufáramos": "tufar",
    "tufárei": "tufar",
    "tufáreis": "tufar",
    "tufásseis": "tufar",
    "tufássemos": "tufar",
    "tufávamo": "tufar",
    "tufávamos": "tufar",
    "tufávei": "tufar",
    "tufáveis": "tufar",
    "tufões": "tufão",
    "tuge": "tugir",
    "tugem": "tugir",
    "tuges": "tugir",
    "tugi": "tugir",
    "tugia": "tugir",
    "tugiam": "tugir",
    "tugias": "tugir",
    "tugida": "tugir",
    "tugidas": "tugir",
    "tugido": "tugir",
    "tugidos": "tugir",
    "tugimo": "tugir",
    "tugimos": "tugir",
    "tugindo": "tugir",
    "tugira": "tugir",
    "tugiram": "tugir",
    "tugiras": "tugir",
    "tugirdes": "tugir",
    "tugirei": "tugir",
    "tugireis": "tugir",
    "tugirem": "tugir",
    "tugiremos": "tugir",
    "tugires": "tugir",
    "tugiria": "tugir",
    "tugiriam": "tugir",
    "tugirias": "tugir",
    "tugirmo": "tugir",
    "tugirmos": "tugir",
    "tugirá": "tugir",
    "tugirás": "tugir",
    "tugirão": "tugir",
    "tugiríamos": "tugir",
    "tugiríeis": "tugir",
    "tugis": "tugir",
    "tugisse": "tugir",
    "tugissem": "tugir",
    "tugisses": "tugir",
    "tugiste": "tugir",
    "tugistes": "tugir",
    "tugiu": "tugir",
    "tugues": "tugue",
    "tugíamo": "tugir",
    "tugíamos": "tugir",
    "tugíeis": "tugir",
    "tugíramo": "tugir",
    "tugíramos": "tugir",
    "tugíreis": "tugir",
    "tugísseis": "tugir",
    "tugíssemos": "tugir",
    "tugúrios": "tugúrio",
    "tuias": "tuia",
    "tuins": "tuim",
    "tuitiva": "tuitivo",
    "tuitivas": "tuitivo",
    "tuitivos": "tuitivo",
    "tuiuiús": "tuiuiú",
    "tuições": "tuição",
    "tuiúvas": "tuiúva",
    "tuja": "tugir",
    "tujais": "tugir",
    "tujam": "tugir",
    "tujamo": "tugir",
    "tujamos": "tugir",
    "tujas": "tuja",
    "tujo": "tugir",
    "tujubas": "tujuba",
    "tules": "tule",
    "tulhas": "tulha",
    "tulheira": "tulheiro",
    "tulheiras": "tulheiro",
    "tulheiros": "tulheiro",
    "tuliana": "tuliano",
    "tulianas": "tuliano",
    "tulianos": "tuliano",
    "tulipa": "túlipa",
    "tulipas": "túlipa",
    "tulipeiras": "tulipeira",
    "tulipeiros": "tulipeiro",
    "tulipácea": "tulipáceo",
    "tulipáceas": "tulipáceo",
    "tulipáceos": "tulipáceo",
    "tumba": "tumbar",
    "tumbada": "tumbar",
    "tumbadas": "tumbar",
    "tumbado": "tumbar",
    "tumbados": "tumbar",
    "tumbai": "tumbar",
    "tumbais": "tumbar",
    "tumbam": "tumbar",
    "tumbamo": "tumbar",
    "tumbamos": "tumbar",
    "tumbando": "tumbar",
    "tumbara": "tumbar",
    "tumbaram": "tumbar",
    "tumbaras": "tumbar",
    "tumbardes": "tumbar",
    "tumbarei": "tumbar",
    "tumbareis": "tumbar",
    "tumbarem": "tumbar",
    "tumbaremos": "tumbar",
    "tumbares": "tumbar",
    "tumbaria": "tumbar",
    "tumbariam": "tumbar",
    "tumbarias": "tumbar",
    "tumbarmo": "tumbar",
    "tumbarmos": "tumbar",
    "tumbará": "tumbar",
    "tumbarás": "tumbar",
    "tumbarão": "tumbar",
    "tumbaríamos": "tumbar",
    "tumbaríeis": "tumbar",
    "tumbas": "tumbar",
    "tumbasse": "tumbar",
    "tumbassem": "tumbar",
    "tumbasses": "tumbar",
    "tumbaste": "tumbar",
    "tumbastes": "tumbar",
    "tumbava": "tumbar",
    "tumbavam": "tumbar",
    "tumbavas": "tumbar",
    "tumbe": "tumbar",
    "tumbei": "tumbar",
    "tumbeira": "tumbeiro",
    "tumbeiras": "tumbeiro",
    "tumbeiros": "tumbeiro",
    "tumbeis": "tumbar",
    "tumbem": "tumbar",
    "tumbemo": "tumbar",
    "tumbemos": "tumbar",
    "tumbes": "tumbar",
    "tumbices": "tumbice",
    "tumbo": "tumbar",
    "tumbou": "tumbar",
    "tumbámo": "tumbar",
    "tumbámos": "tumbar",
    "tumbáramo": "tumbar",
    "tumbáramos": "tumbar",
    "tumbáreis": "tumbar",
    "tumbásseis": "tumbar",
    "tumbássemos": "tumbar",
    "tumbávamo": "tumbar",
    "tumbávamos": "tumbar",
    "tumbáveis": "tumbar",
    "tumefacientes": "tumefaciente",
    "tumefacta": "tumefacto",
    "tumefactas": "tumefacto",
    "tumefactos": "tumefacto",
    "tumefacções": "tumefacção",
    "tumefarei": "tumefazer",
    "tumefareis": "tumefazer",
    "tumefaremos": "tumefazer",
    "tumefaria": "tumefazer",
    "tumefariam": "tumefazer",
    "tumefarias": "tumefazer",
    "tumefará": "tumefazer",
    "tumefarás": "tumefazer",
    "tumefarão": "tumefazer",
    "tumefaríamos": "tumefazer",
    "tumefaríeis": "tumefazer",
    "tumefaz": "tumefazer",
    "tumefaze": "tumefazer",
    "tumefazei": "tumefazer",
    "tumefazeis": "tumefazer",
    "tumefazem": "tumefazer",
    "tumefazemo": "tumefazer",
    "tumefazemos": "tumefazer",
    "tumefazendo": "tumefazer",
    "tumefazerde": "tumefazer",
    "tumefazerdes": "tumefazer",
    "tumefazere": "tumefazer",
    "tumefazerem": "tumefazer",
    "tumefazeres": "tumefazer",
    "tumefazermo": "tumefazer",
    "tumefazermos": "tumefazer",
    "tumefazes": "tumefazer",
    "tumefazia": "tumefazer",
    "tumefaziam": "tumefazer",
    "tumefazias": "tumefazer",
    "tumefazê": "tumefazer",
    "tumefazíamo": "tumefazer",
    "tumefazíamos": "tumefazer",
    "tumefazíei": "tumefazer",
    "tumefazíeis": "tumefazer",
    "tumefaça": "tumefazer",
    "tumefaçais": "tumefazer",
    "tumefaçam": "tumefazer",
    "tumefaçamo": "tumefazer",
    "tumefaçamos": "tumefazer",
    "tumefaças": "tumefazer",
    "tumefaço": "tumefazer",
    "tumefeita": "tumefeito",
    "tumefeitas": "tumefeito",
    "tumefeito": "tumefazer",
    "tumefeitos": "tumefeito",
    "tumefez": "tumefazer",
    "tumefi": "tumefazer",
    "tumefica": "tumeficar",
    "tumeficada": "tumeficar",
    "tumeficadas": "tumeficar",
    "tumeficado": "tumeficar",
    "tumeficados": "tumeficar",
    "tumeficais": "tumeficar",
    "tumeficam": "tumeficar",
    "tumeficamo": "tumeficar",
    "tumeficamos": "tumeficar",
    "tumeficando": "tumeficar",
    "tumeficantes": "tumeficante",
    "tumeficara": "tumeficar",
    "tumeficaram": "tumeficar",
    "tumeficaras": "tumeficar",
    "tumeficardes": "tumeficar",
    "tumeficarei": "tumeficar",
    "tumeficareis": "tumeficar",
    "tumeficarem": "tumeficar",
    "tumeficaremos": "tumeficar",
    "tumeficares": "tumeficar",
    "tumeficaria": "tumeficar",
    "tumeficariam": "tumeficar",
    "tumeficarias": "tumeficar",
    "tumeficarmo": "tumeficar",
    "tumeficarmos": "tumeficar",
    "tumeficará": "tumeficar",
    "tumeficarás": "tumeficar",
    "tumeficarão": "tumeficar",
    "tumeficaríamos": "tumeficar",
    "tumeficaríeis": "tumeficar",
    "tumeficas": "tumeficar",
    "tumeficasse": "tumeficar",
    "tumeficassem": "tumeficar",
    "tumeficasses": "tumeficar",
    "tumeficaste": "tumeficar",
    "tumeficastes": "tumeficar",
    "tumeficava": "tumeficar",
    "tumeficavam": "tumeficar",
    "tumeficavas": "tumeficar",
    "tumefico": "tumeficar",
    "tumeficou": "tumeficar",
    "tumeficámo": "tumeficar",
    "tumeficámos": "tumeficar",
    "tumeficáramo": "tumeficar",
    "tumeficáramos": "tumeficar",
    "tumeficáreis": "tumeficar",
    "tumeficásseis": "tumeficar",
    "tumeficássemos": "tumeficar",
    "tumeficávamo": "tumeficar",
    "tumeficávamos": "tumeficar",
    "tumeficáveis": "tumeficar",
    "tumefique": "tumeficar",
    "tumefiquei": "tumeficar",
    "tumefiqueis": "tumeficar",
    "tumefiquem": "tumeficar",
    "tumefiquemos": "tumeficar",
    "tumefiques": "tumeficar",
    "tumefiz": "tumefazer",
    "tumefizemo": "tumefazer",
    "tumefizemos": "tumefazer",
    "tumefizer": "tumefazer",
    "tumefizera": "tumefazer",
    "tumefizeram": "tumefazer",
    "tumefizeras": "tumefazer",
    "tumefizerdes": "tumefazer",
    "tumefizerem": "tumefazer",
    "tumefizeres": "tumefazer",
    "tumefizermos": "tumefazer",
    "tumefizesse": "tumefazer",
    "tumefizessem": "tumefazer",
    "tumefizesses": "tumefazer",
    "tumefizeste": "tumefazer",
    "tumefizestes": "tumefazer",
    "tumefizéramo": "tumefazer",
    "tumefizéramos": "tumefazer",
    "tumefizérei": "tumefazer",
    "tumefizéreis": "tumefazer",
    "tumefizésseis": "tumefazer",
    "tumefizéssemos": "tumefazer",
    "tumefá": "tumefazer",
    "tumefê": "tumefazer",
    "tumentes": "tumente",
    "tumesce": "tumescer",
    "tumescei": "tumescer",
    "tumesceis": "tumescer",
    "tumescem": "tumescer",
    "tumescemo": "tumescer",
    "tumescemos": "tumescer",
    "tumescendo": "tumescer",
    "tumescentes": "tumescente",
    "tumescera": "tumescer",
    "tumesceram": "tumescer",
    "tumesceras": "tumescer",
    "tumescerdes": "tumescer",
    "tumescerei": "tumescer",
    "tumescereis": "tumescer",
    "tumescerem": "tumescer",
    "tumesceremos": "tumescer",
    "tumesceres": "tumescer",
    "tumesceria": "tumescer",
    "tumesceriam": "tumescer",
    "tumescerias": "tumescer",
    "tumescermo": "tumescer",
    "tumescermos": "tumescer",
    "tumescerá": "tumescer",
    "tumescerás": "tumescer",
    "tumescerão": "tumescer",
    "tumesceríamos": "tumescer",
    "tumesceríeis": "tumescer",
    "tumesces": "tumescer",
    "tumescesse": "tumescer",
    "tumescessem": "tumescer",
    "tumescesses": "tumescer",
    "tumesceste": "tumescer",
    "tumescestes": "tumescer",
    "tumesceu": "tumescer",
    "tumesci": "tumescer",
    "tumescia": "tumescer",
    "tumesciam": "tumescer",
    "tumescias": "tumescer",
    "tumescida": "tumescer",
    "tumescidas": "tumescer",
    "tumescido": "tumescer",
    "tumescidos": "tumescer",
    "tumescimentos": "tumescimento",
    "tumescências": "tumescência",
    "tumescêramo": "tumescer",
    "tumescêramos": "tumescer",
    "tumescêreis": "tumescer",
    "tumescêsseis": "tumescer",
    "tumescêssemos": "tumescer",
    "tumescíamo": "tumescer",
    "tumescíamos": "tumescer",
    "tumescíeis": "tumescer",
    "tumesça": "tumescer",
    "tumesçais": "tumescer",
    "tumesçam": "tumescer",
    "tumesçamo": "tumescer",
    "tumesçamos": "tumescer",
    "tumesças": "tumescer",
    "tumesço": "tumescer",
    "tumidezes": "tumidez",
    "tumidifica": "tumidificar",
    "tumidificada": "tumidificar",
    "tumidificadas": "tumidificar",
    "tumidificado": "tumidificar",
    "tumidificados": "tumidificar",
    "tumidificai": "tumidificar",
    "tumidificais": "tumidificar",
    "tumidificam": "tumidificar",
    "tumidificamo": "tumidificar",
    "tumidificamos": "tumidificar",
    "tumidificando": "tumidificar",
    "tumidificara": "tumidificar",
    "tumidificaram": "tumidificar",
    "tumidificaras": "tumidificar",
    "tumidificarde": "tumidificar",
    "tumidificardes": "tumidificar",
    "tumidificare": "tumidificar",
    "tumidificarei": "tumidificar",
    "tumidificareis": "tumidificar",
    "tumidificarem": "tumidificar",
    "tumidificaremos": "tumidificar",
    "tumidificares": "tumidificar",
    "tumidificaria": "tumidificar",
    "tumidificariam": "tumidificar",
    "tumidificarias": "tumidificar",
    "tumidificarmo": "tumidificar",
    "tumidificarmos": "tumidificar",
    "tumidificará": "tumidificar",
    "tumidificarás": "tumidificar",
    "tumidificarão": "tumidificar",
    "tumidificaríamos": "tumidificar",
    "tumidificaríeis": "tumidificar",
    "tumidificas": "tumidificar",
    "tumidificasse": "tumidificar",
    "tumidificassem": "tumidificar",
    "tumidificasses": "tumidificar",
    "tumidificaste": "tumidificar",
    "tumidificastes": "tumidificar",
    "tumidificava": "tumidificar",
    "tumidificavam": "tumidificar",
    "tumidificavas": "tumidificar",
    "tumidifico": "tumidificar",
    "tumidificou": "tumidificar",
    "tumidificá": "tumidificar",
    "tumidificámo": "tumidificar",
    "tumidificámos": "tumidificar",
    "tumidificáramo": "tumidificar",
    "tumidificáramos": "tumidificar",
    "tumidificárei": "tumidificar",
    "tumidificáreis": "tumidificar",
    "tumidificásseis": "tumidificar",
    "tumidificássemos": "tumidificar",
    "tumidificávamo": "tumidificar",
    "tumidificávamos": "tumidificar",
    "tumidificávei": "tumidificar",
    "tumidificáveis": "tumidificar",
    "tumidifique": "tumidificar",
    "tumidifiquei": "tumidificar",
    "tumidifiqueis": "tumidificar",
    "tumidifiquem": "tumidificar",
    "tumidifiquemo": "tumidificar",
    "tumidifiquemos": "tumidificar",
    "tumidifiques": "tumidificar",
    "tumorais": "tumoral",
    "tumores": "tumor",
    "tumorizações": "tumorização",
    "tumorosa": "tumoroso",
    "tumorosas": "tumoroso",
    "tumorosos": "tumoroso",
    "tumulares": "tumular",
    "tumuliza": "tumulizar",
    "tumulizada": "tumulizar",
    "tumulizadas": "tumulizar",
    "tumulizado": "tumulizar",
    "tumulizados": "tumulizar",
    "tumulizai": "tumulizar",
    "tumulizais": "tumulizar",
    "tumulizam": "tumulizar",
    "tumulizamo": "tumulizar",
    "tumulizamos": "tumulizar",
    "tumulizando": "tumulizar",
    "tumulizara": "tumulizar",
    "tumulizaram": "tumulizar",
    "tumulizaras": "tumulizar",
    "tumulizarde": "tumulizar",
    "tumulizardes": "tumulizar",
    "tumulizare": "tumulizar",
    "tumulizarei": "tumulizar",
    "tumulizareis": "tumulizar",
    "tumulizarem": "tumulizar",
    "tumulizaremos": "tumulizar",
    "tumulizares": "tumulizar",
    "tumulizaria": "tumulizar",
    "tumulizariam": "tumulizar",
    "tumulizarias": "tumulizar",
    "tumulizarmo": "tumulizar",
    "tumulizarmos": "tumulizar",
    "tumulizará": "tumulizar",
    "tumulizarás": "tumulizar",
    "tumulizarão": "tumulizar",
    "tumulizaríamos": "tumulizar",
    "tumulizaríeis": "tumulizar",
    "tumulizas": "tumulizar",
    "tumulizasse": "tumulizar",
    "tumulizassem": "tumulizar",
    "tumulizasses": "tumulizar",
    "tumulizaste": "tumulizar",
    "tumulizastes": "tumulizar",
    "tumulizava": "tumulizar",
    "tumulizavam": "tumulizar",
    "tumulizavas": "tumulizar",
    "tumulize": "tumulizar",
    "tumulizei": "tumulizar",
    "tumulizeis": "tumulizar",
    "tumulizem": "tumulizar",
    "tumulizemo": "tumulizar",
    "tumulizemos": "tumulizar",
    "tumulizes": "tumulizar",
    "tumulizo": "tumulizar",
    "tumulizou": "tumulizar",
    "tumulizá": "tumulizar",
    "tumulizámo": "tumulizar",
    "tumulizámos": "tumulizar",
    "tumulizáramo": "tumulizar",
    "tumulizáramos": "tumulizar",
    "tumulizárei": "tumulizar",
    "tumulizáreis": "tumulizar",
    "tumulizásseis": "tumulizar",
    "tumulizássemos": "tumulizar",
    "tumulizávamo": "tumulizar",
    "tumulizávamos": "tumulizar",
    "tumulizávei": "tumulizar",
    "tumulizáveis": "tumulizar",
    "tumultos": "tumulto",
    "tumultua": "tumultuar",
    "tumultuada": "tumultuar",
    "tumultuadas": "tumultuar",
    "tumultuado": "tumultuar",
    "tumultuadora": "tumultuador",
    "tumultuadoras": "tumultuador",
    "tumultuadores": "tumultuador",
    "tumultuados": "tumultuar",
    "tumultuai": "tumultuar",
    "tumultuais": "tumultuar",
    "tumultuam": "tumultuar",
    "tumultuamo": "tumultuar",
    "tumultuamos": "tumultuar",
    "tumultuando": "tumultuar",
    "tumultuantes": "tumultuante",
    "tumultuara": "tumultuar",
    "tumultuaram": "tumultuar",
    "tumultuaras": "tumultuar",
    "tumultuarde": "tumultuar",
    "tumultuardes": "tumultuar",
    "tumultuare": "tumultuar",
    "tumultuarei": "tumultuar",
    "tumultuareis": "tumultuar",
    "tumultuarem": "tumultuar",
    "tumultuaremos": "tumultuar",
    "tumultuares": "tumultuar",
    "tumultuaria": "tumultuar",
    "tumultuariam": "tumultuar",
    "tumultuarias": "tumultuar",
    "tumultuarmo": "tumultuar",
    "tumultuarmos": "tumultuar",
    "tumultuará": "tumultuar",
    "tumultuarás": "tumultuar",
    "tumultuarão": "tumultuar",
    "tumultuaríamos": "tumultuar",
    "tumultuaríeis": "tumultuar",
    "tumultuas": "tumultuar",
    "tumultuasse": "tumultuar",
    "tumultuassem": "tumultuar",
    "tumultuasses": "tumultuar",
    "tumultuaste": "tumultuar",
    "tumultuastes": "tumultuar",
    "tumultuava": "tumultuar",
    "tumultuavam": "tumultuar",
    "tumultuavas": "tumultuar",
    "tumultue": "tumultuar",
    "tumultuei": "tumultuar",
    "tumultueis": "tumultuar",
    "tumultuem": "tumultuar",
    "tumultuemo": "tumultuar",
    "tumultuemos": "tumultuar",
    "tumultues": "tumultuar",
    "tumultuo": "tumultuar",
    "tumultuosa": "tumultuoso",
    "tumultuosas": "tumultuoso",
    "tumultuosos": "tumultuoso",
    "tumultuou": "tumultuar",
    "tumultuá": "tumultuar",
    "tumultuámo": "tumultuar",
    "tumultuámos": "tumultuar",
    "tumultuáramo": "tumultuar",
    "tumultuáramos": "tumultuar",
    "tumultuárei": "tumultuar",
    "tumultuáreis": "tumultuar",
    "tumultuária": "tumultuário",
    "tumultuárias": "tumultuário",
    "tumultuários": "tumultuário",
    "tumultuásseis": "tumultuar",
    "tumultuássemos": "tumultuar",
    "tumultuávamo": "tumultuar",
    "tumultuávamos": "tumultuar",
    "tumultuávei": "tumultuar",
    "tumultuáveis": "tumultuar",
    "tuna": "tuno",
    "tunada": "tunar",
    "tunadas": "tunar",
    "tunado": "tunar",
    "tunadora": "tunador",
    "tunadoras": "tunador",
    "tunadores": "tunador",
    "tunados": "tunar",
    "tunai": "tunar",
    "tunais": "tunar",
    "tunam": "tunar",
    "tunamo": "tunar",
    "tunamos": "tunar",
    "tunando": "tunar",
    "tunantagens": "tunantagem",
    "tunantarias": "tunantaria",
    "tunantea": "tunante",
    "tunanteada": "tunantear",
    "tunanteadas": "tunantear",
    "tunanteado": "tunantear",
    "tunanteados": "tunantear",
    "tunanteai": "tunantear",
    "tunanteais": "tunantear",
    "tunanteamo": "tunantear",
    "tunanteamos": "tunantear",
    "tunanteando": "tunantear",
    "tunanteara": "tunantear",
    "tunantearam": "tunantear",
    "tunantearas": "tunantear",
    "tunanteardes": "tunantear",
    "tunantearei": "tunantear",
    "tunanteareis": "tunantear",
    "tunantearem": "tunantear",
    "tunantearemos": "tunantear",
    "tunanteares": "tunantear",
    "tunantearia": "tunantear",
    "tunanteariam": "tunantear",
    "tunantearias": "tunantear",
    "tunantearmo": "tunantear",
    "tunantearmos": "tunantear",
    "tunanteará": "tunantear",
    "tunantearás": "tunantear",
    "tunantearão": "tunantear",
    "tunantearíamos": "tunantear",
    "tunantearíeis": "tunantear",
    "tunanteas": "tunante",
    "tunanteasse": "tunantear",
    "tunanteassem": "tunantear",
    "tunanteasses": "tunantear",
    "tunanteaste": "tunantear",
    "tunanteastes": "tunantear",
    "tunanteava": "tunantear",
    "tunanteavam": "tunantear",
    "tunanteavas": "tunantear",
    "tunanteei": "tunantear",
    "tunanteeis": "tunantear",
    "tunanteemo": "tunantear",
    "tunanteemos": "tunantear",
    "tunantees": "tunante",
    "tunanteia": "tunantear",
    "tunanteiam": "tunantear",
    "tunanteias": "tunantear",
    "tunanteie": "tunantear",
    "tunanteiem": "tunantear",
    "tunanteies": "tunantear",
    "tunanteio": "tunantear",
    "tunanteou": "tunantear",
    "tunanteámo": "tunantear",
    "tunanteámos": "tunantear",
    "tunanteáramo": "tunantear",
    "tunanteáramos": "tunantear",
    "tunanteáreis": "tunantear",
    "tunanteásseis": "tunantear",
    "tunanteássemos": "tunantear",
    "tunanteávamo": "tunantear",
    "tunanteávamos": "tunantear",
    "tunanteáveis": "tunantear",
    "tunara": "tunar",
    "tunaram": "tunar",
    "tunaras": "tunar",
    "tunardes": "tunar",
    "tunarei": "tunar",
    "tunareis": "tunar",
    "tunarem": "tunar",
    "tunaremos": "tunar",
    "tunares": "tunar",
    "tunaria": "tunar",
    "tunariam": "tunar",
    "tunarias": "tunar",
    "tunarmo": "tunar",
    "tunarmos": "tunar",
    "tunará": "tunar",
    "tunarás": "tunar",
    "tunarão": "tunar",
    "tunaríamos": "tunar",
    "tunaríeis": "tunar",
    "tunas": "tuno",
    "tunasse": "tunar",
    "tunassem": "tunar",
    "tunasses": "tunar",
    "tunaste": "tunar",
    "tunastes": "tunar",
    "tunava": "tunar",
    "tunavam": "tunar",
    "tunavas": "tunar",
    "tunda": "tundar",
    "tundada": "tundar",
    "tundadas": "tundar",
    "tundado": "tundar",
    "tundados": "tundar",
    "tundai": "tundar",
    "tundais": "tundar",
    "tundam": "tundar",
    "tundamo": "tundar",
    "tundamos": "tundar",
    "tundando": "tundar",
    "tundara": "tundar",
    "tundaram": "tundar",
    "tundaras": "tundar",
    "tundarde": "tundar",
    "tundardes": "tundar",
    "tundare": "tundar",
    "tundarei": "tundar",
    "tundareis": "tundar",
    "tundarem": "tundar",
    "tundaremos": "tundar",
    "tundares": "tundar",
    "tundaria": "tundar",
    "tundariam": "tundar",
    "tundarias": "tundar",
    "tundarmo": "tundar",
    "tundarmos": "tundar",
    "tundará": "tundar",
    "tundarás": "tundar",
    "tundarão": "tundar",
    "tundaríamos": "tundar",
    "tundaríeis": "tundar",
    "tundas": "tundar",
    "tundasse": "tundar",
    "tundassem": "tundar",
    "tundasses": "tundar",
    "tundaste": "tundar",
    "tundastes": "tundar",
    "tundava": "tundar",
    "tundavam": "tundar",
    "tundavas": "tundar",
    "tunde": "tundar",
    "tundei": "tundar",
    "tundeis": "tundar",
    "tundem": "tundar",
    "tundemo": "tundar",
    "tundemos": "tundar",
    "tundes": "tundar",
    "tundo": "tundar",
    "tundos": "tundo",
    "tundou": "tundar",
    "tundras": "tundra",
    "tundá": "tundar",
    "tundámo": "tundar",
    "tundámos": "tundar",
    "tundáramo": "tundar",
    "tundáramos": "tundar",
    "tundárei": "tundar",
    "tundáreis": "tundar",
    "tundásseis": "tundar",
    "tundássemos": "tundar",
    "tundávamo": "tundar",
    "tundávamos": "tundar",
    "tundávei": "tundar",
    "tundáveis": "tundar",
    "tune": "tunar",
    "tunei": "tunar",
    "tuneis": "tunar",
    "tunem": "tunar",
    "tunemo": "tunar",
    "tunemos": "tunar",
    "tunes": "tunar",
    "tunesina": "tunesino",
    "tunesinas": "tunesino",
    "tunesinos": "tunesino",
    "tunetenses": "tunetense",
    "tungas": "tunga",
    "tungsténica": "tungsténico",
    "tungsténicas": "tungsténico",
    "tungsténicos": "tungsténico",
    "tungsténios": "tungsténio",
    "tungulas": "tungula",
    "tunicada": "tunicado",
    "tunicadas": "tunicado",
    "tunicados": "tunicado",
    "tunicelas": "tunicela",
    "tunicinas": "tunicina",
    "tunicários": "tunicário",
    "tunicífera": "tunicífero",
    "tunicíferas": "tunicífero",
    "tunicíferos": "tunicífero",
    "tuniquetes": "tuniquete",
    "tunisina": "tunisino",
    "tunisinas": "tunisino",
    "tunisinos": "tunisino",
    "tuno": "tunar",
    "tunos": "tuno",
    "tunou": "tunar",
    "tunámo": "tunar",
    "tunámos": "tunar",
    "tunáramo": "tunar",
    "tunáramos": "tunar",
    "tunáreis": "tunar",
    "tunásseis": "tunar",
    "tunássemos": "tunar",
    "tunávamo": "tunar",
    "tunávamos": "tunar",
    "tunáveis": "tunar",
    "tupa": "tupir",
    "tupaias": "tupaia",
    "tupais": "tupir",
    "tupaiídeos": "tupaiídeo",
    "tupam": "tupir",
    "tupamo": "tupir",
    "tupamos": "tupir",
    "tupas": "tupir",
    "tupe": "tupir",
    "tupem": "tupir",
    "tupes": "tupir",
    "tupi": "tupir",
    "tupia": "tupir",
    "tupiam": "tupir",
    "tupias": "tupir",
    "tupida": "tupir",
    "tupidas": "tupir",
    "tupido": "tupir",
    "tupidos": "tupir",
    "tupimo": "tupir",
    "tupimos": "tupir",
    "tupinambas": "tupinamba",
    "tupinambores": "tupinambor",
    "tupinambos": "tupinambo",
    "tupinambás": "tupinambá",
    "tupindo": "tupir",
    "tupinismos": "tupinismo",
    "tupira": "tupir",
    "tupiram": "tupir",
    "tupiras": "tupir",
    "tupirde": "tupir",
    "tupirdes": "tupir",
    "tupire": "tupir",
    "tupirei": "tupir",
    "tupireis": "tupir",
    "tupirem": "tupir",
    "tupiremos": "tupir",
    "tupires": "tupir",
    "tupiria": "tupir",
    "tupiriam": "tupir",
    "tupirias": "tupir",
    "tupirmo": "tupir",
    "tupirmos": "tupir",
    "tupirá": "tupir",
    "tupirás": "tupir",
    "tupirão": "tupir",
    "tupiríamos": "tupir",
    "tupiríeis": "tupir",
    "tupis": "tupir",
    "tupisse": "tupir",
    "tupissem": "tupir",
    "tupisses": "tupir",
    "tupiste": "tupir",
    "tupistes": "tupir",
    "tupiu": "tupir",
    "tupo": "tupir",
    "tupáiidas": "tupáiida",
    "tupés": "tupé",
    "tupíamo": "tupir",
    "tupíamos": "tupir",
    "tupíei": "tupir",
    "tupíeis": "tupir",
    "tupíramo": "tupir",
    "tupíramos": "tupir",
    "tupírei": "tupir",
    "tupíreis": "tupir",
    "tupísseis": "tupir",
    "tupíssemos": "tupir",
    "turacos": "turaco",
    "turanianos": "turaniano",
    "turaris": "turari",
    "turba": "turbar",
    "turbada": "turbar",
    "turbadas": "turbar",
    "turbado": "turbar",
    "turbadora": "turbador",
    "turbadoras": "turbador",
    "turbadores": "turbador",
    "turbados": "turbar",
    "turbai": "turbar",
    "turbais": "turbar",
    "turbam": "turbar",
    "turbamentos": "turbamento",
    "turbamo": "turbar",
    "turbamos": "turbar",
    "turbamultas": "turbamulta",
    "turbando": "turbar",
    "turbantes": "turbante",
    "turbara": "turbar",
    "turbaram": "turbar",
    "turbaras": "turbar",
    "turbarde": "turbar",
    "turbardes": "turbar",
    "turbare": "turbar",
    "turbarei": "turbar",
    "turbareis": "turbar",
    "turbarem": "turbar",
    "turbaremos": "turbar",
    "turbares": "turbar",
    "turbaria": "turbar",
    "turbariam": "turbar",
    "turbarias": "turbar",
    "turbarmo": "turbar",
    "turbarmos": "turbar",
    "turbará": "turbar",
    "turbarás": "turbar",
    "turbarão": "turbar",
    "turbaríamos": "turbar",
    "turbaríeis": "turbar",
    "turbas": "turbar",
    "turbasse": "turbar",
    "turbassem": "turbar",
    "turbasses": "turbar",
    "turbaste": "turbar",
    "turbastes": "turbar",
    "turbativa": "turbativo",
    "turbativas": "turbativo",
    "turbativos": "turbativo",
    "turbava": "turbar",
    "turbavam": "turbar",
    "turbavas": "turbar",
    "turbe": "turbar",
    "turbei": "turbar",
    "turbeis": "turbar",
    "turbelariada": "turbelariado",
    "turbelariadas": "turbelariado",
    "turbelariados": "turbelariado",
    "turbelária": "turbelário",
    "turbelárias": "turbelário",
    "turbelários": "turbelário",
    "turbem": "turbar",
    "turbemo": "turbar",
    "turbemos": "turbar",
    "turbes": "turbar",
    "turbidezes": "turbidez",
    "turbilhona": "turbilhonar",
    "turbilhonada": "turbilhonar",
    "turbilhonadas": "turbilhonar",
    "turbilhonado": "turbilhonar",
    "turbilhonados": "turbilhonar",
    "turbilhonai": "turbilhonar",
    "turbilhonais": "turbilhonar",
    "turbilhonam": "turbilhonar",
    "turbilhonamo": "turbilhonar",
    "turbilhonamos": "turbilhonar",
    "turbilhonando": "turbilhonar",
    "turbilhonara": "turbilhonar",
    "turbilhonaram": "turbilhonar",
    "turbilhonaras": "turbilhonar",
    "turbilhonardes": "turbilhonar",
    "turbilhonarei": "turbilhonar",
    "turbilhonareis": "turbilhonar",
    "turbilhonarem": "turbilhonar",
    "turbilhonaremos": "turbilhonar",
    "turbilhonares": "turbilhonar",
    "turbilhonaria": "turbilhonar",
    "turbilhonariam": "turbilhonar",
    "turbilhonarias": "turbilhonar",
    "turbilhonarmo": "turbilhonar",
    "turbilhonarmos": "turbilhonar",
    "turbilhonará": "turbilhonar",
    "turbilhonarás": "turbilhonar",
    "turbilhonarão": "turbilhonar",
    "turbilhonaríamos": "turbilhonar",
    "turbilhonaríeis": "turbilhonar",
    "turbilhonas": "turbilhonar",
    "turbilhonasse": "turbilhonar",
    "turbilhonassem": "turbilhonar",
    "turbilhonasses": "turbilhonar",
    "turbilhonaste": "turbilhonar",
    "turbilhonastes": "turbilhonar",
    "turbilhonava": "turbilhonar",
    "turbilhonavam": "turbilhonar",
    "turbilhonavas": "turbilhonar",
    "turbilhone": "turbilhonar",
    "turbilhonei": "turbilhonar",
    "turbilhoneis": "turbilhonar",
    "turbilhonem": "turbilhonar",
    "turbilhonemo": "turbilhonar",
    "turbilhonemos": "turbilhonar",
    "turbilhones": "turbilhonar",
    "turbilhono": "turbilhonar",
    "turbilhonou": "turbilhonar",
    "turbilhonámo": "turbilhonar",
    "turbilhonámos": "turbilhonar",
    "turbilhonáramo": "turbilhonar",
    "turbilhonáramos": "turbilhonar",
    "turbilhonáreis": "turbilhonar",
    "turbilhonásseis": "turbilhonar",
    "turbilhonássemos": "turbilhonar",
    "turbilhonávamo": "turbilhonar",
    "turbilhonávamos": "turbilhonar",
    "turbilhonáveis": "turbilhonar",
    "turbilhões": "turbilhão",
    "turbinada": "turbinado",
    "turbinadas": "turbinado",
    "turbinados": "turbinado",
    "turbinais": "turbinal",
    "turbinas": "turbina",
    "turbinectomias": "turbinectomia",
    "turbiniformes": "turbiniforme",
    "turbinosa": "turbinoso",
    "turbinosas": "turbinoso",
    "turbinosos": "turbinoso",
    "turbinótomos": "turbinótomo",
    "turbo": "turbar",
    "turboalternadores": "turboalternador",
    "turbodieseis": "turbodiesel",
    "turbou": "turbar",
    "turbulenta": "turbulento",
    "turbulentas": "turbulento",
    "turbulentos": "turbulento",
    "turbulências": "turbulência",
    "turbá": "turbar",
    "turbámo": "turbar",
    "turbámos": "turbar",
    "turbáramo": "turbar",
    "turbáramos": "turbar",
    "turbárei": "turbar",
    "turbáreis": "turbar",
    "turbásseis": "turbar",
    "turbássemos": "turbar",
    "turbávamo": "turbar",
    "turbávamos": "turbar",
    "turbávei": "turbar",
    "turbáveis": "turbável",
    "turbínea": "turbíneo",
    "turbíneas": "turbíneo",
    "turbíneos": "turbíneo",
    "turca": "turco",
    "turcas": "turco",
    "turcomanos": "turcomano",
    "turcos": "turco",
    "turcófila": "turcófilo",
    "turcófilas": "turcófilo",
    "turcófilos": "turcófilo",
    "turcófoba": "turcófobo",
    "turcófobas": "turcófobo",
    "turcófobos": "turcófobo",
    "turdetana": "turdetano",
    "turdetanas": "turdetano",
    "turdetanos": "turdetano",
    "turdídeos": "turdídeo",
    "turfas": "turfa",
    "turfeiras": "turfeira",
    "turfosa": "turfoso",
    "turfosas": "turfoso",
    "turfosos": "turfoso",
    "turfóis": "turfol",
    "turge": "turgir",
    "turgem": "turgir",
    "turgentes": "turgente",
    "turges": "turgir",
    "turgesce": "turgescer",
    "turgescei": "turgescer",
    "turgesceis": "turgescer",
    "turgescem": "turgescer",
    "turgescemo": "turgescer",
    "turgescemos": "turgescer",
    "turgescendo": "turgescer",
    "turgescentes": "turgescente",
    "turgescera": "turgescer",
    "turgesceram": "turgescer",
    "turgesceras": "turgescer",
    "turgescerdes": "turgescer",
    "turgescerei": "turgescer",
    "turgescereis": "turgescer",
    "turgescerem": "turgescer",
    "turgesceremos": "turgescer",
    "turgesceres": "turgescer",
    "turgesceria": "turgescer",
    "turgesceriam": "turgescer",
    "turgescerias": "turgescer",
    "turgescermo": "turgescer",
    "turgescermos": "turgescer",
    "turgescerá": "turgescer",
    "turgescerás": "turgescer",
    "turgescerão": "turgescer",
    "turgesceríamos": "turgescer",
    "turgesceríeis": "turgescer",
    "turgesces": "turgescer",
    "turgescesse": "turgescer",
    "turgescessem": "turgescer",
    "turgescesses": "turgescer",
    "turgesceste": "turgescer",
    "turgescestes": "turgescer",
    "turgesceu": "turgescer",
    "turgesci": "turgescer",
    "turgescia": "turgescer",
    "turgesciam": "turgescer",
    "turgescias": "turgescer",
    "turgescida": "turgescer",
    "turgescidas": "turgescer",
    "turgescido": "turgescer",
    "turgescidos": "turgescer",
    "turgescências": "turgescência",
    "turgescêramo": "turgescer",
    "turgescêramos": "turgescer",
    "turgescêreis": "turgescer",
    "turgescêsseis": "turgescer",
    "turgescêssemos": "turgescer",
    "turgescíamo": "turgescer",
    "turgescíamos": "turgescer",
    "turgescíeis": "turgescer",
    "turgesça": "turgescer",
    "turgesçais": "turgescer",
    "turgesçam": "turgescer",
    "turgesçamo": "turgescer",
    "turgesçamos": "turgescer",
    "turgesças": "turgescer",
    "turgesço": "turgescer",
    "turgi": "turgir",
    "turgia": "turgir",
    "turgiam": "turgir",
    "turgias": "turgir",
    "turgida": "turgir",
    "turgidas": "turgir",
    "turgidezes": "turgidez",
    "turgido": "turgir",
    "turgidos": "turgir",
    "turgimo": "turgir",
    "turgimos": "turgir",
    "turgimões": "turgimão",
    "turgindo": "turgir",
    "turgira": "turgir",
    "turgiram": "turgir",
    "turgiras": "turgir",
    "turgirdes": "turgir",
    "turgirei": "turgir",
    "turgireis": "turgir",
    "turgirem": "turgir",
    "turgiremos": "turgir",
    "turgires": "turgir",
    "turgiria": "turgir",
    "turgiriam": "turgir",
    "turgirias": "turgir",
    "turgirmo": "turgir",
    "turgirmos": "turgir",
    "turgirá": "turgir",
    "turgirás": "turgir",
    "turgirão": "turgir",
    "turgiríamos": "turgir",
    "turgiríeis": "turgir",
    "turgis": "turgir",
    "turgisse": "turgir",
    "turgissem": "turgir",
    "turgisses": "turgir",
    "turgiste": "turgir",
    "turgistes": "turgir",
    "turgiu": "turgir",
    "turgências": "turgência",
    "turgíamo": "turgir",
    "turgíamos": "turgir",
    "turgíeis": "turgir",
    "turgíramo": "turgir",
    "turgíramos": "turgir",
    "turgíreis": "turgir",
    "turgísseis": "turgir",
    "turgíssemos": "turgir",
    "turibula": "turibular",
    "turibulada": "turibular",
    "turibuladas": "turibular",
    "turibulado": "turibular",
    "turibulados": "turibular",
    "turibulai": "turibular",
    "turibulais": "turibular",
    "turibulam": "turibular",
    "turibulamo": "turibular",
    "turibulamos": "turibular",
    "turibulando": "turibular",
    "turibulara": "turibular",
    "turibularam": "turibular",
    "turibularas": "turibular",
    "turibularde": "turibular",
    "turibulardes": "turibular",
    "turibulare": "turibular",
    "turibularei": "turibular",
    "turibulareis": "turibular",
    "turibularem": "turibular",
    "turibularemos": "turibular",
    "turibulares": "turibular",
    "turibularia": "turibular",
    "turibulariam": "turibular",
    "turibularias": "turibular",
    "turibularmo": "turibular",
    "turibularmos": "turibular",
    "turibulará": "turibular",
    "turibularás": "turibular",
    "turibularão": "turibular",
    "turibularíamos": "turibular",
    "turibularíeis": "turibular",
    "turibulas": "turibular",
    "turibulasse": "turibular",
    "turibulassem": "turibular",
    "turibulasses": "turibular",
    "turibulaste": "turibular",
    "turibulastes": "turibular",
    "turibulava": "turibular",
    "turibulavam": "turibular",
    "turibulavas": "turibular",
    "turibule": "turibular",
    "turibulei": "turibular",
    "turibuleis": "turibular",
    "turibulem": "turibular",
    "turibulemo": "turibular",
    "turibulemos": "turibular",
    "turibules": "turibular",
    "turibulo": "turibular",
    "turibulou": "turibular",
    "turibulá": "turibular",
    "turibulámo": "turibular",
    "turibulámos": "turibular",
    "turibuláramo": "turibular",
    "turibuláramos": "turibular",
    "turibulárei": "turibular",
    "turibuláreis": "turibular",
    "turibulária": "turibulário",
    "turibulárias": "turibulário",
    "turibulários": "turibulário",
    "turibulásseis": "turibular",
    "turibulássemos": "turibular",
    "turibulávamo": "turibular",
    "turibulávamos": "turibular",
    "turibulávei": "turibular",
    "turibuláveis": "turibular",
    "turifera": "turiferar",
    "turiferada": "turiferar",
    "turiferadas": "turiferar",
    "turiferado": "turiferar",
    "turiferados": "turiferar",
    "turiferai": "turiferar",
    "turiferais": "turiferar",
    "turiferam": "turiferar",
    "turiferamo": "turiferar",
    "turiferamos": "turiferar",
    "turiferando": "turiferar",
    "turiferara": "turiferar",
    "turiferaram": "turiferar",
    "turiferaras": "turiferar",
    "turiferarde": "turiferar",
    "turiferardes": "turiferar",
    "turiferare": "turiferar",
    "turiferarei": "turiferar",
    "turiferareis": "turiferar",
    "turiferarem": "turiferar",
    "turiferaremos": "turiferar",
    "turiferares": "turiferar",
    "turiferaria": "turiferar",
    "turiferariam": "turiferar",
    "turiferarias": "turiferar",
    "turiferarmo": "turiferar",
    "turiferarmos": "turiferar",
    "turiferará": "turiferar",
    "turiferarás": "turiferar",
    "turiferarão": "turiferar",
    "turiferaríamos": "turiferar",
    "turiferaríeis": "turiferar",
    "turiferas": "turiferar",
    "turiferasse": "turiferar",
    "turiferassem": "turiferar",
    "turiferasses": "turiferar",
    "turiferaste": "turiferar",
    "turiferastes": "turiferar",
    "turiferava": "turiferar",
    "turiferavam": "turiferar",
    "turiferavas": "turiferar",
    "turiferações": "turiferação",
    "turifere": "turiferar",
    "turiferei": "turiferar",
    "turifereis": "turiferar",
    "turiferem": "turiferar",
    "turiferemo": "turiferar",
    "turiferemos": "turiferar",
    "turiferes": "turiferar",
    "turifero": "turiferar",
    "turiferou": "turiferar",
    "turiferá": "turiferar",
    "turiferámo": "turiferar",
    "turiferámos": "turiferar",
    "turiferáramo": "turiferar",
    "turiferáramos": "turiferar",
    "turiferárei": "turiferar",
    "turiferáreis": "turiferar",
    "turiferária": "turiferário",
    "turiferárias": "turiferário",
    "turiferários": "turiferário",
    "turiferásseis": "turiferar",
    "turiferássemos": "turiferar",
    "turiferávamo": "turiferar",
    "turiferávamos": "turiferar",
    "turiferávei": "turiferar",
    "turiferáveis": "turiferar",
    "turifica": "turificar",
    "turificada": "turificar",
    "turificadas": "turificar",
    "turificado": "turificar",
    "turificadora": "turificador",
    "turificadoras": "turificador",
    "turificadores": "turificador",
    "turificados": "turificar",
    "turificai": "turificar",
    "turificais": "turificar",
    "turificam": "turificar",
    "turificamo": "turificar",
    "turificamos": "turificar",
    "turificando": "turificar",
    "turificantes": "turificante",
    "turificara": "turificar",
    "turificaram": "turificar",
    "turificaras": "turificar",
    "turificarde": "turificar",
    "turificardes": "turificar",
    "turificare": "turificar",
    "turificarei": "turificar",
    "turificareis": "turificar",
    "turificarem": "turificar",
    "turificaremos": "turificar",
    "turificares": "turificar",
    "turificaria": "turificar",
    "turificariam": "turificar",
    "turificarias": "turificar",
    "turificarmo": "turificar",
    "turificarmos": "turificar",
    "turificará": "turificar",
    "turificarás": "turificar",
    "turificarão": "turificar",
    "turificaríamos": "turificar",
    "turificaríeis": "turificar",
    "turificas": "turificar",
    "turificasse": "turificar",
    "turificassem": "turificar",
    "turificasses": "turificar",
    "turificaste": "turificar",
    "turificastes": "turificar",
    "turificava": "turificar",
    "turificavam": "turificar",
    "turificavas": "turificar",
    "turificações": "turificação",
    "turifico": "turificar",
    "turificou": "turificar",
    "turificá": "turificar",
    "turificámo": "turificar",
    "turificámos": "turificar",
    "turificáramo": "turificar",
    "turificáramos": "turificar",
    "turificárei": "turificar",
    "turificáreis": "turificar",
    "turificásseis": "turificar",
    "turificássemos": "turificar",
    "turificávamo": "turificar",
    "turificávamos": "turificar",
    "turificávei": "turificar",
    "turificáveis": "turificar",
    "turifique": "turificar",
    "turifiquei": "turificar",
    "turifiqueis": "turificar",
    "turifiquem": "turificar",
    "turifiquemo": "turificar",
    "turifiquemos": "turificar",
    "turifiques": "turificar",
    "turina": "turino",
    "turinas": "turino",
    "turingianos": "turingiano",
    "turinos": "turino",
    "turismos": "turismo",
    "turistas": "turista",
    "turiões": "turião",
    "turja": "turgir",
    "turjais": "turgir",
    "turjam": "turgir",
    "turjamo": "turgir",
    "turjamos": "turgir",
    "turjas": "turgir",
    "turjo": "turgir",
    "turmalinas": "turmalina",
    "turmalinosa": "turmalinoso",
    "turmalinosas": "turmalinoso",
    "turmalinosos": "turmalinoso",
    "turmas": "turma",
    "turnacianos": "turnaciano",
    "turneráceas": "turnerácea",
    "turneráceos": "turneráceo",
    "turnos": "turno",
    "turonenses": "turonense",
    "turonianos": "turoniano",
    "turonicenses": "turonicense",
    "turpilóquios": "turpilóquio",
    "turpitudes": "turpitude",
    "turquesada": "turquesado",
    "turquesadas": "turquesado",
    "turquesados": "turquesado",
    "turquesas": "turquesa",
    "turquesca": "turquesco",
    "turquescas": "turquesco",
    "turquescos": "turquesco",
    "turquestana": "turquestano",
    "turquestanas": "turquestano",
    "turquestanos": "turquestano",
    "turquinas": "turquina",
    "turquis": "turqui",
    "turquêses": "turquês",
    "turra": "turrar",
    "turrada": "turrar",
    "turradas": "turrar",
    "turrado": "turrar",
    "turrados": "turrar",
    "turrai": "turrar",
    "turrais": "turrar",
    "turram": "turrar",
    "turramo": "turrar",
    "turramos": "turrar",
    "turrando": "turrar",
    "turrara": "turrar",
    "turraram": "turrar",
    "turraras": "turrar",
    "turrardes": "turrar",
    "turrarei": "turrar",
    "turrareis": "turrar",
    "turrarem": "turrar",
    "turraremos": "turrar",
    "turrares": "turrar",
    "turraria": "turrar",
    "turrariam": "turrar",
    "turrarias": "turrar",
    "turrarmo": "turrar",
    "turrarmos": "turrar",
    "turrará": "turrar",
    "turrarás": "turrar",
    "turrarão": "turrar",
    "turraríamos": "turrar",
    "turraríeis": "turrar",
    "turras": "turrar",
    "turrasse": "turrar",
    "turrassem": "turrar",
    "turrasses": "turrar",
    "turraste": "turrar",
    "turrastes": "turrar",
    "turrava": "turrar",
    "turravam": "turrar",
    "turravas": "turrar",
    "turre": "turrar",
    "turrei": "turrar",
    "turreis": "turrar",
    "turrem": "turrar",
    "turremo": "turrar",
    "turremos": "turrar",
    "turres": "turrar",
    "turrinha": "turra",
    "turrinhas": "turra",
    "turristas": "turrista",
    "turrita": "turra",
    "turritas": "turra",
    "turro": "turrar",
    "turrona": "turrão",
    "turronas": "turrão",
    "turrou": "turrar",
    "turrámo": "turrar",
    "turrámos": "turrar",
    "turráramo": "turrar",
    "turráramos": "turrar",
    "turráreis": "turrar",
    "turrásseis": "turrar",
    "turrássemos": "turrar",
    "turrávamo": "turrar",
    "turrávamos": "turrar",
    "turráveis": "turrar",
    "turrífaga": "turrífago",
    "turrífagas": "turrífago",
    "turrífagos": "turrífago",
    "turrífera": "turrífero",
    "turríferas": "turrífero",
    "turríferos": "turrífero",
    "turrígera": "turrígero",
    "turrígeras": "turrígero",
    "turrígeros": "turrígero",
    "turrões": "turrão",
    "turturina": "turturino",
    "turturinada": "turturinar",
    "turturinadas": "turturinar",
    "turturinado": "turturinar",
    "turturinados": "turturinar",
    "turturinai": "turturinar",
    "turturinais": "turturinar",
    "turturinam": "turturinar",
    "turturinamo": "turturinar",
    "turturinamos": "turturinar",
    "turturinando": "turturinar",
    "turturinara": "turturinar",
    "turturinaram": "turturinar",
    "turturinaras": "turturinar",
    "turturinardes": "turturinar",
    "turturinarei": "turturinar",
    "turturinareis": "turturinar",
    "turturinarem": "turturinar",
    "turturinaremos": "turturinar",
    "turturinares": "turturinar",
    "turturinaria": "turturinar",
    "turturinariam": "turturinar",
    "turturinarias": "turturinar",
    "turturinarmo": "turturinar",
    "turturinarmos": "turturinar",
    "turturinará": "turturinar",
    "turturinarás": "turturinar",
    "turturinarão": "turturinar",
    "turturinaríamos": "turturinar",
    "turturinaríeis": "turturinar",
    "turturinas": "turturino",
    "turturinasse": "turturinar",
    "turturinassem": "turturinar",
    "turturinasses": "turturinar",
    "turturinaste": "turturinar",
    "turturinastes": "turturinar",
    "turturinava": "turturinar",
    "turturinavam": "turturinar",
    "turturinavas": "turturinar",
    "turturine": "turturinar",
    "turturinei": "turturinar",
    "turturineis": "turturinar",
    "turturinem": "turturinar",
    "turturinemo": "turturinar",
    "turturinemos": "turturinar",
    "turturines": "turturinar",
    "turturino": "turturinar",
    "turturinos": "turturino",
    "turturinou": "turturinar",
    "turturinámo": "turturinar",
    "turturinámos": "turturinar",
    "turturináramo": "turturinar",
    "turturináramos": "turturinar",
    "turturináreis": "turturinar",
    "turturinásseis": "turturinar",
    "turturinássemos": "turturinar",
    "turturinávamo": "turturinar",
    "turturinávamos": "turturinar",
    "turturináveis": "turturinar",
    "turva": "turvo",
    "turvada": "turvar",
    "turvadas": "turvar",
    "turvado": "turvar",
    "turvadora": "turvador",
    "turvadoras": "turvador",
    "turvadores": "turvador",
    "turvados": "turvar",
    "turvai": "turvar",
    "turvais": "turvar",
    "turvam": "turvar",
    "turvamentos": "turvamento",
    "turvamo": "turvar",
    "turvamos": "turvar",
    "turvando": "turvar",
    "turvara": "turvar",
    "turvaram": "turvar",
    "turvaras": "turvar",
    "turvarde": "turvar",
    "turvardes": "turvar",
    "turvare": "turvar",
    "turvarei": "turvar",
    "turvareis": "turvar",
    "turvarem": "turvar",
    "turvaremos": "turvar",
    "turvares": "turvar",
    "turvaria": "turvar",
    "turvariam": "turvar",
    "turvarias": "turvar",
    "turvarmo": "turvar",
    "turvarmos": "turvar",
    "turvará": "turvar",
    "turvarás": "turvar",
    "turvarão": "turvar",
    "turvaríamos": "turvar",
    "turvaríeis": "turvar",
    "turvas": "turvo",
    "turvasse": "turvar",
    "turvassem": "turvar",
    "turvasses": "turvar",
    "turvaste": "turvar",
    "turvastes": "turvar",
    "turvava": "turvar",
    "turvavam": "turvar",
    "turvavas": "turvar",
    "turvações": "turvação",
    "turve": "turvar",
    "turvei": "turvar",
    "turveis": "turvar",
    "turveja": "turvejar",
    "turvejada": "turvejar",
    "turvejadas": "turvejar",
    "turvejado": "turvejar",
    "turvejados": "turvejar",
    "turvejai": "turvejar",
    "turvejais": "turvejar",
    "turvejam": "turvejar",
    "turvejamo": "turvejar",
    "turvejamos": "turvejar",
    "turvejando": "turvejar",
    "turvejara": "turvejar",
    "turvejaram": "turvejar",
    "turvejaras": "turvejar",
    "turvejarde": "turvejar",
    "turvejardes": "turvejar",
    "turvejare": "turvejar",
    "turvejarei": "turvejar",
    "turvejareis": "turvejar",
    "turvejarem": "turvejar",
    "turvejaremos": "turvejar",
    "turvejares": "turvejar",
    "turvejaria": "turvejar",
    "turvejariam": "turvejar",
    "turvejarias": "turvejar",
    "turvejarmo": "turvejar",
    "turvejarmos": "turvejar",
    "turvejará": "turvejar",
    "turvejarás": "turvejar",
    "turvejarão": "turvejar",
    "turvejaríamos": "turvejar",
    "turvejaríeis": "turvejar",
    "turvejas": "turvejar",
    "turvejasse": "turvejar",
    "turvejassem": "turvejar",
    "turvejasses": "turvejar",
    "turvejaste": "turvejar",
    "turvejastes": "turvejar",
    "turvejava": "turvejar",
    "turvejavam": "turvejar",
    "turvejavas": "turvejar",
    "turveje": "turvejar",
    "turvejei": "turvejar",
    "turvejeis": "turvejar",
    "turvejem": "turvejar",
    "turvejemo": "turvejar",
    "turvejemos": "turvejar",
    "turvejes": "turvejar",
    "turvejo": "turvejar",
    "turvejou": "turvejar",
    "turvejá": "turvejar",
    "turvejámo": "turvejar",
    "turvejámos": "turvejar",
    "turvejáramo": "turvejar",
    "turvejáramos": "turvejar",
    "turvejárei": "turvejar",
    "turvejáreis": "turvejar",
    "turvejásseis": "turvejar",
    "turvejássemos": "turvejar",
    "turvejávamo": "turvejar",
    "turvejávamos": "turvejar",
    "turvejávei": "turvejar",
    "turvejáveis": "turvejar",
    "turvem": "turvar",
    "turvemo": "turvar",
    "turvemos": "turvar",
    "turves": "turvar",
    "turvinha": "turvo",
    "turvinhas": "turvo",
    "turvinho": "turvo",
    "turvinhos": "turvo",
    "turvita": "turvo",
    "turvitas": "turvo",
    "turvito": "turvo",
    "turvitos": "turvo",
    "turvo": "turvar",
    "turvos": "turvo",
    "turvou": "turvar",
    "turvá": "turvar",
    "turvámo": "turvar",
    "turvámos": "turvar",
    "turváramo": "turvar",
    "turváramos": "turvar",
    "turvárei": "turvar",
    "turváreis": "turvar",
    "turvásseis": "turvar",
    "turvássemos": "turvar",
    "turvávamo": "turvar",
    "turvávamos": "turvar",
    "turvávei": "turvar",
    "turváveis": "turvar",
    "turvíssima": "turvo",
    "turvíssimas": "turvo",
    "turvíssimo": "turvo",
    "turvíssimos": "turvo",
    "turânia": "turânio",
    "turânias": "turânio",
    "turânica": "turânico",
    "turânicas": "turânico",
    "turânicos": "turânico",
    "turânios": "turânio",
    "turíbulos": "turíbulo",
    "turícrema": "turícremo",
    "turícremas": "turícremo",
    "turícremos": "turícremo",
    "turífera": "turífero",
    "turíferas": "turífero",
    "turíferos": "turífero",
    "turística": "turístico",
    "turísticas": "turístico",
    "turísticos": "turístico",
    "tusculana": "tusculano",
    "tusculanas": "tusculano",
    "tusculanos": "tusculano",
    "tussa": "tossir",
    "tussais": "tossir",
    "tussam": "tossir",
    "tussamo": "tossir",
    "tussamos": "tossir",
    "tussas": "tossir",
    "tussico": "tossicar",
    "tussilagens": "tussilagem",
    "tussique": "tossicar",
    "tussiqueis": "tossicar",
    "tussiquem": "tossicar",
    "tussiquemo": "tossicar",
    "tussiquemos": "tossicar",
    "tussiques": "tossicar",
    "tusso": "tossir",
    "tusébios": "tusébio",
    "tutanos": "tutano",
    "tuteada": "tutear",
    "tuteadas": "tutear",
    "tuteado": "tutear",
    "tuteados": "tutear",
    "tuteai": "tutear",
    "tuteais": "tutear",
    "tuteamo": "tutear",
    "tuteamos": "tutear",
    "tuteando": "tutear",
    "tuteara": "tutear",
    "tutearam": "tutear",
    "tutearas": "tutear",
    "tutearde": "tutear",
    "tuteardes": "tutear",
    "tuteare": "tutear",
    "tutearei": "tutear",
    "tuteareis": "tutear",
    "tutearem": "tutear",
    "tutearemos": "tutear",
    "tuteares": "tutear",
    "tutearia": "tutear",
    "tuteariam": "tutear",
    "tutearias": "tutear",
    "tutearmo": "tutear",
    "tutearmos": "tutear",
    "tuteará": "tutear",
    "tutearás": "tutear",
    "tutearão": "tutear",
    "tutearíamos": "tutear",
    "tutearíeis": "tutear",
    "tuteasse": "tutear",
    "tuteassem": "tutear",
    "tuteasses": "tutear",
    "tuteaste": "tutear",
    "tuteastes": "tutear",
    "tuteava": "tutear",
    "tuteavam": "tutear",
    "tuteavas": "tutear",
    "tuteei": "tutear",
    "tuteeis": "tutear",
    "tuteemo": "tutear",
    "tuteemos": "tutear",
    "tuteia": "tutear",
    "tuteiam": "tutear",
    "tuteias": "tutear",
    "tuteie": "tutear",
    "tuteiem": "tutear",
    "tuteies": "tutear",
    "tuteio": "tutear",
    "tuteios": "tuteio",
    "tutela": "tutelar",
    "tutelada": "tutelar",
    "tuteladas": "tutelar",
    "tutelado": "tutelar",
    "tutelados": "tutelar",
    "tutelagens": "tutelagem",
    "tutelai": "tutelar",
    "tutelais": "tutelar",
    "tutelam": "tutelar",
    "tutelamo": "tutelar",
    "tutelamos": "tutelar",
    "tutelando": "tutelar",
    "tutelara": "tutelar",
    "tutelaram": "tutelar",
    "tutelaras": "tutelar",
    "tutelarde": "tutelar",
    "tutelardes": "tutelar",
    "tutelare": "tutelar",
    "tutelarei": "tutelar",
    "tutelareis": "tutelar",
    "tutelarem": "tutelar",
    "tutelaremos": "tutelar",
    "tutelares": "tutelar",
    "tutelaria": "tutelar",
    "tutelariam": "tutelar",
    "tutelarias": "tutelar",
    "tutelarmo": "tutelar",
    "tutelarmos": "tutelar",
    "tutelará": "tutelar",
    "tutelarás": "tutelar",
    "tutelarão": "tutelar",
    "tutelaríamos": "tutelar",
    "tutelaríeis": "tutelar",
    "tutelas": "tutelar",
    "tutelasse": "tutelar",
    "tutelassem": "tutelar",
    "tutelasses": "tutelar",
    "tutelaste": "tutelar",
    "tutelastes": "tutelar",
    "tutelava": "tutelar",
    "tutelavam": "tutelar",
    "tutelavas": "tutelar",
    "tutele": "tutelar",
    "tutelei": "tutelar",
    "tuteleis": "tutelar",
    "tutelem": "tutelar",
    "tutelemo": "tutelar",
    "tutelemos": "tutelar",
    "tuteles": "tutelar",
    "tutelo": "tutelar",
    "tutelou": "tutelar",
    "tutelá": "tutelar",
    "tutelámo": "tutelar",
    "tutelámos": "tutelar",
    "tuteláramo": "tutelar",
    "tuteláramos": "tutelar",
    "tutelárei": "tutelar",
    "tuteláreis": "tutelar",
    "tutelásseis": "tutelar",
    "tutelássemos": "tutelar",
    "tutelávamo": "tutelar",
    "tutelávamos": "tutelar",
    "tutelávei": "tutelar",
    "tuteláveis": "tutelável",
    "tuteou": "tutear",
    "tuteá": "tutear",
    "tuteámo": "tutear",
    "tuteámos": "tutear",
    "tuteáramo": "tutear",
    "tuteáramos": "tutear",
    "tuteárei": "tutear",
    "tuteáreis": "tutear",
    "tuteásseis": "tutear",
    "tuteássemos": "tutear",
    "tuteávamo": "tutear",
    "tuteávamos": "tutear",
    "tuteávei": "tutear",
    "tuteáveis": "tutear",
    "tutia": "tutiar",
    "tutiada": "tutiar",
    "tutiadas": "tutiar",
    "tutiado": "tutiar",
    "tutiados": "tutiar",
    "tutiai": "tutiar",
    "tutiais": "tutiar",
    "tutiam": "tutiar",
    "tutiamo": "tutiar",
    "tutiamos": "tutiar",
    "tutiando": "tutiar",
    "tutiara": "tutiar",
    "tutiaram": "tutiar",
    "tutiaras": "tutiar",
    "tutiardes": "tutiar",
    "tutiarei": "tutiar",
    "tutiareis": "tutiar",
    "tutiarem": "tutiar",
    "tutiaremos": "tutiar",
    "tutiares": "tutiar",
    "tutiaria": "tutiar",
    "tutiariam": "tutiar",
    "tutiarias": "tutiar",
    "tutiarmo": "tutiar",
    "tutiarmos": "tutiar",
    "tutiará": "tutiar",
    "tutiarás": "tutiar",
    "tutiarão": "tutiar",
    "tutiaríamos": "tutiar",
    "tutiaríeis": "tutiar",
    "tutias": "tutiar",
    "tutiasse": "tutiar",
    "tutiassem": "tutiar",
    "tutiasses": "tutiar",
    "tutiaste": "tutiar",
    "tutiastes": "tutiar",
    "tutiava": "tutiar",
    "tutiavam": "tutiar",
    "tutiavas": "tutiar",
    "tutie": "tutiar",
    "tutiei": "tutiar",
    "tutieis": "tutiar",
    "tutiem": "tutiar",
    "tutiemo": "tutiar",
    "tutiemos": "tutiar",
    "tuties": "tutiar",
    "tutilimúndis": "tutilimúndi",
    "tutina": "tutino",
    "tutinas": "tutino",
    "tutinegras": "tutinegra",
    "tutinegros": "tutinegro",
    "tutinos": "tutino",
    "tutio": "tutiar",
    "tutiou": "tutiar",
    "tutiámo": "tutiar",
    "tutiámos": "tutiar",
    "tutiáramo": "tutiar",
    "tutiáramos": "tutiar",
    "tutiáreis": "tutiar",
    "tutiásseis": "tutiar",
    "tutiássemos": "tutiar",
    "tutiávamo": "tutiar",
    "tutiávamos": "tutiar",
    "tutiáveis": "tutiar",
    "tutora": "tutorar",
    "tutorada": "tutorar",
    "tutoradas": "tutorar",
    "tutorado": "tutorar",
    "tutorados": "tutorar",
    "tutorai": "tutorar",
    "tutorais": "tutorar",
    "tutoram": "tutorar",
    "tutoramo": "tutorar",
    "tutoramos": "tutorar",
    "tutorando": "tutorar",
    "tutorara": "tutorar",
    "tutoraram": "tutorar",
    "tutoraras": "tutorar",
    "tutorarde": "tutorar",
    "tutorardes": "tutorar",
    "tutorare": "tutorar",
    "tutorarei": "tutorar",
    "tutorareis": "tutorar",
    "tutorarem": "tutorar",
    "tutoraremos": "tutorar",
    "tutorares": "tutorar",
    "tutoraria": "tutorar",
    "tutorariam": "tutorar",
    "tutorarias": "tutorar",
    "tutorarmo": "tutorar",
    "tutorarmos": "tutorar",
    "tutorará": "tutorar",
    "tutorarás": "tutorar",
    "tutorarão": "tutorar",
    "tutoraríamos": "tutorar",
    "tutoraríeis": "tutorar",
    "tutoras": "tutorar",
    "tutorasse": "tutorar",
    "tutorassem": "tutorar",
    "tutorasses": "tutorar",
    "tutoraste": "tutorar",
    "tutorastes": "tutorar",
    "tutorava": "tutorar",
    "tutoravam": "tutorar",
    "tutoravas": "tutorar",
    "tutore": "tutorar",
    "tutoreada": "tutorear",
    "tutoreadas": "tutorear",
    "tutoreado": "tutorear",
    "tutoreados": "tutorear",
    "tutoreai": "tutorear",
    "tutoreais": "tutorear",
    "tutoreamo": "tutorear",
    "tutoreamos": "tutorear",
    "tutoreando": "tutorear",
    "tutoreara": "tutorear",
    "tutorearam": "tutorear",
    "tutorearas": "tutorear",
    "tutorearde": "tutorear",
    "tutoreardes": "tutorear",
    "tutoreare": "tutorear",
    "tutorearei": "tutorear",
    "tutoreareis": "tutorear",
    "tutorearem": "tutorear",
    "tutorearemos": "tutorear",
    "tutoreares": "tutorear",
    "tutorearia": "tutorear",
    "tutoreariam": "tutorear",
    "tutorearias": "tutorear",
    "tutorearmo": "tutorear",
    "tutorearmos": "tutorear",
    "tutoreará": "tutorear",
    "tutorearás": "tutorear",
    "tutorearão": "tutorear",
    "tutorearíamos": "tutorear",
    "tutorearíeis": "tutorear",
    "tutoreasse": "tutorear",
    "tutoreassem": "tutorear",
    "tutoreasses": "tutorear",
    "tutoreaste": "tutorear",
    "tutoreastes": "tutorear",
    "tutoreava": "tutorear",
    "tutoreavam": "tutorear",
    "tutoreavas": "tutorear",
    "tutoreei": "tutorear",
    "tutoreeis": "tutorear",
    "tutoreemo": "tutorear",
    "tutoreemos": "tutorear",
    "tutorei": "tutorar",
    "tutoreia": "tutorear",
    "tutoreiam": "tutorear",
    "tutoreias": "tutorear",
    "tutoreie": "tutorear",
    "tutoreiem": "tutorear",
    "tutoreies": "tutorear",
    "tutoreio": "tutorear",
    "tutoreis": "tutorar",
    "tutorem": "tutorar",
    "tutoremo": "tutorar",
    "tutoremos": "tutorar",
    "tutoreou": "tutorear",
    "tutores": "tutorar",
    "tutoreá": "tutorear",
    "tutoreámo": "tutorear",
    "tutoreámos": "tutorear",
    "tutoreáramo": "tutorear",
    "tutoreáramos": "tutorear",
    "tutoreárei": "tutorear",
    "tutoreáreis": "tutorear",
    "tutoreásseis": "tutorear",
    "tutoreássemos": "tutorear",
    "tutoreávamo": "tutorear",
    "tutoreávamos": "tutorear",
    "tutoreávei": "tutorear",
    "tutoreáveis": "tutoreável",
    "tutoriais": "tutorial",
    "tutorias": "tutoria",
    "tutoro": "tutorar",
    "tutorou": "tutorar",
    "tutorá": "tutorar",
    "tutorámo": "tutorar",
    "tutorámos": "tutorar",
    "tutoráramo": "tutorar",
    "tutoráramos": "tutorar",
    "tutorárei": "tutorar",
    "tutoráreis": "tutorar",
    "tutorásseis": "tutorar",
    "tutorássemos": "tutorar",
    "tutorávamo": "tutorar",
    "tutorávamos": "tutorar",
    "tutorávei": "tutorar",
    "tutoráveis": "tutorar",
    "tutos": "tuto",
    "tutsis": "tutsi",
    "tutus": "tutu",
    "tutáculos": "tutáculo",
    "tutória": "tutório",
    "tutórias": "tutório",
    "tutórios": "tutório",
    "tutões": "tutão",
    "tuvinos": "tuvino",
    "tuzas": "tuza",
    "tuís": "tuí",
    "tvs": "tv",
    "tzares": "tzar",
    "tzarina": "tzar",
    "tzarinas": "tzar",
    "tábica": "tábico",
    "tábicas": "tábico",
    "tábicos": "tábico",
    "tábuas": "tábua",
    "tábulas": "tábula",
    "tácita": "tácito",
    "tácitas": "tácito",
    "tácitos": "tácito",
    "tácteis": "táctil",
    "táctica": "táctico",
    "tácticas": "táctico",
    "tácticos": "táctico",
    "tádegas": "tádega",
    "tágides": "tágide",
    "táguedas": "tágueda",
    "tálamos": "tálamo",
    "táleres": "táler",
    "tálios": "tálio",
    "tálitros": "tálitro",
    "tápsias": "tápsia",
    "tármica": "tármico",
    "tármicas": "tármico",
    "tármicos": "tármico",
    "társica": "társico",
    "társicas": "társico",
    "társicos": "társico",
    "társios": "társio",
    "tártagos": "tártago",
    "tártara": "tártaro",
    "tártaras": "tártaro",
    "tártaros": "tártaro",
    "tátara": "tátaro",
    "tátaras": "tátaro",
    "tátaros": "tátaro",
    "táurea": "táureo",
    "táureas": "táureo",
    "táureos": "táureo",
    "távedas": "táveda",
    "távegas": "távega",
    "távoas": "távoa",
    "távolas": "távola",
    "táxis": "táxi",
    "tâmaras": "tâmara",
    "tâmis": "tâmil",
    "tâmpona": "tâmpão",
    "tâmponas": "tâmpão",
    "tâmpões": "tâmpão",
    "tâmuis": "tâmul",
    "tânagras": "tânagra",
    "tânica": "tânico",
    "tânicas": "tânico",
    "tânicos": "tânico",
    "tânjaras": "tânjara",
    "tânjaros": "tânjaro",
    "tântalos": "tântalo",
    "tântrica": "tântrico",
    "tântricas": "tântrico",
    "tântricos": "tântrico",
    "tçares": "tçar",
    "tçarina": "tçar",
    "tçarinas": "tçar",
    "técnica": "técnico",
    "técnicas": "técnico",
    "técnicos": "técnico",
    "tédios": "tédio",
    "tégmenes": "tégmen",
    "tégulas": "tégula",
    "téjidas": "téjida",
    "télamones": "télamon",
    "télsons": "télson",
    "témens": "témen",
    "ténias": "ténia",
    "ténues": "ténue",
    "tépalas": "tépala",
    "tépida": "tépido",
    "tépidas": "tépido",
    "tépidos": "tépido",
    "térbios": "térbio",
    "tércias": "tércia",
    "tércios": "tércio",
    "térebras": "térebra",
    "térmica": "térmico",
    "térmicas": "térmico",
    "térmicos": "térmico",
    "términos": "término",
    "térmita": "térmite",
    "térmitas": "térmite",
    "térmites": "térmite",
    "térmodos": "térmodo",
    "térrea": "térreo",
    "térreas": "térreo",
    "térreos": "térreo",
    "tésseras": "téssera",
    "tétanos": "tétano",
    "tética": "tético",
    "téticas": "tético",
    "téticos": "tético",
    "tétradas": "tétrada",
    "tétrates": "tétrate",
    "tétrica": "tétrico",
    "tétricas": "tétrico",
    "tétricos": "tétrico",
    "tétrodos": "tétrodo",
    "tétuns": "tétum",
    "téxteis": "téxtil",
    "tê": "ter",
    "têm": "ter",
    "têmperas": "têmpera",
    "têmporas": "têmpora",
    "tênares": "tênar",
    "tênderes": "tênder",
    "têneis": "tênil",
    "tês": "tê",
    "têxteis": "têxtil",
    "tíbia": "tíbio",
    "tíbias": "tíbio",
    "tíbios": "tíbio",
    "tífica": "tífico",
    "tíficas": "tífico",
    "tíficos": "tífico",
    "tílburis": "tílburi",
    "tíleas": "tílea",
    "tílias": "tília",
    "tímbrica": "tímbrico",
    "tímbricas": "tímbrico",
    "tímbricos": "tímbrico",
    "tímica": "tímico",
    "tímicas": "tímico",
    "tímicos": "tímico",
    "tímida": "tímido",
    "tímidas": "tímido",
    "tímidos": "tímido",
    "tímpanos": "tímpano",
    "tíneas": "tínea",
    "tínhamo": "ter",
    "tínhamos": "ter",
    "tínhei": "ter",
    "tínheis": "ter",
    "típica": "típico",
    "típicas": "típico",
    "típicos": "típico",
    "tíria": "tírio",
    "tírias": "tírio",
    "tírios": "tírio",
    "tísica": "tísico",
    "tísicas": "tísico",
    "tísicos": "tísico",
    "títeres": "títere",
    "títulos": "título",
    "tódidas": "tódida",
    "tónica": "tónico",
    "tónicas": "tónico",
    "tónicos": "tónico",
    "tópias": "tópia",
    "tópica": "tópico",
    "tópicas": "tópico",
    "tópicos": "tópico",
    "tóraxes": "tórax",
    "tórculos": "tórculo",
    "tórios": "tório",
    "tórpida": "tórpido",
    "tórpidas": "tórpido",
    "tórpidos": "tórpido",
    "tórrida": "tórrido",
    "tórridas": "tórrido",
    "tórridos": "tórrido",
    "tórulos": "tórulo",
    "tóxica": "tóxico",
    "tóxicas": "tóxico",
    "tóxicos": "tóxico",
    "tômbolas": "tômbola",
    "tômbolos": "tômbolo",
    "tôs": "tô",
    "túbaras": "túbara",
    "túberas": "túbera",
    "túlios": "túlio",
    "túlipas": "túlipa",
    "túmida": "túmido",
    "túmidas": "túmido",
    "túmidos": "túmido",
    "túmulos": "túmulo",
    "túndrica": "túndrico",
    "túndricas": "túndrico",
    "túndricos": "túndrico",
    "túneis": "túnel",
    "túnicas": "túnica",
    "túrbida": "túrbido",
    "túrbidas": "túrbido",
    "túrbidos": "túrbido",
    "túrdidas": "túrdida",
    "túrdula": "túrdulo",
    "túrdulas": "túrdulo",
    "túrdulos": "túrdulo",
    "túrgida": "túrgido",
    "túrgidas": "túrgido",
    "túrgidos": "túrgido",
    "túrnepos": "túrnepo",
    "túrpida": "túrpido",
    "túrpidas": "túrpido",
    "túrpidos": "túrpido",
    "tútulos": "tútulo",
    "uacaris": "uacari",
    "uadadás": "uadadá",
    "uanambés": "uanambé",
    "uariquinas": "uariquina",
    "uariás": "uariá",
    "uarubés": "uarubé",
    "uarurembóias": "uarurembóia",
    "uatupus": "uatupu",
    "uauaçus": "uauaçu",
    "ubacabas": "ubacaba",
    "ubaenses": "ubaense",
    "ubangos": "ubango",
    "ubaranas": "ubarana",
    "ubatãs": "ubatã",
    "ubera": "uberar",
    "uberada": "uberar",
    "uberadas": "uberar",
    "uberado": "uberar",
    "uberados": "uberar",
    "uberai": "uberar",
    "uberais": "uberar",
    "uberam": "uberar",
    "uberamo": "uberar",
    "uberamos": "uberar",
    "uberando": "uberar",
    "uberara": "uberar",
    "uberaram": "uberar",
    "uberaras": "uberar",
    "uberarde": "uberar",
    "uberardes": "uberar",
    "uberare": "uberar",
    "uberarei": "uberar",
    "uberareis": "uberar",
    "uberarem": "uberar",
    "uberaremos": "uberar",
    "uberares": "uberar",
    "uberaria": "uberar",
    "uberariam": "uberar",
    "uberarias": "uberar",
    "uberarmo": "uberar",
    "uberarmos": "uberar",
    "uberará": "uberar",
    "uberarás": "uberar",
    "uberarão": "uberar",
    "uberaríamos": "uberar",
    "uberaríeis": "uberar",
    "uberas": "uberar",
    "uberasse": "uberar",
    "uberassem": "uberar",
    "uberasses": "uberar",
    "uberaste": "uberar",
    "uberastes": "uberar",
    "uberava": "uberar",
    "uberavam": "uberar",
    "uberavas": "uberar",
    "uberdades": "uberdade",
    "ubere": "uberar",
    "uberei": "uberar",
    "ubereis": "uberar",
    "uberem": "uberar",
    "uberemo": "uberar",
    "uberemos": "uberar",
    "uberes": "uberar",
    "ubero": "uberar",
    "uberosa": "uberoso",
    "uberosas": "uberoso",
    "uberosos": "uberoso",
    "uberou": "uberar",
    "uberá": "uberar",
    "uberámo": "uberar",
    "uberámos": "uberar",
    "uberáramo": "uberar",
    "uberáramos": "uberar",
    "uberárei": "uberar",
    "uberáreis": "uberar",
    "uberásseis": "uberar",
    "uberássemos": "uberar",
    "uberávamo": "uberar",
    "uberávamos": "uberar",
    "uberávei": "uberar",
    "uberáveis": "uberável",
    "uberérrima": "úbere",
    "uberérrimas": "úbere",
    "uberérrimo": "úbere",
    "uberérrimos": "úbere",
    "ubiangangas": "ubianganga",
    "ubimirins": "ubimirim",
    "ubins": "ubim",
    "ubiquidades": "ubiquidade",
    "ubiquistas": "ubiquista",
    "ubiquitária": "ubiquitário",
    "ubiquitárias": "ubiquitário",
    "ubiquitários": "ubiquitário",
    "ubiracicás": "ubiracicá",
    "ubis": "ubi",
    "ubás": "ubá",
    "ubíqua": "ubíquo",
    "ubíquas": "ubíquo",
    "ubíquos": "ubíquo",
    "ucasses": "ucasse",
    "ucharias": "ucharia",
    "uchas": "ucha",
    "uchona": "uchão",
    "uchonas": "uchão",
    "uchões": "uchão",
    "ucraniana": "ucraniano",
    "ucranianas": "ucraniano",
    "ucranianos": "ucraniano",
    "ucronias": "ucronia",
    "ucuubas": "ucuuba",
    "ucuubeiras": "ucuubeira",
    "uda": "udo",
    "udas": "udo",
    "udometrias": "udometria",
    "udométrica": "udométrico",
    "udométricas": "udométrico",
    "udométricos": "udométrico",
    "udos": "udo",
    "udus": "udu",
    "udómetros": "udómetro",
    "ufana": "ufano",
    "ufanada": "ufanar",
    "ufanadas": "ufanar",
    "ufanado": "ufanar",
    "ufanados": "ufanar",
    "ufanai": "ufanar",
    "ufanais": "ufanar",
    "ufanam": "ufanar",
    "ufanamo": "ufanar",
    "ufanamos": "ufanar",
    "ufanando": "ufanar",
    "ufanara": "ufanar",
    "ufanaram": "ufanar",
    "ufanaras": "ufanar",
    "ufanarde": "ufanar",
    "ufanardes": "ufanar",
    "ufanare": "ufanar",
    "ufanarei": "ufanar",
    "ufanareis": "ufanar",
    "ufanarem": "ufanar",
    "ufanaremos": "ufanar",
    "ufanares": "ufanar",
    "ufanaria": "ufanar",
    "ufanariam": "ufanar",
    "ufanarias": "ufanar",
    "ufanarmo": "ufanar",
    "ufanarmos": "ufanar",
    "ufanará": "ufanar",
    "ufanarás": "ufanar",
    "ufanarão": "ufanar",
    "ufanaríamos": "ufanar",
    "ufanaríeis": "ufanar",
    "ufanas": "ufano",
    "ufanasse": "ufanar",
    "ufanassem": "ufanar",
    "ufanasses": "ufanar",
    "ufanaste": "ufanar",
    "ufanastes": "ufanar",
    "ufanava": "ufanar",
    "ufanavam": "ufanar",
    "ufanavas": "ufanar",
    "ufane": "ufanar",
    "ufanei": "ufanar",
    "ufaneis": "ufanar",
    "ufanem": "ufanar",
    "ufanemo": "ufanar",
    "ufanemos": "ufanar",
    "ufanes": "ufanar",
    "ufanias": "ufania",
    "ufano": "ufanar",
    "ufanos": "ufano",
    "ufanosa": "ufanoso",
    "ufanosas": "ufanoso",
    "ufanosos": "ufanoso",
    "ufanou": "ufanar",
    "ufaná": "ufanar",
    "ufanámo": "ufanar",
    "ufanámos": "ufanar",
    "ufanáramo": "ufanar",
    "ufanáramos": "ufanar",
    "ufanárei": "ufanar",
    "ufanáreis": "ufanar",
    "ufanásseis": "ufanar",
    "ufanássemos": "ufanar",
    "ufanávamo": "ufanar",
    "ufanávamos": "ufanar",
    "ufanávei": "ufanar",
    "ufanáveis": "ufanável",
    "ufaníssima": "ufano",
    "ufaníssimas": "ufano",
    "ufaníssimo": "ufano",
    "ufaníssimos": "ufano",
    "ufas": "ufa",
    "uga": "ugar",
    "ugabes": "ugabe",
    "ugada": "ugar",
    "ugadas": "ugar",
    "ugado": "ugar",
    "ugados": "ugar",
    "ugadíssima": "ugado",
    "ugadíssimas": "ugado",
    "ugadíssimo": "ugado",
    "ugadíssimos": "ugado",
    "ugai": "ugar",
    "ugais": "ugar",
    "ugalha": "ugalhar",
    "ugalhada": "ugalhar",
    "ugalhadas": "ugalhar",
    "ugalhado": "ugalhar",
    "ugalhados": "ugalhar",
    "ugalhai": "ugalhar",
    "ugalhais": "ugalhar",
    "ugalham": "ugalhar",
    "ugalhamo": "ugalhar",
    "ugalhamos": "ugalhar",
    "ugalhando": "ugalhar",
    "ugalhara": "ugalhar",
    "ugalharam": "ugalhar",
    "ugalharas": "ugalhar",
    "ugalharde": "ugalhar",
    "ugalhardes": "ugalhar",
    "ugalhare": "ugalhar",
    "ugalharei": "ugalhar",
    "ugalhareis": "ugalhar",
    "ugalharem": "ugalhar",
    "ugalharemos": "ugalhar",
    "ugalhares": "ugalhar",
    "ugalharia": "ugalhar",
    "ugalhariam": "ugalhar",
    "ugalharias": "ugalhar",
    "ugalharmo": "ugalhar",
    "ugalharmos": "ugalhar",
    "ugalhará": "ugalhar",
    "ugalharás": "ugalhar",
    "ugalharão": "ugalhar",
    "ugalharíamos": "ugalhar",
    "ugalharíeis": "ugalhar",
    "ugalhas": "ugalhar",
    "ugalhasse": "ugalhar",
    "ugalhassem": "ugalhar",
    "ugalhasses": "ugalhar",
    "ugalhaste": "ugalhar",
    "ugalhastes": "ugalhar",
    "ugalhava": "ugalhar",
    "ugalhavam": "ugalhar",
    "ugalhavas": "ugalhar",
    "ugalhe": "ugalhar",
    "ugalhei": "ugalhar",
    "ugalheis": "ugalhar",
    "ugalhem": "ugalhar",
    "ugalhemo": "ugalhar",
    "ugalhemos": "ugalhar",
    "ugalhes": "ugalhar",
    "ugalho": "ugalhar",
    "ugalhos": "ugalho",
    "ugalhou": "ugalhar",
    "ugalhá": "ugalhar",
    "ugalhámo": "ugalhar",
    "ugalhámos": "ugalhar",
    "ugalháramo": "ugalhar",
    "ugalháramos": "ugalhar",
    "ugalhárei": "ugalhar",
    "ugalháreis": "ugalhar",
    "ugalhásseis": "ugalhar",
    "ugalhássemos": "ugalhar",
    "ugalhávamo": "ugalhar",
    "ugalhávamos": "ugalhar",
    "ugalhávei": "ugalhar",
    "ugalháveis": "ugalhável",
    "ugam": "ugar",
    "ugamo": "ugar",
    "ugamos": "ugar",
    "ugandesa": "ugandês",
    "ugandesas": "ugandês",
    "ugandeses": "ugandês",
    "ugando": "ugar",
    "ugara": "ugar",
    "ugaram": "ugar",
    "ugaras": "ugar",
    "ugarde": "ugar",
    "ugardes": "ugar",
    "ugare": "ugar",
    "ugarei": "ugar",
    "ugareis": "ugar",
    "ugarem": "ugar",
    "ugaremos": "ugar",
    "ugares": "ugar",
    "ugaria": "ugar",
    "ugariam": "ugar",
    "ugarias": "ugar",
    "ugarmo": "ugar",
    "ugarmos": "ugar",
    "ugará": "ugar",
    "ugarás": "ugar",
    "ugarão": "ugar",
    "ugaríamos": "ugar",
    "ugaríeis": "ugar",
    "ugarítica": "ugarítico",
    "ugaríticas": "ugarítico",
    "ugaríticos": "ugarítico",
    "ugas": "ugar",
    "ugasse": "ugar",
    "ugassem": "ugar",
    "ugasses": "ugar",
    "ugaste": "ugar",
    "ugastes": "ugar",
    "ugava": "ugar",
    "ugavam": "ugar",
    "ugavas": "ugar",
    "ugo": "ugar",
    "ugolina": "ugolino",
    "ugolinas": "ugolino",
    "ugolinesca": "ugolinesco",
    "ugolinescas": "ugolinesco",
    "ugolinescos": "ugolinesco",
    "ugolinos": "ugolino",
    "ugou": "ugar",
    "ugros": "ugro",
    "ugue": "ugar",
    "uguei": "ugar",
    "ugueis": "ugar",
    "uguem": "ugar",
    "uguemo": "ugar",
    "uguemos": "ugar",
    "ugues": "ugar",
    "ugá": "ugar",
    "ugámo": "ugar",
    "ugámos": "ugar",
    "ugáramo": "ugar",
    "ugáramos": "ugar",
    "ugárei": "ugar",
    "ugáreis": "ugar",
    "ugásseis": "ugar",
    "ugássemos": "ugar",
    "ugávamo": "ugar",
    "ugávamos": "ugar",
    "ugávei": "ugar",
    "ugáveis": "ugável",
    "uiaras": "uiara",
    "uigures": "uigure",
    "uigúrica": "uigúrico",
    "uigúricas": "uigúrico",
    "uigúricos": "uigúrico",
    "uiofobias": "uiofobia",
    "uirapurus": "uirapuru",
    "uiraris": "uirari",
    "uisques": "uisque",
    "uiva": "uivar",
    "uivada": "uivar",
    "uivadas": "uivar",
    "uivado": "uivar",
    "uivadora": "uivador",
    "uivadoras": "uivador",
    "uivadores": "uivador",
    "uivados": "uivar",
    "uivadíssima": "uivado",
    "uivadíssimas": "uivado",
    "uivadíssimo": "uivado",
    "uivadíssimos": "uivado",
    "uivai": "uivar",
    "uivais": "uivar",
    "uivam": "uivar",
    "uivamo": "uivar",
    "uivamos": "uivar",
    "uivando": "uivar",
    "uivara": "uivar",
    "uivaram": "uivar",
    "uivaras": "uivar",
    "uivardes": "uivar",
    "uivarei": "uivar",
    "uivareis": "uivar",
    "uivarem": "uivar",
    "uivaremos": "uivar",
    "uivares": "uivar",
    "uivaria": "uivar",
    "uivariam": "uivar",
    "uivarias": "uivar",
    "uivarmo": "uivar",
    "uivarmos": "uivar",
    "uivará": "uivar",
    "uivarás": "uivar",
    "uivarão": "uivar",
    "uivaríamos": "uivar",
    "uivaríeis": "uivar",
    "uivas": "uivar",
    "uivasse": "uivar",
    "uivassem": "uivar",
    "uivasses": "uivar",
    "uivaste": "uivar",
    "uivastes": "uivar",
    "uivava": "uivar",
    "uivavam": "uivar",
    "uivavas": "uivar",
    "uive": "uivar",
    "uivei": "uivar",
    "uiveis": "uivar",
    "uivem": "uivar",
    "uivemo": "uivar",
    "uivemos": "uivar",
    "uives": "uivar",
    "uivo": "uivar",
    "uivos": "uivo",
    "uivou": "uivar",
    "uivámo": "uivar",
    "uivámos": "uivar",
    "uiváramo": "uivar",
    "uiváramos": "uivar",
    "uiváreis": "uivar",
    "uivásseis": "uivar",
    "uivássemos": "uivar",
    "uivávamo": "uivar",
    "uivávamos": "uivar",
    "uiváveis": "uivável",
    "ujas": "uja",
    "ujes": "uje",
    "ujicas": "ujica",
    "ujos": "ujo",
    "ulalgias": "ulalgia",
    "ulanos": "ulano",
    "ulcera": "ulcerar",
    "ulcerada": "ulcerar",
    "ulceradas": "ulcerar",
    "ulcerado": "ulcerar",
    "ulcerados": "ulcerar",
    "ulceradíssima": "ulcerado",
    "ulceradíssimas": "ulcerado",
    "ulceradíssimo": "ulcerado",
    "ulceradíssimos": "ulcerado",
    "ulcerai": "ulcerar",
    "ulcerais": "ulcerar",
    "ulceram": "ulcerar",
    "ulceramo": "ulcerar",
    "ulceramos": "ulcerar",
    "ulcerando": "ulcerar",
    "ulcerara": "ulcerar",
    "ulceraram": "ulcerar",
    "ulceraras": "ulcerar",
    "ulcerarde": "ulcerar",
    "ulcerardes": "ulcerar",
    "ulcerare": "ulcerar",
    "ulcerarei": "ulcerar",
    "ulcerareis": "ulcerar",
    "ulcerarem": "ulcerar",
    "ulceraremos": "ulcerar",
    "ulcerares": "ulcerar",
    "ulceraria": "ulcerar",
    "ulcerariam": "ulcerar",
    "ulcerarias": "ulcerar",
    "ulcerarmo": "ulcerar",
    "ulcerarmos": "ulcerar",
    "ulcerará": "ulcerar",
    "ulcerarás": "ulcerar",
    "ulcerarão": "ulcerar",
    "ulceraríamos": "ulcerar",
    "ulceraríeis": "ulcerar",
    "ulceras": "ulcerar",
    "ulcerasse": "ulcerar",
    "ulcerassem": "ulcerar",
    "ulcerasses": "ulcerar",
    "ulceraste": "ulcerar",
    "ulcerastes": "ulcerar",
    "ulcerativa": "ulcerativo",
    "ulcerativas": "ulcerativo",
    "ulcerativos": "ulcerativo",
    "ulcerava": "ulcerar",
    "ulceravam": "ulcerar",
    "ulceravas": "ulcerar",
    "ulcerações": "ulceração",
    "ulcere": "ulcerar",
    "ulcerei": "ulcerar",
    "ulcereis": "ulcerar",
    "ulcerem": "ulcerar",
    "ulceremo": "ulcerar",
    "ulceremos": "ulcerar",
    "ulceres": "ulcerar",
    "ulcero": "ulcerar",
    "ulcerosa": "ulceroso",
    "ulcerosas": "ulceroso",
    "ulcerosos": "ulceroso",
    "ulcerou": "ulcerar",
    "ulcerá": "ulcerar",
    "ulcerámo": "ulcerar",
    "ulcerámos": "ulcerar",
    "ulceráramo": "ulcerar",
    "ulceráramos": "ulcerar",
    "ulcerárei": "ulcerar",
    "ulceráreis": "ulcerar",
    "ulcerásseis": "ulcerar",
    "ulcerássemos": "ulcerar",
    "ulcerávamo": "ulcerar",
    "ulcerávamos": "ulcerar",
    "ulcerávei": "ulcerar",
    "ulceráveis": "ulcerável",
    "ulceróides": "ulceróide",
    "ulcóides": "ulcóide",
    "ulemás": "ulemá",
    "uliginosa": "uliginoso",
    "uliginosas": "uliginoso",
    "uliginosos": "uliginoso",
    "uliginária": "uliginário",
    "uliginárias": "uliginário",
    "uliginários": "uliginário",
    "ulisseia": "ulisseu",
    "ulisseias": "ulisseu",
    "ulisseus": "ulisseu",
    "ulissiponenses": "ulissiponense",
    "ulites": "ulite",
    "ulmarinas": "ulmarina",
    "ulmeiras": "ulmeira",
    "ulmeiros": "ulmeiro",
    "ulmos": "ulmo",
    "ulmácea": "ulmáceo",
    "ulmáceas": "ulmáceo",
    "ulmáceos": "ulmáceo",
    "ulmárias": "ulmária",
    "ulnais": "ulnal",
    "ulnares": "ulnar",
    "ulnas": "ulna",
    "ulnária": "ulnário",
    "ulnárias": "ulnário",
    "ulnários": "ulnário",
    "uloatrofias": "uloatrofia",
    "ulomas": "uloma",
    "ulos": "ulo",
    "ulta": "ulto",
    "ultas": "ulto",
    "ulteriores": "ulterior",
    "ulterioridades": "ulterioridade",
    "ultima": "ultimar",
    "ultimada": "ultimar",
    "ultimadas": "ultimar",
    "ultimado": "ultimar",
    "ultimadora": "ultimador",
    "ultimadoras": "ultimador",
    "ultimadores": "ultimador",
    "ultimados": "ultimar",
    "ultimadíssima": "ultimado",
    "ultimadíssimas": "ultimado",
    "ultimadíssimo": "ultimado",
    "ultimadíssimos": "ultimado",
    "ultimai": "ultimar",
    "ultimais": "ultimar",
    "ultimam": "ultimar",
    "ultimamo": "ultimar",
    "ultimamos": "ultimar",
    "ultimando": "ultimar",
    "ultimara": "ultimar",
    "ultimaram": "ultimar",
    "ultimaras": "ultimar",
    "ultimarde": "ultimar",
    "ultimardes": "ultimar",
    "ultimare": "ultimar",
    "ultimarei": "ultimar",
    "ultimareis": "ultimar",
    "ultimarem": "ultimar",
    "ultimaremos": "ultimar",
    "ultimares": "ultimar",
    "ultimaria": "ultimar",
    "ultimariam": "ultimar",
    "ultimarias": "ultimar",
    "ultimarmo": "ultimar",
    "ultimarmos": "ultimar",
    "ultimará": "ultimar",
    "ultimarás": "ultimar",
    "ultimarão": "ultimar",
    "ultimaríamos": "ultimar",
    "ultimaríeis": "ultimar",
    "ultimas": "ultimar",
    "ultimasse": "ultimar",
    "ultimassem": "ultimar",
    "ultimasses": "ultimar",
    "ultimaste": "ultimar",
    "ultimastes": "ultimar",
    "ultimatos": "ultimato",
    "ultimatuns": "ultimatum",
    "ultimava": "ultimar",
    "ultimavam": "ultimar",
    "ultimavas": "ultimar",
    "ultimações": "ultimação",
    "ultime": "ultimar",
    "ultimei": "ultimar",
    "ultimeis": "ultimar",
    "ultimem": "ultimar",
    "ultimemo": "ultimar",
    "ultimemos": "ultimar",
    "ultimes": "ultimar",
    "ultimo": "ultimar",
    "ultimogénita": "ultimogénito",
    "ultimogénitas": "ultimogénito",
    "ultimogénitos": "ultimogénito",
    "ultimou": "ultimar",
    "ultimá": "ultimar",
    "ultimámo": "ultimar",
    "ultimámos": "ultimar",
    "ultimáramo": "ultimar",
    "ultimáramos": "ultimar",
    "ultimárei": "ultimar",
    "ultimáreis": "ultimar",
    "ultimásseis": "ultimar",
    "ultimássemos": "ultimar",
    "ultimávamo": "ultimar",
    "ultimávamos": "ultimar",
    "ultimávei": "ultimar",
    "ultimáveis": "ultimável",
    "ultora": "ultor",
    "ultoras": "ultor",
    "ultores": "ultor",
    "ultos": "ulto",
    "ultrabásica": "ultrabásico",
    "ultrabásicas": "ultrabásico",
    "ultrabásicos": "ultrabásico",
    "ultracentrifuga": "ultracentrifugar",
    "ultracentrifugada": "ultracentrifugar",
    "ultracentrifugadas": "ultracentrifugar",
    "ultracentrifugado": "ultracentrifugar",
    "ultracentrifugados": "ultracentrifugar",
    "ultracentrifugai": "ultracentrifugar",
    "ultracentrifugais": "ultracentrifugar",
    "ultracentrifugam": "ultracentrifugar",
    "ultracentrifugamo": "ultracentrifugar",
    "ultracentrifugamos": "ultracentrifugar",
    "ultracentrifugando": "ultracentrifugar",
    "ultracentrifugara": "ultracentrifugar",
    "ultracentrifugaram": "ultracentrifugar",
    "ultracentrifugaras": "ultracentrifugar",
    "ultracentrifugarde": "ultracentrifugar",
    "ultracentrifugardes": "ultracentrifugar",
    "ultracentrifugare": "ultracentrifugar",
    "ultracentrifugarei": "ultracentrifugar",
    "ultracentrifugareis": "ultracentrifugar",
    "ultracentrifugarem": "ultracentrifugar",
    "ultracentrifugaremos": "ultracentrifugar",
    "ultracentrifugares": "ultracentrifugar",
    "ultracentrifugaria": "ultracentrifugar",
    "ultracentrifugariam": "ultracentrifugar",
    "ultracentrifugarias": "ultracentrifugar",
    "ultracentrifugarmo": "ultracentrifugar",
    "ultracentrifugarmos": "ultracentrifugar",
    "ultracentrifugará": "ultracentrifugar",
    "ultracentrifugarás": "ultracentrifugar",
    "ultracentrifugarão": "ultracentrifugar",
    "ultracentrifugaríamos": "ultracentrifugar",
    "ultracentrifugaríeis": "ultracentrifugar",
    "ultracentrifugas": "ultracentrifugar",
    "ultracentrifugasse": "ultracentrifugar",
    "ultracentrifugassem": "ultracentrifugar",
    "ultracentrifugasses": "ultracentrifugar",
    "ultracentrifugaste": "ultracentrifugar",
    "ultracentrifugastes": "ultracentrifugar",
    "ultracentrifugava": "ultracentrifugar",
    "ultracentrifugavam": "ultracentrifugar",
    "ultracentrifugavas": "ultracentrifugar",
    "ultracentrifugações": "ultracentrifugação",
    "ultracentrifugo": "ultracentrifugar",
    "ultracentrifugou": "ultracentrifugar",
    "ultracentrifugue": "ultracentrifugar",
    "ultracentrifuguei": "ultracentrifugar",
    "ultracentrifugueis": "ultracentrifugar",
    "ultracentrifuguem": "ultracentrifugar",
    "ultracentrifuguemo": "ultracentrifugar",
    "ultracentrifuguemos": "ultracentrifugar",
    "ultracentrifugues": "ultracentrifugar",
    "ultracentrifugá": "ultracentrifugar",
    "ultracentrifugámo": "ultracentrifugar",
    "ultracentrifugámos": "ultracentrifugar",
    "ultracentrifugáramo": "ultracentrifugar",
    "ultracentrifugáramos": "ultracentrifugar",
    "ultracentrifugárei": "ultracentrifugar",
    "ultracentrifugáreis": "ultracentrifugar",
    "ultracentrifugásseis": "ultracentrifugar",
    "ultracentrifugássemos": "ultracentrifugar",
    "ultracentrifugávamo": "ultracentrifugar",
    "ultracentrifugávamos": "ultracentrifugar",
    "ultracentrifugávei": "ultracentrifugar",
    "ultracentrifugáveis": "ultracentrifugável",
    "ultraclara": "ultraclaro",
    "ultraclaras": "ultraclaro",
    "ultraclaros": "ultraclaro",
    "ultracongelada": "ultracongelado",
    "ultracongeladas": "ultracongelado",
    "ultracongelados": "ultracongelado",
    "ultracongelações": "ultracongelação",
    "ultraconservadora": "ultraconservador",
    "ultraconservadoras": "ultraconservador",
    "ultraconservadores": "ultraconservador",
    "ultracorrecções": "ultracorrecção",
    "ultracurta": "ultracurto",
    "ultracurtas": "ultracurto",
    "ultracurtos": "ultracurto",
    "ultrafantástica": "ultrafantástico",
    "ultrafantásticas": "ultrafantástico",
    "ultrafantásticos": "ultrafantástico",
    "ultrafiltrações": "ultrafiltração",
    "ultraja": "ultrajar",
    "ultrajada": "ultrajar",
    "ultrajadas": "ultrajar",
    "ultrajado": "ultrajar",
    "ultrajadora": "ultrajador",
    "ultrajadoras": "ultrajador",
    "ultrajadores": "ultrajador",
    "ultrajados": "ultrajar",
    "ultrajadíssima": "ultrajado",
    "ultrajadíssimas": "ultrajado",
    "ultrajadíssimo": "ultrajado",
    "ultrajadíssimos": "ultrajado",
    "ultrajai": "ultrajar",
    "ultrajais": "ultrajar",
    "ultrajam": "ultrajar",
    "ultrajamo": "ultrajar",
    "ultrajamos": "ultrajar",
    "ultrajana": "ultrajano",
    "ultrajanas": "ultrajano",
    "ultrajando": "ultrajar",
    "ultrajanos": "ultrajano",
    "ultrajantes": "ultrajante",
    "ultrajara": "ultrajar",
    "ultrajaram": "ultrajar",
    "ultrajaras": "ultrajar",
    "ultrajarde": "ultrajar",
    "ultrajardes": "ultrajar",
    "ultrajare": "ultrajar",
    "ultrajarei": "ultrajar",
    "ultrajareis": "ultrajar",
    "ultrajarem": "ultrajar",
    "ultrajaremos": "ultrajar",
    "ultrajares": "ultrajar",
    "ultrajaria": "ultrajar",
    "ultrajariam": "ultrajar",
    "ultrajarias": "ultrajar",
    "ultrajarmo": "ultrajar",
    "ultrajarmos": "ultrajar",
    "ultrajará": "ultrajar",
    "ultrajarás": "ultrajar",
    "ultrajarão": "ultrajar",
    "ultrajaríamos": "ultrajar",
    "ultrajaríeis": "ultrajar",
    "ultrajas": "ultrajar",
    "ultrajasse": "ultrajar",
    "ultrajassem": "ultrajar",
    "ultrajasses": "ultrajar",
    "ultrajaste": "ultrajar",
    "ultrajastes": "ultrajar",
    "ultrajava": "ultrajar",
    "ultrajavam": "ultrajar",
    "ultrajavas": "ultrajar",
    "ultraje": "ultrajar",
    "ultrajei": "ultrajar",
    "ultrajeis": "ultrajar",
    "ultrajem": "ultrajar",
    "ultrajemo": "ultrajar",
    "ultrajemos": "ultrajar",
    "ultrajes": "ultraje",
    "ultrajo": "ultrajar",
    "ultrajosa": "ultrajoso",
    "ultrajosas": "ultrajoso",
    "ultrajosos": "ultrajoso",
    "ultrajou": "ultrajar",
    "ultrajá": "ultrajar",
    "ultrajámo": "ultrajar",
    "ultrajámos": "ultrajar",
    "ultrajáramo": "ultrajar",
    "ultrajáramos": "ultrajar",
    "ultrajárei": "ultrajar",
    "ultrajáreis": "ultrajar",
    "ultrajásseis": "ultrajar",
    "ultrajássemos": "ultrajar",
    "ultrajávamo": "ultrajar",
    "ultrajávamos": "ultrajar",
    "ultrajávei": "ultrajar",
    "ultrajáveis": "ultrajável",
    "ultraliberais": "ultraliberal",
    "ultraliberalismos": "ultraliberalismo",
    "ultramada": "ultramado",
    "ultramadas": "ultramado",
    "ultramados": "ultramado",
    "ultramares": "ultramar",
    "ultramarina": "ultramarino",
    "ultramarinas": "ultramarino",
    "ultramarinos": "ultramarino",
    "ultramicroscopias": "ultramicroscopia",
    "ultramicroscópica": "ultramicroscópico",
    "ultramicroscópicas": "ultramicroscópico",
    "ultramicroscópicos": "ultramicroscópico",
    "ultramicroscópios": "ultramicroscópio",
    "ultramoderna": "ultramoderno",
    "ultramodernas": "ultramoderno",
    "ultramodernos": "ultramoderno",
    "ultramoderníssima": "ultramoderno",
    "ultramoderníssimas": "ultramoderno",
    "ultramoderníssimo": "ultramoderno",
    "ultramoderníssimos": "ultramoderno",
    "ultramontana": "ultramontano",
    "ultramontanas": "ultramontano",
    "ultramontanismos": "ultramontanismo",
    "ultramontanos": "ultramontano",
    "ultramáveis": "ultramável",
    "ultranacionalismos": "ultranacionalismo",
    "ultranacionalistas": "ultranacionalista",
    "ultranaturais": "ultranatural",
    "ultrapassa": "ultrapassar",
    "ultrapassada": "ultrapassar",
    "ultrapassadas": "ultrapassar",
    "ultrapassado": "ultrapassar",
    "ultrapassados": "ultrapassar",
    "ultrapassagens": "ultrapassagem",
    "ultrapassai": "ultrapassar",
    "ultrapassais": "ultrapassar",
    "ultrapassam": "ultrapassar",
    "ultrapassamo": "ultrapassar",
    "ultrapassamos": "ultrapassar",
    "ultrapassando": "ultrapassar",
    "ultrapassara": "ultrapassar",
    "ultrapassaram": "ultrapassar",
    "ultrapassaras": "ultrapassar",
    "ultrapassarde": "ultrapassar",
    "ultrapassardes": "ultrapassar",
    "ultrapassare": "ultrapassar",
    "ultrapassarei": "ultrapassar",
    "ultrapassareis": "ultrapassar",
    "ultrapassarem": "ultrapassar",
    "ultrapassaremos": "ultrapassar",
    "ultrapassares": "ultrapassar",
    "ultrapassaria": "ultrapassar",
    "ultrapassariam": "ultrapassar",
    "ultrapassarias": "ultrapassar",
    "ultrapassarmo": "ultrapassar",
    "ultrapassarmos": "ultrapassar",
    "ultrapassará": "ultrapassar",
    "ultrapassarás": "ultrapassar",
    "ultrapassarão": "ultrapassar",
    "ultrapassaríamos": "ultrapassar",
    "ultrapassaríeis": "ultrapassar",
    "ultrapassas": "ultrapassar",
    "ultrapassasse": "ultrapassar",
    "ultrapassassem": "ultrapassar",
    "ultrapassasses": "ultrapassar",
    "ultrapassaste": "ultrapassar",
    "ultrapassastes": "ultrapassar",
    "ultrapassava": "ultrapassar",
    "ultrapassavam": "ultrapassar",
    "ultrapassavas": "ultrapassar",
    "ultrapasse": "ultrapassar",
    "ultrapassei": "ultrapassar",
    "ultrapasseis": "ultrapassar",
    "ultrapassem": "ultrapassar",
    "ultrapassemo": "ultrapassar",
    "ultrapassemos": "ultrapassar",
    "ultrapasses": "ultrapassar",
    "ultrapasso": "ultrapassar",
    "ultrapassou": "ultrapassar",
    "ultrapassá": "ultrapassar",
    "ultrapassámo": "ultrapassar",
    "ultrapassámos": "ultrapassar",
    "ultrapassáramo": "ultrapassar",
    "ultrapassáramos": "ultrapassar",
    "ultrapassárei": "ultrapassar",
    "ultrapassáreis": "ultrapassar",
    "ultrapassásseis": "ultrapassar",
    "ultrapassássemos": "ultrapassar",
    "ultrapassávamo": "ultrapassar",
    "ultrapassávamos": "ultrapassar",
    "ultrapassávei": "ultrapassar",
    "ultrapassáveis": "ultrapassável",
    "ultraperiférica": "ultraperiférico",
    "ultraperiféricas": "ultraperiférico",
    "ultraperiféricos": "ultraperiférico",
    "ultrapressões": "ultrapressão",
    "ultraterrestres": "ultraterrestre",
    "ultravioletas": "ultravioleta",
    "ultraviolências": "ultraviolência",
    "ultravíros": "ultravírus",
    "ultrazodiacais": "ultrazodiacal",
    "ultrices": "ultrice",
    "ultrizes": "ultriz",
    "ultrizs": "ultriz",
    "ulula": "ulular",
    "ululada": "ulular",
    "ululadas": "ulular",
    "ululado": "ulular",
    "ululadora": "ululador",
    "ululadoras": "ululador",
    "ululadores": "ululador",
    "ululados": "ulular",
    "ululai": "ulular",
    "ululais": "ulular",
    "ululam": "ulular",
    "ululamo": "ulular",
    "ululamos": "ulular",
    "ululando": "ulular",
    "ululantes": "ululante",
    "ululara": "ulular",
    "ulularam": "ulular",
    "ulularas": "ulular",
    "ululardes": "ulular",
    "ulularei": "ulular",
    "ululareis": "ulular",
    "ulularem": "ulular",
    "ulularemos": "ulular",
    "ululares": "ulular",
    "ulularia": "ulular",
    "ululariam": "ulular",
    "ulularias": "ulular",
    "ulularmo": "ulular",
    "ulularmos": "ulular",
    "ululará": "ulular",
    "ulularás": "ulular",
    "ulularão": "ulular",
    "ulularíamos": "ulular",
    "ulularíeis": "ulular",
    "ululas": "ulular",
    "ululasse": "ulular",
    "ululassem": "ulular",
    "ululasses": "ulular",
    "ululaste": "ulular",
    "ululastes": "ulular",
    "ululatos": "ululato",
    "ululava": "ulular",
    "ululavam": "ulular",
    "ululavas": "ulular",
    "ululações": "ululação",
    "ulule": "ulular",
    "ululei": "ulular",
    "ululeis": "ulular",
    "ululem": "ulular",
    "ululemo": "ulular",
    "ululemos": "ulular",
    "ulules": "ulular",
    "ululo": "ulular",
    "ululos": "ululo",
    "ululou": "ulular",
    "ululámo": "ulular",
    "ululámos": "ulular",
    "ululáramo": "ulular",
    "ululáramos": "ulular",
    "ululáreis": "ulular",
    "ululásseis": "ulular",
    "ululássemos": "ulular",
    "ululávamo": "ulular",
    "ululávamos": "ulular",
    "ululáveis": "ululável",
    "ulváceas": "ulvácea",
    "ulótrica": "ulótrico",
    "ulótricas": "ulótrico",
    "ulótricos": "ulótrico",
    "uma": "umar",
    "umada": "umar",
    "umadas": "umar",
    "umado": "umar",
    "umados": "umar",
    "umai": "umar",
    "umais": "umar",
    "umam": "umar",
    "umamo": "umar",
    "umamos": "umar",
    "umando": "umar",
    "umara": "umar",
    "umaram": "umar",
    "umaras": "umar",
    "umardes": "umar",
    "umarei": "umar",
    "umareis": "umar",
    "umarem": "umar",
    "umaremos": "umar",
    "umares": "umar",
    "umaria": "umar",
    "umariam": "umar",
    "umarias": "umar",
    "umaris": "umari",
    "umarmo": "umar",
    "umarmos": "umar",
    "umará": "umar",
    "umarás": "umar",
    "umarão": "umar",
    "umaríamos": "umar",
    "umaríeis": "umar",
    "umas": "umar",
    "umasse": "umar",
    "umassem": "umar",
    "umasses": "umar",
    "umaste": "umar",
    "umastes": "umar",
    "umava": "umar",
    "umavam": "umar",
    "umavas": "umar",
    "umações": "umação",
    "umbalas": "umbala",
    "umbambas": "umbamba",
    "umbaúbas": "umbaúba",
    "umbelada": "umbelado",
    "umbeladas": "umbelado",
    "umbelados": "umbelado",
    "umbelas": "umbela",
    "umbeliformes": "umbeliforme",
    "umbelífera": "umbelífero",
    "umbelíferas": "umbelífero",
    "umbelíferos": "umbelífero",
    "umbigadas": "umbigada",
    "umbigos": "umbigo",
    "umbigueiras": "umbigueira",
    "umbilicada": "umbilicado",
    "umbilicadas": "umbilicado",
    "umbilicados": "umbilicado",
    "umbilicais": "umbilical",
    "umbraculiformes": "umbraculiforme",
    "umbraculífera": "umbraculífero",
    "umbraculíferas": "umbraculífero",
    "umbraculíferos": "umbraculífero",
    "umbrais": "umbral",
    "umbras": "umbra",
    "umbratícolas": "umbratícola",
    "umbrelas": "umbrela",
    "umbrias": "umbria",
    "umbros": "umbro",
    "umbrosa": "umbroso",
    "umbrosas": "umbroso",
    "umbrosos": "umbroso",
    "umbráculos": "umbráculo",
    "umbrálica": "umbrálico",
    "umbrálicas": "umbrálico",
    "umbrálicos": "umbrálico",
    "umbrátis": "umbrátil",
    "umbrículas": "umbrícula",
    "umbrífera": "umbrífero",
    "umbríferas": "umbrífero",
    "umbríferos": "umbrífero",
    "umbrófila": "umbrófilo",
    "umbrófilas": "umbrófilo",
    "umbrófilos": "umbrófilo",
    "umbrófoba": "umbrófobo",
    "umbrófobas": "umbrófobo",
    "umbrófobos": "umbrófobo",
    "umbus": "umbu",
    "umbuzeiros": "umbuzeiro",
    "umbélulas": "umbélula",
    "ume": "umar",
    "umei": "umar",
    "umeis": "umar",
    "umem": "umar",
    "umemo": "umar",
    "umemos": "umar",
    "umerais": "umeral",
    "umerária": "umerário",
    "umerárias": "umerário",
    "umerários": "umerário",
    "umes": "ume",
    "umo": "umar",
    "umou": "umar",
    "umámo": "umar",
    "umámos": "umar",
    "umáramo": "umar",
    "umáramos": "umar",
    "umáreis": "umar",
    "umásseis": "umar",
    "umássemos": "umar",
    "umávamo": "umar",
    "umávamos": "umar",
    "umáveis": "umar",
    "una": "uno",
    "unada": "unar",
    "unadas": "unar",
    "unado": "unar",
    "unados": "unar",
    "unai": "unar",
    "unais": "unir",
    "unam": "unir",
    "unamo": "unir",
    "unamos": "unir",
    "unando": "unar",
    "unanima": "unanimar",
    "unanimada": "unanimar",
    "unanimadas": "unanimar",
    "unanimado": "unanimar",
    "unanimados": "unanimar",
    "unanimai": "unanimar",
    "unanimais": "unanimar",
    "unanimam": "unanimar",
    "unanimamo": "unanimar",
    "unanimamos": "unanimar",
    "unanimando": "unanimar",
    "unanimara": "unanimar",
    "unanimaram": "unanimar",
    "unanimaras": "unanimar",
    "unanimarde": "unanimar",
    "unanimardes": "unanimar",
    "unanimare": "unanimar",
    "unanimarei": "unanimar",
    "unanimareis": "unanimar",
    "unanimarem": "unanimar",
    "unanimaremos": "unanimar",
    "unanimares": "unanimar",
    "unanimaria": "unanimar",
    "unanimariam": "unanimar",
    "unanimarias": "unanimar",
    "unanimarmo": "unanimar",
    "unanimarmos": "unanimar",
    "unanimará": "unanimar",
    "unanimarás": "unanimar",
    "unanimarão": "unanimar",
    "unanimaríamos": "unanimar",
    "unanimaríeis": "unanimar",
    "unanimas": "unanimar",
    "unanimasse": "unanimar",
    "unanimassem": "unanimar",
    "unanimasses": "unanimar",
    "unanimaste": "unanimar",
    "unanimastes": "unanimar",
    "unanimava": "unanimar",
    "unanimavam": "unanimar",
    "unanimavas": "unanimar",
    "unanime": "unanimar",
    "unanimei": "unanimar",
    "unanimeis": "unanimar",
    "unanimem": "unanimar",
    "unanimemo": "unanimar",
    "unanimemos": "unanimar",
    "unanimes": "unanimar",
    "unanimidades": "unanimidade",
    "unanimismos": "unanimismo",
    "unanimistas": "unanimista",
    "unanimo": "unanimar",
    "unanimou": "unanimar",
    "unanimá": "unanimar",
    "unanimámo": "unanimar",
    "unanimámos": "unanimar",
    "unanimáramo": "unanimar",
    "unanimáramos": "unanimar",
    "unanimárei": "unanimar",
    "unanimáreis": "unanimar",
    "unanimásseis": "unanimar",
    "unanimássemos": "unanimar",
    "unanimávamo": "unanimar",
    "unanimávamos": "unanimar",
    "unanimávei": "unanimar",
    "unanimáveis": "unanimar",
    "unara": "unar",
    "unaram": "unar",
    "unaras": "unar",
    "unarde": "unar",
    "unardes": "unar",
    "unare": "unar",
    "unarei": "unar",
    "unareis": "unar",
    "unarem": "unar",
    "unaremos": "unar",
    "unares": "unar",
    "unaria": "unar",
    "unariam": "unar",
    "unarias": "unar",
    "unarmo": "unar",
    "unarmos": "unar",
    "unará": "unar",
    "unarás": "unar",
    "unarão": "unar",
    "unaríamos": "unar",
    "unaríeis": "unar",
    "unas": "uno",
    "unasse": "unar",
    "unassem": "unar",
    "unasses": "unar",
    "unaste": "unar",
    "unastes": "unar",
    "unava": "unar",
    "unavam": "unar",
    "unavas": "unar",
    "unciais": "uncial",
    "unciformes": "unciforme",
    "uncinada": "uncinado",
    "uncinadas": "uncinado",
    "uncinados": "uncinado",
    "uncirrostra": "uncirrostro",
    "uncirrostras": "uncirrostro",
    "uncirrostros": "uncirrostro",
    "uncíneas": "uncínea",
    "undabunda": "undabundo",
    "undabundas": "undabundo",
    "undabundos": "undabundo",
    "undalos": "undalo",
    "undantes": "undante",
    "undações": "undação",
    "undecenais": "undecenal",
    "undecágonos": "undecágono",
    "undiflava": "undiflavo",
    "undiflavas": "undiflavo",
    "undiflavos": "undiflavo",
    "undosa": "undoso",
    "undosas": "undoso",
    "undosos": "undoso",
    "undulada": "undulado",
    "unduladas": "undulado",
    "undulados": "undulado",
    "unduladíssima": "undulado",
    "unduladíssimas": "undulado",
    "unduladíssimo": "undulado",
    "unduladíssimos": "undulado",
    "undulosa": "unduloso",
    "undulosas": "unduloso",
    "undulosos": "unduloso",
    "unduláveis": "undulável",
    "undécima": "undécimo",
    "undécimas": "undécimo",
    "undécimos": "undécimo",
    "undécupla": "undécuplo",
    "undícolas": "undícola",
    "undífera": "undífero",
    "undíferas": "undífero",
    "undíferos": "undífero",
    "undíflua": "undífluo",
    "undífluas": "undífluo",
    "undífluos": "undífluo",
    "undísseca": "undísseco",
    "undíssecas": "undísseco",
    "undíssecos": "undísseco",
    "undíssona": "undíssono",
    "undíssonas": "undíssono",
    "undíssonos": "undíssono",
    "undívaga": "undívago",
    "undívagas": "undívago",
    "undívagos": "undívago",
    "une": "unir",
    "unei": "unar",
    "uneis": "unar",
    "unem": "unir",
    "unemo": "unar",
    "unemos": "unar",
    "unes": "unir",
    "unge": "ungir",
    "ungem": "ungir",
    "unges": "ungir",
    "ungi": "ungir",
    "ungia": "ungir",
    "ungiam": "ungir",
    "ungias": "ungir",
    "ungida": "ungir",
    "ungidas": "ungir",
    "ungido": "ungir",
    "ungidos": "ungir",
    "ungidíssima": "ungido",
    "ungidíssimas": "ungido",
    "ungidíssimo": "ungido",
    "ungidíssimos": "ungido",
    "ungimo": "ungir",
    "ungimos": "ungir",
    "ungindo": "ungir",
    "ungira": "ungir",
    "ungiram": "ungir",
    "ungiras": "ungir",
    "ungirde": "ungir",
    "ungirdes": "ungir",
    "ungire": "ungir",
    "ungirei": "ungir",
    "ungireis": "ungir",
    "ungirem": "ungir",
    "ungiremos": "ungir",
    "ungires": "ungir",
    "ungiria": "ungir",
    "ungiriam": "ungir",
    "ungirias": "ungir",
    "ungirmo": "ungir",
    "ungirmos": "ungir",
    "ungirá": "ungir",
    "ungirás": "ungir",
    "ungirão": "ungir",
    "ungiríamos": "ungir",
    "ungiríeis": "ungir",
    "ungis": "ungir",
    "ungisse": "ungir",
    "ungissem": "ungir",
    "ungisses": "ungir",
    "ungiste": "ungir",
    "ungistes": "ungir",
    "ungiu": "ungir",
    "unguais": "ungual",
    "unguaris": "unguari",
    "ungueais": "ungueal",
    "unguenta": "unguentar",
    "unguentada": "unguentar",
    "unguentadas": "unguentar",
    "unguentado": "unguentar",
    "unguentados": "unguentar",
    "unguentai": "unguentar",
    "unguentais": "unguentar",
    "unguentam": "unguentar",
    "unguentamo": "unguentar",
    "unguentamos": "unguentar",
    "unguentando": "unguentar",
    "unguentara": "unguentar",
    "unguentaram": "unguentar",
    "unguentaras": "unguentar",
    "unguentarde": "unguentar",
    "unguentardes": "unguentar",
    "unguentare": "unguentar",
    "unguentarei": "unguentar",
    "unguentareis": "unguentar",
    "unguentarem": "unguentar",
    "unguentaremos": "unguentar",
    "unguentares": "unguentar",
    "unguentaria": "unguentar",
    "unguentariam": "unguentar",
    "unguentarias": "unguentar",
    "unguentarmo": "unguentar",
    "unguentarmos": "unguentar",
    "unguentará": "unguentar",
    "unguentarás": "unguentar",
    "unguentarão": "unguentar",
    "unguentaríamos": "unguentar",
    "unguentaríeis": "unguentar",
    "unguentas": "unguentar",
    "unguentasse": "unguentar",
    "unguentassem": "unguentar",
    "unguentasses": "unguentar",
    "unguentaste": "unguentar",
    "unguentastes": "unguentar",
    "unguentava": "unguentar",
    "unguentavam": "unguentar",
    "unguentavas": "unguentar",
    "unguente": "unguentar",
    "unguentei": "unguentar",
    "unguenteis": "unguentar",
    "unguentem": "unguentar",
    "unguentemo": "unguentar",
    "unguentemos": "unguentar",
    "unguentes": "unguentar",
    "unguento": "unguentar",
    "unguentos": "unguento",
    "unguentou": "unguentar",
    "unguentá": "unguentar",
    "unguentácea": "unguentáceo",
    "unguentáceas": "unguentáceo",
    "unguentáceos": "unguentáceo",
    "unguentámo": "unguentar",
    "unguentámos": "unguentar",
    "unguentáramo": "unguentar",
    "unguentáramos": "unguentar",
    "unguentárei": "unguentar",
    "unguentáreis": "unguentar",
    "unguentária": "unguentário",
    "unguentárias": "unguentário",
    "unguentários": "unguentário",
    "unguentásseis": "unguentar",
    "unguentássemos": "unguentar",
    "unguentávamo": "unguentar",
    "unguentávamos": "unguentar",
    "unguentávei": "unguentar",
    "unguentáveis": "unguentável",
    "unguiais": "unguial",
    "unguiculada": "unguiculado",
    "unguiculadas": "unguiculado",
    "unguiculados": "unguiculado",
    "unguiformes": "unguiforme",
    "unguinosa": "unguinoso",
    "unguinosas": "unguinoso",
    "unguinosos": "unguinoso",
    "unguis": "ungui",
    "ungulada": "ungulado",
    "unguladas": "ungulado",
    "ungulados": "ungulado",
    "ungulígrada": "ungulígrado",
    "ungulígradas": "ungulígrado",
    "ungulígrados": "ungulígrado",
    "unguífera": "unguífero",
    "unguíferas": "unguífero",
    "unguíferos": "unguífero",
    "ungíamo": "ungir",
    "ungíamos": "ungir",
    "ungíei": "ungir",
    "ungíeis": "ungir",
    "ungíramo": "ungir",
    "ungíramos": "ungir",
    "ungírei": "ungir",
    "ungíreis": "ungir",
    "ungísseis": "ungir",
    "ungíssemos": "ungir",
    "ungíveis": "ungível",
    "unha": "unhar",
    "unhacas": "unhaca",
    "unhada": "unhar",
    "unhadas": "unhar",
    "unhado": "unhar",
    "unhadora": "unhador",
    "unhadoras": "unhador",
    "unhadores": "unhador",
    "unhados": "unhar",
    "unhagatas": "unhagata",
    "unhai": "unhar",
    "unhais": "unhar",
    "unham": "unhar",
    "unhamentos": "unhamento",
    "unhamo": "unhar",
    "unhamos": "unhar",
    "unhando": "unhar",
    "unhantes": "unhante",
    "unhara": "unhar",
    "unharam": "unhar",
    "unharas": "unhar",
    "unharde": "unhar",
    "unhardes": "unhar",
    "unhare": "unhar",
    "unharei": "unhar",
    "unhareis": "unhar",
    "unharem": "unhar",
    "unharemos": "unhar",
    "unhares": "unhar",
    "unharia": "unhar",
    "unhariam": "unhar",
    "unharias": "unhar",
    "unharmo": "unhar",
    "unharmos": "unhar",
    "unhará": "unhar",
    "unharás": "unhar",
    "unharão": "unhar",
    "unharíamos": "unhar",
    "unharíeis": "unhar",
    "unhas": "unhar",
    "unhasse": "unhar",
    "unhassem": "unhar",
    "unhasses": "unhar",
    "unhaste": "unhar",
    "unhastes": "unhar",
    "unhava": "unhar",
    "unhavam": "unhar",
    "unhavas": "unhar",
    "unhaços": "unhaço",
    "unhe": "unhar",
    "unhei": "unhar",
    "unheiros": "unheiro",
    "unheis": "unhar",
    "unhem": "unhar",
    "unhemo": "unhar",
    "unhemos": "unhar",
    "unhes": "unhar",
    "unhinha": "unha",
    "unhinhas": "unha",
    "unhita": "unha",
    "unhitas": "unha",
    "unho": "unhar",
    "unhou": "unhar",
    "unhá": "unhar",
    "unhámo": "unhar",
    "unhámos": "unhar",
    "unháramo": "unhar",
    "unháramos": "unhar",
    "unhárei": "unhar",
    "unháreis": "unhar",
    "unhásseis": "unhar",
    "unhássemos": "unhar",
    "unhávamo": "unhar",
    "unhávamos": "unhar",
    "unhávei": "unhar",
    "unháveis": "unhável",
    "unhões": "unhão",
    "uni": "unir",
    "unia": "unir",
    "unialada": "unialado",
    "unialadas": "unialado",
    "unialados": "unialado",
    "uniam": "unir",
    "uniangulara": "uniangular",
    "uniangularas": "uniangular",
    "uniangulares": "uniangular",
    "uniarticulada": "uniarticulado",
    "uniarticuladas": "uniarticulado",
    "uniarticulados": "uniarticulado",
    "unias": "unir",
    "uniaxiais": "uniaxial",
    "unibranquiada": "unibranquiado",
    "unibranquiadas": "unibranquiado",
    "unibranquiados": "unibranquiado",
    "unicapsulares": "unicapsular",
    "unicarpelares": "unicarpelar",
    "unicaules": "unicaule",
    "unicelulares": "unicelular",
    "unicidades": "unicidade",
    "uniciliares": "uniciliar",
    "unicolores": "unicolor",
    "unicornes": "unicorne",
    "unicultora": "unicultor",
    "unicultoras": "unicultor",
    "unicultores": "unicultor",
    "unicíssima": "único",
    "unicíssimas": "único",
    "unicíssimo": "único",
    "unicíssimos": "único",
    "unicórnea": "unicórneo",
    "unicórneas": "unicórneo",
    "unicórneos": "unicórneo",
    "unicórnios": "unicórnio",
    "unicúspides": "unicúspide",
    "unida": "unir",
    "unidades": "unidade",
    "unidas": "unir",
    "unidimensionais": "unidimensional",
    "unidireccionais": "unidireccional",
    "unido": "unir",
    "unidos": "unir",
    "unidáctila": "unidáctilo",
    "unidáctilas": "unidáctilo",
    "unidáctilos": "unidáctilo",
    "unidíssima": "unido",
    "unidíssimas": "unido",
    "unidíssimo": "unido",
    "unidíssimos": "unido",
    "unifaciais": "unifacial",
    "unifica": "unificar",
    "unificada": "unificar",
    "unificadas": "unificar",
    "unificado": "unificar",
    "unificadora": "unificador",
    "unificadoras": "unificador",
    "unificadores": "unificador",
    "unificados": "unificar",
    "unificadíssima": "unificado",
    "unificadíssimas": "unificado",
    "unificadíssimo": "unificado",
    "unificadíssimos": "unificado",
    "unificai": "unificar",
    "unificais": "unificar",
    "unificam": "unificar",
    "unificamo": "unificar",
    "unificamos": "unificar",
    "unificando": "unificar",
    "unificara": "unificar",
    "unificaram": "unificar",
    "unificaras": "unificar",
    "unificarde": "unificar",
    "unificardes": "unificar",
    "unificare": "unificar",
    "unificarei": "unificar",
    "unificareis": "unificar",
    "unificarem": "unificar",
    "unificaremos": "unificar",
    "unificares": "unificar",
    "unificaria": "unificar",
    "unificariam": "unificar",
    "unificarias": "unificar",
    "unificarmo": "unificar",
    "unificarmos": "unificar",
    "unificará": "unificar",
    "unificarás": "unificar",
    "unificarão": "unificar",
    "unificaríamos": "unificar",
    "unificaríeis": "unificar",
    "unificas": "unificar",
    "unificasse": "unificar",
    "unificassem": "unificar",
    "unificasses": "unificar",
    "unificaste": "unificar",
    "unificastes": "unificar",
    "unificava": "unificar",
    "unificavam": "unificar",
    "unificavas": "unificar",
    "unificações": "unificação",
    "unifico": "unificar",
    "unificou": "unificar",
    "unificá": "unificar",
    "unificámo": "unificar",
    "unificámos": "unificar",
    "unificáramo": "unificar",
    "unificáramos": "unificar",
    "unificárei": "unificar",
    "unificáreis": "unificar",
    "unificásseis": "unificar",
    "unificássemos": "unificar",
    "unificávamo": "unificar",
    "unificávamos": "unificar",
    "unificávei": "unificar",
    "unificáveis": "unificável",
    "unifilares": "unifilar",
    "unifique": "unificar",
    "unifiquei": "unificar",
    "unifiqueis": "unificar",
    "unifiquem": "unificar",
    "unifiquemo": "unificar",
    "unifiquemos": "unificar",
    "unifiques": "unificar",
    "uniflora": "unifloro",
    "unifloras": "unifloro",
    "unifloros": "unifloro",
    "unifoliada": "unifoliado",
    "unifoliadas": "unifoliado",
    "unifoliados": "unifoliado",
    "uniforma": "uniformar",
    "uniformada": "uniformar",
    "uniformadas": "uniformar",
    "uniformado": "uniformar",
    "uniformados": "uniformar",
    "uniformai": "uniformar",
    "uniformais": "uniformar",
    "uniformam": "uniformar",
    "uniformamo": "uniformar",
    "uniformamos": "uniformar",
    "uniformando": "uniformar",
    "uniformara": "uniformar",
    "uniformaram": "uniformar",
    "uniformaras": "uniformar",
    "uniformarde": "uniformar",
    "uniformardes": "uniformar",
    "uniformare": "uniformar",
    "uniformarei": "uniformar",
    "uniformareis": "uniformar",
    "uniformarem": "uniformar",
    "uniformaremos": "uniformar",
    "uniformares": "uniformar",
    "uniformaria": "uniformar",
    "uniformariam": "uniformar",
    "uniformarias": "uniformar",
    "uniformarmo": "uniformar",
    "uniformarmos": "uniformar",
    "uniformará": "uniformar",
    "uniformarás": "uniformar",
    "uniformarão": "uniformar",
    "uniformaríamos": "uniformar",
    "uniformaríeis": "uniformar",
    "uniformas": "uniformar",
    "uniformasse": "uniformar",
    "uniformassem": "uniformar",
    "uniformasses": "uniformar",
    "uniformaste": "uniformar",
    "uniformastes": "uniformar",
    "uniformava": "uniformar",
    "uniformavam": "uniformar",
    "uniformavas": "uniformar",
    "uniforme": "uniformar",
    "uniformei": "uniformar",
    "uniformeis": "uniformar",
    "uniformem": "uniformar",
    "uniformemo": "uniformar",
    "uniformemos": "uniformar",
    "uniformes": "uniforme",
    "uniformidades": "uniformidade",
    "uniformiza": "uniformizar",
    "uniformizada": "uniformizar",
    "uniformizadas": "uniformizar",
    "uniformizado": "uniformizar",
    "uniformizadora": "uniformizador",
    "uniformizadoras": "uniformizador",
    "uniformizadores": "uniformizador",
    "uniformizados": "uniformizar",
    "uniformizadíssima": "uniformizado",
    "uniformizadíssimas": "uniformizado",
    "uniformizadíssimo": "uniformizado",
    "uniformizadíssimos": "uniformizado",
    "uniformizai": "uniformizar",
    "uniformizais": "uniformizar",
    "uniformizam": "uniformizar",
    "uniformizamo": "uniformizar",
    "uniformizamos": "uniformizar",
    "uniformizando": "uniformizar",
    "uniformizara": "uniformizar",
    "uniformizaram": "uniformizar",
    "uniformizaras": "uniformizar",
    "uniformizarde": "uniformizar",
    "uniformizardes": "uniformizar",
    "uniformizare": "uniformizar",
    "uniformizarei": "uniformizar",
    "uniformizareis": "uniformizar",
    "uniformizarem": "uniformizar",
    "uniformizaremos": "uniformizar",
    "uniformizares": "uniformizar",
    "uniformizaria": "uniformizar",
    "uniformizariam": "uniformizar",
    "uniformizarias": "uniformizar",
    "uniformizarmo": "uniformizar",
    "uniformizarmos": "uniformizar",
    "uniformizará": "uniformizar",
    "uniformizarás": "uniformizar",
    "uniformizarão": "uniformizar",
    "uniformizaríamos": "uniformizar",
    "uniformizaríeis": "uniformizar",
    "uniformizas": "uniformizar",
    "uniformizasse": "uniformizar",
    "uniformizassem": "uniformizar",
    "uniformizasses": "uniformizar",
    "uniformizaste": "uniformizar",
    "uniformizastes": "uniformizar",
    "uniformizava": "uniformizar",
    "uniformizavam": "uniformizar",
    "uniformizavas": "uniformizar",
    "uniformizações": "uniformização",
    "uniformize": "uniformizar",
    "uniformizei": "uniformizar",
    "uniformizeis": "uniformizar",
    "uniformizem": "uniformizar",
    "uniformizemo": "uniformizar",
    "uniformizemos": "uniformizar",
    "uniformizes": "uniformizar",
    "uniformizo": "uniformizar",
    "uniformizou": "uniformizar",
    "uniformizá": "uniformizar",
    "uniformizámo": "uniformizar",
    "uniformizámos": "uniformizar",
    "uniformizáramo": "uniformizar",
    "uniformizáramos": "uniformizar",
    "uniformizárei": "uniformizar",
    "uniformizáreis": "uniformizar",
    "uniformizásseis": "uniformizar",
    "uniformizássemos": "uniformizar",
    "uniformizávamo": "uniformizar",
    "uniformizávamos": "uniformizar",
    "uniformizávei": "uniformizar",
    "uniformizáveis": "uniformizável",
    "uniformo": "uniformar",
    "uniformou": "uniformar",
    "uniformá": "uniformar",
    "uniformámo": "uniformar",
    "uniformámos": "uniformar",
    "uniformáramo": "uniformar",
    "uniformáramos": "uniformar",
    "uniformárei": "uniformar",
    "uniformáreis": "uniformar",
    "uniformásseis": "uniformar",
    "uniformássemos": "uniformar",
    "uniformávamo": "uniformar",
    "uniformávamos": "uniformar",
    "uniformávei": "uniformar",
    "uniformáveis": "uniformável",
    "unifólia": "unifólio",
    "unifólias": "unifólio",
    "unifólios": "unifólio",
    "unigamias": "unigamia",
    "unigénita": "unigénito",
    "unigénitas": "unigénito",
    "unigénitos": "unigénito",
    "unijugada": "unijugado",
    "unijugadas": "unijugado",
    "unijugados": "unijugado",
    "unilabiada": "unilabiado",
    "unilabiadas": "unilabiado",
    "unilabiados": "unilabiado",
    "unilaterais": "unilateral",
    "unilateralidades": "unilateralidade",
    "unilibada": "unilibado",
    "unilibadas": "unilibado",
    "unilibados": "unilibado",
    "unilingue": "unilíngue",
    "unilingues": "unilíngue",
    "uniliterais": "uniliteral",
    "unilobulada": "unilobulado",
    "unilobuladas": "unilobulado",
    "unilobulados": "unilobulado",
    "uniloculares": "unilocular",
    "unilíngues": "unilíngue",
    "unilítera": "unilítero",
    "unilíteras": "unilítero",
    "unilíteros": "unilítero",
    "unimaculada": "unimaculado",
    "unimaculadas": "unimaculado",
    "unimaculados": "unimaculado",
    "unimamas": "unimama",
    "unimetalismos": "unimetalismo",
    "unimo": "unir",
    "unimos": "unir",
    "unindo": "unir",
    "uninervada": "uninervado",
    "uninervadas": "uninervado",
    "uninervados": "uninervado",
    "uninominais": "uninominal",
    "uninucleada": "uninucleado",
    "uninucleadas": "uninucleado",
    "uninucleados": "uninucleado",
    "uninucleares": "uninuclear",
    "unioculada": "unioculado",
    "unioculadas": "unioculado",
    "unioculados": "unioculado",
    "unionismos": "unionismo",
    "unionistas": "unionista",
    "unionídeos": "unionídeo",
    "uniovulares": "uniovular",
    "uniparidades": "uniparidade",
    "unipartidária": "unipartidário",
    "unipartidárias": "unipartidário",
    "unipartidários": "unipartidário",
    "unipedais": "unipedal",
    "unipenes": "unipene",
    "unipessoais": "unipessoal",
    "unipolares": "unipolar",
    "unipolaridades": "unipolaridade",
    "unipétala": "unipétalo",
    "unipétalas": "unipétalo",
    "unipétalos": "unipétalo",
    "unira": "unir",
    "uniram": "unir",
    "uniras": "unir",
    "unirde": "unir",
    "unirdes": "unir",
    "unire": "unir",
    "unirei": "unir",
    "unireis": "unir",
    "unirem": "unir",
    "uniremos": "unir",
    "unires": "unir",
    "uniria": "unir",
    "uniriam": "unir",
    "unirias": "unir",
    "unirmo": "unir",
    "unirmos": "unir",
    "unirrefringentes": "unirrefringente",
    "unirremes": "unirreme",
    "unirá": "unir",
    "unirás": "unir",
    "unirão": "unir",
    "uniríamos": "unir",
    "uniríeis": "unir",
    "unis": "unir",
    "unisperma": "unispermo",
    "unispermas": "unispermo",
    "unispermos": "unispermo",
    "unispérmica": "unispérmico",
    "unispérmicas": "unispérmico",
    "unispérmicos": "unispérmico",
    "unisse": "unir",
    "unissem": "unir",
    "unisseriada": "unisseriado",
    "unisseriadas": "unisseriado",
    "unisseriados": "unisseriado",
    "unisses": "unir",
    "unissexuada": "unissexuado",
    "unissexuadas": "unissexuado",
    "unissexuados": "unissexuado",
    "unissexuais": "unissexual",
    "unissexualidades": "unissexualidade",
    "unissexualismos": "unissexualismo",
    "unissonantes": "unissonante",
    "unissonâncias": "unissonância",
    "uniste": "unir",
    "unistes": "unir",
    "unitarisma": "unitarismo",
    "unitarismas": "unitarismo",
    "unitarismos": "unitarismo",
    "unitaristas": "unitarista",
    "unitiva": "unitivo",
    "unitivas": "unitivo",
    "unitivos": "unitivo",
    "unitária": "unitário",
    "unitárias": "unitário",
    "unitários": "unitário",
    "uniu": "unir",
    "univalentes": "univalente",
    "univalves": "univalve",
    "univalvulares": "univalvular",
    "univalências": "univalência",
    "universa": "universo",
    "universais": "universal",
    "universalidades": "universalidade",
    "universalisada": "universalisado",
    "universalisadas": "universalisado",
    "universalisados": "universalisado",
    "universalismos": "universalismo",
    "universalistas": "universalista",
    "universalisáveis": "universalisável",
    "universaliza": "universalizar",
    "universalizada": "universalizar",
    "universalizadas": "universalizar",
    "universalizado": "universalizar",
    "universalizados": "universalizar",
    "universalizai": "universalizar",
    "universalizais": "universalizar",
    "universalizam": "universalizar",
    "universalizamo": "universalizar",
    "universalizamos": "universalizar",
    "universalizando": "universalizar",
    "universalizara": "universalizar",
    "universalizaram": "universalizar",
    "universalizaras": "universalizar",
    "universalizarde": "universalizar",
    "universalizardes": "universalizar",
    "universalizare": "universalizar",
    "universalizarei": "universalizar",
    "universalizareis": "universalizar",
    "universalizarem": "universalizar",
    "universalizaremos": "universalizar",
    "universalizares": "universalizar",
    "universalizaria": "universalizar",
    "universalizariam": "universalizar",
    "universalizarias": "universalizar",
    "universalizarmo": "universalizar",
    "universalizarmos": "universalizar",
    "universalizará": "universalizar",
    "universalizarás": "universalizar",
    "universalizarão": "universalizar",
    "universalizaríamos": "universalizar",
    "universalizaríeis": "universalizar",
    "universalizas": "universalizar",
    "universalizasse": "universalizar",
    "universalizassem": "universalizar",
    "universalizasses": "universalizar",
    "universalizaste": "universalizar",
    "universalizastes": "universalizar",
    "universalizava": "universalizar",
    "universalizavam": "universalizar",
    "universalizavas": "universalizar",
    "universalizações": "universalização",
    "universalize": "universalizar",
    "universalizei": "universalizar",
    "universalizeis": "universalizar",
    "universalizem": "universalizar",
    "universalizemo": "universalizar",
    "universalizemos": "universalizar",
    "universalizes": "universalizar",
    "universalizo": "universalizar",
    "universalizou": "universalizar",
    "universalizá": "universalizar",
    "universalizámo": "universalizar",
    "universalizámos": "universalizar",
    "universalizáramo": "universalizar",
    "universalizáramos": "universalizar",
    "universalizárei": "universalizar",
    "universalizáreis": "universalizar",
    "universalizásseis": "universalizar",
    "universalizássemos": "universalizar",
    "universalizávamo": "universalizar",
    "universalizávamos": "universalizar",
    "universalizávei": "universalizar",
    "universalizáveis": "universalizar",
    "universalíssima": "universal",
    "universalíssimas": "universal",
    "universalíssimo": "universal",
    "universalíssimos": "universal",
    "universas": "universo",
    "universidades": "universidade",
    "universitária": "universitário",
    "universitárias": "universitário",
    "universitários": "universitário",
    "universos": "universo",
    "univitelina": "univitelino",
    "univitelinas": "univitelino",
    "univitelinos": "univitelino",
    "univocações": "univocação",
    "univocidades": "univocidade",
    "univérvea": "univérveo",
    "univérveas": "univérveo",
    "univérveos": "univérveo",
    "uniónidas": "uniónida",
    "uniões": "união",
    "unja": "ungir",
    "unjais": "ungir",
    "unjam": "ungir",
    "unjamo": "ungir",
    "unjamos": "ungir",
    "unjas": "ungir",
    "unjo": "ungir",
    "uno": "unir",
    "unos": "uno",
    "unou": "unar",
    "uns": "um",
    "unta": "untar",
    "untada": "untar",
    "untadas": "untar",
    "untadelas": "untadela",
    "untado": "untar",
    "untadora": "untador",
    "untadoras": "untador",
    "untadores": "untador",
    "untados": "untar",
    "untaduras": "untadura",
    "untadíssima": "untado",
    "untadíssimas": "untado",
    "untadíssimo": "untado",
    "untadíssimos": "untado",
    "untai": "untar",
    "untais": "untar",
    "untam": "untar",
    "untamo": "untar",
    "untamos": "untar",
    "untando": "untar",
    "untanhas": "untanha",
    "untara": "untar",
    "untaram": "untar",
    "untaras": "untar",
    "untarde": "untar",
    "untardes": "untar",
    "untare": "untar",
    "untarei": "untar",
    "untareis": "untar",
    "untarem": "untar",
    "untaremos": "untar",
    "untares": "untar",
    "untaria": "untar",
    "untariam": "untar",
    "untarias": "untar",
    "untarmo": "untar",
    "untarmos": "untar",
    "untará": "untar",
    "untarás": "untar",
    "untarão": "untar",
    "untaríamos": "untar",
    "untaríeis": "untar",
    "untas": "untar",
    "untasse": "untar",
    "untassem": "untar",
    "untasses": "untar",
    "untaste": "untar",
    "untastes": "untar",
    "untava": "untar",
    "untavam": "untar",
    "untavas": "untar",
    "unte": "untar",
    "untei": "untar",
    "unteis": "untar",
    "untem": "untar",
    "untemo": "untar",
    "untemos": "untar",
    "untes": "untar",
    "untita": "untitar",
    "untitada": "untitar",
    "untitadas": "untitar",
    "untitado": "untitar",
    "untitados": "untitar",
    "untitai": "untitar",
    "untitais": "untitar",
    "untitam": "untitar",
    "untitamo": "untitar",
    "untitamos": "untitar",
    "untitando": "untitar",
    "untitara": "untitar",
    "untitaram": "untitar",
    "untitaras": "untitar",
    "untitarde": "untitar",
    "untitardes": "untitar",
    "untitare": "untitar",
    "untitarei": "untitar",
    "untitareis": "untitar",
    "untitarem": "untitar",
    "untitaremos": "untitar",
    "untitares": "untitar",
    "untitaria": "untitar",
    "untitariam": "untitar",
    "untitarias": "untitar",
    "untitarmo": "untitar",
    "untitarmos": "untitar",
    "untitará": "untitar",
    "untitarás": "untitar",
    "untitarão": "untitar",
    "untitaríamos": "untitar",
    "untitaríeis": "untitar",
    "untitas": "untitar",
    "untitasse": "untitar",
    "untitassem": "untitar",
    "untitasses": "untitar",
    "untitaste": "untitar",
    "untitastes": "untitar",
    "untitava": "untitar",
    "untitavam": "untitar",
    "untitavas": "untitar",
    "untite": "untitar",
    "untitei": "untitar",
    "untiteis": "untitar",
    "untitem": "untitar",
    "untitemo": "untitar",
    "untitemos": "untitar",
    "untites": "untitar",
    "untito": "untitar",
    "untitou": "untitar",
    "untitá": "untitar",
    "untitámo": "untitar",
    "untitámos": "untitar",
    "untitáramo": "untitar",
    "untitáramos": "untitar",
    "untitárei": "untitar",
    "untitáreis": "untitar",
    "untitásseis": "untitar",
    "untitássemos": "untitar",
    "untitávamo": "untitar",
    "untitávamos": "untitar",
    "untitávei": "untitar",
    "untitáveis": "untitável",
    "unto": "untar",
    "untos": "unto",
    "untou": "untar",
    "untuosa": "untuoso",
    "untuosas": "untuoso",
    "untuosidades": "untuosidade",
    "untuosos": "untuoso",
    "untuosíssima": "untuoso",
    "untuosíssimas": "untuoso",
    "untuosíssimo": "untuoso",
    "untuosíssimos": "untuoso",
    "unturas": "untura",
    "untá": "untar",
    "untámo": "untar",
    "untámos": "untar",
    "untáramo": "untar",
    "untáramos": "untar",
    "untárei": "untar",
    "untáreis": "untar",
    "untásseis": "untar",
    "untássemos": "untar",
    "untávamo": "untar",
    "untávamos": "untar",
    "untávei": "untar",
    "untáveis": "untável",
    "untórios": "untório",
    "uná": "unar",
    "unámo": "unar",
    "unámos": "unar",
    "unáramo": "unar",
    "unáramos": "unar",
    "unárei": "unar",
    "unáreis": "unar",
    "unária": "unário",
    "unárias": "unário",
    "unários": "unário",
    "unásseis": "unar",
    "unássemos": "unar",
    "unávamo": "unar",
    "unávamos": "unar",
    "unávei": "unar",
    "unáveis": "unar",
    "unânimes": "unânime",
    "unções": "unção",
    "uníamo": "unir",
    "uníamos": "unir",
    "uníei": "unir",
    "uníeis": "unir",
    "unígama": "unígamo",
    "unígamas": "unígamo",
    "unígamos": "unígamo",
    "uníjuga": "uníjugo",
    "uníjugas": "uníjugo",
    "uníjugos": "uníjugo",
    "uníloqua": "uníloquo",
    "uníloquas": "uníloquo",
    "uníloquos": "uníloquo",
    "unímana": "unímano",
    "unímanas": "unímano",
    "unímanos": "unímano",
    "unípara": "uníparo",
    "uníparas": "uníparo",
    "uníparos": "uníparo",
    "unípedes": "unípede",
    "uníramo": "unir",
    "uníramos": "unir",
    "unírei": "unir",
    "uníreis": "unir",
    "unísseis": "unir",
    "uníssemos": "unir",
    "uníssona": "uníssono",
    "uníssonas": "uníssono",
    "uníssonos": "uníssono",
    "uníveis": "unível",
    "unívoca": "unívoco",
    "unívocas": "unívoco",
    "unívocos": "unívoco",
    "unócula": "unóculo",
    "unóculas": "unóculo",
    "unóculos": "unóculo",
    "upa": "upar",
    "upada": "upar",
    "upadas": "upar",
    "upado": "upar",
    "upados": "upar",
    "upai": "upar",
    "upais": "upar",
    "upam": "upar",
    "upamo": "upar",
    "upamos": "upar",
    "upandas": "upanda",
    "upando": "upar",
    "upara": "upar",
    "uparam": "upar",
    "uparas": "upar",
    "upardes": "upar",
    "uparei": "upar",
    "upareis": "upar",
    "uparem": "upar",
    "uparemos": "upar",
    "upares": "upar",
    "uparia": "upar",
    "upariam": "upar",
    "uparias": "upar",
    "uparmo": "upar",
    "uparmos": "upar",
    "upará": "upar",
    "uparás": "upar",
    "uparão": "upar",
    "uparíamos": "upar",
    "uparíeis": "upar",
    "upas": "upar",
    "upasse": "upar",
    "upassem": "upar",
    "upasses": "upar",
    "upaste": "upar",
    "upastes": "upar",
    "upava": "upar",
    "upavam": "upar",
    "upavas": "upar",
    "upe": "upar",
    "upei": "upar",
    "upeis": "upar",
    "upem": "upar",
    "upemo": "upar",
    "upemos": "upar",
    "upes": "upar",
    "upo": "upar",
    "upou": "upar",
    "upupídeos": "upupídeo",
    "upámo": "upar",
    "upámos": "upar",
    "upáramo": "upar",
    "upáramos": "upar",
    "upáreis": "upar",
    "upásseis": "upar",
    "upássemos": "upar",
    "upávamo": "upar",
    "upávamos": "upar",
    "upáveis": "upável",
    "upúpidas": "upúpida",
    "uracas": "uraca",
    "uraliana": "uraliano",
    "uralianas": "uraliano",
    "uralianos": "uraliano",
    "uralites": "uralite",
    "uralitizações": "uralitização",
    "uranelídeos": "uranelídeo",
    "uraninites": "uraninite",
    "uranismos": "uranismo",
    "uranistas": "uranista",
    "uranites": "uranite",
    "uranografias": "uranografia",
    "uranográfica": "uranográfico",
    "uranográficas": "uranográfico",
    "uranográficos": "uranográfico",
    "uranologias": "uranologia",
    "uranológica": "uranológico",
    "uranológicas": "uranológico",
    "uranológicos": "uranológico",
    "uranometrias": "uranometria",
    "uranométrica": "uranométrico",
    "uranométricas": "uranométrico",
    "uranométricos": "uranométrico",
    "uranoplastias": "uranoplastia",
    "uranoramas": "uranorama",
    "uranos": "urano",
    "uranoscopias": "uranoscopia",
    "uranófana": "uranófano",
    "uranófanas": "uranófano",
    "uranófanos": "uranófano",
    "uranógrafos": "uranógrafo",
    "uranólitos": "uranólito",
    "uraparás": "urapará",
    "uraquitãs": "uraquitã",
    "uras": "ura",
    "urbana": "urbano",
    "urbanas": "urbano",
    "urbanidades": "urbanidade",
    "urbanismos": "urbanismo",
    "urbanistas": "urbanista",
    "urbanitas": "urbanita",
    "urbaniza": "urbanizar",
    "urbanizada": "urbanizar",
    "urbanizadas": "urbanizar",
    "urbanizado": "urbanizar",
    "urbanizadora": "urbanizador",
    "urbanizadoras": "urbanizador",
    "urbanizadores": "urbanizador",
    "urbanizados": "urbanizar",
    "urbanizadíssima": "urbanizado",
    "urbanizadíssimas": "urbanizado",
    "urbanizadíssimo": "urbanizado",
    "urbanizadíssimos": "urbanizado",
    "urbanizai": "urbanizar",
    "urbanizais": "urbanizar",
    "urbanizam": "urbanizar",
    "urbanizamo": "urbanizar",
    "urbanizamos": "urbanizar",
    "urbanizando": "urbanizar",
    "urbanizara": "urbanizar",
    "urbanizaram": "urbanizar",
    "urbanizaras": "urbanizar",
    "urbanizarde": "urbanizar",
    "urbanizardes": "urbanizar",
    "urbanizare": "urbanizar",
    "urbanizarei": "urbanizar",
    "urbanizareis": "urbanizar",
    "urbanizarem": "urbanizar",
    "urbanizaremos": "urbanizar",
    "urbanizares": "urbanizar",
    "urbanizaria": "urbanizar",
    "urbanizariam": "urbanizar",
    "urbanizarias": "urbanizar",
    "urbanizarmo": "urbanizar",
    "urbanizarmos": "urbanizar",
    "urbanizará": "urbanizar",
    "urbanizarás": "urbanizar",
    "urbanizarão": "urbanizar",
    "urbanizaríamos": "urbanizar",
    "urbanizaríeis": "urbanizar",
    "urbanizas": "urbanizar",
    "urbanizasse": "urbanizar",
    "urbanizassem": "urbanizar",
    "urbanizasses": "urbanizar",
    "urbanizaste": "urbanizar",
    "urbanizastes": "urbanizar",
    "urbanizava": "urbanizar",
    "urbanizavam": "urbanizar",
    "urbanizavas": "urbanizar",
    "urbanizações": "urbanização",
    "urbanize": "urbanizar",
    "urbanizei": "urbanizar",
    "urbanizeis": "urbanizar",
    "urbanizem": "urbanizar",
    "urbanizemo": "urbanizar",
    "urbanizemos": "urbanizar",
    "urbanizes": "urbanizar",
    "urbanizo": "urbanizar",
    "urbanizou": "urbanizar",
    "urbanizá": "urbanizar",
    "urbanizámo": "urbanizar",
    "urbanizámos": "urbanizar",
    "urbanizáramo": "urbanizar",
    "urbanizáramos": "urbanizar",
    "urbanizárei": "urbanizar",
    "urbanizáreis": "urbanizar",
    "urbanizásseis": "urbanizar",
    "urbanizássemos": "urbanizar",
    "urbanizávamo": "urbanizar",
    "urbanizávamos": "urbanizar",
    "urbanizávei": "urbanizar",
    "urbanizáveis": "urbanizável",
    "urbanos": "urbano",
    "urbanística": "urbanístico",
    "urbanísticas": "urbanístico",
    "urbanísticos": "urbanístico",
    "urbes": "urbe",
    "urbícolas": "urbícola",
    "urbígenas": "urbígena",
    "urcas": "urca",
    "urceolada": "urceolado",
    "urceoladas": "urceolado",
    "urceolados": "urceolado",
    "urceolares": "urceolar",
    "urceolífera": "urceolífero",
    "urceolíferas": "urceolífero",
    "urceolíferos": "urceolífero",
    "urchilas": "urchila",
    "urcholhas": "urcholha",
    "urcos": "urco",
    "urcéolas": "urcéola",
    "urcéolos": "urcéolo",
    "urda": "urdir",
    "urdais": "urdir",
    "urdam": "urdir",
    "urdamo": "urdir",
    "urdamos": "urdir",
    "urdas": "urdir",
    "urde": "urdir",
    "urdedos": "urdedo",
    "urdem": "urdir",
    "urdes": "urdir",
    "urdi": "urdir",
    "urdia": "urdir",
    "urdiam": "urdir",
    "urdias": "urdir",
    "urdida": "urdir",
    "urdidas": "urdir",
    "urdideiras": "urdideira",
    "urdido": "urdir",
    "urdidora": "urdidor",
    "urdidoras": "urdidor",
    "urdidores": "urdidor",
    "urdidos": "urdir",
    "urdiduras": "urdidura",
    "urdimentas": "urdimenta",
    "urdimentos": "urdimento",
    "urdimo": "urdir",
    "urdimos": "urdir",
    "urdindo": "urdir",
    "urdira": "urdir",
    "urdiram": "urdir",
    "urdiras": "urdir",
    "urdirde": "urdir",
    "urdirdes": "urdir",
    "urdire": "urdir",
    "urdirei": "urdir",
    "urdireis": "urdir",
    "urdirem": "urdir",
    "urdiremos": "urdir",
    "urdires": "urdir",
    "urdiria": "urdir",
    "urdiriam": "urdir",
    "urdirias": "urdir",
    "urdirmo": "urdir",
    "urdirmos": "urdir",
    "urdirá": "urdir",
    "urdirás": "urdir",
    "urdirão": "urdir",
    "urdiríamos": "urdir",
    "urdiríeis": "urdir",
    "urdis": "urdir",
    "urdisse": "urdir",
    "urdissem": "urdir",
    "urdisses": "urdir",
    "urdiste": "urdir",
    "urdistes": "urdir",
    "urdiu": "urdir",
    "urdo": "urdir",
    "urdumes": "urdume",
    "urdus": "urdu",
    "urdíamo": "urdir",
    "urdíamos": "urdir",
    "urdíei": "urdir",
    "urdíeis": "urdir",
    "urdíramo": "urdir",
    "urdíramos": "urdir",
    "urdírei": "urdir",
    "urdíreis": "urdir",
    "urdísseis": "urdir",
    "urdíssemos": "urdir",
    "urdíveis": "urdível",
    "ureases": "urease",
    "uredos": "uredo",
    "uredínea": "uredíneo",
    "uredíneas": "uredíneo",
    "uredíneos": "uredíneo",
    "uredósporos": "uredósporo",
    "ureias": "ureia",
    "uremias": "uremia",
    "urentes": "urente",
    "ureometrias": "ureometria",
    "uretalgias": "uretalgia",
    "ureterais": "ureteral",
    "ureteralgias": "ureteralgia",
    "ureterectomias": "ureterectomia",
    "ureterites": "ureterite",
    "ureterografias": "ureterografia",
    "ureterotomias": "ureterotomia",
    "uretrais": "uretral",
    "uretralgias": "uretralgia",
    "uretras": "uretra",
    "uretrectomias": "uretrectomia",
    "uretrites": "uretrite",
    "uretrocistotomias": "uretrocistotomia",
    "uretrodinias": "uretrodinia",
    "uretrofraxias": "uretrofraxia",
    "uretrorragias": "uretrorragia",
    "uretrorrectais": "uretrorrectal",
    "uretrorreias": "uretrorreia",
    "uretroscopias": "uretroscopia",
    "uretroscópica": "uretroscópico",
    "uretroscópicas": "uretroscópico",
    "uretroscópicos": "uretroscópico",
    "uretroscópios": "uretroscópio",
    "uretrostenias": "uretrostenia",
    "uretrostenoses": "uretrostenose",
    "uretrostomias": "uretrostomia",
    "uretrotomias": "uretrotomia",
    "uretrovaginais": "uretrovaginal",
    "uretrálgica": "uretrálgico",
    "uretrálgicas": "uretrálgico",
    "uretrálgicos": "uretrálgico",
    "uretálgica": "uretálgico",
    "uretálgicas": "uretálgico",
    "uretálgicos": "uretálgico",
    "uretérica": "uretérico",
    "uretéricas": "uretérico",
    "uretéricos": "uretérico",
    "urge": "urgir",
    "urgebões": "urgebão",
    "urgem": "urgir",
    "urgemantas": "urgemanta",
    "urgentes": "urgente",
    "urgentíssima": "urgente",
    "urgentíssimas": "urgente",
    "urgentíssimo": "urgente",
    "urgentíssimos": "urgente",
    "urges": "urgir",
    "urgevões": "urgevão",
    "urgi": "urgir",
    "urgia": "urgir",
    "urgiam": "urgir",
    "urgias": "urgir",
    "urgida": "urgir",
    "urgidas": "urgir",
    "urgido": "urgir",
    "urgidos": "urgir",
    "urgidíssima": "urgido",
    "urgidíssimas": "urgido",
    "urgidíssimo": "urgido",
    "urgidíssimos": "urgido",
    "urgimo": "urgir",
    "urgimos": "urgir",
    "urgindo": "urgir",
    "urgira": "urgir",
    "urgiram": "urgir",
    "urgiras": "urgir",
    "urgirdes": "urgir",
    "urgirei": "urgir",
    "urgireis": "urgir",
    "urgirem": "urgir",
    "urgiremos": "urgir",
    "urgires": "urgir",
    "urgiria": "urgir",
    "urgiriam": "urgir",
    "urgirias": "urgir",
    "urgirmo": "urgir",
    "urgirmos": "urgir",
    "urgirá": "urgir",
    "urgirás": "urgir",
    "urgirão": "urgir",
    "urgiríamos": "urgir",
    "urgiríeis": "urgir",
    "urgis": "urgir",
    "urgisse": "urgir",
    "urgissem": "urgir",
    "urgisses": "urgir",
    "urgiste": "urgir",
    "urgistes": "urgir",
    "urgiu": "urgir",
    "urgueirais": "urgueiral",
    "urgueiras": "urgueira",
    "urgências": "urgência",
    "urgíamo": "urgir",
    "urgíamos": "urgir",
    "urgíeis": "urgir",
    "urgíramo": "urgir",
    "urgíramos": "urgir",
    "urgíreis": "urgir",
    "urgísseis": "urgir",
    "urgíssemos": "urgir",
    "urgíveis": "urgível",
    "uricanas": "uricana",
    "uricemias": "uricemia",
    "uricémica": "uricémico",
    "uricémicas": "uricémico",
    "uricémicos": "uricémico",
    "urina": "urinar",
    "urinada": "urinar",
    "urinadas": "urinar",
    "urinado": "urinar",
    "urinados": "urinar",
    "urinai": "urinar",
    "urinais": "urinar",
    "urinam": "urinar",
    "urinamo": "urinar",
    "urinamos": "urinar",
    "urinando": "urinar",
    "urinara": "urinar",
    "urinaram": "urinar",
    "urinaras": "urinar",
    "urinardes": "urinar",
    "urinarei": "urinar",
    "urinareis": "urinar",
    "urinarem": "urinar",
    "urinaremos": "urinar",
    "urinares": "urinar",
    "urinaria": "urinar",
    "urinariam": "urinar",
    "urinarias": "urinar",
    "urinarmo": "urinar",
    "urinarmos": "urinar",
    "urinará": "urinar",
    "urinarás": "urinar",
    "urinarão": "urinar",
    "urinaríamos": "urinar",
    "urinaríeis": "urinar",
    "urinas": "urinar",
    "urinasse": "urinar",
    "urinassem": "urinar",
    "urinasses": "urinar",
    "urinaste": "urinar",
    "urinastes": "urinar",
    "urinava": "urinar",
    "urinavam": "urinar",
    "urinavas": "urinar",
    "urinações": "urinação",
    "urine": "urinar",
    "urinei": "urinar",
    "urineis": "urinar",
    "urinem": "urinar",
    "urinemo": "urinar",
    "urinemos": "urinar",
    "urines": "urinar",
    "urino": "urinar",
    "urinosa": "urinoso",
    "urinosas": "urinoso",
    "urinosos": "urinoso",
    "urinou": "urinar",
    "urinámo": "urinar",
    "urinámos": "urinar",
    "urináramo": "urinar",
    "urináramos": "urinar",
    "urináreis": "urinar",
    "urinária": "urinário",
    "urinárias": "urinário",
    "urinários": "urinário",
    "urinásseis": "urinar",
    "urinássemos": "urinar",
    "urinávamo": "urinar",
    "urinávamos": "urinar",
    "urináveis": "urinável",
    "urinífera": "urinífero",
    "uriníferas": "urinífero",
    "uriníferos": "urinífero",
    "urinípara": "uriníparo",
    "uriníparas": "uriníparo",
    "uriníparos": "uriníparo",
    "urinóis": "urinol",
    "uritutus": "uritutu",
    "urja": "urgir",
    "urjais": "urgir",
    "urjam": "urgir",
    "urjamo": "urgir",
    "urjamos": "urgir",
    "urjas": "urgir",
    "urjo": "urgir",
    "urnas": "urna",
    "urnários": "urnário",
    "urnígera": "urnígero",
    "urnígeras": "urnígero",
    "urnígeros": "urnígero",
    "urobilinas": "urobilina",
    "urobrânquia": "urobrânquio",
    "urobrânquias": "urobrânquio",
    "urobrânquios": "urobrânquio",
    "urocistes": "urociste",
    "urocistites": "urocistite",
    "urocistos": "urocisto",
    "urocordada": "urocordado",
    "urocordadas": "urocordado",
    "urocordados": "urocordado",
    "urocrisias": "urocrisia",
    "urocromas": "urocroma",
    "urocrítica": "urocrítico",
    "urocríticas": "urocrítico",
    "urocríticos": "urocrítico",
    "urodela": "urodelo",
    "urodelas": "urodelo",
    "urodelos": "urodelo",
    "urodinias": "urodinia",
    "urofilias": "urofilia",
    "urogenitais": "urogenital",
    "urografias": "urografia",
    "urologias": "urologia",
    "urologistas": "urologista",
    "urológica": "urológico",
    "urológicas": "urológico",
    "urológicos": "urológico",
    "uropigiais": "uropigial",
    "uropoeses": "uropoese",
    "uropoieses": "uropoiese",
    "uropígios": "uropígio",
    "uropódios": "uropódio",
    "urorragias": "urorragia",
    "urorreias": "urorreia",
    "uros": "uro",
    "uroscopias": "uroscopia",
    "uroscópica": "uroscópico",
    "uroscópicas": "uroscópico",
    "uroscópicos": "uroscópico",
    "urostilos": "urostilo",
    "urotropinas": "urotropina",
    "uroxantinas": "uroxantina",
    "urra": "urrar",
    "urracas": "urraca",
    "urrada": "urrar",
    "urradas": "urrar",
    "urrado": "urrar",
    "urradora": "urrador",
    "urradoras": "urrador",
    "urradores": "urrador",
    "urrados": "urrar",
    "urrai": "urrar",
    "urrais": "urrar",
    "urram": "urrar",
    "urramo": "urrar",
    "urramos": "urrar",
    "urrando": "urrar",
    "urrara": "urrar",
    "urraram": "urrar",
    "urraras": "urrar",
    "urrardes": "urrar",
    "urrarei": "urrar",
    "urrareis": "urrar",
    "urrarem": "urrar",
    "urraremos": "urrar",
    "urrares": "urrar",
    "urraria": "urrar",
    "urrariam": "urrar",
    "urrarias": "urrar",
    "urrarmo": "urrar",
    "urrarmos": "urrar",
    "urrará": "urrar",
    "urrarás": "urrar",
    "urrarão": "urrar",
    "urraríamos": "urrar",
    "urraríeis": "urrar",
    "urras": "urrar",
    "urrasse": "urrar",
    "urrassem": "urrar",
    "urrasses": "urrar",
    "urraste": "urrar",
    "urrastes": "urrar",
    "urrava": "urrar",
    "urravam": "urrar",
    "urravas": "urrar",
    "urre": "urrar",
    "urrei": "urrar",
    "urreis": "urrar",
    "urrem": "urrar",
    "urremo": "urrar",
    "urremos": "urrar",
    "urres": "urrar",
    "urro": "urrar",
    "urros": "urro",
    "urrou": "urrar",
    "urrámo": "urrar",
    "urrámos": "urrar",
    "urráramo": "urrar",
    "urráramos": "urrar",
    "urráreis": "urrar",
    "urrásseis": "urrar",
    "urrássemos": "urrar",
    "urrávamo": "urrar",
    "urrávamos": "urrar",
    "urráveis": "urrável",
    "ursa": "urso",
    "ursas": "urso",
    "ursina": "ursino",
    "ursinas": "ursino",
    "ursinha": "urso",
    "ursinhas": "urso",
    "ursinho": "urso",
    "ursinhos": "urso",
    "ursinos": "ursino",
    "ursita": "urso",
    "ursitas": "urso",
    "ursito": "urso",
    "ursitos": "urso",
    "ursos": "urso",
    "ursulinas": "ursulina",
    "ursídeos": "ursídeo",
    "urtica": "urticar",
    "urticada": "urticar",
    "urticadas": "urticar",
    "urticado": "urticar",
    "urticados": "urticar",
    "urticai": "urticar",
    "urticais": "urticar",
    "urticam": "urticar",
    "urticamo": "urticar",
    "urticamos": "urticar",
    "urticando": "urticar",
    "urticantes": "urticante",
    "urticara": "urticar",
    "urticaram": "urticar",
    "urticaras": "urticar",
    "urticarde": "urticar",
    "urticardes": "urticar",
    "urticare": "urticar",
    "urticarei": "urticar",
    "urticareis": "urticar",
    "urticarem": "urticar",
    "urticaremos": "urticar",
    "urticares": "urticar",
    "urticaria": "urticar",
    "urticariam": "urticar",
    "urticarias": "urticar",
    "urticarmo": "urticar",
    "urticarmos": "urticar",
    "urticará": "urticar",
    "urticarás": "urticar",
    "urticarão": "urticar",
    "urticaríamos": "urticar",
    "urticaríeis": "urticar",
    "urticas": "urticar",
    "urticasse": "urticar",
    "urticassem": "urticar",
    "urticasses": "urticar",
    "urticaste": "urticar",
    "urticastes": "urticar",
    "urticava": "urticar",
    "urticavam": "urticar",
    "urticavas": "urticar",
    "urticações": "urticação",
    "urticifoliada": "urticifoliado",
    "urticifoliadas": "urticifoliado",
    "urticifoliados": "urticifoliado",
    "urtico": "urticar",
    "urticou": "urticar",
    "urticá": "urticar",
    "urticáceas": "urticácea",
    "urticámo": "urticar",
    "urticámos": "urticar",
    "urticáramo": "urticar",
    "urticáramos": "urticar",
    "urticárei": "urticar",
    "urticáreis": "urticar",
    "urticárias": "urticária",
    "urticásseis": "urticar",
    "urticássemos": "urticar",
    "urticávamo": "urticar",
    "urticávamos": "urticar",
    "urticávei": "urticar",
    "urticáveis": "urticável",
    "urtiga": "urtigar",
    "urtigada": "urtigar",
    "urtigadas": "urtigar",
    "urtigado": "urtigar",
    "urtigados": "urtigar",
    "urtigai": "urtigar",
    "urtigais": "urtigar",
    "urtigam": "urtigar",
    "urtigamo": "urtigar",
    "urtigamos": "urtigar",
    "urtigando": "urtigar",
    "urtigara": "urtigar",
    "urtigaram": "urtigar",
    "urtigaras": "urtigar",
    "urtigarde": "urtigar",
    "urtigardes": "urtigar",
    "urtigare": "urtigar",
    "urtigarei": "urtigar",
    "urtigareis": "urtigar",
    "urtigarem": "urtigar",
    "urtigaremos": "urtigar",
    "urtigares": "urtigar",
    "urtigaria": "urtigar",
    "urtigariam": "urtigar",
    "urtigarias": "urtigar",
    "urtigarmo": "urtigar",
    "urtigarmos": "urtigar",
    "urtigará": "urtigar",
    "urtigarás": "urtigar",
    "urtigarão": "urtigar",
    "urtigaríamos": "urtigar",
    "urtigaríeis": "urtigar",
    "urtigas": "urtigar",
    "urtigasse": "urtigar",
    "urtigassem": "urtigar",
    "urtigasses": "urtigar",
    "urtigaste": "urtigar",
    "urtigastes": "urtigar",
    "urtigava": "urtigar",
    "urtigavam": "urtigar",
    "urtigavas": "urtigar",
    "urtigações": "urtigação",
    "urtigo": "urtigar",
    "urtigou": "urtigar",
    "urtigue": "urtigar",
    "urtiguei": "urtigar",
    "urtigueis": "urtigar",
    "urtiguem": "urtigar",
    "urtiguemo": "urtigar",
    "urtiguemos": "urtigar",
    "urtigues": "urtigar",
    "urtigá": "urtigar",
    "urtigámo": "urtigar",
    "urtigámos": "urtigar",
    "urtigáramo": "urtigar",
    "urtigáramos": "urtigar",
    "urtigárei": "urtigar",
    "urtigáreis": "urtigar",
    "urtigásseis": "urtigar",
    "urtigássemos": "urtigar",
    "urtigávamo": "urtigar",
    "urtigávamos": "urtigar",
    "urtigávei": "urtigar",
    "urtigáveis": "urtigável",
    "urtigões": "urtigão",
    "urtique": "urticar",
    "urtiquei": "urticar",
    "urtiqueis": "urticar",
    "urtiquem": "urticar",
    "urtiquemo": "urticar",
    "urtiquemos": "urticar",
    "urtiques": "urticar",
    "urtíceas": "urtícea",
    "urubus": "urubu",
    "urubuzinhos": "urubuzinho",
    "urucaris": "urucari",
    "urucubacas": "urucubaca",
    "urucueiros": "urucueiro",
    "urucuris": "urucuri",
    "urucus": "urucu",
    "urucuubas": "urucuuba",
    "urucuzeiros": "urucuzeiro",
    "uruguaia": "uruguaio",
    "uruguaiana": "uruguaiano",
    "uruguaianas": "uruguaiano",
    "uruguaianos": "uruguaiano",
    "uruguaias": "uruguaio",
    "uruguaios": "uruguaio",
    "urupemas": "urupema",
    "urupês": "urupê",
    "ururuguaia": "ururuguaio",
    "ururuguaias": "ururuguaio",
    "ururuguaios": "ururuguaio",
    "urus": "uru",
    "urutaguas": "urutagua",
    "urutaus": "urutau",
    "urutus": "urutu",
    "uruçumirins": "uruçumirim",
    "uruçus": "uruçu",
    "urzais": "urzal",
    "urzeiras": "urzeira",
    "urzelas": "urzela",
    "urzelinas": "urzelina",
    "urzes": "urze",
    "urzibelhas": "urzibelha",
    "urália": "urálio",
    "urálias": "urálio",
    "urálios": "urálio",
    "urânias": "urânia",
    "urânica": "urânico",
    "urânicas": "urânico",
    "urânicos": "urânico",
    "urânios": "urânio",
    "uréases": "uréase",
    "urémica": "urémico",
    "urémicas": "urémico",
    "urémicos": "urémico",
    "uréteres": "uréter",
    "urética": "urético",
    "uréticas": "urético",
    "uréticos": "urético",
    "urétrica": "urétrico",
    "urétricas": "urétrico",
    "urétricos": "urétrico",
    "urências": "urência",
    "urólitos": "urólito",
    "uróloga": "urólogo",
    "urólogas": "urólogo",
    "urólogos": "urólogo",
    "urópodes": "urópode",
    "usa": "usar",
    "usada": "usar",
    "usadas": "usar",
    "usado": "usar",
    "usados": "usar",
    "usadíssima": "usado",
    "usadíssimas": "usado",
    "usadíssimo": "usado",
    "usadíssimos": "usado",
    "usagres": "usagre",
    "usai": "usar",
    "usais": "usar",
    "usam": "usar",
    "usamo": "usar",
    "usamos": "usar",
    "usando": "usar",
    "usanças": "usança",
    "usara": "usar",
    "usaram": "usar",
    "usaras": "usar",
    "usarde": "usar",
    "usardes": "usar",
    "usare": "usar",
    "usarei": "usar",
    "usareis": "usar",
    "usarem": "usar",
    "usaremos": "usar",
    "usares": "usar",
    "usaria": "usar",
    "usariam": "usar",
    "usarias": "usar",
    "usarmo": "usar",
    "usarmos": "usar",
    "usará": "usar",
    "usarás": "usar",
    "usarão": "usar",
    "usaríamos": "usar",
    "usaríeis": "usar",
    "usas": "usar",
    "usasse": "usar",
    "usassem": "usar",
    "usasses": "usar",
    "usaste": "usar",
    "usastes": "usar",
    "usava": "usar",
    "usavam": "usar",
    "usavas": "usar",
    "use": "usar",
    "usei": "usar",
    "useira": "useiro",
    "useiras": "useiro",
    "useiros": "useiro",
    "useis": "usar",
    "usem": "usar",
    "usemo": "usar",
    "usemos": "usar",
    "uses": "usar",
    "usgas": "usga",
    "usinas": "usina",
    "usineira": "usineiro",
    "usineiras": "usineiro",
    "usineiros": "usineiro",
    "usita": "usitar",
    "usitada": "usitar",
    "usitadas": "usitar",
    "usitado": "usitar",
    "usitados": "usitar",
    "usitai": "usitar",
    "usitais": "usitar",
    "usitam": "usitar",
    "usitamo": "usitar",
    "usitamos": "usitar",
    "usitando": "usitar",
    "usitara": "usitar",
    "usitaram": "usitar",
    "usitaras": "usitar",
    "usitarde": "usitar",
    "usitardes": "usitar",
    "usitare": "usitar",
    "usitarei": "usitar",
    "usitareis": "usitar",
    "usitarem": "usitar",
    "usitaremos": "usitar",
    "usitares": "usitar",
    "usitaria": "usitar",
    "usitariam": "usitar",
    "usitarias": "usitar",
    "usitarmo": "usitar",
    "usitarmos": "usitar",
    "usitará": "usitar",
    "usitarás": "usitar",
    "usitarão": "usitar",
    "usitaríamos": "usitar",
    "usitaríeis": "usitar",
    "usitas": "usitar",
    "usitasse": "usitar",
    "usitassem": "usitar",
    "usitasses": "usitar",
    "usitaste": "usitar",
    "usitastes": "usitar",
    "usitava": "usitar",
    "usitavam": "usitar",
    "usitavas": "usitar",
    "usite": "usitar",
    "usitei": "usitar",
    "usiteis": "usitar",
    "usitem": "usitar",
    "usitemo": "usitar",
    "usitemos": "usitar",
    "usites": "usitar",
    "usito": "usitar",
    "usitou": "usitar",
    "usitá": "usitar",
    "usitámo": "usitar",
    "usitámos": "usitar",
    "usitáramo": "usitar",
    "usitáramos": "usitar",
    "usitárei": "usitar",
    "usitáreis": "usitar",
    "usitásseis": "usitar",
    "usitássemos": "usitar",
    "usitávamo": "usitar",
    "usitávamos": "usitar",
    "usitávei": "usitar",
    "usitáveis": "usitar",
    "usneáceas": "usneácea",
    "uso": "usar",
    "usos": "uso",
    "usou": "usar",
    "ussa": "usso",
    "ussas": "usso",
    "ussos": "usso",
    "usta": "usto",
    "ustais": "ustir",
    "ustam": "ustir",
    "ustamo": "ustir",
    "ustamos": "ustir",
    "ustas": "usto",
    "uste": "ustir",
    "ustem": "ustir",
    "ustes": "ustir",
    "usti": "ustir",
    "ustia": "ustir",
    "ustiam": "ustir",
    "ustias": "ustir",
    "ustida": "ustir",
    "ustidas": "ustir",
    "ustido": "ustir",
    "ustidos": "ustir",
    "ustimo": "ustir",
    "ustimos": "ustir",
    "ustindo": "ustir",
    "ustira": "ustir",
    "ustiram": "ustir",
    "ustiras": "ustir",
    "ustirde": "ustir",
    "ustirdes": "ustir",
    "ustire": "ustir",
    "ustirei": "ustir",
    "ustireis": "ustir",
    "ustirem": "ustir",
    "ustiremos": "ustir",
    "ustires": "ustir",
    "ustiria": "ustir",
    "ustiriam": "ustir",
    "ustirias": "ustir",
    "ustirmo": "ustir",
    "ustirmos": "ustir",
    "ustirá": "ustir",
    "ustirás": "ustir",
    "ustirão": "ustir",
    "ustiríamos": "ustir",
    "ustiríeis": "ustir",
    "ustis": "ustir",
    "ustisse": "ustir",
    "ustissem": "ustir",
    "ustisses": "ustir",
    "ustiste": "ustir",
    "ustistes": "ustir",
    "ustiu": "ustir",
    "usto": "ustir",
    "ustos": "usto",
    "ustula": "ustular",
    "ustulada": "ustular",
    "ustuladas": "ustular",
    "ustulado": "ustular",
    "ustulados": "ustular",
    "ustulai": "ustular",
    "ustulais": "ustular",
    "ustulam": "ustular",
    "ustulamo": "ustular",
    "ustulamos": "ustular",
    "ustulando": "ustular",
    "ustulara": "ustular",
    "ustularam": "ustular",
    "ustularas": "ustular",
    "ustularde": "ustular",
    "ustulardes": "ustular",
    "ustulare": "ustular",
    "ustularei": "ustular",
    "ustulareis": "ustular",
    "ustularem": "ustular",
    "ustularemos": "ustular",
    "ustulares": "ustular",
    "ustularia": "ustular",
    "ustulariam": "ustular",
    "ustularias": "ustular",
    "ustularmo": "ustular",
    "ustularmos": "ustular",
    "ustulará": "ustular",
    "ustularás": "ustular",
    "ustularão": "ustular",
    "ustularíamos": "ustular",
    "ustularíeis": "ustular",
    "ustulas": "ustular",
    "ustulasse": "ustular",
    "ustulassem": "ustular",
    "ustulasses": "ustular",
    "ustulaste": "ustular",
    "ustulastes": "ustular",
    "ustulava": "ustular",
    "ustulavam": "ustular",
    "ustulavas": "ustular",
    "ustulações": "ustulação",
    "ustule": "ustular",
    "ustulei": "ustular",
    "ustuleis": "ustular",
    "ustulem": "ustular",
    "ustulemo": "ustular",
    "ustulemos": "ustular",
    "ustules": "ustular",
    "ustulo": "ustular",
    "ustulou": "ustular",
    "ustulá": "ustular",
    "ustulámo": "ustular",
    "ustulámos": "ustular",
    "ustuláramo": "ustular",
    "ustuláramos": "ustular",
    "ustulárei": "ustular",
    "ustuláreis": "ustular",
    "ustulásseis": "ustular",
    "ustulássemos": "ustular",
    "ustulávamo": "ustular",
    "ustulávamos": "ustular",
    "ustulávei": "ustular",
    "ustuláveis": "ustulável",
    "ustíamo": "ustir",
    "ustíamos": "ustir",
    "ustíei": "ustir",
    "ustíeis": "ustir",
    "ustíramo": "ustir",
    "ustíramos": "ustir",
    "ustírei": "ustir",
    "ustíreis": "ustir",
    "ustísseis": "ustir",
    "ustíssemos": "ustir",
    "ustória": "ustório",
    "ustórias": "ustório",
    "ustórios": "ustório",
    "ustões": "ustão",
    "usuais": "usual",
    "usualíssima": "usual",
    "usualíssimas": "usual",
    "usualíssimo": "usual",
    "usualíssimos": "usual",
    "usucapa": "usucapir",
    "usucapais": "usucapir",
    "usucapam": "usucapir",
    "usucapamo": "usucapir",
    "usucapamos": "usucapir",
    "usucapas": "usucapir",
    "usucape": "usucapir",
    "usucapem": "usucapir",
    "usucapes": "usucapir",
    "usucapi": "usucapir",
    "usucapia": "usucapir",
    "usucapiam": "usucapir",
    "usucapias": "usucapir",
    "usucapida": "usucapir",
    "usucapidas": "usucapir",
    "usucapido": "usucapir",
    "usucapidos": "usucapir",
    "usucapientes": "usucapiente",
    "usucapimo": "usucapir",
    "usucapimos": "usucapir",
    "usucapindo": "usucapir",
    "usucapira": "usucapir",
    "usucapiram": "usucapir",
    "usucapiras": "usucapir",
    "usucapirde": "usucapir",
    "usucapirdes": "usucapir",
    "usucapire": "usucapir",
    "usucapirei": "usucapir",
    "usucapireis": "usucapir",
    "usucapirem": "usucapir",
    "usucapiremos": "usucapir",
    "usucapires": "usucapir",
    "usucapiria": "usucapir",
    "usucapiriam": "usucapir",
    "usucapirias": "usucapir",
    "usucapirmo": "usucapir",
    "usucapirmos": "usucapir",
    "usucapirá": "usucapir",
    "usucapirás": "usucapir",
    "usucapirão": "usucapir",
    "usucapiríamos": "usucapir",
    "usucapiríeis": "usucapir",
    "usucapis": "usucapir",
    "usucapisse": "usucapir",
    "usucapissem": "usucapir",
    "usucapisses": "usucapir",
    "usucapiste": "usucapir",
    "usucapistes": "usucapir",
    "usucapiu": "usucapir",
    "usucapiões": "usucapião",
    "usucapo": "usucapir",
    "usucapta": "usucapto",
    "usucaptas": "usucapto",
    "usucaptos": "usucapto",
    "usucapíamo": "usucapir",
    "usucapíamos": "usucapir",
    "usucapíei": "usucapir",
    "usucapíeis": "usucapir",
    "usucapíramo": "usucapir",
    "usucapíramos": "usucapir",
    "usucapírei": "usucapir",
    "usucapíreis": "usucapir",
    "usucapísseis": "usucapir",
    "usucapíssemos": "usucapir",
    "usufrua": "usufruir",
    "usufruais": "usufruir",
    "usufruam": "usufruir",
    "usufruamo": "usufruir",
    "usufruamos": "usufruir",
    "usufruas": "usufruir",
    "usufruem": "usufruir",
    "usufrui": "usufruir",
    "usufruida": "usufruido",
    "usufruidas": "usufruido",
    "usufruidora": "usufruidor",
    "usufruidoras": "usufruidor",
    "usufruidores": "usufruidor",
    "usufruidos": "usufruido",
    "usufruidíssima": "usufruido",
    "usufruidíssimas": "usufruido",
    "usufruidíssimo": "usufruido",
    "usufruidíssimos": "usufruido",
    "usufruindo": "usufruir",
    "usufruirde": "usufruir",
    "usufruirdes": "usufruir",
    "usufruirei": "usufruir",
    "usufruireis": "usufruir",
    "usufruiremos": "usufruir",
    "usufruiria": "usufruir",
    "usufruiriam": "usufruir",
    "usufruirias": "usufruir",
    "usufruirmo": "usufruir",
    "usufruirmos": "usufruir",
    "usufruirá": "usufruir",
    "usufruirás": "usufruir",
    "usufruirão": "usufruir",
    "usufruiríamos": "usufruir",
    "usufruiríeis": "usufruir",
    "usufruis": "usufruir",
    "usufruiu": "usufruir",
    "usufruições": "usufruição",
    "usufruo": "usufruir",
    "usufrutos": "usufruto",
    "usufrutua": "usufrutuar",
    "usufrutuada": "usufrutuar",
    "usufrutuadas": "usufrutuar",
    "usufrutuado": "usufrutuar",
    "usufrutuados": "usufrutuar",
    "usufrutuai": "usufrutuar",
    "usufrutuais": "usufrutuar",
    "usufrutuam": "usufrutuar",
    "usufrutuamo": "usufrutuar",
    "usufrutuamos": "usufrutuar",
    "usufrutuando": "usufrutuar",
    "usufrutuara": "usufrutuar",
    "usufrutuaram": "usufrutuar",
    "usufrutuaras": "usufrutuar",
    "usufrutuarde": "usufrutuar",
    "usufrutuardes": "usufrutuar",
    "usufrutuare": "usufrutuar",
    "usufrutuarei": "usufrutuar",
    "usufrutuareis": "usufrutuar",
    "usufrutuarem": "usufrutuar",
    "usufrutuaremos": "usufrutuar",
    "usufrutuares": "usufrutuar",
    "usufrutuaria": "usufrutuar",
    "usufrutuariam": "usufrutuar",
    "usufrutuarias": "usufrutuar",
    "usufrutuarmo": "usufrutuar",
    "usufrutuarmos": "usufrutuar",
    "usufrutuará": "usufrutuar",
    "usufrutuarás": "usufrutuar",
    "usufrutuarão": "usufrutuar",
    "usufrutuaríamos": "usufrutuar",
    "usufrutuaríeis": "usufrutuar",
    "usufrutuas": "usufrutuar",
    "usufrutuasse": "usufrutuar",
    "usufrutuassem": "usufrutuar",
    "usufrutuasses": "usufrutuar",
    "usufrutuaste": "usufrutuar",
    "usufrutuastes": "usufrutuar",
    "usufrutuava": "usufrutuar",
    "usufrutuavam": "usufrutuar",
    "usufrutuavas": "usufrutuar",
    "usufrutue": "usufrutuar",
    "usufrutuei": "usufrutuar",
    "usufrutueis": "usufrutuar",
    "usufrutuem": "usufrutuar",
    "usufrutuemo": "usufrutuar",
    "usufrutuemos": "usufrutuar",
    "usufrutues": "usufrutuar",
    "usufrutuo": "usufrutuar",
    "usufrutuou": "usufrutuar",
    "usufrutuá": "usufrutuar",
    "usufrutuámo": "usufrutuar",
    "usufrutuámos": "usufrutuar",
    "usufrutuáramo": "usufrutuar",
    "usufrutuáramos": "usufrutuar",
    "usufrutuárei": "usufrutuar",
    "usufrutuáreis": "usufrutuar",
    "usufrutuária": "usufrutuário",
    "usufrutuárias": "usufrutuário",
    "usufrutuários": "usufrutuário",
    "usufrutuásseis": "usufrutuar",
    "usufrutuássemos": "usufrutuar",
    "usufrutuávamo": "usufrutuar",
    "usufrutuávamos": "usufrutuar",
    "usufrutuávei": "usufrutuar",
    "usufrutuáveis": "usufrutuável",
    "usufruí": "usufruir",
    "usufruía": "usufruir",
    "usufruíam": "usufruir",
    "usufruíamo": "usufruir",
    "usufruíamos": "usufruir",
    "usufruías": "usufruir",
    "usufruída": "usufruir",
    "usufruídas": "usufruir",
    "usufruído": "usufruir",
    "usufruídos": "usufruir",
    "usufruíei": "usufruir",
    "usufruíeis": "usufruir",
    "usufruímo": "usufruir",
    "usufruímos": "usufruir",
    "usufruíra": "usufruir",
    "usufruíram": "usufruir",
    "usufruíramo": "usufruir",
    "usufruíramos": "usufruir",
    "usufruíras": "usufruir",
    "usufruíre": "usufruir",
    "usufruírei": "usufruir",
    "usufruíreis": "usufruir",
    "usufruírem": "usufruir",
    "usufruíres": "usufruir",
    "usufruís": "usufruir",
    "usufruísse": "usufruir",
    "usufruísseis": "usufruir",
    "usufruíssem": "usufruir",
    "usufruíssemos": "usufruir",
    "usufruísses": "usufruir",
    "usufruíste": "usufruir",
    "usufruístes": "usufruir",
    "usufruíveis": "usufruível",
    "usura": "usurar",
    "usurada": "usurar",
    "usuradas": "usurar",
    "usurado": "usurar",
    "usurados": "usurar",
    "usurai": "usurar",
    "usurais": "usurar",
    "usuram": "usurar",
    "usuramo": "usurar",
    "usuramos": "usurar",
    "usurando": "usurar",
    "usurara": "usurar",
    "usuraram": "usurar",
    "usuraras": "usurar",
    "usurardes": "usurar",
    "usurarei": "usurar",
    "usurareis": "usurar",
    "usurarem": "usurar",
    "usuraremos": "usurar",
    "usurares": "usurar",
    "usuraria": "usurar",
    "usurariam": "usurar",
    "usurarias": "usurar",
    "usurarmo": "usurar",
    "usurarmos": "usurar",
    "usurará": "usurar",
    "usurarás": "usurar",
    "usurarão": "usurar",
    "usuraríamos": "usurar",
    "usuraríeis": "usurar",
    "usuras": "usurar",
    "usurasse": "usurar",
    "usurassem": "usurar",
    "usurasses": "usurar",
    "usuraste": "usurar",
    "usurastes": "usurar",
    "usurava": "usurar",
    "usuravam": "usurar",
    "usuravas": "usurar",
    "usure": "usurar",
    "usurei": "usurar",
    "usureis": "usurar",
    "usurem": "usurar",
    "usuremo": "usurar",
    "usuremos": "usurar",
    "usures": "usurar",
    "usuro": "usurar",
    "usurou": "usurar",
    "usurpa": "usurpar",
    "usurpada": "usurpar",
    "usurpadas": "usurpar",
    "usurpado": "usurpar",
    "usurpadora": "usurpador",
    "usurpadoras": "usurpador",
    "usurpadores": "usurpador",
    "usurpados": "usurpar",
    "usurpadíssima": "usurpado",
    "usurpadíssimas": "usurpado",
    "usurpadíssimo": "usurpado",
    "usurpadíssimos": "usurpado",
    "usurpai": "usurpar",
    "usurpais": "usurpar",
    "usurpam": "usurpar",
    "usurpamo": "usurpar",
    "usurpamos": "usurpar",
    "usurpando": "usurpar",
    "usurpara": "usurpar",
    "usurparam": "usurpar",
    "usurparas": "usurpar",
    "usurparde": "usurpar",
    "usurpardes": "usurpar",
    "usurpare": "usurpar",
    "usurparei": "usurpar",
    "usurpareis": "usurpar",
    "usurparem": "usurpar",
    "usurparemos": "usurpar",
    "usurpares": "usurpar",
    "usurparia": "usurpar",
    "usurpariam": "usurpar",
    "usurparias": "usurpar",
    "usurparmo": "usurpar",
    "usurparmos": "usurpar",
    "usurpará": "usurpar",
    "usurparás": "usurpar",
    "usurparão": "usurpar",
    "usurparíamos": "usurpar",
    "usurparíeis": "usurpar",
    "usurpas": "usurpar",
    "usurpasse": "usurpar",
    "usurpassem": "usurpar",
    "usurpasses": "usurpar",
    "usurpaste": "usurpar",
    "usurpastes": "usurpar",
    "usurpatória": "usurpatório",
    "usurpatórias": "usurpatório",
    "usurpatórios": "usurpatório",
    "usurpava": "usurpar",
    "usurpavam": "usurpar",
    "usurpavas": "usurpar",
    "usurpações": "usurpação",
    "usurpe": "usurpar",
    "usurpei": "usurpar",
    "usurpeis": "usurpar",
    "usurpem": "usurpar",
    "usurpemo": "usurpar",
    "usurpemos": "usurpar",
    "usurpes": "usurpar",
    "usurpo": "usurpar",
    "usurpou": "usurpar",
    "usurpá": "usurpar",
    "usurpámo": "usurpar",
    "usurpámos": "usurpar",
    "usurpáramo": "usurpar",
    "usurpáramos": "usurpar",
    "usurpárei": "usurpar",
    "usurpáreis": "usurpar",
    "usurpásseis": "usurpar",
    "usurpássemos": "usurpar",
    "usurpávamo": "usurpar",
    "usurpávamos": "usurpar",
    "usurpávei": "usurpar",
    "usurpáveis": "usurpável",
    "usurámo": "usurar",
    "usurámos": "usurar",
    "usuráramo": "usurar",
    "usuráramos": "usurar",
    "usuráreis": "usurar",
    "usurária": "usurário",
    "usurárias": "usurário",
    "usurários": "usurário",
    "usurásseis": "usurar",
    "usurássemos": "usurar",
    "usurávamo": "usurar",
    "usurávamos": "usurar",
    "usuráveis": "usurar",
    "usuária": "usuário",
    "usuárias": "usuário",
    "usuários": "usuário",
    "usá": "usar",
    "usámo": "usar",
    "usámos": "usar",
    "usáramo": "usar",
    "usáramos": "usar",
    "usárei": "usar",
    "usáreis": "usar",
    "usásseis": "usar",
    "usássemos": "usar",
    "usávamo": "usar",
    "usávamos": "usar",
    "usávei": "usar",
    "usáveis": "usável",
    "utas": "uta",
    "utenas": "utena",
    "utensilagens": "utensilagem",
    "utensilidades": "utensilidade",
    "utensílios": "utensílio",
    "utentes": "utente",
    "uteralgias": "uteralgia",
    "uteremias": "uteremia",
    "uteriformes": "uteriforme",
    "uterina": "uterino",
    "uterinas": "uterino",
    "uterinos": "uterino",
    "uterismos": "uterismo",
    "uterites": "uterite",
    "uterodinias": "uterodinia",
    "uteromanias": "uteromania",
    "uteromaníaca": "uteromaníaco",
    "uteromaníacas": "uteromaníaco",
    "uteromaníacos": "uteromaníaco",
    "uterorragias": "uterorragia",
    "uteroscopias": "uteroscopia",
    "uteroscópios": "uteroscópio",
    "uterotomias": "uterotomia",
    "uterótomos": "uterótomo",
    "uticenses": "uticense",
    "utilidades": "utilidade",
    "utilitarismos": "utilitarismo",
    "utilitaristas": "utilitarista",
    "utilitária": "utilitário",
    "utilitárias": "utilitário",
    "utilitários": "utilitário",
    "utiliza": "utilizar",
    "utilizada": "utilizar",
    "utilizadas": "utilizar",
    "utilizado": "utilizar",
    "utilizadora": "utilizador",
    "utilizadoras": "utilizador",
    "utilizadores": "utilizador",
    "utilizados": "utilizar",
    "utilizadíssima": "utilizado",
    "utilizadíssimas": "utilizado",
    "utilizadíssimo": "utilizado",
    "utilizadíssimos": "utilizado",
    "utilizai": "utilizar",
    "utilizais": "utilizar",
    "utilizam": "utilizar",
    "utilizamo": "utilizar",
    "utilizamos": "utilizar",
    "utilizando": "utilizar",
    "utilizara": "utilizar",
    "utilizaram": "utilizar",
    "utilizaras": "utilizar",
    "utilizarde": "utilizar",
    "utilizardes": "utilizar",
    "utilizare": "utilizar",
    "utilizarei": "utilizar",
    "utilizareis": "utilizar",
    "utilizarem": "utilizar",
    "utilizaremos": "utilizar",
    "utilizares": "utilizar",
    "utilizaria": "utilizar",
    "utilizariam": "utilizar",
    "utilizarias": "utilizar",
    "utilizarmo": "utilizar",
    "utilizarmos": "utilizar",
    "utilizará": "utilizar",
    "utilizarás": "utilizar",
    "utilizarão": "utilizar",
    "utilizaríamos": "utilizar",
    "utilizaríeis": "utilizar",
    "utilizas": "utilizar",
    "utilizasse": "utilizar",
    "utilizassem": "utilizar",
    "utilizasses": "utilizar",
    "utilizaste": "utilizar",
    "utilizastes": "utilizar",
    "utilizava": "utilizar",
    "utilizavam": "utilizar",
    "utilizavas": "utilizar",
    "utilizações": "utilização",
    "utilize": "utilizar",
    "utilizei": "utilizar",
    "utilizeis": "utilizar",
    "utilizem": "utilizar",
    "utilizemo": "utilizar",
    "utilizemos": "utilizar",
    "utilizes": "utilizar",
    "utilizo": "utilizar",
    "utilizou": "utilizar",
    "utilizá": "utilizar",
    "utilizámo": "utilizar",
    "utilizámos": "utilizar",
    "utilizáramo": "utilizar",
    "utilizáramos": "utilizar",
    "utilizárei": "utilizar",
    "utilizáreis": "utilizar",
    "utilizásseis": "utilizar",
    "utilizássemos": "utilizar",
    "utilizávamo": "utilizar",
    "utilizávamos": "utilizar",
    "utilizávei": "utilizar",
    "utilizáveis": "utilizável",
    "utilíssima": "útil",
    "utilíssimas": "útil",
    "utilíssimo": "útil",
    "utilíssimos": "útil",
    "utopias": "utopia",
    "utopistas": "utopista",
    "utriculares": "utricular",
    "utriculariformes": "utriculariforme",
    "utriculariácea": "utriculariáceo",
    "utriculariáceas": "utriculariáceo",
    "utriculariáceos": "utriculariáceo",
    "utriculiformes": "utriculiforme",
    "utriculosa": "utriculoso",
    "utriculosas": "utriculoso",
    "utriculosos": "utriculoso",
    "utriculárias": "utriculária",
    "utriformes": "utriforme",
    "utrários": "utrário",
    "utrículos": "utrículo",
    "uts": "ut",
    "utuabas": "utuaba",
    "utérculos": "utérculo",
    "utópica": "utópico",
    "utópicas": "utópico",
    "utópicos": "utópico",
    "uu": "u",
    "uvadas": "uvada",
    "uvaias": "uvaia",
    "uvaieiras": "uvaieira",
    "uvais": "uval",
    "uvalas": "uvala",
    "uvalhas": "uvalha",
    "uvalheiras": "uvalheira",
    "uvas": "uva",
    "uvaças": "uvaça",
    "uviformes": "uviforme",
    "uvinha": "uva",
    "uvinhas": "uva",
    "uvita": "uva",
    "uvitas": "uva",
    "uvulares": "uvular",
    "uvulariáceas": "uvulariácea",
    "uvuliformes": "uvuliforme",
    "uvulites": "uvulite",
    "uvulária": "uvulário",
    "uvulárias": "uvulário",
    "uvulários": "uvulário",
    "uvífera": "uvífero",
    "uvíferas": "uvífero",
    "uvíferos": "uvífero",
    "uxoriana": "uxoriano",
    "uxorianas": "uxoriano",
    "uxorianos": "uxoriano",
    "uxoricidas": "uxoricida",
    "uxoricídios": "uxoricídio",
    "uxória": "uxório",
    "uxórias": "uxório",
    "uxórios": "uxório",
    "uzitenses": "uzitense",
    "uzífures": "uzífur",
    "uzífuros": "uzífuro",
    "uçus": "uçu",
    "uçás": "uçá",
    "uísques": "uísque",
    "vaca": "vacar",
    "vacada": "vacar",
    "vacadas": "vacar",
    "vacado": "vacar",
    "vacados": "vacar",
    "vacais": "vacar",
    "vacam": "vacar",
    "vacamo": "vacar",
    "vacamos": "vacar",
    "vacando": "vacar",
    "vacantes": "vacante",
    "vacara": "vacar",
    "vacaram": "vacar",
    "vacaras": "vacar",
    "vacardes": "vacar",
    "vacarei": "vacar",
    "vacareis": "vacar",
    "vacarem": "vacar",
    "vacaremos": "vacar",
    "vacares": "vacar",
    "vacaria": "vacar",
    "vacariam": "vacar",
    "vacarias": "vacaria",
    "vacariis": "vacaril",
    "vacarina": "vacarino",
    "vacarinas": "vacarino",
    "vacarinos": "vacarino",
    "vacarmo": "vacar",
    "vacarmos": "vacar",
    "vacará": "vacar",
    "vacarás": "vacar",
    "vacarão": "vacar",
    "vacaríamos": "vacar",
    "vacaríeis": "vacar",
    "vacas": "vacar",
    "vacasse": "vacar",
    "vacassem": "vacar",
    "vacasses": "vacar",
    "vacaste": "vacar",
    "vacastes": "vacar",
    "vacaturas": "vacatura",
    "vacava": "vacar",
    "vacavam": "vacar",
    "vacavas": "vacar",
    "vacazinha": "boi",
    "vacazinhas": "boi",
    "vacazita": "boi",
    "vacazitas": "boi",
    "vacações": "vacação",
    "vacila": "vacilar",
    "vacilada": "vacilar",
    "vaciladas": "vacilar",
    "vacilado": "vacilar",
    "vacilados": "vacilar",
    "vacilai": "vacilar",
    "vacilais": "vacilar",
    "vacilam": "vacilar",
    "vacilamo": "vacilar",
    "vacilamos": "vacilar",
    "vacilando": "vacilar",
    "vacilantes": "vacilante",
    "vacilara": "vacilar",
    "vacilaram": "vacilar",
    "vacilaras": "vacilar",
    "vacilardes": "vacilar",
    "vacilarei": "vacilar",
    "vacilareis": "vacilar",
    "vacilarem": "vacilar",
    "vacilaremos": "vacilar",
    "vacilares": "vacilar",
    "vacilaria": "vacilar",
    "vacilariam": "vacilar",
    "vacilarias": "vacilar",
    "vacilarmo": "vacilar",
    "vacilarmos": "vacilar",
    "vacilará": "vacilar",
    "vacilarás": "vacilar",
    "vacilarão": "vacilar",
    "vacilaríamos": "vacilar",
    "vacilaríeis": "vacilar",
    "vacilas": "vacilar",
    "vacilasse": "vacilar",
    "vacilassem": "vacilar",
    "vacilasses": "vacilar",
    "vacilaste": "vacilar",
    "vacilastes": "vacilar",
    "vacilatória": "vacilatório",
    "vacilatórias": "vacilatório",
    "vacilatórios": "vacilatório",
    "vacilava": "vacilar",
    "vacilavam": "vacilar",
    "vacilavas": "vacilar",
    "vacilações": "vacilação",
    "vacile": "vacilar",
    "vacilei": "vacilar",
    "vacileis": "vacilar",
    "vacilem": "vacilar",
    "vacilemo": "vacilar",
    "vacilemos": "vacilar",
    "vaciles": "vacilar",
    "vacilo": "vacilar",
    "vacilou": "vacilar",
    "vacilámo": "vacilar",
    "vacilámos": "vacilar",
    "vaciláramo": "vacilar",
    "vaciláramos": "vacilar",
    "vaciláreis": "vacilar",
    "vacilásseis": "vacilar",
    "vacilássemos": "vacilar",
    "vacilávamo": "vacilar",
    "vacilávamos": "vacilar",
    "vaciláveis": "vacilar",
    "vacina": "vacinar",
    "vacinada": "vacinar",
    "vacinadas": "vacinar",
    "vacinado": "vacinar",
    "vacinadora": "vacinador",
    "vacinadoras": "vacinador",
    "vacinadores": "vacinador",
    "vacinados": "vacinar",
    "vacinadíssima": "vacinado",
    "vacinadíssimas": "vacinado",
    "vacinadíssimo": "vacinado",
    "vacinadíssimos": "vacinado",
    "vacinai": "vacinar",
    "vacinais": "vacinar",
    "vacinam": "vacinar",
    "vacinamo": "vacinar",
    "vacinamos": "vacinar",
    "vacinando": "vacinar",
    "vacinara": "vacinar",
    "vacinaram": "vacinar",
    "vacinaras": "vacinar",
    "vacinarde": "vacinar",
    "vacinardes": "vacinar",
    "vacinare": "vacinar",
    "vacinarei": "vacinar",
    "vacinareis": "vacinar",
    "vacinarem": "vacinar",
    "vacinaremos": "vacinar",
    "vacinares": "vacinar",
    "vacinaria": "vacinar",
    "vacinariam": "vacinar",
    "vacinarias": "vacinar",
    "vacinarmo": "vacinar",
    "vacinarmos": "vacinar",
    "vacinará": "vacinar",
    "vacinarás": "vacinar",
    "vacinarão": "vacinar",
    "vacinaríamos": "vacinar",
    "vacinaríeis": "vacinar",
    "vacinas": "vacinar",
    "vacinasse": "vacinar",
    "vacinassem": "vacinar",
    "vacinasses": "vacinar",
    "vacinaste": "vacinar",
    "vacinastes": "vacinar",
    "vacinava": "vacinar",
    "vacinavam": "vacinar",
    "vacinavas": "vacinar",
    "vacinações": "vacinação",
    "vacine": "vacinar",
    "vacinei": "vacinar",
    "vacineis": "vacinar",
    "vacinem": "vacinar",
    "vacinemo": "vacinar",
    "vacinemos": "vacinar",
    "vacines": "vacinar",
    "vaciniformes": "vaciniforme",
    "vacino": "vacinar",
    "vacinogenias": "vacinogenia",
    "vacinogénica": "vacinogénico",
    "vacinogénicas": "vacinogénico",
    "vacinogénicos": "vacinogénico",
    "vacinostilos": "vacinostilo",
    "vacinoterapias": "vacinoterapia",
    "vacinou": "vacinar",
    "vaciná": "vacinar",
    "vacinámo": "vacinar",
    "vacinámos": "vacinar",
    "vacináramo": "vacinar",
    "vacináramos": "vacinar",
    "vacinárei": "vacinar",
    "vacináreis": "vacinar",
    "vacinásseis": "vacinar",
    "vacinássemos": "vacinar",
    "vacinávamo": "vacinar",
    "vacinávamos": "vacinar",
    "vacinávei": "vacinar",
    "vacináveis": "vacinável",
    "vacinífera": "vacinífero",
    "vaciníferas": "vacinífero",
    "vaciníferos": "vacinífero",
    "vacinóides": "vacinóide",
    "vaco": "vacar",
    "vacou": "vacar",
    "vacuidades": "vacuidade",
    "vacuns": "vacum",
    "vacuolares": "vacuolar",
    "vacuolizações": "vacuolização",
    "vacuomas": "vacuoma",
    "vacuísmos": "vacuísmo",
    "vacuómetros": "vacuómetro",
    "vacámo": "vacar",
    "vacámos": "vacar",
    "vacáramo": "vacar",
    "vacáramos": "vacar",
    "vacáreis": "vacar",
    "vacásseis": "vacar",
    "vacássemos": "vacar",
    "vacávamo": "vacar",
    "vacávamos": "vacar",
    "vacáveis": "vacar",
    "vacâncias": "vacância",
    "vacínica": "vacínico",
    "vacínicas": "vacínico",
    "vacínicos": "vacínico",
    "vacões": "vacão",
    "vacúolos": "vacúolo",
    "vadeada": "vadear",
    "vadeadas": "vadear",
    "vadeado": "vadear",
    "vadeados": "vadear",
    "vadeai": "vadear",
    "vadeais": "vadear",
    "vadeamo": "vadear",
    "vadeamos": "vadear",
    "vadeando": "vadear",
    "vadeara": "vadear",
    "vadearam": "vadear",
    "vadearas": "vadear",
    "vadearde": "vadear",
    "vadeardes": "vadear",
    "vadeare": "vadear",
    "vadearei": "vadear",
    "vadeareis": "vadear",
    "vadearem": "vadear",
    "vadearemos": "vadear",
    "vadeares": "vadear",
    "vadearia": "vadear",
    "vadeariam": "vadear",
    "vadearias": "vadear",
    "vadearmo": "vadear",
    "vadearmos": "vadear",
    "vadeará": "vadear",
    "vadearás": "vadear",
    "vadearão": "vadear",
    "vadearíamos": "vadear",
    "vadearíeis": "vadear",
    "vadeasse": "vadear",
    "vadeassem": "vadear",
    "vadeasses": "vadear",
    "vadeaste": "vadear",
    "vadeastes": "vadear",
    "vadeava": "vadear",
    "vadeavam": "vadear",
    "vadeavas": "vadear",
    "vadeações": "vadeação",
    "vadeei": "vadear",
    "vadeeis": "vadear",
    "vadeemo": "vadear",
    "vadeemos": "vadear",
    "vadeia": "vadear",
    "vadeiam": "vadear",
    "vadeias": "vadear",
    "vadeie": "vadear",
    "vadeiem": "vadear",
    "vadeies": "vadear",
    "vadeio": "vadear",
    "vadeosa": "vadeoso",
    "vadeosas": "vadeoso",
    "vadeosos": "vadeoso",
    "vadeou": "vadear",
    "vades": "ir",
    "vadeá": "vadear",
    "vadeámo": "vadear",
    "vadeámos": "vadear",
    "vadeáramo": "vadear",
    "vadeáramos": "vadear",
    "vadeárei": "vadear",
    "vadeáreis": "vadear",
    "vadeásseis": "vadear",
    "vadeássemos": "vadear",
    "vadeávamo": "vadear",
    "vadeávamos": "vadear",
    "vadeávei": "vadear",
    "vadeáveis": "vadeável",
    "vadia": "vadio",
    "vadiada": "vadiar",
    "vadiadas": "vadiar",
    "vadiado": "vadiar",
    "vadiados": "vadiar",
    "vadiagens": "vadiagem",
    "vadiai": "vadiar",
    "vadiais": "vadiar",
    "vadiam": "vadiar",
    "vadiamo": "vadiar",
    "vadiamos": "vadiar",
    "vadiando": "vadiar",
    "vadiara": "vadiar",
    "vadiaram": "vadiar",
    "vadiaras": "vadiar",
    "vadiardes": "vadiar",
    "vadiarei": "vadiar",
    "vadiareis": "vadiar",
    "vadiarem": "vadiar",
    "vadiaremos": "vadiar",
    "vadiares": "vadiar",
    "vadiaria": "vadiar",
    "vadiariam": "vadiar",
    "vadiarias": "vadiar",
    "vadiarmo": "vadiar",
    "vadiarmos": "vadiar",
    "vadiará": "vadiar",
    "vadiarás": "vadiar",
    "vadiarão": "vadiar",
    "vadiaríamos": "vadiar",
    "vadiaríeis": "vadiar",
    "vadias": "vadio",
    "vadiasse": "vadiar",
    "vadiassem": "vadiar",
    "vadiasses": "vadiar",
    "vadiaste": "vadiar",
    "vadiastes": "vadiar",
    "vadiava": "vadiar",
    "vadiavam": "vadiar",
    "vadiavas": "vadiar",
    "vadiazinha": "vadio",
    "vadiazinhas": "vadio",
    "vadiazita": "vadio",
    "vadiazitas": "vadio",
    "vadiações": "vadiação",
    "vadie": "vadiar",
    "vadiei": "vadiar",
    "vadieis": "vadiar",
    "vadiem": "vadiar",
    "vadiemo": "vadiar",
    "vadiemos": "vadiar",
    "vadies": "vadiar",
    "vadiices": "vadiice",
    "vadio": "vadiar",
    "vadios": "vadio",
    "vadiota": "vadiote",
    "vadiotas": "vadiote",
    "vadiotes": "vadiote",
    "vadiou": "vadiar",
    "vadiozinho": "vadio",
    "vadiozinhos": "vadio",
    "vadiozito": "vadio",
    "vadiozitos": "vadio",
    "vadiámo": "vadiar",
    "vadiámos": "vadiar",
    "vadiáramo": "vadiar",
    "vadiáramos": "vadiar",
    "vadiáreis": "vadiar",
    "vadiásseis": "vadiar",
    "vadiássemos": "vadiar",
    "vadiávamo": "vadiar",
    "vadiávamos": "vadiar",
    "vadiáveis": "vadiar",
    "vadroiis": "vadroil",
    "vaga": "vago",
    "vagabunda": "vagabundo",
    "vagabundada": "vagabundar",
    "vagabundadas": "vagabundar",
    "vagabundado": "vagabundar",
    "vagabundados": "vagabundar",
    "vagabundagens": "vagabundagem",
    "vagabundai": "vagabundar",
    "vagabundais": "vagabundar",
    "vagabundam": "vagabundar",
    "vagabundamo": "vagabundar",
    "vagabundamos": "vagabundar",
    "vagabundando": "vagabundar",
    "vagabundara": "vagabundar",
    "vagabundaram": "vagabundar",
    "vagabundaras": "vagabundar",
    "vagabundardes": "vagabundar",
    "vagabundarei": "vagabundar",
    "vagabundareis": "vagabundar",
    "vagabundarem": "vagabundar",
    "vagabundaremos": "vagabundar",
    "vagabundares": "vagabundar",
    "vagabundaria": "vagabundar",
    "vagabundariam": "vagabundar",
    "vagabundarias": "vagabundar",
    "vagabundarmo": "vagabundar",
    "vagabundarmos": "vagabundar",
    "vagabundará": "vagabundar",
    "vagabundarás": "vagabundar",
    "vagabundarão": "vagabundar",
    "vagabundaríamos": "vagabundar",
    "vagabundaríeis": "vagabundar",
    "vagabundas": "vagabundo",
    "vagabundasse": "vagabundar",
    "vagabundassem": "vagabundar",
    "vagabundasses": "vagabundar",
    "vagabundaste": "vagabundar",
    "vagabundastes": "vagabundar",
    "vagabundava": "vagabundar",
    "vagabundavam": "vagabundar",
    "vagabundavas": "vagabundar",
    "vagabundazinha": "vagabundo",
    "vagabundazinhas": "vagabundo",
    "vagabundazita": "vagabundo",
    "vagabundazitas": "vagabundo",
    "vagabunde": "vagabundar",
    "vagabundeada": "vagabundear",
    "vagabundeadas": "vagabundear",
    "vagabundeado": "vagabundear",
    "vagabundeados": "vagabundear",
    "vagabundeai": "vagabundear",
    "vagabundeais": "vagabundear",
    "vagabundeamo": "vagabundear",
    "vagabundeamos": "vagabundear",
    "vagabundeando": "vagabundear",
    "vagabundeara": "vagabundear",
    "vagabundearam": "vagabundear",
    "vagabundearas": "vagabundear",
    "vagabundeardes": "vagabundear",
    "vagabundearei": "vagabundear",
    "vagabundeareis": "vagabundear",
    "vagabundearem": "vagabundear",
    "vagabundearemos": "vagabundear",
    "vagabundeares": "vagabundear",
    "vagabundearia": "vagabundear",
    "vagabundeariam": "vagabundear",
    "vagabundearias": "vagabundear",
    "vagabundearmo": "vagabundear",
    "vagabundearmos": "vagabundear",
    "vagabundeará": "vagabundear",
    "vagabundearás": "vagabundear",
    "vagabundearão": "vagabundear",
    "vagabundearíamos": "vagabundear",
    "vagabundearíeis": "vagabundear",
    "vagabundeasse": "vagabundear",
    "vagabundeassem": "vagabundear",
    "vagabundeasses": "vagabundear",
    "vagabundeaste": "vagabundear",
    "vagabundeastes": "vagabundear",
    "vagabundeava": "vagabundear",
    "vagabundeavam": "vagabundear",
    "vagabundeavas": "vagabundear",
    "vagabundeei": "vagabundear",
    "vagabundeeis": "vagabundear",
    "vagabundeemo": "vagabundear",
    "vagabundeemos": "vagabundear",
    "vagabundei": "vagabundar",
    "vagabundeia": "vagabundear",
    "vagabundeiam": "vagabundear",
    "vagabundeias": "vagabundear",
    "vagabundeie": "vagabundear",
    "vagabundeiem": "vagabundear",
    "vagabundeies": "vagabundear",
    "vagabundeio": "vagabundear",
    "vagabundeis": "vagabundar",
    "vagabundem": "vagabundar",
    "vagabundemo": "vagabundar",
    "vagabundemos": "vagabundar",
    "vagabundeou": "vagabundear",
    "vagabundes": "vagabundar",
    "vagabundeámo": "vagabundear",
    "vagabundeámos": "vagabundear",
    "vagabundeáramo": "vagabundear",
    "vagabundeáramos": "vagabundear",
    "vagabundeáreis": "vagabundear",
    "vagabundeásseis": "vagabundear",
    "vagabundeássemos": "vagabundear",
    "vagabundeávamo": "vagabundear",
    "vagabundeávamos": "vagabundear",
    "vagabundeáveis": "vagabundear",
    "vagabundo": "vagabundar",
    "vagabundos": "vagabundo",
    "vagabundou": "vagabundar",
    "vagabundozinho": "vagabundo",
    "vagabundozinhos": "vagabundo",
    "vagabundozito": "vagabundo",
    "vagabundozitos": "vagabundo",
    "vagabundámo": "vagabundar",
    "vagabundámos": "vagabundar",
    "vagabundáramo": "vagabundar",
    "vagabundáramos": "vagabundar",
    "vagabundáreis": "vagabundar",
    "vagabundásseis": "vagabundar",
    "vagabundássemos": "vagabundar",
    "vagabundávamo": "vagabundar",
    "vagabundávamos": "vagabundar",
    "vagabundáveis": "vagabundar",
    "vagada": "vagar",
    "vagadas": "vagar",
    "vagado": "vagar",
    "vagados": "vagar",
    "vagai": "vagar",
    "vagais": "vagar",
    "vagalhões": "vagalhão",
    "vagam": "vagar",
    "vagamo": "vagar",
    "vagamos": "vagar",
    "vagamunda": "vagamundo",
    "vagamundas": "vagamundo",
    "vagamundeada": "vagamundear",
    "vagamundeadas": "vagamundear",
    "vagamundeado": "vagamundear",
    "vagamundeados": "vagamundear",
    "vagamundeai": "vagamundear",
    "vagamundeais": "vagamundear",
    "vagamundeamo": "vagamundear",
    "vagamundeamos": "vagamundear",
    "vagamundeando": "vagamundear",
    "vagamundeara": "vagamundear",
    "vagamundearam": "vagamundear",
    "vagamundearas": "vagamundear",
    "vagamundeardes": "vagamundear",
    "vagamundearei": "vagamundear",
    "vagamundeareis": "vagamundear",
    "vagamundearem": "vagamundear",
    "vagamundearemos": "vagamundear",
    "vagamundeares": "vagamundear",
    "vagamundearia": "vagamundear",
    "vagamundeariam": "vagamundear",
    "vagamundearias": "vagamundear",
    "vagamundearmo": "vagamundear",
    "vagamundearmos": "vagamundear",
    "vagamundeará": "vagamundear",
    "vagamundearás": "vagamundear",
    "vagamundearão": "vagamundear",
    "vagamundearíamos": "vagamundear",
    "vagamundearíeis": "vagamundear",
    "vagamundeasse": "vagamundear",
    "vagamundeassem": "vagamundear",
    "vagamundeasses": "vagamundear",
    "vagamundeaste": "vagamundear",
    "vagamundeastes": "vagamundear",
    "vagamundeava": "vagamundear",
    "vagamundeavam": "vagamundear",
    "vagamundeavas": "vagamundear",
    "vagamundeei": "vagamundear",
    "vagamundeeis": "vagamundear",
    "vagamundeemo": "vagamundear",
    "vagamundeemos": "vagamundear",
    "vagamundeia": "vagamundear",
    "vagamundeiam": "vagamundear",
    "vagamundeias": "vagamundear",
    "vagamundeie": "vagamundear",
    "vagamundeiem": "vagamundear",
    "vagamundeies": "vagamundear",
    "vagamundeio": "vagamundear",
    "vagamundeou": "vagamundear",
    "vagamundeámo": "vagamundear",
    "vagamundeámos": "vagamundear",
    "vagamundeáramo": "vagamundear",
    "vagamundeáramos": "vagamundear",
    "vagamundeáreis": "vagamundear",
    "vagamundeásseis": "vagamundear",
    "vagamundeássemos": "vagamundear",
    "vagamundeávamo": "vagamundear",
    "vagamundeávamos": "vagamundear",
    "vagamundeáveis": "vagamundear",
    "vagamundos": "vagamundo",
    "vagando": "vagar",
    "vagantes": "vagante",
    "vagara": "vagar",
    "vagaram": "vagar",
    "vagaras": "vagar",
    "vagardes": "vagar",
    "vagarei": "vagar",
    "vagareis": "vagar",
    "vagarem": "vagar",
    "vagaremos": "vagar",
    "vagarenta": "vagarento",
    "vagarentas": "vagarento",
    "vagarentos": "vagarento",
    "vagares": "vagar",
    "vagarezas": "vagareza",
    "vagaria": "vagar",
    "vagariam": "vagar",
    "vagarias": "vagar",
    "vagarmo": "vagar",
    "vagarmos": "vagar",
    "vagarosa": "vagaroso",
    "vagarosas": "vagaroso",
    "vagarosos": "vagaroso",
    "vagará": "vagar",
    "vagarás": "vagar",
    "vagarão": "vagar",
    "vagaríamos": "vagar",
    "vagaríeis": "vagar",
    "vagas": "vago",
    "vagasse": "vagar",
    "vagassem": "vagar",
    "vagasses": "vagar",
    "vagaste": "vagar",
    "vagastes": "vagar",
    "vagaturas": "vagatura",
    "vagava": "vagar",
    "vagavam": "vagar",
    "vagavas": "vagar",
    "vagações": "vagação",
    "vage": "vagir",
    "vagem": "vagir",
    "vagens": "vagem",
    "vages": "vagir",
    "vagi": "vagir",
    "vagia": "vagir",
    "vagiam": "vagir",
    "vagias": "vagir",
    "vagida": "vagir",
    "vagidas": "vagir",
    "vagido": "vagir",
    "vagidos": "vagir",
    "vagimo": "vagir",
    "vagimos": "vagir",
    "vaginais": "vaginal",
    "vaginas": "vagina",
    "vagindo": "vagir",
    "vaginiformes": "vaginiforme",
    "vaginismos": "vaginismo",
    "vaginites": "vaginite",
    "vaginodinias": "vaginodinia",
    "vaginoscopias": "vaginoscopia",
    "vaginotomias": "vaginotomia",
    "vaginulada": "vaginulado",
    "vaginuladas": "vaginulado",
    "vaginulados": "vaginulado",
    "vaginulífera": "vaginulífero",
    "vaginulíferas": "vaginulífero",
    "vaginulíferos": "vaginulífero",
    "vaginífera": "vaginífero",
    "vaginíferas": "vaginífero",
    "vaginíferos": "vaginífero",
    "vagira": "vagir",
    "vagiram": "vagir",
    "vagiras": "vagir",
    "vagirdes": "vagir",
    "vagirei": "vagir",
    "vagireis": "vagir",
    "vagirem": "vagir",
    "vagiremos": "vagir",
    "vagires": "vagir",
    "vagiria": "vagir",
    "vagiriam": "vagir",
    "vagirias": "vagir",
    "vagirmo": "vagir",
    "vagirmos": "vagir",
    "vagirá": "vagir",
    "vagirás": "vagir",
    "vagirão": "vagir",
    "vagiríamos": "vagir",
    "vagiríeis": "vagir",
    "vagis": "vagir",
    "vagisse": "vagir",
    "vagissem": "vagir",
    "vagisses": "vagir",
    "vagiste": "vagir",
    "vagistes": "vagir",
    "vagiu": "vagir",
    "vago": "vagar",
    "vagomestres": "vagomestre",
    "vagoneira": "vagoneiro",
    "vagoneiras": "vagoneiro",
    "vagoneiros": "vagoneiro",
    "vagonetas": "vagoneta",
    "vagonetes": "vagonete",
    "vagos": "vago",
    "vagotonias": "vagotonia",
    "vagou": "vagar",
    "vague": "vagar",
    "vagueada": "vaguear",
    "vagueadas": "vaguear",
    "vagueado": "vaguear",
    "vagueados": "vaguear",
    "vagueai": "vaguear",
    "vagueais": "vaguear",
    "vagueamo": "vaguear",
    "vagueamos": "vaguear",
    "vagueando": "vaguear",
    "vagueara": "vaguear",
    "vaguearam": "vaguear",
    "vaguearas": "vaguear",
    "vagueardes": "vaguear",
    "vaguearei": "vaguear",
    "vagueareis": "vaguear",
    "vaguearem": "vaguear",
    "vaguearemos": "vaguear",
    "vagueares": "vaguear",
    "vaguearia": "vaguear",
    "vagueariam": "vaguear",
    "vaguearias": "vaguear",
    "vaguearmo": "vaguear",
    "vaguearmos": "vaguear",
    "vagueará": "vaguear",
    "vaguearás": "vaguear",
    "vaguearão": "vaguear",
    "vaguearíamos": "vaguear",
    "vaguearíeis": "vaguear",
    "vagueasse": "vaguear",
    "vagueassem": "vaguear",
    "vagueasses": "vaguear",
    "vagueaste": "vaguear",
    "vagueastes": "vaguear",
    "vagueava": "vaguear",
    "vagueavam": "vaguear",
    "vagueavas": "vaguear",
    "vagueações": "vagueação",
    "vaguedos": "vaguedo",
    "vagueei": "vaguear",
    "vagueeis": "vaguear",
    "vagueemo": "vaguear",
    "vagueemos": "vaguear",
    "vaguei": "vagar",
    "vagueia": "vaguear",
    "vagueiam": "vaguear",
    "vagueias": "vaguear",
    "vagueie": "vaguear",
    "vagueiem": "vaguear",
    "vagueies": "vaguear",
    "vagueio": "vaguear",
    "vagueiras": "vagueira",
    "vagueiros": "vagueiro",
    "vagueis": "vagar",
    "vagueja": "vaguejar",
    "vaguejada": "vaguejar",
    "vaguejadas": "vaguejar",
    "vaguejado": "vaguejar",
    "vaguejados": "vaguejar",
    "vaguejai": "vaguejar",
    "vaguejais": "vaguejar",
    "vaguejam": "vaguejar",
    "vaguejamo": "vaguejar",
    "vaguejamos": "vaguejar",
    "vaguejando": "vaguejar",
    "vaguejara": "vaguejar",
    "vaguejaram": "vaguejar",
    "vaguejaras": "vaguejar",
    "vaguejardes": "vaguejar",
    "vaguejarei": "vaguejar",
    "vaguejareis": "vaguejar",
    "vaguejarem": "vaguejar",
    "vaguejaremos": "vaguejar",
    "vaguejares": "vaguejar",
    "vaguejaria": "vaguejar",
    "vaguejariam": "vaguejar",
    "vaguejarias": "vaguejar",
    "vaguejarmo": "vaguejar",
    "vaguejarmos": "vaguejar",
    "vaguejará": "vaguejar",
    "vaguejarás": "vaguejar",
    "vaguejarão": "vaguejar",
    "vaguejaríamos": "vaguejar",
    "vaguejaríeis": "vaguejar",
    "vaguejas": "vaguejar",
    "vaguejasse": "vaguejar",
    "vaguejassem": "vaguejar",
    "vaguejasses": "vaguejar",
    "vaguejaste": "vaguejar",
    "vaguejastes": "vaguejar",
    "vaguejava": "vaguejar",
    "vaguejavam": "vaguejar",
    "vaguejavas": "vaguejar",
    "vagueje": "vaguejar",
    "vaguejei": "vaguejar",
    "vaguejeis": "vaguejar",
    "vaguejem": "vaguejar",
    "vaguejemo": "vaguejar",
    "vaguejemos": "vaguejar",
    "vaguejes": "vaguejar",
    "vaguejo": "vaguejar",
    "vaguejou": "vaguejar",
    "vaguejámo": "vaguejar",
    "vaguejámos": "vaguejar",
    "vaguejáramo": "vaguejar",
    "vaguejáramos": "vaguejar",
    "vaguejáreis": "vaguejar",
    "vaguejásseis": "vaguejar",
    "vaguejássemos": "vaguejar",
    "vaguejávamo": "vaguejar",
    "vaguejávamos": "vaguejar",
    "vaguejáveis": "vaguejar",
    "vaguem": "vagar",
    "vaguemo": "vagar",
    "vaguemos": "vagar",
    "vaguenses": "vaguense",
    "vagueou": "vaguear",
    "vagues": "vagar",
    "vaguezas": "vagueza",
    "vagueámo": "vaguear",
    "vagueámos": "vaguear",
    "vagueáramo": "vaguear",
    "vagueáramos": "vaguear",
    "vagueáreis": "vaguear",
    "vagueásseis": "vaguear",
    "vagueássemos": "vaguear",
    "vagueávamo": "vaguear",
    "vagueávamos": "vaguear",
    "vagueáveis": "vaguear",
    "vaguíssima": "vago",
    "vaguíssimas": "vago",
    "vaguíssimo": "vago",
    "vaguíssimos": "vago",
    "vagámo": "vagar",
    "vagámos": "vagar",
    "vagáramo": "vagar",
    "vagáramos": "vagar",
    "vagáreis": "vagar",
    "vagásseis": "vagar",
    "vagássemos": "vagar",
    "vagávamo": "vagar",
    "vagávamos": "vagar",
    "vagáveis": "vagar",
    "vagâncias": "vagância",
    "vagíamo": "vagir",
    "vagíamos": "vagir",
    "vagíeis": "vagir",
    "vagínulas": "vagínula",
    "vagíramo": "vagir",
    "vagíramos": "vagir",
    "vagíreis": "vagir",
    "vagísseis": "vagir",
    "vagíssemos": "vagir",
    "vagões": "vagão",
    "vai": "ir",
    "vaia": "vaiar",
    "vaiada": "vaiar",
    "vaiadas": "vaiar",
    "vaiado": "vaiar",
    "vaiadora": "vaiador",
    "vaiadoras": "vaiador",
    "vaiadores": "vaiador",
    "vaiados": "vaiar",
    "vaiai": "vaiar",
    "vaiais": "vaiar",
    "vaiam": "vaiar",
    "vaiamo": "vaiar",
    "vaiamos": "vaiar",
    "vaiando": "vaiar",
    "vaiara": "vaiar",
    "vaiaram": "vaiar",
    "vaiaras": "vaiar",
    "vaiarde": "vaiar",
    "vaiardes": "vaiar",
    "vaiare": "vaiar",
    "vaiarei": "vaiar",
    "vaiareis": "vaiar",
    "vaiarem": "vaiar",
    "vaiaremos": "vaiar",
    "vaiares": "vaiar",
    "vaiaria": "vaiar",
    "vaiariam": "vaiar",
    "vaiarias": "vaiar",
    "vaiarmo": "vaiar",
    "vaiarmos": "vaiar",
    "vaiará": "vaiar",
    "vaiarás": "vaiar",
    "vaiarão": "vaiar",
    "vaiaríamos": "vaiar",
    "vaiaríeis": "vaiar",
    "vaias": "vaiar",
    "vaiasse": "vaiar",
    "vaiassem": "vaiar",
    "vaiasses": "vaiar",
    "vaiaste": "vaiar",
    "vaiastes": "vaiar",
    "vaiava": "vaiar",
    "vaiavam": "vaiar",
    "vaiavas": "vaiar",
    "vaidades": "vaidade",
    "vaidosa": "vaidoso",
    "vaidosas": "vaidoso",
    "vaidosinha": "vaidoso",
    "vaidosinhas": "vaidoso",
    "vaidosinho": "vaidoso",
    "vaidosinhos": "vaidoso",
    "vaidosita": "vaidoso",
    "vaidositas": "vaidoso",
    "vaidosito": "vaidoso",
    "vaidositos": "vaidoso",
    "vaidosos": "vaidoso",
    "vaie": "vaiar",
    "vaiei": "vaiar",
    "vaieis": "vaiar",
    "vaiem": "vaiar",
    "vaiemo": "vaiar",
    "vaiemos": "vaiar",
    "vaies": "vaiar",
    "vailas": "vaila",
    "vaio": "vaiar",
    "vaiou": "vaiar",
    "vairas": "vaira",
    "vais": "ir",
    "vaivéns": "vaivém",
    "vaixiás": "vaixiá",
    "vaixás": "vaixá",
    "vaiá": "vaiar",
    "vaiámo": "vaiar",
    "vaiámos": "vaiar",
    "vaiáramo": "vaiar",
    "vaiáramos": "vaiar",
    "vaiárei": "vaiar",
    "vaiáreis": "vaiar",
    "vaiásseis": "vaiar",
    "vaiássemos": "vaiar",
    "vaiávamo": "vaiar",
    "vaiávamos": "vaiar",
    "vaiávei": "vaiar",
    "vaiáveis": "vaiar",
    "vaja": "vagir",
    "vajais": "vagir",
    "vajam": "vagir",
    "vajamo": "vagir",
    "vajamos": "vagir",
    "vajas": "vagir",
    "vajo": "vagir",
    "vala": "valar",
    "valada": "valar",
    "valadas": "valar",
    "valadia": "valadio",
    "valadias": "valadio",
    "valadios": "valadio",
    "valado": "valar",
    "valadora": "valador",
    "valadoras": "valador",
    "valadores": "valador",
    "valados": "valar",
    "valagens": "valagem",
    "valai": "valar",
    "valais": "valar",
    "valam": "valar",
    "valamo": "valar",
    "valamos": "valar",
    "valando": "valar",
    "valanginianos": "valanginiano",
    "valara": "valar",
    "valaram": "valar",
    "valaras": "valar",
    "valarde": "valar",
    "valardes": "valar",
    "valare": "valar",
    "valarei": "valar",
    "valareis": "valar",
    "valarem": "valar",
    "valaremos": "valar",
    "valares": "valar",
    "valaria": "valar",
    "valariam": "valar",
    "valarias": "valar",
    "valarmo": "valar",
    "valarmos": "valar",
    "valará": "valar",
    "valarás": "valar",
    "valarão": "valar",
    "valaríamos": "valar",
    "valaríeis": "valar",
    "valas": "valar",
    "valasse": "valar",
    "valassem": "valar",
    "valasses": "valar",
    "valaste": "valar",
    "valastes": "valar",
    "valava": "valar",
    "valavam": "valar",
    "valavas": "valar",
    "valda": "valdo",
    "valdas": "valdo",
    "valdeira": "valdeiro",
    "valdeiras": "valdeiro",
    "valdeiros": "valdeiro",
    "valdenses": "valdense",
    "valdos": "valdo",
    "vale": "valer",
    "valedia": "valedio",
    "valedias": "valedio",
    "valedios": "valedio",
    "valedoira": "valedoiro",
    "valedoiras": "valedoiro",
    "valedoiros": "valedoiro",
    "valedora": "valedor",
    "valedoras": "valedor",
    "valedores": "valedor",
    "valedoura": "valedouro",
    "valedouras": "valedouro",
    "valedouros": "valedouro",
    "valei": "valer",
    "valeira": "valeiro",
    "valeiras": "valeiro",
    "valeiros": "valeiro",
    "valeis": "valer",
    "valejos": "valejo",
    "valem": "valer",
    "valemo": "valer",
    "valemos": "valer",
    "valenciana": "valenciano",
    "valencianas": "valenciano",
    "valencianites": "valencianite",
    "valencianos": "valenciano",
    "valencinas": "valencina",
    "valendo": "valer",
    "valentaça": "valentaço",
    "valentaças": "valentaço",
    "valentaços": "valentaço",
    "valentes": "valente",
    "valentezinha": "valente",
    "valentezinhas": "valente",
    "valentezinho": "valente",
    "valentezinhos": "valente",
    "valentezita": "valente",
    "valentezitas": "valente",
    "valentezito": "valente",
    "valentezitos": "valente",
    "valentias": "valentia",
    "valentinha": "valente",
    "valentinhas": "valente",
    "valentinho": "valente",
    "valentinhos": "valente",
    "valentita": "valente",
    "valentitas": "valente",
    "valentito": "valente",
    "valentitos": "valente",
    "valentona": "valentão",
    "valentonas": "valentão",
    "valentíssima": "valente",
    "valentíssimas": "valente",
    "valentíssimo": "valente",
    "valentíssimos": "valente",
    "valentões": "valentão",
    "valera": "valer",
    "valeram": "valer",
    "valeras": "valer",
    "valeratos": "valerato",
    "valerdes": "valer",
    "valerei": "valer",
    "valereis": "valer",
    "valerem": "valer",
    "valeremos": "valer",
    "valeres": "valer",
    "valeria": "valer",
    "valeriam": "valer",
    "valerianas": "valeriana",
    "valerianatos": "valerianato",
    "valerianelas": "valerianela",
    "valerianáceas": "valerianácea",
    "valerias": "valer",
    "valeriânica": "valeriânico",
    "valeriânicas": "valeriânico",
    "valeriânicos": "valeriânico",
    "valermo": "valer",
    "valermos": "valer",
    "valerosa": "valeroso",
    "valerosas": "valeroso",
    "valerosos": "valeroso",
    "valerá": "valer",
    "valerás": "valer",
    "valerão": "valer",
    "valeríamos": "valer",
    "valeríeis": "valer",
    "vales": "valer",
    "valesiana": "valesiano",
    "valesianas": "valesiano",
    "valesianos": "valesiano",
    "valesse": "valer",
    "valessem": "valer",
    "valesses": "valer",
    "valeste": "valer",
    "valestes": "valer",
    "valetas": "valeta",
    "valetes": "valete",
    "valetudinária": "valetudinário",
    "valetudinárias": "valetudinário",
    "valetudinários": "valetudinário",
    "valeu": "valer",
    "valha": "valer",
    "valhacoitos": "valhacoito",
    "valhacoutos": "valhacouto",
    "valhais": "valer",
    "valham": "valer",
    "valhamo": "valer",
    "valhamos": "valer",
    "valhas": "valer",
    "valho": "valer",
    "vali": "valer",
    "valia": "valer",
    "valiam": "valer",
    "valias": "valia",
    "valida": "valido",
    "validada": "validar",
    "validadas": "validar",
    "validades": "validade",
    "validado": "validar",
    "validados": "validar",
    "validai": "validar",
    "validais": "validar",
    "validam": "validar",
    "validamo": "validar",
    "validamos": "validar",
    "validando": "validar",
    "validara": "validar",
    "validaram": "validar",
    "validaras": "validar",
    "validarde": "validar",
    "validardes": "validar",
    "validare": "validar",
    "validarei": "validar",
    "validareis": "validar",
    "validarem": "validar",
    "validaremos": "validar",
    "validares": "validar",
    "validaria": "validar",
    "validariam": "validar",
    "validarias": "validar",
    "validarmo": "validar",
    "validarmos": "validar",
    "validará": "validar",
    "validarás": "validar",
    "validarão": "validar",
    "validaríamos": "validar",
    "validaríeis": "validar",
    "validas": "valido",
    "validasse": "validar",
    "validassem": "validar",
    "validasses": "validar",
    "validaste": "validar",
    "validastes": "validar",
    "validava": "validar",
    "validavam": "validar",
    "validavas": "validar",
    "validações": "validação",
    "valide": "validar",
    "validei": "validar",
    "valideis": "validar",
    "validem": "validar",
    "validemo": "validar",
    "validemos": "validar",
    "valides": "validar",
    "validezes": "validez",
    "valido": "validar",
    "validos": "valido",
    "validou": "validar",
    "validá": "validar",
    "validámo": "validar",
    "validámos": "validar",
    "validáramo": "validar",
    "validáramos": "validar",
    "validárei": "validar",
    "validáreis": "validar",
    "validásseis": "validar",
    "validássemos": "validar",
    "validávamo": "validar",
    "validávamos": "validar",
    "validávei": "validar",
    "validáveis": "validável",
    "valimentos": "valimento",
    "valinha": "vala",
    "valinhas": "vala",
    "valiosa": "valioso",
    "valiosas": "valioso",
    "valiosos": "valioso",
    "valiosíssima": "valioso",
    "valiosíssimas": "valioso",
    "valiosíssimo": "valioso",
    "valiosíssimos": "valioso",
    "valita": "vala",
    "valitas": "vala",
    "valo": "valar",
    "valoa": "valão",
    "valoas": "valão",
    "valongueira": "valongueiro",
    "valongueiras": "valongueiro",
    "valongueiros": "valongueiro",
    "valonguenses": "valonguense",
    "valora": "valorar",
    "valorada": "valorar",
    "valoradas": "valorar",
    "valorado": "valorar",
    "valorados": "valorar",
    "valorai": "valorar",
    "valorais": "valorar",
    "valoram": "valorar",
    "valoramo": "valorar",
    "valoramos": "valorar",
    "valorando": "valorar",
    "valorara": "valorar",
    "valoraram": "valorar",
    "valoraras": "valorar",
    "valorarde": "valorar",
    "valorardes": "valorar",
    "valorare": "valorar",
    "valorarei": "valorar",
    "valorareis": "valorar",
    "valorarem": "valorar",
    "valoraremos": "valorar",
    "valorares": "valorar",
    "valoraria": "valorar",
    "valorariam": "valorar",
    "valorarias": "valorar",
    "valorarmo": "valorar",
    "valorarmos": "valorar",
    "valorará": "valorar",
    "valorarás": "valorar",
    "valorarão": "valorar",
    "valoraríamos": "valorar",
    "valoraríeis": "valorar",
    "valoras": "valorar",
    "valorasse": "valorar",
    "valorassem": "valorar",
    "valorasses": "valorar",
    "valoraste": "valorar",
    "valorastes": "valorar",
    "valorativa": "valorativo",
    "valorativas": "valorativo",
    "valorativos": "valorativo",
    "valorava": "valorar",
    "valoravam": "valorar",
    "valoravas": "valorar",
    "valorações": "valoração",
    "valore": "valorar",
    "valorei": "valorar",
    "valoreis": "valorar",
    "valorem": "valorar",
    "valoremo": "valorar",
    "valoremos": "valorar",
    "valores": "valorar",
    "valoriza": "valorizar",
    "valorizada": "valorizar",
    "valorizadas": "valorizar",
    "valorizado": "valorizar",
    "valorizados": "valorizar",
    "valorizai": "valorizar",
    "valorizais": "valorizar",
    "valorizam": "valorizar",
    "valorizamo": "valorizar",
    "valorizamos": "valorizar",
    "valorizando": "valorizar",
    "valorizara": "valorizar",
    "valorizaram": "valorizar",
    "valorizaras": "valorizar",
    "valorizarde": "valorizar",
    "valorizardes": "valorizar",
    "valorizare": "valorizar",
    "valorizarei": "valorizar",
    "valorizareis": "valorizar",
    "valorizarem": "valorizar",
    "valorizaremos": "valorizar",
    "valorizares": "valorizar",
    "valorizaria": "valorizar",
    "valorizariam": "valorizar",
    "valorizarias": "valorizar",
    "valorizarmo": "valorizar",
    "valorizarmos": "valorizar",
    "valorizará": "valorizar",
    "valorizarás": "valorizar",
    "valorizarão": "valorizar",
    "valorizaríamos": "valorizar",
    "valorizaríeis": "valorizar",
    "valorizas": "valorizar",
    "valorizasse": "valorizar",
    "valorizassem": "valorizar",
    "valorizasses": "valorizar",
    "valorizaste": "valorizar",
    "valorizastes": "valorizar",
    "valorizava": "valorizar",
    "valorizavam": "valorizar",
    "valorizavas": "valorizar",
    "valorizações": "valorização",
    "valorize": "valorizar",
    "valorizei": "valorizar",
    "valorizeis": "valorizar",
    "valorizem": "valorizar",
    "valorizemo": "valorizar",
    "valorizemos": "valorizar",
    "valorizes": "valorizar",
    "valorizo": "valorizar",
    "valorizou": "valorizar",
    "valorizá": "valorizar",
    "valorizámo": "valorizar",
    "valorizámos": "valorizar",
    "valorizáramo": "valorizar",
    "valorizáramos": "valorizar",
    "valorizárei": "valorizar",
    "valorizáreis": "valorizar",
    "valorizásseis": "valorizar",
    "valorizássemos": "valorizar",
    "valorizávamo": "valorizar",
    "valorizávamos": "valorizar",
    "valorizávei": "valorizar",
    "valorizáveis": "valorizar",
    "valoro": "valorar",
    "valorosa": "valoroso",
    "valorosas": "valoroso",
    "valorosidades": "valorosidade",
    "valorosos": "valoroso",
    "valorosíssima": "valoroso",
    "valorosíssimas": "valoroso",
    "valorosíssimo": "valoroso",
    "valorosíssimos": "valoroso",
    "valorou": "valorar",
    "valorá": "valorar",
    "valorámo": "valorar",
    "valorámos": "valorar",
    "valoráramo": "valorar",
    "valoráramos": "valorar",
    "valorárei": "valorar",
    "valoráreis": "valorar",
    "valorásseis": "valorar",
    "valorássemos": "valorar",
    "valorávamo": "valorar",
    "valorávamos": "valorar",
    "valorávei": "valorar",
    "valoráveis": "valorar",
    "valos": "valo",
    "valou": "valar",
    "valpacenses": "valpacense",
    "valquírias": "valquíria",
    "valsa": "valsar",
    "valsada": "valsar",
    "valsadas": "valsar",
    "valsado": "valsar",
    "valsadora": "valsador",
    "valsadoras": "valsador",
    "valsadores": "valsador",
    "valsados": "valsar",
    "valsai": "valsar",
    "valsais": "valsar",
    "valsam": "valsar",
    "valsamo": "valsar",
    "valsamos": "valsar",
    "valsando": "valsar",
    "valsara": "valsar",
    "valsaram": "valsar",
    "valsaras": "valsar",
    "valsardes": "valsar",
    "valsarei": "valsar",
    "valsareis": "valsar",
    "valsarem": "valsar",
    "valsaremos": "valsar",
    "valsares": "valsar",
    "valsaria": "valsar",
    "valsariam": "valsar",
    "valsarias": "valsar",
    "valsarmo": "valsar",
    "valsarmos": "valsar",
    "valsará": "valsar",
    "valsarás": "valsar",
    "valsarão": "valsar",
    "valsaríamos": "valsar",
    "valsaríeis": "valsar",
    "valsas": "valsar",
    "valsasse": "valsar",
    "valsassem": "valsar",
    "valsasses": "valsar",
    "valsaste": "valsar",
    "valsastes": "valsar",
    "valsava": "valsar",
    "valsavam": "valsar",
    "valsavas": "valsar",
    "valse": "valsar",
    "valsei": "valsar",
    "valseis": "valsar",
    "valseja": "valsejar",
    "valsejada": "valsejar",
    "valsejadas": "valsejar",
    "valsejado": "valsejar",
    "valsejados": "valsejar",
    "valsejai": "valsejar",
    "valsejais": "valsejar",
    "valsejam": "valsejar",
    "valsejamo": "valsejar",
    "valsejamos": "valsejar",
    "valsejando": "valsejar",
    "valsejara": "valsejar",
    "valsejaram": "valsejar",
    "valsejaras": "valsejar",
    "valsejardes": "valsejar",
    "valsejarei": "valsejar",
    "valsejareis": "valsejar",
    "valsejarem": "valsejar",
    "valsejaremos": "valsejar",
    "valsejares": "valsejar",
    "valsejaria": "valsejar",
    "valsejariam": "valsejar",
    "valsejarias": "valsejar",
    "valsejarmo": "valsejar",
    "valsejarmos": "valsejar",
    "valsejará": "valsejar",
    "valsejarás": "valsejar",
    "valsejarão": "valsejar",
    "valsejaríamos": "valsejar",
    "valsejaríeis": "valsejar",
    "valsejas": "valsejar",
    "valsejasse": "valsejar",
    "valsejassem": "valsejar",
    "valsejasses": "valsejar",
    "valsejaste": "valsejar",
    "valsejastes": "valsejar",
    "valsejava": "valsejar",
    "valsejavam": "valsejar",
    "valsejavas": "valsejar",
    "valseje": "valsejar",
    "valsejei": "valsejar",
    "valsejeis": "valsejar",
    "valsejem": "valsejar",
    "valsejemo": "valsejar",
    "valsejemos": "valsejar",
    "valsejes": "valsejar",
    "valsejo": "valsejar",
    "valsejou": "valsejar",
    "valsejámo": "valsejar",
    "valsejámos": "valsejar",
    "valsejáramo": "valsejar",
    "valsejáramos": "valsejar",
    "valsejáreis": "valsejar",
    "valsejásseis": "valsejar",
    "valsejássemos": "valsejar",
    "valsejávamo": "valsejar",
    "valsejávamos": "valsejar",
    "valsejáveis": "valsejar",
    "valsem": "valsar",
    "valsemo": "valsar",
    "valsemos": "valsar",
    "valses": "valsar",
    "valsistas": "valsista",
    "valso": "valsar",
    "valsou": "valsar",
    "valsámo": "valsar",
    "valsámos": "valsar",
    "valsáramo": "valsar",
    "valsáramos": "valsar",
    "valsáreis": "valsar",
    "valsásseis": "valsar",
    "valsássemos": "valsar",
    "valsávamo": "valsar",
    "valsávamos": "valsar",
    "valsáveis": "valsar",
    "valvares": "valvar",
    "valvas": "valva",
    "valverdes": "valverde",
    "valviformees": "valviforme",
    "valvulada": "valvulado",
    "valvuladas": "valvulado",
    "valvulados": "valvulado",
    "valvulares": "valvular",
    "valvulites": "valvulite",
    "valvulotomias": "valvulotomia",
    "valá": "valar",
    "valámo": "valar",
    "valámos": "valar",
    "valáquia": "valáquio",
    "valáquias": "valáquio",
    "valáquios": "valáquio",
    "valáramo": "valar",
    "valáramos": "valar",
    "valárei": "valar",
    "valáreis": "valar",
    "valásseis": "valar",
    "valássemos": "valar",
    "valávamo": "valar",
    "valávamos": "valar",
    "valávei": "valar",
    "valáveis": "valar",
    "valérica": "valérico",
    "valéricas": "valérico",
    "valéricos": "valérico",
    "valências": "valência",
    "valêramo": "valer",
    "valêramos": "valer",
    "valêreis": "valer",
    "valêsseis": "valer",
    "valêssemos": "valer",
    "valíamo": "valer",
    "valíamos": "valer",
    "valíeis": "valer",
    "valões": "valão",
    "vamo": "ir",
    "vamos": "ir",
    "vampira": "vampiro",
    "vampiras": "vampiro",
    "vampiresas": "vampiresa",
    "vampiresca": "vampiresco",
    "vampirescas": "vampiresco",
    "vampirescos": "vampiresco",
    "vampirina": "vampirino",
    "vampirinas": "vampirino",
    "vampirinos": "vampirino",
    "vampirismos": "vampirismo",
    "vampiriza": "vampirizar",
    "vampirizada": "vampirizar",
    "vampirizadas": "vampirizar",
    "vampirizado": "vampirizar",
    "vampirizados": "vampirizar",
    "vampirizai": "vampirizar",
    "vampirizais": "vampirizar",
    "vampirizam": "vampirizar",
    "vampirizamo": "vampirizar",
    "vampirizamos": "vampirizar",
    "vampirizando": "vampirizar",
    "vampirizara": "vampirizar",
    "vampirizaram": "vampirizar",
    "vampirizaras": "vampirizar",
    "vampirizarde": "vampirizar",
    "vampirizardes": "vampirizar",
    "vampirizare": "vampirizar",
    "vampirizarei": "vampirizar",
    "vampirizareis": "vampirizar",
    "vampirizarem": "vampirizar",
    "vampirizaremos": "vampirizar",
    "vampirizares": "vampirizar",
    "vampirizaria": "vampirizar",
    "vampirizariam": "vampirizar",
    "vampirizarias": "vampirizar",
    "vampirizarmo": "vampirizar",
    "vampirizarmos": "vampirizar",
    "vampirizará": "vampirizar",
    "vampirizarás": "vampirizar",
    "vampirizarão": "vampirizar",
    "vampirizaríamos": "vampirizar",
    "vampirizaríeis": "vampirizar",
    "vampirizas": "vampirizar",
    "vampirizasse": "vampirizar",
    "vampirizassem": "vampirizar",
    "vampirizasses": "vampirizar",
    "vampirizaste": "vampirizar",
    "vampirizastes": "vampirizar",
    "vampirizava": "vampirizar",
    "vampirizavam": "vampirizar",
    "vampirizavas": "vampirizar",
    "vampirize": "vampirizar",
    "vampirizei": "vampirizar",
    "vampirizeis": "vampirizar",
    "vampirizem": "vampirizar",
    "vampirizemo": "vampirizar",
    "vampirizemos": "vampirizar",
    "vampirizes": "vampirizar",
    "vampirizo": "vampirizar",
    "vampirizou": "vampirizar",
    "vampirizá": "vampirizar",
    "vampirizámo": "vampirizar",
    "vampirizámos": "vampirizar",
    "vampirizáramo": "vampirizar",
    "vampirizáramos": "vampirizar",
    "vampirizárei": "vampirizar",
    "vampirizáreis": "vampirizar",
    "vampirizásseis": "vampirizar",
    "vampirizássemos": "vampirizar",
    "vampirizávamo": "vampirizar",
    "vampirizávamos": "vampirizar",
    "vampirizávei": "vampirizar",
    "vampirizáveis": "vampirizar",
    "vampiros": "vampiro",
    "vamps": "vamp",
    "vampírica": "vampírico",
    "vampíricas": "vampírico",
    "vampíricos": "vampírico",
    "vanadatos": "vanadato",
    "vanadinites": "vanadinite",
    "vandalismos": "vandalismo",
    "vandaliza": "vandalizar",
    "vandalizada": "vandalizar",
    "vandalizadas": "vandalizar",
    "vandalizado": "vandalizar",
    "vandalizados": "vandalizar",
    "vandalizai": "vandalizar",
    "vandalizais": "vandalizar",
    "vandalizam": "vandalizar",
    "vandalizamo": "vandalizar",
    "vandalizamos": "vandalizar",
    "vandalizando": "vandalizar",
    "vandalizara": "vandalizar",
    "vandalizaram": "vandalizar",
    "vandalizaras": "vandalizar",
    "vandalizarde": "vandalizar",
    "vandalizardes": "vandalizar",
    "vandalizare": "vandalizar",
    "vandalizarei": "vandalizar",
    "vandalizareis": "vandalizar",
    "vandalizarem": "vandalizar",
    "vandalizaremos": "vandalizar",
    "vandalizares": "vandalizar",
    "vandalizaria": "vandalizar",
    "vandalizariam": "vandalizar",
    "vandalizarias": "vandalizar",
    "vandalizarmo": "vandalizar",
    "vandalizarmos": "vandalizar",
    "vandalizará": "vandalizar",
    "vandalizarás": "vandalizar",
    "vandalizarão": "vandalizar",
    "vandalizaríamos": "vandalizar",
    "vandalizaríeis": "vandalizar",
    "vandalizas": "vandalizar",
    "vandalizasse": "vandalizar",
    "vandalizassem": "vandalizar",
    "vandalizasses": "vandalizar",
    "vandalizaste": "vandalizar",
    "vandalizastes": "vandalizar",
    "vandalizava": "vandalizar",
    "vandalizavam": "vandalizar",
    "vandalizavas": "vandalizar",
    "vandalize": "vandalizar",
    "vandalizei": "vandalizar",
    "vandalizeis": "vandalizar",
    "vandalizem": "vandalizar",
    "vandalizemo": "vandalizar",
    "vandalizemos": "vandalizar",
    "vandalizes": "vandalizar",
    "vandalizo": "vandalizar",
    "vandalizou": "vandalizar",
    "vandalizá": "vandalizar",
    "vandalizámo": "vandalizar",
    "vandalizámos": "vandalizar",
    "vandalizáramo": "vandalizar",
    "vandalizáramos": "vandalizar",
    "vandalizárei": "vandalizar",
    "vandalizáreis": "vandalizar",
    "vandalizásseis": "vandalizar",
    "vandalizássemos": "vandalizar",
    "vandalizávamo": "vandalizar",
    "vandalizávamos": "vandalizar",
    "vandalizávei": "vandalizar",
    "vandalizáveis": "vandalizar",
    "vandáceas": "vandácea",
    "vandálica": "vandálico",
    "vandálicas": "vandálico",
    "vandálicos": "vandálico",
    "vanganas": "vangana",
    "vangloria": "vangloriar",
    "vangloriada": "vangloriar",
    "vangloriadas": "vangloriar",
    "vangloriado": "vangloriar",
    "vangloriados": "vangloriar",
    "vangloriai": "vangloriar",
    "vangloriais": "vangloriar",
    "vangloriam": "vangloriar",
    "vangloriamo": "vangloriar",
    "vangloriamos": "vangloriar",
    "vangloriando": "vangloriar",
    "vangloriara": "vangloriar",
    "vangloriaram": "vangloriar",
    "vangloriaras": "vangloriar",
    "vangloriarde": "vangloriar",
    "vangloriardes": "vangloriar",
    "vangloriare": "vangloriar",
    "vangloriarei": "vangloriar",
    "vangloriareis": "vangloriar",
    "vangloriarem": "vangloriar",
    "vangloriaremos": "vangloriar",
    "vangloriares": "vangloriar",
    "vangloriaria": "vangloriar",
    "vangloriariam": "vangloriar",
    "vangloriarias": "vangloriar",
    "vangloriarmo": "vangloriar",
    "vangloriarmos": "vangloriar",
    "vangloriará": "vangloriar",
    "vangloriarás": "vangloriar",
    "vangloriarão": "vangloriar",
    "vangloriaríamos": "vangloriar",
    "vangloriaríeis": "vangloriar",
    "vanglorias": "vangloriar",
    "vangloriasse": "vangloriar",
    "vangloriassem": "vangloriar",
    "vangloriasses": "vangloriar",
    "vangloriaste": "vangloriar",
    "vangloriastes": "vangloriar",
    "vangloriava": "vangloriar",
    "vangloriavam": "vangloriar",
    "vangloriavas": "vangloriar",
    "vanglorie": "vangloriar",
    "vangloriei": "vangloriar",
    "vanglorieis": "vangloriar",
    "vangloriem": "vangloriar",
    "vangloriemo": "vangloriar",
    "vangloriemos": "vangloriar",
    "vanglories": "vangloriar",
    "vanglorio": "vangloriar",
    "vangloriosa": "vanglorioso",
    "vangloriosas": "vanglorioso",
    "vangloriosos": "vanglorioso",
    "vangloriou": "vangloriar",
    "vangloriá": "vangloriar",
    "vangloriámo": "vangloriar",
    "vangloriámos": "vangloriar",
    "vangloriáramo": "vangloriar",
    "vangloriáramos": "vangloriar",
    "vangloriárei": "vangloriar",
    "vangloriáreis": "vangloriar",
    "vangloriásseis": "vangloriar",
    "vangloriássemos": "vangloriar",
    "vangloriávamo": "vangloriar",
    "vangloriávamos": "vangloriar",
    "vangloriávei": "vangloriar",
    "vangloriáveis": "vangloriar",
    "vanglórias": "vanglória",
    "vanguardas": "vanguarda",
    "vanguardeada": "vanguardear",
    "vanguardeadas": "vanguardear",
    "vanguardeado": "vanguardear",
    "vanguardeados": "vanguardear",
    "vanguardeai": "vanguardear",
    "vanguardeais": "vanguardear",
    "vanguardeamo": "vanguardear",
    "vanguardeamos": "vanguardear",
    "vanguardeando": "vanguardear",
    "vanguardeara": "vanguardear",
    "vanguardearam": "vanguardear",
    "vanguardearas": "vanguardear",
    "vanguardearde": "vanguardear",
    "vanguardeardes": "vanguardear",
    "vanguardeare": "vanguardear",
    "vanguardearei": "vanguardear",
    "vanguardeareis": "vanguardear",
    "vanguardearem": "vanguardear",
    "vanguardearemos": "vanguardear",
    "vanguardeares": "vanguardear",
    "vanguardearia": "vanguardear",
    "vanguardeariam": "vanguardear",
    "vanguardearias": "vanguardear",
    "vanguardearmo": "vanguardear",
    "vanguardearmos": "vanguardear",
    "vanguardeará": "vanguardear",
    "vanguardearás": "vanguardear",
    "vanguardearão": "vanguardear",
    "vanguardearíamos": "vanguardear",
    "vanguardearíeis": "vanguardear",
    "vanguardeasse": "vanguardear",
    "vanguardeassem": "vanguardear",
    "vanguardeasses": "vanguardear",
    "vanguardeaste": "vanguardear",
    "vanguardeastes": "vanguardear",
    "vanguardeava": "vanguardear",
    "vanguardeavam": "vanguardear",
    "vanguardeavas": "vanguardear",
    "vanguardeei": "vanguardear",
    "vanguardeeis": "vanguardear",
    "vanguardeemo": "vanguardear",
    "vanguardeemos": "vanguardear",
    "vanguardeia": "vanguardear",
    "vanguardeiam": "vanguardear",
    "vanguardeias": "vanguardear",
    "vanguardeie": "vanguardear",
    "vanguardeiem": "vanguardear",
    "vanguardeies": "vanguardear",
    "vanguardeio": "vanguardear",
    "vanguardeira": "vanguardeiro",
    "vanguardeiras": "vanguardeiro",
    "vanguardeiros": "vanguardeiro",
    "vanguardeou": "vanguardear",
    "vanguardeá": "vanguardear",
    "vanguardeámo": "vanguardear",
    "vanguardeámos": "vanguardear",
    "vanguardeáramo": "vanguardear",
    "vanguardeáramos": "vanguardear",
    "vanguardeárei": "vanguardear",
    "vanguardeáreis": "vanguardear",
    "vanguardeásseis": "vanguardear",
    "vanguardeássemos": "vanguardear",
    "vanguardeávamo": "vanguardear",
    "vanguardeávamos": "vanguardear",
    "vanguardeávei": "vanguardear",
    "vanguardeáveis": "vanguardear",
    "vanguardistas": "vanguardista",
    "vangueja": "vanguejar",
    "vanguejada": "vanguejar",
    "vanguejadas": "vanguejar",
    "vanguejado": "vanguejar",
    "vanguejados": "vanguejar",
    "vanguejai": "vanguejar",
    "vanguejais": "vanguejar",
    "vanguejam": "vanguejar",
    "vanguejamo": "vanguejar",
    "vanguejamos": "vanguejar",
    "vanguejando": "vanguejar",
    "vanguejara": "vanguejar",
    "vanguejaram": "vanguejar",
    "vanguejaras": "vanguejar",
    "vanguejardes": "vanguejar",
    "vanguejarei": "vanguejar",
    "vanguejareis": "vanguejar",
    "vanguejarem": "vanguejar",
    "vanguejaremos": "vanguejar",
    "vanguejares": "vanguejar",
    "vanguejaria": "vanguejar",
    "vanguejariam": "vanguejar",
    "vanguejarias": "vanguejar",
    "vanguejarmo": "vanguejar",
    "vanguejarmos": "vanguejar",
    "vanguejará": "vanguejar",
    "vanguejarás": "vanguejar",
    "vanguejarão": "vanguejar",
    "vanguejaríamos": "vanguejar",
    "vanguejaríeis": "vanguejar",
    "vanguejas": "vanguejar",
    "vanguejasse": "vanguejar",
    "vanguejassem": "vanguejar",
    "vanguejasses": "vanguejar",
    "vanguejaste": "vanguejar",
    "vanguejastes": "vanguejar",
    "vanguejava": "vanguejar",
    "vanguejavam": "vanguejar",
    "vanguejavas": "vanguejar",
    "vangueje": "vanguejar",
    "vanguejei": "vanguejar",
    "vanguejeis": "vanguejar",
    "vanguejem": "vanguejar",
    "vanguejemo": "vanguejar",
    "vanguejemos": "vanguejar",
    "vanguejes": "vanguejar",
    "vanguejo": "vanguejar",
    "vanguejou": "vanguejar",
    "vanguejámo": "vanguejar",
    "vanguejámos": "vanguejar",
    "vanguejáramo": "vanguejar",
    "vanguejáramos": "vanguejar",
    "vanguejáreis": "vanguejar",
    "vanguejásseis": "vanguejar",
    "vanguejássemos": "vanguejar",
    "vanguejávamo": "vanguejar",
    "vanguejávamos": "vanguejar",
    "vanguejáveis": "vanguejar",
    "vanidades": "vanidade",
    "vanilinas": "vanilina",
    "vaniloquentes": "vaniloquente",
    "vaniloquências": "vaniloquência",
    "vaniláceas": "vanilácea",
    "vanilóquios": "vanilóquio",
    "vantagens": "vantagem",
    "vantajosa": "vantajoso",
    "vantajosas": "vantajoso",
    "vantajosos": "vantajoso",
    "vantes": "vante",
    "vanádica": "vanádico",
    "vanádicas": "vanádico",
    "vanádicos": "vanádico",
    "vanádios": "vanádio",
    "vaníloqua": "vaníloquo",
    "vaníloquas": "vaníloquo",
    "vaníloquos": "vaníloquo",
    "vaníssima": "vão",
    "vaníssimas": "vão",
    "vaníssimo": "vão",
    "vaníssimos": "vão",
    "vapora": "vaporar",
    "vaporada": "vaporar",
    "vaporadas": "vaporar",
    "vaporado": "vaporar",
    "vaporados": "vaporar",
    "vaporai": "vaporar",
    "vaporais": "vaporar",
    "vaporam": "vaporar",
    "vaporamo": "vaporar",
    "vaporamos": "vaporar",
    "vaporando": "vaporar",
    "vaporara": "vaporar",
    "vaporaram": "vaporar",
    "vaporaras": "vaporar",
    "vaporardes": "vaporar",
    "vaporarei": "vaporar",
    "vaporareis": "vaporar",
    "vaporarem": "vaporar",
    "vaporaremos": "vaporar",
    "vaporares": "vaporar",
    "vaporaria": "vaporar",
    "vaporariam": "vaporar",
    "vaporarias": "vaporar",
    "vaporarmo": "vaporar",
    "vaporarmos": "vaporar",
    "vaporará": "vaporar",
    "vaporarás": "vaporar",
    "vaporarão": "vaporar",
    "vaporaríamos": "vaporar",
    "vaporaríeis": "vaporar",
    "vaporas": "vaporar",
    "vaporasse": "vaporar",
    "vaporassem": "vaporar",
    "vaporasses": "vaporar",
    "vaporaste": "vaporar",
    "vaporastes": "vaporar",
    "vaporava": "vaporar",
    "vaporavam": "vaporar",
    "vaporavas": "vaporar",
    "vapore": "vaporar",
    "vaporei": "vaporar",
    "vaporeis": "vaporar",
    "vaporem": "vaporar",
    "vaporemo": "vaporar",
    "vaporemos": "vaporar",
    "vapores": "vaporar",
    "vaporiza": "vaporizar",
    "vaporizada": "vaporizar",
    "vaporizadas": "vaporizar",
    "vaporizado": "vaporizar",
    "vaporizadora": "vaporizador",
    "vaporizadoras": "vaporizador",
    "vaporizadores": "vaporizador",
    "vaporizados": "vaporizar",
    "vaporizai": "vaporizar",
    "vaporizais": "vaporizar",
    "vaporizam": "vaporizar",
    "vaporizamo": "vaporizar",
    "vaporizamos": "vaporizar",
    "vaporizando": "vaporizar",
    "vaporizara": "vaporizar",
    "vaporizaram": "vaporizar",
    "vaporizaras": "vaporizar",
    "vaporizarde": "vaporizar",
    "vaporizardes": "vaporizar",
    "vaporizare": "vaporizar",
    "vaporizarei": "vaporizar",
    "vaporizareis": "vaporizar",
    "vaporizarem": "vaporizar",
    "vaporizaremos": "vaporizar",
    "vaporizares": "vaporizar",
    "vaporizaria": "vaporizar",
    "vaporizariam": "vaporizar",
    "vaporizarias": "vaporizar",
    "vaporizarmo": "vaporizar",
    "vaporizarmos": "vaporizar",
    "vaporizará": "vaporizar",
    "vaporizarás": "vaporizar",
    "vaporizarão": "vaporizar",
    "vaporizaríamos": "vaporizar",
    "vaporizaríeis": "vaporizar",
    "vaporizas": "vaporizar",
    "vaporizasse": "vaporizar",
    "vaporizassem": "vaporizar",
    "vaporizasses": "vaporizar",
    "vaporizaste": "vaporizar",
    "vaporizastes": "vaporizar",
    "vaporizava": "vaporizar",
    "vaporizavam": "vaporizar",
    "vaporizavas": "vaporizar",
    "vaporizações": "vaporização",
    "vaporize": "vaporizar",
    "vaporizei": "vaporizar",
    "vaporizeis": "vaporizar",
    "vaporizem": "vaporizar",
    "vaporizemo": "vaporizar",
    "vaporizemos": "vaporizar",
    "vaporizes": "vaporizar",
    "vaporizo": "vaporizar",
    "vaporizou": "vaporizar",
    "vaporizá": "vaporizar",
    "vaporizámo": "vaporizar",
    "vaporizámos": "vaporizar",
    "vaporizáramo": "vaporizar",
    "vaporizáramos": "vaporizar",
    "vaporizárei": "vaporizar",
    "vaporizáreis": "vaporizar",
    "vaporizásseis": "vaporizar",
    "vaporizássemos": "vaporizar",
    "vaporizávamo": "vaporizar",
    "vaporizávamos": "vaporizar",
    "vaporizávei": "vaporizar",
    "vaporizáveis": "vaporizar",
    "vaporo": "vaporar",
    "vaporosa": "vaporoso",
    "vaporosas": "vaporoso",
    "vaporosos": "vaporoso",
    "vaporosíssima": "vaporoso",
    "vaporosíssimas": "vaporoso",
    "vaporosíssimo": "vaporoso",
    "vaporosíssimos": "vaporoso",
    "vaporou": "vaporar",
    "vaporámo": "vaporar",
    "vaporámos": "vaporar",
    "vaporáramo": "vaporar",
    "vaporáramos": "vaporar",
    "vaporáreis": "vaporar",
    "vaporásseis": "vaporar",
    "vaporássemos": "vaporar",
    "vaporávamo": "vaporar",
    "vaporávamos": "vaporar",
    "vaporáveis": "vaporável",
    "vaporífera": "vaporífero",
    "vaporíferas": "vaporífero",
    "vaporíferos": "vaporífero",
    "vaporímetros": "vaporímetro",
    "vapula": "vapular",
    "vapulada": "vapular",
    "vapuladas": "vapular",
    "vapulado": "vapular",
    "vapulados": "vapular",
    "vapulai": "vapular",
    "vapulais": "vapular",
    "vapulam": "vapular",
    "vapulamo": "vapular",
    "vapulamos": "vapular",
    "vapulando": "vapular",
    "vapulara": "vapular",
    "vapularam": "vapular",
    "vapularas": "vapular",
    "vapularde": "vapular",
    "vapulardes": "vapular",
    "vapulare": "vapular",
    "vapularei": "vapular",
    "vapulareis": "vapular",
    "vapularem": "vapular",
    "vapularemos": "vapular",
    "vapulares": "vapular",
    "vapularia": "vapular",
    "vapulariam": "vapular",
    "vapularias": "vapular",
    "vapularmo": "vapular",
    "vapularmos": "vapular",
    "vapulará": "vapular",
    "vapularás": "vapular",
    "vapularão": "vapular",
    "vapularíamos": "vapular",
    "vapularíeis": "vapular",
    "vapulas": "vapular",
    "vapulasse": "vapular",
    "vapulassem": "vapular",
    "vapulasses": "vapular",
    "vapulaste": "vapular",
    "vapulastes": "vapular",
    "vapulava": "vapular",
    "vapulavam": "vapular",
    "vapulavas": "vapular",
    "vapule": "vapular",
    "vapulei": "vapular",
    "vapuleis": "vapular",
    "vapulem": "vapular",
    "vapulemo": "vapular",
    "vapulemos": "vapular",
    "vapules": "vapular",
    "vapulo": "vapular",
    "vapulou": "vapular",
    "vapulá": "vapular",
    "vapulámo": "vapular",
    "vapulámos": "vapular",
    "vapuláramo": "vapular",
    "vapuláramos": "vapular",
    "vapulárei": "vapular",
    "vapuláreis": "vapular",
    "vapulásseis": "vapular",
    "vapulássemos": "vapular",
    "vapulávamo": "vapular",
    "vapulávamos": "vapular",
    "vapulávei": "vapular",
    "vapuláveis": "vapular",
    "vaque": "vacar",
    "vaqueana": "vaqueano",
    "vaqueanas": "vaqueano",
    "vaqueanos": "vaqueano",
    "vaquei": "vacar",
    "vaqueira": "vaqueiro",
    "vaqueiradas": "vaqueirada",
    "vaqueiramas": "vaqueirama",
    "vaqueiras": "vaqueiro",
    "vaqueiros": "vaqueiro",
    "vaqueis": "vacar",
    "vaqueja": "vaquejar",
    "vaquejada": "vaquejar",
    "vaquejadas": "vaquejar",
    "vaquejado": "vaquejar",
    "vaquejados": "vaquejar",
    "vaquejai": "vaquejar",
    "vaquejais": "vaquejar",
    "vaquejam": "vaquejar",
    "vaquejamo": "vaquejar",
    "vaquejamos": "vaquejar",
    "vaquejando": "vaquejar",
    "vaquejara": "vaquejar",
    "vaquejaram": "vaquejar",
    "vaquejaras": "vaquejar",
    "vaquejarde": "vaquejar",
    "vaquejardes": "vaquejar",
    "vaquejare": "vaquejar",
    "vaquejarei": "vaquejar",
    "vaquejareis": "vaquejar",
    "vaquejarem": "vaquejar",
    "vaquejaremos": "vaquejar",
    "vaquejares": "vaquejar",
    "vaquejaria": "vaquejar",
    "vaquejariam": "vaquejar",
    "vaquejarias": "vaquejar",
    "vaquejarmo": "vaquejar",
    "vaquejarmos": "vaquejar",
    "vaquejará": "vaquejar",
    "vaquejarás": "vaquejar",
    "vaquejarão": "vaquejar",
    "vaquejaríamos": "vaquejar",
    "vaquejaríeis": "vaquejar",
    "vaquejas": "vaquejar",
    "vaquejasse": "vaquejar",
    "vaquejassem": "vaquejar",
    "vaquejasses": "vaquejar",
    "vaquejaste": "vaquejar",
    "vaquejastes": "vaquejar",
    "vaquejava": "vaquejar",
    "vaquejavam": "vaquejar",
    "vaquejavas": "vaquejar",
    "vaqueje": "vaquejar",
    "vaquejei": "vaquejar",
    "vaquejeis": "vaquejar",
    "vaquejem": "vaquejar",
    "vaquejemo": "vaquejar",
    "vaquejemos": "vaquejar",
    "vaquejes": "vaquejar",
    "vaquejo": "vaquejar",
    "vaquejou": "vaquejar",
    "vaquejá": "vaquejar",
    "vaquejámo": "vaquejar",
    "vaquejámos": "vaquejar",
    "vaquejáramo": "vaquejar",
    "vaquejáramos": "vaquejar",
    "vaquejárei": "vaquejar",
    "vaquejáreis": "vaquejar",
    "vaquejásseis": "vaquejar",
    "vaquejássemos": "vaquejar",
    "vaquejávamo": "vaquejar",
    "vaquejávamos": "vaquejar",
    "vaquejávei": "vaquejar",
    "vaquejáveis": "vaquejar",
    "vaquem": "vacar",
    "vaquemos": "vacar",
    "vaques": "vacar",
    "vaquetas": "vaqueta",
    "vaquinha": "boi",
    "vaquinhas": "boi",
    "vaquita": "boi",
    "vaquitas": "boi",
    "vara": "varar",
    "varada": "varar",
    "varadas": "varar",
    "varado": "varar",
    "varadoiros": "varadoiro",
    "varadora": "varador",
    "varadoras": "varador",
    "varadores": "varador",
    "varados": "varar",
    "varadouros": "varadouro",
    "varadíssima": "varado",
    "varadíssimas": "varado",
    "varadíssimo": "varado",
    "varadíssimos": "varado",
    "varai": "varar",
    "varais": "varar",
    "varam": "varar",
    "varamo": "varar",
    "varamos": "varar",
    "varandas": "varanda",
    "varandinha": "varanda",
    "varandinhas": "varanda",
    "varandins": "varandim",
    "varandita": "varanda",
    "varanditas": "varanda",
    "varando": "varar",
    "varapaus": "varapau",
    "varara": "varar",
    "vararam": "varar",
    "vararas": "varar",
    "vararde": "varar",
    "varardes": "varar",
    "varare": "varar",
    "vararei": "varar",
    "varareis": "varar",
    "vararem": "varar",
    "vararemos": "varar",
    "varares": "varar",
    "vararia": "varar",
    "varariam": "varar",
    "vararias": "varar",
    "vararmo": "varar",
    "vararmos": "varar",
    "varará": "varar",
    "vararás": "varar",
    "vararão": "varar",
    "vararíamos": "varar",
    "vararíeis": "varar",
    "varas": "varar",
    "varasse": "varar",
    "varassem": "varar",
    "varasses": "varar",
    "varaste": "varar",
    "varastes": "varar",
    "varatojana": "varatojano",
    "varatojanas": "varatojano",
    "varatojanos": "varatojano",
    "varava": "varar",
    "varavam": "varar",
    "varavas": "varar",
    "varações": "varação",
    "vare": "varar",
    "vareada": "varear",
    "vareadas": "varear",
    "vareado": "varear",
    "vareados": "varear",
    "vareagens": "vareagem",
    "vareai": "varear",
    "vareais": "varear",
    "vareamo": "varear",
    "vareamos": "varear",
    "vareando": "varear",
    "vareara": "varear",
    "varearam": "varear",
    "varearas": "varear",
    "varearde": "varear",
    "vareardes": "varear",
    "vareare": "varear",
    "varearei": "varear",
    "vareareis": "varear",
    "varearem": "varear",
    "varearemos": "varear",
    "vareares": "varear",
    "varearia": "varear",
    "vareariam": "varear",
    "varearias": "varear",
    "varearmo": "varear",
    "varearmos": "varear",
    "vareará": "varear",
    "varearás": "varear",
    "varearão": "varear",
    "varearíamos": "varear",
    "varearíeis": "varear",
    "vareasse": "varear",
    "vareassem": "varear",
    "vareasses": "varear",
    "vareaste": "varear",
    "vareastes": "varear",
    "vareava": "varear",
    "vareavam": "varear",
    "vareavas": "varear",
    "varedos": "varedo",
    "vareei": "varear",
    "vareeis": "varear",
    "vareemo": "varear",
    "vareemos": "varear",
    "varei": "varar",
    "vareia": "varear",
    "vareiam": "varear",
    "vareias": "varear",
    "vareie": "varear",
    "vareiem": "varear",
    "vareies": "varear",
    "vareio": "varear",
    "vareios": "vareio",
    "vareira": "vareiro",
    "vareiras": "vareiro",
    "vareiros": "vareiro",
    "vareis": "varar",
    "vareja": "varejar",
    "varejada": "varejar",
    "varejadas": "varejar",
    "varejado": "varejar",
    "varejadora": "varejador",
    "varejadoras": "varejador",
    "varejadores": "varejador",
    "varejados": "varejar",
    "varejaduras": "varejadura",
    "varejai": "varejar",
    "varejais": "varejar",
    "varejam": "varejar",
    "varejamentos": "varejamento",
    "varejamo": "varejar",
    "varejamos": "varejar",
    "varejando": "varejar",
    "varejara": "varejar",
    "varejaram": "varejar",
    "varejaras": "varejar",
    "varejarde": "varejar",
    "varejardes": "varejar",
    "varejare": "varejar",
    "varejarei": "varejar",
    "varejareis": "varejar",
    "varejarem": "varejar",
    "varejaremos": "varejar",
    "varejares": "varejar",
    "varejaria": "varejar",
    "varejariam": "varejar",
    "varejarias": "varejar",
    "varejarmo": "varejar",
    "varejarmos": "varejar",
    "varejará": "varejar",
    "varejarás": "varejar",
    "varejarão": "varejar",
    "varejaríamos": "varejar",
    "varejaríeis": "varejar",
    "varejas": "varejar",
    "varejasse": "varejar",
    "varejassem": "varejar",
    "varejasses": "varejar",
    "varejaste": "varejar",
    "varejastes": "varejar",
    "varejava": "varejar",
    "varejavam": "varejar",
    "varejavas": "varejar",
    "vareje": "varejar",
    "varejei": "varejar",
    "varejeiras": "varejeira",
    "varejeis": "varejar",
    "varejem": "varejar",
    "varejemo": "varejar",
    "varejemos": "varejar",
    "varejes": "varejar",
    "varejo": "varejar",
    "varejos": "varejo",
    "varejou": "varejar",
    "varejá": "varejar",
    "varejámo": "varejar",
    "varejámos": "varejar",
    "varejáramo": "varejar",
    "varejáramos": "varejar",
    "varejárei": "varejar",
    "varejáreis": "varejar",
    "varejásseis": "varejar",
    "varejássemos": "varejar",
    "varejávamo": "varejar",
    "varejávamos": "varejar",
    "varejávei": "varejar",
    "varejáveis": "varejar",
    "varejões": "varejão",
    "varelas": "varela",
    "varem": "varar",
    "varemo": "varar",
    "varemos": "varar",
    "vareou": "varear",
    "vareques": "vareque",
    "vares": "varar",
    "varestilhas": "varestilha",
    "varetas": "vareta",
    "vareá": "varear",
    "vareámo": "varear",
    "vareámos": "varear",
    "vareáramo": "varear",
    "vareáramos": "varear",
    "vareárei": "varear",
    "vareáreis": "varear",
    "vareásseis": "varear",
    "vareássemos": "varear",
    "vareávamo": "varear",
    "vareávamos": "varear",
    "vareávei": "varear",
    "vareáveis": "varear",
    "vargas": "varga",
    "vargedos": "vargedo",
    "vargeiros": "vargeiro",
    "vargens": "vargem",
    "vargueiros": "vargueiro",
    "varia": "variar",
    "variabilidades": "variabilidade",
    "variada": "variar",
    "variadas": "variar",
    "variadeiras": "variadeira",
    "variado": "variar",
    "variados": "variar",
    "variadíssima": "variado",
    "variadíssimas": "variado",
    "variadíssimo": "variado",
    "variadíssimos": "variado",
    "variagens": "variagem",
    "variai": "variar",
    "variais": "variar",
    "variam": "variar",
    "variamo": "variar",
    "variamos": "variar",
    "variando": "variar",
    "varianelas": "varianela",
    "variantes": "variante",
    "variara": "variar",
    "variaram": "variar",
    "variaras": "variar",
    "variarde": "variar",
    "variardes": "variar",
    "variare": "variar",
    "variarei": "variar",
    "variareis": "variar",
    "variarem": "variar",
    "variaremos": "variar",
    "variares": "variar",
    "variaria": "variar",
    "variariam": "variar",
    "variarias": "variar",
    "variarmo": "variar",
    "variarmos": "variar",
    "variará": "variar",
    "variarás": "variar",
    "variarão": "variar",
    "variaríamos": "variar",
    "variaríeis": "variar",
    "varias": "variar",
    "variasse": "variar",
    "variassem": "variar",
    "variasses": "variar",
    "variaste": "variar",
    "variastes": "variar",
    "variava": "variar",
    "variavam": "variar",
    "variavas": "variar",
    "variazes": "variaz",
    "variações": "variação",
    "varicelares": "varicelar",
    "varicelas": "varicela",
    "varicelóides": "varicelóide",
    "varicoceles": "varicocele",
    "varicosa": "varicoso",
    "varicosas": "varicoso",
    "varicoses": "varicose",
    "varicosidades": "varicosidade",
    "varicosos": "varicoso",
    "varie": "variar",
    "variedades": "variedade",
    "variega": "variegar",
    "variegada": "variegar",
    "variegadas": "variegar",
    "variegado": "variegar",
    "variegados": "variegar",
    "variegai": "variegar",
    "variegais": "variegar",
    "variegam": "variegar",
    "variegamo": "variegar",
    "variegamos": "variegar",
    "variegando": "variegar",
    "variegara": "variegar",
    "variegaram": "variegar",
    "variegaras": "variegar",
    "variegarde": "variegar",
    "variegardes": "variegar",
    "variegare": "variegar",
    "variegarei": "variegar",
    "variegareis": "variegar",
    "variegarem": "variegar",
    "variegaremos": "variegar",
    "variegares": "variegar",
    "variegaria": "variegar",
    "variegariam": "variegar",
    "variegarias": "variegar",
    "variegarmo": "variegar",
    "variegarmos": "variegar",
    "variegará": "variegar",
    "variegarás": "variegar",
    "variegarão": "variegar",
    "variegaríamos": "variegar",
    "variegaríeis": "variegar",
    "variegas": "variegar",
    "variegasse": "variegar",
    "variegassem": "variegar",
    "variegasses": "variegar",
    "variegaste": "variegar",
    "variegastes": "variegar",
    "variegava": "variegar",
    "variegavam": "variegar",
    "variegavas": "variegar",
    "variegações": "variegação",
    "variego": "variegar",
    "variegou": "variegar",
    "variegue": "variegar",
    "varieguei": "variegar",
    "variegueis": "variegar",
    "varieguem": "variegar",
    "varieguemo": "variegar",
    "varieguemos": "variegar",
    "variegues": "variegar",
    "variegá": "variegar",
    "variegámo": "variegar",
    "variegámos": "variegar",
    "variegáramo": "variegar",
    "variegáramos": "variegar",
    "variegárei": "variegar",
    "variegáreis": "variegar",
    "variegásseis": "variegar",
    "variegássemos": "variegar",
    "variegávamo": "variegar",
    "variegávamos": "variegar",
    "variegávei": "variegar",
    "variegáveis": "variegar",
    "variei": "variar",
    "varieis": "variar",
    "variem": "variar",
    "variemo": "variar",
    "variemos": "variar",
    "varies": "variar",
    "varina": "varino",
    "varinagens": "varinagem",
    "varinas": "varino",
    "varineis": "varinel",
    "varinha": "vara",
    "varinhas": "vara",
    "varinos": "varino",
    "vario": "variar",
    "variolada": "variolado",
    "varioladas": "variolado",
    "variolados": "variolado",
    "variolares": "variolar",
    "varioliformes": "varioliforme",
    "variolizações": "variolização",
    "variolóides": "variolóide",
    "variou": "variar",
    "varita": "vara",
    "varitas": "vara",
    "varizes": "variz",
    "variá": "variar",
    "variámo": "variar",
    "variámos": "variar",
    "variáramo": "variar",
    "variáramos": "variar",
    "variárei": "variar",
    "variáreis": "variar",
    "variásseis": "variar",
    "variássemos": "variar",
    "variávamo": "variar",
    "variávamos": "variar",
    "variávei": "variar",
    "variáveis": "variável",
    "variâncias": "variância",
    "variólica": "variólico",
    "variólicas": "variólico",
    "variólicos": "variólico",
    "variómetros": "variómetro",
    "varjas": "varja",
    "varo": "varar",
    "varolas": "varola",
    "varonias": "varonia",
    "varoniis": "varonil",
    "varonilidades": "varonilidade",
    "varou": "varar",
    "varovites": "varovite",
    "varra": "varrer",
    "varrais": "varrer",
    "varram": "varrer",
    "varramo": "varrer",
    "varramos": "varrer",
    "varras": "varrer",
    "varrascos": "varrasco",
    "varre": "varrer",
    "varredeira": "varredor",
    "varredeiras": "varredor",
    "varredelas": "varredela",
    "varredoiras": "varredoira",
    "varredoiros": "varredoiro",
    "varredora": "varredor",
    "varredoras": "varredor",
    "varredores": "varredor",
    "varredouras": "varredoura",
    "varredouros": "varredouro",
    "varreduras": "varredura",
    "varrei": "varrer",
    "varreis": "varrer",
    "varrem": "varrer",
    "varremo": "varrer",
    "varremos": "varrer",
    "varrendo": "varrer",
    "varrera": "varrer",
    "varreram": "varrer",
    "varreras": "varrer",
    "varrerde": "varrer",
    "varrerdes": "varrer",
    "varrere": "varrer",
    "varrerei": "varrer",
    "varrereis": "varrer",
    "varrerem": "varrer",
    "varreremos": "varrer",
    "varreres": "varrer",
    "varreria": "varrer",
    "varreriam": "varrer",
    "varrerias": "varrer",
    "varrermo": "varrer",
    "varrermos": "varrer",
    "varrerá": "varrer",
    "varrerás": "varrer",
    "varrerão": "varrer",
    "varreríamos": "varrer",
    "varreríeis": "varrer",
    "varres": "varrer",
    "varresse": "varrer",
    "varressem": "varrer",
    "varresses": "varrer",
    "varreste": "varrer",
    "varrestes": "varrer",
    "varreu": "varrer",
    "varri": "varrer",
    "varria": "varrer",
    "varriam": "varrer",
    "varrias": "varrer",
    "varrida": "varrido",
    "varridas": "varrido",
    "varridinha": "varrido",
    "varridinhas": "varrido",
    "varridinho": "varrido",
    "varridinhos": "varrido",
    "varridita": "varrido",
    "varriditas": "varrido",
    "varridito": "varrido",
    "varriditos": "varrido",
    "varrido": "varrer",
    "varridos": "varrido",
    "varridíssima": "varrido",
    "varridíssimas": "varrido",
    "varridíssimo": "varrido",
    "varridíssimos": "varrido",
    "varrisca": "varriscar",
    "varriscada": "varriscar",
    "varriscadas": "varriscar",
    "varriscado": "varriscar",
    "varriscados": "varriscar",
    "varriscai": "varriscar",
    "varriscais": "varriscar",
    "varriscam": "varriscar",
    "varriscamo": "varriscar",
    "varriscamos": "varriscar",
    "varriscando": "varriscar",
    "varriscara": "varriscar",
    "varriscaram": "varriscar",
    "varriscaras": "varriscar",
    "varriscarde": "varriscar",
    "varriscardes": "varriscar",
    "varriscare": "varriscar",
    "varriscarei": "varriscar",
    "varriscareis": "varriscar",
    "varriscarem": "varriscar",
    "varriscaremos": "varriscar",
    "varriscares": "varriscar",
    "varriscaria": "varriscar",
    "varriscariam": "varriscar",
    "varriscarias": "varriscar",
    "varriscarmo": "varriscar",
    "varriscarmos": "varriscar",
    "varriscará": "varriscar",
    "varriscarás": "varriscar",
    "varriscarão": "varriscar",
    "varriscaríamos": "varriscar",
    "varriscaríeis": "varriscar",
    "varriscas": "varriscar",
    "varriscasse": "varriscar",
    "varriscassem": "varriscar",
    "varriscasses": "varriscar",
    "varriscaste": "varriscar",
    "varriscastes": "varriscar",
    "varriscava": "varriscar",
    "varriscavam": "varriscar",
    "varriscavas": "varriscar",
    "varrisco": "varriscar",
    "varriscou": "varriscar",
    "varriscá": "varriscar",
    "varriscámo": "varriscar",
    "varriscámos": "varriscar",
    "varriscáramo": "varriscar",
    "varriscáramos": "varriscar",
    "varriscárei": "varriscar",
    "varriscáreis": "varriscar",
    "varriscásseis": "varriscar",
    "varriscássemos": "varriscar",
    "varriscávamo": "varriscar",
    "varriscávamos": "varriscar",
    "varriscávei": "varriscar",
    "varriscáveis": "varriscar",
    "varrisque": "varriscar",
    "varrisquei": "varriscar",
    "varrisqueis": "varriscar",
    "varrisquem": "varriscar",
    "varrisquemo": "varriscar",
    "varrisquemos": "varriscar",
    "varrisques": "varriscar",
    "varro": "varrer",
    "varrê": "varrer",
    "varrêramo": "varrer",
    "varrêramos": "varrer",
    "varrêrei": "varrer",
    "varrêreis": "varrer",
    "varrêsseis": "varrer",
    "varrêssemos": "varrer",
    "varríamo": "varrer",
    "varríamos": "varrer",
    "varríei": "varrer",
    "varríeis": "varrer",
    "varrões": "varrão",
    "varsoviana": "varsoviano",
    "varsovianas": "varsoviano",
    "varsovianos": "varsoviano",
    "varuda": "varudo",
    "varudas": "varudo",
    "varudos": "varudo",
    "varuncas": "varunca",
    "varves": "varve",
    "varzina": "varzino",
    "varzinas": "varzino",
    "varzinenses": "varzinense",
    "varzinos": "varzino",
    "varzins": "varzim",
    "vará": "varar",
    "varámo": "varar",
    "varámos": "varar",
    "varáramo": "varar",
    "varáramos": "varar",
    "varárei": "varar",
    "varáreis": "varar",
    "varásseis": "varar",
    "varássemos": "varar",
    "varávamo": "varar",
    "varávamos": "varar",
    "varávei": "varar",
    "varáveis": "varar",
    "varículas": "varícula",
    "varíolas": "varíola",
    "varões": "varão",
    "vasada": "vasado",
    "vasadas": "vasado",
    "vasados": "vasado",
    "vasadíssima": "vasado",
    "vasadíssimas": "vasado",
    "vasadíssimo": "vasado",
    "vasadíssimos": "vasado",
    "vasaréus": "vasaréu",
    "vasas": "vasa",
    "vasca": "vasco",
    "vascas": "vasco",
    "vascoleja": "vascolejar",
    "vascolejada": "vascolejar",
    "vascolejadas": "vascolejar",
    "vascolejado": "vascolejar",
    "vascolejadora": "vascolejador",
    "vascolejadoras": "vascolejador",
    "vascolejadores": "vascolejador",
    "vascolejados": "vascolejar",
    "vascolejai": "vascolejar",
    "vascolejais": "vascolejar",
    "vascolejam": "vascolejar",
    "vascolejamentos": "vascolejamento",
    "vascolejamo": "vascolejar",
    "vascolejamos": "vascolejar",
    "vascolejando": "vascolejar",
    "vascolejara": "vascolejar",
    "vascolejaram": "vascolejar",
    "vascolejaras": "vascolejar",
    "vascolejarde": "vascolejar",
    "vascolejardes": "vascolejar",
    "vascolejare": "vascolejar",
    "vascolejarei": "vascolejar",
    "vascolejareis": "vascolejar",
    "vascolejarem": "vascolejar",
    "vascolejaremos": "vascolejar",
    "vascolejares": "vascolejar",
    "vascolejaria": "vascolejar",
    "vascolejariam": "vascolejar",
    "vascolejarias": "vascolejar",
    "vascolejarmo": "vascolejar",
    "vascolejarmos": "vascolejar",
    "vascolejará": "vascolejar",
    "vascolejarás": "vascolejar",
    "vascolejarão": "vascolejar",
    "vascolejaríamos": "vascolejar",
    "vascolejaríeis": "vascolejar",
    "vascolejas": "vascolejar",
    "vascolejasse": "vascolejar",
    "vascolejassem": "vascolejar",
    "vascolejasses": "vascolejar",
    "vascolejaste": "vascolejar",
    "vascolejastes": "vascolejar",
    "vascolejava": "vascolejar",
    "vascolejavam": "vascolejar",
    "vascolejavas": "vascolejar",
    "vascoleje": "vascolejar",
    "vascolejei": "vascolejar",
    "vascolejeis": "vascolejar",
    "vascolejem": "vascolejar",
    "vascolejemo": "vascolejar",
    "vascolejemos": "vascolejar",
    "vascolejes": "vascolejar",
    "vascolejo": "vascolejar",
    "vascolejou": "vascolejar",
    "vascolejá": "vascolejar",
    "vascolejámo": "vascolejar",
    "vascolejámos": "vascolejar",
    "vascolejáramo": "vascolejar",
    "vascolejáramos": "vascolejar",
    "vascolejárei": "vascolejar",
    "vascolejáreis": "vascolejar",
    "vascolejásseis": "vascolejar",
    "vascolejássemos": "vascolejar",
    "vascolejávamo": "vascolejar",
    "vascolejávamos": "vascolejar",
    "vascolejávei": "vascolejar",
    "vascolejáveis": "vascolejar",
    "vascolosa": "vascoloso",
    "vascolosas": "vascoloso",
    "vascolosos": "vascoloso",
    "vascona": "vascão",
    "vasconas": "vascão",
    "vasconceada": "vasconcear",
    "vasconceadas": "vasconcear",
    "vasconceado": "vasconcear",
    "vasconceados": "vasconcear",
    "vasconceai": "vasconcear",
    "vasconceais": "vasconcear",
    "vasconceamo": "vasconcear",
    "vasconceamos": "vasconcear",
    "vasconceando": "vasconcear",
    "vasconceara": "vasconcear",
    "vasconcearam": "vasconcear",
    "vasconcearas": "vasconcear",
    "vasconceardes": "vasconcear",
    "vasconcearei": "vasconcear",
    "vasconceareis": "vasconcear",
    "vasconcearem": "vasconcear",
    "vasconcearemos": "vasconcear",
    "vasconceares": "vasconcear",
    "vasconcearia": "vasconcear",
    "vasconceariam": "vasconcear",
    "vasconcearias": "vasconcear",
    "vasconcearmo": "vasconcear",
    "vasconcearmos": "vasconcear",
    "vasconceará": "vasconcear",
    "vasconcearás": "vasconcear",
    "vasconcearão": "vasconcear",
    "vasconcearíamos": "vasconcear",
    "vasconcearíeis": "vasconcear",
    "vasconceasse": "vasconcear",
    "vasconceassem": "vasconcear",
    "vasconceasses": "vasconcear",
    "vasconceaste": "vasconcear",
    "vasconceastes": "vasconcear",
    "vasconceava": "vasconcear",
    "vasconceavam": "vasconcear",
    "vasconceavas": "vasconcear",
    "vasconceei": "vasconcear",
    "vasconceeis": "vasconcear",
    "vasconceemo": "vasconcear",
    "vasconceemos": "vasconcear",
    "vasconceia": "vasconcear",
    "vasconceiam": "vasconcear",
    "vasconceias": "vasconcear",
    "vasconceie": "vasconcear",
    "vasconceiem": "vasconcear",
    "vasconceies": "vasconcear",
    "vasconceio": "vasconcear",
    "vasconceou": "vasconcear",
    "vasconceámo": "vasconcear",
    "vasconceámos": "vasconcear",
    "vasconceáramo": "vasconcear",
    "vasconceáramos": "vasconcear",
    "vasconceáreis": "vasconcear",
    "vasconceásseis": "vasconcear",
    "vasconceássemos": "vasconcear",
    "vasconceávamo": "vasconcear",
    "vasconceávamos": "vasconcear",
    "vasconceáveis": "vasconcear",
    "vascongada": "vascongado",
    "vascongadas": "vascongado",
    "vascongados": "vascongado",
    "vasconça": "vasconço",
    "vasconças": "vasconço",
    "vasconços": "vasconço",
    "vascos": "vasco",
    "vascosa": "vascoso",
    "vascosas": "vascoso",
    "vascosos": "vascoso",
    "vascuenses": "vascuense",
    "vasculares": "vascular",
    "vascularidades": "vascularidade",
    "vasculariza": "vascularizar",
    "vascularizada": "vascularizar",
    "vascularizadas": "vascularizar",
    "vascularizado": "vascularizar",
    "vascularizados": "vascularizar",
    "vascularizai": "vascularizar",
    "vascularizais": "vascularizar",
    "vascularizam": "vascularizar",
    "vascularizamo": "vascularizar",
    "vascularizamos": "vascularizar",
    "vascularizando": "vascularizar",
    "vascularizara": "vascularizar",
    "vascularizaram": "vascularizar",
    "vascularizaras": "vascularizar",
    "vascularizarde": "vascularizar",
    "vascularizardes": "vascularizar",
    "vascularizare": "vascularizar",
    "vascularizarei": "vascularizar",
    "vascularizareis": "vascularizar",
    "vascularizarem": "vascularizar",
    "vascularizaremos": "vascularizar",
    "vascularizares": "vascularizar",
    "vascularizaria": "vascularizar",
    "vascularizariam": "vascularizar",
    "vascularizarias": "vascularizar",
    "vascularizarmo": "vascularizar",
    "vascularizarmos": "vascularizar",
    "vascularizará": "vascularizar",
    "vascularizarás": "vascularizar",
    "vascularizarão": "vascularizar",
    "vascularizaríamos": "vascularizar",
    "vascularizaríeis": "vascularizar",
    "vascularizas": "vascularizar",
    "vascularizasse": "vascularizar",
    "vascularizassem": "vascularizar",
    "vascularizasses": "vascularizar",
    "vascularizaste": "vascularizar",
    "vascularizastes": "vascularizar",
    "vascularizava": "vascularizar",
    "vascularizavam": "vascularizar",
    "vascularizavas": "vascularizar",
    "vascularizações": "vascularização",
    "vascularize": "vascularizar",
    "vascularizei": "vascularizar",
    "vascularizeis": "vascularizar",
    "vascularizem": "vascularizar",
    "vascularizemo": "vascularizar",
    "vascularizemos": "vascularizar",
    "vascularizes": "vascularizar",
    "vascularizo": "vascularizar",
    "vascularizou": "vascularizar",
    "vascularizá": "vascularizar",
    "vascularizámo": "vascularizar",
    "vascularizámos": "vascularizar",
    "vascularizáramo": "vascularizar",
    "vascularizáramos": "vascularizar",
    "vascularizárei": "vascularizar",
    "vascularizáreis": "vascularizar",
    "vascularizásseis": "vascularizar",
    "vascularizássemos": "vascularizar",
    "vascularizávamo": "vascularizar",
    "vascularizávamos": "vascularizar",
    "vascularizávei": "vascularizar",
    "vascularizáveis": "vascularizar",
    "vasculha": "vasculhar",
    "vasculhada": "vasculhar",
    "vasculhadas": "vasculhar",
    "vasculhadeira": "vasculhador",
    "vasculhadeiras": "vasculhador",
    "vasculhado": "vasculhar",
    "vasculhadora": "vasculhador",
    "vasculhadoras": "vasculhador",
    "vasculhadores": "vasculhador",
    "vasculhados": "vasculhar",
    "vasculhai": "vasculhar",
    "vasculhais": "vasculhar",
    "vasculham": "vasculhar",
    "vasculhamo": "vasculhar",
    "vasculhamos": "vasculhar",
    "vasculhando": "vasculhar",
    "vasculhara": "vasculhar",
    "vasculharam": "vasculhar",
    "vasculharas": "vasculhar",
    "vasculharde": "vasculhar",
    "vasculhardes": "vasculhar",
    "vasculhare": "vasculhar",
    "vasculharei": "vasculhar",
    "vasculhareis": "vasculhar",
    "vasculharem": "vasculhar",
    "vasculharemos": "vasculhar",
    "vasculhares": "vasculhar",
    "vasculharia": "vasculhar",
    "vasculhariam": "vasculhar",
    "vasculharias": "vasculhar",
    "vasculharmo": "vasculhar",
    "vasculharmos": "vasculhar",
    "vasculhará": "vasculhar",
    "vasculharás": "vasculhar",
    "vasculharão": "vasculhar",
    "vasculharíamos": "vasculhar",
    "vasculharíeis": "vasculhar",
    "vasculhas": "vasculhar",
    "vasculhasse": "vasculhar",
    "vasculhassem": "vasculhar",
    "vasculhasses": "vasculhar",
    "vasculhaste": "vasculhar",
    "vasculhastes": "vasculhar",
    "vasculhava": "vasculhar",
    "vasculhavam": "vasculhar",
    "vasculhavas": "vasculhar",
    "vasculhe": "vasculhar",
    "vasculhei": "vasculhar",
    "vasculheis": "vasculhar",
    "vasculhem": "vasculhar",
    "vasculhemo": "vasculhar",
    "vasculhemos": "vasculhar",
    "vasculhes": "vasculhar",
    "vasculho": "vasculhar",
    "vasculhos": "vasculho",
    "vasculhou": "vasculhar",
    "vasculhá": "vasculhar",
    "vasculhámo": "vasculhar",
    "vasculhámos": "vasculhar",
    "vasculháramo": "vasculhar",
    "vasculháramos": "vasculhar",
    "vasculhárei": "vasculhar",
    "vasculháreis": "vasculhar",
    "vasculhásseis": "vasculhar",
    "vasculhássemos": "vasculhar",
    "vasculhávamo": "vasculhar",
    "vasculhávamos": "vasculhar",
    "vasculhávei": "vasculhar",
    "vasculháveis": "vasculhar",
    "vascões": "vascão",
    "vasectomias": "vasectomia",
    "vaseira": "vaseiro",
    "vaseiras": "vaseiro",
    "vaseirona": "vaseirão",
    "vaseironas": "vaseirão",
    "vaseiros": "vaseiro",
    "vaseirões": "vaseirão",
    "vaselinas": "vaselina",
    "vasenta": "vasento",
    "vasentas": "vasento",
    "vasentos": "vasento",
    "vasiformes": "vasiforme",
    "vasilhames": "vasilhame",
    "vasilhas": "vasilha",
    "vasinho": "vaso",
    "vasinhos": "vaso",
    "vasito": "vaso",
    "vasitos": "vaso",
    "vasoactiva": "vasoactivo",
    "vasoactivas": "vasoactivo",
    "vasoactivos": "vasoactivo",
    "vasocelulares": "vasocelular",
    "vasoconstritora": "vasoconstritor",
    "vasoconstritoras": "vasoconstritor",
    "vasoconstritores": "vasoconstritor",
    "vasoconstrições": "vasoconstrição",
    "vasodilatadora": "vasodilatador",
    "vasodilatadoras": "vasodilatador",
    "vasodilatadores": "vasodilatador",
    "vasodilatações": "vasodilatação",
    "vasomotora": "vasomotor",
    "vasomotoras": "vasomotor",
    "vasomotores": "vasomotor",
    "vasomotrizes": "vasomotriz",
    "vasos": "vaso",
    "vasosa": "vasoso",
    "vasosas": "vasoso",
    "vasosos": "vasoso",
    "vasostomias": "vasostomia",
    "vasotomias": "vasotomia",
    "vasqueira": "vasqueiro",
    "vasqueiras": "vasqueiro",
    "vasqueiros": "vasqueiro",
    "vasqueja": "vasquejar",
    "vasquejada": "vasquejar",
    "vasquejadas": "vasquejar",
    "vasquejado": "vasquejar",
    "vasquejados": "vasquejar",
    "vasquejai": "vasquejar",
    "vasquejais": "vasquejar",
    "vasquejam": "vasquejar",
    "vasquejamo": "vasquejar",
    "vasquejamos": "vasquejar",
    "vasquejando": "vasquejar",
    "vasquejantes": "vasquejante",
    "vasquejara": "vasquejar",
    "vasquejaram": "vasquejar",
    "vasquejaras": "vasquejar",
    "vasquejardes": "vasquejar",
    "vasquejarei": "vasquejar",
    "vasquejareis": "vasquejar",
    "vasquejarem": "vasquejar",
    "vasquejaremos": "vasquejar",
    "vasquejares": "vasquejar",
    "vasquejaria": "vasquejar",
    "vasquejariam": "vasquejar",
    "vasquejarias": "vasquejar",
    "vasquejarmo": "vasquejar",
    "vasquejarmos": "vasquejar",
    "vasquejará": "vasquejar",
    "vasquejarás": "vasquejar",
    "vasquejarão": "vasquejar",
    "vasquejaríamos": "vasquejar",
    "vasquejaríeis": "vasquejar",
    "vasquejas": "vasquejar",
    "vasquejasse": "vasquejar",
    "vasquejassem": "vasquejar",
    "vasquejasses": "vasquejar",
    "vasquejaste": "vasquejar",
    "vasquejastes": "vasquejar",
    "vasquejava": "vasquejar",
    "vasquejavam": "vasquejar",
    "vasquejavas": "vasquejar",
    "vasqueje": "vasquejar",
    "vasquejei": "vasquejar",
    "vasquejeis": "vasquejar",
    "vasquejem": "vasquejar",
    "vasquejemo": "vasquejar",
    "vasquejemos": "vasquejar",
    "vasquejes": "vasquejar",
    "vasquejo": "vasquejar",
    "vasquejou": "vasquejar",
    "vasquejámo": "vasquejar",
    "vasquejámos": "vasquejar",
    "vasquejáramo": "vasquejar",
    "vasquejáramos": "vasquejar",
    "vasquejáreis": "vasquejar",
    "vasquejásseis": "vasquejar",
    "vasquejássemos": "vasquejar",
    "vasquejávamo": "vasquejar",
    "vasquejávamos": "vasquejar",
    "vasquejáveis": "vasquejar",
    "vasquinhas": "vasquinha",
    "vasquins": "vasquim",
    "vassala": "vassalo",
    "vassalagens": "vassalagem",
    "vassalas": "vassalo",
    "vassalos": "vassalo",
    "vassalíssima": "vassalo",
    "vassalíssimas": "vassalo",
    "vassalíssimo": "vassalo",
    "vassalíssimos": "vassalo",
    "vassoira": "vassoirar",
    "vassoirada": "vassoirar",
    "vassoiradas": "vassoirar",
    "vassoirado": "vassoirar",
    "vassoirados": "vassoirar",
    "vassoirai": "vassoirar",
    "vassoirais": "vassoirar",
    "vassoiram": "vassoirar",
    "vassoiramo": "vassoirar",
    "vassoiramos": "vassoirar",
    "vassoirando": "vassoirar",
    "vassoirara": "vassoirar",
    "vassoiraram": "vassoirar",
    "vassoiraras": "vassoirar",
    "vassoirarde": "vassoirar",
    "vassoirardes": "vassoirar",
    "vassoirare": "vassoirar",
    "vassoirarei": "vassoirar",
    "vassoirareis": "vassoirar",
    "vassoirarem": "vassoirar",
    "vassoiraremos": "vassoirar",
    "vassoirares": "vassoirar",
    "vassoiraria": "vassoirar",
    "vassoirariam": "vassoirar",
    "vassoirarias": "vassoirar",
    "vassoirarmo": "vassoirar",
    "vassoirarmos": "vassoirar",
    "vassoirará": "vassoirar",
    "vassoirarás": "vassoirar",
    "vassoirarão": "vassoirar",
    "vassoiraríamos": "vassoirar",
    "vassoiraríeis": "vassoirar",
    "vassoiras": "vassoirar",
    "vassoirasse": "vassoirar",
    "vassoirassem": "vassoirar",
    "vassoirasses": "vassoirar",
    "vassoiraste": "vassoirar",
    "vassoirastes": "vassoirar",
    "vassoirava": "vassoirar",
    "vassoiravam": "vassoirar",
    "vassoiravas": "vassoirar",
    "vassoire": "vassoirar",
    "vassoirei": "vassoirar",
    "vassoireira": "vassoireiro",
    "vassoireiras": "vassoireiro",
    "vassoireiros": "vassoireiro",
    "vassoireis": "vassoirar",
    "vassoirem": "vassoirar",
    "vassoiremo": "vassoirar",
    "vassoiremos": "vassoirar",
    "vassoires": "vassoirar",
    "vassoirinha": "vassoira",
    "vassoirinhas": "vassoirinha",
    "vassoirita": "vassoira",
    "vassoiritas": "vassoira",
    "vassoiro": "vassoirar",
    "vassoiros": "vassoiro",
    "vassoirou": "vassoirar",
    "vassoirá": "vassoirar",
    "vassoirámo": "vassoirar",
    "vassoirámos": "vassoirar",
    "vassoiráramo": "vassoirar",
    "vassoiráramos": "vassoirar",
    "vassoirárei": "vassoirar",
    "vassoiráreis": "vassoirar",
    "vassoirásseis": "vassoirar",
    "vassoirássemos": "vassoirar",
    "vassoirávamo": "vassoirar",
    "vassoirávamos": "vassoirar",
    "vassoirávei": "vassoirar",
    "vassoiráveis": "vassoirar",
    "vassoura": "vassourar",
    "vassourada": "vassourar",
    "vassouradas": "vassourar",
    "vassourado": "vassourar",
    "vassourados": "vassourar",
    "vassourai": "vassourar",
    "vassourais": "vassourar",
    "vassouram": "vassourar",
    "vassouramo": "vassourar",
    "vassouramos": "vassourar",
    "vassourando": "vassourar",
    "vassourara": "vassourar",
    "vassouraram": "vassourar",
    "vassouraras": "vassourar",
    "vassourarde": "vassourar",
    "vassourardes": "vassourar",
    "vassourare": "vassourar",
    "vassourarei": "vassourar",
    "vassourareis": "vassourar",
    "vassourarem": "vassourar",
    "vassouraremos": "vassourar",
    "vassourares": "vassourar",
    "vassouraria": "vassourar",
    "vassourariam": "vassourar",
    "vassourarias": "vassourar",
    "vassourarmo": "vassourar",
    "vassourarmos": "vassourar",
    "vassourará": "vassourar",
    "vassourarás": "vassourar",
    "vassourarão": "vassourar",
    "vassouraríamos": "vassourar",
    "vassouraríeis": "vassourar",
    "vassouras": "vassourar",
    "vassourasse": "vassourar",
    "vassourassem": "vassourar",
    "vassourasses": "vassourar",
    "vassouraste": "vassourar",
    "vassourastes": "vassourar",
    "vassourava": "vassourar",
    "vassouravam": "vassourar",
    "vassouravas": "vassourar",
    "vassoure": "vassourar",
    "vassourei": "vassourar",
    "vassoureira": "vassoureiro",
    "vassoureiras": "vassoureiro",
    "vassoureiros": "vassoureiro",
    "vassoureis": "vassourar",
    "vassourem": "vassourar",
    "vassouremo": "vassourar",
    "vassouremos": "vassourar",
    "vassourenses": "vassourense",
    "vassoures": "vassourar",
    "vassourinha": "vassoura",
    "vassourinhas": "vassourinha",
    "vassourita": "vassoura",
    "vassouritas": "vassoura",
    "vassouro": "vassourar",
    "vassouros": "vassouro",
    "vassourou": "vassourar",
    "vassourá": "vassourar",
    "vassourámo": "vassourar",
    "vassourámos": "vassourar",
    "vassouráramo": "vassourar",
    "vassouráramos": "vassourar",
    "vassourárei": "vassourar",
    "vassouráreis": "vassourar",
    "vassourásseis": "vassourar",
    "vassourássemos": "vassourar",
    "vassourávamo": "vassourar",
    "vassourávamos": "vassourar",
    "vassourávei": "vassourar",
    "vassouráveis": "vassourar",
    "vasta": "vasto",
    "vastada": "vastar",
    "vastadas": "vastar",
    "vastado": "vastar",
    "vastadora": "vastador",
    "vastadoras": "vastador",
    "vastadores": "vastador",
    "vastados": "vastar",
    "vastai": "vastar",
    "vastais": "vastar",
    "vastam": "vastar",
    "vastamo": "vastar",
    "vastamos": "vastar",
    "vastando": "vastar",
    "vastara": "vastar",
    "vastaram": "vastar",
    "vastaras": "vastar",
    "vastarde": "vastar",
    "vastardes": "vastar",
    "vastare": "vastar",
    "vastarei": "vastar",
    "vastareis": "vastar",
    "vastarem": "vastar",
    "vastaremos": "vastar",
    "vastares": "vastar",
    "vastaria": "vastar",
    "vastariam": "vastar",
    "vastarias": "vastar",
    "vastarmo": "vastar",
    "vastarmos": "vastar",
    "vastará": "vastar",
    "vastarás": "vastar",
    "vastarão": "vastar",
    "vastaríamos": "vastar",
    "vastaríeis": "vastar",
    "vastas": "vasto",
    "vastasse": "vastar",
    "vastassem": "vastar",
    "vastasses": "vastar",
    "vastaste": "vastar",
    "vastastes": "vastar",
    "vastava": "vastar",
    "vastavam": "vastar",
    "vastavas": "vastar",
    "vastações": "vastação",
    "vaste": "vastar",
    "vastei": "vastar",
    "vasteis": "vastar",
    "vastem": "vastar",
    "vastemo": "vastar",
    "vastemos": "vastar",
    "vastes": "vastar",
    "vastezas": "vasteza",
    "vastidões": "vastidão",
    "vasto": "vastar",
    "vastos": "vasto",
    "vastou": "vastar",
    "vastuosa": "vastuoso",
    "vastuosas": "vastuoso",
    "vastuosos": "vastuoso",
    "vastá": "vastar",
    "vastámo": "vastar",
    "vastámos": "vastar",
    "vastáramo": "vastar",
    "vastáramos": "vastar",
    "vastárei": "vastar",
    "vastáreis": "vastar",
    "vastásseis": "vastar",
    "vastássemos": "vastar",
    "vastávamo": "vastar",
    "vastávamos": "vastar",
    "vastávei": "vastar",
    "vastáveis": "vastar",
    "vastíssima": "vasto",
    "vastíssimas": "vasto",
    "vastíssimo": "vasto",
    "vastíssimos": "vasto",
    "vasícolas": "vasícola",
    "vatapás": "vatapá",
    "vateis": "vatel",
    "vates": "vate",
    "vaticana": "vaticano",
    "vaticanas": "vaticano",
    "vaticanismos": "vaticanismo",
    "vaticanistas": "vaticanista",
    "vaticanos": "vaticano",
    "vaticina": "vaticinar",
    "vaticinada": "vaticinar",
    "vaticinadas": "vaticinar",
    "vaticinado": "vaticinar",
    "vaticinadora": "vaticinador",
    "vaticinadoras": "vaticinador",
    "vaticinadores": "vaticinador",
    "vaticinados": "vaticinar",
    "vaticinai": "vaticinar",
    "vaticinais": "vaticinar",
    "vaticinam": "vaticinar",
    "vaticinamo": "vaticinar",
    "vaticinamos": "vaticinar",
    "vaticinando": "vaticinar",
    "vaticinantes": "vaticinante",
    "vaticinara": "vaticinar",
    "vaticinaram": "vaticinar",
    "vaticinaras": "vaticinar",
    "vaticinarde": "vaticinar",
    "vaticinardes": "vaticinar",
    "vaticinare": "vaticinar",
    "vaticinarei": "vaticinar",
    "vaticinareis": "vaticinar",
    "vaticinarem": "vaticinar",
    "vaticinaremos": "vaticinar",
    "vaticinares": "vaticinar",
    "vaticinaria": "vaticinar",
    "vaticinariam": "vaticinar",
    "vaticinarias": "vaticinar",
    "vaticinarmo": "vaticinar",
    "vaticinarmos": "vaticinar",
    "vaticinará": "vaticinar",
    "vaticinarás": "vaticinar",
    "vaticinarão": "vaticinar",
    "vaticinaríamos": "vaticinar",
    "vaticinaríeis": "vaticinar",
    "vaticinas": "vaticinar",
    "vaticinasse": "vaticinar",
    "vaticinassem": "vaticinar",
    "vaticinasses": "vaticinar",
    "vaticinaste": "vaticinar",
    "vaticinastes": "vaticinar",
    "vaticinava": "vaticinar",
    "vaticinavam": "vaticinar",
    "vaticinavas": "vaticinar",
    "vaticinações": "vaticinação",
    "vaticine": "vaticinar",
    "vaticinei": "vaticinar",
    "vaticineis": "vaticinar",
    "vaticinem": "vaticinar",
    "vaticinemo": "vaticinar",
    "vaticinemos": "vaticinar",
    "vaticines": "vaticinar",
    "vaticino": "vaticinar",
    "vaticinou": "vaticinar",
    "vaticiná": "vaticinar",
    "vaticinámo": "vaticinar",
    "vaticinámos": "vaticinar",
    "vaticináramo": "vaticinar",
    "vaticináramos": "vaticinar",
    "vaticinárei": "vaticinar",
    "vaticináreis": "vaticinar",
    "vaticinásseis": "vaticinar",
    "vaticinássemos": "vaticinar",
    "vaticinávamo": "vaticinar",
    "vaticinávamos": "vaticinar",
    "vaticinávei": "vaticinar",
    "vaticináveis": "vaticinar",
    "vaticínios": "vaticínio",
    "vatricosa": "vatricoso",
    "vatricosas": "vatricoso",
    "vatricosos": "vatricoso",
    "vatídica": "vatídico",
    "vatídicas": "vatídico",
    "vatídicos": "vatídico",
    "vatímetros": "vatímetro",
    "vaus": "vau",
    "vavavás": "vavavá",
    "vaza": "vazar",
    "vazada": "vazar",
    "vazadas": "vazar",
    "vazado": "vazar",
    "vazadoiros": "vazadoiro",
    "vazadora": "vazador",
    "vazadoras": "vazador",
    "vazadores": "vazador",
    "vazados": "vazar",
    "vazadouros": "vazadouro",
    "vazaduras": "vazadura",
    "vazai": "vazar",
    "vazais": "vazar",
    "vazam": "vazar",
    "vazamentos": "vazamento",
    "vazamo": "vazar",
    "vazamos": "vazar",
    "vazando": "vazar",
    "vazantes": "vazante",
    "vazara": "vazar",
    "vazaram": "vazar",
    "vazaras": "vazar",
    "vazarde": "vazar",
    "vazardes": "vazar",
    "vazare": "vazar",
    "vazarei": "vazar",
    "vazareis": "vazar",
    "vazarem": "vazar",
    "vazaremos": "vazar",
    "vazares": "vazar",
    "vazaria": "vazar",
    "vazariam": "vazar",
    "vazarias": "vazar",
    "vazarmo": "vazar",
    "vazarmos": "vazar",
    "vazará": "vazar",
    "vazarás": "vazar",
    "vazarão": "vazar",
    "vazaríamos": "vazar",
    "vazaríeis": "vazar",
    "vazas": "vazar",
    "vazasse": "vazar",
    "vazassem": "vazar",
    "vazasses": "vazar",
    "vazaste": "vazar",
    "vazastes": "vazar",
    "vazava": "vazar",
    "vazavam": "vazar",
    "vazavas": "vazar",
    "vaze": "vazar",
    "vazei": "vazar",
    "vazeis": "vazar",
    "vazem": "vazar",
    "vazemo": "vazar",
    "vazemos": "vazar",
    "vazes": "vazar",
    "vazia": "vazio",
    "vaziada": "vaziar",
    "vaziadas": "vaziar",
    "vaziado": "vaziar",
    "vaziadora": "vaziador",
    "vaziadoras": "vaziador",
    "vaziadores": "vaziador",
    "vaziados": "vaziar",
    "vaziai": "vaziar",
    "vaziais": "vaziar",
    "vaziam": "vaziar",
    "vaziamo": "vaziar",
    "vaziamos": "vaziar",
    "vaziando": "vaziar",
    "vaziara": "vaziar",
    "vaziaram": "vaziar",
    "vaziaras": "vaziar",
    "vaziarde": "vaziar",
    "vaziardes": "vaziar",
    "vaziare": "vaziar",
    "vaziarei": "vaziar",
    "vaziareis": "vaziar",
    "vaziarem": "vaziar",
    "vaziaremos": "vaziar",
    "vaziares": "vaziar",
    "vaziaria": "vaziar",
    "vaziariam": "vaziar",
    "vaziarias": "vaziar",
    "vaziarmo": "vaziar",
    "vaziarmos": "vaziar",
    "vaziará": "vaziar",
    "vaziarás": "vaziar",
    "vaziarão": "vaziar",
    "vaziaríamos": "vaziar",
    "vaziaríeis": "vaziar",
    "vazias": "vazio",
    "vaziasse": "vaziar",
    "vaziassem": "vaziar",
    "vaziasses": "vaziar",
    "vaziaste": "vaziar",
    "vaziastes": "vaziar",
    "vaziava": "vaziar",
    "vaziavam": "vaziar",
    "vaziavas": "vaziar",
    "vazie": "vaziar",
    "vaziei": "vaziar",
    "vazieis": "vaziar",
    "vaziem": "vaziar",
    "vaziemo": "vaziar",
    "vaziemos": "vaziar",
    "vazies": "vaziar",
    "vazio": "vaziar",
    "vazios": "vazio",
    "vaziou": "vaziar",
    "vaziá": "vaziar",
    "vaziámo": "vaziar",
    "vaziámos": "vaziar",
    "vaziáramo": "vaziar",
    "vaziáramos": "vaziar",
    "vaziárei": "vaziar",
    "vaziáreis": "vaziar",
    "vaziásseis": "vaziar",
    "vaziássemos": "vaziar",
    "vaziávamo": "vaziar",
    "vaziávamos": "vaziar",
    "vaziávei": "vaziar",
    "vaziáveis": "vaziar",
    "vaziíssima": "vazio",
    "vaziíssimas": "vazio",
    "vaziíssimo": "vazio",
    "vaziíssimos": "vazio",
    "vazo": "vazar",
    "vazou": "vazar",
    "vazá": "vazar",
    "vazámo": "vazar",
    "vazámos": "vazar",
    "vazáramo": "vazar",
    "vazáramos": "vazar",
    "vazárei": "vazar",
    "vazáreis": "vazar",
    "vazásseis": "vazar",
    "vazássemos": "vazar",
    "vazávamo": "vazar",
    "vazávamos": "vazar",
    "vazávei": "vazar",
    "vazáveis": "vazar",
    "vazões": "vazão",
    "veada": "veado",
    "veadas": "veado",
    "veadeiros": "veadeiro",
    "veadora": "veador",
    "veadoras": "veador",
    "veadores": "veador",
    "veados": "veado",
    "vearias": "vearia",
    "veações": "veação",
    "vecedominos": "vecedomino",
    "vectações": "vectação",
    "vectores": "vector",
    "vectoriais": "vectorial",
    "vectoriza": "vectorizar",
    "vectorizada": "vectorizar",
    "vectorizadas": "vectorizar",
    "vectorizado": "vectorizar",
    "vectorizados": "vectorizar",
    "vectorizai": "vectorizar",
    "vectorizais": "vectorizar",
    "vectorizam": "vectorizar",
    "vectorizamo": "vectorizar",
    "vectorizamos": "vectorizar",
    "vectorizando": "vectorizar",
    "vectorizara": "vectorizar",
    "vectorizaram": "vectorizar",
    "vectorizaras": "vectorizar",
    "vectorizarde": "vectorizar",
    "vectorizardes": "vectorizar",
    "vectorizare": "vectorizar",
    "vectorizarei": "vectorizar",
    "vectorizareis": "vectorizar",
    "vectorizarem": "vectorizar",
    "vectorizaremos": "vectorizar",
    "vectorizares": "vectorizar",
    "vectorizaria": "vectorizar",
    "vectorizariam": "vectorizar",
    "vectorizarias": "vectorizar",
    "vectorizarmo": "vectorizar",
    "vectorizarmos": "vectorizar",
    "vectorizará": "vectorizar",
    "vectorizarás": "vectorizar",
    "vectorizarão": "vectorizar",
    "vectorizaríamos": "vectorizar",
    "vectorizaríeis": "vectorizar",
    "vectorizas": "vectorizar",
    "vectorizasse": "vectorizar",
    "vectorizassem": "vectorizar",
    "vectorizasses": "vectorizar",
    "vectorizaste": "vectorizar",
    "vectorizastes": "vectorizar",
    "vectorizava": "vectorizar",
    "vectorizavam": "vectorizar",
    "vectorizavas": "vectorizar",
    "vectorize": "vectorizar",
    "vectorizei": "vectorizar",
    "vectorizeis": "vectorizar",
    "vectorizem": "vectorizar",
    "vectorizemo": "vectorizar",
    "vectorizemos": "vectorizar",
    "vectorizes": "vectorizar",
    "vectorizo": "vectorizar",
    "vectorizou": "vectorizar",
    "vectorizá": "vectorizar",
    "vectorizámo": "vectorizar",
    "vectorizámos": "vectorizar",
    "vectorizáramo": "vectorizar",
    "vectorizáramos": "vectorizar",
    "vectorizárei": "vectorizar",
    "vectorizáreis": "vectorizar",
    "vectorizásseis": "vectorizar",
    "vectorizássemos": "vectorizar",
    "vectorizávamo": "vectorizar",
    "vectorizávamos": "vectorizar",
    "vectorizávei": "vectorizar",
    "vectorizáveis": "vectorizar",
    "vecturiona": "vecturião",
    "vecturionas": "vecturião",
    "vecturiões": "vecturião",
    "veda": "vedar",
    "vedada": "vedar",
    "vedadas": "vedar",
    "vedado": "vedar",
    "vedadora": "vedador",
    "vedadoras": "vedador",
    "vedadores": "vedador",
    "vedados": "vedar",
    "vedadíssima": "vedado",
    "vedadíssimas": "vedado",
    "vedadíssimo": "vedado",
    "vedadíssimos": "vedado",
    "vedai": "vedar",
    "vedais": "vedar",
    "vedam": "vedar",
    "vedamo": "vedar",
    "vedamos": "vedar",
    "vedando": "vedar",
    "vedara": "vedar",
    "vedaram": "vedar",
    "vedaras": "vedar",
    "vedarde": "vedar",
    "vedardes": "vedar",
    "vedare": "vedar",
    "vedarei": "vedar",
    "vedareis": "vedar",
    "vedarem": "vedar",
    "vedaremos": "vedar",
    "vedares": "vedar",
    "vedaria": "vedar",
    "vedariam": "vedar",
    "vedarias": "vedar",
    "vedarmo": "vedar",
    "vedarmos": "vedar",
    "vedará": "vedar",
    "vedarás": "vedar",
    "vedarão": "vedar",
    "vedaríamos": "vedar",
    "vedaríeis": "vedar",
    "vedas": "vedar",
    "vedasse": "vedar",
    "vedassem": "vedar",
    "vedasses": "vedar",
    "vedaste": "vedar",
    "vedastes": "vedar",
    "vedava": "vedar",
    "vedavam": "vedar",
    "vedavas": "vedar",
    "vedações": "vedação",
    "vede": "ver",
    "vedei": "vedar",
    "vedeis": "vedar",
    "vedem": "vedar",
    "vedemo": "vedar",
    "vedemos": "vedar",
    "vedes": "ver",
    "vedetas": "vedeta",
    "vedetismos": "vedetismo",
    "vedo": "vedar",
    "vedora": "vedor",
    "vedoras": "vedor",
    "vedores": "vedor",
    "vedorias": "vedoria",
    "vedos": "vedo",
    "vedou": "vedar",
    "vedra": "vedro",
    "vedras": "vedro",
    "vedros": "vedro",
    "vedá": "vedar",
    "vedálias": "vedália",
    "vedámo": "vedar",
    "vedámos": "vedar",
    "vedáramo": "vedar",
    "vedáramos": "vedar",
    "vedárei": "vedar",
    "vedáreis": "vedar",
    "vedásseis": "vedar",
    "vedássemos": "vedar",
    "vedávamo": "vedar",
    "vedávamos": "vedar",
    "vedávei": "vedar",
    "vedáveis": "vedável",
    "veeiras": "veeira",
    "veeiros": "veeiro",
    "veementes": "veemente",
    "veementiza": "veementizar",
    "veementizada": "veementizar",
    "veementizadas": "veementizar",
    "veementizado": "veementizar",
    "veementizados": "veementizar",
    "veementizai": "veementizar",
    "veementizais": "veementizar",
    "veementizam": "veementizar",
    "veementizamo": "veementizar",
    "veementizamos": "veementizar",
    "veementizando": "veementizar",
    "veementizara": "veementizar",
    "veementizaram": "veementizar",
    "veementizaras": "veementizar",
    "veementizarde": "veementizar",
    "veementizardes": "veementizar",
    "veementizare": "veementizar",
    "veementizarei": "veementizar",
    "veementizareis": "veementizar",
    "veementizarem": "veementizar",
    "veementizaremos": "veementizar",
    "veementizares": "veementizar",
    "veementizaria": "veementizar",
    "veementizariam": "veementizar",
    "veementizarias": "veementizar",
    "veementizarmo": "veementizar",
    "veementizarmos": "veementizar",
    "veementizará": "veementizar",
    "veementizarás": "veementizar",
    "veementizarão": "veementizar",
    "veementizaríamos": "veementizar",
    "veementizaríeis": "veementizar",
    "veementizas": "veementizar",
    "veementizasse": "veementizar",
    "veementizassem": "veementizar",
    "veementizasses": "veementizar",
    "veementizaste": "veementizar",
    "veementizastes": "veementizar",
    "veementizava": "veementizar",
    "veementizavam": "veementizar",
    "veementizavas": "veementizar",
    "veementize": "veementizar",
    "veementizei": "veementizar",
    "veementizeis": "veementizar",
    "veementizem": "veementizar",
    "veementizemo": "veementizar",
    "veementizemos": "veementizar",
    "veementizes": "veementizar",
    "veementizo": "veementizar",
    "veementizou": "veementizar",
    "veementizá": "veementizar",
    "veementizámo": "veementizar",
    "veementizámos": "veementizar",
    "veementizáramo": "veementizar",
    "veementizáramos": "veementizar",
    "veementizárei": "veementizar",
    "veementizáreis": "veementizar",
    "veementizásseis": "veementizar",
    "veementizássemos": "veementizar",
    "veementizávamo": "veementizar",
    "veementizávamos": "veementizar",
    "veementizávei": "veementizar",
    "veementizáveis": "veementizar",
    "veemências": "veemência",
    "vegeta": "vegetar",
    "vegetabilidades": "vegetabilidade",
    "vegetabilismos": "vegetabilismo",
    "vegetada": "vegetar",
    "vegetadas": "vegetar",
    "vegetado": "vegetar",
    "vegetados": "vegetar",
    "vegetai": "vegetar",
    "vegetais": "vegetar",
    "vegetaliana": "vegetaliano",
    "vegetalianas": "vegetaliano",
    "vegetalianos": "vegetaliano",
    "vegetalidades": "vegetalidade",
    "vegetalina": "vegetalino",
    "vegetalinas": "vegetalino",
    "vegetalinos": "vegetalino",
    "vegetalismos": "vegetalismo",
    "vegetalistas": "vegetalista",
    "vegetaliza": "vegetalizar",
    "vegetalizada": "vegetalizar",
    "vegetalizadas": "vegetalizar",
    "vegetalizado": "vegetalizar",
    "vegetalizados": "vegetalizar",
    "vegetalizai": "vegetalizar",
    "vegetalizais": "vegetalizar",
    "vegetalizam": "vegetalizar",
    "vegetalizamo": "vegetalizar",
    "vegetalizamos": "vegetalizar",
    "vegetalizando": "vegetalizar",
    "vegetalizara": "vegetalizar",
    "vegetalizaram": "vegetalizar",
    "vegetalizaras": "vegetalizar",
    "vegetalizarde": "vegetalizar",
    "vegetalizardes": "vegetalizar",
    "vegetalizare": "vegetalizar",
    "vegetalizarei": "vegetalizar",
    "vegetalizareis": "vegetalizar",
    "vegetalizarem": "vegetalizar",
    "vegetalizaremos": "vegetalizar",
    "vegetalizares": "vegetalizar",
    "vegetalizaria": "vegetalizar",
    "vegetalizariam": "vegetalizar",
    "vegetalizarias": "vegetalizar",
    "vegetalizarmo": "vegetalizar",
    "vegetalizarmos": "vegetalizar",
    "vegetalizará": "vegetalizar",
    "vegetalizarás": "vegetalizar",
    "vegetalizarão": "vegetalizar",
    "vegetalizaríamos": "vegetalizar",
    "vegetalizaríeis": "vegetalizar",
    "vegetalizas": "vegetalizar",
    "vegetalizasse": "vegetalizar",
    "vegetalizassem": "vegetalizar",
    "vegetalizasses": "vegetalizar",
    "vegetalizaste": "vegetalizar",
    "vegetalizastes": "vegetalizar",
    "vegetalizava": "vegetalizar",
    "vegetalizavam": "vegetalizar",
    "vegetalizavas": "vegetalizar",
    "vegetalize": "vegetalizar",
    "vegetalizei": "vegetalizar",
    "vegetalizeis": "vegetalizar",
    "vegetalizem": "vegetalizar",
    "vegetalizemo": "vegetalizar",
    "vegetalizemos": "vegetalizar",
    "vegetalizes": "vegetalizar",
    "vegetalizo": "vegetalizar",
    "vegetalizou": "vegetalizar",
    "vegetalizá": "vegetalizar",
    "vegetalizámo": "vegetalizar",
    "vegetalizámos": "vegetalizar",
    "vegetalizáramo": "vegetalizar",
    "vegetalizáramos": "vegetalizar",
    "vegetalizárei": "vegetalizar",
    "vegetalizáreis": "vegetalizar",
    "vegetalizásseis": "vegetalizar",
    "vegetalizássemos": "vegetalizar",
    "vegetalizávamo": "vegetalizar",
    "vegetalizávamos": "vegetalizar",
    "vegetalizávei": "vegetalizar",
    "vegetalizáveis": "vegetalizar",
    "vegetam": "vegetar",
    "vegetamo": "vegetar",
    "vegetamos": "vegetar",
    "vegetando": "vegetar",
    "vegetantes": "vegetante",
    "vegetara": "vegetar",
    "vegetaram": "vegetar",
    "vegetaras": "vegetar",
    "vegetardes": "vegetar",
    "vegetarei": "vegetar",
    "vegetareis": "vegetar",
    "vegetarem": "vegetar",
    "vegetaremos": "vegetar",
    "vegetares": "vegetar",
    "vegetaria": "vegetar",
    "vegetariam": "vegetar",
    "vegetariana": "vegetariano",
    "vegetarianas": "vegetariano",
    "vegetarianos": "vegetariano",
    "vegetarias": "vegetar",
    "vegetarismos": "vegetarismo",
    "vegetaristas": "vegetarista",
    "vegetarmo": "vegetar",
    "vegetarmos": "vegetar",
    "vegetará": "vegetar",
    "vegetarás": "vegetar",
    "vegetarão": "vegetar",
    "vegetaríamos": "vegetar",
    "vegetaríeis": "vegetar",
    "vegetas": "vegetar",
    "vegetasse": "vegetar",
    "vegetassem": "vegetar",
    "vegetasses": "vegetar",
    "vegetaste": "vegetar",
    "vegetastes": "vegetar",
    "vegetativa": "vegetativo",
    "vegetativas": "vegetativo",
    "vegetativos": "vegetativo",
    "vegetava": "vegetar",
    "vegetavam": "vegetar",
    "vegetavas": "vegetar",
    "vegetações": "vegetação",
    "vegete": "vegetar",
    "vegetei": "vegetar",
    "vegeteis": "vegetar",
    "vegetem": "vegetar",
    "vegetemo": "vegetar",
    "vegetemos": "vegetar",
    "vegetes": "vegetar",
    "vegeto": "vegetar",
    "vegetou": "vegetar",
    "vegetálculos": "vegetálculo",
    "vegetámo": "vegetar",
    "vegetámos": "vegetar",
    "vegetáramo": "vegetar",
    "vegetáramos": "vegetar",
    "vegetáreis": "vegetar",
    "vegetásseis": "vegetar",
    "vegetássemos": "vegetar",
    "vegetávamo": "vegetar",
    "vegetávamos": "vegetar",
    "vegetáveis": "vegetável",
    "veias": "veia",
    "veicula": "veicular",
    "veiculada": "veicular",
    "veiculadas": "veicular",
    "veiculado": "veicular",
    "veiculados": "veicular",
    "veiculai": "veicular",
    "veiculais": "veicular",
    "veiculam": "veicular",
    "veiculamo": "veicular",
    "veiculamos": "veicular",
    "veiculando": "veicular",
    "veiculara": "veicular",
    "veicularam": "veicular",
    "veicularas": "veicular",
    "veicularde": "veicular",
    "veiculardes": "veicular",
    "veiculare": "veicular",
    "veicularei": "veicular",
    "veiculareis": "veicular",
    "veicularem": "veicular",
    "veicularemos": "veicular",
    "veiculares": "veicular",
    "veicularia": "veicular",
    "veiculariam": "veicular",
    "veicularias": "veicular",
    "veicularmo": "veicular",
    "veicularmos": "veicular",
    "veiculará": "veicular",
    "veicularás": "veicular",
    "veicularão": "veicular",
    "veicularíamos": "veicular",
    "veicularíeis": "veicular",
    "veiculas": "veicular",
    "veiculasse": "veicular",
    "veiculassem": "veicular",
    "veiculasses": "veicular",
    "veiculaste": "veicular",
    "veiculastes": "veicular",
    "veiculava": "veicular",
    "veiculavam": "veicular",
    "veiculavas": "veicular",
    "veiculações": "veiculação",
    "veicule": "veicular",
    "veiculei": "veicular",
    "veiculeis": "veicular",
    "veiculem": "veicular",
    "veiculemo": "veicular",
    "veiculemos": "veicular",
    "veicules": "veicular",
    "veiculo": "veicular",
    "veiculou": "veicular",
    "veiculá": "veicular",
    "veiculámo": "veicular",
    "veiculámos": "veicular",
    "veiculáramo": "veicular",
    "veiculáramos": "veicular",
    "veiculárei": "veicular",
    "veiculáreis": "veicular",
    "veiculásseis": "veicular",
    "veiculássemos": "veicular",
    "veiculávamo": "veicular",
    "veiculávamos": "veicular",
    "veiculávei": "veicular",
    "veiculáveis": "veicular",
    "veigas": "veiga",
    "veio": "vir",
    "veios": "veio",
    "veirada": "veirado",
    "veiradas": "veirado",
    "veirados": "veirado",
    "veiros": "veiro",
    "veja": "ver",
    "vejais": "ver",
    "vejam": "ver",
    "vejamo": "ver",
    "vejamos": "ver",
    "vejas": "ver",
    "vejeta": "vejete",
    "vejetas": "vejete",
    "vejetes": "vejete",
    "vejo": "ver",
    "vela": "velar",
    "velachos": "velacho",
    "velada": "velar",
    "veladas": "velar",
    "velado": "velar",
    "veladora": "velador",
    "veladoras": "velador",
    "veladores": "velador",
    "velados": "velar",
    "veladuras": "veladura",
    "veladíssima": "velado",
    "veladíssimas": "velado",
    "veladíssimo": "velado",
    "veladíssimos": "velado",
    "velai": "velar",
    "velais": "velar",
    "velam": "velar",
    "velamentos": "velamento",
    "velames": "velame",
    "velamo": "velar",
    "velamos": "velar",
    "velando": "velar",
    "velanças": "velança",
    "velara": "velar",
    "velaram": "velar",
    "velaras": "velar",
    "velarde": "velar",
    "velardes": "velar",
    "velare": "velar",
    "velarei": "velar",
    "velareis": "velar",
    "velarem": "velar",
    "velaremos": "velar",
    "velares": "velar",
    "velaria": "velar",
    "velariam": "velar",
    "velarias": "velar",
    "velarizações": "velarização",
    "velarmo": "velar",
    "velarmos": "velar",
    "velará": "velar",
    "velarás": "velar",
    "velarão": "velar",
    "velaríamos": "velar",
    "velaríeis": "velar",
    "velas": "velar",
    "velasse": "velar",
    "velassem": "velar",
    "velasses": "velar",
    "velaste": "velar",
    "velastes": "velar",
    "velava": "velar",
    "velavam": "velar",
    "velavas": "velar",
    "velações": "velação",
    "vele": "velar",
    "veleada": "velear",
    "veleadas": "velear",
    "veleado": "velear",
    "veleados": "velear",
    "veleai": "velear",
    "veleais": "velear",
    "veleamo": "velear",
    "veleamos": "velear",
    "veleando": "velear",
    "veleara": "velear",
    "velearam": "velear",
    "velearas": "velear",
    "velearde": "velear",
    "veleardes": "velear",
    "veleare": "velear",
    "velearei": "velear",
    "veleareis": "velear",
    "velearem": "velear",
    "velearemos": "velear",
    "veleares": "velear",
    "velearia": "velear",
    "veleariam": "velear",
    "velearias": "velear",
    "velearmo": "velear",
    "velearmos": "velear",
    "veleará": "velear",
    "velearás": "velear",
    "velearão": "velear",
    "velearíamos": "velear",
    "velearíeis": "velear",
    "veleasse": "velear",
    "veleassem": "velear",
    "veleasses": "velear",
    "veleaste": "velear",
    "veleastes": "velear",
    "veleava": "velear",
    "veleavam": "velear",
    "veleavas": "velear",
    "veleei": "velear",
    "veleeis": "velear",
    "veleemo": "velear",
    "veleemos": "velear",
    "velei": "velar",
    "veleia": "velear",
    "veleiam": "velear",
    "veleias": "velear",
    "veleidades": "veleidade",
    "veleie": "velear",
    "veleiem": "velear",
    "veleies": "velear",
    "veleio": "velear",
    "veleira": "veleiro",
    "veleiras": "veleiro",
    "veleiros": "veleiro",
    "veleis": "velar",
    "veleja": "velejar",
    "velejada": "velejar",
    "velejadas": "velejar",
    "velejado": "velejar",
    "velejadora": "velejador",
    "velejadoras": "velejador",
    "velejadores": "velejador",
    "velejados": "velejar",
    "velejai": "velejar",
    "velejais": "velejar",
    "velejam": "velejar",
    "velejamo": "velejar",
    "velejamos": "velejar",
    "velejando": "velejar",
    "velejara": "velejar",
    "velejaram": "velejar",
    "velejaras": "velejar",
    "velejardes": "velejar",
    "velejarei": "velejar",
    "velejareis": "velejar",
    "velejarem": "velejar",
    "velejaremos": "velejar",
    "velejares": "velejar",
    "velejaria": "velejar",
    "velejariam": "velejar",
    "velejarias": "velejar",
    "velejarmo": "velejar",
    "velejarmos": "velejar",
    "velejará": "velejar",
    "velejarás": "velejar",
    "velejarão": "velejar",
    "velejaríamos": "velejar",
    "velejaríeis": "velejar",
    "velejas": "velejar",
    "velejasse": "velejar",
    "velejassem": "velejar",
    "velejasses": "velejar",
    "velejaste": "velejar",
    "velejastes": "velejar",
    "velejava": "velejar",
    "velejavam": "velejar",
    "velejavas": "velejar",
    "veleje": "velejar",
    "velejei": "velejar",
    "velejeis": "velejar",
    "velejem": "velejar",
    "velejemo": "velejar",
    "velejemos": "velejar",
    "velejes": "velejar",
    "velejo": "velejar",
    "velejou": "velejar",
    "velejámo": "velejar",
    "velejámos": "velejar",
    "velejáramo": "velejar",
    "velejáramos": "velejar",
    "velejáreis": "velejar",
    "velejásseis": "velejar",
    "velejássemos": "velejar",
    "velejávamo": "velejar",
    "velejávamos": "velejar",
    "velejáveis": "velejar",
    "velem": "velar",
    "velemo": "velar",
    "velemos": "velar",
    "velenhos": "velenho",
    "veleou": "velear",
    "veles": "velar",
    "veletas": "veleta",
    "veletinas": "veletina",
    "veleá": "velear",
    "veleámo": "velear",
    "veleámos": "velear",
    "veleáramo": "velear",
    "veleáramos": "velear",
    "veleárei": "velear",
    "veleáreis": "velear",
    "veleásseis": "velear",
    "veleássemos": "velear",
    "veleávamo": "velear",
    "veleávamos": "velear",
    "veleávei": "velear",
    "veleáveis": "velear",
    "velha": "velho",
    "velhaca": "velhaco",
    "velhacadas": "velhacada",
    "velhacagens": "velhacagem",
    "velhacarias": "velhacaria",
    "velhacas": "velhaco",
    "velhacazes": "velhacaz",
    "velhacazinha": "velhaco",
    "velhacazinhas": "velhaco",
    "velhacazita": "velhaco",
    "velhacazitas": "velhaco",
    "velhacos": "velhaco",
    "velhacozinho": "velhaco",
    "velhacozinhos": "velhaco",
    "velhacozito": "velhaco",
    "velhacozitos": "velhaco",
    "velhacória": "velhacório",
    "velhacórias": "velhacório",
    "velhacórios": "velhacório",
    "velhadas": "velhada",
    "velhaqueada": "velhaquear",
    "velhaqueadas": "velhaquear",
    "velhaqueado": "velhaquear",
    "velhaqueados": "velhaquear",
    "velhaqueai": "velhaquear",
    "velhaqueais": "velhaquear",
    "velhaqueamo": "velhaquear",
    "velhaqueamos": "velhaquear",
    "velhaqueando": "velhaquear",
    "velhaqueara": "velhaquear",
    "velhaquearam": "velhaquear",
    "velhaquearas": "velhaquear",
    "velhaqueardes": "velhaquear",
    "velhaquearei": "velhaquear",
    "velhaqueareis": "velhaquear",
    "velhaquearem": "velhaquear",
    "velhaquearemos": "velhaquear",
    "velhaqueares": "velhaquear",
    "velhaquearia": "velhaquear",
    "velhaqueariam": "velhaquear",
    "velhaquearias": "velhaquear",
    "velhaquearmo": "velhaquear",
    "velhaquearmos": "velhaquear",
    "velhaqueará": "velhaquear",
    "velhaquearás": "velhaquear",
    "velhaquearão": "velhaquear",
    "velhaquearíamos": "velhaquear",
    "velhaquearíeis": "velhaquear",
    "velhaqueasse": "velhaquear",
    "velhaqueassem": "velhaquear",
    "velhaqueasses": "velhaquear",
    "velhaqueaste": "velhaquear",
    "velhaqueastes": "velhaquear",
    "velhaqueava": "velhaquear",
    "velhaqueavam": "velhaquear",
    "velhaqueavas": "velhaquear",
    "velhaqueei": "velhaquear",
    "velhaqueeis": "velhaquear",
    "velhaqueemo": "velhaquear",
    "velhaqueemos": "velhaquear",
    "velhaqueia": "velhaquear",
    "velhaqueiam": "velhaquear",
    "velhaqueias": "velhaquear",
    "velhaqueie": "velhaquear",
    "velhaqueiem": "velhaquear",
    "velhaqueies": "velhaquear",
    "velhaqueio": "velhaquear",
    "velhaqueou": "velhaquear",
    "velhaquesca": "velhaquesco",
    "velhaquescas": "velhaquesco",
    "velhaquescos": "velhaquesco",
    "velhaquetes": "velhaquete",
    "velhaqueámo": "velhaquear",
    "velhaqueámos": "velhaquear",
    "velhaqueáramo": "velhaquear",
    "velhaqueáramos": "velhaquear",
    "velhaqueáreis": "velhaquear",
    "velhaqueásseis": "velhaquear",
    "velhaqueássemos": "velhaquear",
    "velhaqueávamo": "velhaquear",
    "velhaqueávamos": "velhaquear",
    "velhaqueáveis": "velhaquear",
    "velhaquinha": "velhaco",
    "velhaquinhas": "velhaco",
    "velhaquinho": "velhaco",
    "velhaquinhos": "velhaco",
    "velhaquita": "velhaco",
    "velhaquitas": "velhaco",
    "velhaquito": "velhaco",
    "velhaquitos": "velhaco",
    "velhaquíssima": "velhaco",
    "velhaquíssimas": "velhaco",
    "velhaquíssimo": "velhaco",
    "velhaquíssimos": "velhaco",
    "velharias": "velharia",
    "velhas": "velho",
    "velhices": "velhice",
    "velhinha": "velho",
    "velhinhas": "velho",
    "velhinho": "velho",
    "velhinhos": "velho",
    "velhita": "velho",
    "velhitas": "velho",
    "velhito": "velho",
    "velhitos": "velho",
    "velhoris": "velhori",
    "velhorra": "velhorro",
    "velhorras": "velhorro",
    "velhorros": "velhorro",
    "velhos": "velho",
    "velhota": "velhote",
    "velhotas": "velhote",
    "velhotes": "velhote",
    "velhusca": "velhusco",
    "velhuscas": "velhusco",
    "velhuscos": "velhusco",
    "velhustra": "velhustro",
    "velhustras": "velhustro",
    "velhustros": "velhustro",
    "velhíssima": "velho",
    "velhíssimas": "velho",
    "velhíssimo": "velho",
    "velhíssimos": "velho",
    "velica": "velicar",
    "velicada": "velicar",
    "velicadas": "velicar",
    "velicado": "velicar",
    "velicados": "velicar",
    "velicai": "velicar",
    "velicais": "velicar",
    "velicam": "velicar",
    "velicamo": "velicar",
    "velicamos": "velicar",
    "velicando": "velicar",
    "velicara": "velicar",
    "velicaram": "velicar",
    "velicaras": "velicar",
    "velicarde": "velicar",
    "velicardes": "velicar",
    "velicare": "velicar",
    "velicarei": "velicar",
    "velicareis": "velicar",
    "velicarem": "velicar",
    "velicaremos": "velicar",
    "velicares": "velicar",
    "velicaria": "velicar",
    "velicariam": "velicar",
    "velicarias": "velicar",
    "velicarmo": "velicar",
    "velicarmos": "velicar",
    "velicará": "velicar",
    "velicarás": "velicar",
    "velicarão": "velicar",
    "velicaríamos": "velicar",
    "velicaríeis": "velicar",
    "velicas": "velicar",
    "velicasse": "velicar",
    "velicassem": "velicar",
    "velicasses": "velicar",
    "velicaste": "velicar",
    "velicastes": "velicar",
    "velicativa": "velicativo",
    "velicativas": "velicativo",
    "velicativos": "velicativo",
    "velicava": "velicar",
    "velicavam": "velicar",
    "velicavas": "velicar",
    "velicações": "velicação",
    "velico": "velicar",
    "velicou": "velicar",
    "velicá": "velicar",
    "velicámo": "velicar",
    "velicámos": "velicar",
    "velicáramo": "velicar",
    "velicáramos": "velicar",
    "velicárei": "velicar",
    "velicáreis": "velicar",
    "velicásseis": "velicar",
    "velicássemos": "velicar",
    "velicávamo": "velicar",
    "velicávamos": "velicar",
    "velicávei": "velicar",
    "velicáveis": "velicar",
    "veliformes": "veliforme",
    "velilhos": "velilho",
    "velinha": "vela",
    "velinhas": "velinha",
    "velinos": "velino",
    "velique": "velicar",
    "veliquei": "velicar",
    "veliqueis": "velicar",
    "veliquem": "velicar",
    "veliquemo": "velicar",
    "veliquemos": "velicar",
    "veliques": "velicar",
    "velita": "vela",
    "velitas": "vela",
    "velo": "velar",
    "velocidades": "velocidade",
    "velocinos": "velocino",
    "velocipedias": "velocipedia",
    "velocipedismos": "velocipedismo",
    "velocipedistas": "velocipedista",
    "velocistas": "velocista",
    "velocímanos": "velocímano",
    "velocímetros": "velocímetro",
    "velocípedes": "velocípede",
    "velocíssima": "veloz",
    "velocíssimas": "veloz",
    "velocíssimo": "veloz",
    "velocíssimos": "veloz",
    "velodilhos": "velodilho",
    "velos": "velo",
    "velosa": "veloso",
    "velosas": "veloso",
    "velosos": "veloso",
    "velou": "velar",
    "velozes": "veloz",
    "veluda": "veludo",
    "veludas": "veludo",
    "veludilhos": "veludilho",
    "veludinha": "veludo",
    "veludinhas": "veludo",
    "veludinho": "veludo",
    "veludinhos": "veludo",
    "veludita": "veludo",
    "veluditas": "veludo",
    "veludito": "veludo",
    "veluditos": "veludo",
    "veludos": "veludo",
    "veludosa": "veludoso",
    "veludosas": "veludoso",
    "veludosos": "veludoso",
    "veludínea": "veludíneo",
    "veludíneas": "veludíneo",
    "veludíneos": "veludíneo",
    "veludíssima": "veludo",
    "veludíssimas": "veludo",
    "veludíssimo": "veludo",
    "veludíssimos": "veludo",
    "velutinas": "velutina",
    "velá": "velar",
    "velámo": "velar",
    "velámos": "velar",
    "veláramo": "velar",
    "veláramos": "velar",
    "velárei": "velar",
    "veláreis": "velar",
    "velários": "velário",
    "velásseis": "velar",
    "velássemos": "velar",
    "velávamo": "velar",
    "velávamos": "velar",
    "velávei": "velar",
    "veláveis": "velar",
    "velâmens": "velâmen",
    "velífera": "velífero",
    "velíferas": "velífero",
    "velíferos": "velífero",
    "velígera": "velígero",
    "velígeras": "velígero",
    "velígeros": "velígero",
    "velívaga": "velívago",
    "velívagas": "velívago",
    "velívagos": "velívago",
    "velívola": "velívolo",
    "velívolas": "velívolo",
    "velívolos": "velívolo",
    "velódromos": "velódromo",
    "velórios": "velório",
    "vem": "vir",
    "vemo": "ver",
    "vemos": "ver",
    "venada": "venado",
    "venadas": "venado",
    "venados": "venado",
    "venais": "venal",
    "venalidades": "venalidade",
    "venaliza": "venalizar",
    "venalizada": "venalizar",
    "venalizadas": "venalizar",
    "venalizado": "venalizar",
    "venalizados": "venalizar",
    "venalizai": "venalizar",
    "venalizais": "venalizar",
    "venalizam": "venalizar",
    "venalizamo": "venalizar",
    "venalizamos": "venalizar",
    "venalizando": "venalizar",
    "venalizara": "venalizar",
    "venalizaram": "venalizar",
    "venalizaras": "venalizar",
    "venalizarde": "venalizar",
    "venalizardes": "venalizar",
    "venalizare": "venalizar",
    "venalizarei": "venalizar",
    "venalizareis": "venalizar",
    "venalizarem": "venalizar",
    "venalizaremos": "venalizar",
    "venalizares": "venalizar",
    "venalizaria": "venalizar",
    "venalizariam": "venalizar",
    "venalizarias": "venalizar",
    "venalizarmo": "venalizar",
    "venalizarmos": "venalizar",
    "venalizará": "venalizar",
    "venalizarás": "venalizar",
    "venalizarão": "venalizar",
    "venalizaríamos": "venalizar",
    "venalizaríeis": "venalizar",
    "venalizas": "venalizar",
    "venalizasse": "venalizar",
    "venalizassem": "venalizar",
    "venalizasses": "venalizar",
    "venalizaste": "venalizar",
    "venalizastes": "venalizar",
    "venalizava": "venalizar",
    "venalizavam": "venalizar",
    "venalizavas": "venalizar",
    "venalize": "venalizar",
    "venalizei": "venalizar",
    "venalizeis": "venalizar",
    "venalizem": "venalizar",
    "venalizemo": "venalizar",
    "venalizemos": "venalizar",
    "venalizes": "venalizar",
    "venalizo": "venalizar",
    "venalizou": "venalizar",
    "venalizá": "venalizar",
    "venalizámo": "venalizar",
    "venalizámos": "venalizar",
    "venalizáramo": "venalizar",
    "venalizáramos": "venalizar",
    "venalizárei": "venalizar",
    "venalizáreis": "venalizar",
    "venalizásseis": "venalizar",
    "venalizássemos": "venalizar",
    "venalizávamo": "venalizar",
    "venalizávamos": "venalizar",
    "venalizávei": "venalizar",
    "venalizáveis": "venalizar",
    "venatória": "venatório",
    "venatórias": "venatório",
    "venatórios": "venatório",
    "venações": "venação",
    "vence": "vencer",
    "vencedora": "vencedor",
    "vencedoras": "vencedor",
    "vencedores": "vencedor",
    "vencei": "vencer",
    "venceis": "vencer",
    "vencelhos": "vencelho",
    "vencem": "vencer",
    "vencemo": "vencer",
    "vencemos": "vencer",
    "vencendo": "vencer",
    "vencera": "vencer",
    "venceram": "vencer",
    "venceras": "vencer",
    "vencerde": "vencer",
    "vencerdes": "vencer",
    "vencere": "vencer",
    "vencerei": "vencer",
    "vencereis": "vencer",
    "vencerem": "vencer",
    "venceremos": "vencer",
    "venceres": "vencer",
    "venceria": "vencer",
    "venceriam": "vencer",
    "vencerias": "vencer",
    "vencermo": "vencer",
    "vencermos": "vencer",
    "vencerá": "vencer",
    "vencerás": "vencer",
    "vencerão": "vencer",
    "venceríamos": "vencer",
    "venceríeis": "vencer",
    "vences": "vencer",
    "vencesse": "vencer",
    "vencessem": "vencer",
    "vencesses": "vencer",
    "venceste": "vencer",
    "vencestes": "vencer",
    "venceu": "vencer",
    "venci": "vencer",
    "vencia": "vencer",
    "venciam": "vencer",
    "vencias": "vencer",
    "vencibilidades": "vencibilidade",
    "vencida": "vencido",
    "vencidas": "vencido",
    "vencido": "vencer",
    "vencidos": "vencido",
    "vencidíssima": "vencido",
    "vencidíssimas": "vencido",
    "vencidíssimo": "vencido",
    "vencidíssimos": "vencido",
    "vencilhos": "vencilho",
    "vencimentos": "vencimento",
    "vencê": "vencer",
    "vencêramo": "vencer",
    "vencêramos": "vencer",
    "vencêrei": "vencer",
    "vencêreis": "vencer",
    "vencêsseis": "vencer",
    "vencêssemos": "vencer",
    "vencíamo": "vencer",
    "vencíamos": "vencer",
    "vencíei": "vencer",
    "vencíeis": "vencer",
    "vencíveis": "vencível",
    "venda": "vender",
    "vendada": "vendar",
    "vendadas": "vendar",
    "vendado": "vendar",
    "vendados": "vendar",
    "vendagens": "vendagem",
    "vendai": "vendar",
    "vendais": "vender",
    "vendam": "vender",
    "vendamo": "vender",
    "vendamos": "vender",
    "vendando": "vendar",
    "vendara": "vendar",
    "vendaram": "vendar",
    "vendaras": "vendar",
    "vendarde": "vendar",
    "vendardes": "vendar",
    "vendare": "vendar",
    "vendarei": "vendar",
    "vendareis": "vendar",
    "vendarem": "vendar",
    "vendaremos": "vendar",
    "vendares": "vendar",
    "vendaria": "vendar",
    "vendariam": "vendar",
    "vendarias": "vendar",
    "vendarmo": "vendar",
    "vendarmos": "vendar",
    "vendará": "vendar",
    "vendarás": "vendar",
    "vendarão": "vendar",
    "vendaríamos": "vendar",
    "vendaríeis": "vendar",
    "vendas": "vender",
    "vendasse": "vendar",
    "vendassem": "vendar",
    "vendasses": "vendar",
    "vendaste": "vendar",
    "vendastes": "vendar",
    "vendava": "vendar",
    "vendavais": "vendaval",
    "vendavam": "vendar",
    "vendavas": "vendar",
    "vende": "vender",
    "vendedeira": "vendedor",
    "vendedeiras": "vendedor",
    "vendedoiros": "vendedoiro",
    "vendedora": "vendedor",
    "vendedoras": "vendedor",
    "vendedorazinha": "vendedor",
    "vendedorazinhas": "vendedor",
    "vendedorazita": "vendedor",
    "vendedorazitas": "vendedor",
    "vendedores": "vendedor",
    "vendedorzinho": "vendedor",
    "vendedorzinhos": "vendedor",
    "vendedorzito": "vendedor",
    "vendedorzitos": "vendedor",
    "vendedoura": "vendedouro",
    "vendedouras": "vendedouro",
    "vendedouros": "vendedouro",
    "vendei": "vender",
    "vendeira": "vendeiro",
    "vendeiras": "vendeiro",
    "vendeiros": "vendeiro",
    "vendeis": "vender",
    "vendem": "vender",
    "vendemo": "vender",
    "vendemos": "vender",
    "vendendo": "vender",
    "vendera": "vender",
    "venderam": "vender",
    "venderas": "vender",
    "venderde": "vender",
    "venderdes": "vender",
    "vendere": "vender",
    "venderei": "vender",
    "vendereis": "vender",
    "venderem": "vender",
    "venderemos": "vender",
    "venderes": "vender",
    "venderia": "vender",
    "venderiam": "vender",
    "venderias": "vender",
    "vendermo": "vender",
    "vendermos": "vender",
    "venderá": "vender",
    "venderás": "vender",
    "venderão": "vender",
    "venderíamos": "vender",
    "venderíeis": "vender",
    "vendes": "vender",
    "vendesse": "vender",
    "vendessem": "vender",
    "vendesses": "vender",
    "vendeste": "vender",
    "vendestes": "vender",
    "vendetas": "vendeta",
    "vendettas": "vendetta",
    "vendeu": "vender",
    "vendi": "vender",
    "vendia": "vender",
    "vendiam": "vender",
    "vendias": "vender",
    "vendida": "vendido",
    "vendidas": "vendido",
    "vendido": "vender",
    "vendidos": "vendido",
    "vendidíssima": "vendido",
    "vendidíssimas": "vendido",
    "vendidíssimo": "vendido",
    "vendidíssimos": "vendido",
    "vendilhões": "vendilhão",
    "vendimentos": "vendimento",
    "vendições": "vendição",
    "vendo": "ver",
    "vendou": "vendar",
    "vendá": "vendar",
    "vendámo": "vendar",
    "vendámos": "vendar",
    "vendáramo": "vendar",
    "vendáramos": "vendar",
    "vendárei": "vendar",
    "vendáreis": "vendar",
    "vendásseis": "vendar",
    "vendássemos": "vendar",
    "vendávamo": "vendar",
    "vendávamos": "vendar",
    "vendávei": "vendar",
    "vendáveis": "vendável",
    "vendê": "vender",
    "vendêramo": "vender",
    "vendêramos": "vender",
    "vendêrei": "vender",
    "vendêreis": "vender",
    "vendêsseis": "vender",
    "vendêssemos": "vender",
    "vendíamo": "vender",
    "vendíamos": "vender",
    "vendíei": "vender",
    "vendíeis": "vender",
    "vendíveis": "vendível",
    "veneficia": "veneficiar",
    "veneficiada": "veneficiar",
    "veneficiadas": "veneficiar",
    "veneficiado": "veneficiar",
    "veneficiados": "veneficiar",
    "veneficiai": "veneficiar",
    "veneficiais": "veneficiar",
    "veneficiam": "veneficiar",
    "veneficiamo": "veneficiar",
    "veneficiamos": "veneficiar",
    "veneficiando": "veneficiar",
    "veneficiara": "veneficiar",
    "veneficiaram": "veneficiar",
    "veneficiaras": "veneficiar",
    "veneficiarde": "veneficiar",
    "veneficiardes": "veneficiar",
    "veneficiare": "veneficiar",
    "veneficiarei": "veneficiar",
    "veneficiareis": "veneficiar",
    "veneficiarem": "veneficiar",
    "veneficiaremos": "veneficiar",
    "veneficiares": "veneficiar",
    "veneficiaria": "veneficiar",
    "veneficiariam": "veneficiar",
    "veneficiarias": "veneficiar",
    "veneficiarmo": "veneficiar",
    "veneficiarmos": "veneficiar",
    "veneficiará": "veneficiar",
    "veneficiarás": "veneficiar",
    "veneficiarão": "veneficiar",
    "veneficiaríamos": "veneficiar",
    "veneficiaríeis": "veneficiar",
    "veneficias": "veneficiar",
    "veneficiasse": "veneficiar",
    "veneficiassem": "veneficiar",
    "veneficiasses": "veneficiar",
    "veneficiaste": "veneficiar",
    "veneficiastes": "veneficiar",
    "veneficiava": "veneficiar",
    "veneficiavam": "veneficiar",
    "veneficiavas": "veneficiar",
    "veneficie": "veneficiar",
    "veneficiei": "veneficiar",
    "veneficieis": "veneficiar",
    "veneficiem": "veneficiar",
    "veneficiemo": "veneficiar",
    "veneficiemos": "veneficiar",
    "veneficies": "veneficiar",
    "veneficio": "veneficiar",
    "veneficiou": "veneficiar",
    "veneficiá": "veneficiar",
    "veneficiámo": "veneficiar",
    "veneficiámos": "veneficiar",
    "veneficiáramo": "veneficiar",
    "veneficiáramos": "veneficiar",
    "veneficiárei": "veneficiar",
    "veneficiáreis": "veneficiar",
    "veneficiásseis": "veneficiar",
    "veneficiássemos": "veneficiar",
    "veneficiávamo": "veneficiar",
    "veneficiávamos": "veneficiar",
    "veneficiávei": "veneficiar",
    "veneficiáveis": "veneficiar",
    "venefícios": "venefício",
    "venenas": "venena",
    "venenos": "veneno",
    "venenosa": "venenoso",
    "venenosas": "venenoso",
    "venenosidades": "venenosidade",
    "venenosos": "venenoso",
    "venenífera": "venenífero",
    "veneníferas": "venenífero",
    "veneníferos": "venenífero",
    "venenípara": "veneníparo",
    "veneníparas": "veneníparo",
    "veneníparos": "veneníparo",
    "venera": "venerar",
    "venerabilidades": "venerabilidade",
    "venerabilíssima": "venerável",
    "venerabilíssimas": "venerável",
    "venerabilíssimo": "venerável",
    "venerabilíssimos": "venerável",
    "venerabunda": "venerabundo",
    "venerabundas": "venerabundo",
    "venerabundos": "venerabundo",
    "venerada": "venerar",
    "veneradas": "venerar",
    "venerado": "venerar",
    "veneradora": "venerador",
    "veneradoras": "venerador",
    "veneradores": "venerador",
    "venerados": "venerar",
    "veneradíssima": "venerado",
    "veneradíssimas": "venerado",
    "veneradíssimo": "venerado",
    "veneradíssimos": "venerado",
    "venerai": "venerar",
    "venerais": "venerar",
    "veneralatos": "veneralato",
    "veneram": "venerar",
    "veneramo": "venerar",
    "veneramos": "venerar",
    "veneranda": "venerando",
    "venerandas": "venerando",
    "venerando": "venerar",
    "venerandos": "venerando",
    "venerandíssima": "venerando",
    "venerandíssimas": "venerando",
    "venerandíssimo": "venerando",
    "venerandíssimos": "venerando",
    "venerara": "venerar",
    "veneraram": "venerar",
    "veneraras": "venerar",
    "venerarde": "venerar",
    "venerardes": "venerar",
    "venerare": "venerar",
    "venerarei": "venerar",
    "venerareis": "venerar",
    "venerarem": "venerar",
    "veneraremos": "venerar",
    "venerares": "venerar",
    "veneraria": "venerar",
    "venerariam": "venerar",
    "venerarias": "venerar",
    "venerarmo": "venerar",
    "venerarmos": "venerar",
    "venerará": "venerar",
    "venerarás": "venerar",
    "venerarão": "venerar",
    "veneraríamos": "venerar",
    "veneraríeis": "venerar",
    "veneras": "venerar",
    "venerasse": "venerar",
    "venerassem": "venerar",
    "venerasses": "venerar",
    "veneraste": "venerar",
    "venerastes": "venerar",
    "venerava": "venerar",
    "veneravam": "venerar",
    "veneravas": "venerar",
    "venerações": "veneração",
    "venere": "venerar",
    "venerei": "venerar",
    "venereis": "venerar",
    "venerem": "venerar",
    "veneremo": "venerar",
    "veneremos": "venerar",
    "venereologias": "venereologia",
    "venereologistas": "venereologista",
    "veneres": "venerar",
    "venero": "venerar",
    "venerou": "venerar",
    "venerá": "venerar",
    "venerámo": "venerar",
    "venerámos": "venerar",
    "veneráramo": "venerar",
    "veneráramos": "venerar",
    "venerárei": "venerar",
    "veneráreis": "venerar",
    "venerásseis": "venerar",
    "venerássemos": "venerar",
    "venerávamo": "venerar",
    "venerávamos": "venerar",
    "venerávei": "venerar",
    "veneráveis": "venerável",
    "venerídeos": "venerídeo",
    "venetas": "veneta",
    "veneziana": "veneziano",
    "venezianas": "veneziano",
    "venezianos": "veneziano",
    "venezuelaa": "venezuelao",
    "venezuelaas": "venezuelao",
    "venezuelana": "venezuelano",
    "venezuelanas": "venezuelano",
    "venezuelanos": "venezuelano",
    "venezuelaos": "venezuelao",
    "venha": "vir",
    "venhais": "vir",
    "venham": "vir",
    "venhamo": "vir",
    "venhamos": "vir",
    "venhas": "vir",
    "venho": "vir",
    "veniaga": "veniagar",
    "veniagada": "veniagar",
    "veniagadas": "veniagar",
    "veniagado": "veniagar",
    "veniagados": "veniagar",
    "veniagai": "veniagar",
    "veniagais": "veniagar",
    "veniagam": "veniagar",
    "veniagamo": "veniagar",
    "veniagamos": "veniagar",
    "veniagando": "veniagar",
    "veniagara": "veniagar",
    "veniagaram": "veniagar",
    "veniagaras": "veniagar",
    "veniagarde": "veniagar",
    "veniagardes": "veniagar",
    "veniagare": "veniagar",
    "veniagarei": "veniagar",
    "veniagareis": "veniagar",
    "veniagarem": "veniagar",
    "veniagaremos": "veniagar",
    "veniagares": "veniagar",
    "veniagaria": "veniagar",
    "veniagariam": "veniagar",
    "veniagarias": "veniagar",
    "veniagarmo": "veniagar",
    "veniagarmos": "veniagar",
    "veniagará": "veniagar",
    "veniagarás": "veniagar",
    "veniagarão": "veniagar",
    "veniagaríamos": "veniagar",
    "veniagaríeis": "veniagar",
    "veniagas": "veniagar",
    "veniagasse": "veniagar",
    "veniagassem": "veniagar",
    "veniagasses": "veniagar",
    "veniagaste": "veniagar",
    "veniagastes": "veniagar",
    "veniagava": "veniagar",
    "veniagavam": "veniagar",
    "veniagavas": "veniagar",
    "veniago": "veniagar",
    "veniagou": "veniagar",
    "veniague": "veniagar",
    "veniaguei": "veniagar",
    "veniagueis": "veniagar",
    "veniaguem": "veniagar",
    "veniaguemo": "veniagar",
    "veniaguemos": "veniagar",
    "veniagues": "veniagar",
    "veniagá": "veniagar",
    "veniagámo": "veniagar",
    "veniagámos": "veniagar",
    "veniagáramo": "veniagar",
    "veniagáramos": "veniagar",
    "veniagárei": "veniagar",
    "veniagáreis": "veniagar",
    "veniagásseis": "veniagar",
    "veniagássemos": "veniagar",
    "veniagávamo": "veniagar",
    "veniagávamos": "veniagar",
    "veniagávei": "veniagar",
    "veniagáveis": "veniagar",
    "veniais": "venial",
    "venialidades": "venialidade",
    "venidas": "venida",
    "venissecções": "venissecção",
    "venosa": "venoso",
    "venosas": "venoso",
    "venosidades": "venosidade",
    "venosos": "venoso",
    "vens": "vir",
    "venta": "ventar",
    "ventada": "ventar",
    "ventadas": "ventar",
    "ventado": "ventar",
    "ventados": "ventar",
    "ventai": "ventar",
    "ventais": "ventar",
    "ventam": "ventar",
    "ventamo": "ventar",
    "ventamos": "ventar",
    "ventanas": "ventana",
    "ventando": "ventar",
    "ventaneada": "ventanear",
    "ventaneadas": "ventanear",
    "ventaneado": "ventanear",
    "ventaneados": "ventanear",
    "ventaneai": "ventanear",
    "ventaneais": "ventanear",
    "ventaneamo": "ventanear",
    "ventaneamos": "ventanear",
    "ventaneando": "ventanear",
    "ventaneara": "ventanear",
    "ventanearam": "ventanear",
    "ventanearas": "ventanear",
    "ventanearde": "ventanear",
    "ventaneardes": "ventanear",
    "ventaneare": "ventanear",
    "ventanearei": "ventanear",
    "ventaneareis": "ventanear",
    "ventanearem": "ventanear",
    "ventanearemos": "ventanear",
    "ventaneares": "ventanear",
    "ventanearia": "ventanear",
    "ventaneariam": "ventanear",
    "ventanearias": "ventanear",
    "ventanearmo": "ventanear",
    "ventanearmos": "ventanear",
    "ventaneará": "ventanear",
    "ventanearás": "ventanear",
    "ventanearão": "ventanear",
    "ventanearíamos": "ventanear",
    "ventanearíeis": "ventanear",
    "ventaneasse": "ventanear",
    "ventaneassem": "ventanear",
    "ventaneasses": "ventanear",
    "ventaneaste": "ventanear",
    "ventaneastes": "ventanear",
    "ventaneava": "ventanear",
    "ventaneavam": "ventanear",
    "ventaneavas": "ventanear",
    "ventaneei": "ventanear",
    "ventaneeis": "ventanear",
    "ventaneemo": "ventanear",
    "ventaneemos": "ventanear",
    "ventaneia": "ventanear",
    "ventaneiam": "ventanear",
    "ventaneias": "ventanear",
    "ventaneie": "ventanear",
    "ventaneiem": "ventanear",
    "ventaneies": "ventanear",
    "ventaneio": "ventanear",
    "ventaneiras": "ventaneira",
    "ventaneja": "ventanejar",
    "ventanejada": "ventanejar",
    "ventanejadas": "ventanejar",
    "ventanejado": "ventanejar",
    "ventanejados": "ventanejar",
    "ventanejai": "ventanejar",
    "ventanejais": "ventanejar",
    "ventanejam": "ventanejar",
    "ventanejamo": "ventanejar",
    "ventanejamos": "ventanejar",
    "ventanejando": "ventanejar",
    "ventanejara": "ventanejar",
    "ventanejaram": "ventanejar",
    "ventanejaras": "ventanejar",
    "ventanejardes": "ventanejar",
    "ventanejarei": "ventanejar",
    "ventanejareis": "ventanejar",
    "ventanejarem": "ventanejar",
    "ventanejaremos": "ventanejar",
    "ventanejares": "ventanejar",
    "ventanejaria": "ventanejar",
    "ventanejariam": "ventanejar",
    "ventanejarias": "ventanejar",
    "ventanejarmo": "ventanejar",
    "ventanejarmos": "ventanejar",
    "ventanejará": "ventanejar",
    "ventanejarás": "ventanejar",
    "ventanejarão": "ventanejar",
    "ventanejaríamos": "ventanejar",
    "ventanejaríeis": "ventanejar",
    "ventanejas": "ventanejar",
    "ventanejasse": "ventanejar",
    "ventanejassem": "ventanejar",
    "ventanejasses": "ventanejar",
    "ventanejaste": "ventanejar",
    "ventanejastes": "ventanejar",
    "ventanejava": "ventanejar",
    "ventanejavam": "ventanejar",
    "ventanejavas": "ventanejar",
    "ventaneje": "ventanejar",
    "ventanejei": "ventanejar",
    "ventanejeis": "ventanejar",
    "ventanejem": "ventanejar",
    "ventanejemo": "ventanejar",
    "ventanejemos": "ventanejar",
    "ventanejes": "ventanejar",
    "ventanejo": "ventanejar",
    "ventanejou": "ventanejar",
    "ventanejámo": "ventanejar",
    "ventanejámos": "ventanejar",
    "ventanejáramo": "ventanejar",
    "ventanejáramos": "ventanejar",
    "ventanejáreis": "ventanejar",
    "ventanejásseis": "ventanejar",
    "ventanejássemos": "ventanejar",
    "ventanejávamo": "ventanejar",
    "ventanejávamos": "ventanejar",
    "ventanejáveis": "ventanejar",
    "ventaneou": "ventanear",
    "ventaneá": "ventanear",
    "ventaneámo": "ventanear",
    "ventaneámos": "ventanear",
    "ventaneáramo": "ventanear",
    "ventaneáramos": "ventanear",
    "ventaneárei": "ventanear",
    "ventaneáreis": "ventanear",
    "ventaneásseis": "ventanear",
    "ventaneássemos": "ventanear",
    "ventaneávamo": "ventanear",
    "ventaneávamos": "ventanear",
    "ventaneávei": "ventanear",
    "ventaneáveis": "ventanear",
    "ventanias": "ventania",
    "ventanilhas": "ventanilha",
    "ventara": "ventar",
    "ventaram": "ventar",
    "ventaras": "ventar",
    "ventardes": "ventar",
    "ventarei": "ventar",
    "ventareis": "ventar",
    "ventarem": "ventar",
    "ventaremos": "ventar",
    "ventares": "ventar",
    "ventaria": "ventar",
    "ventariam": "ventar",
    "ventarias": "ventar",
    "ventarmo": "ventar",
    "ventarmos": "ventar",
    "ventarolas": "ventarola",
    "ventará": "ventar",
    "ventarás": "ventar",
    "ventarão": "ventar",
    "ventaríamos": "ventar",
    "ventaríeis": "ventar",
    "ventas": "ventar",
    "ventasse": "ventar",
    "ventassem": "ventar",
    "ventasses": "ventar",
    "ventaste": "ventar",
    "ventastes": "ventar",
    "ventava": "ventar",
    "ventavam": "ventar",
    "ventavas": "ventar",
    "vente": "ventar",
    "ventei": "ventar",
    "venteis": "ventar",
    "ventem": "ventar",
    "ventemo": "ventar",
    "ventemos": "ventar",
    "ventes": "ventar",
    "ventifacta": "ventifacto",
    "ventifactas": "ventifacto",
    "ventifactos": "ventifacto",
    "ventila": "ventilar",
    "ventilabra": "ventilabro",
    "ventilabras": "ventilabro",
    "ventilabros": "ventilabro",
    "ventilada": "ventilar",
    "ventiladas": "ventilar",
    "ventilado": "ventilar",
    "ventiladora": "ventilador",
    "ventiladoras": "ventilador",
    "ventiladores": "ventilador",
    "ventilados": "ventilar",
    "ventilai": "ventilar",
    "ventilais": "ventilar",
    "ventilam": "ventilar",
    "ventilamo": "ventilar",
    "ventilamos": "ventilar",
    "ventilando": "ventilar",
    "ventilantes": "ventilante",
    "ventilara": "ventilar",
    "ventilaram": "ventilar",
    "ventilaras": "ventilar",
    "ventilarde": "ventilar",
    "ventilardes": "ventilar",
    "ventilare": "ventilar",
    "ventilarei": "ventilar",
    "ventilareis": "ventilar",
    "ventilarem": "ventilar",
    "ventilaremos": "ventilar",
    "ventilares": "ventilar",
    "ventilaria": "ventilar",
    "ventilariam": "ventilar",
    "ventilarias": "ventilar",
    "ventilarmo": "ventilar",
    "ventilarmos": "ventilar",
    "ventilará": "ventilar",
    "ventilarás": "ventilar",
    "ventilarão": "ventilar",
    "ventilaríamos": "ventilar",
    "ventilaríeis": "ventilar",
    "ventilas": "ventilar",
    "ventilasse": "ventilar",
    "ventilassem": "ventilar",
    "ventilasses": "ventilar",
    "ventilaste": "ventilar",
    "ventilastes": "ventilar",
    "ventilativa": "ventilativo",
    "ventilativas": "ventilativo",
    "ventilativos": "ventilativo",
    "ventilava": "ventilar",
    "ventilavam": "ventilar",
    "ventilavas": "ventilar",
    "ventilações": "ventilação",
    "ventile": "ventilar",
    "ventilei": "ventilar",
    "ventileis": "ventilar",
    "ventilem": "ventilar",
    "ventilemo": "ventilar",
    "ventilemos": "ventilar",
    "ventiles": "ventilar",
    "ventilo": "ventilar",
    "ventilou": "ventilar",
    "ventilá": "ventilar",
    "ventilámo": "ventilar",
    "ventilámos": "ventilar",
    "ventiláramo": "ventilar",
    "ventiláramos": "ventilar",
    "ventilárei": "ventilar",
    "ventiláreis": "ventilar",
    "ventilásseis": "ventilar",
    "ventilássemos": "ventilar",
    "ventilávamo": "ventilar",
    "ventilávamos": "ventilar",
    "ventilávei": "ventilar",
    "ventiláveis": "ventilar",
    "vento": "ventar",
    "ventoinha": "ventoinhar",
    "ventoinhada": "ventoinhar",
    "ventoinhadas": "ventoinhar",
    "ventoinhado": "ventoinhar",
    "ventoinhados": "ventoinhar",
    "ventoinhai": "ventoinhar",
    "ventoinhais": "ventoinhar",
    "ventoinham": "ventoinhar",
    "ventoinhamo": "ventoinhar",
    "ventoinhamos": "ventoinhar",
    "ventoinhando": "ventoinhar",
    "ventoinhara": "ventoinhar",
    "ventoinharam": "ventoinhar",
    "ventoinharas": "ventoinhar",
    "ventoinhardes": "ventoinhar",
    "ventoinharei": "ventoinhar",
    "ventoinhareis": "ventoinhar",
    "ventoinharem": "ventoinhar",
    "ventoinharemos": "ventoinhar",
    "ventoinhares": "ventoinhar",
    "ventoinharia": "ventoinhar",
    "ventoinhariam": "ventoinhar",
    "ventoinharias": "ventoinhar",
    "ventoinharmo": "ventoinhar",
    "ventoinharmos": "ventoinhar",
    "ventoinhará": "ventoinhar",
    "ventoinharás": "ventoinhar",
    "ventoinharão": "ventoinhar",
    "ventoinharíamos": "ventoinhar",
    "ventoinharíeis": "ventoinhar",
    "ventoinhas": "ventoinhar",
    "ventoinhasse": "ventoinhar",
    "ventoinhassem": "ventoinhar",
    "ventoinhasses": "ventoinhar",
    "ventoinhaste": "ventoinhar",
    "ventoinhastes": "ventoinhar",
    "ventoinhava": "ventoinhar",
    "ventoinhavam": "ventoinhar",
    "ventoinhavas": "ventoinhar",
    "ventoinhe": "ventoinhar",
    "ventoinhei": "ventoinhar",
    "ventoinheis": "ventoinhar",
    "ventoinhem": "ventoinhar",
    "ventoinhemo": "ventoinhar",
    "ventoinhemos": "ventoinhar",
    "ventoinhes": "ventoinhar",
    "ventoinho": "ventoinhar",
    "ventoinhos": "ventoinho",
    "ventoinhou": "ventoinhar",
    "ventoinhámo": "ventoinhar",
    "ventoinhámos": "ventoinhar",
    "ventoinháramo": "ventoinhar",
    "ventoinháramos": "ventoinhar",
    "ventoinháreis": "ventoinhar",
    "ventoinhásseis": "ventoinhar",
    "ventoinhássemos": "ventoinhar",
    "ventoinhávamo": "ventoinhar",
    "ventoinhávamos": "ventoinhar",
    "ventoinháveis": "ventoinhar",
    "ventores": "ventor",
    "ventos": "vento",
    "ventosa": "ventoso",
    "ventosas": "ventoso",
    "ventosidades": "ventosidade",
    "ventosos": "ventoso",
    "ventou": "ventar",
    "ventradas": "ventrada",
    "ventrais": "ventral",
    "ventrechas": "ventrecha",
    "ventres": "ventre",
    "ventrezinho": "ventre",
    "ventrezinhos": "ventre",
    "ventrezito": "ventre",
    "ventrezitos": "ventre",
    "ventriculares": "ventricular",
    "ventriculitos": "ventriculito",
    "ventrilavada": "ventrilavado",
    "ventrilavadas": "ventrilavado",
    "ventrilavados": "ventrilavado",
    "ventriloquias": "ventriloquia",
    "ventriloquismos": "ventriloquismo",
    "ventriloquistas": "ventriloquista",
    "ventripotentes": "ventripotente",
    "ventriscas": "ventrisca",
    "ventruda": "ventrudo",
    "ventrudas": "ventrudo",
    "ventrudos": "ventrudo",
    "ventrusidades": "ventrusidade",
    "ventrículos": "ventrículo",
    "ventríloquos": "ventríloquo",
    "ventura": "venturo",
    "venturas": "venturo",
    "ventures": "venture",
    "venturinas": "venturina",
    "venturos": "venturo",
    "venturosa": "venturoso",
    "venturosas": "venturoso",
    "venturosos": "venturoso",
    "ventusas": "ventusa",
    "ventámo": "ventar",
    "ventámos": "ventar",
    "ventáramo": "ventar",
    "ventáramos": "ventar",
    "ventáreis": "ventar",
    "ventásseis": "ventar",
    "ventássemos": "ventar",
    "ventávamo": "ventar",
    "ventávamos": "ventar",
    "ventáveis": "ventar",
    "ventãs": "ventã",
    "ventígena": "ventígeno",
    "ventígenas": "ventígeno",
    "ventígenos": "ventígeno",
    "venulada": "venulado",
    "venuladas": "venulado",
    "venulados": "venulado",
    "venusiana": "venusiano",
    "venusianas": "venusiano",
    "venusianos": "venusiano",
    "venusina": "venusino",
    "venusinas": "venusino",
    "venusinos": "venusino",
    "venusta": "venusto",
    "venustas": "venusto",
    "venustidades": "venustidade",
    "venustos": "venusto",
    "venábulos": "venábulo",
    "vença": "vencer",
    "vençais": "vencer",
    "vençam": "vencer",
    "vençamo": "vencer",
    "vençamos": "vencer",
    "venças": "vencer",
    "venço": "vencer",
    "venéfica": "venéfico",
    "venéficas": "venéfico",
    "venéficos": "venéfico",
    "venérea": "venéreo",
    "venéreas": "venéreo",
    "venéreos": "venéreo",
    "venéridas": "venérida",
    "veníflua": "venífluo",
    "venífluas": "venífluo",
    "venífluos": "venífluo",
    "venúsios": "venúsio",
    "vera": "vero",
    "veracidades": "veracidade",
    "veracíssima": "veraz",
    "veracíssimas": "veraz",
    "veracíssimo": "veraz",
    "veracíssimos": "veraz",
    "veraneada": "veranear",
    "veraneadas": "veranear",
    "veraneado": "veranear",
    "veraneados": "veranear",
    "veraneai": "veranear",
    "veraneais": "veranear",
    "veraneamo": "veranear",
    "veraneamos": "veranear",
    "veraneando": "veranear",
    "veraneantes": "veraneante",
    "veraneara": "veranear",
    "veranearam": "veranear",
    "veranearas": "veranear",
    "veraneardes": "veranear",
    "veranearei": "veranear",
    "veraneareis": "veranear",
    "veranearem": "veranear",
    "veranearemos": "veranear",
    "veraneares": "veranear",
    "veranearia": "veranear",
    "veraneariam": "veranear",
    "veranearias": "veranear",
    "veranearmo": "veranear",
    "veranearmos": "veranear",
    "veraneará": "veranear",
    "veranearás": "veranear",
    "veranearão": "veranear",
    "veranearíamos": "veranear",
    "veranearíeis": "veranear",
    "veraneasse": "veranear",
    "veraneassem": "veranear",
    "veraneasses": "veranear",
    "veraneaste": "veranear",
    "veraneastes": "veranear",
    "veraneava": "veranear",
    "veraneavam": "veranear",
    "veraneavas": "veranear",
    "veraneei": "veranear",
    "veraneeis": "veranear",
    "veraneemo": "veranear",
    "veraneemos": "veranear",
    "veranega": "veranego",
    "veranegas": "veranego",
    "veranegos": "veranego",
    "veraneia": "veranear",
    "veraneiam": "veranear",
    "veraneias": "veranear",
    "veraneie": "veranear",
    "veraneiem": "veranear",
    "veraneies": "veranear",
    "veraneio": "veranear",
    "veraneios": "veraneio",
    "veraneou": "veranear",
    "veraneámo": "veranear",
    "veraneámos": "veranear",
    "veraneáramo": "veranear",
    "veraneáramos": "veranear",
    "veraneáreis": "veranear",
    "veraneásseis": "veranear",
    "veraneássemos": "veranear",
    "veraneávamo": "veranear",
    "veraneávamos": "veranear",
    "veraneáveis": "veranear",
    "veranicos": "veranico",
    "veranistas": "veranista",
    "veras": "vero",
    "verascópios": "verascópio",
    "veratrinas": "veratrina",
    "veratros": "veratro",
    "veratráceas": "veratrácea",
    "verazes": "veraz",
    "verbais": "verbal",
    "verbalismos": "verbalismo",
    "verbalistas": "verbalista",
    "verbaliza": "verbalizar",
    "verbalizada": "verbalizar",
    "verbalizadas": "verbalizar",
    "verbalizado": "verbalizar",
    "verbalizados": "verbalizar",
    "verbalizai": "verbalizar",
    "verbalizais": "verbalizar",
    "verbalizam": "verbalizar",
    "verbalizamo": "verbalizar",
    "verbalizamos": "verbalizar",
    "verbalizando": "verbalizar",
    "verbalizara": "verbalizar",
    "verbalizaram": "verbalizar",
    "verbalizaras": "verbalizar",
    "verbalizarde": "verbalizar",
    "verbalizardes": "verbalizar",
    "verbalizare": "verbalizar",
    "verbalizarei": "verbalizar",
    "verbalizareis": "verbalizar",
    "verbalizarem": "verbalizar",
    "verbalizaremos": "verbalizar",
    "verbalizares": "verbalizar",
    "verbalizaria": "verbalizar",
    "verbalizariam": "verbalizar",
    "verbalizarias": "verbalizar",
    "verbalizarmo": "verbalizar",
    "verbalizarmos": "verbalizar",
    "verbalizará": "verbalizar",
    "verbalizarás": "verbalizar",
    "verbalizarão": "verbalizar",
    "verbalizaríamos": "verbalizar",
    "verbalizaríeis": "verbalizar",
    "verbalizas": "verbalizar",
    "verbalizasse": "verbalizar",
    "verbalizassem": "verbalizar",
    "verbalizasses": "verbalizar",
    "verbalizaste": "verbalizar",
    "verbalizastes": "verbalizar",
    "verbalizava": "verbalizar",
    "verbalizavam": "verbalizar",
    "verbalizavas": "verbalizar",
    "verbalizações": "verbalização",
    "verbalize": "verbalizar",
    "verbalizei": "verbalizar",
    "verbalizeis": "verbalizar",
    "verbalizem": "verbalizar",
    "verbalizemo": "verbalizar",
    "verbalizemos": "verbalizar",
    "verbalizes": "verbalizar",
    "verbalizo": "verbalizar",
    "verbalizou": "verbalizar",
    "verbalizá": "verbalizar",
    "verbalizámo": "verbalizar",
    "verbalizámos": "verbalizar",
    "verbalizáramo": "verbalizar",
    "verbalizáramos": "verbalizar",
    "verbalizárei": "verbalizar",
    "verbalizáreis": "verbalizar",
    "verbalizásseis": "verbalizar",
    "verbalizássemos": "verbalizar",
    "verbalizávamo": "verbalizar",
    "verbalizávamos": "verbalizar",
    "verbalizávei": "verbalizar",
    "verbalizáveis": "verbalizável",
    "verbalíssima": "verbal",
    "verbalíssimas": "verbal",
    "verbalíssimo": "verbal",
    "verbalíssimos": "verbal",
    "verbas": "verba",
    "verbascos": "verbasco",
    "verbenas": "verbena",
    "verbenácea": "verbenáceo",
    "verbenáceas": "verbenáceo",
    "verbenáceos": "verbenáceo",
    "verbera": "verberar",
    "verberada": "verberar",
    "verberadas": "verberar",
    "verberado": "verberar",
    "verberadora": "verberador",
    "verberadoras": "verberador",
    "verberadores": "verberador",
    "verberados": "verberar",
    "verberai": "verberar",
    "verberais": "verberar",
    "verberam": "verberar",
    "verberamo": "verberar",
    "verberamos": "verberar",
    "verberando": "verberar",
    "verberantes": "verberante",
    "verberara": "verberar",
    "verberaram": "verberar",
    "verberaras": "verberar",
    "verberarde": "verberar",
    "verberardes": "verberar",
    "verberare": "verberar",
    "verberarei": "verberar",
    "verberareis": "verberar",
    "verberarem": "verberar",
    "verberaremos": "verberar",
    "verberares": "verberar",
    "verberaria": "verberar",
    "verberariam": "verberar",
    "verberarias": "verberar",
    "verberarmo": "verberar",
    "verberarmos": "verberar",
    "verberará": "verberar",
    "verberarás": "verberar",
    "verberarão": "verberar",
    "verberaríamos": "verberar",
    "verberaríeis": "verberar",
    "verberas": "verberar",
    "verberasse": "verberar",
    "verberassem": "verberar",
    "verberasses": "verberar",
    "verberaste": "verberar",
    "verberastes": "verberar",
    "verberativa": "verberativo",
    "verberativas": "verberativo",
    "verberativos": "verberativo",
    "verberava": "verberar",
    "verberavam": "verberar",
    "verberavas": "verberar",
    "verberações": "verberação",
    "verbere": "verberar",
    "verberei": "verberar",
    "verbereis": "verberar",
    "verberem": "verberar",
    "verberemo": "verberar",
    "verberemos": "verberar",
    "verberes": "verberar",
    "verbero": "verberar",
    "verberou": "verberar",
    "verberá": "verberar",
    "verberámo": "verberar",
    "verberámos": "verberar",
    "verberáramo": "verberar",
    "verberáramos": "verberar",
    "verberárei": "verberar",
    "verberáreis": "verberar",
    "verberásseis": "verberar",
    "verberássemos": "verberar",
    "verberávamo": "verberar",
    "verberávamos": "verberar",
    "verberávei": "verberar",
    "verberáveis": "verberar",
    "verberões": "verberão",
    "verbeta": "verbetar",
    "verbetada": "verbetar",
    "verbetadas": "verbetar",
    "verbetado": "verbetar",
    "verbetados": "verbetar",
    "verbetai": "verbetar",
    "verbetais": "verbetar",
    "verbetam": "verbetar",
    "verbetamo": "verbetar",
    "verbetamos": "verbetar",
    "verbetando": "verbetar",
    "verbetara": "verbetar",
    "verbetaram": "verbetar",
    "verbetaras": "verbetar",
    "verbetarde": "verbetar",
    "verbetardes": "verbetar",
    "verbetare": "verbetar",
    "verbetarei": "verbetar",
    "verbetareis": "verbetar",
    "verbetarem": "verbetar",
    "verbetaremos": "verbetar",
    "verbetares": "verbetar",
    "verbetaria": "verbetar",
    "verbetariam": "verbetar",
    "verbetarias": "verbetar",
    "verbetarmo": "verbetar",
    "verbetarmos": "verbetar",
    "verbetará": "verbetar",
    "verbetarás": "verbetar",
    "verbetarão": "verbetar",
    "verbetaríamos": "verbetar",
    "verbetaríeis": "verbetar",
    "verbetas": "verbetar",
    "verbetasse": "verbetar",
    "verbetassem": "verbetar",
    "verbetasses": "verbetar",
    "verbetaste": "verbetar",
    "verbetastes": "verbetar",
    "verbetava": "verbetar",
    "verbetavam": "verbetar",
    "verbetavas": "verbetar",
    "verbete": "verbetar",
    "verbetei": "verbetar",
    "verbeteiros": "verbeteiro",
    "verbeteis": "verbetar",
    "verbetem": "verbetar",
    "verbetemo": "verbetar",
    "verbetemos": "verbetar",
    "verbetes": "verbete",
    "verbeto": "verbetar",
    "verbetou": "verbetar",
    "verbetá": "verbetar",
    "verbetámo": "verbetar",
    "verbetámos": "verbetar",
    "verbetáramo": "verbetar",
    "verbetáramos": "verbetar",
    "verbetárei": "verbetar",
    "verbetáreis": "verbetar",
    "verbetásseis": "verbetar",
    "verbetássemos": "verbetar",
    "verbetávamo": "verbetar",
    "verbetávamos": "verbetar",
    "verbetávei": "verbetar",
    "verbetáveis": "verbetar",
    "verbiagens": "verbiagem",
    "verbomanias": "verbomania",
    "verbomaníaca": "verbomaníaco",
    "verbomaníacas": "verbomaníaco",
    "verbomaníacos": "verbomaníaco",
    "verborreias": "verborreia",
    "verborreica": "verborreico",
    "verborreicas": "verborreico",
    "verborreicos": "verborreico",
    "verbos": "verbo",
    "verbosa": "verboso",
    "verbosas": "verboso",
    "verbosidades": "verbosidade",
    "verbosos": "verboso",
    "verbosíssima": "verboso",
    "verbosíssimas": "verboso",
    "verbosíssimo": "verboso",
    "verbosíssimos": "verboso",
    "verbómaca": "verbómaco",
    "verbómacas": "verbómaco",
    "verbómacos": "verbómaco",
    "verdacha": "verdacho",
    "verdachas": "verdacho",
    "verdachos": "verdacho",
    "verdadeira": "verdadeiro",
    "verdadeiras": "verdadeiro",
    "verdadeiros": "verdadeiro",
    "verdades": "verdade",
    "verdadezinha": "verdade",
    "verdadezinhas": "verdade",
    "verdadezita": "verdade",
    "verdadezitas": "verdade",
    "verdasca": "verdasco",
    "verdascada": "verdascar",
    "verdascadas": "verdascar",
    "verdascado": "verdascar",
    "verdascados": "verdascar",
    "verdascai": "verdascar",
    "verdascais": "verdascar",
    "verdascam": "verdascar",
    "verdascamo": "verdascar",
    "verdascamos": "verdascar",
    "verdascando": "verdascar",
    "verdascara": "verdascar",
    "verdascaram": "verdascar",
    "verdascaras": "verdascar",
    "verdascarde": "verdascar",
    "verdascardes": "verdascar",
    "verdascare": "verdascar",
    "verdascarei": "verdascar",
    "verdascareis": "verdascar",
    "verdascarem": "verdascar",
    "verdascaremos": "verdascar",
    "verdascares": "verdascar",
    "verdascaria": "verdascar",
    "verdascariam": "verdascar",
    "verdascarias": "verdascar",
    "verdascarmo": "verdascar",
    "verdascarmos": "verdascar",
    "verdascará": "verdascar",
    "verdascarás": "verdascar",
    "verdascarão": "verdascar",
    "verdascaríamos": "verdascar",
    "verdascaríeis": "verdascar",
    "verdascas": "verdasco",
    "verdascasse": "verdascar",
    "verdascassem": "verdascar",
    "verdascasses": "verdascar",
    "verdascaste": "verdascar",
    "verdascastes": "verdascar",
    "verdascava": "verdascar",
    "verdascavam": "verdascar",
    "verdascavas": "verdascar",
    "verdasco": "verdascar",
    "verdascos": "verdasco",
    "verdascou": "verdascar",
    "verdascá": "verdascar",
    "verdascámo": "verdascar",
    "verdascámos": "verdascar",
    "verdascáramo": "verdascar",
    "verdascáramos": "verdascar",
    "verdascárei": "verdascar",
    "verdascáreis": "verdascar",
    "verdascásseis": "verdascar",
    "verdascássemos": "verdascar",
    "verdascávamo": "verdascar",
    "verdascávamos": "verdascar",
    "verdascávei": "verdascar",
    "verdascáveis": "verdascar",
    "verdasque": "verdascar",
    "verdasquei": "verdascar",
    "verdasqueis": "verdascar",
    "verdasquem": "verdascar",
    "verdasquemo": "verdascar",
    "verdasquemos": "verdascar",
    "verdasques": "verdascar",
    "verdasta": "verdasto",
    "verdastas": "verdasto",
    "verdastos": "verdasto",
    "verde": "ver",
    "verdeada": "verdear",
    "verdeadas": "verdear",
    "verdeado": "verdear",
    "verdeados": "verdear",
    "verdeai": "verdear",
    "verdeais": "verdear",
    "verdeamo": "verdear",
    "verdeamos": "verdear",
    "verdeando": "verdear",
    "verdeara": "verdear",
    "verdearam": "verdear",
    "verdearas": "verdear",
    "verdeardes": "verdear",
    "verdearei": "verdear",
    "verdeareis": "verdear",
    "verdearem": "verdear",
    "verdearemos": "verdear",
    "verdeares": "verdear",
    "verdearia": "verdear",
    "verdeariam": "verdear",
    "verdearias": "verdear",
    "verdearmo": "verdear",
    "verdearmos": "verdear",
    "verdeará": "verdear",
    "verdearás": "verdear",
    "verdearão": "verdear",
    "verdearíamos": "verdear",
    "verdearíeis": "verdear",
    "verdeasse": "verdear",
    "verdeassem": "verdear",
    "verdeasses": "verdear",
    "verdeaste": "verdear",
    "verdeastes": "verdear",
    "verdeava": "verdear",
    "verdeavam": "verdear",
    "verdeavas": "verdear",
    "verdece": "verdecer",
    "verdecei": "verdecer",
    "verdeceis": "verdecer",
    "verdecem": "verdecer",
    "verdecemo": "verdecer",
    "verdecemos": "verdecer",
    "verdecendo": "verdecer",
    "verdecera": "verdecer",
    "verdeceram": "verdecer",
    "verdeceras": "verdecer",
    "verdecerdes": "verdecer",
    "verdecerei": "verdecer",
    "verdecereis": "verdecer",
    "verdecerem": "verdecer",
    "verdeceremos": "verdecer",
    "verdeceres": "verdecer",
    "verdeceria": "verdecer",
    "verdeceriam": "verdecer",
    "verdecerias": "verdecer",
    "verdecermo": "verdecer",
    "verdecermos": "verdecer",
    "verdecerá": "verdecer",
    "verdecerás": "verdecer",
    "verdecerão": "verdecer",
    "verdeceríamos": "verdecer",
    "verdeceríeis": "verdecer",
    "verdeces": "verdecer",
    "verdecesse": "verdecer",
    "verdecessem": "verdecer",
    "verdecesses": "verdecer",
    "verdeceste": "verdecer",
    "verdecestes": "verdecer",
    "verdeceu": "verdecer",
    "verdeci": "verdecer",
    "verdecia": "verdecer",
    "verdeciam": "verdecer",
    "verdecias": "verdecer",
    "verdecida": "verdecer",
    "verdecidas": "verdecer",
    "verdecido": "verdecer",
    "verdecidos": "verdecer",
    "verdecêramo": "verdecer",
    "verdecêramos": "verdecer",
    "verdecêreis": "verdecer",
    "verdecêsseis": "verdecer",
    "verdecêssemos": "verdecer",
    "verdecíamo": "verdecer",
    "verdecíamos": "verdecer",
    "verdecíeis": "verdecer",
    "verdeei": "verdear",
    "verdeeis": "verdear",
    "verdeemo": "verdear",
    "verdeemos": "verdear",
    "verdega": "verdegar",
    "verdegada": "verdegar",
    "verdegadas": "verdegar",
    "verdegado": "verdegar",
    "verdegados": "verdegar",
    "verdegai": "verdegar",
    "verdegais": "verdegar",
    "verdegam": "verdegar",
    "verdegamo": "verdegar",
    "verdegamos": "verdegar",
    "verdegando": "verdegar",
    "verdegara": "verdegar",
    "verdegaram": "verdegar",
    "verdegaras": "verdegar",
    "verdegardes": "verdegar",
    "verdegarei": "verdegar",
    "verdegareis": "verdegar",
    "verdegarem": "verdegar",
    "verdegaremos": "verdegar",
    "verdegares": "verdegar",
    "verdegaria": "verdegar",
    "verdegariam": "verdegar",
    "verdegarias": "verdegar",
    "verdegarmo": "verdegar",
    "verdegarmos": "verdegar",
    "verdegará": "verdegar",
    "verdegarás": "verdegar",
    "verdegarão": "verdegar",
    "verdegaríamos": "verdegar",
    "verdegaríeis": "verdegar",
    "verdegas": "verdegar",
    "verdegasse": "verdegar",
    "verdegassem": "verdegar",
    "verdegasses": "verdegar",
    "verdegaste": "verdegar",
    "verdegastes": "verdegar",
    "verdegava": "verdegar",
    "verdegavam": "verdegar",
    "verdegavas": "verdegar",
    "verdego": "verdegar",
    "verdegou": "verdegar",
    "verdegue": "verdegar",
    "verdeguei": "verdegar",
    "verdegueis": "verdegar",
    "verdeguem": "verdegar",
    "verdeguemo": "verdegar",
    "verdeguemos": "verdegar",
    "verdegues": "verdegar",
    "verdegulhos": "verdegulho",
    "verdegámo": "verdegar",
    "verdegámos": "verdegar",
    "verdegáramo": "verdegar",
    "verdegáramos": "verdegar",
    "verdegáreis": "verdegar",
    "verdegásseis": "verdegar",
    "verdegássemos": "verdegar",
    "verdegávamo": "verdegar",
    "verdegávamos": "verdegar",
    "verdegáveis": "verdegar",
    "verdeia": "verdear",
    "verdeiam": "verdear",
    "verdeias": "verdeia",
    "verdeie": "verdear",
    "verdeiem": "verdear",
    "verdeies": "verdear",
    "verdeio": "verdear",
    "verdeja": "verdejar",
    "verdejada": "verdejar",
    "verdejadas": "verdejar",
    "verdejado": "verdejar",
    "verdejados": "verdejar",
    "verdejai": "verdejar",
    "verdejais": "verdejar",
    "verdejam": "verdejar",
    "verdejamo": "verdejar",
    "verdejamos": "verdejar",
    "verdejando": "verdejar",
    "verdejantes": "verdejante",
    "verdejara": "verdejar",
    "verdejaram": "verdejar",
    "verdejaras": "verdejar",
    "verdejardes": "verdejar",
    "verdejarei": "verdejar",
    "verdejareis": "verdejar",
    "verdejarem": "verdejar",
    "verdejaremos": "verdejar",
    "verdejares": "verdejar",
    "verdejaria": "verdejar",
    "verdejariam": "verdejar",
    "verdejarias": "verdejar",
    "verdejarmo": "verdejar",
    "verdejarmos": "verdejar",
    "verdejará": "verdejar",
    "verdejarás": "verdejar",
    "verdejarão": "verdejar",
    "verdejaríamos": "verdejar",
    "verdejaríeis": "verdejar",
    "verdejas": "verdejar",
    "verdejasse": "verdejar",
    "verdejassem": "verdejar",
    "verdejasses": "verdejar",
    "verdejaste": "verdejar",
    "verdejastes": "verdejar",
    "verdejava": "verdejar",
    "verdejavam": "verdejar",
    "verdejavas": "verdejar",
    "verdeje": "verdejar",
    "verdejei": "verdejar",
    "verdejeis": "verdejar",
    "verdejem": "verdejar",
    "verdejemo": "verdejar",
    "verdejemos": "verdejar",
    "verdejes": "verdejar",
    "verdejo": "verdejar",
    "verdejou": "verdejar",
    "verdejámo": "verdejar",
    "verdejámos": "verdejar",
    "verdejáramo": "verdejar",
    "verdejáramos": "verdejar",
    "verdejáreis": "verdejar",
    "verdejásseis": "verdejar",
    "verdejássemos": "verdejar",
    "verdejávamo": "verdejar",
    "verdejávamos": "verdejar",
    "verdejáveis": "verdejar",
    "verdejâncias": "verdejância",
    "verdelhas": "verdelha",
    "verdelhos": "verdelho",
    "verdelhões": "verdelhão",
    "verdenegra": "verdenegro",
    "verdenegras": "verdenegro",
    "verdenegros": "verdenegro",
    "verdeou": "verdear",
    "verderois": "verderol",
    "verdes": "verde",
    "verdetes": "verdete",
    "verdezelhas": "verdezelha",
    "verdeámo": "verdear",
    "verdeámos": "verdear",
    "verdeáramo": "verdear",
    "verdeáramos": "verdear",
    "verdeáreis": "verdear",
    "verdeásseis": "verdear",
    "verdeássemos": "verdear",
    "verdeávamo": "verdear",
    "verdeávamos": "verdear",
    "verdeáveis": "verdear",
    "verdeça": "verdecer",
    "verdeçais": "verdecer",
    "verdeçam": "verdecer",
    "verdeçamo": "verdecer",
    "verdeçamos": "verdecer",
    "verdeças": "verdecer",
    "verdeço": "verdecer",
    "verdiana": "verdiano",
    "verdianas": "verdiano",
    "verdianos": "verdiano",
    "verdilhotes": "verdilhote",
    "verdilhões": "verdilhão",
    "verdinha": "verde",
    "verdinhas": "verde",
    "verdinho": "verde",
    "verdinhos": "verde",
    "verdinzelas": "verdinzela",
    "verdisseca": "verdisseco",
    "verdissecas": "verdisseco",
    "verdissecos": "verdisseco",
    "verdita": "verde",
    "verditas": "verde",
    "verdito": "verde",
    "verditos": "verde",
    "verdizeis": "verdizel",
    "verdizelas": "verdizela",
    "verdizelos": "verdizelo",
    "verdoegas": "verdoega",
    "verdoenga": "verdoengo",
    "verdoengas": "verdoengo",
    "verdoengos": "verdoengo",
    "verdolenga": "verdolengo",
    "verdolengas": "verdolengo",
    "verdolengos": "verdolengo",
    "verdores": "verdor",
    "verdosa": "verdoso",
    "verdosas": "verdoso",
    "verdosos": "verdoso",
    "verdotes": "verdote",
    "verduga": "verdugo",
    "verdugas": "verdugo",
    "verdugos": "verdugo",
    "verduguilhos": "verduguilho",
    "verdugões": "verdugão",
    "verdumes": "verdume",
    "verduniza": "verdunizar",
    "verdunizada": "verdunizar",
    "verdunizadas": "verdunizar",
    "verdunizado": "verdunizar",
    "verdunizados": "verdunizar",
    "verdunizai": "verdunizar",
    "verdunizais": "verdunizar",
    "verdunizam": "verdunizar",
    "verdunizamo": "verdunizar",
    "verdunizamos": "verdunizar",
    "verdunizando": "verdunizar",
    "verdunizara": "verdunizar",
    "verdunizaram": "verdunizar",
    "verdunizaras": "verdunizar",
    "verdunizarde": "verdunizar",
    "verdunizardes": "verdunizar",
    "verdunizare": "verdunizar",
    "verdunizarei": "verdunizar",
    "verdunizareis": "verdunizar",
    "verdunizarem": "verdunizar",
    "verdunizaremos": "verdunizar",
    "verdunizares": "verdunizar",
    "verdunizaria": "verdunizar",
    "verdunizariam": "verdunizar",
    "verdunizarias": "verdunizar",
    "verdunizarmo": "verdunizar",
    "verdunizarmos": "verdunizar",
    "verdunizará": "verdunizar",
    "verdunizarás": "verdunizar",
    "verdunizarão": "verdunizar",
    "verdunizaríamos": "verdunizar",
    "verdunizaríeis": "verdunizar",
    "verdunizas": "verdunizar",
    "verdunizasse": "verdunizar",
    "verdunizassem": "verdunizar",
    "verdunizasses": "verdunizar",
    "verdunizaste": "verdunizar",
    "verdunizastes": "verdunizar",
    "verdunizava": "verdunizar",
    "verdunizavam": "verdunizar",
    "verdunizavas": "verdunizar",
    "verdunizações": "verdunização",
    "verdunize": "verdunizar",
    "verdunizei": "verdunizar",
    "verdunizeis": "verdunizar",
    "verdunizem": "verdunizar",
    "verdunizemo": "verdunizar",
    "verdunizemos": "verdunizar",
    "verdunizes": "verdunizar",
    "verdunizo": "verdunizar",
    "verdunizou": "verdunizar",
    "verdunizá": "verdunizar",
    "verdunizámo": "verdunizar",
    "verdunizámos": "verdunizar",
    "verdunizáramo": "verdunizar",
    "verdunizáramos": "verdunizar",
    "verdunizárei": "verdunizar",
    "verdunizáreis": "verdunizar",
    "verdunizásseis": "verdunizar",
    "verdunizássemos": "verdunizar",
    "verdunizávamo": "verdunizar",
    "verdunizávamos": "verdunizar",
    "verdunizávei": "verdunizar",
    "verdunizáveis": "verdunizar",
    "verduns": "verdum",
    "verduras": "verdura",
    "verdureira": "verdureiro",
    "verdureiras": "verdureiro",
    "verdureiros": "verdureiro",
    "verdurinha": "verdura",
    "verdurinhas": "verdura",
    "verdurita": "verdura",
    "verduritas": "verdura",
    "verdíssima": "verde",
    "verdíssimas": "verde",
    "verdíssimo": "verde",
    "verdíssimos": "verde",
    "vere": "ver",
    "vereada": "verear",
    "vereadas": "verear",
    "vereado": "verear",
    "vereadora": "vereador",
    "vereadoras": "vereador",
    "vereadores": "vereador",
    "vereados": "verear",
    "vereai": "verear",
    "vereais": "verear",
    "vereamentos": "vereamento",
    "vereamo": "verear",
    "vereamos": "verear",
    "vereando": "verear",
    "vereara": "verear",
    "verearam": "verear",
    "verearas": "verear",
    "vereardes": "verear",
    "verearei": "verear",
    "vereareis": "verear",
    "verearem": "verear",
    "verearemos": "verear",
    "vereares": "verear",
    "verearia": "verear",
    "vereariam": "verear",
    "verearias": "verear",
    "verearmo": "verear",
    "verearmos": "verear",
    "vereará": "verear",
    "verearás": "verear",
    "verearão": "verear",
    "verearíamos": "verear",
    "verearíeis": "verear",
    "vereasse": "verear",
    "vereassem": "verear",
    "vereasses": "verear",
    "vereaste": "verear",
    "vereastes": "verear",
    "vereava": "verear",
    "vereavam": "verear",
    "vereavas": "verear",
    "vereações": "vereação",
    "verecunda": "verecundo",
    "verecundas": "verecundo",
    "verecundos": "verecundo",
    "verecúndias": "verecúndia",
    "veredas": "vereda",
    "veredictos": "veredicto",
    "vereei": "verear",
    "vereeis": "verear",
    "vereemo": "verear",
    "vereemos": "verear",
    "verei": "ver",
    "vereia": "verear",
    "vereiam": "verear",
    "vereias": "verear",
    "vereie": "verear",
    "vereiem": "verear",
    "vereies": "verear",
    "vereio": "verear",
    "vereis": "ver",
    "verem": "ver",
    "veremos": "ver",
    "vereou": "verear",
    "veres": "ver",
    "vereámo": "verear",
    "vereámos": "verear",
    "vereáramo": "verear",
    "vereáramos": "verear",
    "vereáreis": "verear",
    "vereásseis": "verear",
    "vereássemos": "verear",
    "vereávamo": "verear",
    "vereávamos": "verear",
    "vereáveis": "verear",
    "verga": "vergar",
    "vergada": "vergar",
    "vergadas": "vergar",
    "vergadiça": "vergadiço",
    "vergadiças": "vergadiço",
    "vergadiços": "vergadiço",
    "vergado": "vergar",
    "vergados": "vergar",
    "vergaduras": "vergadura",
    "vergadíssima": "vergado",
    "vergadíssimas": "vergado",
    "vergadíssimo": "vergado",
    "vergadíssimos": "vergado",
    "vergai": "vergar",
    "vergais": "vergar",
    "vergalha": "vergalhar",
    "vergalhada": "vergalhar",
    "vergalhadas": "vergalhar",
    "vergalhado": "vergalhar",
    "vergalhados": "vergalhar",
    "vergalhai": "vergalhar",
    "vergalhais": "vergalhar",
    "vergalham": "vergalhar",
    "vergalhamentos": "vergalhamento",
    "vergalhamo": "vergalhar",
    "vergalhamos": "vergalhar",
    "vergalhando": "vergalhar",
    "vergalhara": "vergalhar",
    "vergalharam": "vergalhar",
    "vergalharas": "vergalhar",
    "vergalharde": "vergalhar",
    "vergalhardes": "vergalhar",
    "vergalhare": "vergalhar",
    "vergalharei": "vergalhar",
    "vergalhareis": "vergalhar",
    "vergalharem": "vergalhar",
    "vergalharemos": "vergalhar",
    "vergalhares": "vergalhar",
    "vergalharia": "vergalhar",
    "vergalhariam": "vergalhar",
    "vergalharias": "vergalhar",
    "vergalharmo": "vergalhar",
    "vergalharmos": "vergalhar",
    "vergalhará": "vergalhar",
    "vergalharás": "vergalhar",
    "vergalharão": "vergalhar",
    "vergalharíamos": "vergalhar",
    "vergalharíeis": "vergalhar",
    "vergalhas": "vergalhar",
    "vergalhasse": "vergalhar",
    "vergalhassem": "vergalhar",
    "vergalhasses": "vergalhar",
    "vergalhaste": "vergalhar",
    "vergalhastes": "vergalhar",
    "vergalhava": "vergalhar",
    "vergalhavam": "vergalhar",
    "vergalhavas": "vergalhar",
    "vergalhe": "vergalhar",
    "vergalhei": "vergalhar",
    "vergalheis": "vergalhar",
    "vergalhem": "vergalhar",
    "vergalhemo": "vergalhar",
    "vergalhemos": "vergalhar",
    "vergalhes": "vergalhar",
    "vergalho": "vergalhar",
    "vergalhos": "vergalho",
    "vergalhou": "vergalhar",
    "vergalhá": "vergalhar",
    "vergalhámo": "vergalhar",
    "vergalhámos": "vergalhar",
    "vergalháramo": "vergalhar",
    "vergalháramos": "vergalhar",
    "vergalhárei": "vergalhar",
    "vergalháreis": "vergalhar",
    "vergalhásseis": "vergalhar",
    "vergalhássemos": "vergalhar",
    "vergalhávamo": "vergalhar",
    "vergalhávamos": "vergalhar",
    "vergalhávei": "vergalhar",
    "vergalháveis": "vergalhar",
    "vergalhões": "vergalhão",
    "vergam": "vergar",
    "vergames": "vergame",
    "vergamo": "vergar",
    "vergamos": "vergar",
    "vergamotas": "vergamota",
    "verganchas": "vergancha",
    "vergando": "vergar",
    "vergara": "vergar",
    "vergaram": "vergar",
    "vergaras": "vergar",
    "vergarde": "vergar",
    "vergardes": "vergar",
    "vergare": "vergar",
    "vergarei": "vergar",
    "vergareis": "vergar",
    "vergarem": "vergar",
    "vergaremos": "vergar",
    "vergares": "vergar",
    "vergaria": "vergar",
    "vergariam": "vergar",
    "vergarias": "vergar",
    "vergarmo": "vergar",
    "vergarmos": "vergar",
    "vergará": "vergar",
    "vergarás": "vergar",
    "vergarão": "vergar",
    "vergaríamos": "vergar",
    "vergaríeis": "vergar",
    "vergas": "vergar",
    "vergasse": "vergar",
    "vergassem": "vergar",
    "vergasses": "vergar",
    "vergasta": "vergastar",
    "vergastada": "vergastar",
    "vergastadas": "vergastar",
    "vergastado": "vergastar",
    "vergastados": "vergastar",
    "vergastai": "vergastar",
    "vergastais": "vergastar",
    "vergastam": "vergastar",
    "vergastamo": "vergastar",
    "vergastamos": "vergastar",
    "vergastando": "vergastar",
    "vergastara": "vergastar",
    "vergastaram": "vergastar",
    "vergastaras": "vergastar",
    "vergastarde": "vergastar",
    "vergastardes": "vergastar",
    "vergastare": "vergastar",
    "vergastarei": "vergastar",
    "vergastareis": "vergastar",
    "vergastarem": "vergastar",
    "vergastaremos": "vergastar",
    "vergastares": "vergastar",
    "vergastaria": "vergastar",
    "vergastariam": "vergastar",
    "vergastarias": "vergastar",
    "vergastarmo": "vergastar",
    "vergastarmos": "vergastar",
    "vergastará": "vergastar",
    "vergastarás": "vergastar",
    "vergastarão": "vergastar",
    "vergastaríamos": "vergastar",
    "vergastaríeis": "vergastar",
    "vergastas": "vergastar",
    "vergastasse": "vergastar",
    "vergastassem": "vergastar",
    "vergastasses": "vergastar",
    "vergastaste": "vergastar",
    "vergastastes": "vergastar",
    "vergastava": "vergastar",
    "vergastavam": "vergastar",
    "vergastavas": "vergastar",
    "vergaste": "vergastar",
    "vergastei": "vergastar",
    "vergasteiros": "vergasteiro",
    "vergasteis": "vergastar",
    "vergastem": "vergastar",
    "vergastemo": "vergastar",
    "vergastemos": "vergastar",
    "vergastes": "vergastar",
    "vergasto": "vergastar",
    "vergastou": "vergastar",
    "vergastá": "vergastar",
    "vergastámo": "vergastar",
    "vergastámos": "vergastar",
    "vergastáramo": "vergastar",
    "vergastáramos": "vergastar",
    "vergastárei": "vergastar",
    "vergastáreis": "vergastar",
    "vergastásseis": "vergastar",
    "vergastássemos": "vergastar",
    "vergastávamo": "vergastar",
    "vergastávamos": "vergastar",
    "vergastávei": "vergastar",
    "vergastáveis": "vergastar",
    "vergaturas": "vergatura",
    "vergava": "vergar",
    "vergavam": "vergar",
    "vergavas": "vergar",
    "verginha": "verga",
    "verginhas": "verga",
    "vergita": "verga",
    "vergitas": "verga",
    "vergo": "vergar",
    "vergoadas": "vergoada",
    "vergonhas": "vergonha",
    "vergonhaços": "vergonhaço",
    "vergonhosa": "vergonhoso",
    "vergonhosas": "vergonhoso",
    "vergonhosos": "vergonhoso",
    "vergonteada": "vergontear",
    "vergonteadas": "vergontear",
    "vergonteado": "vergontear",
    "vergonteados": "vergontear",
    "vergonteai": "vergontear",
    "vergonteais": "vergontear",
    "vergonteamo": "vergontear",
    "vergonteamos": "vergontear",
    "vergonteando": "vergontear",
    "vergonteara": "vergontear",
    "vergontearam": "vergontear",
    "vergontearas": "vergontear",
    "vergonteardes": "vergontear",
    "vergontearei": "vergontear",
    "vergonteareis": "vergontear",
    "vergontearem": "vergontear",
    "vergontearemos": "vergontear",
    "vergonteares": "vergontear",
    "vergontearia": "vergontear",
    "vergonteariam": "vergontear",
    "vergontearias": "vergontear",
    "vergontearmo": "vergontear",
    "vergontearmos": "vergontear",
    "vergonteará": "vergontear",
    "vergontearás": "vergontear",
    "vergontearão": "vergontear",
    "vergontearíamos": "vergontear",
    "vergontearíeis": "vergontear",
    "vergonteasse": "vergontear",
    "vergonteassem": "vergontear",
    "vergonteasses": "vergontear",
    "vergonteaste": "vergontear",
    "vergonteastes": "vergontear",
    "vergonteava": "vergontear",
    "vergonteavam": "vergontear",
    "vergonteavas": "vergontear",
    "vergonteei": "vergontear",
    "vergonteeis": "vergontear",
    "vergonteemo": "vergontear",
    "vergonteemos": "vergontear",
    "vergonteia": "vergontear",
    "vergonteiam": "vergontear",
    "vergonteias": "vergontear",
    "vergonteie": "vergontear",
    "vergonteiem": "vergontear",
    "vergonteies": "vergontear",
    "vergonteio": "vergontear",
    "vergonteou": "vergontear",
    "vergonteámo": "vergontear",
    "vergonteámos": "vergontear",
    "vergonteáramo": "vergontear",
    "vergonteáramos": "vergontear",
    "vergonteáreis": "vergontear",
    "vergonteásseis": "vergontear",
    "vergonteássemos": "vergontear",
    "vergonteávamo": "vergontear",
    "vergonteávamos": "vergontear",
    "vergonteáveis": "vergontear",
    "vergou": "vergar",
    "vergue": "vergar",
    "verguei": "vergar",
    "vergueira": "vergueiro",
    "vergueiras": "vergueiro",
    "vergueiros": "vergueiro",
    "vergueis": "vergar",
    "verguem": "vergar",
    "verguemo": "vergar",
    "verguemos": "vergar",
    "vergues": "vergar",
    "verguetas": "vergueta",
    "verguia": "verguio",
    "verguias": "verguio",
    "verguios": "verguio",
    "vergá": "vergar",
    "vergámo": "vergar",
    "vergámos": "vergar",
    "vergáramo": "vergar",
    "vergáramos": "vergar",
    "vergárei": "vergar",
    "vergáreis": "vergar",
    "vergásseis": "vergar",
    "vergássemos": "vergar",
    "vergávamo": "vergar",
    "vergávamos": "vergar",
    "vergávei": "vergar",
    "vergáveis": "vergável",
    "vergéis": "vergel",
    "vergências": "vergência",
    "vergônteas": "vergôntea",
    "vergões": "vergão",
    "veria": "ver",
    "veriam": "ver",
    "verias": "ver",
    "veridicidades": "veridicidade",
    "verifica": "verificar",
    "verificada": "verificar",
    "verificadas": "verificar",
    "verificado": "verificar",
    "verificadora": "verificador",
    "verificadoras": "verificador",
    "verificadores": "verificador",
    "verificados": "verificar",
    "verificai": "verificar",
    "verificais": "verificar",
    "verificam": "verificar",
    "verificamo": "verificar",
    "verificamos": "verificar",
    "verificando": "verificar",
    "verificara": "verificar",
    "verificaram": "verificar",
    "verificaras": "verificar",
    "verificarde": "verificar",
    "verificardes": "verificar",
    "verificare": "verificar",
    "verificarei": "verificar",
    "verificareis": "verificar",
    "verificarem": "verificar",
    "verificaremos": "verificar",
    "verificares": "verificar",
    "verificaria": "verificar",
    "verificariam": "verificar",
    "verificarias": "verificar",
    "verificarmo": "verificar",
    "verificarmos": "verificar",
    "verificará": "verificar",
    "verificarás": "verificar",
    "verificarão": "verificar",
    "verificaríamos": "verificar",
    "verificaríeis": "verificar",
    "verificas": "verificar",
    "verificasse": "verificar",
    "verificassem": "verificar",
    "verificasses": "verificar",
    "verificaste": "verificar",
    "verificastes": "verificar",
    "verificativa": "verificativo",
    "verificativas": "verificativo",
    "verificativos": "verificativo",
    "verificava": "verificar",
    "verificavam": "verificar",
    "verificavas": "verificar",
    "verificações": "verificação",
    "verifico": "verificar",
    "verificou": "verificar",
    "verificá": "verificar",
    "verificámo": "verificar",
    "verificámos": "verificar",
    "verificáramo": "verificar",
    "verificáramos": "verificar",
    "verificárei": "verificar",
    "verificáreis": "verificar",
    "verificásseis": "verificar",
    "verificássemos": "verificar",
    "verificávamo": "verificar",
    "verificávamos": "verificar",
    "verificávei": "verificar",
    "verificáveis": "verificável",
    "verifique": "verificar",
    "verifiquei": "verificar",
    "verifiqueis": "verificar",
    "verifiquem": "verificar",
    "verifiquemo": "verificar",
    "verifiquemos": "verificar",
    "verifiques": "verificar",
    "verissímeis": "verissímil",
    "vermelha": "vermelho",
    "vermelhada": "vermelhar",
    "vermelhadas": "vermelhar",
    "vermelhado": "vermelhar",
    "vermelhados": "vermelhar",
    "vermelhai": "vermelhar",
    "vermelhais": "vermelhar",
    "vermelham": "vermelhar",
    "vermelhamo": "vermelhar",
    "vermelhamos": "vermelhar",
    "vermelhando": "vermelhar",
    "vermelhara": "vermelhar",
    "vermelharam": "vermelhar",
    "vermelharas": "vermelhar",
    "vermelharde": "vermelhar",
    "vermelhardes": "vermelhar",
    "vermelhare": "vermelhar",
    "vermelharei": "vermelhar",
    "vermelhareis": "vermelhar",
    "vermelharem": "vermelhar",
    "vermelharemos": "vermelhar",
    "vermelhares": "vermelhar",
    "vermelharia": "vermelhar",
    "vermelhariam": "vermelhar",
    "vermelharias": "vermelhar",
    "vermelharmo": "vermelhar",
    "vermelharmos": "vermelhar",
    "vermelhará": "vermelhar",
    "vermelharás": "vermelhar",
    "vermelharão": "vermelhar",
    "vermelharíamos": "vermelhar",
    "vermelharíeis": "vermelhar",
    "vermelhas": "vermelho",
    "vermelhasse": "vermelhar",
    "vermelhassem": "vermelhar",
    "vermelhasses": "vermelhar",
    "vermelhaste": "vermelhar",
    "vermelhastes": "vermelhar",
    "vermelhava": "vermelhar",
    "vermelhavam": "vermelhar",
    "vermelhavas": "vermelhar",
    "vermelhaça": "vermelho",
    "vermelhaças": "vermelho",
    "vermelhaço": "vermelho",
    "vermelhaços": "vermelho",
    "vermelhe": "vermelhar",
    "vermelheada": "vermelhear",
    "vermelheadas": "vermelhear",
    "vermelheado": "vermelhear",
    "vermelheados": "vermelhear",
    "vermelheai": "vermelhear",
    "vermelheais": "vermelhear",
    "vermelheamo": "vermelhear",
    "vermelheamos": "vermelhear",
    "vermelheando": "vermelhear",
    "vermelheara": "vermelhear",
    "vermelhearam": "vermelhear",
    "vermelhearas": "vermelhear",
    "vermelheardes": "vermelhear",
    "vermelhearei": "vermelhear",
    "vermelheareis": "vermelhear",
    "vermelhearem": "vermelhear",
    "vermelhearemos": "vermelhear",
    "vermelheares": "vermelhear",
    "vermelhearia": "vermelhear",
    "vermelheariam": "vermelhear",
    "vermelhearias": "vermelhear",
    "vermelhearmo": "vermelhear",
    "vermelhearmos": "vermelhear",
    "vermelheará": "vermelhear",
    "vermelhearás": "vermelhear",
    "vermelhearão": "vermelhear",
    "vermelhearíamos": "vermelhear",
    "vermelhearíeis": "vermelhear",
    "vermelheasse": "vermelhear",
    "vermelheassem": "vermelhear",
    "vermelheasses": "vermelhear",
    "vermelheaste": "vermelhear",
    "vermelheastes": "vermelhear",
    "vermelheava": "vermelhear",
    "vermelheavam": "vermelhear",
    "vermelheavas": "vermelhear",
    "vermelhece": "vermelhecer",
    "vermelhecei": "vermelhecer",
    "vermelheceis": "vermelhecer",
    "vermelhecem": "vermelhecer",
    "vermelhecemo": "vermelhecer",
    "vermelhecemos": "vermelhecer",
    "vermelhecendo": "vermelhecer",
    "vermelhecera": "vermelhecer",
    "vermelheceram": "vermelhecer",
    "vermelheceras": "vermelhecer",
    "vermelhecerdes": "vermelhecer",
    "vermelhecerei": "vermelhecer",
    "vermelhecereis": "vermelhecer",
    "vermelhecerem": "vermelhecer",
    "vermelheceremos": "vermelhecer",
    "vermelheceres": "vermelhecer",
    "vermelheceria": "vermelhecer",
    "vermelheceriam": "vermelhecer",
    "vermelhecerias": "vermelhecer",
    "vermelhecermo": "vermelhecer",
    "vermelhecermos": "vermelhecer",
    "vermelhecerá": "vermelhecer",
    "vermelhecerás": "vermelhecer",
    "vermelhecerão": "vermelhecer",
    "vermelheceríamos": "vermelhecer",
    "vermelheceríeis": "vermelhecer",
    "vermelheces": "vermelhecer",
    "vermelhecesse": "vermelhecer",
    "vermelhecessem": "vermelhecer",
    "vermelhecesses": "vermelhecer",
    "vermelheceste": "vermelhecer",
    "vermelhecestes": "vermelhecer",
    "vermelheceu": "vermelhecer",
    "vermelheci": "vermelhecer",
    "vermelhecia": "vermelhecer",
    "vermelheciam": "vermelhecer",
    "vermelhecias": "vermelhecer",
    "vermelhecida": "vermelhecer",
    "vermelhecidas": "vermelhecer",
    "vermelhecido": "vermelhecer",
    "vermelhecidos": "vermelhecer",
    "vermelhecêramo": "vermelhecer",
    "vermelhecêramos": "vermelhecer",
    "vermelhecêreis": "vermelhecer",
    "vermelhecêsseis": "vermelhecer",
    "vermelhecêssemos": "vermelhecer",
    "vermelhecíamo": "vermelhecer",
    "vermelhecíamos": "vermelhecer",
    "vermelhecíeis": "vermelhecer",
    "vermelheei": "vermelhear",
    "vermelheeis": "vermelhear",
    "vermelheemo": "vermelhear",
    "vermelheemos": "vermelhear",
    "vermelhei": "vermelhar",
    "vermelheia": "vermelhear",
    "vermelheiam": "vermelhear",
    "vermelheias": "vermelhear",
    "vermelheie": "vermelhear",
    "vermelheiem": "vermelhear",
    "vermelheies": "vermelhear",
    "vermelheio": "vermelhear",
    "vermelheis": "vermelhar",
    "vermelheja": "vermelhejar",
    "vermelhejada": "vermelhejar",
    "vermelhejadas": "vermelhejar",
    "vermelhejado": "vermelhejar",
    "vermelhejados": "vermelhejar",
    "vermelhejai": "vermelhejar",
    "vermelhejais": "vermelhejar",
    "vermelhejam": "vermelhejar",
    "vermelhejamo": "vermelhejar",
    "vermelhejamos": "vermelhejar",
    "vermelhejando": "vermelhejar",
    "vermelhejara": "vermelhejar",
    "vermelhejaram": "vermelhejar",
    "vermelhejaras": "vermelhejar",
    "vermelhejarde": "vermelhejar",
    "vermelhejardes": "vermelhejar",
    "vermelhejare": "vermelhejar",
    "vermelhejarei": "vermelhejar",
    "vermelhejareis": "vermelhejar",
    "vermelhejarem": "vermelhejar",
    "vermelhejaremos": "vermelhejar",
    "vermelhejares": "vermelhejar",
    "vermelhejaria": "vermelhejar",
    "vermelhejariam": "vermelhejar",
    "vermelhejarias": "vermelhejar",
    "vermelhejarmo": "vermelhejar",
    "vermelhejarmos": "vermelhejar",
    "vermelhejará": "vermelhejar",
    "vermelhejarás": "vermelhejar",
    "vermelhejarão": "vermelhejar",
    "vermelhejaríamos": "vermelhejar",
    "vermelhejaríeis": "vermelhejar",
    "vermelhejas": "vermelhejar",
    "vermelhejasse": "vermelhejar",
    "vermelhejassem": "vermelhejar",
    "vermelhejasses": "vermelhejar",
    "vermelhejaste": "vermelhejar",
    "vermelhejastes": "vermelhejar",
    "vermelhejava": "vermelhejar",
    "vermelhejavam": "vermelhejar",
    "vermelhejavas": "vermelhejar",
    "vermelheje": "vermelhejar",
    "vermelhejei": "vermelhejar",
    "vermelhejeis": "vermelhejar",
    "vermelhejem": "vermelhejar",
    "vermelhejemo": "vermelhejar",
    "vermelhejemos": "vermelhejar",
    "vermelhejes": "vermelhejar",
    "vermelhejo": "vermelhejar",
    "vermelhejou": "vermelhejar",
    "vermelhejá": "vermelhejar",
    "vermelhejámo": "vermelhejar",
    "vermelhejámos": "vermelhejar",
    "vermelhejáramo": "vermelhejar",
    "vermelhejáramos": "vermelhejar",
    "vermelhejárei": "vermelhejar",
    "vermelhejáreis": "vermelhejar",
    "vermelhejásseis": "vermelhejar",
    "vermelhejássemos": "vermelhejar",
    "vermelhejávamo": "vermelhejar",
    "vermelhejávamos": "vermelhejar",
    "vermelhejávei": "vermelhejar",
    "vermelhejáveis": "vermelhejar",
    "vermelhem": "vermelhar",
    "vermelhemo": "vermelhar",
    "vermelhemos": "vermelhar",
    "vermelheou": "vermelhear",
    "vermelhes": "vermelhar",
    "vermelheámo": "vermelhear",
    "vermelheámos": "vermelhear",
    "vermelheáramo": "vermelhear",
    "vermelheáramos": "vermelhear",
    "vermelheáreis": "vermelhear",
    "vermelheásseis": "vermelhear",
    "vermelheássemos": "vermelhear",
    "vermelheávamo": "vermelhear",
    "vermelheávamos": "vermelhear",
    "vermelheáveis": "vermelhear",
    "vermelheça": "vermelhecer",
    "vermelheçais": "vermelhecer",
    "vermelheçam": "vermelhecer",
    "vermelheçamo": "vermelhecer",
    "vermelheçamos": "vermelhecer",
    "vermelheças": "vermelhecer",
    "vermelheço": "vermelhecer",
    "vermelhidões": "vermelhidão",
    "vermelhinha": "vermelho",
    "vermelhinhas": "vermelho",
    "vermelhinho": "vermelho",
    "vermelhinhos": "vermelho",
    "vermelhita": "vermelho",
    "vermelhitas": "vermelho",
    "vermelhito": "vermelho",
    "vermelhitos": "vermelho",
    "vermelho": "vermelhar",
    "vermelhos": "vermelho",
    "vermelhosa": "vermelhoso",
    "vermelhosas": "vermelhoso",
    "vermelhosos": "vermelhoso",
    "vermelhou": "vermelhar",
    "vermelhusca": "vermelhusco",
    "vermelhuscas": "vermelhusco",
    "vermelhuscos": "vermelhusco",
    "vermelhuça": "vermelhuço",
    "vermelhuças": "vermelhuço",
    "vermelhuços": "vermelhuço",
    "vermelhá": "vermelhar",
    "vermelhámo": "vermelhar",
    "vermelhámos": "vermelhar",
    "vermelháramo": "vermelhar",
    "vermelháramos": "vermelhar",
    "vermelhárei": "vermelhar",
    "vermelháreis": "vermelhar",
    "vermelhásseis": "vermelhar",
    "vermelhássemos": "vermelhar",
    "vermelhávamo": "vermelhar",
    "vermelhávamos": "vermelhar",
    "vermelhávei": "vermelhar",
    "vermelháveis": "vermelhar",
    "vermelhíssima": "vermelho",
    "vermelhíssimas": "vermelho",
    "vermelhíssimo": "vermelho",
    "vermelhíssimos": "vermelho",
    "vermelhões": "vermelhão",
    "vermes": "verme",
    "vermicidas": "vermicida",
    "vermiculada": "vermiculado",
    "vermiculadas": "vermiculado",
    "vermiculados": "vermiculado",
    "vermiculares": "vermicular",
    "vermiculações": "vermiculação",
    "vermiculites": "vermiculite",
    "vermiculosa": "vermiculoso",
    "vermiculosas": "vermiculoso",
    "vermiculosos": "vermiculoso",
    "vermiculuras": "vermiculura",
    "vermiculárias": "vermiculária",
    "vermiformes": "vermiforme",
    "vermilingue": "vermilíngue",
    "vermilingues": "vermilíngues",
    "vermilíngues": "vermilíngue",
    "vermina": "verminar",
    "verminada": "verminar",
    "verminadas": "verminar",
    "verminado": "verminar",
    "verminados": "verminar",
    "verminai": "verminar",
    "verminais": "verminar",
    "verminam": "verminar",
    "verminamo": "verminar",
    "verminamos": "verminar",
    "verminando": "verminar",
    "verminara": "verminar",
    "verminaram": "verminar",
    "verminaras": "verminar",
    "verminarde": "verminar",
    "verminardes": "verminar",
    "verminare": "verminar",
    "verminarei": "verminar",
    "verminareis": "verminar",
    "verminarem": "verminar",
    "verminaremos": "verminar",
    "verminares": "verminar",
    "verminaria": "verminar",
    "verminariam": "verminar",
    "verminarias": "verminar",
    "verminarmo": "verminar",
    "verminarmos": "verminar",
    "verminará": "verminar",
    "verminarás": "verminar",
    "verminarão": "verminar",
    "verminaríamos": "verminar",
    "verminaríeis": "verminar",
    "verminas": "verminar",
    "verminasse": "verminar",
    "verminassem": "verminar",
    "verminasses": "verminar",
    "verminaste": "verminar",
    "verminastes": "verminar",
    "verminava": "verminar",
    "verminavam": "verminar",
    "verminavas": "verminar",
    "verminações": "verminação",
    "vermine": "verminar",
    "verminei": "verminar",
    "vermineiras": "vermineira",
    "vermineis": "verminar",
    "verminem": "verminar",
    "verminemo": "verminar",
    "verminemos": "verminar",
    "vermines": "verminar",
    "vermino": "verminar",
    "verminosa": "verminoso",
    "verminosas": "verminoso",
    "verminoses": "verminose",
    "verminosos": "verminoso",
    "verminou": "verminar",
    "verminá": "verminar",
    "verminámo": "verminar",
    "verminámos": "verminar",
    "vermináramo": "verminar",
    "vermináramos": "verminar",
    "verminárei": "verminar",
    "vermináreis": "verminar",
    "verminásseis": "verminar",
    "verminássemos": "verminar",
    "verminávamo": "verminar",
    "verminávamos": "verminar",
    "verminávei": "verminar",
    "vermináveis": "verminar",
    "vermo": "ver",
    "vermos": "ver",
    "vermutes": "vermute",
    "vermículos": "vermículo",
    "vermídeos": "vermídeo",
    "vermífuga": "vermífugo",
    "vermífugas": "vermífugo",
    "vermífugos": "vermífugo",
    "vermívora": "vermívoro",
    "vermívoras": "vermívoro",
    "vermívoros": "vermívoro",
    "verna": "verno",
    "vernaculares": "vernacular",
    "vernaculações": "vernaculação",
    "vernaculidades": "vernaculidade",
    "vernaculismos": "vernaculismo",
    "vernaculistas": "vernaculista",
    "vernaculiza": "vernaculizar",
    "vernaculizada": "vernaculizar",
    "vernaculizadas": "vernaculizar",
    "vernaculizado": "vernaculizar",
    "vernaculizados": "vernaculizar",
    "vernaculizai": "vernaculizar",
    "vernaculizais": "vernaculizar",
    "vernaculizam": "vernaculizar",
    "vernaculizamo": "vernaculizar",
    "vernaculizamos": "vernaculizar",
    "vernaculizando": "vernaculizar",
    "vernaculizara": "vernaculizar",
    "vernaculizaram": "vernaculizar",
    "vernaculizaras": "vernaculizar",
    "vernaculizarde": "vernaculizar",
    "vernaculizardes": "vernaculizar",
    "vernaculizare": "vernaculizar",
    "vernaculizarei": "vernaculizar",
    "vernaculizareis": "vernaculizar",
    "vernaculizarem": "vernaculizar",
    "vernaculizaremos": "vernaculizar",
    "vernaculizares": "vernaculizar",
    "vernaculizaria": "vernaculizar",
    "vernaculizariam": "vernaculizar",
    "vernaculizarias": "vernaculizar",
    "vernaculizarmo": "vernaculizar",
    "vernaculizarmos": "vernaculizar",
    "vernaculizará": "vernaculizar",
    "vernaculizarás": "vernaculizar",
    "vernaculizarão": "vernaculizar",
    "vernaculizaríamos": "vernaculizar",
    "vernaculizaríeis": "vernaculizar",
    "vernaculizas": "vernaculizar",
    "vernaculizasse": "vernaculizar",
    "vernaculizassem": "vernaculizar",
    "vernaculizasses": "vernaculizar",
    "vernaculizaste": "vernaculizar",
    "vernaculizastes": "vernaculizar",
    "vernaculizava": "vernaculizar",
    "vernaculizavam": "vernaculizar",
    "vernaculizavas": "vernaculizar",
    "vernaculize": "vernaculizar",
    "vernaculizei": "vernaculizar",
    "vernaculizeis": "vernaculizar",
    "vernaculizem": "vernaculizar",
    "vernaculizemo": "vernaculizar",
    "vernaculizemos": "vernaculizar",
    "vernaculizes": "vernaculizar",
    "vernaculizo": "vernaculizar",
    "vernaculizou": "vernaculizar",
    "vernaculizá": "vernaculizar",
    "vernaculizámo": "vernaculizar",
    "vernaculizámos": "vernaculizar",
    "vernaculizáramo": "vernaculizar",
    "vernaculizáramos": "vernaculizar",
    "vernaculizárei": "vernaculizar",
    "vernaculizáreis": "vernaculizar",
    "vernaculizásseis": "vernaculizar",
    "vernaculizássemos": "vernaculizar",
    "vernaculizávamo": "vernaculizar",
    "vernaculizávamos": "vernaculizar",
    "vernaculizávei": "vernaculizar",
    "vernaculizáveis": "vernaculizar",
    "vernada": "vernar",
    "vernadas": "vernar",
    "vernado": "vernar",
    "vernados": "vernar",
    "vernai": "vernar",
    "vernais": "vernar",
    "vernam": "vernar",
    "vernamo": "vernar",
    "vernamos": "vernar",
    "vernando": "vernar",
    "vernantes": "vernante",
    "vernara": "vernar",
    "vernaram": "vernar",
    "vernaras": "vernar",
    "vernardes": "vernar",
    "vernarei": "vernar",
    "vernareis": "vernar",
    "vernarem": "vernar",
    "vernaremos": "vernar",
    "vernares": "vernar",
    "vernaria": "vernar",
    "vernariam": "vernar",
    "vernarias": "vernar",
    "vernarmo": "vernar",
    "vernarmos": "vernar",
    "vernará": "vernar",
    "vernarás": "vernar",
    "vernarão": "vernar",
    "vernaríamos": "vernar",
    "vernaríeis": "vernar",
    "vernas": "verno",
    "vernasse": "vernar",
    "vernassem": "vernar",
    "vernasses": "vernar",
    "vernaste": "vernar",
    "vernastes": "vernar",
    "vernava": "vernar",
    "vernavam": "vernar",
    "vernavas": "vernar",
    "vernações": "vernação",
    "verne": "vernar",
    "vernei": "vernar",
    "verneis": "vernar",
    "vernem": "vernar",
    "vernemo": "vernar",
    "vernemos": "vernar",
    "vernes": "vernar",
    "vernicífera": "vernicífero",
    "vernicíferas": "vernicífero",
    "vernicíferos": "vernicífero",
    "vernizes": "verniz",
    "verno": "vernar",
    "vernos": "verno",
    "vernou": "vernar",
    "vernácula": "vernáculo",
    "vernáculas": "vernáculo",
    "vernáculos": "vernáculo",
    "vernámo": "vernar",
    "vernámos": "vernar",
    "vernáramo": "vernar",
    "vernáramos": "vernar",
    "vernáreis": "vernar",
    "vernásseis": "vernar",
    "vernássemos": "vernar",
    "vernávamo": "vernar",
    "vernávamos": "vernar",
    "vernáveis": "vernar",
    "vernícoma": "vernícomo",
    "vernícomas": "vernícomo",
    "vernícomos": "vernícomo",
    "veronais": "veronal",
    "veronenses": "veronense",
    "veronesa": "veronês",
    "veronesas": "veronês",
    "veroneses": "veronês",
    "veros": "vero",
    "verosimilhantes": "verosimilhante",
    "verosimilhanças": "verosimilhança",
    "verosimilitudes": "verosimilitude",
    "verosímeis": "verosímil",
    "verrascos": "verrasco",
    "verriculada": "verriculado",
    "verriculadas": "verriculado",
    "verriculados": "verriculado",
    "verrina": "verrinar",
    "verrinada": "verrinar",
    "verrinadas": "verrinar",
    "verrinado": "verrinar",
    "verrinados": "verrinar",
    "verrinai": "verrinar",
    "verrinais": "verrinar",
    "verrinam": "verrinar",
    "verrinamo": "verrinar",
    "verrinamos": "verrinar",
    "verrinando": "verrinar",
    "verrinara": "verrinar",
    "verrinaram": "verrinar",
    "verrinaras": "verrinar",
    "verrinarde": "verrinar",
    "verrinardes": "verrinar",
    "verrinare": "verrinar",
    "verrinarei": "verrinar",
    "verrinareis": "verrinar",
    "verrinarem": "verrinar",
    "verrinaremos": "verrinar",
    "verrinares": "verrinar",
    "verrinaria": "verrinar",
    "verrinariam": "verrinar",
    "verrinarias": "verrinar",
    "verrinarmo": "verrinar",
    "verrinarmos": "verrinar",
    "verrinará": "verrinar",
    "verrinarás": "verrinar",
    "verrinarão": "verrinar",
    "verrinaríamos": "verrinar",
    "verrinaríeis": "verrinar",
    "verrinas": "verrinar",
    "verrinasse": "verrinar",
    "verrinassem": "verrinar",
    "verrinasses": "verrinar",
    "verrinaste": "verrinar",
    "verrinastes": "verrinar",
    "verrinava": "verrinar",
    "verrinavam": "verrinar",
    "verrinavas": "verrinar",
    "verrine": "verrinar",
    "verrinei": "verrinar",
    "verrineira": "verrineiro",
    "verrineiras": "verrineiro",
    "verrineiros": "verrineiro",
    "verrineis": "verrinar",
    "verrinem": "verrinar",
    "verrinemo": "verrinar",
    "verrinemos": "verrinar",
    "verrines": "verrinar",
    "verrinistas": "verrinista",
    "verrino": "verrinar",
    "verrinosa": "verrinoso",
    "verrinosas": "verrinoso",
    "verrinosos": "verrinoso",
    "verrinou": "verrinar",
    "verriná": "verrinar",
    "verrinámo": "verrinar",
    "verrinámos": "verrinar",
    "verrináramo": "verrinar",
    "verrináramos": "verrinar",
    "verrinárei": "verrinar",
    "verrináreis": "verrinar",
    "verrinária": "verrinário",
    "verrinárias": "verrinário",
    "verrinários": "verrinário",
    "verrinásseis": "verrinar",
    "verrinássemos": "verrinar",
    "verrinávamo": "verrinar",
    "verrinávamos": "verrinar",
    "verrinávei": "verrinar",
    "verrináveis": "verrinar",
    "verrucais": "verrucal",
    "verruciformes": "verruciforme",
    "verrucárias": "verrucária",
    "verrucífera": "verrucífero",
    "verrucíferas": "verrucífero",
    "verrucíferos": "verrucífero",
    "verrugas": "verruga",
    "verruginha": "verruga",
    "verruginhas": "verruga",
    "verrugita": "verruga",
    "verrugitas": "verruga",
    "verrugosa": "verrugoso",
    "verrugosas": "verrugoso",
    "verrugosos": "verrugoso",
    "verruguenta": "verruguento",
    "verruguentas": "verruguento",
    "verruguentos": "verruguento",
    "verruma": "verrumar",
    "verrumada": "verrumar",
    "verrumadas": "verrumar",
    "verrumado": "verrumar",
    "verrumados": "verrumar",
    "verrumai": "verrumar",
    "verrumais": "verrumar",
    "verrumam": "verrumar",
    "verrumamo": "verrumar",
    "verrumamos": "verrumar",
    "verrumando": "verrumar",
    "verrumara": "verrumar",
    "verrumaram": "verrumar",
    "verrumaras": "verrumar",
    "verrumarde": "verrumar",
    "verrumardes": "verrumar",
    "verrumare": "verrumar",
    "verrumarei": "verrumar",
    "verrumareis": "verrumar",
    "verrumarem": "verrumar",
    "verrumaremos": "verrumar",
    "verrumares": "verrumar",
    "verrumaria": "verrumar",
    "verrumariam": "verrumar",
    "verrumarias": "verrumar",
    "verrumarmo": "verrumar",
    "verrumarmos": "verrumar",
    "verrumará": "verrumar",
    "verrumarás": "verrumar",
    "verrumarão": "verrumar",
    "verrumaríamos": "verrumar",
    "verrumaríeis": "verrumar",
    "verrumas": "verrumar",
    "verrumasse": "verrumar",
    "verrumassem": "verrumar",
    "verrumasses": "verrumar",
    "verrumaste": "verrumar",
    "verrumastes": "verrumar",
    "verrumava": "verrumar",
    "verrumavam": "verrumar",
    "verrumavas": "verrumar",
    "verrume": "verrumar",
    "verrumei": "verrumar",
    "verrumeira": "verrumeiro",
    "verrumeiras": "verrumeiro",
    "verrumeiros": "verrumeiro",
    "verrumeis": "verrumar",
    "verrumem": "verrumar",
    "verrumemo": "verrumar",
    "verrumemos": "verrumar",
    "verrumes": "verrumar",
    "verrumo": "verrumar",
    "verrumou": "verrumar",
    "verrumá": "verrumar",
    "verrumámo": "verrumar",
    "verrumámos": "verrumar",
    "verrumáramo": "verrumar",
    "verrumáramos": "verrumar",
    "verrumárei": "verrumar",
    "verrumáreis": "verrumar",
    "verrumásseis": "verrumar",
    "verrumássemos": "verrumar",
    "verrumávamo": "verrumar",
    "verrumávamos": "verrumar",
    "verrumávei": "verrumar",
    "verrumáveis": "verrumar",
    "verrumões": "verrumão",
    "verrículos": "verrículo",
    "versa": "versar",
    "versada": "versar",
    "versadas": "versar",
    "versado": "versar",
    "versados": "versar",
    "versadíssima": "versado",
    "versadíssimas": "versado",
    "versadíssimo": "versado",
    "versadíssimos": "versado",
    "versai": "versar",
    "versais": "versar",
    "versalhadas": "versalhada",
    "versam": "versar",
    "versamo": "versar",
    "versamos": "versar",
    "versando": "versar",
    "versara": "versar",
    "versaram": "versar",
    "versaras": "versar",
    "versarde": "versar",
    "versardes": "versar",
    "versare": "versar",
    "versarei": "versar",
    "versareis": "versar",
    "versarem": "versar",
    "versaremos": "versar",
    "versares": "versar",
    "versaria": "versar",
    "versariam": "versar",
    "versarias": "versaria",
    "versarmo": "versar",
    "versarmos": "versar",
    "versará": "versar",
    "versarás": "versar",
    "versarão": "versar",
    "versaríamos": "versar",
    "versaríeis": "versar",
    "versas": "versar",
    "versasse": "versar",
    "versassem": "versar",
    "versasses": "versar",
    "versaste": "versar",
    "versastes": "versar",
    "versatilidades": "versatilidade",
    "versava": "versar",
    "versavam": "versar",
    "versavas": "versar",
    "verse": "versar",
    "versei": "versar",
    "verseis": "versar",
    "verseja": "versejar",
    "versejada": "versejar",
    "versejadas": "versejar",
    "versejado": "versejar",
    "versejadora": "versejador",
    "versejadoras": "versejador",
    "versejadores": "versejador",
    "versejados": "versejar",
    "versejai": "versejar",
    "versejais": "versejar",
    "versejam": "versejar",
    "versejamo": "versejar",
    "versejamos": "versejar",
    "versejando": "versejar",
    "versejara": "versejar",
    "versejaram": "versejar",
    "versejaras": "versejar",
    "versejarde": "versejar",
    "versejardes": "versejar",
    "versejare": "versejar",
    "versejarei": "versejar",
    "versejareis": "versejar",
    "versejarem": "versejar",
    "versejaremos": "versejar",
    "versejares": "versejar",
    "versejaria": "versejar",
    "versejariam": "versejar",
    "versejarias": "versejar",
    "versejarmo": "versejar",
    "versejarmos": "versejar",
    "versejará": "versejar",
    "versejarás": "versejar",
    "versejarão": "versejar",
    "versejaríamos": "versejar",
    "versejaríeis": "versejar",
    "versejas": "versejar",
    "versejasse": "versejar",
    "versejassem": "versejar",
    "versejasses": "versejar",
    "versejaste": "versejar",
    "versejastes": "versejar",
    "versejava": "versejar",
    "versejavam": "versejar",
    "versejavas": "versejar",
    "verseje": "versejar",
    "versejei": "versejar",
    "versejeis": "versejar",
    "versejem": "versejar",
    "versejemo": "versejar",
    "versejemos": "versejar",
    "versejes": "versejar",
    "versejo": "versejar",
    "versejou": "versejar",
    "versejá": "versejar",
    "versejámo": "versejar",
    "versejámos": "versejar",
    "versejáramo": "versejar",
    "versejáramos": "versejar",
    "versejárei": "versejar",
    "versejáreis": "versejar",
    "versejásseis": "versejar",
    "versejássemos": "versejar",
    "versejávamo": "versejar",
    "versejávamos": "versejar",
    "versejávei": "versejar",
    "versejáveis": "versejar",
    "versem": "versar",
    "versemo": "versar",
    "versemos": "versar",
    "verses": "versar",
    "versetos": "verseto",
    "versicolora": "versicolor",
    "versicoloras": "versicolor",
    "versicolores": "versicolor",
    "versicorada": "versicorado",
    "versicoradas": "versicorado",
    "versicorados": "versicorado",
    "versifica": "versificar",
    "versificada": "versificar",
    "versificadas": "versificar",
    "versificado": "versificar",
    "versificadora": "versificador",
    "versificadoras": "versificador",
    "versificadores": "versificador",
    "versificados": "versificar",
    "versificai": "versificar",
    "versificais": "versificar",
    "versificam": "versificar",
    "versificamo": "versificar",
    "versificamos": "versificar",
    "versificando": "versificar",
    "versificara": "versificar",
    "versificaram": "versificar",
    "versificaras": "versificar",
    "versificarde": "versificar",
    "versificardes": "versificar",
    "versificare": "versificar",
    "versificarei": "versificar",
    "versificareis": "versificar",
    "versificarem": "versificar",
    "versificaremos": "versificar",
    "versificares": "versificar",
    "versificaria": "versificar",
    "versificariam": "versificar",
    "versificarias": "versificar",
    "versificarmo": "versificar",
    "versificarmos": "versificar",
    "versificará": "versificar",
    "versificarás": "versificar",
    "versificarão": "versificar",
    "versificaríamos": "versificar",
    "versificaríeis": "versificar",
    "versificas": "versificar",
    "versificasse": "versificar",
    "versificassem": "versificar",
    "versificasses": "versificar",
    "versificaste": "versificar",
    "versificastes": "versificar",
    "versificava": "versificar",
    "versificavam": "versificar",
    "versificavas": "versificar",
    "versificações": "versificação",
    "versifico": "versificar",
    "versificou": "versificar",
    "versificá": "versificar",
    "versificámo": "versificar",
    "versificámos": "versificar",
    "versificáramo": "versificar",
    "versificáramos": "versificar",
    "versificárei": "versificar",
    "versificáreis": "versificar",
    "versificásseis": "versificar",
    "versificássemos": "versificar",
    "versificávamo": "versificar",
    "versificávamos": "versificar",
    "versificávei": "versificar",
    "versificáveis": "versificar",
    "versifique": "versificar",
    "versifiquei": "versificar",
    "versifiqueis": "versificar",
    "versifiquem": "versificar",
    "versifiquemo": "versificar",
    "versifiquemos": "versificar",
    "versifiques": "versificar",
    "versilibrismos": "versilibrismo",
    "versilibristas": "versilibrista",
    "versinho": "verso",
    "versinhos": "verso",
    "versistas": "versista",
    "versito": "verso",
    "versitos": "verso",
    "verso": "versar",
    "versores": "versor",
    "versos": "verso",
    "versou": "versar",
    "verstas": "versta",
    "verstes": "verste",
    "versá": "versar",
    "versámo": "versar",
    "versámos": "versar",
    "versáramo": "versar",
    "versáramos": "versar",
    "versárei": "versar",
    "versáreis": "versar",
    "versásseis": "versar",
    "versássemos": "versar",
    "versáteis": "versátil",
    "versávamo": "versar",
    "versávamos": "versar",
    "versávei": "versar",
    "versáveis": "versar",
    "versículos": "versículo",
    "versífera": "versífero",
    "versíferas": "versífero",
    "versíferos": "versífero",
    "versífica": "versífico",
    "versíficas": "versífico",
    "versíficos": "versífico",
    "versões": "versão",
    "verta": "verter",
    "vertais": "verter",
    "vertam": "verter",
    "vertamo": "verter",
    "vertamos": "verter",
    "vertas": "verter",
    "verte": "verter",
    "vertebra": "vertebrar",
    "vertebrada": "vertebrar",
    "vertebradas": "vertebrar",
    "vertebrado": "vertebrar",
    "vertebrados": "vertebrar",
    "vertebrai": "vertebrar",
    "vertebrais": "vertebrar",
    "vertebralidades": "vertebralidade",
    "vertebram": "vertebrar",
    "vertebramo": "vertebrar",
    "vertebramos": "vertebrar",
    "vertebrando": "vertebrar",
    "vertebrara": "vertebrar",
    "vertebraram": "vertebrar",
    "vertebraras": "vertebrar",
    "vertebrarde": "vertebrar",
    "vertebrardes": "vertebrar",
    "vertebrare": "vertebrar",
    "vertebrarei": "vertebrar",
    "vertebrareis": "vertebrar",
    "vertebrarem": "vertebrar",
    "vertebraremos": "vertebrar",
    "vertebrares": "vertebrar",
    "vertebraria": "vertebrar",
    "vertebrariam": "vertebrar",
    "vertebrarias": "vertebrar",
    "vertebrarmo": "vertebrar",
    "vertebrarmos": "vertebrar",
    "vertebrará": "vertebrar",
    "vertebrarás": "vertebrar",
    "vertebrarão": "vertebrar",
    "vertebraríamos": "vertebrar",
    "vertebraríeis": "vertebrar",
    "vertebras": "vertebrar",
    "vertebrasse": "vertebrar",
    "vertebrassem": "vertebrar",
    "vertebrasses": "vertebrar",
    "vertebraste": "vertebrar",
    "vertebrastes": "vertebrar",
    "vertebrava": "vertebrar",
    "vertebravam": "vertebrar",
    "vertebravas": "vertebrar",
    "vertebre": "vertebrar",
    "vertebrei": "vertebrar",
    "vertebreis": "vertebrar",
    "vertebrem": "vertebrar",
    "vertebremo": "vertebrar",
    "vertebremos": "vertebrar",
    "vertebres": "vertebrar",
    "vertebrizações": "vertebrização",
    "vertebro": "vertebrar",
    "vertebrocostais": "vertebrocostal",
    "vertebroilíaca": "vertebroilíaco",
    "vertebroilíacas": "vertebroilíaco",
    "vertebroilíacos": "vertebroilíaco",
    "vertebrosa": "vertebroso",
    "vertebrosas": "vertebroso",
    "vertebrosos": "vertebroso",
    "vertebrou": "vertebrar",
    "vertebrá": "vertebrar",
    "vertebrámo": "vertebrar",
    "vertebrámos": "vertebrar",
    "vertebráramo": "vertebrar",
    "vertebráramos": "vertebrar",
    "vertebrárei": "vertebrar",
    "vertebráreis": "vertebrar",
    "vertebrásseis": "vertebrar",
    "vertebrássemos": "vertebrar",
    "vertebrávamo": "vertebrar",
    "vertebrávamos": "vertebrar",
    "vertebrávei": "vertebrar",
    "vertebráveis": "vertebrar",
    "vertedoiros": "vertedoiro",
    "vertedora": "vertedor",
    "vertedoras": "vertedor",
    "vertedores": "vertedor",
    "vertedouros": "vertedouro",
    "verteduras": "vertedura",
    "vertei": "verter",
    "verteis": "verter",
    "vertem": "verter",
    "vertemo": "verter",
    "vertemos": "verter",
    "vertendo": "verter",
    "vertentes": "vertente",
    "vertera": "verter",
    "verteram": "verter",
    "verteras": "verter",
    "verterde": "verter",
    "verterdes": "verter",
    "vertere": "verter",
    "verterei": "verter",
    "vertereis": "verter",
    "verterem": "verter",
    "verteremos": "verter",
    "verteres": "verter",
    "verteria": "verter",
    "verteriam": "verter",
    "verterias": "verter",
    "vertermo": "verter",
    "vertermos": "verter",
    "verterá": "verter",
    "verterás": "verter",
    "verterão": "verter",
    "verteríamos": "verter",
    "verteríeis": "verter",
    "vertes": "verter",
    "vertesse": "verter",
    "vertessem": "verter",
    "vertesses": "verter",
    "verteste": "verter",
    "vertestes": "verter",
    "verteu": "verter",
    "verti": "verter",
    "vertia": "verter",
    "vertiam": "verter",
    "vertias": "verter",
    "verticais": "vertical",
    "verticalidades": "verticalidade",
    "verticaliza": "verticalizar",
    "verticalizada": "verticalizar",
    "verticalizadas": "verticalizar",
    "verticalizado": "verticalizar",
    "verticalizados": "verticalizar",
    "verticalizai": "verticalizar",
    "verticalizais": "verticalizar",
    "verticalizam": "verticalizar",
    "verticalizamo": "verticalizar",
    "verticalizamos": "verticalizar",
    "verticalizando": "verticalizar",
    "verticalizara": "verticalizar",
    "verticalizaram": "verticalizar",
    "verticalizaras": "verticalizar",
    "verticalizarde": "verticalizar",
    "verticalizardes": "verticalizar",
    "verticalizare": "verticalizar",
    "verticalizarei": "verticalizar",
    "verticalizareis": "verticalizar",
    "verticalizarem": "verticalizar",
    "verticalizaremos": "verticalizar",
    "verticalizares": "verticalizar",
    "verticalizaria": "verticalizar",
    "verticalizariam": "verticalizar",
    "verticalizarias": "verticalizar",
    "verticalizarmo": "verticalizar",
    "verticalizarmos": "verticalizar",
    "verticalizará": "verticalizar",
    "verticalizarás": "verticalizar",
    "verticalizarão": "verticalizar",
    "verticalizaríamos": "verticalizar",
    "verticalizaríeis": "verticalizar",
    "verticalizas": "verticalizar",
    "verticalizasse": "verticalizar",
    "verticalizassem": "verticalizar",
    "verticalizasses": "verticalizar",
    "verticalizaste": "verticalizar",
    "verticalizastes": "verticalizar",
    "verticalizava": "verticalizar",
    "verticalizavam": "verticalizar",
    "verticalizavas": "verticalizar",
    "verticalizações": "verticalização",
    "verticalize": "verticalizar",
    "verticalizei": "verticalizar",
    "verticalizeis": "verticalizar",
    "verticalizem": "verticalizar",
    "verticalizemo": "verticalizar",
    "verticalizemos": "verticalizar",
    "verticalizes": "verticalizar",
    "verticalizo": "verticalizar",
    "verticalizou": "verticalizar",
    "verticalizá": "verticalizar",
    "verticalizámo": "verticalizar",
    "verticalizámos": "verticalizar",
    "verticalizáramo": "verticalizar",
    "verticalizáramos": "verticalizar",
    "verticalizárei": "verticalizar",
    "verticalizáreis": "verticalizar",
    "verticalizásseis": "verticalizar",
    "verticalizássemos": "verticalizar",
    "verticalizávamo": "verticalizar",
    "verticalizávamos": "verticalizar",
    "verticalizávei": "verticalizar",
    "verticalizáveis": "verticalizar",
    "verticalíssima": "vertical",
    "verticalíssimas": "vertical",
    "verticalíssimo": "vertical",
    "verticalíssimos": "vertical",
    "verticidades": "verticidade",
    "verticilada": "verticilado",
    "verticiladas": "verticilado",
    "verticilados": "verticilado",
    "verticilastros": "verticilastro",
    "verticiliflora": "verticilifloro",
    "verticilifloras": "verticilifloro",
    "verticilifloros": "verticilifloro",
    "verticilos": "verticilo",
    "vertida": "vertido",
    "vertidas": "vertido",
    "vertido": "verter",
    "vertidos": "vertido",
    "vertigens": "vertigem",
    "vertiginosa": "vertiginoso",
    "vertiginosas": "vertiginoso",
    "vertiginosos": "vertiginoso",
    "verto": "verter",
    "vertê": "verter",
    "vertêramo": "verter",
    "vertêramos": "verter",
    "vertêrei": "verter",
    "vertêreis": "verter",
    "vertêsseis": "verter",
    "vertêssemos": "verter",
    "vertíamo": "verter",
    "vertíamos": "verter",
    "vertíei": "verter",
    "vertíeis": "verter",
    "verves": "verve",
    "verá": "ver",
    "verás": "ver",
    "verátrica": "verátrico",
    "verátricas": "verátrico",
    "verátricos": "verátrico",
    "verão": "ver",
    "verças": "verça",
    "verçuda": "verçudo",
    "verçudas": "verçudo",
    "verçudos": "verçudo",
    "veríamos": "ver",
    "verídica": "verídico",
    "verídicas": "verídico",
    "verídicos": "verídico",
    "veríeis": "ver",
    "verónicas": "verónica",
    "verões": "verão",
    "vesana": "vesano",
    "vesanas": "vesano",
    "vesanos": "vesano",
    "vesca": "vesco",
    "vescas": "vesco",
    "vescos": "vesco",
    "vesga": "vesgo",
    "vesgas": "vesgo",
    "vesgos": "vesgo",
    "vesgueada": "vesguear",
    "vesgueadas": "vesguear",
    "vesgueado": "vesguear",
    "vesgueados": "vesguear",
    "vesgueai": "vesguear",
    "vesgueais": "vesguear",
    "vesgueamo": "vesguear",
    "vesgueamos": "vesguear",
    "vesgueando": "vesguear",
    "vesgueara": "vesguear",
    "vesguearam": "vesguear",
    "vesguearas": "vesguear",
    "vesgueardes": "vesguear",
    "vesguearei": "vesguear",
    "vesgueareis": "vesguear",
    "vesguearem": "vesguear",
    "vesguearemos": "vesguear",
    "vesgueares": "vesguear",
    "vesguearia": "vesguear",
    "vesgueariam": "vesguear",
    "vesguearias": "vesguear",
    "vesguearmo": "vesguear",
    "vesguearmos": "vesguear",
    "vesgueará": "vesguear",
    "vesguearás": "vesguear",
    "vesguearão": "vesguear",
    "vesguearíamos": "vesguear",
    "vesguearíeis": "vesguear",
    "vesgueasse": "vesguear",
    "vesgueassem": "vesguear",
    "vesgueasses": "vesguear",
    "vesgueaste": "vesguear",
    "vesgueastes": "vesguear",
    "vesgueava": "vesguear",
    "vesgueavam": "vesguear",
    "vesgueavas": "vesguear",
    "vesgueei": "vesguear",
    "vesgueeis": "vesguear",
    "vesgueemo": "vesguear",
    "vesgueemos": "vesguear",
    "vesgueia": "vesguear",
    "vesgueiam": "vesguear",
    "vesgueias": "vesguear",
    "vesgueie": "vesguear",
    "vesgueiem": "vesguear",
    "vesgueies": "vesguear",
    "vesgueio": "vesguear",
    "vesgueira": "vesgueiro",
    "vesgueiras": "vesgueiro",
    "vesgueiros": "vesgueiro",
    "vesgueou": "vesguear",
    "vesgueámo": "vesguear",
    "vesgueámos": "vesguear",
    "vesgueáramo": "vesguear",
    "vesgueáramos": "vesguear",
    "vesgueáreis": "vesguear",
    "vesgueásseis": "vesguear",
    "vesgueássemos": "vesguear",
    "vesgueávamo": "vesguear",
    "vesgueávamos": "vesguear",
    "vesgueáveis": "vesguear",
    "vesguíssima": "vesgo",
    "vesguíssimas": "vesgo",
    "vesguíssimo": "vesgo",
    "vesguíssimos": "vesgo",
    "vesica": "vesicar",
    "vesicada": "vesicar",
    "vesicadas": "vesicar",
    "vesicado": "vesicar",
    "vesicados": "vesicar",
    "vesicai": "vesicar",
    "vesicais": "vesicar",
    "vesicam": "vesicar",
    "vesicamo": "vesicar",
    "vesicamos": "vesicar",
    "vesicando": "vesicar",
    "vesicantes": "vesicante",
    "vesicara": "vesicar",
    "vesicaram": "vesicar",
    "vesicaras": "vesicar",
    "vesicarde": "vesicar",
    "vesicardes": "vesicar",
    "vesicare": "vesicar",
    "vesicarei": "vesicar",
    "vesicareis": "vesicar",
    "vesicarem": "vesicar",
    "vesicaremos": "vesicar",
    "vesicares": "vesicar",
    "vesicaria": "vesicar",
    "vesicariam": "vesicar",
    "vesicarias": "vesicar",
    "vesicarmo": "vesicar",
    "vesicarmos": "vesicar",
    "vesicará": "vesicar",
    "vesicarás": "vesicar",
    "vesicarão": "vesicar",
    "vesicaríamos": "vesicar",
    "vesicaríeis": "vesicar",
    "vesicas": "vesicar",
    "vesicasse": "vesicar",
    "vesicassem": "vesicar",
    "vesicasses": "vesicar",
    "vesicaste": "vesicar",
    "vesicastes": "vesicar",
    "vesicatória": "vesicatório",
    "vesicatórias": "vesicatório",
    "vesicatórios": "vesicatório",
    "vesicava": "vesicar",
    "vesicavam": "vesicar",
    "vesicavas": "vesicar",
    "vesicações": "vesicação",
    "vesico": "vesicar",
    "vesicorrectais": "vesicorrectal",
    "vesicotomias": "vesicotomia",
    "vesicou": "vesicar",
    "vesicovaginais": "vesicovaginal",
    "vesiculares": "vesicular",
    "vesiculações": "vesiculação",
    "vesiculectomias": "vesiculectomia",
    "vesiculiformes": "vesiculiforme",
    "vesiculites": "vesiculite",
    "vesiculosa": "vesiculoso",
    "vesiculosas": "vesiculoso",
    "vesiculosos": "vesiculoso",
    "vesiculotomias": "vesiculotomia",
    "vesiculífera": "vesiculífero",
    "vesiculíferas": "vesiculífero",
    "vesiculíferos": "vesiculífero",
    "vesicá": "vesicar",
    "vesicámo": "vesicar",
    "vesicámos": "vesicar",
    "vesicáramo": "vesicar",
    "vesicáramos": "vesicar",
    "vesicárei": "vesicar",
    "vesicáreis": "vesicar",
    "vesicásseis": "vesicar",
    "vesicássemos": "vesicar",
    "vesicávamo": "vesicar",
    "vesicávamos": "vesicar",
    "vesicávei": "vesicar",
    "vesicáveis": "vesicar",
    "vesique": "vesicar",
    "vesiquei": "vesicar",
    "vesiqueis": "vesicar",
    "vesiquem": "vesicar",
    "vesiquemo": "vesicar",
    "vesiquemos": "vesicar",
    "vesiques": "vesicar",
    "vespas": "vespa",
    "vespeiros": "vespeiro",
    "vesperais": "vesperal",
    "vespertina": "vespertino",
    "vespertinas": "vespertino",
    "vespertinos": "vespertino",
    "vespilheira": "vespilheiro",
    "vespilheiras": "vespilheiro",
    "vespilheiros": "vespilheiro",
    "vespilões": "vespilão",
    "vespérias": "vespéria",
    "vespídeos": "vespídeo",
    "vespões": "vespão",
    "vessa": "vessar",
    "vessada": "vessar",
    "vessadas": "vessar",
    "vessadelas": "vessadela",
    "vessado": "vessar",
    "vessadoiros": "vessadoiro",
    "vessados": "vessar",
    "vessadouros": "vessadouro",
    "vessai": "vessar",
    "vessais": "vessar",
    "vessam": "vessar",
    "vessamo": "vessar",
    "vessamos": "vessar",
    "vessando": "vessar",
    "vessara": "vessar",
    "vessaram": "vessar",
    "vessaras": "vessar",
    "vessarde": "vessar",
    "vessardes": "vessar",
    "vessare": "vessar",
    "vessarei": "vessar",
    "vessareis": "vessar",
    "vessarem": "vessar",
    "vessaremos": "vessar",
    "vessares": "vessar",
    "vessaria": "vessar",
    "vessariam": "vessar",
    "vessarias": "vessar",
    "vessarmo": "vessar",
    "vessarmos": "vessar",
    "vessará": "vessar",
    "vessarás": "vessar",
    "vessarão": "vessar",
    "vessaríamos": "vessar",
    "vessaríeis": "vessar",
    "vessas": "vessar",
    "vessasse": "vessar",
    "vessassem": "vessar",
    "vessasses": "vessar",
    "vessaste": "vessar",
    "vessastes": "vessar",
    "vessava": "vessar",
    "vessavam": "vessar",
    "vessavas": "vessar",
    "vesse": "vessar",
    "vessei": "vessar",
    "vesseis": "vessar",
    "vessem": "vessar",
    "vessemo": "vessar",
    "vessemos": "vessar",
    "vesses": "vessar",
    "vesso": "vessar",
    "vessou": "vessar",
    "vessá": "vessar",
    "vessámo": "vessar",
    "vessámos": "vessar",
    "vessáramo": "vessar",
    "vessáramos": "vessar",
    "vessárei": "vessar",
    "vessáreis": "vessar",
    "vessásseis": "vessar",
    "vessássemos": "vessar",
    "vessávamo": "vessar",
    "vessávamos": "vessar",
    "vessávei": "vessar",
    "vessáveis": "vessar",
    "vestais": "vestal",
    "vestalidades": "vestalidade",
    "vestalina": "vestalino",
    "vestalinas": "vestalino",
    "vestalinos": "vestalino",
    "veste": "vestir",
    "vestem": "vestir",
    "vestes": "vestir",
    "vesti": "vestir",
    "vestia": "vestir",
    "vestiam": "vestir",
    "vestiarias": "vestiaria",
    "vestias": "vestir",
    "vestibulares": "vestibular",
    "vestida": "vestir",
    "vestidas": "vestir",
    "vestideiras": "vestideira",
    "vestidinha": "vestido",
    "vestidinhas": "vestido",
    "vestidinho": "vestido",
    "vestidinhos": "vestido",
    "vestidita": "vestido",
    "vestiditas": "vestido",
    "vestidito": "vestido",
    "vestiditos": "vestido",
    "vestido": "vestir",
    "vestidos": "vestir",
    "vestiduras": "vestidura",
    "vestidíssima": "vestido",
    "vestidíssimas": "vestido",
    "vestidíssimo": "vestido",
    "vestidíssimos": "vestido",
    "vestimentas": "vestimenta",
    "vestimenteiros": "vestimenteiro",
    "vestimo": "vestir",
    "vestimos": "vestir",
    "vestindo": "vestir",
    "vestira": "vestir",
    "vestiram": "vestir",
    "vestiras": "vestir",
    "vestirde": "vestir",
    "vestirdes": "vestir",
    "vestire": "vestir",
    "vestirei": "vestir",
    "vestireis": "vestir",
    "vestirem": "vestir",
    "vestiremos": "vestir",
    "vestires": "vestir",
    "vestiria": "vestir",
    "vestiriam": "vestir",
    "vestirias": "vestir",
    "vestirmo": "vestir",
    "vestirmos": "vestir",
    "vestirá": "vestir",
    "vestirás": "vestir",
    "vestirão": "vestir",
    "vestiríamos": "vestir",
    "vestiríeis": "vestir",
    "vestis": "vestir",
    "vestisse": "vestir",
    "vestissem": "vestir",
    "vestisses": "vestir",
    "vestiste": "vestir",
    "vestistes": "vestir",
    "vestiu": "vestir",
    "vestiários": "vestiário",
    "vestusta": "vestusto",
    "vestustas": "vestusto",
    "vestustos": "vestusto",
    "vestuários": "vestuário",
    "vestíamo": "vestir",
    "vestíamos": "vestir",
    "vestíbulos": "vestíbulo",
    "vestíei": "vestir",
    "vestíeis": "vestir",
    "vestígios": "vestígio",
    "vestíramo": "vestir",
    "vestíramos": "vestir",
    "vestírei": "vestir",
    "vestíreis": "vestir",
    "vestísseis": "vestir",
    "vestíssemos": "vestir",
    "vestíveis": "vestível",
    "vesuviana": "vesuviano",
    "vesuvianas": "vesuviano",
    "vesuvianites": "vesuvianite",
    "vesuvianos": "vesuviano",
    "vesânias": "vesânia",
    "vesânica": "vesânico",
    "vesânicas": "vesânico",
    "vesânicos": "vesânico",
    "vesículas": "vesícula",
    "veta": "vetar",
    "vetada": "vetar",
    "vetadas": "vetar",
    "vetado": "vetar",
    "vetados": "vetar",
    "vetai": "vetar",
    "vetais": "vetar",
    "vetam": "vetar",
    "vetamo": "vetar",
    "vetamos": "vetar",
    "vetando": "vetar",
    "vetara": "vetar",
    "vetaram": "vetar",
    "vetaras": "vetar",
    "vetarde": "vetar",
    "vetardes": "vetar",
    "vetare": "vetar",
    "vetarei": "vetar",
    "vetareis": "vetar",
    "vetarem": "vetar",
    "vetaremos": "vetar",
    "vetares": "vetar",
    "vetaria": "vetar",
    "vetariam": "vetar",
    "vetarias": "vetar",
    "vetarmo": "vetar",
    "vetarmos": "vetar",
    "vetará": "vetar",
    "vetarás": "vetar",
    "vetarão": "vetar",
    "vetaríamos": "vetar",
    "vetaríeis": "vetar",
    "vetas": "vetar",
    "vetasse": "vetar",
    "vetassem": "vetar",
    "vetasses": "vetar",
    "vetaste": "vetar",
    "vetastes": "vetar",
    "vetava": "vetar",
    "vetavam": "vetar",
    "vetavas": "vetar",
    "vete": "vetar",
    "vetei": "vetar",
    "veteis": "vetar",
    "vetem": "vetar",
    "vetemo": "vetar",
    "vetemos": "vetar",
    "veteramentos": "veteramento",
    "veterana": "veterano",
    "veteranas": "veterano",
    "veteranias": "veterania",
    "veteranices": "veteranice",
    "veteranos": "veterano",
    "veterinária": "veterinário",
    "veterinárias": "veterinário",
    "veterinários": "veterinário",
    "vetes": "vetar",
    "vetiveres": "vetiver",
    "veto": "vetar",
    "vetos": "veto",
    "vetou": "vetar",
    "vetusta": "vetusto",
    "vetustades": "vetustade",
    "vetustas": "vetusto",
    "vetustezes": "vetustez",
    "vetustos": "vetusto",
    "vetá": "vetar",
    "vetámo": "vetar",
    "vetámos": "vetar",
    "vetáramo": "vetar",
    "vetáramos": "vetar",
    "vetárei": "vetar",
    "vetáreis": "vetar",
    "vetásseis": "vetar",
    "vetássemos": "vetar",
    "vetávamo": "vetar",
    "vetávamos": "vetar",
    "vetávei": "vetar",
    "vetáveis": "vetar",
    "vetérrima": "vetérrimo",
    "vetérrimas": "vetérrimo",
    "vetérrimos": "vetérrimo",
    "vetões": "vetão",
    "vexa": "vexar",
    "vexada": "vexar",
    "vexadas": "vexar",
    "vexado": "vexar",
    "vexadora": "vexador",
    "vexadoras": "vexador",
    "vexadores": "vexador",
    "vexados": "vexar",
    "vexadíssima": "vexado",
    "vexadíssimas": "vexado",
    "vexadíssimo": "vexado",
    "vexadíssimos": "vexado",
    "vexai": "vexar",
    "vexais": "vexar",
    "vexam": "vexar",
    "vexames": "vexame",
    "vexamo": "vexar",
    "vexamos": "vexar",
    "vexando": "vexar",
    "vexantes": "vexante",
    "vexara": "vexar",
    "vexaram": "vexar",
    "vexaras": "vexar",
    "vexarde": "vexar",
    "vexardes": "vexar",
    "vexare": "vexar",
    "vexarei": "vexar",
    "vexareis": "vexar",
    "vexarem": "vexar",
    "vexaremos": "vexar",
    "vexares": "vexar",
    "vexaria": "vexar",
    "vexariam": "vexar",
    "vexarias": "vexar",
    "vexarmo": "vexar",
    "vexarmos": "vexar",
    "vexará": "vexar",
    "vexarás": "vexar",
    "vexarão": "vexar",
    "vexaríamos": "vexar",
    "vexaríeis": "vexar",
    "vexas": "vexar",
    "vexasse": "vexar",
    "vexassem": "vexar",
    "vexasses": "vexar",
    "vexaste": "vexar",
    "vexastes": "vexar",
    "vexativa": "vexativo",
    "vexativas": "vexativo",
    "vexativos": "vexativo",
    "vexatória": "vexatório",
    "vexatórias": "vexatório",
    "vexatórios": "vexatório",
    "vexava": "vexar",
    "vexavam": "vexar",
    "vexavas": "vexar",
    "vexações": "vexação",
    "vexe": "vexar",
    "vexei": "vexar",
    "vexeis": "vexar",
    "vexem": "vexar",
    "vexemo": "vexar",
    "vexemos": "vexar",
    "vexes": "vexar",
    "vexilares": "vexilar",
    "vexilos": "vexilo",
    "vexilários": "vexilário",
    "vexo": "vexar",
    "vexou": "vexar",
    "vexá": "vexar",
    "vexámo": "vexar",
    "vexámos": "vexar",
    "vexáramo": "vexar",
    "vexáramos": "vexar",
    "vexárei": "vexar",
    "vexáreis": "vexar",
    "vexásseis": "vexar",
    "vexássemos": "vexar",
    "vexávamo": "vexar",
    "vexávamos": "vexar",
    "vexávei": "vexar",
    "vexáveis": "vexar",
    "veza": "vezar",
    "vezada": "vezar",
    "vezadas": "vezar",
    "vezado": "vezar",
    "vezados": "vezar",
    "vezai": "vezar",
    "vezais": "vezar",
    "vezam": "vezar",
    "vezamo": "vezar",
    "vezamos": "vezar",
    "vezando": "vezar",
    "vezara": "vezar",
    "vezaram": "vezar",
    "vezaras": "vezar",
    "vezarde": "vezar",
    "vezardes": "vezar",
    "vezare": "vezar",
    "vezarei": "vezar",
    "vezareis": "vezar",
    "vezarem": "vezar",
    "vezaremos": "vezar",
    "vezares": "vezar",
    "vezaria": "vezar",
    "vezariam": "vezar",
    "vezarias": "vezar",
    "vezarmo": "vezar",
    "vezarmos": "vezar",
    "vezará": "vezar",
    "vezarás": "vezar",
    "vezarão": "vezar",
    "vezaríamos": "vezar",
    "vezaríeis": "vezar",
    "vezas": "vezar",
    "vezasse": "vezar",
    "vezassem": "vezar",
    "vezasses": "vezar",
    "vezaste": "vezar",
    "vezastes": "vezar",
    "vezava": "vezar",
    "vezavam": "vezar",
    "vezavas": "vezar",
    "veze": "vezar",
    "vezei": "vezar",
    "vezeira": "vezeiro",
    "vezeiras": "vezeiro",
    "vezeiros": "vezeiro",
    "vezeis": "vezar",
    "vezem": "vezar",
    "vezemo": "vezar",
    "vezemos": "vezar",
    "vezes": "vezar",
    "vezo": "vezar",
    "vezos": "vezo",
    "vezou": "vezar",
    "vezá": "vezar",
    "vezámo": "vezar",
    "vezámos": "vezar",
    "vezáramo": "vezar",
    "vezáramos": "vezar",
    "vezárei": "vezar",
    "vezáreis": "vezar",
    "vezásseis": "vezar",
    "vezássemos": "vezar",
    "vezávamo": "vezar",
    "vezávamos": "vezar",
    "vezávei": "vezar",
    "vezáveis": "vezar",
    "veículos": "veículo",
    "vi": "vir",
    "via": "ver",
    "viabilidades": "viabilidade",
    "viabililidades": "viabililidade",
    "viabiliza": "viabilizar",
    "viabilizada": "viabilizar",
    "viabilizadas": "viabilizar",
    "viabilizado": "viabilizar",
    "viabilizados": "viabilizar",
    "viabilizai": "viabilizar",
    "viabilizais": "viabilizar",
    "viabilizam": "viabilizar",
    "viabilizamo": "viabilizar",
    "viabilizamos": "viabilizar",
    "viabilizando": "viabilizar",
    "viabilizara": "viabilizar",
    "viabilizaram": "viabilizar",
    "viabilizaras": "viabilizar",
    "viabilizarde": "viabilizar",
    "viabilizardes": "viabilizar",
    "viabilizare": "viabilizar",
    "viabilizarei": "viabilizar",
    "viabilizareis": "viabilizar",
    "viabilizarem": "viabilizar",
    "viabilizaremos": "viabilizar",
    "viabilizares": "viabilizar",
    "viabilizaria": "viabilizar",
    "viabilizariam": "viabilizar",
    "viabilizarias": "viabilizar",
    "viabilizarmo": "viabilizar",
    "viabilizarmos": "viabilizar",
    "viabilizará": "viabilizar",
    "viabilizarás": "viabilizar",
    "viabilizarão": "viabilizar",
    "viabilizaríamos": "viabilizar",
    "viabilizaríeis": "viabilizar",
    "viabilizas": "viabilizar",
    "viabilizasse": "viabilizar",
    "viabilizassem": "viabilizar",
    "viabilizasses": "viabilizar",
    "viabilizaste": "viabilizar",
    "viabilizastes": "viabilizar",
    "viabilizava": "viabilizar",
    "viabilizavam": "viabilizar",
    "viabilizavas": "viabilizar",
    "viabilizações": "viabilização",
    "viabilize": "viabilizar",
    "viabilizei": "viabilizar",
    "viabilizeis": "viabilizar",
    "viabilizem": "viabilizar",
    "viabilizemo": "viabilizar",
    "viabilizemos": "viabilizar",
    "viabilizes": "viabilizar",
    "viabilizo": "viabilizar",
    "viabilizou": "viabilizar",
    "viabilizá": "viabilizar",
    "viabilizámo": "viabilizar",
    "viabilizámos": "viabilizar",
    "viabilizáramo": "viabilizar",
    "viabilizáramos": "viabilizar",
    "viabilizárei": "viabilizar",
    "viabilizáreis": "viabilizar",
    "viabilizásseis": "viabilizar",
    "viabilizássemos": "viabilizar",
    "viabilizávamo": "viabilizar",
    "viabilizávamos": "viabilizar",
    "viabilizávei": "viabilizar",
    "viabilizáveis": "viabilizar",
    "viadora": "viador",
    "viadoras": "viador",
    "viadores": "viador",
    "viados": "viado",
    "viadutos": "viaduto",
    "viageira": "viageiro",
    "viageiras": "viageiro",
    "viageiros": "viageiro",
    "viagens": "viagem",
    "viagenzinha": "viagem",
    "viagenzinhas": "viagem",
    "viagenzita": "viagem",
    "viagenzitas": "viagem",
    "viais": "vial",
    "viaja": "viajar",
    "viajada": "viajar",
    "viajadas": "viajar",
    "viajado": "viajar",
    "viajadora": "viajador",
    "viajadoras": "viajador",
    "viajadores": "viajador",
    "viajados": "viajar",
    "viajai": "viajar",
    "viajais": "viajar",
    "viajam": "viajar",
    "viajamo": "viajar",
    "viajamos": "viajar",
    "viajando": "viajar",
    "viajantes": "viajante",
    "viajara": "viajar",
    "viajaram": "viajar",
    "viajaras": "viajar",
    "viajarde": "viajar",
    "viajardes": "viajar",
    "viajare": "viajar",
    "viajarei": "viajar",
    "viajareis": "viajar",
    "viajarem": "viajar",
    "viajaremos": "viajar",
    "viajares": "viajar",
    "viajaria": "viajar",
    "viajariam": "viajar",
    "viajarias": "viajar",
    "viajarmo": "viajar",
    "viajarmos": "viajar",
    "viajará": "viajar",
    "viajarás": "viajar",
    "viajarão": "viajar",
    "viajaríamos": "viajar",
    "viajaríeis": "viajar",
    "viajas": "viajar",
    "viajasse": "viajar",
    "viajassem": "viajar",
    "viajasses": "viajar",
    "viajaste": "viajar",
    "viajastes": "viajar",
    "viajatas": "viajata",
    "viajava": "viajar",
    "viajavam": "viajar",
    "viajavas": "viajar",
    "viaje": "viajar",
    "viajei": "viajar",
    "viajeis": "viajar",
    "viajem": "viajar",
    "viajemo": "viajar",
    "viajemos": "viajar",
    "viajes": "viajar",
    "viajo": "viajar",
    "viajora": "viajor",
    "viajoras": "viajor",
    "viajores": "viajor",
    "viajou": "viajar",
    "viajá": "viajar",
    "viajámo": "viajar",
    "viajámos": "viajar",
    "viajáramo": "viajar",
    "viajáramos": "viajar",
    "viajárei": "viajar",
    "viajáreis": "viajar",
    "viajásseis": "viajar",
    "viajássemos": "viajar",
    "viajávamo": "viajar",
    "viajávamos": "viajar",
    "viajávei": "viajar",
    "viajáveis": "viajar",
    "viam": "ver",
    "vianda": "viandar",
    "viandada": "viandar",
    "viandadas": "viandar",
    "viandado": "viandar",
    "viandados": "viandar",
    "viandai": "viandar",
    "viandais": "viandar",
    "viandam": "viandar",
    "viandamo": "viandar",
    "viandamos": "viandar",
    "viandando": "viandar",
    "viandantees": "viandante",
    "viandantes": "viandante",
    "viandara": "viandar",
    "viandaram": "viandar",
    "viandaras": "viandar",
    "viandardes": "viandar",
    "viandarei": "viandar",
    "viandareis": "viandar",
    "viandarem": "viandar",
    "viandaremos": "viandar",
    "viandares": "viandar",
    "viandaria": "viandar",
    "viandariam": "viandar",
    "viandarias": "viandar",
    "viandarmo": "viandar",
    "viandarmos": "viandar",
    "viandará": "viandar",
    "viandarás": "viandar",
    "viandarão": "viandar",
    "viandaríamos": "viandar",
    "viandaríeis": "viandar",
    "viandas": "viandar",
    "viandasse": "viandar",
    "viandassem": "viandar",
    "viandasses": "viandar",
    "viandaste": "viandar",
    "viandastes": "viandar",
    "viandava": "viandar",
    "viandavam": "viandar",
    "viandavas": "viandar",
    "viande": "viandar",
    "viandei": "viandar",
    "viandeira": "viandeiro",
    "viandeiras": "viandeiro",
    "viandeiros": "viandeiro",
    "viandeis": "viandar",
    "viandem": "viandar",
    "viandemo": "viandar",
    "viandemos": "viandar",
    "viandes": "viandar",
    "viando": "viandar",
    "viandou": "viandar",
    "viandámo": "viandar",
    "viandámos": "viandar",
    "viandáramo": "viandar",
    "viandáramos": "viandar",
    "viandáreis": "viandar",
    "viandásseis": "viandar",
    "viandássemos": "viandar",
    "viandávamo": "viandar",
    "viandávamos": "viandar",
    "viandáveis": "viandar",
    "vianensees": "vianense",
    "vianenses": "vianense",
    "vianesa": "vianês",
    "vianesas": "vianês",
    "vianeses": "vianês",
    "vias": "via",
    "viatica": "viaticar",
    "viaticada": "viaticar",
    "viaticadas": "viaticar",
    "viaticado": "viaticar",
    "viaticados": "viaticar",
    "viaticai": "viaticar",
    "viaticais": "viaticar",
    "viaticam": "viaticar",
    "viaticamo": "viaticar",
    "viaticamos": "viaticar",
    "viaticando": "viaticar",
    "viaticara": "viaticar",
    "viaticaram": "viaticar",
    "viaticaras": "viaticar",
    "viaticarde": "viaticar",
    "viaticardes": "viaticar",
    "viaticare": "viaticar",
    "viaticarei": "viaticar",
    "viaticareis": "viaticar",
    "viaticarem": "viaticar",
    "viaticaremos": "viaticar",
    "viaticares": "viaticar",
    "viaticaria": "viaticar",
    "viaticariam": "viaticar",
    "viaticarias": "viaticar",
    "viaticarmo": "viaticar",
    "viaticarmos": "viaticar",
    "viaticará": "viaticar",
    "viaticarás": "viaticar",
    "viaticarão": "viaticar",
    "viaticaríamos": "viaticar",
    "viaticaríeis": "viaticar",
    "viaticas": "viaticar",
    "viaticasse": "viaticar",
    "viaticassem": "viaticar",
    "viaticasses": "viaticar",
    "viaticaste": "viaticar",
    "viaticastes": "viaticar",
    "viaticava": "viaticar",
    "viaticavam": "viaticar",
    "viaticavas": "viaticar",
    "viatico": "viaticar",
    "viaticou": "viaticar",
    "viaticá": "viaticar",
    "viaticámo": "viaticar",
    "viaticámos": "viaticar",
    "viaticáramo": "viaticar",
    "viaticáramos": "viaticar",
    "viaticárei": "viaticar",
    "viaticáreis": "viaticar",
    "viaticásseis": "viaticar",
    "viaticássemos": "viaticar",
    "viaticávamo": "viaticar",
    "viaticávamos": "viaticar",
    "viaticávei": "viaticar",
    "viaticáveis": "viaticar",
    "viatique": "viaticar",
    "viatiquei": "viaticar",
    "viatiqueis": "viaticar",
    "viatiquem": "viaticar",
    "viatiquemo": "viaticar",
    "viatiquemos": "viaticar",
    "viatiques": "viaticar",
    "viaturas": "viatura",
    "viatória": "viatório",
    "viatórias": "viatório",
    "viatórios": "viatório",
    "viações": "viação",
    "vibas": "viba",
    "vibra": "vibrar",
    "vibrada": "vibrar",
    "vibradas": "vibrar",
    "vibrado": "vibrar",
    "vibradora": "vibrador",
    "vibradoras": "vibrador",
    "vibradores": "vibrador",
    "vibrados": "vibrar",
    "vibrai": "vibrar",
    "vibrais": "vibrar",
    "vibram": "vibrar",
    "vibramo": "vibrar",
    "vibramos": "vibrar",
    "vibrando": "vibrar",
    "vibrantes": "vibrante",
    "vibrara": "vibrar",
    "vibraram": "vibrar",
    "vibraras": "vibrar",
    "vibrarde": "vibrar",
    "vibrardes": "vibrar",
    "vibrare": "vibrar",
    "vibrarei": "vibrar",
    "vibrareis": "vibrar",
    "vibrarem": "vibrar",
    "vibraremos": "vibrar",
    "vibrares": "vibrar",
    "vibraria": "vibrar",
    "vibrariam": "vibrar",
    "vibrarias": "vibrar",
    "vibrarmo": "vibrar",
    "vibrarmos": "vibrar",
    "vibrará": "vibrar",
    "vibrarás": "vibrar",
    "vibrarão": "vibrar",
    "vibraríamos": "vibrar",
    "vibraríeis": "vibrar",
    "vibras": "vibrar",
    "vibrasse": "vibrar",
    "vibrassem": "vibrar",
    "vibrasses": "vibrar",
    "vibraste": "vibrar",
    "vibrastes": "vibrar",
    "vibratilidades": "vibratilidade",
    "vibratos": "vibrato",
    "vibratória": "vibratório",
    "vibratórias": "vibratório",
    "vibratórios": "vibratório",
    "vibrava": "vibrar",
    "vibravam": "vibrar",
    "vibravas": "vibrar",
    "vibrações": "vibração",
    "vibre": "vibrar",
    "vibrei": "vibrar",
    "vibreis": "vibrar",
    "vibrem": "vibrar",
    "vibremo": "vibrar",
    "vibremos": "vibrar",
    "vibres": "vibrar",
    "vibrissas": "vibrissa",
    "vibriões": "vibrião",
    "vibro": "vibrar",
    "vibroscópios": "vibroscópio",
    "vibrou": "vibrar",
    "vibrá": "vibrar",
    "vibrámo": "vibrar",
    "vibrámos": "vibrar",
    "vibráramo": "vibrar",
    "vibráramos": "vibrar",
    "vibrárei": "vibrar",
    "vibráreis": "vibrar",
    "vibrásseis": "vibrar",
    "vibrássemos": "vibrar",
    "vibráteis": "vibrátil",
    "vibrávamo": "vibrar",
    "vibrávamos": "vibrar",
    "vibrávei": "vibrar",
    "vibráveis": "vibrar",
    "viburnos": "viburno",
    "viburnáceas": "viburnácea",
    "vicariais": "vicarial",
    "vicariantes": "vicariante",
    "vicariatos": "vicariato",
    "vice": "viçar",
    "vicei": "viçar",
    "viceis": "viçar",
    "viceja": "vicejar",
    "vicejada": "vicejar",
    "vicejadas": "vicejar",
    "vicejado": "vicejar",
    "vicejados": "vicejar",
    "vicejai": "vicejar",
    "vicejais": "vicejar",
    "vicejam": "vicejar",
    "vicejamo": "vicejar",
    "vicejamos": "vicejar",
    "vicejando": "vicejar",
    "vicejantes": "vicejante",
    "vicejara": "vicejar",
    "vicejaram": "vicejar",
    "vicejaras": "vicejar",
    "vicejardes": "vicejar",
    "vicejarei": "vicejar",
    "vicejareis": "vicejar",
    "vicejarem": "vicejar",
    "vicejaremos": "vicejar",
    "vicejares": "vicejar",
    "vicejaria": "vicejar",
    "vicejariam": "vicejar",
    "vicejarias": "vicejar",
    "vicejarmo": "vicejar",
    "vicejarmos": "vicejar",
    "vicejará": "vicejar",
    "vicejarás": "vicejar",
    "vicejarão": "vicejar",
    "vicejaríamos": "vicejar",
    "vicejaríeis": "vicejar",
    "vicejas": "vicejar",
    "vicejasse": "vicejar",
    "vicejassem": "vicejar",
    "vicejasses": "vicejar",
    "vicejaste": "vicejar",
    "vicejastes": "vicejar",
    "vicejava": "vicejar",
    "vicejavam": "vicejar",
    "vicejavas": "vicejar",
    "viceje": "vicejar",
    "vicejei": "vicejar",
    "vicejeis": "vicejar",
    "vicejem": "vicejar",
    "vicejemo": "vicejar",
    "vicejemos": "vicejar",
    "vicejes": "vicejar",
    "vicejo": "vicejar",
    "vicejos": "vicejo",
    "vicejou": "vicejar",
    "vicejámo": "vicejar",
    "vicejámos": "vicejar",
    "vicejáramo": "vicejar",
    "vicejáramos": "vicejar",
    "vicejáreis": "vicejar",
    "vicejásseis": "vicejar",
    "vicejássemos": "vicejar",
    "vicejávamo": "vicejar",
    "vicejávamos": "vicejar",
    "vicejáveis": "vicejar",
    "vicem": "viçar",
    "vicemo": "viçar",
    "vicemos": "viçar",
    "vicenais": "vicenal",
    "vicenda": "vicendo",
    "vicendas": "vicendo",
    "vicendos": "vicendo",
    "vicentina": "vicentino",
    "vicentinas": "vicentino",
    "vicentinos": "vicentino",
    "vicentistas": "vicentista",
    "vicenários": "vicenário",
    "vices": "viçar",
    "vicesimais": "vicesimal",
    "vicia": "viciar",
    "viciada": "viciar",
    "viciadas": "viciar",
    "viciado": "viciar",
    "viciadora": "viciador",
    "viciadoras": "viciador",
    "viciadores": "viciador",
    "viciados": "viciar",
    "viciai": "viciar",
    "viciais": "viciar",
    "viciam": "viciar",
    "viciamentos": "viciamento",
    "viciamo": "viciar",
    "viciamos": "viciar",
    "viciando": "viciar",
    "viciantes": "viciante",
    "viciara": "viciar",
    "viciaram": "viciar",
    "viciaras": "viciar",
    "viciarde": "viciar",
    "viciardes": "viciar",
    "viciare": "viciar",
    "viciarei": "viciar",
    "viciareis": "viciar",
    "viciarem": "viciar",
    "viciaremos": "viciar",
    "viciares": "viciar",
    "viciaria": "viciar",
    "viciariam": "viciar",
    "viciarias": "viciar",
    "viciarmo": "viciar",
    "viciarmos": "viciar",
    "viciará": "viciar",
    "viciarás": "viciar",
    "viciarão": "viciar",
    "viciaríamos": "viciar",
    "viciaríeis": "viciar",
    "vicias": "viciar",
    "viciasse": "viciar",
    "viciassem": "viciar",
    "viciasses": "viciar",
    "viciaste": "viciar",
    "viciastes": "viciar",
    "viciava": "viciar",
    "viciavam": "viciar",
    "viciavas": "viciar",
    "viciações": "viciação",
    "vicie": "viciar",
    "viciei": "viciar",
    "vicieis": "viciar",
    "viciem": "viciar",
    "viciemo": "viciar",
    "viciemos": "viciar",
    "vicies": "viciar",
    "vicilinos": "vicilino",
    "vicinais": "vicinal",
    "vicinalidades": "vicinalidade",
    "vicio": "viciar",
    "viciosa": "vicioso",
    "viciosas": "vicioso",
    "viciosidades": "viciosidade",
    "viciosos": "vicioso",
    "viciou": "viciar",
    "vicissitudes": "vicissitude",
    "viciá": "viciar",
    "viciámo": "viciar",
    "viciámos": "viciar",
    "viciáramo": "viciar",
    "viciáramos": "viciar",
    "viciárei": "viciar",
    "viciáreis": "viciar",
    "viciásseis": "viciar",
    "viciássemos": "viciar",
    "viciávamo": "viciar",
    "viciávamos": "viciar",
    "viciávei": "viciar",
    "viciáveis": "viciar",
    "vicomagísteres": "vicomagíster",
    "victrices": "victrice",
    "vicunhas": "vicunha",
    "vicária": "vicário",
    "vicárias": "vicário",
    "vicários": "vicário",
    "vicénios": "vicénio",
    "vicésima": "vicésimo",
    "vicésimas": "vicésimo",
    "vicésimos": "vicésimo",
    "vida": "vidar",
    "vidada": "vidar",
    "vidadas": "vidar",
    "vidado": "vidar",
    "vidados": "vidar",
    "vidai": "vidar",
    "vidais": "vidar",
    "vidam": "vidar",
    "vidamas": "vidama",
    "vidamias": "vidamia",
    "vidamo": "vidar",
    "vidamos": "vidar",
    "vidando": "vidar",
    "vidara": "vidar",
    "vidaram": "vidar",
    "vidaras": "vidar",
    "vidarde": "vidar",
    "vidardes": "vidar",
    "vidare": "vidar",
    "vidarei": "vidar",
    "vidareis": "vidar",
    "vidarem": "vidar",
    "vidaremos": "vidar",
    "vidares": "vidar",
    "vidaria": "vidar",
    "vidariam": "vidar",
    "vidarias": "vidar",
    "vidarmo": "vidar",
    "vidarmos": "vidar",
    "vidará": "vidar",
    "vidarás": "vidar",
    "vidarão": "vidar",
    "vidaríamos": "vidar",
    "vidaríeis": "vidar",
    "vidas": "vidar",
    "vidasse": "vidar",
    "vidassem": "vidar",
    "vidasses": "vidar",
    "vidaste": "vidar",
    "vidastes": "vidar",
    "vidava": "vidar",
    "vidavam": "vidar",
    "vidavas": "vidar",
    "vide": "vidar",
    "videi": "vidar",
    "videira": "videiro",
    "videiras": "videiro",
    "videirinha": "videirinho",
    "videirinhas": "videirinho",
    "videirinhos": "videirinho",
    "videirismos": "videirismo",
    "videiros": "videiro",
    "videis": "vidar",
    "videm": "vidar",
    "videmo": "vidar",
    "videmos": "vidar",
    "videntes": "vidente",
    "videocassetes": "videocassete",
    "videoclipes": "videoclipe",
    "videoclips": "videoclip",
    "videoclubes": "videoclube",
    "videoconferências": "videoconferência",
    "videodiscos": "videodisco",
    "videogramas": "videograma",
    "videográfica": "videográfico",
    "videográficas": "videográfico",
    "videográficos": "videográfico",
    "videojogos": "videojogo",
    "videos": "video",
    "videotapes": "videotape",
    "videotecas": "videoteca",
    "videowalls": "videowall",
    "vides": "vide",
    "vidinha": "vida",
    "vidinhas": "vida",
    "vidita": "vida",
    "viditas": "vida",
    "vido": "vidar",
    "vidoeiros": "vidoeiro",
    "vidonhas": "vidonha",
    "vidonhos": "vidonho",
    "vidos": "vido",
    "vidou": "vidar",
    "vidra": "vidrar",
    "vidraceiros": "vidraceiro",
    "vidracenta": "vidracento",
    "vidracentas": "vidracento",
    "vidracentos": "vidracento",
    "vidracistas": "vidracista",
    "vidrada": "vidrar",
    "vidradas": "vidrar",
    "vidrado": "vidrar",
    "vidradores": "vidrador",
    "vidrados": "vidrar",
    "vidragens": "vidragem",
    "vidrai": "vidrar",
    "vidrais": "vidrar",
    "vidralhadas": "vidralhada",
    "vidram": "vidrar",
    "vidramentos": "vidramento",
    "vidramo": "vidrar",
    "vidramos": "vidrar",
    "vidrando": "vidrar",
    "vidrara": "vidrar",
    "vidraram": "vidrar",
    "vidraras": "vidrar",
    "vidrarde": "vidrar",
    "vidrardes": "vidrar",
    "vidrare": "vidrar",
    "vidrarei": "vidrar",
    "vidrareis": "vidrar",
    "vidrarem": "vidrar",
    "vidraremos": "vidrar",
    "vidrares": "vidrar",
    "vidraria": "vidrar",
    "vidrariam": "vidrar",
    "vidrarias": "vidraria",
    "vidrarmo": "vidrar",
    "vidrarmos": "vidrar",
    "vidrará": "vidrar",
    "vidrarás": "vidrar",
    "vidrarão": "vidrar",
    "vidraríamos": "vidrar",
    "vidraríeis": "vidrar",
    "vidras": "vidrar",
    "vidrasse": "vidrar",
    "vidrassem": "vidrar",
    "vidrasses": "vidrar",
    "vidraste": "vidrar",
    "vidrastes": "vidrar",
    "vidrava": "vidrar",
    "vidravam": "vidrar",
    "vidravas": "vidrar",
    "vidraçarias": "vidraçaria",
    "vidraças": "vidraça",
    "vidraços": "vidraço",
    "vidre": "vidrar",
    "vidrecomes": "vidrecome",
    "vidrei": "vidrar",
    "vidreira": "vidreiro",
    "vidreiras": "vidreiro",
    "vidreiros": "vidreiro",
    "vidreis": "vidrar",
    "vidrem": "vidrar",
    "vidremo": "vidrar",
    "vidremos": "vidrar",
    "vidrenta": "vidrento",
    "vidrentas": "vidrento",
    "vidrentos": "vidrento",
    "vidres": "vidrar",
    "vidrilhos": "vidrilho",
    "vidrina": "vidrino",
    "vidrinas": "vidrino",
    "vidrinho": "vidro",
    "vidrinhos": "vidro",
    "vidrinos": "vidrino",
    "vidrito": "vidro",
    "vidritos": "vidro",
    "vidro": "vidrar",
    "vidros": "vidro",
    "vidrosa": "vidroso",
    "vidrosas": "vidroso",
    "vidrosos": "vidroso",
    "vidrou": "vidrar",
    "vidrá": "vidrar",
    "vidrámo": "vidrar",
    "vidrámos": "vidrar",
    "vidráramo": "vidrar",
    "vidráramos": "vidrar",
    "vidrárei": "vidrar",
    "vidráreis": "vidrar",
    "vidrásseis": "vidrar",
    "vidrássemos": "vidrar",
    "vidrávamo": "vidrar",
    "vidrávamos": "vidrar",
    "vidrávei": "vidrar",
    "vidráveis": "vidrar",
    "vidrões": "vidrão",
    "viduais": "vidual",
    "vidá": "vidar",
    "vidámo": "vidar",
    "vidámos": "vidar",
    "vidáramo": "vidar",
    "vidáramos": "vidar",
    "vidárei": "vidar",
    "vidáreis": "vidar",
    "vidásseis": "vidar",
    "vidássemos": "vidar",
    "vidávamo": "vidar",
    "vidávamos": "vidar",
    "vidávei": "vidar",
    "vidáveis": "vidar",
    "vidências": "vidência",
    "vieiras": "vieira",
    "vieirenses": "vieirense",
    "vielas": "viela",
    "viemo": "vir",
    "viemos": "vir",
    "vienenses": "vienense",
    "vier": "vir",
    "viera": "vir",
    "vieram": "vir",
    "vieras": "vir",
    "vierdes": "vir",
    "vierem": "vir",
    "vieres": "vir",
    "viermos": "vir",
    "viesse": "vir",
    "viessem": "vir",
    "viesses": "vir",
    "vieste": "vir",
    "viestes": "vir",
    "vietnamitas": "vietnamita",
    "viga": "vigar",
    "vigada": "vigar",
    "vigadas": "vigar",
    "vigado": "vigar",
    "vigados": "vigar",
    "vigai": "vigar",
    "vigairadas": "vigairada",
    "vigairarias": "vigairaria",
    "vigais": "vigar",
    "vigam": "vigar",
    "vigamentos": "vigamento",
    "vigamo": "vigar",
    "vigamos": "vigar",
    "vigando": "vigar",
    "vigara": "vigar",
    "vigaram": "vigar",
    "vigararias": "vigararia",
    "vigaras": "vigar",
    "vigarde": "vigar",
    "vigardes": "vigar",
    "vigare": "vigar",
    "vigarei": "vigar",
    "vigareis": "vigar",
    "vigarem": "vigar",
    "vigaremos": "vigar",
    "vigares": "vigar",
    "vigaria": "vigar",
    "vigariam": "vigar",
    "vigarias": "vigar",
    "vigariatos": "vigariato",
    "vigarices": "vigarice",
    "vigarismos": "vigarismo",
    "vigaristas": "vigarista",
    "vigariza": "vigarizar",
    "vigarizada": "vigarizar",
    "vigarizadas": "vigarizar",
    "vigarizado": "vigarizar",
    "vigarizados": "vigarizar",
    "vigarizai": "vigarizar",
    "vigarizais": "vigarizar",
    "vigarizam": "vigarizar",
    "vigarizamo": "vigarizar",
    "vigarizamos": "vigarizar",
    "vigarizando": "vigarizar",
    "vigarizara": "vigarizar",
    "vigarizaram": "vigarizar",
    "vigarizaras": "vigarizar",
    "vigarizarde": "vigarizar",
    "vigarizardes": "vigarizar",
    "vigarizare": "vigarizar",
    "vigarizarei": "vigarizar",
    "vigarizareis": "vigarizar",
    "vigarizarem": "vigarizar",
    "vigarizaremos": "vigarizar",
    "vigarizares": "vigarizar",
    "vigarizaria": "vigarizar",
    "vigarizariam": "vigarizar",
    "vigarizarias": "vigarizar",
    "vigarizarmo": "vigarizar",
    "vigarizarmos": "vigarizar",
    "vigarizará": "vigarizar",
    "vigarizarás": "vigarizar",
    "vigarizarão": "vigarizar",
    "vigarizaríamos": "vigarizar",
    "vigarizaríeis": "vigarizar",
    "vigarizas": "vigarizar",
    "vigarizasse": "vigarizar",
    "vigarizassem": "vigarizar",
    "vigarizasses": "vigarizar",
    "vigarizaste": "vigarizar",
    "vigarizastes": "vigarizar",
    "vigarizava": "vigarizar",
    "vigarizavam": "vigarizar",
    "vigarizavas": "vigarizar",
    "vigarize": "vigarizar",
    "vigarizei": "vigarizar",
    "vigarizeis": "vigarizar",
    "vigarizem": "vigarizar",
    "vigarizemo": "vigarizar",
    "vigarizemos": "vigarizar",
    "vigarizes": "vigarizar",
    "vigarizo": "vigarizar",
    "vigarizou": "vigarizar",
    "vigarizá": "vigarizar",
    "vigarizámo": "vigarizar",
    "vigarizámos": "vigarizar",
    "vigarizáramo": "vigarizar",
    "vigarizáramos": "vigarizar",
    "vigarizárei": "vigarizar",
    "vigarizáreis": "vigarizar",
    "vigarizásseis": "vigarizar",
    "vigarizássemos": "vigarizar",
    "vigarizávamo": "vigarizar",
    "vigarizávamos": "vigarizar",
    "vigarizávei": "vigarizar",
    "vigarizáveis": "vigarizar",
    "vigarmo": "vigar",
    "vigarmos": "vigar",
    "vigará": "vigar",
    "vigarás": "vigar",
    "vigarão": "vigar",
    "vigaríamos": "vigar",
    "vigaríeis": "vigar",
    "vigas": "vigar",
    "vigasse": "vigar",
    "vigassem": "vigar",
    "vigasses": "vigar",
    "vigaste": "vigar",
    "vigastes": "vigar",
    "vigava": "vigar",
    "vigavam": "vigar",
    "vigavas": "vigar",
    "vige": "viger",
    "vigei": "viger",
    "vigeis": "viger",
    "vigem": "viger",
    "vigemo": "viger",
    "vigemos": "viger",
    "vigendo": "viger",
    "vigentes": "vigente",
    "vigentíssima": "vigente",
    "vigentíssimas": "vigente",
    "vigentíssimo": "vigente",
    "vigentíssimos": "vigente",
    "vigera": "viger",
    "vigeram": "viger",
    "vigeras": "viger",
    "vigerdes": "viger",
    "vigerei": "viger",
    "vigereis": "viger",
    "vigerem": "viger",
    "vigeremos": "viger",
    "vigeres": "viger",
    "vigeria": "viger",
    "vigeriam": "viger",
    "vigerias": "viger",
    "vigermo": "viger",
    "vigermos": "viger",
    "vigerá": "viger",
    "vigerás": "viger",
    "vigerão": "viger",
    "vigeríamos": "viger",
    "vigeríeis": "viger",
    "viges": "viger",
    "vigesse": "viger",
    "vigessem": "viger",
    "vigesses": "viger",
    "vigeste": "viger",
    "vigestes": "viger",
    "vigeu": "viger",
    "vigi": "viger",
    "vigia": "vigiar",
    "vigiada": "vigiar",
    "vigiadas": "vigiar",
    "vigiado": "vigiar",
    "vigiadora": "vigiador",
    "vigiadoras": "vigiador",
    "vigiadores": "vigiador",
    "vigiados": "vigiar",
    "vigiai": "vigiar",
    "vigiais": "vigiar",
    "vigiam": "vigiar",
    "vigiamo": "vigiar",
    "vigiamos": "vigiar",
    "vigiando": "vigiar",
    "vigiantes": "vigiante",
    "vigiara": "vigiar",
    "vigiaram": "vigiar",
    "vigiaras": "vigiar",
    "vigiarde": "vigiar",
    "vigiardes": "vigiar",
    "vigiare": "vigiar",
    "vigiarei": "vigiar",
    "vigiareis": "vigiar",
    "vigiarem": "vigiar",
    "vigiaremos": "vigiar",
    "vigiares": "vigiar",
    "vigiaria": "vigiar",
    "vigiariam": "vigiar",
    "vigiarias": "vigiar",
    "vigiarmo": "vigiar",
    "vigiarmos": "vigiar",
    "vigiará": "vigiar",
    "vigiarás": "vigiar",
    "vigiarão": "vigiar",
    "vigiaríamos": "vigiar",
    "vigiaríeis": "vigiar",
    "vigias": "vigiar",
    "vigiasse": "vigiar",
    "vigiassem": "vigiar",
    "vigiasses": "vigiar",
    "vigiaste": "vigiar",
    "vigiastes": "vigiar",
    "vigiava": "vigiar",
    "vigiavam": "vigiar",
    "vigiavas": "vigiar",
    "vigida": "viger",
    "vigidas": "viger",
    "vigido": "viger",
    "vigidos": "viger",
    "vigie": "vigiar",
    "vigiei": "vigiar",
    "vigieis": "vigiar",
    "vigiem": "vigiar",
    "vigiemo": "vigiar",
    "vigiemos": "vigiar",
    "vigies": "vigiar",
    "vigila": "vigilar",
    "vigilada": "vigilar",
    "vigiladas": "vigilar",
    "vigilado": "vigilar",
    "vigiladora": "vigilador",
    "vigiladoras": "vigilador",
    "vigiladores": "vigilador",
    "vigilados": "vigilar",
    "vigilai": "vigilar",
    "vigilais": "vigilar",
    "vigilam": "vigilar",
    "vigilambulismos": "vigilambulismo",
    "vigilamo": "vigilar",
    "vigilamos": "vigilar",
    "vigilando": "vigilar",
    "vigilantes": "vigilante",
    "vigilara": "vigilar",
    "vigilaram": "vigilar",
    "vigilaras": "vigilar",
    "vigilarde": "vigilar",
    "vigilardes": "vigilar",
    "vigilare": "vigilar",
    "vigilarei": "vigilar",
    "vigilareis": "vigilar",
    "vigilarem": "vigilar",
    "vigilaremos": "vigilar",
    "vigilares": "vigilar",
    "vigilaria": "vigilar",
    "vigilariam": "vigilar",
    "vigilarias": "vigilar",
    "vigilarmo": "vigilar",
    "vigilarmos": "vigilar",
    "vigilará": "vigilar",
    "vigilarás": "vigilar",
    "vigilarão": "vigilar",
    "vigilaríamos": "vigilar",
    "vigilaríeis": "vigilar",
    "vigilas": "vigilar",
    "vigilasse": "vigilar",
    "vigilassem": "vigilar",
    "vigilasses": "vigilar",
    "vigilaste": "vigilar",
    "vigilastes": "vigilar",
    "vigilava": "vigilar",
    "vigilavam": "vigilar",
    "vigilavas": "vigilar",
    "vigile": "vigilar",
    "vigilei": "vigilar",
    "vigileis": "vigilar",
    "vigilem": "vigilar",
    "vigilemo": "vigilar",
    "vigilemos": "vigilar",
    "vigiles": "vigilar",
    "vigilo": "vigilar",
    "vigilou": "vigilar",
    "vigilá": "vigilar",
    "vigilámo": "vigilar",
    "vigilámos": "vigilar",
    "vigiláramo": "vigilar",
    "vigiláramos": "vigilar",
    "vigilárei": "vigilar",
    "vigiláreis": "vigilar",
    "vigilásseis": "vigilar",
    "vigilássemos": "vigilar",
    "vigilávamo": "vigilar",
    "vigilávamos": "vigilar",
    "vigilávei": "vigilar",
    "vigiláveis": "vigilar",
    "vigilâmbula": "vigilâmbulo",
    "vigilâmbulas": "vigilâmbulo",
    "vigilâmbulos": "vigilâmbulo",
    "vigilâncias": "vigilância",
    "vigio": "vigiar",
    "vigiou": "vigiar",
    "vigiá": "vigiar",
    "vigiámo": "vigiar",
    "vigiámos": "vigiar",
    "vigiáramo": "vigiar",
    "vigiáramos": "vigiar",
    "vigiárei": "vigiar",
    "vigiáreis": "vigiar",
    "vigiásseis": "vigiar",
    "vigiássemos": "vigiar",
    "vigiávamo": "vigiar",
    "vigiávamos": "vigiar",
    "vigiávei": "vigiar",
    "vigiáveis": "vigiar",
    "vigo": "vigar",
    "vigonhos": "vigonho",
    "vigora": "vigorar",
    "vigorada": "vigorar",
    "vigoradas": "vigorar",
    "vigorado": "vigorar",
    "vigorados": "vigorar",
    "vigorai": "vigorar",
    "vigorais": "vigorar",
    "vigoram": "vigorar",
    "vigoramo": "vigorar",
    "vigoramos": "vigorar",
    "vigorando": "vigorar",
    "vigorantes": "vigorante",
    "vigorara": "vigorar",
    "vigoraram": "vigorar",
    "vigoraras": "vigorar",
    "vigorarde": "vigorar",
    "vigorardes": "vigorar",
    "vigorare": "vigorar",
    "vigorarei": "vigorar",
    "vigorareis": "vigorar",
    "vigorarem": "vigorar",
    "vigoraremos": "vigorar",
    "vigorares": "vigorar",
    "vigoraria": "vigorar",
    "vigorariam": "vigorar",
    "vigorarias": "vigorar",
    "vigorarmo": "vigorar",
    "vigorarmos": "vigorar",
    "vigorará": "vigorar",
    "vigorarás": "vigorar",
    "vigorarão": "vigorar",
    "vigoraríamos": "vigorar",
    "vigoraríeis": "vigorar",
    "vigoras": "vigorar",
    "vigorasse": "vigorar",
    "vigorassem": "vigorar",
    "vigorasses": "vigorar",
    "vigoraste": "vigorar",
    "vigorastes": "vigorar",
    "vigorava": "vigorar",
    "vigoravam": "vigorar",
    "vigoravas": "vigorar",
    "vigore": "vigorar",
    "vigorei": "vigorar",
    "vigoreis": "vigorar",
    "vigorem": "vigorar",
    "vigoremo": "vigorar",
    "vigoremos": "vigorar",
    "vigores": "vigorar",
    "vigorites": "vigorite",
    "vigoriza": "vigorizar",
    "vigorizada": "vigorizar",
    "vigorizadas": "vigorizar",
    "vigorizado": "vigorizar",
    "vigorizados": "vigorizar",
    "vigorizai": "vigorizar",
    "vigorizais": "vigorizar",
    "vigorizam": "vigorizar",
    "vigorizamo": "vigorizar",
    "vigorizamos": "vigorizar",
    "vigorizando": "vigorizar",
    "vigorizara": "vigorizar",
    "vigorizaram": "vigorizar",
    "vigorizaras": "vigorizar",
    "vigorizarde": "vigorizar",
    "vigorizardes": "vigorizar",
    "vigorizare": "vigorizar",
    "vigorizarei": "vigorizar",
    "vigorizareis": "vigorizar",
    "vigorizarem": "vigorizar",
    "vigorizaremos": "vigorizar",
    "vigorizares": "vigorizar",
    "vigorizaria": "vigorizar",
    "vigorizariam": "vigorizar",
    "vigorizarias": "vigorizar",
    "vigorizarmo": "vigorizar",
    "vigorizarmos": "vigorizar",
    "vigorizará": "vigorizar",
    "vigorizarás": "vigorizar",
    "vigorizarão": "vigorizar",
    "vigorizaríamos": "vigorizar",
    "vigorizaríeis": "vigorizar",
    "vigorizas": "vigorizar",
    "vigorizasse": "vigorizar",
    "vigorizassem": "vigorizar",
    "vigorizasses": "vigorizar",
    "vigorizaste": "vigorizar",
    "vigorizastes": "vigorizar",
    "vigorizava": "vigorizar",
    "vigorizavam": "vigorizar",
    "vigorizavas": "vigorizar",
    "vigorize": "vigorizar",
    "vigorizei": "vigorizar",
    "vigorizeis": "vigorizar",
    "vigorizem": "vigorizar",
    "vigorizemo": "vigorizar",
    "vigorizemos": "vigorizar",
    "vigorizes": "vigorizar",
    "vigorizo": "vigorizar",
    "vigorizou": "vigorizar",
    "vigorizá": "vigorizar",
    "vigorizámo": "vigorizar",
    "vigorizámos": "vigorizar",
    "vigorizáramo": "vigorizar",
    "vigorizáramos": "vigorizar",
    "vigorizárei": "vigorizar",
    "vigorizáreis": "vigorizar",
    "vigorizásseis": "vigorizar",
    "vigorizássemos": "vigorizar",
    "vigorizávamo": "vigorizar",
    "vigorizávamos": "vigorizar",
    "vigorizávei": "vigorizar",
    "vigorizáveis": "vigorizar",
    "vigoro": "vigorar",
    "vigorosa": "vigoroso",
    "vigorosas": "vigoroso",
    "vigorosos": "vigoroso",
    "vigorosíssima": "vigoroso",
    "vigorosíssimas": "vigoroso",
    "vigorosíssimo": "vigoroso",
    "vigorosíssimos": "vigoroso",
    "vigorou": "vigorar",
    "vigorá": "vigorar",
    "vigorámo": "vigorar",
    "vigorámos": "vigorar",
    "vigoráramo": "vigorar",
    "vigoráramos": "vigorar",
    "vigorárei": "vigorar",
    "vigoráreis": "vigorar",
    "vigorásseis": "vigorar",
    "vigorássemos": "vigorar",
    "vigorávamo": "vigorar",
    "vigorávamos": "vigorar",
    "vigorávei": "vigorar",
    "vigoráveis": "vigorar",
    "vigotas": "vigota",
    "vigotes": "vigote",
    "vigou": "vigar",
    "vigue": "vigar",
    "viguei": "vigar",
    "vigueis": "vigar",
    "viguem": "vigar",
    "viguemo": "vigar",
    "viguemos": "vigar",
    "vigues": "vigar",
    "vigá": "vigar",
    "vigámo": "vigar",
    "vigámos": "vigar",
    "vigáramo": "vigar",
    "vigáramos": "vigar",
    "vigárei": "vigar",
    "vigáreis": "vigar",
    "vigária": "vigário",
    "vigárias": "vigário",
    "vigários": "vigário",
    "vigásseis": "vigar",
    "vigássemos": "vigar",
    "vigávamo": "vigar",
    "vigávamos": "vigar",
    "vigávei": "vigar",
    "vigáveis": "vigar",
    "vigésima": "vigésimo",
    "vigésimas": "vigésimo",
    "vigésimos": "vigésimo",
    "vigências": "vigência",
    "vigêramo": "viger",
    "vigêramos": "viger",
    "vigêreis": "viger",
    "vigêsseis": "viger",
    "vigêssemos": "viger",
    "vigíamo": "viger",
    "vigíamos": "viger",
    "vigíeis": "viger",
    "vigílias": "vigília",
    "vija": "viger",
    "vijais": "viger",
    "vijam": "viger",
    "vijamo": "viger",
    "vijamos": "viger",
    "vijas": "viger",
    "vijo": "viger",
    "vilacondenses": "vilacondense",
    "vilafranquenses": "vilafranquense",
    "vilanagens": "vilanagem",
    "vilanazes": "vilanaz",
    "vilanaça": "vilanaço",
    "vilanaças": "vilanaço",
    "vilanaços": "vilanaço",
    "vilancetes": "vilancete",
    "vilancicos": "vilancico",
    "vilanesca": "vilanesco",
    "vilanescas": "vilanesco",
    "vilanescos": "vilanesco",
    "vilanias": "vilania",
    "vilarejos": "vilarejo",
    "vilares": "vilar",
    "vilarinhos": "vilarinho",
    "vilas": "vila",
    "vilegiatura": "vilegiaturar",
    "vilegiaturada": "vilegiaturar",
    "vilegiaturadas": "vilegiaturar",
    "vilegiaturado": "vilegiaturar",
    "vilegiaturados": "vilegiaturar",
    "vilegiaturai": "vilegiaturar",
    "vilegiaturais": "vilegiaturar",
    "vilegiaturam": "vilegiaturar",
    "vilegiaturamo": "vilegiaturar",
    "vilegiaturamos": "vilegiaturar",
    "vilegiaturando": "vilegiaturar",
    "vilegiaturara": "vilegiaturar",
    "vilegiaturaram": "vilegiaturar",
    "vilegiaturaras": "vilegiaturar",
    "vilegiaturardes": "vilegiaturar",
    "vilegiaturarei": "vilegiaturar",
    "vilegiaturareis": "vilegiaturar",
    "vilegiaturarem": "vilegiaturar",
    "vilegiaturaremos": "vilegiaturar",
    "vilegiaturares": "vilegiaturar",
    "vilegiaturaria": "vilegiaturar",
    "vilegiaturariam": "vilegiaturar",
    "vilegiaturarias": "vilegiaturar",
    "vilegiaturarmo": "vilegiaturar",
    "vilegiaturarmos": "vilegiaturar",
    "vilegiaturará": "vilegiaturar",
    "vilegiaturarás": "vilegiaturar",
    "vilegiaturarão": "vilegiaturar",
    "vilegiaturaríamos": "vilegiaturar",
    "vilegiaturaríeis": "vilegiaturar",
    "vilegiaturas": "vilegiaturar",
    "vilegiaturasse": "vilegiaturar",
    "vilegiaturassem": "vilegiaturar",
    "vilegiaturasses": "vilegiaturar",
    "vilegiaturaste": "vilegiaturar",
    "vilegiaturastes": "vilegiaturar",
    "vilegiaturava": "vilegiaturar",
    "vilegiaturavam": "vilegiaturar",
    "vilegiaturavas": "vilegiaturar",
    "vilegiature": "vilegiaturar",
    "vilegiaturei": "vilegiaturar",
    "vilegiatureis": "vilegiaturar",
    "vilegiaturem": "vilegiaturar",
    "vilegiaturemo": "vilegiaturar",
    "vilegiaturemos": "vilegiaturar",
    "vilegiatures": "vilegiaturar",
    "vilegiaturistas": "vilegiaturista",
    "vilegiaturo": "vilegiaturar",
    "vilegiaturou": "vilegiaturar",
    "vilegiaturámo": "vilegiaturar",
    "vilegiaturámos": "vilegiaturar",
    "vilegiaturáramo": "vilegiaturar",
    "vilegiaturáramos": "vilegiaturar",
    "vilegiaturáreis": "vilegiaturar",
    "vilegiaturásseis": "vilegiaturar",
    "vilegiaturássemos": "vilegiaturar",
    "vilegiaturávamo": "vilegiaturar",
    "vilegiaturávamos": "vilegiaturar",
    "vilegiaturáveis": "vilegiaturar",
    "vilelas": "vilela",
    "vilesce": "vilescer",
    "vilescei": "vilescer",
    "vilesceis": "vilescer",
    "vilescem": "vilescer",
    "vilescemo": "vilescer",
    "vilescemos": "vilescer",
    "vilescendo": "vilescer",
    "vilescera": "vilescer",
    "vilesceram": "vilescer",
    "vilesceras": "vilescer",
    "vilescerde": "vilescer",
    "vilescerdes": "vilescer",
    "vilescere": "vilescer",
    "vilescerei": "vilescer",
    "vilescereis": "vilescer",
    "vilescerem": "vilescer",
    "vilesceremos": "vilescer",
    "vilesceres": "vilescer",
    "vilesceria": "vilescer",
    "vilesceriam": "vilescer",
    "vilescerias": "vilescer",
    "vilescermo": "vilescer",
    "vilescermos": "vilescer",
    "vilescerá": "vilescer",
    "vilescerás": "vilescer",
    "vilescerão": "vilescer",
    "vilesceríamos": "vilescer",
    "vilesceríeis": "vilescer",
    "vilesces": "vilescer",
    "vilescesse": "vilescer",
    "vilescessem": "vilescer",
    "vilescesses": "vilescer",
    "vilesceste": "vilescer",
    "vilescestes": "vilescer",
    "vilesceu": "vilescer",
    "vilesci": "vilescer",
    "vilescia": "vilescer",
    "vilesciam": "vilescer",
    "vilescias": "vilescer",
    "vilescida": "vilescer",
    "vilescidas": "vilescer",
    "vilescido": "vilescer",
    "vilescidos": "vilescer",
    "vilescê": "vilescer",
    "vilescêramo": "vilescer",
    "vilescêramos": "vilescer",
    "vilescêrei": "vilescer",
    "vilescêreis": "vilescer",
    "vilescêsseis": "vilescer",
    "vilescêssemos": "vilescer",
    "vilescíamo": "vilescer",
    "vilescíamos": "vilescer",
    "vilescíei": "vilescer",
    "vilescíeis": "vilescer",
    "vilesça": "vilescer",
    "vilesçais": "vilescer",
    "vilesçam": "vilescer",
    "vilesçamo": "vilescer",
    "vilesçamos": "vilescer",
    "vilesças": "vilescer",
    "vilesço": "vilescer",
    "viletas": "vileta",
    "vilezas": "vileza",
    "vilhancetes": "vilhancete",
    "vilhancicos": "vilhancico",
    "vilifica": "vilificar",
    "vilificada": "vilificar",
    "vilificadas": "vilificar",
    "vilificado": "vilificar",
    "vilificados": "vilificar",
    "vilificai": "vilificar",
    "vilificais": "vilificar",
    "vilificam": "vilificar",
    "vilificamo": "vilificar",
    "vilificamos": "vilificar",
    "vilificando": "vilificar",
    "vilificara": "vilificar",
    "vilificaram": "vilificar",
    "vilificaras": "vilificar",
    "vilificarde": "vilificar",
    "vilificardes": "vilificar",
    "vilificare": "vilificar",
    "vilificarei": "vilificar",
    "vilificareis": "vilificar",
    "vilificarem": "vilificar",
    "vilificaremos": "vilificar",
    "vilificares": "vilificar",
    "vilificaria": "vilificar",
    "vilificariam": "vilificar",
    "vilificarias": "vilificar",
    "vilificarmo": "vilificar",
    "vilificarmos": "vilificar",
    "vilificará": "vilificar",
    "vilificarás": "vilificar",
    "vilificarão": "vilificar",
    "vilificaríamos": "vilificar",
    "vilificaríeis": "vilificar",
    "vilificas": "vilificar",
    "vilificasse": "vilificar",
    "vilificassem": "vilificar",
    "vilificasses": "vilificar",
    "vilificaste": "vilificar",
    "vilificastes": "vilificar",
    "vilificava": "vilificar",
    "vilificavam": "vilificar",
    "vilificavas": "vilificar",
    "vilifico": "vilificar",
    "vilificou": "vilificar",
    "vilificá": "vilificar",
    "vilificámo": "vilificar",
    "vilificámos": "vilificar",
    "vilificáramo": "vilificar",
    "vilificáramos": "vilificar",
    "vilificárei": "vilificar",
    "vilificáreis": "vilificar",
    "vilificásseis": "vilificar",
    "vilificássemos": "vilificar",
    "vilificávamo": "vilificar",
    "vilificávamos": "vilificar",
    "vilificávei": "vilificar",
    "vilificáveis": "vilificar",
    "vilifique": "vilificar",
    "vilifiquei": "vilificar",
    "vilifiqueis": "vilificar",
    "vilifiquem": "vilificar",
    "vilifiquemo": "vilificar",
    "vilifiquemos": "vilificar",
    "vilifiques": "vilificar",
    "vilipendia": "vilipendiar",
    "vilipendiada": "vilipendiar",
    "vilipendiadas": "vilipendiar",
    "vilipendiado": "vilipendiar",
    "vilipendiadora": "vilipendiador",
    "vilipendiadoras": "vilipendiador",
    "vilipendiadores": "vilipendiador",
    "vilipendiados": "vilipendiar",
    "vilipendiai": "vilipendiar",
    "vilipendiais": "vilipendiar",
    "vilipendiam": "vilipendiar",
    "vilipendiamo": "vilipendiar",
    "vilipendiamos": "vilipendiar",
    "vilipendiando": "vilipendiar",
    "vilipendiara": "vilipendiar",
    "vilipendiaram": "vilipendiar",
    "vilipendiaras": "vilipendiar",
    "vilipendiarde": "vilipendiar",
    "vilipendiardes": "vilipendiar",
    "vilipendiare": "vilipendiar",
    "vilipendiarei": "vilipendiar",
    "vilipendiareis": "vilipendiar",
    "vilipendiarem": "vilipendiar",
    "vilipendiaremos": "vilipendiar",
    "vilipendiares": "vilipendiar",
    "vilipendiaria": "vilipendiar",
    "vilipendiariam": "vilipendiar",
    "vilipendiarias": "vilipendiar",
    "vilipendiarmo": "vilipendiar",
    "vilipendiarmos": "vilipendiar",
    "vilipendiará": "vilipendiar",
    "vilipendiarás": "vilipendiar",
    "vilipendiarão": "vilipendiar",
    "vilipendiaríamos": "vilipendiar",
    "vilipendiaríeis": "vilipendiar",
    "vilipendias": "vilipendiar",
    "vilipendiasse": "vilipendiar",
    "vilipendiassem": "vilipendiar",
    "vilipendiasses": "vilipendiar",
    "vilipendiaste": "vilipendiar",
    "vilipendiastes": "vilipendiar",
    "vilipendiava": "vilipendiar",
    "vilipendiavam": "vilipendiar",
    "vilipendiavas": "vilipendiar",
    "vilipendie": "vilipendiar",
    "vilipendiei": "vilipendiar",
    "vilipendieis": "vilipendiar",
    "vilipendiem": "vilipendiar",
    "vilipendiemo": "vilipendiar",
    "vilipendiemos": "vilipendiar",
    "vilipendies": "vilipendiar",
    "vilipendio": "vilipendiar",
    "vilipendiosa": "vilipendioso",
    "vilipendiosas": "vilipendioso",
    "vilipendiosos": "vilipendioso",
    "vilipendiou": "vilipendiar",
    "vilipendiá": "vilipendiar",
    "vilipendiámo": "vilipendiar",
    "vilipendiámos": "vilipendiar",
    "vilipendiáramo": "vilipendiar",
    "vilipendiáramos": "vilipendiar",
    "vilipendiárei": "vilipendiar",
    "vilipendiáreis": "vilipendiar",
    "vilipendiásseis": "vilipendiar",
    "vilipendiássemos": "vilipendiar",
    "vilipendiávamo": "vilipendiar",
    "vilipendiávamos": "vilipendiar",
    "vilipendiávei": "vilipendiar",
    "vilipendiáveis": "vilipendiar",
    "vilipêndios": "vilipêndio",
    "viloa": "vilão",
    "viloas": "vilão",
    "vilosa": "viloso",
    "vilosas": "viloso",
    "vilosidades": "vilosidade",
    "vilosos": "viloso",
    "vilotas": "vilota",
    "vilta": "viltar",
    "viltada": "viltar",
    "viltadas": "viltar",
    "viltado": "viltar",
    "viltados": "viltar",
    "viltai": "viltar",
    "viltais": "viltar",
    "viltam": "viltar",
    "viltamo": "viltar",
    "viltamos": "viltar",
    "viltando": "viltar",
    "viltanças": "viltança",
    "viltara": "viltar",
    "viltaram": "viltar",
    "viltaras": "viltar",
    "viltarde": "viltar",
    "viltardes": "viltar",
    "viltare": "viltar",
    "viltarei": "viltar",
    "viltareis": "viltar",
    "viltarem": "viltar",
    "viltaremos": "viltar",
    "viltares": "viltar",
    "viltaria": "viltar",
    "viltariam": "viltar",
    "viltarias": "viltar",
    "viltarmo": "viltar",
    "viltarmos": "viltar",
    "viltará": "viltar",
    "viltarás": "viltar",
    "viltarão": "viltar",
    "viltaríamos": "viltar",
    "viltaríeis": "viltar",
    "viltas": "viltar",
    "viltasse": "viltar",
    "viltassem": "viltar",
    "viltasses": "viltar",
    "viltaste": "viltar",
    "viltastes": "viltar",
    "viltava": "viltar",
    "viltavam": "viltar",
    "viltavas": "viltar",
    "vilte": "viltar",
    "viltei": "viltar",
    "vilteis": "viltar",
    "viltem": "viltar",
    "viltemo": "viltar",
    "viltemos": "viltar",
    "viltes": "viltar",
    "vilto": "viltar",
    "viltou": "viltar",
    "viltá": "viltar",
    "viltámo": "viltar",
    "viltámos": "viltar",
    "viltáramo": "viltar",
    "viltáramos": "viltar",
    "viltárei": "viltar",
    "viltáreis": "viltar",
    "viltásseis": "viltar",
    "viltássemos": "viltar",
    "viltávamo": "viltar",
    "viltávamos": "viltar",
    "viltávei": "viltar",
    "viltáveis": "viltar",
    "vilórias": "vilória",
    "vilões": "vilão",
    "vim": "vir",
    "vimaranenses": "vimaranense",
    "vimas": "vima",
    "vimeiros": "vimeiro",
    "vimes": "vime",
    "vimiais": "vimial",
    "vimieiros": "vimieiro",
    "viminosa": "viminoso",
    "viminosas": "viminoso",
    "viminosos": "viminoso",
    "vimo": "vir",
    "vimos": "vir",
    "vimosa": "vimoso",
    "vimosas": "vimoso",
    "vimosos": "vimoso",
    "vimínea": "vimíneo",
    "vimíneas": "vimíneo",
    "vimíneos": "vimíneo",
    "vinagens": "vinagem",
    "vinagra": "vinagrar",
    "vinagrada": "vinagrar",
    "vinagradas": "vinagrar",
    "vinagrado": "vinagrar",
    "vinagrados": "vinagrar",
    "vinagrai": "vinagrar",
    "vinagrais": "vinagrar",
    "vinagram": "vinagrar",
    "vinagramo": "vinagrar",
    "vinagramos": "vinagrar",
    "vinagrando": "vinagrar",
    "vinagrara": "vinagrar",
    "vinagraram": "vinagrar",
    "vinagraras": "vinagrar",
    "vinagrarde": "vinagrar",
    "vinagrardes": "vinagrar",
    "vinagrare": "vinagrar",
    "vinagrarei": "vinagrar",
    "vinagrareis": "vinagrar",
    "vinagrarem": "vinagrar",
    "vinagraremos": "vinagrar",
    "vinagrares": "vinagrar",
    "vinagraria": "vinagrar",
    "vinagrariam": "vinagrar",
    "vinagrarias": "vinagrar",
    "vinagrarmo": "vinagrar",
    "vinagrarmos": "vinagrar",
    "vinagrará": "vinagrar",
    "vinagrarás": "vinagrar",
    "vinagrarão": "vinagrar",
    "vinagraríamos": "vinagrar",
    "vinagraríeis": "vinagrar",
    "vinagras": "vinagrar",
    "vinagrasse": "vinagrar",
    "vinagrassem": "vinagrar",
    "vinagrasses": "vinagrar",
    "vinagraste": "vinagrar",
    "vinagrastes": "vinagrar",
    "vinagrava": "vinagrar",
    "vinagravam": "vinagrar",
    "vinagravas": "vinagrar",
    "vinagre": "vinagrar",
    "vinagrei": "vinagrar",
    "vinagreiras": "vinagreira",
    "vinagreiros": "vinagreiro",
    "vinagreis": "vinagrar",
    "vinagrem": "vinagrar",
    "vinagremo": "vinagrar",
    "vinagremos": "vinagrar",
    "vinagrenta": "vinagrento",
    "vinagrentas": "vinagrento",
    "vinagrentos": "vinagrento",
    "vinagres": "vinagre",
    "vinagretas": "vinagreta",
    "vinagrinhos": "vinagrinho",
    "vinagro": "vinagrar",
    "vinagrou": "vinagrar",
    "vinagrá": "vinagrar",
    "vinagrámo": "vinagrar",
    "vinagrámos": "vinagrar",
    "vinagráramo": "vinagrar",
    "vinagráramos": "vinagrar",
    "vinagrárei": "vinagrar",
    "vinagráreis": "vinagrar",
    "vinagrásseis": "vinagrar",
    "vinagrássemos": "vinagrar",
    "vinagrávamo": "vinagrar",
    "vinagrávamos": "vinagrar",
    "vinagrávei": "vinagrar",
    "vinagráveis": "vinagrar",
    "vinas": "vina",
    "vinca": "vincar",
    "vincada": "vincar",
    "vincadas": "vincar",
    "vincado": "vincar",
    "vincados": "vincar",
    "vincai": "vincar",
    "vincais": "vincar",
    "vincam": "vincar",
    "vincamo": "vincar",
    "vincamos": "vincar",
    "vincando": "vincar",
    "vincara": "vincar",
    "vincaram": "vincar",
    "vincaras": "vincar",
    "vincarde": "vincar",
    "vincardes": "vincar",
    "vincare": "vincar",
    "vincarei": "vincar",
    "vincareis": "vincar",
    "vincarem": "vincar",
    "vincaremos": "vincar",
    "vincares": "vincar",
    "vincaria": "vincar",
    "vincariam": "vincar",
    "vincarias": "vincar",
    "vincarmo": "vincar",
    "vincarmos": "vincar",
    "vincará": "vincar",
    "vincarás": "vincar",
    "vincarão": "vincar",
    "vincaríamos": "vincar",
    "vincaríeis": "vincar",
    "vincas": "vincar",
    "vincasse": "vincar",
    "vincassem": "vincar",
    "vincasses": "vincar",
    "vincaste": "vincar",
    "vincastes": "vincar",
    "vincava": "vincar",
    "vincavam": "vincar",
    "vincavas": "vincar",
    "vincelhos": "vincelho",
    "vincenda": "vincendo",
    "vincendas": "vincendo",
    "vincendos": "vincendo",
    "vincilhos": "vincilho",
    "vincitura": "vincituro",
    "vincituras": "vincituro",
    "vincituros": "vincituro",
    "vinco": "vincar",
    "vincos": "vinco",
    "vincou": "vincar",
    "vincula": "vincular",
    "vinculada": "vincular",
    "vinculadas": "vincular",
    "vinculado": "vincular",
    "vinculadora": "vinculador",
    "vinculadoras": "vinculador",
    "vinculadores": "vinculador",
    "vinculados": "vincular",
    "vinculai": "vincular",
    "vinculais": "vincular",
    "vinculam": "vincular",
    "vinculamo": "vincular",
    "vinculamos": "vincular",
    "vinculando": "vincular",
    "vinculara": "vincular",
    "vincularam": "vincular",
    "vincularas": "vincular",
    "vincularde": "vincular",
    "vinculardes": "vincular",
    "vinculare": "vincular",
    "vincularei": "vincular",
    "vinculareis": "vincular",
    "vincularem": "vincular",
    "vincularemos": "vincular",
    "vinculares": "vincular",
    "vincularia": "vincular",
    "vinculariam": "vincular",
    "vincularias": "vincular",
    "vincularmo": "vincular",
    "vincularmos": "vincular",
    "vinculará": "vincular",
    "vincularás": "vincular",
    "vincularão": "vincular",
    "vincularíamos": "vincular",
    "vincularíeis": "vincular",
    "vinculas": "vincular",
    "vinculasse": "vincular",
    "vinculassem": "vincular",
    "vinculasses": "vincular",
    "vinculaste": "vincular",
    "vinculastes": "vincular",
    "vinculativa": "vinculativo",
    "vinculativas": "vinculativo",
    "vinculativos": "vinculativo",
    "vinculatória": "vinculatório",
    "vinculatórias": "vinculatório",
    "vinculatórios": "vinculatório",
    "vinculava": "vincular",
    "vinculavam": "vincular",
    "vinculavas": "vincular",
    "vinculações": "vinculação",
    "vincule": "vincular",
    "vinculei": "vincular",
    "vinculeis": "vincular",
    "vinculem": "vincular",
    "vinculemo": "vincular",
    "vinculemos": "vincular",
    "vincules": "vincular",
    "vinculo": "vincular",
    "vinculou": "vincular",
    "vinculá": "vincular",
    "vinculámo": "vincular",
    "vinculámos": "vincular",
    "vinculáramo": "vincular",
    "vinculáramos": "vincular",
    "vinculárei": "vincular",
    "vinculáreis": "vincular",
    "vinculásseis": "vincular",
    "vinculássemos": "vincular",
    "vinculávamo": "vincular",
    "vinculávamos": "vincular",
    "vinculávei": "vincular",
    "vinculáveis": "vinculável",
    "vincá": "vincar",
    "vincámo": "vincar",
    "vincámos": "vincar",
    "vincáramo": "vincar",
    "vincáramos": "vincar",
    "vincárei": "vincar",
    "vincáreis": "vincar",
    "vincásseis": "vincar",
    "vincássemos": "vincar",
    "vincávamo": "vincar",
    "vincávamos": "vincar",
    "vincávei": "vincar",
    "vincáveis": "vincar",
    "vinda": "vir",
    "vindas": "vir",
    "vinde": "vir",
    "vindemiários": "vindemiário",
    "vindes": "vir",
    "vindica": "vindicar",
    "vindicada": "vindicar",
    "vindicadas": "vindicar",
    "vindicado": "vindicar",
    "vindicadora": "vindicador",
    "vindicadoras": "vindicador",
    "vindicadores": "vindicador",
    "vindicados": "vindicar",
    "vindicai": "vindicar",
    "vindicais": "vindicar",
    "vindicam": "vindicar",
    "vindicamo": "vindicar",
    "vindicamos": "vindicar",
    "vindicando": "vindicar",
    "vindicara": "vindicar",
    "vindicaram": "vindicar",
    "vindicaras": "vindicar",
    "vindicarde": "vindicar",
    "vindicardes": "vindicar",
    "vindicare": "vindicar",
    "vindicarei": "vindicar",
    "vindicareis": "vindicar",
    "vindicarem": "vindicar",
    "vindicaremos": "vindicar",
    "vindicares": "vindicar",
    "vindicaria": "vindicar",
    "vindicariam": "vindicar",
    "vindicarias": "vindicar",
    "vindicarmo": "vindicar",
    "vindicarmos": "vindicar",
    "vindicará": "vindicar",
    "vindicarás": "vindicar",
    "vindicarão": "vindicar",
    "vindicaríamos": "vindicar",
    "vindicaríeis": "vindicar",
    "vindicas": "vindicar",
    "vindicasse": "vindicar",
    "vindicassem": "vindicar",
    "vindicasses": "vindicar",
    "vindicaste": "vindicar",
    "vindicastes": "vindicar",
    "vindicativa": "vindicativo",
    "vindicativas": "vindicativo",
    "vindicativos": "vindicativo",
    "vindicava": "vindicar",
    "vindicavam": "vindicar",
    "vindicavas": "vindicar",
    "vindicações": "vindicação",
    "vindico": "vindicar",
    "vindicou": "vindicar",
    "vindictas": "vindicta",
    "vindicá": "vindicar",
    "vindicámo": "vindicar",
    "vindicámos": "vindicar",
    "vindicáramo": "vindicar",
    "vindicáramos": "vindicar",
    "vindicárei": "vindicar",
    "vindicáreis": "vindicar",
    "vindicásseis": "vindicar",
    "vindicássemos": "vindicar",
    "vindicávamo": "vindicar",
    "vindicávamos": "vindicar",
    "vindicávei": "vindicar",
    "vindicáveis": "vindicar",
    "vindima": "vindimo",
    "vindimada": "vindimar",
    "vindimadas": "vindimar",
    "vindimadeira": "vindimadeiro",
    "vindimadeiras": "vindimadeiro",
    "vindimadeiros": "vindimadeiro",
    "vindimado": "vindimar",
    "vindimadora": "vindimador",
    "vindimadoras": "vindimador",
    "vindimadores": "vindimador",
    "vindimados": "vindimar",
    "vindimaduras": "vindimadura",
    "vindimai": "vindimar",
    "vindimais": "vindimar",
    "vindimam": "vindimar",
    "vindimamo": "vindimar",
    "vindimamos": "vindimar",
    "vindimando": "vindimar",
    "vindimara": "vindimar",
    "vindimaram": "vindimar",
    "vindimaras": "vindimar",
    "vindimarde": "vindimar",
    "vindimardes": "vindimar",
    "vindimare": "vindimar",
    "vindimarei": "vindimar",
    "vindimareis": "vindimar",
    "vindimarem": "vindimar",
    "vindimaremos": "vindimar",
    "vindimares": "vindimar",
    "vindimaria": "vindimar",
    "vindimariam": "vindimar",
    "vindimarias": "vindimar",
    "vindimarmo": "vindimar",
    "vindimarmos": "vindimar",
    "vindimará": "vindimar",
    "vindimarás": "vindimar",
    "vindimarão": "vindimar",
    "vindimaríamos": "vindimar",
    "vindimaríeis": "vindimar",
    "vindimas": "vindimo",
    "vindimasse": "vindimar",
    "vindimassem": "vindimar",
    "vindimasses": "vindimar",
    "vindimaste": "vindimar",
    "vindimastes": "vindimar",
    "vindimava": "vindimar",
    "vindimavam": "vindimar",
    "vindimavas": "vindimar",
    "vindime": "vindimar",
    "vindimei": "vindimar",
    "vindimeira": "vindimeiro",
    "vindimeiras": "vindimeiro",
    "vindimeiros": "vindimeiro",
    "vindimeis": "vindimar",
    "vindimem": "vindimar",
    "vindimemo": "vindimar",
    "vindimemos": "vindimar",
    "vindimes": "vindimar",
    "vindimo": "vindimar",
    "vindimos": "vindimo",
    "vindimou": "vindimar",
    "vindimá": "vindimar",
    "vindimámo": "vindimar",
    "vindimámos": "vindimar",
    "vindimáramo": "vindimar",
    "vindimáramos": "vindimar",
    "vindimárei": "vindimar",
    "vindimáreis": "vindimar",
    "vindimásseis": "vindimar",
    "vindimássemos": "vindimar",
    "vindimávamo": "vindimar",
    "vindimávamos": "vindimar",
    "vindimávei": "vindimar",
    "vindimáveis": "vindimar",
    "vindique": "vindicar",
    "vindiquei": "vindicar",
    "vindiqueis": "vindicar",
    "vindiquem": "vindicar",
    "vindiquemo": "vindicar",
    "vindiquemos": "vindicar",
    "vindiques": "vindicar",
    "vinditas": "vindita",
    "vindiça": "vindiço",
    "vindiças": "vindiço",
    "vindiços": "vindiço",
    "vindo": "vir",
    "vindoboniana": "vindoboniano",
    "vindobonianas": "vindoboniano",
    "vindobonianos": "vindoboniano",
    "vindoira": "vindoiro",
    "vindoiras": "vindoiro",
    "vindoiros": "vindoiro",
    "vindos": "vir",
    "vindoura": "vindouro",
    "vindouras": "vindouro",
    "vindouros": "vindouro",
    "vindícias": "vindícia",
    "vinga": "vingar",
    "vingada": "vingar",
    "vingadas": "vingar",
    "vingado": "vingar",
    "vingadora": "vingador",
    "vingadoras": "vingador",
    "vingadores": "vingador",
    "vingados": "vingar",
    "vingai": "vingar",
    "vingais": "vingar",
    "vingam": "vingar",
    "vingamo": "vingar",
    "vingamos": "vingar",
    "vingando": "vingar",
    "vinganças": "vingança",
    "vingara": "vingar",
    "vingaram": "vingar",
    "vingaras": "vingar",
    "vingarde": "vingar",
    "vingardes": "vingar",
    "vingare": "vingar",
    "vingarei": "vingar",
    "vingareis": "vingar",
    "vingarem": "vingar",
    "vingaremos": "vingar",
    "vingares": "vingar",
    "vingaria": "vingar",
    "vingariam": "vingar",
    "vingarias": "vingar",
    "vingarmo": "vingar",
    "vingarmos": "vingar",
    "vingará": "vingar",
    "vingarás": "vingar",
    "vingarão": "vingar",
    "vingaríamos": "vingar",
    "vingaríeis": "vingar",
    "vingas": "vingar",
    "vingasse": "vingar",
    "vingassem": "vingar",
    "vingasses": "vingar",
    "vingaste": "vingar",
    "vingastes": "vingar",
    "vingativa": "vingativo",
    "vingativas": "vingativo",
    "vingativos": "vingativo",
    "vingava": "vingar",
    "vingavam": "vingar",
    "vingavas": "vingar",
    "vingações": "vingação",
    "vingo": "vingar",
    "vingou": "vingar",
    "vingue": "vingar",
    "vinguei": "vingar",
    "vingueis": "vingar",
    "vinguem": "vingar",
    "vinguemo": "vingar",
    "vinguemos": "vingar",
    "vingues": "vingue",
    "vingá": "vingar",
    "vingámo": "vingar",
    "vingámos": "vingar",
    "vingáramo": "vingar",
    "vingáramos": "vingar",
    "vingárei": "vingar",
    "vingáreis": "vingar",
    "vingásseis": "vingar",
    "vingássemos": "vingar",
    "vingávamo": "vingar",
    "vingávamos": "vingar",
    "vingávei": "vingar",
    "vingáveis": "vingar",
    "vinha": "vir",
    "vinhadeira": "vinhadeiro",
    "vinhadeiras": "vinhadeiro",
    "vinhadeiros": "vinhadeiro",
    "vinhagens": "vinhagem",
    "vinhagos": "vinhago",
    "vinhais": "vinhal",
    "vinham": "vir",
    "vinhanças": "vinhança",
    "vinharrões": "vinharrão",
    "vinhas": "vir",
    "vinhatarias": "vinhataria",
    "vinhateira": "vinhateiro",
    "vinhateiras": "vinhateiro",
    "vinhateiros": "vinhateiro",
    "vinhaças": "vinhaça",
    "vinhedos": "vinhedo",
    "vinheira": "vinheiro",
    "vinheiras": "vinheiro",
    "vinheiros": "vinheiro",
    "vinhetas": "vinheta",
    "vinhetes": "vinhete",
    "vinhetistas": "vinhetista",
    "vinhinho": "vinho",
    "vinhinhos": "vinho",
    "vinhito": "vinho",
    "vinhitos": "vinho",
    "vinhocas": "vinhoca",
    "vinhos": "vinho",
    "vinhotes": "vinhote",
    "vinhádegos": "vinhádego",
    "vinháticos": "vinhático",
    "vinhões": "vinhão",
    "vinicolorímetros": "vinicolorímetro",
    "vinicultora": "vinicultor",
    "vinicultoras": "vinicultor",
    "vinicultores": "vinicultor",
    "viniculturas": "vinicultura",
    "vinifica": "vinificar",
    "vinificada": "vinificar",
    "vinificadas": "vinificar",
    "vinificado": "vinificar",
    "vinificadors": "vinificador",
    "vinificados": "vinificar",
    "vinificai": "vinificar",
    "vinificais": "vinificar",
    "vinificam": "vinificar",
    "vinificamo": "vinificar",
    "vinificamos": "vinificar",
    "vinificando": "vinificar",
    "vinificara": "vinificar",
    "vinificaram": "vinificar",
    "vinificaras": "vinificar",
    "vinificarde": "vinificar",
    "vinificardes": "vinificar",
    "vinificare": "vinificar",
    "vinificarei": "vinificar",
    "vinificareis": "vinificar",
    "vinificarem": "vinificar",
    "vinificaremos": "vinificar",
    "vinificares": "vinificar",
    "vinificaria": "vinificar",
    "vinificariam": "vinificar",
    "vinificarias": "vinificar",
    "vinificarmo": "vinificar",
    "vinificarmos": "vinificar",
    "vinificará": "vinificar",
    "vinificarás": "vinificar",
    "vinificarão": "vinificar",
    "vinificaríamos": "vinificar",
    "vinificaríeis": "vinificar",
    "vinificas": "vinificar",
    "vinificasse": "vinificar",
    "vinificassem": "vinificar",
    "vinificasses": "vinificar",
    "vinificaste": "vinificar",
    "vinificastes": "vinificar",
    "vinificava": "vinificar",
    "vinificavam": "vinificar",
    "vinificavas": "vinificar",
    "vinificações": "vinificação",
    "vinifico": "vinificar",
    "vinificou": "vinificar",
    "vinificá": "vinificar",
    "vinificámo": "vinificar",
    "vinificámos": "vinificar",
    "vinificáramo": "vinificar",
    "vinificáramos": "vinificar",
    "vinificárei": "vinificar",
    "vinificáreis": "vinificar",
    "vinificásseis": "vinificar",
    "vinificássemos": "vinificar",
    "vinificávamo": "vinificar",
    "vinificávamos": "vinificar",
    "vinificávei": "vinificar",
    "vinificáveis": "vinificar",
    "vinifique": "vinificar",
    "vinifiquei": "vinificar",
    "vinifiqueis": "vinificar",
    "vinifiquem": "vinificar",
    "vinifiquemo": "vinificar",
    "vinifiquemos": "vinificar",
    "vinifiques": "vinificar",
    "vinilos": "vinilo",
    "vinis": "vinil",
    "vinolenta": "vinolento",
    "vinolentas": "vinolento",
    "vinolentos": "vinolento",
    "vinolências": "vinolência",
    "vinosa": "vinoso",
    "vinosas": "vinoso",
    "vinosidades": "vinosidade",
    "vinosos": "vinoso",
    "vinque": "vincar",
    "vinquei": "vincar",
    "vinqueis": "vincar",
    "vinquem": "vincar",
    "vinquemo": "vincar",
    "vinquemos": "vincar",
    "vinques": "vincar",
    "vintavos": "vintavo",
    "vintedozena": "vintedozeno",
    "vintedozenas": "vintedozeno",
    "vintedozenos": "vintedozeno",
    "vintena": "vinteno",
    "vintenas": "vinteno",
    "vintenos": "vinteno",
    "vinteochena": "vinteocheno",
    "vinteochenas": "vinteocheno",
    "vinteochenos": "vinteocheno",
    "vintequatrena": "vintequatreno",
    "vintequatrenas": "vintequatreno",
    "vintequatrenos": "vintequatreno",
    "vintequatrias": "vintequatria",
    "vintismos": "vintismo",
    "vintistas": "vintista",
    "vinténios": "vinténio",
    "vinténs": "vintém",
    "vinácea": "vináceo",
    "vináceas": "vináceo",
    "vináceos": "vináceo",
    "vinária": "vinário",
    "vinárias": "vinário",
    "vinários": "vinário",
    "vinícolas": "vinícola",
    "vinífera": "vinífero",
    "viníferas": "vinífero",
    "viníferos": "vinífero",
    "viola": "violar",
    "violabilidades": "violabilidade",
    "violada": "violar",
    "violadas": "violar",
    "violado": "violar",
    "violadora": "violador",
    "violadoras": "violador",
    "violadores": "violador",
    "violados": "violar",
    "violadíssima": "violado",
    "violadíssimas": "violado",
    "violadíssimo": "violado",
    "violadíssimos": "violado",
    "violai": "violar",
    "violais": "violar",
    "violam": "violar",
    "violamo": "violar",
    "violamos": "violar",
    "violando": "violar",
    "violara": "violar",
    "violaram": "violar",
    "violaras": "violar",
    "violarde": "violar",
    "violardes": "violar",
    "violare": "violar",
    "violarei": "violar",
    "violareis": "violar",
    "violarem": "violar",
    "violaremos": "violar",
    "violares": "violar",
    "violaria": "violar",
    "violariam": "violar",
    "violarias": "violaria",
    "violarmo": "violar",
    "violarmos": "violar",
    "violará": "violar",
    "violarás": "violar",
    "violarão": "violar",
    "violaríamos": "violar",
    "violaríeis": "violar",
    "violas": "violar",
    "violasse": "violar",
    "violassem": "violar",
    "violasses": "violar",
    "violaste": "violar",
    "violastes": "violar",
    "violatória": "violatório",
    "violatórias": "violatório",
    "violatórios": "violatório",
    "violava": "violar",
    "violavam": "violar",
    "violavas": "violar",
    "violações": "violação",
    "viole": "violar",
    "violei": "violar",
    "violeira": "violeiro",
    "violeiras": "violeiro",
    "violeiros": "violeiro",
    "violeis": "violar",
    "violem": "violar",
    "violemo": "violar",
    "violemos": "violar",
    "violenta": "violento",
    "violentada": "violentar",
    "violentadas": "violentar",
    "violentado": "violentar",
    "violentadora": "violentador",
    "violentadoras": "violentador",
    "violentadores": "violentador",
    "violentados": "violentar",
    "violentadíssima": "violentado",
    "violentadíssimas": "violentado",
    "violentadíssimo": "violentado",
    "violentadíssimos": "violentado",
    "violentai": "violentar",
    "violentais": "violentar",
    "violentam": "violentar",
    "violentamo": "violentar",
    "violentamos": "violentar",
    "violentando": "violentar",
    "violentara": "violentar",
    "violentaram": "violentar",
    "violentaras": "violentar",
    "violentarde": "violentar",
    "violentardes": "violentar",
    "violentare": "violentar",
    "violentarei": "violentar",
    "violentareis": "violentar",
    "violentarem": "violentar",
    "violentaremos": "violentar",
    "violentares": "violentar",
    "violentaria": "violentar",
    "violentariam": "violentar",
    "violentarias": "violentar",
    "violentarmo": "violentar",
    "violentarmos": "violentar",
    "violentará": "violentar",
    "violentarás": "violentar",
    "violentarão": "violentar",
    "violentaríamos": "violentar",
    "violentaríeis": "violentar",
    "violentas": "violento",
    "violentasse": "violentar",
    "violentassem": "violentar",
    "violentasses": "violentar",
    "violentaste": "violentar",
    "violentastes": "violentar",
    "violentava": "violentar",
    "violentavam": "violentar",
    "violentavas": "violentar",
    "violentações": "violentação",
    "violente": "violentar",
    "violentei": "violentar",
    "violenteis": "violentar",
    "violentem": "violentar",
    "violentemo": "violentar",
    "violentemos": "violentar",
    "violentes": "violentar",
    "violento": "violentar",
    "violentos": "violento",
    "violentou": "violentar",
    "violentá": "violentar",
    "violentámo": "violentar",
    "violentámos": "violentar",
    "violentáramo": "violentar",
    "violentáramos": "violentar",
    "violentárei": "violentar",
    "violentáreis": "violentar",
    "violentásseis": "violentar",
    "violentássemos": "violentar",
    "violentávamo": "violentar",
    "violentávamos": "violentar",
    "violentávei": "violentar",
    "violentáveis": "violentar",
    "violentíssima": "violento",
    "violentíssimas": "violento",
    "violentíssimo": "violento",
    "violentíssimos": "violento",
    "violes": "violar",
    "violetas": "violeta",
    "violeteiras": "violeteira",
    "violetes": "violete",
    "violetistas": "violetista",
    "violinistas": "violinista",
    "violinos": "violino",
    "violistas": "violista",
    "violo": "violar",
    "violoncelistas": "violoncelista",
    "violoncelos": "violoncelo",
    "violonistas": "violonista",
    "violou": "violar",
    "violá": "violar",
    "violácea": "violáceo",
    "violáceas": "violáceo",
    "violáceos": "violáceo",
    "violámo": "violar",
    "violámos": "violar",
    "violáramo": "violar",
    "violáramos": "violar",
    "violárei": "violar",
    "violáreis": "violar",
    "violásseis": "violar",
    "violássemos": "violar",
    "violávamo": "violar",
    "violávamos": "violar",
    "violávei": "violar",
    "violáveis": "violável",
    "violências": "violência",
    "violões": "violão",
    "viomais": "viomal",
    "viperina": "viperino",
    "viperinas": "viperino",
    "viperinos": "viperino",
    "viperídeos": "viperídeo",
    "vips": "vip",
    "vipéridas": "vipérida",
    "vir": "ver",
    "vira": "virar",
    "virada": "virar",
    "viradas": "virar",
    "viradeiras": "viradeira",
    "viradelas": "viradela",
    "viradinhos": "viradinho",
    "virado": "virar",
    "viradora": "virador",
    "viradoras": "virador",
    "viradores": "virador",
    "virados": "virar",
    "viradíssima": "virado",
    "viradíssimas": "virado",
    "viradíssimo": "virado",
    "viradíssimos": "virado",
    "viragens": "viragem",
    "viragos": "virago",
    "virai": "virar",
    "virais": "virar",
    "viram": "virar",
    "viramentos": "viramento",
    "viramo": "virar",
    "viramos": "virar",
    "virando": "virar",
    "virara": "virar",
    "viraram": "virar",
    "viraras": "virar",
    "virarde": "virar",
    "virardes": "virar",
    "virare": "virar",
    "virarei": "virar",
    "virareis": "virar",
    "virarem": "virar",
    "viraremos": "virar",
    "virares": "virar",
    "viraria": "virar",
    "virariam": "virar",
    "virarias": "virar",
    "virarmo": "virar",
    "virarmos": "virar",
    "virará": "virar",
    "virarás": "virar",
    "virarão": "virar",
    "viraríamos": "virar",
    "viraríeis": "virar",
    "viras": "virar",
    "virasse": "virar",
    "virassem": "virar",
    "virasses": "virar",
    "viraste": "virar",
    "virastes": "virar",
    "virava": "virar",
    "viravam": "virar",
    "viravas": "virar",
    "viravolta": "viravoltar",
    "viravoltada": "viravoltar",
    "viravoltadas": "viravoltar",
    "viravoltado": "viravoltar",
    "viravoltados": "viravoltar",
    "viravoltai": "viravoltar",
    "viravoltais": "viravoltar",
    "viravoltam": "viravoltar",
    "viravoltamo": "viravoltar",
    "viravoltamos": "viravoltar",
    "viravoltando": "viravoltar",
    "viravoltara": "viravoltar",
    "viravoltaram": "viravoltar",
    "viravoltaras": "viravoltar",
    "viravoltardes": "viravoltar",
    "viravoltarei": "viravoltar",
    "viravoltareis": "viravoltar",
    "viravoltarem": "viravoltar",
    "viravoltaremos": "viravoltar",
    "viravoltares": "viravoltar",
    "viravoltaria": "viravoltar",
    "viravoltariam": "viravoltar",
    "viravoltarias": "viravoltar",
    "viravoltarmo": "viravoltar",
    "viravoltarmos": "viravoltar",
    "viravoltará": "viravoltar",
    "viravoltarás": "viravoltar",
    "viravoltarão": "viravoltar",
    "viravoltaríamos": "viravoltar",
    "viravoltaríeis": "viravoltar",
    "viravoltas": "viravoltar",
    "viravoltasse": "viravoltar",
    "viravoltassem": "viravoltar",
    "viravoltasses": "viravoltar",
    "viravoltaste": "viravoltar",
    "viravoltastes": "viravoltar",
    "viravoltava": "viravoltar",
    "viravoltavam": "viravoltar",
    "viravoltavas": "viravoltar",
    "viravolte": "viravoltar",
    "viravoltei": "viravoltar",
    "viravolteis": "viravoltar",
    "viravoltem": "viravoltar",
    "viravoltemo": "viravoltar",
    "viravoltemos": "viravoltar",
    "viravoltes": "viravoltar",
    "viravolto": "viravoltar",
    "viravoltou": "viravoltar",
    "viravoltámo": "viravoltar",
    "viravoltámos": "viravoltar",
    "viravoltáramo": "viravoltar",
    "viravoltáramos": "viravoltar",
    "viravoltáreis": "viravoltar",
    "viravoltásseis": "viravoltar",
    "viravoltássemos": "viravoltar",
    "viravoltávamo": "viravoltar",
    "viravoltávamos": "viravoltar",
    "viravoltáveis": "viravoltar",
    "virações": "viração",
    "virde": "vir",
    "virdes": "vir",
    "vire": "virar",
    "virei": "virar",
    "vireis": "virar",
    "virem": "virar",
    "viremo": "virar",
    "viremos": "virar",
    "virentes": "virente",
    "vires": "virar",
    "virescências": "virescência",
    "virgas": "virga",
    "virgações": "virgação",
    "virgens": "virgem",
    "virginais": "virginal",
    "virginaliza": "virginalizar",
    "virginalizada": "virginalizar",
    "virginalizadas": "virginalizar",
    "virginalizado": "virginalizar",
    "virginalizados": "virginalizar",
    "virginalizai": "virginalizar",
    "virginalizais": "virginalizar",
    "virginalizam": "virginalizar",
    "virginalizamo": "virginalizar",
    "virginalizamos": "virginalizar",
    "virginalizando": "virginalizar",
    "virginalizara": "virginalizar",
    "virginalizaram": "virginalizar",
    "virginalizaras": "virginalizar",
    "virginalizarde": "virginalizar",
    "virginalizardes": "virginalizar",
    "virginalizare": "virginalizar",
    "virginalizarei": "virginalizar",
    "virginalizareis": "virginalizar",
    "virginalizarem": "virginalizar",
    "virginalizaremos": "virginalizar",
    "virginalizares": "virginalizar",
    "virginalizaria": "virginalizar",
    "virginalizariam": "virginalizar",
    "virginalizarias": "virginalizar",
    "virginalizarmo": "virginalizar",
    "virginalizarmos": "virginalizar",
    "virginalizará": "virginalizar",
    "virginalizarás": "virginalizar",
    "virginalizarão": "virginalizar",
    "virginalizaríamos": "virginalizar",
    "virginalizaríeis": "virginalizar",
    "virginalizas": "virginalizar",
    "virginalizasse": "virginalizar",
    "virginalizassem": "virginalizar",
    "virginalizasses": "virginalizar",
    "virginalizaste": "virginalizar",
    "virginalizastes": "virginalizar",
    "virginalizava": "virginalizar",
    "virginalizavam": "virginalizar",
    "virginalizavas": "virginalizar",
    "virginalize": "virginalizar",
    "virginalizei": "virginalizar",
    "virginalizeis": "virginalizar",
    "virginalizem": "virginalizar",
    "virginalizemo": "virginalizar",
    "virginalizemos": "virginalizar",
    "virginalizes": "virginalizar",
    "virginalizo": "virginalizar",
    "virginalizou": "virginalizar",
    "virginalizá": "virginalizar",
    "virginalizámo": "virginalizar",
    "virginalizámos": "virginalizar",
    "virginalizáramo": "virginalizar",
    "virginalizáramos": "virginalizar",
    "virginalizárei": "virginalizar",
    "virginalizáreis": "virginalizar",
    "virginalizásseis": "virginalizar",
    "virginalizássemos": "virginalizar",
    "virginalizávamo": "virginalizar",
    "virginalizávamos": "virginalizar",
    "virginalizávei": "virginalizar",
    "virginalizáveis": "virginalizar",
    "virgindades": "virgindade",
    "virginiza": "virginizar",
    "virginizada": "virginizar",
    "virginizadas": "virginizar",
    "virginizado": "virginizar",
    "virginizados": "virginizar",
    "virginizai": "virginizar",
    "virginizais": "virginizar",
    "virginizam": "virginizar",
    "virginizamo": "virginizar",
    "virginizamos": "virginizar",
    "virginizando": "virginizar",
    "virginizara": "virginizar",
    "virginizaram": "virginizar",
    "virginizaras": "virginizar",
    "virginizarde": "virginizar",
    "virginizardes": "virginizar",
    "virginizare": "virginizar",
    "virginizarei": "virginizar",
    "virginizareis": "virginizar",
    "virginizarem": "virginizar",
    "virginizaremos": "virginizar",
    "virginizares": "virginizar",
    "virginizaria": "virginizar",
    "virginizariam": "virginizar",
    "virginizarias": "virginizar",
    "virginizarmo": "virginizar",
    "virginizarmos": "virginizar",
    "virginizará": "virginizar",
    "virginizarás": "virginizar",
    "virginizarão": "virginizar",
    "virginizaríamos": "virginizar",
    "virginizaríeis": "virginizar",
    "virginizas": "virginizar",
    "virginizasse": "virginizar",
    "virginizassem": "virginizar",
    "virginizasses": "virginizar",
    "virginizaste": "virginizar",
    "virginizastes": "virginizar",
    "virginizava": "virginizar",
    "virginizavam": "virginizar",
    "virginizavas": "virginizar",
    "virginize": "virginizar",
    "virginizei": "virginizar",
    "virginizeis": "virginizar",
    "virginizem": "virginizar",
    "virginizemo": "virginizar",
    "virginizemos": "virginizar",
    "virginizes": "virginizar",
    "virginizo": "virginizar",
    "virginizou": "virginizar",
    "virginizá": "virginizar",
    "virginizámo": "virginizar",
    "virginizámos": "virginizar",
    "virginizáramo": "virginizar",
    "virginizáramos": "virginizar",
    "virginizárei": "virginizar",
    "virginizáreis": "virginizar",
    "virginizásseis": "virginizar",
    "virginizássemos": "virginizar",
    "virginizávamo": "virginizar",
    "virginizávamos": "virginizar",
    "virginizávei": "virginizar",
    "virginizáveis": "virginizar",
    "virglorianos": "virgloriano",
    "virgos": "virgo",
    "virgula": "virgular",
    "virgulada": "virgular",
    "virguladas": "virgular",
    "virgulado": "virgular",
    "virgulados": "virgular",
    "virgulai": "virgular",
    "virgulais": "virgular",
    "virgulam": "virgular",
    "virgulamo": "virgular",
    "virgulamos": "virgular",
    "virgulando": "virgular",
    "virgulara": "virgular",
    "virgularam": "virgular",
    "virgularas": "virgular",
    "virgularde": "virgular",
    "virgulardes": "virgular",
    "virgulare": "virgular",
    "virgularei": "virgular",
    "virgulareis": "virgular",
    "virgularem": "virgular",
    "virgularemos": "virgular",
    "virgulares": "virgular",
    "virgularia": "virgular",
    "virgulariam": "virgular",
    "virgularias": "virgular",
    "virgularmo": "virgular",
    "virgularmos": "virgular",
    "virgulará": "virgular",
    "virgularás": "virgular",
    "virgularão": "virgular",
    "virgularíamos": "virgular",
    "virgularíeis": "virgular",
    "virgulas": "virgular",
    "virgulasse": "virgular",
    "virgulassem": "virgular",
    "virgulasses": "virgular",
    "virgulaste": "virgular",
    "virgulastes": "virgular",
    "virgulava": "virgular",
    "virgulavam": "virgular",
    "virgulavas": "virgular",
    "virgulações": "virgulação",
    "virgule": "virgular",
    "virgulei": "virgular",
    "virguleis": "virgular",
    "virgulem": "virgular",
    "virgulemo": "virgular",
    "virgulemos": "virgular",
    "virgules": "virgular",
    "virgulo": "virgular",
    "virgulosa": "virguloso",
    "virgulosas": "virguloso",
    "virgulosos": "virguloso",
    "virgulou": "virgular",
    "virgultas": "virgulta",
    "virgulá": "virgular",
    "virgulámo": "virgular",
    "virgulámos": "virgular",
    "virguláramo": "virgular",
    "virguláramos": "virgular",
    "virgulárei": "virgular",
    "virguláreis": "virgular",
    "virgulásseis": "virgular",
    "virgulássemos": "virgular",
    "virgulávamo": "virgular",
    "virgulávamos": "virgular",
    "virgulávei": "virgular",
    "virguláveis": "virgular",
    "virgínea": "virgíneo",
    "virgíneas": "virgíneo",
    "virgíneos": "virgíneo",
    "virgínias": "virgínia",
    "viria": "vir",
    "viriam": "vir",
    "virias": "vir",
    "viriculturas": "viricultura",
    "viridentes": "viridente",
    "viridários": "viridário",
    "virilhas": "virilha",
    "virilidades": "virilidade",
    "virilismos": "virilismo",
    "viriliza": "virilizar",
    "virilizada": "virilizar",
    "virilizadas": "virilizar",
    "virilizado": "virilizar",
    "virilizados": "virilizar",
    "virilizai": "virilizar",
    "virilizais": "virilizar",
    "virilizam": "virilizar",
    "virilizamo": "virilizar",
    "virilizamos": "virilizar",
    "virilizando": "virilizar",
    "virilizara": "virilizar",
    "virilizaram": "virilizar",
    "virilizaras": "virilizar",
    "virilizarde": "virilizar",
    "virilizardes": "virilizar",
    "virilizare": "virilizar",
    "virilizarei": "virilizar",
    "virilizareis": "virilizar",
    "virilizarem": "virilizar",
    "virilizaremos": "virilizar",
    "virilizares": "virilizar",
    "virilizaria": "virilizar",
    "virilizariam": "virilizar",
    "virilizarias": "virilizar",
    "virilizarmo": "virilizar",
    "virilizarmos": "virilizar",
    "virilizará": "virilizar",
    "virilizarás": "virilizar",
    "virilizarão": "virilizar",
    "virilizaríamos": "virilizar",
    "virilizaríeis": "virilizar",
    "virilizas": "virilizar",
    "virilizasse": "virilizar",
    "virilizassem": "virilizar",
    "virilizasses": "virilizar",
    "virilizaste": "virilizar",
    "virilizastes": "virilizar",
    "virilizava": "virilizar",
    "virilizavam": "virilizar",
    "virilizavas": "virilizar",
    "virilize": "virilizar",
    "virilizei": "virilizar",
    "virilizeis": "virilizar",
    "virilizem": "virilizar",
    "virilizemo": "virilizar",
    "virilizemos": "virilizar",
    "virilizes": "virilizar",
    "virilizo": "virilizar",
    "virilizou": "virilizar",
    "virilizá": "virilizar",
    "virilizámo": "virilizar",
    "virilizámos": "virilizar",
    "virilizáramo": "virilizar",
    "virilizáramos": "virilizar",
    "virilizárei": "virilizar",
    "virilizáreis": "virilizar",
    "virilizásseis": "virilizar",
    "virilizássemos": "virilizar",
    "virilizávamo": "virilizar",
    "virilizávamos": "virilizar",
    "virilizávei": "virilizar",
    "virilizáveis": "virilizar",
    "viripotentes": "viripotente",
    "viris": "viril",
    "virmo": "vir",
    "virmos": "vir",
    "viro": "virar",
    "virolas": "virola",
    "virologias": "virologia",
    "virológica": "virológico",
    "virológicas": "virológico",
    "virológicos": "virológico",
    "viros": "viro",
    "virosa": "viroso",
    "virosas": "viroso",
    "viroses": "virose",
    "virosos": "viroso",
    "virotadas": "virotada",
    "virotes": "virote",
    "virotões": "virotão",
    "virou": "virar",
    "virtes": "virte",
    "virtiginosa": "virtiginoso",
    "virtiginosas": "virtiginoso",
    "virtiginosos": "virtiginoso",
    "virtuais": "virtual",
    "virtualidades": "virtualidade",
    "virtudes": "virtude",
    "virtuosa": "virtuoso",
    "virtuosas": "virtuoso",
    "virtuosidades": "virtuosidade",
    "virtuosismos": "virtuosismo",
    "virtuosos": "virtuoso",
    "virulenta": "virulento",
    "virulentas": "virulento",
    "virulentos": "virulento",
    "virulências": "virulência",
    "virutas": "viruta",
    "virá": "virar",
    "virámo": "virar",
    "virámos": "virar",
    "viráramo": "virar",
    "viráramos": "virar",
    "virárei": "virar",
    "viráreis": "virar",
    "virás": "vir",
    "virásseis": "virar",
    "virássemos": "virar",
    "virávamo": "virar",
    "virávamos": "virar",
    "virávei": "virar",
    "viráveis": "virar",
    "virão": "vir",
    "viríamos": "vir",
    "viríeis": "vir",
    "vis": "vil",
    "visa": "visar",
    "visada": "visar",
    "visadas": "visar",
    "visado": "visar",
    "visados": "visar",
    "visadíssima": "visado",
    "visadíssimas": "visado",
    "visadíssimo": "visado",
    "visadíssimos": "visado",
    "visagens": "visagem",
    "visai": "visar",
    "visais": "visar",
    "visam": "visar",
    "visamo": "visar",
    "visamos": "visar",
    "visando": "visar",
    "visara": "visar",
    "visaram": "visar",
    "visaras": "visar",
    "visarde": "visar",
    "visardes": "visar",
    "visare": "visar",
    "visarei": "visar",
    "visareis": "visar",
    "visarem": "visar",
    "visaremos": "visar",
    "visares": "visar",
    "visaria": "visar",
    "visariam": "visar",
    "visarias": "visar",
    "visarmo": "visar",
    "visarmos": "visar",
    "visará": "visar",
    "visarás": "visar",
    "visarão": "visar",
    "visaríamos": "visar",
    "visaríeis": "visar",
    "visas": "visar",
    "visasse": "visar",
    "visassem": "visar",
    "visasses": "visar",
    "visaste": "visar",
    "visastes": "visar",
    "visava": "visar",
    "visavam": "visar",
    "visavas": "visar",
    "viscanos": "viscano",
    "viscerais": "visceral",
    "visceralgias": "visceralgia",
    "viscerosa": "visceroso",
    "viscerosas": "visceroso",
    "viscerosos": "visceroso",
    "viscerotomias": "viscerotomia",
    "viscidezes": "viscidez",
    "viscinas": "viscina",
    "viscoelasticidades": "viscoelasticidade",
    "viscoelástica": "viscoelástico",
    "viscoelásticas": "viscoelástico",
    "viscoelásticos": "viscoelástico",
    "viscondados": "viscondado",
    "viscondes": "visconde",
    "viscondessa": "visconde",
    "viscondessas": "visconde",
    "viscondiza": "viscondizar",
    "viscondizada": "viscondizar",
    "viscondizadas": "viscondizar",
    "viscondizado": "viscondizar",
    "viscondizados": "viscondizar",
    "viscondizai": "viscondizar",
    "viscondizais": "viscondizar",
    "viscondizam": "viscondizar",
    "viscondizamo": "viscondizar",
    "viscondizamos": "viscondizar",
    "viscondizando": "viscondizar",
    "viscondizara": "viscondizar",
    "viscondizaram": "viscondizar",
    "viscondizaras": "viscondizar",
    "viscondizarde": "viscondizar",
    "viscondizardes": "viscondizar",
    "viscondizare": "viscondizar",
    "viscondizarei": "viscondizar",
    "viscondizareis": "viscondizar",
    "viscondizarem": "viscondizar",
    "viscondizaremos": "viscondizar",
    "viscondizares": "viscondizar",
    "viscondizaria": "viscondizar",
    "viscondizariam": "viscondizar",
    "viscondizarias": "viscondizar",
    "viscondizarmo": "viscondizar",
    "viscondizarmos": "viscondizar",
    "viscondizará": "viscondizar",
    "viscondizarás": "viscondizar",
    "viscondizarão": "viscondizar",
    "viscondizaríamos": "viscondizar",
    "viscondizaríeis": "viscondizar",
    "viscondizas": "viscondizar",
    "viscondizasse": "viscondizar",
    "viscondizassem": "viscondizar",
    "viscondizasses": "viscondizar",
    "viscondizaste": "viscondizar",
    "viscondizastes": "viscondizar",
    "viscondizava": "viscondizar",
    "viscondizavam": "viscondizar",
    "viscondizavas": "viscondizar",
    "viscondize": "viscondizar",
    "viscondizei": "viscondizar",
    "viscondizeis": "viscondizar",
    "viscondizem": "viscondizar",
    "viscondizemo": "viscondizar",
    "viscondizemos": "viscondizar",
    "viscondizes": "viscondizar",
    "viscondizo": "viscondizar",
    "viscondizou": "viscondizar",
    "viscondizá": "viscondizar",
    "viscondizámo": "viscondizar",
    "viscondizámos": "viscondizar",
    "viscondizáramo": "viscondizar",
    "viscondizáramos": "viscondizar",
    "viscondizárei": "viscondizar",
    "viscondizáreis": "viscondizar",
    "viscondizásseis": "viscondizar",
    "viscondizássemos": "viscondizar",
    "viscondizávamo": "viscondizar",
    "viscondizávamos": "viscondizar",
    "viscondizávei": "viscondizar",
    "viscondizáveis": "viscondizar",
    "viscos": "visco",
    "viscosa": "viscoso",
    "viscosas": "viscoso",
    "viscoses": "viscose",
    "viscosidades": "viscosidade",
    "viscosos": "viscoso",
    "viscosímetros": "viscosímetro",
    "viscosíssima": "viscoso",
    "viscosíssimas": "viscoso",
    "viscosíssimo": "viscoso",
    "viscosíssimos": "viscoso",
    "viscívora": "viscívoro",
    "viscívoras": "viscívoro",
    "viscívoros": "viscívoro",
    "vise": "visar",
    "viseenses": "viseense",
    "visei": "visar",
    "viseiras": "viseira",
    "viseis": "visar",
    "visem": "visar",
    "visemo": "visar",
    "visemos": "visar",
    "vises": "visar",
    "visga": "visgar",
    "visgada": "visgar",
    "visgadas": "visgar",
    "visgado": "visgar",
    "visgados": "visgar",
    "visgai": "visgar",
    "visgais": "visgar",
    "visgam": "visgar",
    "visgamo": "visgar",
    "visgamos": "visgar",
    "visgando": "visgar",
    "visgara": "visgar",
    "visgaram": "visgar",
    "visgaras": "visgar",
    "visgarde": "visgar",
    "visgardes": "visgar",
    "visgare": "visgar",
    "visgarei": "visgar",
    "visgareis": "visgar",
    "visgarem": "visgar",
    "visgaremos": "visgar",
    "visgares": "visgar",
    "visgaria": "visgar",
    "visgariam": "visgar",
    "visgarias": "visgar",
    "visgarmo": "visgar",
    "visgarmos": "visgar",
    "visgará": "visgar",
    "visgarás": "visgar",
    "visgarão": "visgar",
    "visgaríamos": "visgar",
    "visgaríeis": "visgar",
    "visgas": "visgar",
    "visgasse": "visgar",
    "visgassem": "visgar",
    "visgasses": "visgar",
    "visgaste": "visgar",
    "visgastes": "visgar",
    "visgava": "visgar",
    "visgavam": "visgar",
    "visgavas": "visgar",
    "visgo": "visgar",
    "visgos": "visgo",
    "visgou": "visgar",
    "visgue": "visgar",
    "visguei": "visgar",
    "visgueiros": "visgueiro",
    "visgueis": "visgar",
    "visguem": "visgar",
    "visguemo": "visgar",
    "visguemos": "visgar",
    "visguenta": "visguento",
    "visguentas": "visguento",
    "visguentos": "visguento",
    "visgues": "visgar",
    "visgá": "visgar",
    "visgámo": "visgar",
    "visgámos": "visgar",
    "visgáramo": "visgar",
    "visgáramos": "visgar",
    "visgárei": "visgar",
    "visgáreis": "visgar",
    "visgásseis": "visgar",
    "visgássemos": "visgar",
    "visgávamo": "visgar",
    "visgávamos": "visgar",
    "visgávei": "visgar",
    "visgáveis": "visgar",
    "visibilidades": "visibilidade",
    "visigodos": "visigodo",
    "visigótica": "visigótico",
    "visigóticas": "visigótico",
    "visigóticos": "visigótico",
    "visiona": "visionar",
    "visionada": "visionar",
    "visionadas": "visionar",
    "visionado": "visionar",
    "visionados": "visionar",
    "visionai": "visionar",
    "visionais": "visionar",
    "visionam": "visionar",
    "visionamentos": "visionamento",
    "visionamo": "visionar",
    "visionamos": "visionar",
    "visionando": "visionar",
    "visionara": "visionar",
    "visionaram": "visionar",
    "visionaras": "visionar",
    "visionarde": "visionar",
    "visionardes": "visionar",
    "visionare": "visionar",
    "visionarei": "visionar",
    "visionareis": "visionar",
    "visionarem": "visionar",
    "visionaremos": "visionar",
    "visionares": "visionar",
    "visionaria": "visionar",
    "visionariam": "visionar",
    "visionarias": "visionar",
    "visionarmo": "visionar",
    "visionarmos": "visionar",
    "visionará": "visionar",
    "visionarás": "visionar",
    "visionarão": "visionar",
    "visionaríamos": "visionar",
    "visionaríeis": "visionar",
    "visionas": "visionar",
    "visionasse": "visionar",
    "visionassem": "visionar",
    "visionasses": "visionar",
    "visionaste": "visionar",
    "visionastes": "visionar",
    "visionava": "visionar",
    "visionavam": "visionar",
    "visionavas": "visionar",
    "visionações": "visionação",
    "visione": "visionar",
    "visionei": "visionar",
    "visioneis": "visionar",
    "visionem": "visionar",
    "visionemo": "visionar",
    "visionemos": "visionar",
    "visiones": "visionar",
    "visionices": "visionice",
    "visiono": "visionar",
    "visionou": "visionar",
    "visioná": "visionar",
    "visionámo": "visionar",
    "visionámos": "visionar",
    "visionáramo": "visionar",
    "visionáramos": "visionar",
    "visionárei": "visionar",
    "visionáreis": "visionar",
    "visionária": "visionário",
    "visionárias": "visionário",
    "visionários": "visionário",
    "visionásseis": "visionar",
    "visionássemos": "visionar",
    "visionávamo": "visionar",
    "visionávamos": "visionar",
    "visionávei": "visionar",
    "visionáveis": "visionar",
    "visita": "visitar",
    "visitada": "visitar",
    "visitadas": "visitar",
    "visitado": "visitar",
    "visitadora": "visitador",
    "visitadoras": "visitador",
    "visitadores": "visitador",
    "visitados": "visitar",
    "visitai": "visitar",
    "visitais": "visitar",
    "visitam": "visitar",
    "visitamo": "visitar",
    "visitamos": "visitar",
    "visitando": "visitar",
    "visitantes": "visitante",
    "visitara": "visitar",
    "visitaram": "visitar",
    "visitaras": "visitar",
    "visitarde": "visitar",
    "visitardes": "visitar",
    "visitare": "visitar",
    "visitarei": "visitar",
    "visitareis": "visitar",
    "visitarem": "visitar",
    "visitaremos": "visitar",
    "visitares": "visitar",
    "visitaria": "visitar",
    "visitariam": "visitar",
    "visitarias": "visitar",
    "visitarmo": "visitar",
    "visitarmos": "visitar",
    "visitará": "visitar",
    "visitarás": "visitar",
    "visitarão": "visitar",
    "visitaríamos": "visitar",
    "visitaríeis": "visitar",
    "visitas": "visitar",
    "visitasse": "visitar",
    "visitassem": "visitar",
    "visitasses": "visitar",
    "visitaste": "visitar",
    "visitastes": "visitar",
    "visitava": "visitar",
    "visitavam": "visitar",
    "visitavas": "visitar",
    "visitações": "visitação",
    "visite": "visitar",
    "visitei": "visitar",
    "visiteira": "visiteiro",
    "visiteiras": "visiteiro",
    "visiteiros": "visiteiro",
    "visiteis": "visitar",
    "visitem": "visitar",
    "visitemo": "visitar",
    "visitemos": "visitar",
    "visites": "visitar",
    "visitinha": "visita",
    "visitinhas": "visita",
    "visitita": "visita",
    "visititas": "visita",
    "visito": "visitar",
    "visitou": "visitar",
    "visitá": "visitar",
    "visitámo": "visitar",
    "visitámos": "visitar",
    "visitáramo": "visitar",
    "visitáramos": "visitar",
    "visitárei": "visitar",
    "visitáreis": "visitar",
    "visitásseis": "visitar",
    "visitássemos": "visitar",
    "visitávamo": "visitar",
    "visitávamos": "visitar",
    "visitávei": "visitar",
    "visitáveis": "visitável",
    "visivas": "visiva",
    "vislumbra": "vislumbrar",
    "vislumbrada": "vislumbrar",
    "vislumbradas": "vislumbrar",
    "vislumbrado": "vislumbrar",
    "vislumbrados": "vislumbrar",
    "vislumbrai": "vislumbrar",
    "vislumbrais": "vislumbrar",
    "vislumbram": "vislumbrar",
    "vislumbramo": "vislumbrar",
    "vislumbramos": "vislumbrar",
    "vislumbrando": "vislumbrar",
    "vislumbrara": "vislumbrar",
    "vislumbraram": "vislumbrar",
    "vislumbraras": "vislumbrar",
    "vislumbrarde": "vislumbrar",
    "vislumbrardes": "vislumbrar",
    "vislumbrare": "vislumbrar",
    "vislumbrarei": "vislumbrar",
    "vislumbrareis": "vislumbrar",
    "vislumbrarem": "vislumbrar",
    "vislumbraremos": "vislumbrar",
    "vislumbrares": "vislumbrar",
    "vislumbraria": "vislumbrar",
    "vislumbrariam": "vislumbrar",
    "vislumbrarias": "vislumbrar",
    "vislumbrarmo": "vislumbrar",
    "vislumbrarmos": "vislumbrar",
    "vislumbrará": "vislumbrar",
    "vislumbrarás": "vislumbrar",
    "vislumbrarão": "vislumbrar",
    "vislumbraríamos": "vislumbrar",
    "vislumbraríeis": "vislumbrar",
    "vislumbras": "vislumbrar",
    "vislumbrasse": "vislumbrar",
    "vislumbrassem": "vislumbrar",
    "vislumbrasses": "vislumbrar",
    "vislumbraste": "vislumbrar",
    "vislumbrastes": "vislumbrar",
    "vislumbrava": "vislumbrar",
    "vislumbravam": "vislumbrar",
    "vislumbravas": "vislumbrar",
    "vislumbre": "vislumbrar",
    "vislumbrei": "vislumbrar",
    "vislumbreis": "vislumbrar",
    "vislumbrem": "vislumbrar",
    "vislumbremo": "vislumbrar",
    "vislumbremos": "vislumbrar",
    "vislumbres": "vislumbre",
    "vislumbro": "vislumbrar",
    "vislumbrou": "vislumbrar",
    "vislumbrá": "vislumbrar",
    "vislumbrámo": "vislumbrar",
    "vislumbrámos": "vislumbrar",
    "vislumbráramo": "vislumbrar",
    "vislumbráramos": "vislumbrar",
    "vislumbrárei": "vislumbrar",
    "vislumbráreis": "vislumbrar",
    "vislumbrásseis": "vislumbrar",
    "vislumbrássemos": "vislumbrar",
    "vislumbrávamo": "vislumbrar",
    "vislumbrávamos": "vislumbrar",
    "vislumbrávei": "vislumbrar",
    "vislumbráveis": "vislumbrar",
    "viso": "visar",
    "visonhas": "visonha",
    "visores": "visor",
    "visos": "viso",
    "visou": "visar",
    "vispa": "vispar",
    "vispada": "vispar",
    "vispadas": "vispar",
    "vispado": "vispar",
    "vispados": "vispar",
    "vispai": "vispar",
    "vispais": "vispar",
    "vispam": "vispar",
    "vispamo": "vispar",
    "vispamos": "vispar",
    "vispando": "vispar",
    "vispara": "vispar",
    "visparam": "vispar",
    "visparas": "vispar",
    "vispardes": "vispar",
    "visparei": "vispar",
    "vispareis": "vispar",
    "visparem": "vispar",
    "visparemos": "vispar",
    "vispares": "vispar",
    "visparia": "vispar",
    "vispariam": "vispar",
    "visparias": "vispar",
    "visparmo": "vispar",
    "visparmos": "vispar",
    "vispará": "vispar",
    "visparás": "vispar",
    "visparão": "vispar",
    "visparíamos": "vispar",
    "visparíeis": "vispar",
    "vispas": "vispar",
    "vispasse": "vispar",
    "vispassem": "vispar",
    "vispasses": "vispar",
    "vispaste": "vispar",
    "vispastes": "vispar",
    "vispava": "vispar",
    "vispavam": "vispar",
    "vispavas": "vispar",
    "vispe": "vispar",
    "vispei": "vispar",
    "vispeis": "vispar",
    "vispem": "vispar",
    "vispemo": "vispar",
    "vispemos": "vispar",
    "vispes": "vispar",
    "vispo": "vispar",
    "vispou": "vispar",
    "vispámo": "vispar",
    "vispámos": "vispar",
    "vispáramo": "vispar",
    "vispáramos": "vispar",
    "vispáreis": "vispar",
    "vispásseis": "vispar",
    "vispássemos": "vispar",
    "vispávamo": "vispar",
    "vispávamos": "vispar",
    "vispáveis": "vispar",
    "visqueira": "visqueiro",
    "visqueiras": "visqueiro",
    "visqueiros": "visqueiro",
    "visse": "ver",
    "vissem": "ver",
    "visses": "ver",
    "vista": "visto",
    "vistais": "vestir",
    "vistam": "vestir",
    "vistamo": "vestir",
    "vistamos": "vestir",
    "vistas": "visto",
    "viste": "ver",
    "vistes": "ver",
    "visto": "vestir",
    "vistoria": "vistoriar",
    "vistoriada": "vistoriar",
    "vistoriadas": "vistoriar",
    "vistoriado": "vistoriar",
    "vistoriadora": "vistoriador",
    "vistoriadoras": "vistoriador",
    "vistoriadores": "vistoriador",
    "vistoriados": "vistoriar",
    "vistoriai": "vistoriar",
    "vistoriais": "vistoriar",
    "vistoriam": "vistoriar",
    "vistoriamentos": "vistoriamento",
    "vistoriamo": "vistoriar",
    "vistoriamos": "vistoriar",
    "vistoriando": "vistoriar",
    "vistoriara": "vistoriar",
    "vistoriaram": "vistoriar",
    "vistoriaras": "vistoriar",
    "vistoriarde": "vistoriar",
    "vistoriardes": "vistoriar",
    "vistoriare": "vistoriar",
    "vistoriarei": "vistoriar",
    "vistoriareis": "vistoriar",
    "vistoriarem": "vistoriar",
    "vistoriaremos": "vistoriar",
    "vistoriares": "vistoriar",
    "vistoriaria": "vistoriar",
    "vistoriariam": "vistoriar",
    "vistoriarias": "vistoriar",
    "vistoriarmo": "vistoriar",
    "vistoriarmos": "vistoriar",
    "vistoriará": "vistoriar",
    "vistoriarás": "vistoriar",
    "vistoriarão": "vistoriar",
    "vistoriaríamos": "vistoriar",
    "vistoriaríeis": "vistoriar",
    "vistorias": "vistoriar",
    "vistoriasse": "vistoriar",
    "vistoriassem": "vistoriar",
    "vistoriasses": "vistoriar",
    "vistoriaste": "vistoriar",
    "vistoriastes": "vistoriar",
    "vistoriava": "vistoriar",
    "vistoriavam": "vistoriar",
    "vistoriavas": "vistoriar",
    "vistorie": "vistoriar",
    "vistoriei": "vistoriar",
    "vistorieis": "vistoriar",
    "vistoriem": "vistoriar",
    "vistoriemo": "vistoriar",
    "vistoriemos": "vistoriar",
    "vistories": "vistoriar",
    "vistorio": "vistoriar",
    "vistoriou": "vistoriar",
    "vistoriza": "vistorizar",
    "vistorizada": "vistorizar",
    "vistorizadas": "vistorizar",
    "vistorizado": "vistorizar",
    "vistorizados": "vistorizar",
    "vistorizai": "vistorizar",
    "vistorizais": "vistorizar",
    "vistorizam": "vistorizar",
    "vistorizamo": "vistorizar",
    "vistorizamos": "vistorizar",
    "vistorizando": "vistorizar",
    "vistorizara": "vistorizar",
    "vistorizaram": "vistorizar",
    "vistorizaras": "vistorizar",
    "vistorizarde": "vistorizar",
    "vistorizardes": "vistorizar",
    "vistorizare": "vistorizar",
    "vistorizarei": "vistorizar",
    "vistorizareis": "vistorizar",
    "vistorizarem": "vistorizar",
    "vistorizaremos": "vistorizar",
    "vistorizares": "vistorizar",
    "vistorizaria": "vistorizar",
    "vistorizariam": "vistorizar",
    "vistorizarias": "vistorizar",
    "vistorizarmo": "vistorizar",
    "vistorizarmos": "vistorizar",
    "vistorizará": "vistorizar",
    "vistorizarás": "vistorizar",
    "vistorizarão": "vistorizar",
    "vistorizaríamos": "vistorizar",
    "vistorizaríeis": "vistorizar",
    "vistorizas": "vistorizar",
    "vistorizasse": "vistorizar",
    "vistorizassem": "vistorizar",
    "vistorizasses": "vistorizar",
    "vistorizaste": "vistorizar",
    "vistorizastes": "vistorizar",
    "vistorizava": "vistorizar",
    "vistorizavam": "vistorizar",
    "vistorizavas": "vistorizar",
    "vistorize": "vistorizar",
    "vistorizei": "vistorizar",
    "vistorizeis": "vistorizar",
    "vistorizem": "vistorizar",
    "vistorizemo": "vistorizar",
    "vistorizemos": "vistorizar",
    "vistorizes": "vistorizar",
    "vistorizo": "vistorizar",
    "vistorizou": "vistorizar",
    "vistorizá": "vistorizar",
    "vistorizámo": "vistorizar",
    "vistorizámos": "vistorizar",
    "vistorizáramo": "vistorizar",
    "vistorizáramos": "vistorizar",
    "vistorizárei": "vistorizar",
    "vistorizáreis": "vistorizar",
    "vistorizásseis": "vistorizar",
    "vistorizássemos": "vistorizar",
    "vistorizávamo": "vistorizar",
    "vistorizávamos": "vistorizar",
    "vistorizávei": "vistorizar",
    "vistorizáveis": "vistorizar",
    "vistoriá": "vistoriar",
    "vistoriámo": "vistoriar",
    "vistoriámos": "vistoriar",
    "vistoriáramo": "vistoriar",
    "vistoriáramos": "vistoriar",
    "vistoriárei": "vistoriar",
    "vistoriáreis": "vistoriar",
    "vistoriásseis": "vistoriar",
    "vistoriássemos": "vistoriar",
    "vistoriávamo": "vistoriar",
    "vistoriávamos": "vistoriar",
    "vistoriávei": "vistoriar",
    "vistoriáveis": "vistoriar",
    "vistos": "visto",
    "vistosa": "vistoso",
    "vistosas": "vistoso",
    "vistosos": "vistoso",
    "vistosíssima": "vistoso",
    "vistosíssimas": "vistoso",
    "vistosíssimo": "vistoso",
    "vistosíssimos": "vistoso",
    "vistíssima": "visto",
    "vistíssimas": "visto",
    "vistíssimo": "visto",
    "vistíssimos": "visto",
    "vistões": "vistão",
    "visuais": "visual",
    "visualidades": "visualidade",
    "visualiza": "visualizar",
    "visualizada": "visualizar",
    "visualizadas": "visualizar",
    "visualizado": "visualizar",
    "visualizados": "visualizar",
    "visualizai": "visualizar",
    "visualizais": "visualizar",
    "visualizam": "visualizar",
    "visualizamo": "visualizar",
    "visualizamos": "visualizar",
    "visualizando": "visualizar",
    "visualizara": "visualizar",
    "visualizaram": "visualizar",
    "visualizaras": "visualizar",
    "visualizarde": "visualizar",
    "visualizardes": "visualizar",
    "visualizare": "visualizar",
    "visualizarei": "visualizar",
    "visualizareis": "visualizar",
    "visualizarem": "visualizar",
    "visualizaremos": "visualizar",
    "visualizares": "visualizar",
    "visualizaria": "visualizar",
    "visualizariam": "visualizar",
    "visualizarias": "visualizar",
    "visualizarmo": "visualizar",
    "visualizarmos": "visualizar",
    "visualizará": "visualizar",
    "visualizarás": "visualizar",
    "visualizarão": "visualizar",
    "visualizaríamos": "visualizar",
    "visualizaríeis": "visualizar",
    "visualizas": "visualizar",
    "visualizasse": "visualizar",
    "visualizassem": "visualizar",
    "visualizasses": "visualizar",
    "visualizaste": "visualizar",
    "visualizastes": "visualizar",
    "visualizava": "visualizar",
    "visualizavam": "visualizar",
    "visualizavas": "visualizar",
    "visualizações": "visualização",
    "visualize": "visualizar",
    "visualizei": "visualizar",
    "visualizeis": "visualizar",
    "visualizem": "visualizar",
    "visualizemo": "visualizar",
    "visualizemos": "visualizar",
    "visualizes": "visualizar",
    "visualizo": "visualizar",
    "visualizou": "visualizar",
    "visualizá": "visualizar",
    "visualizámo": "visualizar",
    "visualizámos": "visualizar",
    "visualizáramo": "visualizar",
    "visualizáramos": "visualizar",
    "visualizárei": "visualizar",
    "visualizáreis": "visualizar",
    "visualizásseis": "visualizar",
    "visualizássemos": "visualizar",
    "visualizávamo": "visualizar",
    "visualizávamos": "visualizar",
    "visualizávei": "visualizar",
    "visualizáveis": "visualizável",
    "visá": "visar",
    "visámo": "visar",
    "visámos": "visar",
    "visáramo": "visar",
    "visáramos": "visar",
    "visárei": "visar",
    "visáreis": "visar",
    "visásseis": "visar",
    "visássemos": "visar",
    "visávamo": "visar",
    "visávamos": "visar",
    "visávei": "visar",
    "visáveis": "visar",
    "visíveis": "visível",
    "visória": "visório",
    "visórias": "visório",
    "visórios": "visório",
    "visões": "visão",
    "vitais": "vital",
    "vitalidades": "vitalidade",
    "vitalismos": "vitalismo",
    "vitalistas": "vitalista",
    "vitaliza": "vitalizar",
    "vitalizada": "vitalizar",
    "vitalizadas": "vitalizar",
    "vitalizado": "vitalizar",
    "vitalizadora": "vitalizador",
    "vitalizadoras": "vitalizador",
    "vitalizadores": "vitalizador",
    "vitalizados": "vitalizar",
    "vitalizai": "vitalizar",
    "vitalizais": "vitalizar",
    "vitalizam": "vitalizar",
    "vitalizamo": "vitalizar",
    "vitalizamos": "vitalizar",
    "vitalizando": "vitalizar",
    "vitalizantes": "vitalizante",
    "vitalizara": "vitalizar",
    "vitalizaram": "vitalizar",
    "vitalizaras": "vitalizar",
    "vitalizarde": "vitalizar",
    "vitalizardes": "vitalizar",
    "vitalizare": "vitalizar",
    "vitalizarei": "vitalizar",
    "vitalizareis": "vitalizar",
    "vitalizarem": "vitalizar",
    "vitalizaremos": "vitalizar",
    "vitalizares": "vitalizar",
    "vitalizaria": "vitalizar",
    "vitalizariam": "vitalizar",
    "vitalizarias": "vitalizar",
    "vitalizarmo": "vitalizar",
    "vitalizarmos": "vitalizar",
    "vitalizará": "vitalizar",
    "vitalizarás": "vitalizar",
    "vitalizarão": "vitalizar",
    "vitalizaríamos": "vitalizar",
    "vitalizaríeis": "vitalizar",
    "vitalizas": "vitalizar",
    "vitalizasse": "vitalizar",
    "vitalizassem": "vitalizar",
    "vitalizasses": "vitalizar",
    "vitalizaste": "vitalizar",
    "vitalizastes": "vitalizar",
    "vitalizava": "vitalizar",
    "vitalizavam": "vitalizar",
    "vitalizavas": "vitalizar",
    "vitalizações": "vitalização",
    "vitalize": "vitalizar",
    "vitalizei": "vitalizar",
    "vitalizeis": "vitalizar",
    "vitalizem": "vitalizar",
    "vitalizemo": "vitalizar",
    "vitalizemos": "vitalizar",
    "vitalizes": "vitalizar",
    "vitalizo": "vitalizar",
    "vitalizou": "vitalizar",
    "vitalizá": "vitalizar",
    "vitalizámo": "vitalizar",
    "vitalizámos": "vitalizar",
    "vitalizáramo": "vitalizar",
    "vitalizáramos": "vitalizar",
    "vitalizárei": "vitalizar",
    "vitalizáreis": "vitalizar",
    "vitalizásseis": "vitalizar",
    "vitalizássemos": "vitalizar",
    "vitalizávamo": "vitalizar",
    "vitalizávamos": "vitalizar",
    "vitalizávei": "vitalizar",
    "vitalizáveis": "vitalizar",
    "vitalícia": "vitalício",
    "vitalícias": "vitalício",
    "vitalícios": "vitalício",
    "vitamina": "vitaminar",
    "vitaminada": "vitaminar",
    "vitaminadas": "vitaminar",
    "vitaminado": "vitaminar",
    "vitaminados": "vitaminar",
    "vitaminai": "vitaminar",
    "vitaminais": "vitaminar",
    "vitaminam": "vitaminar",
    "vitaminamo": "vitaminar",
    "vitaminamos": "vitaminar",
    "vitaminando": "vitaminar",
    "vitaminara": "vitaminar",
    "vitaminaram": "vitaminar",
    "vitaminaras": "vitaminar",
    "vitaminarde": "vitaminar",
    "vitaminardes": "vitaminar",
    "vitaminare": "vitaminar",
    "vitaminarei": "vitaminar",
    "vitaminareis": "vitaminar",
    "vitaminarem": "vitaminar",
    "vitaminaremos": "vitaminar",
    "vitaminares": "vitaminar",
    "vitaminaria": "vitaminar",
    "vitaminariam": "vitaminar",
    "vitaminarias": "vitaminar",
    "vitaminarmo": "vitaminar",
    "vitaminarmos": "vitaminar",
    "vitaminará": "vitaminar",
    "vitaminarás": "vitaminar",
    "vitaminarão": "vitaminar",
    "vitaminaríamos": "vitaminar",
    "vitaminaríeis": "vitaminar",
    "vitaminas": "vitaminar",
    "vitaminasse": "vitaminar",
    "vitaminassem": "vitaminar",
    "vitaminasses": "vitaminar",
    "vitaminaste": "vitaminar",
    "vitaminastes": "vitaminar",
    "vitaminava": "vitaminar",
    "vitaminavam": "vitaminar",
    "vitaminavas": "vitaminar",
    "vitaminações": "vitaminação",
    "vitamine": "vitaminar",
    "vitaminei": "vitaminar",
    "vitamineis": "vitaminar",
    "vitaminem": "vitaminar",
    "vitaminemo": "vitaminar",
    "vitaminemos": "vitaminar",
    "vitamines": "vitaminar",
    "vitaminiza": "vitaminizar",
    "vitaminizada": "vitaminizar",
    "vitaminizadas": "vitaminizar",
    "vitaminizado": "vitaminizar",
    "vitaminizados": "vitaminizar",
    "vitaminizai": "vitaminizar",
    "vitaminizais": "vitaminizar",
    "vitaminizam": "vitaminizar",
    "vitaminizamo": "vitaminizar",
    "vitaminizamos": "vitaminizar",
    "vitaminizando": "vitaminizar",
    "vitaminizara": "vitaminizar",
    "vitaminizaram": "vitaminizar",
    "vitaminizaras": "vitaminizar",
    "vitaminizarde": "vitaminizar",
    "vitaminizardes": "vitaminizar",
    "vitaminizare": "vitaminizar",
    "vitaminizarei": "vitaminizar",
    "vitaminizareis": "vitaminizar",
    "vitaminizarem": "vitaminizar",
    "vitaminizaremos": "vitaminizar",
    "vitaminizares": "vitaminizar",
    "vitaminizaria": "vitaminizar",
    "vitaminizariam": "vitaminizar",
    "vitaminizarias": "vitaminizar",
    "vitaminizarmo": "vitaminizar",
    "vitaminizarmos": "vitaminizar",
    "vitaminizará": "vitaminizar",
    "vitaminizarás": "vitaminizar",
    "vitaminizarão": "vitaminizar",
    "vitaminizaríamos": "vitaminizar",
    "vitaminizaríeis": "vitaminizar",
    "vitaminizas": "vitaminizar",
    "vitaminizasse": "vitaminizar",
    "vitaminizassem": "vitaminizar",
    "vitaminizasses": "vitaminizar",
    "vitaminizaste": "vitaminizar",
    "vitaminizastes": "vitaminizar",
    "vitaminizava": "vitaminizar",
    "vitaminizavam": "vitaminizar",
    "vitaminizavas": "vitaminizar",
    "vitaminize": "vitaminizar",
    "vitaminizei": "vitaminizar",
    "vitaminizeis": "vitaminizar",
    "vitaminizem": "vitaminizar",
    "vitaminizemo": "vitaminizar",
    "vitaminizemos": "vitaminizar",
    "vitaminizes": "vitaminizar",
    "vitaminizo": "vitaminizar",
    "vitaminizou": "vitaminizar",
    "vitaminizá": "vitaminizar",
    "vitaminizámo": "vitaminizar",
    "vitaminizámos": "vitaminizar",
    "vitaminizáramo": "vitaminizar",
    "vitaminizáramos": "vitaminizar",
    "vitaminizárei": "vitaminizar",
    "vitaminizáreis": "vitaminizar",
    "vitaminizásseis": "vitaminizar",
    "vitaminizássemos": "vitaminizar",
    "vitaminizávamo": "vitaminizar",
    "vitaminizávamos": "vitaminizar",
    "vitaminizávei": "vitaminizar",
    "vitaminizáveis": "vitaminizar",
    "vitamino": "vitaminar",
    "vitaminoses": "vitaminose",
    "vitaminoterapias": "vitaminoterapia",
    "vitaminou": "vitaminar",
    "vitaminá": "vitaminar",
    "vitaminámo": "vitaminar",
    "vitaminámos": "vitaminar",
    "vitamináramo": "vitaminar",
    "vitamináramos": "vitaminar",
    "vitaminárei": "vitaminar",
    "vitamináreis": "vitaminar",
    "vitaminásseis": "vitaminar",
    "vitaminássemos": "vitaminar",
    "vitaminávamo": "vitaminar",
    "vitaminávamos": "vitaminar",
    "vitaminávei": "vitaminar",
    "vitamináveis": "vitaminar",
    "vitanda": "vitando",
    "vitandas": "vitando",
    "vitandos": "vitando",
    "vitatória": "vitatório",
    "vitatórias": "vitatório",
    "vitatórios": "vitatório",
    "vitela": "vitelo",
    "vitelas": "vitelo",
    "viteleira": "viteleiro",
    "viteleiras": "viteleiro",
    "viteleiros": "viteleiro",
    "viteliductos": "viteliducto",
    "vitelina": "vitelino",
    "vitelinas": "vitelino",
    "vitelinos": "vitelino",
    "viteloductos": "viteloducto",
    "vitelogénea": "vitelogéneo",
    "vitelogéneas": "vitelogéneo",
    "vitelogéneos": "vitelogéneo",
    "vitelogéneses": "vitelogénese",
    "vitelos": "vitelo",
    "vitelífera": "vitelífero",
    "vitelíferas": "vitelífero",
    "vitelíferos": "vitelífero",
    "viticomada": "viticomado",
    "viticomadas": "viticomado",
    "viticomados": "viticomado",
    "viticultora": "viticultor",
    "viticultoras": "viticultor",
    "viticultores": "viticultor",
    "viticulturas": "viticultura",
    "vitiligens": "vitiligem",
    "vitiligos": "vitiligo",
    "vitima": "vitimar",
    "vitimada": "vitimar",
    "vitimadas": "vitimar",
    "vitimado": "vitimar",
    "vitimadores": "vitimador",
    "vitimados": "vitimar",
    "vitimai": "vitimar",
    "vitimais": "vitimar",
    "vitimam": "vitimar",
    "vitimamo": "vitimar",
    "vitimamos": "vitimar",
    "vitimando": "vitimar",
    "vitimara": "vitimar",
    "vitimaram": "vitimar",
    "vitimaras": "vitimar",
    "vitimarde": "vitimar",
    "vitimardes": "vitimar",
    "vitimare": "vitimar",
    "vitimarei": "vitimar",
    "vitimareis": "vitimar",
    "vitimarem": "vitimar",
    "vitimaremos": "vitimar",
    "vitimares": "vitimar",
    "vitimaria": "vitimar",
    "vitimariam": "vitimar",
    "vitimarias": "vitimar",
    "vitimarmo": "vitimar",
    "vitimarmos": "vitimar",
    "vitimará": "vitimar",
    "vitimarás": "vitimar",
    "vitimarão": "vitimar",
    "vitimaríamos": "vitimar",
    "vitimaríeis": "vitimar",
    "vitimas": "vitimar",
    "vitimasse": "vitimar",
    "vitimassem": "vitimar",
    "vitimasses": "vitimar",
    "vitimaste": "vitimar",
    "vitimastes": "vitimar",
    "vitimava": "vitimar",
    "vitimavam": "vitimar",
    "vitimavas": "vitimar",
    "vitimações": "vitimação",
    "vitime": "vitimar",
    "vitimei": "vitimar",
    "vitimeis": "vitimar",
    "vitimem": "vitimar",
    "vitimemo": "vitimar",
    "vitimemos": "vitimar",
    "vitimes": "vitimar",
    "vitimizações": "vitimização",
    "vitimo": "vitimar",
    "vitimou": "vitimar",
    "vitimá": "vitimar",
    "vitimámo": "vitimar",
    "vitimámos": "vitimar",
    "vitimáramo": "vitimar",
    "vitimáramos": "vitimar",
    "vitimárei": "vitimar",
    "vitimáreis": "vitimar",
    "vitimários": "vitimário",
    "vitimásseis": "vitimar",
    "vitimássemos": "vitimar",
    "vitimávamo": "vitimar",
    "vitimávamos": "vitimar",
    "vitimávei": "vitimar",
    "vitimáveis": "vitimar",
    "vitingas": "vitinga",
    "vitivinicultora": "vitivinicultor",
    "vitivinicultoras": "vitivinicultor",
    "vitivinicultores": "vitivinicultor",
    "vitiviniculturas": "vitivinicultura",
    "vitivinícolas": "vitivinícola",
    "vitoria": "vitoriar",
    "vitoriada": "vitoriar",
    "vitoriadas": "vitoriar",
    "vitoriado": "vitoriar",
    "vitoriados": "vitoriar",
    "vitoriai": "vitoriar",
    "vitoriais": "vitoriar",
    "vitoriam": "vitoriar",
    "vitoriamo": "vitoriar",
    "vitoriamos": "vitoriar",
    "vitoriana": "vitoriano",
    "vitorianas": "vitoriano",
    "vitoriando": "vitoriar",
    "vitorianos": "vitoriano",
    "vitoriara": "vitoriar",
    "vitoriaram": "vitoriar",
    "vitoriaras": "vitoriar",
    "vitoriarde": "vitoriar",
    "vitoriardes": "vitoriar",
    "vitoriare": "vitoriar",
    "vitoriarei": "vitoriar",
    "vitoriareis": "vitoriar",
    "vitoriarem": "vitoriar",
    "vitoriaremos": "vitoriar",
    "vitoriares": "vitoriar",
    "vitoriaria": "vitoriar",
    "vitoriariam": "vitoriar",
    "vitoriarias": "vitoriar",
    "vitoriarmo": "vitoriar",
    "vitoriarmos": "vitoriar",
    "vitoriará": "vitoriar",
    "vitoriarás": "vitoriar",
    "vitoriarão": "vitoriar",
    "vitoriaríamos": "vitoriar",
    "vitoriaríeis": "vitoriar",
    "vitorias": "vitoriar",
    "vitoriasse": "vitoriar",
    "vitoriassem": "vitoriar",
    "vitoriasses": "vitoriar",
    "vitoriaste": "vitoriar",
    "vitoriastes": "vitoriar",
    "vitoriava": "vitoriar",
    "vitoriavam": "vitoriar",
    "vitoriavas": "vitoriar",
    "vitorie": "vitoriar",
    "vitoriei": "vitoriar",
    "vitorieis": "vitoriar",
    "vitoriem": "vitoriar",
    "vitoriemo": "vitoriar",
    "vitoriemos": "vitoriar",
    "vitorienses": "vitoriense",
    "vitories": "vitoriar",
    "vitorio": "vitoriar",
    "vitoriosa": "vitorioso",
    "vitoriosas": "vitorioso",
    "vitoriosos": "vitorioso",
    "vitoriou": "vitoriar",
    "vitoriá": "vitoriar",
    "vitoriámo": "vitoriar",
    "vitoriámos": "vitoriar",
    "vitoriáramo": "vitoriar",
    "vitoriáramos": "vitoriar",
    "vitoriárei": "vitoriar",
    "vitoriáreis": "vitoriar",
    "vitoriásseis": "vitoriar",
    "vitoriássemos": "vitoriar",
    "vitoriávamo": "vitoriar",
    "vitoriávamos": "vitoriar",
    "vitoriávei": "vitoriar",
    "vitoriáveis": "vitoriar",
    "vitrais": "vitral",
    "vitraleira": "vitraleiro",
    "vitraleiras": "vitraleiro",
    "vitraleiros": "vitraleiro",
    "vitraliza": "vitralizar",
    "vitralizada": "vitralizar",
    "vitralizadas": "vitralizar",
    "vitralizado": "vitralizar",
    "vitralizados": "vitralizar",
    "vitralizai": "vitralizar",
    "vitralizais": "vitralizar",
    "vitralizam": "vitralizar",
    "vitralizamo": "vitralizar",
    "vitralizamos": "vitralizar",
    "vitralizando": "vitralizar",
    "vitralizara": "vitralizar",
    "vitralizaram": "vitralizar",
    "vitralizaras": "vitralizar",
    "vitralizarde": "vitralizar",
    "vitralizardes": "vitralizar",
    "vitralizare": "vitralizar",
    "vitralizarei": "vitralizar",
    "vitralizareis": "vitralizar",
    "vitralizarem": "vitralizar",
    "vitralizaremos": "vitralizar",
    "vitralizares": "vitralizar",
    "vitralizaria": "vitralizar",
    "vitralizariam": "vitralizar",
    "vitralizarias": "vitralizar",
    "vitralizarmo": "vitralizar",
    "vitralizarmos": "vitralizar",
    "vitralizará": "vitralizar",
    "vitralizarás": "vitralizar",
    "vitralizarão": "vitralizar",
    "vitralizaríamos": "vitralizar",
    "vitralizaríeis": "vitralizar",
    "vitralizas": "vitralizar",
    "vitralizasse": "vitralizar",
    "vitralizassem": "vitralizar",
    "vitralizasses": "vitralizar",
    "vitralizaste": "vitralizar",
    "vitralizastes": "vitralizar",
    "vitralizava": "vitralizar",
    "vitralizavam": "vitralizar",
    "vitralizavas": "vitralizar",
    "vitralize": "vitralizar",
    "vitralizei": "vitralizar",
    "vitralizeis": "vitralizar",
    "vitralizem": "vitralizar",
    "vitralizemo": "vitralizar",
    "vitralizemos": "vitralizar",
    "vitralizes": "vitralizar",
    "vitralizo": "vitralizar",
    "vitralizou": "vitralizar",
    "vitralizá": "vitralizar",
    "vitralizámo": "vitralizar",
    "vitralizámos": "vitralizar",
    "vitralizáramo": "vitralizar",
    "vitralizáramos": "vitralizar",
    "vitralizárei": "vitralizar",
    "vitralizáreis": "vitralizar",
    "vitralizásseis": "vitralizar",
    "vitralizássemos": "vitralizar",
    "vitralizávamo": "vitralizar",
    "vitralizávamos": "vitralizar",
    "vitralizávei": "vitralizar",
    "vitralizáveis": "vitralizar",
    "vitres": "vitre",
    "vitrescibilidades": "vitrescibilidade",
    "vitrescíveis": "vitrescível",
    "vitrifica": "vitrificar",
    "vitrificada": "vitrificar",
    "vitrificadas": "vitrificar",
    "vitrificado": "vitrificar",
    "vitrificados": "vitrificar",
    "vitrificai": "vitrificar",
    "vitrificais": "vitrificar",
    "vitrificam": "vitrificar",
    "vitrificamo": "vitrificar",
    "vitrificamos": "vitrificar",
    "vitrificando": "vitrificar",
    "vitrificara": "vitrificar",
    "vitrificaram": "vitrificar",
    "vitrificaras": "vitrificar",
    "vitrificarde": "vitrificar",
    "vitrificardes": "vitrificar",
    "vitrificare": "vitrificar",
    "vitrificarei": "vitrificar",
    "vitrificareis": "vitrificar",
    "vitrificarem": "vitrificar",
    "vitrificaremos": "vitrificar",
    "vitrificares": "vitrificar",
    "vitrificaria": "vitrificar",
    "vitrificariam": "vitrificar",
    "vitrificarias": "vitrificar",
    "vitrificarmo": "vitrificar",
    "vitrificarmos": "vitrificar",
    "vitrificará": "vitrificar",
    "vitrificarás": "vitrificar",
    "vitrificarão": "vitrificar",
    "vitrificaríamos": "vitrificar",
    "vitrificaríeis": "vitrificar",
    "vitrificas": "vitrificar",
    "vitrificasse": "vitrificar",
    "vitrificassem": "vitrificar",
    "vitrificasses": "vitrificar",
    "vitrificaste": "vitrificar",
    "vitrificastes": "vitrificar",
    "vitrificava": "vitrificar",
    "vitrificavam": "vitrificar",
    "vitrificavas": "vitrificar",
    "vitrificações": "vitrificação",
    "vitrifico": "vitrificar",
    "vitrificou": "vitrificar",
    "vitrificá": "vitrificar",
    "vitrificámo": "vitrificar",
    "vitrificámos": "vitrificar",
    "vitrificáramo": "vitrificar",
    "vitrificáramos": "vitrificar",
    "vitrificárei": "vitrificar",
    "vitrificáreis": "vitrificar",
    "vitrificásseis": "vitrificar",
    "vitrificássemos": "vitrificar",
    "vitrificávamo": "vitrificar",
    "vitrificávamos": "vitrificar",
    "vitrificávei": "vitrificar",
    "vitrificáveis": "vitrificável",
    "vitrifique": "vitrificar",
    "vitrifiquei": "vitrificar",
    "vitrifiqueis": "vitrificar",
    "vitrifiquem": "vitrificar",
    "vitrifiquemo": "vitrificar",
    "vitrifiquemos": "vitrificar",
    "vitrifiques": "vitrificar",
    "vitrinas": "vitrina",
    "vitriolada": "vitriolado",
    "vitrioladas": "vitriolado",
    "vitriolados": "vitriolado",
    "vitrioliza": "vitriolizar",
    "vitriolizada": "vitriolizar",
    "vitriolizadas": "vitriolizar",
    "vitriolizado": "vitriolizar",
    "vitriolizados": "vitriolizar",
    "vitriolizai": "vitriolizar",
    "vitriolizais": "vitriolizar",
    "vitriolizam": "vitriolizar",
    "vitriolizamo": "vitriolizar",
    "vitriolizamos": "vitriolizar",
    "vitriolizando": "vitriolizar",
    "vitriolizara": "vitriolizar",
    "vitriolizaram": "vitriolizar",
    "vitriolizaras": "vitriolizar",
    "vitriolizarde": "vitriolizar",
    "vitriolizardes": "vitriolizar",
    "vitriolizare": "vitriolizar",
    "vitriolizarei": "vitriolizar",
    "vitriolizareis": "vitriolizar",
    "vitriolizarem": "vitriolizar",
    "vitriolizaremos": "vitriolizar",
    "vitriolizares": "vitriolizar",
    "vitriolizaria": "vitriolizar",
    "vitriolizariam": "vitriolizar",
    "vitriolizarias": "vitriolizar",
    "vitriolizarmo": "vitriolizar",
    "vitriolizarmos": "vitriolizar",
    "vitriolizará": "vitriolizar",
    "vitriolizarás": "vitriolizar",
    "vitriolizarão": "vitriolizar",
    "vitriolizaríamos": "vitriolizar",
    "vitriolizaríeis": "vitriolizar",
    "vitriolizas": "vitriolizar",
    "vitriolizasse": "vitriolizar",
    "vitriolizassem": "vitriolizar",
    "vitriolizasses": "vitriolizar",
    "vitriolizaste": "vitriolizar",
    "vitriolizastes": "vitriolizar",
    "vitriolizava": "vitriolizar",
    "vitriolizavam": "vitriolizar",
    "vitriolizavas": "vitriolizar",
    "vitriolizações": "vitriolização",
    "vitriolize": "vitriolizar",
    "vitriolizei": "vitriolizar",
    "vitriolizeis": "vitriolizar",
    "vitriolizem": "vitriolizar",
    "vitriolizemo": "vitriolizar",
    "vitriolizemos": "vitriolizar",
    "vitriolizes": "vitriolizar",
    "vitriolizo": "vitriolizar",
    "vitriolizou": "vitriolizar",
    "vitriolizá": "vitriolizar",
    "vitriolizámo": "vitriolizar",
    "vitriolizámos": "vitriolizar",
    "vitriolizáramo": "vitriolizar",
    "vitriolizáramos": "vitriolizar",
    "vitriolizárei": "vitriolizar",
    "vitriolizáreis": "vitriolizar",
    "vitriolizásseis": "vitriolizar",
    "vitriolizássemos": "vitriolizar",
    "vitriolizávamo": "vitriolizar",
    "vitriolizávamos": "vitriolizar",
    "vitriolizávei": "vitriolizar",
    "vitriolizáveis": "vitriolizar",
    "vitripenes": "vitripene",
    "vitriólica": "vitriólico",
    "vitriólicas": "vitriólico",
    "vitriólicos": "vitriólico",
    "vitríolos": "vitríolo",
    "vitualha": "vitualhar",
    "vitualhada": "vitualhar",
    "vitualhadas": "vitualhar",
    "vitualhado": "vitualhar",
    "vitualhados": "vitualhar",
    "vitualhai": "vitualhar",
    "vitualhais": "vitualhar",
    "vitualham": "vitualhar",
    "vitualhamo": "vitualhar",
    "vitualhamos": "vitualhar",
    "vitualhando": "vitualhar",
    "vitualhara": "vitualhar",
    "vitualharam": "vitualhar",
    "vitualharas": "vitualhar",
    "vitualharde": "vitualhar",
    "vitualhardes": "vitualhar",
    "vitualhare": "vitualhar",
    "vitualharei": "vitualhar",
    "vitualhareis": "vitualhar",
    "vitualharem": "vitualhar",
    "vitualharemos": "vitualhar",
    "vitualhares": "vitualhar",
    "vitualharia": "vitualhar",
    "vitualhariam": "vitualhar",
    "vitualharias": "vitualhar",
    "vitualharmo": "vitualhar",
    "vitualharmos": "vitualhar",
    "vitualhará": "vitualhar",
    "vitualharás": "vitualhar",
    "vitualharão": "vitualhar",
    "vitualharíamos": "vitualhar",
    "vitualharíeis": "vitualhar",
    "vitualhas": "vitualhar",
    "vitualhasse": "vitualhar",
    "vitualhassem": "vitualhar",
    "vitualhasses": "vitualhar",
    "vitualhaste": "vitualhar",
    "vitualhastes": "vitualhar",
    "vitualhava": "vitualhar",
    "vitualhavam": "vitualhar",
    "vitualhavas": "vitualhar",
    "vitualhe": "vitualhar",
    "vitualhei": "vitualhar",
    "vitualheis": "vitualhar",
    "vitualhem": "vitualhar",
    "vitualhemo": "vitualhar",
    "vitualhemos": "vitualhar",
    "vitualhes": "vitualhar",
    "vitualho": "vitualhar",
    "vitualhou": "vitualhar",
    "vitualhá": "vitualhar",
    "vitualhámo": "vitualhar",
    "vitualhámos": "vitualhar",
    "vitualháramo": "vitualhar",
    "vitualháramos": "vitualhar",
    "vitualhárei": "vitualhar",
    "vitualháreis": "vitualhar",
    "vitualhásseis": "vitualhar",
    "vitualhássemos": "vitualhar",
    "vitualhávamo": "vitualhar",
    "vitualhávamos": "vitualhar",
    "vitualhávei": "vitualhar",
    "vitualháveis": "vitualhar",
    "vitupera": "vituperar",
    "vituperada": "vituperar",
    "vituperadas": "vituperar",
    "vituperado": "vituperar",
    "vituperadora": "vituperador",
    "vituperadoras": "vituperador",
    "vituperadores": "vituperador",
    "vituperados": "vituperar",
    "vituperai": "vituperar",
    "vituperais": "vituperar",
    "vituperam": "vituperar",
    "vituperamo": "vituperar",
    "vituperamos": "vituperar",
    "vituperando": "vituperar",
    "vituperara": "vituperar",
    "vituperaram": "vituperar",
    "vituperaras": "vituperar",
    "vituperarde": "vituperar",
    "vituperardes": "vituperar",
    "vituperare": "vituperar",
    "vituperarei": "vituperar",
    "vituperareis": "vituperar",
    "vituperarem": "vituperar",
    "vituperaremos": "vituperar",
    "vituperares": "vituperar",
    "vituperaria": "vituperar",
    "vituperariam": "vituperar",
    "vituperarias": "vituperar",
    "vituperarmo": "vituperar",
    "vituperarmos": "vituperar",
    "vituperará": "vituperar",
    "vituperarás": "vituperar",
    "vituperarão": "vituperar",
    "vituperaríamos": "vituperar",
    "vituperaríeis": "vituperar",
    "vituperas": "vituperar",
    "vituperasse": "vituperar",
    "vituperassem": "vituperar",
    "vituperasses": "vituperar",
    "vituperaste": "vituperar",
    "vituperastes": "vituperar",
    "vituperativa": "vituperativo",
    "vituperativas": "vituperativo",
    "vituperativos": "vituperativo",
    "vituperava": "vituperar",
    "vituperavam": "vituperar",
    "vituperavas": "vituperar",
    "vituperações": "vituperação",
    "vitupere": "vituperar",
    "vituperei": "vituperar",
    "vitupereis": "vituperar",
    "vituperem": "vituperar",
    "vituperemo": "vituperar",
    "vituperemos": "vituperar",
    "vituperes": "vituperar",
    "vituperiosa": "vituperioso",
    "vituperiosas": "vituperioso",
    "vituperiosos": "vituperioso",
    "vitupero": "vituperar",
    "vituperou": "vituperar",
    "vituperá": "vituperar",
    "vituperámo": "vituperar",
    "vituperámos": "vituperar",
    "vituperáramo": "vituperar",
    "vituperáramos": "vituperar",
    "vituperárei": "vituperar",
    "vituperáreis": "vituperar",
    "vituperásseis": "vituperar",
    "vituperássemos": "vituperar",
    "vituperávamo": "vituperar",
    "vituperávamos": "vituperar",
    "vituperávei": "vituperar",
    "vituperáveis": "vituperável",
    "vitupérios": "vitupério",
    "vitáceas": "vitácea",
    "vitáveis": "vitável",
    "vitícolas": "vitícola",
    "vitífera": "vitífero",
    "vitíferas": "vitífero",
    "vitíferos": "vitífero",
    "vitórias": "vitória",
    "viu": "ver",
    "viuva": "viuvar",
    "viuvada": "viuvar",
    "viuvadas": "viuvar",
    "viuvado": "viuvar",
    "viuvados": "viuvar",
    "viuvai": "viuvar",
    "viuvais": "viuvar",
    "viuvam": "viuvar",
    "viuvamo": "viuvar",
    "viuvamos": "viuvar",
    "viuvando": "viuvar",
    "viuvara": "viuvar",
    "viuvaram": "viuvar",
    "viuvaras": "viuvar",
    "viuvardes": "viuvar",
    "viuvarei": "viuvar",
    "viuvareis": "viuvar",
    "viuvarem": "viuvar",
    "viuvaremos": "viuvar",
    "viuvares": "viuvar",
    "viuvaria": "viuvar",
    "viuvariam": "viuvar",
    "viuvarias": "viuvar",
    "viuvarmo": "viuvar",
    "viuvarmos": "viuvar",
    "viuvará": "viuvar",
    "viuvarás": "viuvar",
    "viuvarão": "viuvar",
    "viuvaríamos": "viuvar",
    "viuvaríeis": "viuvar",
    "viuvas": "viuvar",
    "viuvasse": "viuvar",
    "viuvassem": "viuvar",
    "viuvasses": "viuvar",
    "viuvaste": "viuvar",
    "viuvastes": "viuvar",
    "viuvava": "viuvar",
    "viuvavam": "viuvar",
    "viuvavas": "viuvar",
    "viuve": "viuvar",
    "viuvei": "viuvar",
    "viuveis": "viuvar",
    "viuvem": "viuvar",
    "viuvemo": "viuvar",
    "viuvemos": "viuvar",
    "viuves": "viuvar",
    "viuvezes": "viuvez",
    "viuvinha": "viúvo",
    "viuvinhas": "viúvo",
    "viuvinho": "viúvo",
    "viuvinhos": "viúvo",
    "viuvita": "viúvo",
    "viuvitas": "viúvo",
    "viuvito": "viúvo",
    "viuvitos": "viúvo",
    "viuvo": "viuvar",
    "viuvou": "viuvar",
    "viuvámo": "viuvar",
    "viuvámos": "viuvar",
    "viuváramo": "viuvar",
    "viuváramos": "viuvar",
    "viuváreis": "viuvar",
    "viuvásseis": "viuvar",
    "viuvássemos": "viuvar",
    "viuvávamo": "viuvar",
    "viuvávamos": "viuvar",
    "viuváveis": "viuvar",
    "viuvíssima": "viúvo",
    "viuvíssimas": "viúvo",
    "viuvíssimo": "viúvo",
    "viuvíssimos": "viúvo",
    "viva": "vivo",
    "vivaces": "vivace",
    "vivacidades": "vivacidade",
    "vivacíssima": "vivaz",
    "vivacíssimas": "vivaz",
    "vivacíssimo": "vivaz",
    "vivacíssimos": "vivaz",
    "vivada": "vivar",
    "vivadas": "vivar",
    "vivado": "vivar",
    "vivados": "vivar",
    "vivai": "vivar",
    "vivais": "viver",
    "vivalmas": "vivalma",
    "vivam": "viver",
    "vivamo": "viver",
    "vivamos": "viver",
    "vivandeira": "vivandeiro",
    "vivandeiras": "vivandeiro",
    "vivandeiros": "vivandeiro",
    "vivando": "vivar",
    "vivara": "vivar",
    "vivaram": "vivar",
    "vivaras": "vivar",
    "vivardes": "vivar",
    "vivarei": "vivar",
    "vivareis": "vivar",
    "vivarem": "vivar",
    "vivaremos": "vivar",
    "vivares": "vivar",
    "vivaria": "vivar",
    "vivariam": "vivar",
    "vivarias": "vivar",
    "vivarmo": "vivar",
    "vivarmos": "vivar",
    "vivará": "vivar",
    "vivarás": "vivar",
    "vivarão": "vivar",
    "vivaríamos": "vivar",
    "vivaríeis": "vivar",
    "vivas": "vivo",
    "vivasse": "vivar",
    "vivassem": "vivar",
    "vivasses": "vivar",
    "vivaste": "vivar",
    "vivastes": "vivar",
    "vivava": "vivar",
    "vivavam": "vivar",
    "vivavas": "vivar",
    "vivazes": "vivaz",
    "vivaça": "vivaço",
    "vivaças": "vivaço",
    "vivaços": "vivaço",
    "vive": "viver",
    "vivedoira": "vivedoiro",
    "vivedoiras": "vivedoiro",
    "vivedoiros": "vivedoiro",
    "vivedora": "vivedor",
    "vivedoras": "vivedor",
    "vivedores": "vivedor",
    "vivei": "viver",
    "viveiros": "viveiro",
    "viveis": "viver",
    "vivem": "viver",
    "vivemo": "viver",
    "vivemos": "viver",
    "vivendas": "vivenda",
    "vivendazinha": "vivenda",
    "vivendazinhas": "vivenda",
    "vivendazita": "vivenda",
    "vivendazitas": "vivenda",
    "vivendo": "viver",
    "viventes": "vivente",
    "vivenças": "vivença",
    "vivera": "viver",
    "viveram": "viver",
    "viveras": "viver",
    "viverde": "viver",
    "viverdes": "viver",
    "vivere": "viver",
    "viverei": "viver",
    "vivereis": "viver",
    "viverem": "viver",
    "viveremos": "viver",
    "viveres": "viver",
    "viveria": "viver",
    "viveriam": "viver",
    "viverias": "viver",
    "vivermo": "viver",
    "vivermos": "viver",
    "viverrina": "viverrino",
    "viverrinas": "viverrino",
    "viverrinos": "viverrino",
    "viverrídea": "viverrídeo",
    "viverrídeas": "viverrídeo",
    "viverrídeos": "viverrídeo",
    "viverá": "viver",
    "viverás": "viver",
    "viverão": "viver",
    "viveríamos": "viver",
    "viveríeis": "viver",
    "vives": "viver",
    "vivesse": "viver",
    "vivessem": "viver",
    "vivesses": "viver",
    "viveste": "viver",
    "vivestes": "viver",
    "viveu": "viver",
    "vivezas": "viveza",
    "vivi": "viver",
    "vivia": "viver",
    "viviam": "viver",
    "vivianites": "vivianite",
    "vivias": "viver",
    "vivicombúrios": "vivicombúrio",
    "vivida": "vivido",
    "vividas": "vivido",
    "vividezes": "vividez",
    "vivido": "viver",
    "vividos": "vivido",
    "vividíssima": "vivido",
    "vividíssimas": "vivido",
    "vividíssimo": "vivido",
    "vividíssimos": "vivido",
    "vivifica": "vivificar",
    "vivificada": "vivificar",
    "vivificadas": "vivificar",
    "vivificado": "vivificar",
    "vivificadora": "vivificador",
    "vivificadoras": "vivificador",
    "vivificadores": "vivificador",
    "vivificados": "vivificar",
    "vivificai": "vivificar",
    "vivificais": "vivificar",
    "vivificam": "vivificar",
    "vivificamo": "vivificar",
    "vivificamos": "vivificar",
    "vivificando": "vivificar",
    "vivificantes": "vivificante",
    "vivificara": "vivificar",
    "vivificaram": "vivificar",
    "vivificaras": "vivificar",
    "vivificarde": "vivificar",
    "vivificardes": "vivificar",
    "vivificare": "vivificar",
    "vivificarei": "vivificar",
    "vivificareis": "vivificar",
    "vivificarem": "vivificar",
    "vivificaremos": "vivificar",
    "vivificares": "vivificar",
    "vivificaria": "vivificar",
    "vivificariam": "vivificar",
    "vivificarias": "vivificar",
    "vivificarmo": "vivificar",
    "vivificarmos": "vivificar",
    "vivificará": "vivificar",
    "vivificarás": "vivificar",
    "vivificarão": "vivificar",
    "vivificaríamos": "vivificar",
    "vivificaríeis": "vivificar",
    "vivificas": "vivificar",
    "vivificasse": "vivificar",
    "vivificassem": "vivificar",
    "vivificasses": "vivificar",
    "vivificaste": "vivificar",
    "vivificastes": "vivificar",
    "vivificativa": "vivificativo",
    "vivificativas": "vivificativo",
    "vivificativos": "vivificativo",
    "vivificava": "vivificar",
    "vivificavam": "vivificar",
    "vivificavas": "vivificar",
    "vivificações": "vivificação",
    "vivifico": "vivificar",
    "vivificou": "vivificar",
    "vivificá": "vivificar",
    "vivificámo": "vivificar",
    "vivificámos": "vivificar",
    "vivificáramo": "vivificar",
    "vivificáramos": "vivificar",
    "vivificárei": "vivificar",
    "vivificáreis": "vivificar",
    "vivificásseis": "vivificar",
    "vivificássemos": "vivificar",
    "vivificávamo": "vivificar",
    "vivificávamos": "vivificar",
    "vivificávei": "vivificar",
    "vivificáveis": "vivificar",
    "vivifique": "vivificar",
    "vivifiquei": "vivificar",
    "vivifiqueis": "vivificar",
    "vivifiquem": "vivificar",
    "vivifiquemo": "vivificar",
    "vivifiquemos": "vivificar",
    "vivifiques": "vivificar",
    "vivinatalidades": "vivinatalidade",
    "vivinha": "vivo",
    "vivinhas": "vivo",
    "vivinho": "vivo",
    "vivinhos": "vivo",
    "viviparidades": "viviparidade",
    "viviparismos": "viviparismo",
    "vivisseccionistas": "vivisseccionista",
    "vivissectora": "vivissector",
    "vivissectoras": "vivissector",
    "vivissectores": "vivissector",
    "vivissecções": "vivissecção",
    "vivita": "vivo",
    "vivitas": "vivo",
    "vivito": "vivo",
    "vivitos": "vivo",
    "vivo": "viver",
    "vivos": "vivo",
    "vivoteios": "vivoteio",
    "vivou": "vivar",
    "vivámo": "vivar",
    "vivámos": "vivar",
    "viváramo": "vivar",
    "viváramos": "vivar",
    "viváreis": "vivar",
    "vivásseis": "vivar",
    "vivássemos": "vivar",
    "vivávamo": "vivar",
    "vivávamos": "vivar",
    "viváveis": "vivar",
    "vivérridas": "vivérrida",
    "vivê": "viver",
    "vivências": "vivência",
    "vivêramo": "viver",
    "vivêramos": "viver",
    "vivêrei": "viver",
    "vivêreis": "viver",
    "vivêsseis": "viver",
    "vivêssemos": "viver",
    "vivíamo": "viver",
    "vivíamos": "viver",
    "vivíei": "viver",
    "vivíeis": "viver",
    "vivífica": "vivífico",
    "vivíficas": "vivífico",
    "vivíficos": "vivífico",
    "vivípara": "vivíparo",
    "vivíparas": "vivíparo",
    "vivíparos": "vivíparo",
    "vivíssima": "vivo",
    "vivíssimas": "vivo",
    "vivíssimo": "vivo",
    "vivíssimos": "vivo",
    "vivíveis": "vivível",
    "vivórios": "vivório",
    "vixnuísmos": "vixnuísmo",
    "vixnuístas": "vixnuísta",
    "vizelenses": "vizelense",
    "vizindades": "vizindade",
    "vizinha": "vizinho",
    "vizinhada": "vizinhar",
    "vizinhadas": "vizinhar",
    "vizinhado": "vizinhar",
    "vizinhados": "vizinhar",
    "vizinhai": "vizinhar",
    "vizinhais": "vizinhar",
    "vizinham": "vizinhar",
    "vizinhamo": "vizinhar",
    "vizinhamos": "vizinhar",
    "vizinhando": "vizinhar",
    "vizinhantes": "vizinhante",
    "vizinhanças": "vizinhança",
    "vizinhara": "vizinhar",
    "vizinharam": "vizinhar",
    "vizinharas": "vizinhar",
    "vizinhardes": "vizinhar",
    "vizinharei": "vizinhar",
    "vizinhareis": "vizinhar",
    "vizinharem": "vizinhar",
    "vizinharemos": "vizinhar",
    "vizinhares": "vizinhar",
    "vizinharia": "vizinhar",
    "vizinhariam": "vizinhar",
    "vizinharias": "vizinhar",
    "vizinharmo": "vizinhar",
    "vizinharmos": "vizinhar",
    "vizinhará": "vizinhar",
    "vizinharás": "vizinhar",
    "vizinharão": "vizinhar",
    "vizinharíamos": "vizinhar",
    "vizinharíeis": "vizinhar",
    "vizinhas": "vizinho",
    "vizinhasse": "vizinhar",
    "vizinhassem": "vizinhar",
    "vizinhasses": "vizinhar",
    "vizinhaste": "vizinhar",
    "vizinhastes": "vizinhar",
    "vizinhava": "vizinhar",
    "vizinhavam": "vizinhar",
    "vizinhavas": "vizinhar",
    "vizinhe": "vizinhar",
    "vizinhei": "vizinhar",
    "vizinheis": "vizinhar",
    "vizinhem": "vizinhar",
    "vizinhemo": "vizinhar",
    "vizinhemos": "vizinhar",
    "vizinhes": "vizinhar",
    "vizinho": "vizinhar",
    "vizinhos": "vizinho",
    "vizinhou": "vizinhar",
    "vizinhámo": "vizinhar",
    "vizinhámos": "vizinhar",
    "vizinháramo": "vizinhar",
    "vizinháramos": "vizinhar",
    "vizinháreis": "vizinhar",
    "vizinhásseis": "vizinhar",
    "vizinhássemos": "vizinhar",
    "vizinhávamo": "vizinhar",
    "vizinhávamos": "vizinhar",
    "vizinháveis": "vizinhar",
    "vizirados": "vizirado",
    "viziratos": "vizirato",
    "vizires": "vizir",
    "viária": "viário",
    "viárias": "viário",
    "viários": "viário",
    "viáticos": "viático",
    "viáveis": "viável",
    "viça": "viçar",
    "viçada": "viçar",
    "viçadas": "viçar",
    "viçado": "viçar",
    "viçados": "viçar",
    "viçai": "viçar",
    "viçais": "viçar",
    "viçam": "viçar",
    "viçamo": "viçar",
    "viçamos": "viçar",
    "viçando": "viçar",
    "viçara": "viçar",
    "viçaram": "viçar",
    "viçaras": "viçar",
    "viçarde": "viçar",
    "viçardes": "viçar",
    "viçare": "viçar",
    "viçarei": "viçar",
    "viçareis": "viçar",
    "viçarem": "viçar",
    "viçaremos": "viçar",
    "viçares": "viçar",
    "viçaria": "viçar",
    "viçariam": "viçar",
    "viçarias": "viçar",
    "viçarmo": "viçar",
    "viçarmos": "viçar",
    "viçará": "viçar",
    "viçarás": "viçar",
    "viçarão": "viçar",
    "viçaríamos": "viçar",
    "viçaríeis": "viçar",
    "viças": "viçar",
    "viçasse": "viçar",
    "viçassem": "viçar",
    "viçasses": "viçar",
    "viçaste": "viçar",
    "viçastes": "viçar",
    "viçava": "viçar",
    "viçavam": "viçar",
    "viçavas": "viçar",
    "viço": "viçar",
    "viços": "viço",
    "viçosa": "viçoso",
    "viçosas": "viçoso",
    "viçosos": "viçoso",
    "viçosíssima": "viçoso",
    "viçosíssimas": "viçoso",
    "viçosíssimo": "viçoso",
    "viçosíssimos": "viçoso",
    "viçou": "viçar",
    "viçá": "viçar",
    "viçámo": "viçar",
    "viçámos": "viçar",
    "viçáramo": "viçar",
    "viçáramos": "viçar",
    "viçárei": "viçar",
    "viçáreis": "viçar",
    "viçásseis": "viçar",
    "viçássemos": "viçar",
    "viçávamo": "viçar",
    "viçávamos": "viçar",
    "viçávei": "viçar",
    "viçáveis": "viçar",
    "viéramo": "vir",
    "viéramos": "vir",
    "viérei": "vir",
    "viéreis": "vir",
    "viésseis": "vir",
    "viéssemos": "vir",
    "viúva": "viúvo",
    "viúvas": "viúvo",
    "viúvos": "viúvo",
    "vo": "vos",
    "voa": "voar",
    "voada": "voar",
    "voadas": "voar",
    "voado": "voar",
    "voadora": "voador",
    "voadoras": "voador",
    "voadores": "voador",
    "voados": "voar",
    "voaduras": "voadura",
    "voagens": "voagem",
    "voai": "voar",
    "voais": "voar",
    "voam": "voar",
    "voamo": "voar",
    "voamos": "voar",
    "voando": "voar",
    "voantes": "voante",
    "voara": "voar",
    "voaram": "voar",
    "voaras": "voar",
    "voardes": "voar",
    "voarei": "voar",
    "voareis": "voar",
    "voarem": "voar",
    "voaremos": "voar",
    "voares": "voar",
    "voaria": "voar",
    "voariam": "voar",
    "voarias": "voaria",
    "voarmo": "voar",
    "voarmos": "voar",
    "voará": "voar",
    "voarás": "voar",
    "voarão": "voar",
    "voaríamos": "voar",
    "voaríeis": "voar",
    "voas": "voar",
    "voasse": "voar",
    "voassem": "voar",
    "voasses": "voar",
    "voaste": "voar",
    "voastes": "voar",
    "voava": "voar",
    "voavam": "voar",
    "voavas": "voar",
    "vobordes": "voborde",
    "vocabulara": "vocabular",
    "vocabularas": "vocabular",
    "vocabulares": "vocabular",
    "vocabularistas": "vocabularista",
    "vocabulistas": "vocabulista",
    "vocabuliza": "vocabulizar",
    "vocabulizada": "vocabulizar",
    "vocabulizadas": "vocabulizar",
    "vocabulizado": "vocabulizar",
    "vocabulizados": "vocabulizar",
    "vocabulizai": "vocabulizar",
    "vocabulizais": "vocabulizar",
    "vocabulizam": "vocabulizar",
    "vocabulizamo": "vocabulizar",
    "vocabulizamos": "vocabulizar",
    "vocabulizando": "vocabulizar",
    "vocabulizara": "vocabulizar",
    "vocabulizaram": "vocabulizar",
    "vocabulizaras": "vocabulizar",
    "vocabulizarde": "vocabulizar",
    "vocabulizardes": "vocabulizar",
    "vocabulizare": "vocabulizar",
    "vocabulizarei": "vocabulizar",
    "vocabulizareis": "vocabulizar",
    "vocabulizarem": "vocabulizar",
    "vocabulizaremos": "vocabulizar",
    "vocabulizares": "vocabulizar",
    "vocabulizaria": "vocabulizar",
    "vocabulizariam": "vocabulizar",
    "vocabulizarias": "vocabulizar",
    "vocabulizarmo": "vocabulizar",
    "vocabulizarmos": "vocabulizar",
    "vocabulizará": "vocabulizar",
    "vocabulizarás": "vocabulizar",
    "vocabulizarão": "vocabulizar",
    "vocabulizaríamos": "vocabulizar",
    "vocabulizaríeis": "vocabulizar",
    "vocabulizas": "vocabulizar",
    "vocabulizasse": "vocabulizar",
    "vocabulizassem": "vocabulizar",
    "vocabulizasses": "vocabulizar",
    "vocabulizaste": "vocabulizar",
    "vocabulizastes": "vocabulizar",
    "vocabulizava": "vocabulizar",
    "vocabulizavam": "vocabulizar",
    "vocabulizavas": "vocabulizar",
    "vocabulize": "vocabulizar",
    "vocabulizei": "vocabulizar",
    "vocabulizeis": "vocabulizar",
    "vocabulizem": "vocabulizar",
    "vocabulizemo": "vocabulizar",
    "vocabulizemos": "vocabulizar",
    "vocabulizes": "vocabulizar",
    "vocabulizo": "vocabulizar",
    "vocabulizou": "vocabulizar",
    "vocabulizá": "vocabulizar",
    "vocabulizámo": "vocabulizar",
    "vocabulizámos": "vocabulizar",
    "vocabulizáramo": "vocabulizar",
    "vocabulizáramos": "vocabulizar",
    "vocabulizárei": "vocabulizar",
    "vocabulizáreis": "vocabulizar",
    "vocabulizásseis": "vocabulizar",
    "vocabulizássemos": "vocabulizar",
    "vocabulizávamo": "vocabulizar",
    "vocabulizávamos": "vocabulizar",
    "vocabulizávei": "vocabulizar",
    "vocabulizáveis": "vocabulizar",
    "vocabulários": "vocabulário",
    "vocacionada": "vocacionado",
    "vocacionadas": "vocacionado",
    "vocacionados": "vocacionado",
    "vocacionais": "vocacional",
    "vocais": "vocal",
    "vocalismos": "vocalismo",
    "vocalistas": "vocalista",
    "vocaliza": "vocalizar",
    "vocalizada": "vocalizar",
    "vocalizadas": "vocalizar",
    "vocalizado": "vocalizar",
    "vocalizadora": "vocalizador",
    "vocalizadoras": "vocalizador",
    "vocalizadores": "vocalizador",
    "vocalizados": "vocalizar",
    "vocalizai": "vocalizar",
    "vocalizais": "vocalizar",
    "vocalizam": "vocalizar",
    "vocalizamo": "vocalizar",
    "vocalizamos": "vocalizar",
    "vocalizando": "vocalizar",
    "vocalizara": "vocalizar",
    "vocalizaram": "vocalizar",
    "vocalizaras": "vocalizar",
    "vocalizarde": "vocalizar",
    "vocalizardes": "vocalizar",
    "vocalizare": "vocalizar",
    "vocalizarei": "vocalizar",
    "vocalizareis": "vocalizar",
    "vocalizarem": "vocalizar",
    "vocalizaremos": "vocalizar",
    "vocalizares": "vocalizar",
    "vocalizaria": "vocalizar",
    "vocalizariam": "vocalizar",
    "vocalizarias": "vocalizar",
    "vocalizarmo": "vocalizar",
    "vocalizarmos": "vocalizar",
    "vocalizará": "vocalizar",
    "vocalizarás": "vocalizar",
    "vocalizarão": "vocalizar",
    "vocalizaríamos": "vocalizar",
    "vocalizaríeis": "vocalizar",
    "vocalizas": "vocalizar",
    "vocalizasse": "vocalizar",
    "vocalizassem": "vocalizar",
    "vocalizasses": "vocalizar",
    "vocalizaste": "vocalizar",
    "vocalizastes": "vocalizar",
    "vocalizava": "vocalizar",
    "vocalizavam": "vocalizar",
    "vocalizavas": "vocalizar",
    "vocalizações": "vocalização",
    "vocalize": "vocalizar",
    "vocalizei": "vocalizar",
    "vocalizeis": "vocalizar",
    "vocalizem": "vocalizar",
    "vocalizemo": "vocalizar",
    "vocalizemos": "vocalizar",
    "vocalizes": "vocalizar",
    "vocalizo": "vocalizar",
    "vocalizos": "vocalizo",
    "vocalizou": "vocalizar",
    "vocalizá": "vocalizar",
    "vocalizámo": "vocalizar",
    "vocalizámos": "vocalizar",
    "vocalizáramo": "vocalizar",
    "vocalizáramos": "vocalizar",
    "vocalizárei": "vocalizar",
    "vocalizáreis": "vocalizar",
    "vocalizásseis": "vocalizar",
    "vocalizássemos": "vocalizar",
    "vocalizávamo": "vocalizar",
    "vocalizávamos": "vocalizar",
    "vocalizávei": "vocalizar",
    "vocalizáveis": "vocalizável",
    "vocalíssima": "vocal",
    "vocalíssimas": "vocal",
    "vocalíssimo": "vocal",
    "vocalíssimos": "vocal",
    "vocativos": "vocativo",
    "vocações": "vocação",
    "vocifera": "vociferar",
    "vociferada": "vociferar",
    "vociferadas": "vociferar",
    "vociferado": "vociferar",
    "vociferadora": "vociferador",
    "vociferadoras": "vociferador",
    "vociferadores": "vociferador",
    "vociferados": "vociferar",
    "vociferai": "vociferar",
    "vociferais": "vociferar",
    "vociferam": "vociferar",
    "vociferamo": "vociferar",
    "vociferamos": "vociferar",
    "vociferando": "vociferar",
    "vociferantes": "vociferante",
    "vociferara": "vociferar",
    "vociferaram": "vociferar",
    "vociferaras": "vociferar",
    "vociferarde": "vociferar",
    "vociferardes": "vociferar",
    "vociferare": "vociferar",
    "vociferarei": "vociferar",
    "vociferareis": "vociferar",
    "vociferarem": "vociferar",
    "vociferaremos": "vociferar",
    "vociferares": "vociferar",
    "vociferaria": "vociferar",
    "vociferariam": "vociferar",
    "vociferarias": "vociferar",
    "vociferarmo": "vociferar",
    "vociferarmos": "vociferar",
    "vociferará": "vociferar",
    "vociferarás": "vociferar",
    "vociferarão": "vociferar",
    "vociferaríamos": "vociferar",
    "vociferaríeis": "vociferar",
    "vociferas": "vociferar",
    "vociferasse": "vociferar",
    "vociferassem": "vociferar",
    "vociferasses": "vociferar",
    "vociferaste": "vociferar",
    "vociferastes": "vociferar",
    "vociferava": "vociferar",
    "vociferavam": "vociferar",
    "vociferavas": "vociferar",
    "vociferações": "vociferação",
    "vocifere": "vociferar",
    "vociferei": "vociferar",
    "vocifereis": "vociferar",
    "vociferem": "vociferar",
    "vociferemo": "vociferar",
    "vociferemos": "vociferar",
    "vociferes": "vociferar",
    "vocifero": "vociferar",
    "vociferou": "vociferar",
    "vociferá": "vociferar",
    "vociferámo": "vociferar",
    "vociferámos": "vociferar",
    "vociferáramo": "vociferar",
    "vociferáramos": "vociferar",
    "vociferárei": "vociferar",
    "vociferáreis": "vociferar",
    "vociferásseis": "vociferar",
    "vociferássemos": "vociferar",
    "vociferávamo": "vociferar",
    "vociferávamos": "vociferar",
    "vociferávei": "vociferar",
    "vociferáveis": "vociferar",
    "vocábulos": "vocábulo",
    "vocálica": "vocálico",
    "vocálicas": "vocálico",
    "vocálicos": "vocálico",
    "vocês": "você",
    "vodkas": "vodka",
    "voe": "voar",
    "voei": "voar",
    "voeiras": "voeira",
    "voeis": "voar",
    "voeja": "voejar",
    "voejada": "voejar",
    "voejadas": "voejar",
    "voejado": "voejar",
    "voejados": "voejar",
    "voejai": "voejar",
    "voejais": "voejar",
    "voejam": "voejar",
    "voejamo": "voejar",
    "voejamos": "voejar",
    "voejando": "voejar",
    "voejantes": "voejante",
    "voejara": "voejar",
    "voejaram": "voejar",
    "voejaras": "voejar",
    "voejardes": "voejar",
    "voejarei": "voejar",
    "voejareis": "voejar",
    "voejarem": "voejar",
    "voejaremos": "voejar",
    "voejares": "voejar",
    "voejaria": "voejar",
    "voejariam": "voejar",
    "voejarias": "voejar",
    "voejarmo": "voejar",
    "voejarmos": "voejar",
    "voejará": "voejar",
    "voejarás": "voejar",
    "voejarão": "voejar",
    "voejaríamos": "voejar",
    "voejaríeis": "voejar",
    "voejas": "voejar",
    "voejasse": "voejar",
    "voejassem": "voejar",
    "voejasses": "voejar",
    "voejaste": "voejar",
    "voejastes": "voejar",
    "voejava": "voejar",
    "voejavam": "voejar",
    "voejavas": "voejar",
    "voeje": "voejar",
    "voejei": "voejar",
    "voejeis": "voejar",
    "voejem": "voejar",
    "voejemo": "voejar",
    "voejemos": "voejar",
    "voejes": "voejar",
    "voejo": "voejar",
    "voejos": "voejo",
    "voejou": "voejar",
    "voejámo": "voejar",
    "voejámos": "voejar",
    "voejáramo": "voejar",
    "voejáramos": "voejar",
    "voejáreis": "voejar",
    "voejásseis": "voejar",
    "voejássemos": "voejar",
    "voejávamo": "voejar",
    "voejávamos": "voejar",
    "voejáveis": "voejar",
    "voem": "voar",
    "voemo": "voar",
    "voemos": "voar",
    "voes": "voar",
    "voga": "vogar",
    "vogada": "vogar",
    "vogadas": "vogar",
    "vogado": "vogar",
    "vogados": "vogar",
    "vogai": "vogar",
    "vogais": "vogar",
    "vogam": "vogar",
    "vogamo": "vogar",
    "vogamos": "vogar",
    "vogando": "vogar",
    "vogantes": "vogante",
    "vogara": "vogar",
    "vogaram": "vogar",
    "vogaras": "vogar",
    "vogardes": "vogar",
    "vogarei": "vogar",
    "vogareis": "vogar",
    "vogarem": "vogar",
    "vogaremos": "vogar",
    "vogares": "vogar",
    "vogaria": "vogar",
    "vogariam": "vogar",
    "vogarias": "vogar",
    "vogarmo": "vogar",
    "vogarmos": "vogar",
    "vogará": "vogar",
    "vogarás": "vogar",
    "vogarão": "vogar",
    "vogaríamos": "vogar",
    "vogaríeis": "vogar",
    "vogas": "vogar",
    "vogasse": "vogar",
    "vogassem": "vogar",
    "vogasses": "vogar",
    "vogaste": "vogar",
    "vogastes": "vogar",
    "vogava": "vogar",
    "vogavam": "vogar",
    "vogavas": "vogar",
    "vogo": "vogar",
    "vogou": "vogar",
    "vogue": "vogar",
    "voguei": "vogar",
    "vogueiros": "vogueiro",
    "vogueis": "vogar",
    "voguem": "vogar",
    "voguemo": "vogar",
    "voguemos": "vogar",
    "vogues": "vogue",
    "vogámo": "vogar",
    "vogámos": "vogar",
    "vogáramo": "vogar",
    "vogáramos": "vogar",
    "vogáreis": "vogar",
    "vogásseis": "vogar",
    "vogássemos": "vogar",
    "vogávamo": "vogar",
    "vogávamos": "vogar",
    "vogáveis": "vogar",
    "volandeiras": "volandeira",
    "volantes": "volante",
    "volantins": "volantim",
    "volapuques": "volapuque",
    "volapuquistas": "volapuquista",
    "volatarias": "volataria",
    "volatas": "volata",
    "volateada": "volatear",
    "volateadas": "volatear",
    "volateado": "volatear",
    "volateados": "volatear",
    "volateai": "volatear",
    "volateais": "volatear",
    "volateamo": "volatear",
    "volateamos": "volatear",
    "volateando": "volatear",
    "volateara": "volatear",
    "volatearam": "volatear",
    "volatearas": "volatear",
    "volateardes": "volatear",
    "volatearei": "volatear",
    "volateareis": "volatear",
    "volatearem": "volatear",
    "volatearemos": "volatear",
    "volateares": "volatear",
    "volatearia": "volatear",
    "volateariam": "volatear",
    "volatearias": "volatear",
    "volatearmo": "volatear",
    "volatearmos": "volatear",
    "volateará": "volatear",
    "volatearás": "volatear",
    "volatearão": "volatear",
    "volatearíamos": "volatear",
    "volatearíeis": "volatear",
    "volateasse": "volatear",
    "volateassem": "volatear",
    "volateasses": "volatear",
    "volateaste": "volatear",
    "volateastes": "volatear",
    "volateava": "volatear",
    "volateavam": "volatear",
    "volateavas": "volatear",
    "volateei": "volatear",
    "volateeis": "volatear",
    "volateemo": "volatear",
    "volateemos": "volatear",
    "volateia": "volatear",
    "volateiam": "volatear",
    "volateias": "volatear",
    "volateie": "volatear",
    "volateiem": "volatear",
    "volateies": "volatear",
    "volateio": "volatear",
    "volateou": "volatear",
    "volateámo": "volatear",
    "volateámos": "volatear",
    "volateáramo": "volatear",
    "volateáramos": "volatear",
    "volateáreis": "volatear",
    "volateásseis": "volatear",
    "volateássemos": "volatear",
    "volateávamo": "volatear",
    "volateávamos": "volatear",
    "volateáveis": "volatear",
    "volatilidades": "volatilidade",
    "volatiliza": "volatilizar",
    "volatilizada": "volatilizar",
    "volatilizadas": "volatilizar",
    "volatilizado": "volatilizar",
    "volatilizados": "volatilizar",
    "volatilizai": "volatilizar",
    "volatilizais": "volatilizar",
    "volatilizam": "volatilizar",
    "volatilizamo": "volatilizar",
    "volatilizamos": "volatilizar",
    "volatilizando": "volatilizar",
    "volatilizantes": "volatilizante",
    "volatilizara": "volatilizar",
    "volatilizaram": "volatilizar",
    "volatilizaras": "volatilizar",
    "volatilizarde": "volatilizar",
    "volatilizardes": "volatilizar",
    "volatilizare": "volatilizar",
    "volatilizarei": "volatilizar",
    "volatilizareis": "volatilizar",
    "volatilizarem": "volatilizar",
    "volatilizaremos": "volatilizar",
    "volatilizares": "volatilizar",
    "volatilizaria": "volatilizar",
    "volatilizariam": "volatilizar",
    "volatilizarias": "volatilizar",
    "volatilizarmo": "volatilizar",
    "volatilizarmos": "volatilizar",
    "volatilizará": "volatilizar",
    "volatilizarás": "volatilizar",
    "volatilizarão": "volatilizar",
    "volatilizaríamos": "volatilizar",
    "volatilizaríeis": "volatilizar",
    "volatilizas": "volatilizar",
    "volatilizasse": "volatilizar",
    "volatilizassem": "volatilizar",
    "volatilizasses": "volatilizar",
    "volatilizaste": "volatilizar",
    "volatilizastes": "volatilizar",
    "volatilizava": "volatilizar",
    "volatilizavam": "volatilizar",
    "volatilizavas": "volatilizar",
    "volatilizações": "volatilização",
    "volatilize": "volatilizar",
    "volatilizei": "volatilizar",
    "volatilizeis": "volatilizar",
    "volatilizem": "volatilizar",
    "volatilizemo": "volatilizar",
    "volatilizemos": "volatilizar",
    "volatilizes": "volatilizar",
    "volatilizo": "volatilizar",
    "volatilizou": "volatilizar",
    "volatilizá": "volatilizar",
    "volatilizámo": "volatilizar",
    "volatilizámos": "volatilizar",
    "volatilizáramo": "volatilizar",
    "volatilizáramos": "volatilizar",
    "volatilizárei": "volatilizar",
    "volatilizáreis": "volatilizar",
    "volatilizásseis": "volatilizar",
    "volatilizássemos": "volatilizar",
    "volatilizávamo": "volatilizar",
    "volatilizávamos": "volatilizar",
    "volatilizávei": "volatilizar",
    "volatilizáveis": "volatilizável",
    "volatinas": "volatina",
    "volatins": "volatim",
    "volatória": "volatório",
    "volatórias": "volatório",
    "volatórios": "volatório",
    "voleada": "volear",
    "voleadas": "volear",
    "voleado": "volear",
    "voleados": "volear",
    "voleai": "volear",
    "voleais": "volear",
    "voleamo": "volear",
    "voleamos": "volear",
    "voleando": "volear",
    "voleara": "volear",
    "volearam": "volear",
    "volearas": "volear",
    "volearde": "volear",
    "voleardes": "volear",
    "voleare": "volear",
    "volearei": "volear",
    "voleareis": "volear",
    "volearem": "volear",
    "volearemos": "volear",
    "voleares": "volear",
    "volearia": "volear",
    "voleariam": "volear",
    "volearias": "volear",
    "volearmo": "volear",
    "volearmos": "volear",
    "voleará": "volear",
    "volearás": "volear",
    "volearão": "volear",
    "volearíamos": "volear",
    "volearíeis": "volear",
    "voleasse": "volear",
    "voleassem": "volear",
    "voleasses": "volear",
    "voleaste": "volear",
    "voleastes": "volear",
    "voleava": "volear",
    "voleavam": "volear",
    "voleavas": "volear",
    "voleei": "volear",
    "voleeis": "volear",
    "voleemo": "volear",
    "voleemos": "volear",
    "voleia": "volear",
    "voleiam": "volear",
    "voleias": "volear",
    "voleibolistas": "voleibolista",
    "voleie": "volear",
    "voleiem": "volear",
    "voleies": "volear",
    "voleio": "volear",
    "voleis": "volei",
    "volemias": "volemia",
    "voleou": "volear",
    "voleá": "volear",
    "voleámo": "volear",
    "voleámos": "volear",
    "voleáramo": "volear",
    "voleáramos": "volear",
    "voleárei": "volear",
    "voleáreis": "volear",
    "voleásseis": "volear",
    "voleássemos": "volear",
    "voleávamo": "volear",
    "voleávamos": "volear",
    "voleávei": "volear",
    "voleáveis": "volear",
    "volframistas": "volframista",
    "volframites": "volframite",
    "volfrâmios": "volfrâmio",
    "volita": "volitar",
    "volitada": "volitar",
    "volitadas": "volitar",
    "volitado": "volitar",
    "volitados": "volitar",
    "volitai": "volitar",
    "volitais": "volitar",
    "volitam": "volitar",
    "volitamo": "volitar",
    "volitamos": "volitar",
    "volitando": "volitar",
    "volitantes": "volitante",
    "volitara": "volitar",
    "volitaram": "volitar",
    "volitaras": "volitar",
    "volitardes": "volitar",
    "volitarei": "volitar",
    "volitareis": "volitar",
    "volitarem": "volitar",
    "volitaremos": "volitar",
    "volitares": "volitar",
    "volitaria": "volitar",
    "volitariam": "volitar",
    "volitarias": "volitar",
    "volitarmo": "volitar",
    "volitarmos": "volitar",
    "volitará": "volitar",
    "volitarás": "volitar",
    "volitarão": "volitar",
    "volitaríamos": "volitar",
    "volitaríeis": "volitar",
    "volitas": "volitar",
    "volitasse": "volitar",
    "volitassem": "volitar",
    "volitasses": "volitar",
    "volitaste": "volitar",
    "volitastes": "volitar",
    "volitava": "volitar",
    "volitavam": "volitar",
    "volitavas": "volitar",
    "volite": "volitar",
    "volitei": "volitar",
    "voliteis": "volitar",
    "volitem": "volitar",
    "volitemo": "volitar",
    "volitemos": "volitar",
    "volites": "volitar",
    "volitiva": "volitivo",
    "volitivas": "volitivo",
    "volitivos": "volitivo",
    "volito": "volitar",
    "volitou": "volitar",
    "volitámo": "volitar",
    "volitámos": "volitar",
    "volitáramo": "volitar",
    "volitáramos": "volitar",
    "volitáreis": "volitar",
    "volitásseis": "volitar",
    "volitássemos": "volitar",
    "volitávamo": "volitar",
    "volitávamos": "volitar",
    "volitáveis": "volitar",
    "volições": "volição",
    "volos": "volo",
    "volta": "voltar",
    "voltada": "voltar",
    "voltadas": "voltar",
    "voltado": "voltar",
    "voltados": "voltar",
    "voltagens": "voltagem",
    "voltai": "voltar",
    "voltaica": "voltaico",
    "voltaicas": "voltaico",
    "voltaicos": "voltaico",
    "voltairiana": "voltairiano",
    "voltairianas": "voltairiano",
    "voltairianismos": "voltairianismo",
    "voltairianistas": "voltairianista",
    "voltairianos": "voltairiano",
    "voltais": "voltar",
    "voltam": "voltar",
    "voltamo": "voltar",
    "voltamos": "voltar",
    "voltando": "voltar",
    "voltara": "voltar",
    "voltaram": "voltar",
    "voltaras": "voltar",
    "voltardes": "voltar",
    "voltarei": "voltar",
    "voltareis": "voltar",
    "voltarem": "voltar",
    "voltaremos": "voltar",
    "voltares": "voltar",
    "voltaretes": "voltarete",
    "voltaretezinho": "voltarete",
    "voltaretezinhos": "voltarete",
    "voltaretezito": "voltarete",
    "voltaretezitos": "voltarete",
    "voltaretistas": "voltaretista",
    "voltaria": "voltar",
    "voltariam": "voltar",
    "voltarias": "voltar",
    "voltarmo": "voltar",
    "voltarmos": "voltar",
    "voltará": "voltar",
    "voltarás": "voltar",
    "voltarão": "voltar",
    "voltaríamos": "voltar",
    "voltaríeis": "voltar",
    "voltas": "voltar",
    "voltasse": "voltar",
    "voltassem": "voltar",
    "voltasses": "voltar",
    "voltaste": "voltar",
    "voltastes": "voltar",
    "voltava": "voltar",
    "voltavam": "voltar",
    "voltavas": "voltar",
    "volte": "voltar",
    "volteada": "voltear",
    "volteadas": "voltear",
    "volteado": "voltear",
    "volteadora": "volteador",
    "volteadoras": "volteador",
    "volteadores": "volteador",
    "volteados": "voltear",
    "volteaduras": "volteadura",
    "volteai": "voltear",
    "volteais": "voltear",
    "volteamo": "voltear",
    "volteamos": "voltear",
    "volteando": "voltear",
    "volteara": "voltear",
    "voltearam": "voltear",
    "voltearas": "voltear",
    "voltearde": "voltear",
    "volteardes": "voltear",
    "volteare": "voltear",
    "voltearei": "voltear",
    "volteareis": "voltear",
    "voltearem": "voltear",
    "voltearemos": "voltear",
    "volteares": "voltear",
    "voltearia": "voltear",
    "volteariam": "voltear",
    "voltearias": "voltear",
    "voltearmo": "voltear",
    "voltearmos": "voltear",
    "volteará": "voltear",
    "voltearás": "voltear",
    "voltearão": "voltear",
    "voltearíamos": "voltear",
    "voltearíeis": "voltear",
    "volteasse": "voltear",
    "volteassem": "voltear",
    "volteasses": "voltear",
    "volteaste": "voltear",
    "volteastes": "voltear",
    "volteava": "voltear",
    "volteavam": "voltear",
    "volteavas": "voltear",
    "volteações": "volteação",
    "volteei": "voltear",
    "volteeis": "voltear",
    "volteemo": "voltear",
    "volteemos": "voltear",
    "voltei": "voltar",
    "volteia": "voltear",
    "volteiam": "voltear",
    "volteias": "voltear",
    "volteie": "voltear",
    "volteiem": "voltear",
    "volteies": "voltear",
    "volteio": "voltear",
    "volteios": "volteio",
    "volteira": "volteiro",
    "volteiras": "volteiro",
    "volteiros": "volteiro",
    "volteis": "voltar",
    "volteja": "voltejar",
    "voltejada": "voltejar",
    "voltejadas": "voltejar",
    "voltejado": "voltejar",
    "voltejados": "voltejar",
    "voltejai": "voltejar",
    "voltejais": "voltejar",
    "voltejam": "voltejar",
    "voltejamo": "voltejar",
    "voltejamos": "voltejar",
    "voltejando": "voltejar",
    "voltejara": "voltejar",
    "voltejaram": "voltejar",
    "voltejaras": "voltejar",
    "voltejarde": "voltejar",
    "voltejardes": "voltejar",
    "voltejare": "voltejar",
    "voltejarei": "voltejar",
    "voltejareis": "voltejar",
    "voltejarem": "voltejar",
    "voltejaremos": "voltejar",
    "voltejares": "voltejar",
    "voltejaria": "voltejar",
    "voltejariam": "voltejar",
    "voltejarias": "voltejar",
    "voltejarmo": "voltejar",
    "voltejarmos": "voltejar",
    "voltejará": "voltejar",
    "voltejarás": "voltejar",
    "voltejarão": "voltejar",
    "voltejaríamos": "voltejar",
    "voltejaríeis": "voltejar",
    "voltejas": "voltejar",
    "voltejasse": "voltejar",
    "voltejassem": "voltejar",
    "voltejasses": "voltejar",
    "voltejaste": "voltejar",
    "voltejastes": "voltejar",
    "voltejava": "voltejar",
    "voltejavam": "voltejar",
    "voltejavas": "voltejar",
    "volteje": "voltejar",
    "voltejei": "voltejar",
    "voltejeis": "voltejar",
    "voltejem": "voltejar",
    "voltejemo": "voltejar",
    "voltejemos": "voltejar",
    "voltejes": "voltejar",
    "voltejo": "voltejar",
    "voltejou": "voltejar",
    "voltejá": "voltejar",
    "voltejámo": "voltejar",
    "voltejámos": "voltejar",
    "voltejáramo": "voltejar",
    "voltejáramos": "voltejar",
    "voltejárei": "voltejar",
    "voltejáreis": "voltejar",
    "voltejásseis": "voltejar",
    "voltejássemos": "voltejar",
    "voltejávamo": "voltejar",
    "voltejávamos": "voltejar",
    "voltejávei": "voltejar",
    "voltejáveis": "voltejar",
    "voltem": "voltar",
    "voltemo": "voltar",
    "voltemos": "voltar",
    "volteou": "voltear",
    "voltes": "volte",
    "volteá": "voltear",
    "volteámo": "voltear",
    "volteámos": "voltear",
    "volteáramo": "voltear",
    "volteáramos": "voltear",
    "volteárei": "voltear",
    "volteáreis": "voltear",
    "volteásseis": "voltear",
    "volteássemos": "voltear",
    "volteávamo": "voltear",
    "volteávamos": "voltear",
    "volteávei": "voltear",
    "volteáveis": "voltear",
    "voltinha": "volta",
    "voltinhas": "volta",
    "voltita": "volta",
    "voltitas": "volta",
    "volto": "voltar",
    "voltou": "voltar",
    "voltámo": "voltar",
    "voltámos": "voltar",
    "voltáramo": "voltar",
    "voltáramos": "voltar",
    "voltáreis": "voltar",
    "voltária": "voltário",
    "voltárias": "voltário",
    "voltários": "voltário",
    "voltásseis": "voltar",
    "voltássemos": "voltar",
    "voltávamo": "voltar",
    "voltávamos": "voltar",
    "voltáveis": "voltar",
    "voltâmetros": "voltâmetro",
    "voltímetros": "voltímetro",
    "voltívola": "voltívolo",
    "voltívolas": "voltívolo",
    "voltívolos": "voltívolo",
    "volubilidades": "volubilidade",
    "volubilismos": "volubilismo",
    "voluma": "volumar",
    "volumada": "volumar",
    "volumadas": "volumar",
    "volumado": "volumar",
    "volumados": "volumar",
    "volumai": "volumar",
    "volumais": "volumar",
    "volumam": "volumar",
    "volumamo": "volumar",
    "volumamos": "volumar",
    "volumando": "volumar",
    "volumara": "volumar",
    "volumaram": "volumar",
    "volumaras": "volumar",
    "volumarde": "volumar",
    "volumardes": "volumar",
    "volumare": "volumar",
    "volumarei": "volumar",
    "volumareis": "volumar",
    "volumarem": "volumar",
    "volumaremos": "volumar",
    "volumares": "volumar",
    "volumaria": "volumar",
    "volumariam": "volumar",
    "volumarias": "volumar",
    "volumarmo": "volumar",
    "volumarmos": "volumar",
    "volumará": "volumar",
    "volumarás": "volumar",
    "volumarão": "volumar",
    "volumaríamos": "volumar",
    "volumaríeis": "volumar",
    "volumas": "volumar",
    "volumasse": "volumar",
    "volumassem": "volumar",
    "volumasses": "volumar",
    "volumaste": "volumar",
    "volumastes": "volumar",
    "volumava": "volumar",
    "volumavam": "volumar",
    "volumavas": "volumar",
    "volume": "volumar",
    "volumei": "volumar",
    "volumeis": "volumar",
    "volumem": "volumar",
    "volumemo": "volumar",
    "volumemos": "volumar",
    "volumes": "volume",
    "volumetrias": "volumetria",
    "voluminosa": "voluminoso",
    "voluminosas": "voluminoso",
    "voluminosos": "voluminoso",
    "volumo": "volumar",
    "volumosa": "volumoso",
    "volumosas": "volumoso",
    "volumosos": "volumoso",
    "volumou": "volumar",
    "volumá": "volumar",
    "volumámo": "volumar",
    "volumámos": "volumar",
    "volumáramo": "volumar",
    "volumáramos": "volumar",
    "volumárei": "volumar",
    "volumáreis": "volumar",
    "volumásseis": "volumar",
    "volumássemos": "volumar",
    "volumávamo": "volumar",
    "volumávamos": "volumar",
    "volumávei": "volumar",
    "volumáveis": "volumar",
    "volumétrica": "volumétrico",
    "volumétricas": "volumétrico",
    "volumétricos": "volumétrico",
    "volumões": "volumão",
    "voluntariados": "voluntariado",
    "voluntariedades": "voluntariedade",
    "voluntariosa": "voluntarioso",
    "voluntariosas": "voluntarioso",
    "voluntariosidades": "voluntariosidade",
    "voluntariosos": "voluntarioso",
    "voluntarismos": "voluntarismo",
    "voluntaristas": "voluntarista",
    "voluntária": "voluntário",
    "voluntárias": "voluntário",
    "voluntários": "voluntário",
    "voluptua": "voluptuar",
    "voluptuada": "voluptuar",
    "voluptuadas": "voluptuar",
    "voluptuado": "voluptuar",
    "voluptuados": "voluptuar",
    "voluptuai": "voluptuar",
    "voluptuais": "voluptuar",
    "voluptuam": "voluptuar",
    "voluptuamo": "voluptuar",
    "voluptuamos": "voluptuar",
    "voluptuando": "voluptuar",
    "voluptuara": "voluptuar",
    "voluptuaram": "voluptuar",
    "voluptuaras": "voluptuar",
    "voluptuardes": "voluptuar",
    "voluptuarei": "voluptuar",
    "voluptuareis": "voluptuar",
    "voluptuarem": "voluptuar",
    "voluptuaremos": "voluptuar",
    "voluptuares": "voluptuar",
    "voluptuaria": "voluptuar",
    "voluptuariam": "voluptuar",
    "voluptuarias": "voluptuar",
    "voluptuarmo": "voluptuar",
    "voluptuarmos": "voluptuar",
    "voluptuará": "voluptuar",
    "voluptuarás": "voluptuar",
    "voluptuarão": "voluptuar",
    "voluptuaríamos": "voluptuar",
    "voluptuaríeis": "voluptuar",
    "voluptuas": "voluptuar",
    "voluptuasse": "voluptuar",
    "voluptuassem": "voluptuar",
    "voluptuasses": "voluptuar",
    "voluptuaste": "voluptuar",
    "voluptuastes": "voluptuar",
    "voluptuava": "voluptuar",
    "voluptuavam": "voluptuar",
    "voluptuavas": "voluptuar",
    "voluptue": "voluptuar",
    "voluptuei": "voluptuar",
    "voluptueis": "voluptuar",
    "voluptuem": "voluptuar",
    "voluptuemo": "voluptuar",
    "voluptuemos": "voluptuar",
    "voluptues": "voluptuar",
    "voluptuo": "voluptuar",
    "voluptuosa": "voluptuoso",
    "voluptuosas": "voluptuoso",
    "voluptuosidades": "voluptuosidade",
    "voluptuosos": "voluptuoso",
    "voluptuou": "voluptuar",
    "voluptuámo": "voluptuar",
    "voluptuámos": "voluptuar",
    "voluptuáramo": "voluptuar",
    "voluptuáramos": "voluptuar",
    "voluptuáreis": "voluptuar",
    "voluptuária": "voluptuário",
    "voluptuárias": "voluptuário",
    "voluptuários": "voluptuário",
    "voluptuásseis": "voluptuar",
    "voluptuássemos": "voluptuar",
    "voluptuávamo": "voluptuar",
    "voluptuávamos": "voluptuar",
    "voluptuáveis": "voluptuar",
    "voluta": "volutar",
    "volutabros": "volutabro",
    "volutada": "volutar",
    "volutadas": "volutar",
    "volutado": "volutar",
    "volutados": "volutar",
    "volutai": "volutar",
    "volutais": "volutar",
    "volutam": "volutar",
    "volutamo": "volutar",
    "volutamos": "volutar",
    "volutando": "volutar",
    "volutara": "volutar",
    "volutaram": "volutar",
    "volutaras": "volutar",
    "volutarde": "volutar",
    "volutardes": "volutar",
    "volutare": "volutar",
    "volutarei": "volutar",
    "volutareis": "volutar",
    "volutarem": "volutar",
    "volutaremos": "volutar",
    "volutares": "volutar",
    "volutaria": "volutar",
    "volutariam": "volutar",
    "volutarias": "volutar",
    "volutarmo": "volutar",
    "volutarmos": "volutar",
    "volutará": "volutar",
    "volutarás": "volutar",
    "volutarão": "volutar",
    "volutaríamos": "volutar",
    "volutaríeis": "volutar",
    "volutas": "volutar",
    "volutasse": "volutar",
    "volutassem": "volutar",
    "volutasses": "volutar",
    "volutaste": "volutar",
    "volutastes": "volutar",
    "volutava": "volutar",
    "volutavam": "volutar",
    "volutavas": "volutar",
    "volute": "volutar",
    "voluteada": "volutear",
    "voluteadas": "volutear",
    "voluteado": "volutear",
    "voluteados": "volutear",
    "voluteai": "volutear",
    "voluteais": "volutear",
    "voluteamo": "volutear",
    "voluteamos": "volutear",
    "voluteando": "volutear",
    "voluteara": "volutear",
    "volutearam": "volutear",
    "volutearas": "volutear",
    "voluteardes": "volutear",
    "volutearei": "volutear",
    "voluteareis": "volutear",
    "volutearem": "volutear",
    "volutearemos": "volutear",
    "voluteares": "volutear",
    "volutearia": "volutear",
    "voluteariam": "volutear",
    "volutearias": "volutear",
    "volutearmo": "volutear",
    "volutearmos": "volutear",
    "voluteará": "volutear",
    "volutearás": "volutear",
    "volutearão": "volutear",
    "volutearíamos": "volutear",
    "volutearíeis": "volutear",
    "voluteasse": "volutear",
    "voluteassem": "volutear",
    "voluteasses": "volutear",
    "voluteaste": "volutear",
    "voluteastes": "volutear",
    "voluteava": "volutear",
    "voluteavam": "volutear",
    "voluteavas": "volutear",
    "voluteei": "volutear",
    "voluteeis": "volutear",
    "voluteemo": "volutear",
    "voluteemos": "volutear",
    "volutei": "volutar",
    "voluteia": "volutear",
    "voluteiam": "volutear",
    "voluteias": "volutear",
    "voluteie": "volutear",
    "voluteiem": "volutear",
    "voluteies": "volutear",
    "voluteio": "volutear",
    "voluteis": "volutar",
    "volutem": "volutar",
    "volutemo": "volutar",
    "volutemos": "volutar",
    "voluteou": "volutear",
    "volutes": "volutar",
    "voluteámo": "volutear",
    "voluteámos": "volutear",
    "voluteáramo": "volutear",
    "voluteáramos": "volutear",
    "voluteáreis": "volutear",
    "voluteásseis": "volutear",
    "voluteássemos": "volutear",
    "voluteávamo": "volutear",
    "voluteávamos": "volutear",
    "voluteáveis": "volutear",
    "voluto": "volutar",
    "volutou": "volutar",
    "volutá": "volutar",
    "volutámo": "volutar",
    "volutámos": "volutar",
    "volutáramo": "volutar",
    "volutáramos": "volutar",
    "volutárei": "volutar",
    "volutáreis": "volutar",
    "volutásseis": "volutar",
    "volutássemos": "volutar",
    "volutávamo": "volutar",
    "volutávamos": "volutar",
    "volutávei": "volutar",
    "volutáveis": "volutar",
    "volva": "volver",
    "volvada": "volvado",
    "volvadas": "volvado",
    "volvados": "volvado",
    "volvais": "volver",
    "volvam": "volver",
    "volvamo": "volver",
    "volvamos": "volver",
    "volvas": "volver",
    "volve": "volver",
    "volvei": "volver",
    "volveis": "volver",
    "volvem": "volver",
    "volvemo": "volver",
    "volvemos": "volver",
    "volvendo": "volver",
    "volvera": "volver",
    "volveram": "volver",
    "volveras": "volver",
    "volverde": "volver",
    "volverdes": "volver",
    "volvere": "volver",
    "volverei": "volver",
    "volvereis": "volver",
    "volverem": "volver",
    "volveremos": "volver",
    "volveres": "volver",
    "volveria": "volver",
    "volveriam": "volver",
    "volverias": "volver",
    "volvermo": "volver",
    "volvermos": "volver",
    "volverá": "volver",
    "volverás": "volver",
    "volverão": "volver",
    "volveríamos": "volver",
    "volveríeis": "volver",
    "volves": "volver",
    "volvesse": "volver",
    "volvessem": "volver",
    "volvesses": "volver",
    "volveste": "volver",
    "volvestes": "volver",
    "volveu": "volver",
    "volvi": "volver",
    "volvia": "volver",
    "volviam": "volver",
    "volvias": "volver",
    "volvida": "volvido",
    "volvidas": "volvido",
    "volvido": "volver",
    "volvidos": "volvido",
    "volvo": "volver",
    "volvocales": "volvocale",
    "volvocáceas": "volvocácea",
    "volvocídeos": "volvocídeo",
    "volvos": "volvo",
    "volvácea": "volváceo",
    "volváceas": "volváceo",
    "volváceos": "volváceo",
    "volvê": "volver",
    "volvêramo": "volver",
    "volvêramos": "volver",
    "volvêrei": "volver",
    "volvêreis": "volver",
    "volvêsseis": "volver",
    "volvêssemos": "volver",
    "volvíamo": "volver",
    "volvíamos": "volver",
    "volvíei": "volver",
    "volvíeis": "volver",
    "voláteis": "volátil",
    "volíveis": "volível",
    "volúmica": "volúmico",
    "volúmicas": "volúmico",
    "volúmicos": "volúmico",
    "volúpias": "volúpia",
    "volúveis": "volúvel",
    "vomita": "vomitar",
    "vomitada": "vomitar",
    "vomitadas": "vomitar",
    "vomitado": "vomitar",
    "vomitadora": "vomitador",
    "vomitadoras": "vomitador",
    "vomitadores": "vomitador",
    "vomitados": "vomitar",
    "vomitadíssima": "vomitado",
    "vomitadíssimas": "vomitado",
    "vomitadíssimo": "vomitado",
    "vomitadíssimos": "vomitado",
    "vomitai": "vomitar",
    "vomitais": "vomitar",
    "vomitam": "vomitar",
    "vomitamo": "vomitar",
    "vomitamos": "vomitar",
    "vomitando": "vomitar",
    "vomitara": "vomitar",
    "vomitaram": "vomitar",
    "vomitaras": "vomitar",
    "vomitarde": "vomitar",
    "vomitardes": "vomitar",
    "vomitare": "vomitar",
    "vomitarei": "vomitar",
    "vomitareis": "vomitar",
    "vomitarem": "vomitar",
    "vomitaremos": "vomitar",
    "vomitares": "vomitar",
    "vomitaria": "vomitar",
    "vomitariam": "vomitar",
    "vomitarias": "vomitar",
    "vomitarmo": "vomitar",
    "vomitarmos": "vomitar",
    "vomitará": "vomitar",
    "vomitarás": "vomitar",
    "vomitarão": "vomitar",
    "vomitaríamos": "vomitar",
    "vomitaríeis": "vomitar",
    "vomitas": "vomitar",
    "vomitasse": "vomitar",
    "vomitassem": "vomitar",
    "vomitasses": "vomitar",
    "vomitaste": "vomitar",
    "vomitastes": "vomitar",
    "vomitava": "vomitar",
    "vomitavam": "vomitar",
    "vomitavas": "vomitar",
    "vomite": "vomitar",
    "vomitei": "vomitar",
    "vomiteis": "vomitar",
    "vomitem": "vomitar",
    "vomitemo": "vomitar",
    "vomitemos": "vomitar",
    "vomites": "vomitar",
    "vomitiva": "vomitivo",
    "vomitivas": "vomitivo",
    "vomitivos": "vomitivo",
    "vomito": "vomitar",
    "vomitou": "vomitar",
    "vomitá": "vomitar",
    "vomitámo": "vomitar",
    "vomitámos": "vomitar",
    "vomitáramo": "vomitar",
    "vomitáramos": "vomitar",
    "vomitárei": "vomitar",
    "vomitáreis": "vomitar",
    "vomitásseis": "vomitar",
    "vomitássemos": "vomitar",
    "vomitávamo": "vomitar",
    "vomitávamos": "vomitar",
    "vomitávei": "vomitar",
    "vomitáveis": "vomitar",
    "vomitória": "vomitório",
    "vomitórias": "vomitório",
    "vomitórios": "vomitório",
    "vomições": "vomição",
    "vontades": "vontade",
    "voo": "voar",
    "voodus": "voodu",
    "voos": "voo",
    "voou": "voar",
    "voraces": "vorace",
    "voracidades": "voracidade",
    "voragens": "voragem",
    "voraginosa": "voraginoso",
    "voraginosas": "voraginoso",
    "voraginosos": "voraginoso",
    "vorazes": "voraz",
    "vorticelas": "vorticela",
    "vorticidades": "vorticidade",
    "vorticosa": "vorticoso",
    "vorticosas": "vorticoso",
    "vorticosos": "vorticoso",
    "vortilhona": "vortilhonar",
    "vortilhonada": "vortilhonar",
    "vortilhonadas": "vortilhonar",
    "vortilhonado": "vortilhonar",
    "vortilhonados": "vortilhonar",
    "vortilhonai": "vortilhonar",
    "vortilhonais": "vortilhonar",
    "vortilhonam": "vortilhonar",
    "vortilhonamo": "vortilhonar",
    "vortilhonamos": "vortilhonar",
    "vortilhonando": "vortilhonar",
    "vortilhonara": "vortilhonar",
    "vortilhonaram": "vortilhonar",
    "vortilhonaras": "vortilhonar",
    "vortilhonardes": "vortilhonar",
    "vortilhonarei": "vortilhonar",
    "vortilhonareis": "vortilhonar",
    "vortilhonarem": "vortilhonar",
    "vortilhonaremos": "vortilhonar",
    "vortilhonares": "vortilhonar",
    "vortilhonaria": "vortilhonar",
    "vortilhonariam": "vortilhonar",
    "vortilhonarias": "vortilhonar",
    "vortilhonarmo": "vortilhonar",
    "vortilhonarmos": "vortilhonar",
    "vortilhonará": "vortilhonar",
    "vortilhonarás": "vortilhonar",
    "vortilhonarão": "vortilhonar",
    "vortilhonaríamos": "vortilhonar",
    "vortilhonaríeis": "vortilhonar",
    "vortilhonas": "vortilhonar",
    "vortilhonasse": "vortilhonar",
    "vortilhonassem": "vortilhonar",
    "vortilhonasses": "vortilhonar",
    "vortilhonaste": "vortilhonar",
    "vortilhonastes": "vortilhonar",
    "vortilhonava": "vortilhonar",
    "vortilhonavam": "vortilhonar",
    "vortilhonavas": "vortilhonar",
    "vortilhone": "vortilhonar",
    "vortilhonei": "vortilhonar",
    "vortilhoneis": "vortilhonar",
    "vortilhonem": "vortilhonar",
    "vortilhonemo": "vortilhonar",
    "vortilhonemos": "vortilhonar",
    "vortilhones": "vortilhonar",
    "vortilhono": "vortilhonar",
    "vortilhonou": "vortilhonar",
    "vortilhonámo": "vortilhonar",
    "vortilhonámos": "vortilhonar",
    "vortilhonáramo": "vortilhonar",
    "vortilhonáramos": "vortilhonar",
    "vortilhonáreis": "vortilhonar",
    "vortilhonásseis": "vortilhonar",
    "vortilhonássemos": "vortilhonar",
    "vortilhonávamo": "vortilhonar",
    "vortilhonávamos": "vortilhonar",
    "vortilhonáveis": "vortilhonar",
    "vortilhões": "vortilhão",
    "voseada": "vosear",
    "voseadas": "vosear",
    "voseado": "vosear",
    "voseados": "vosear",
    "voseai": "vosear",
    "voseais": "vosear",
    "voseamo": "vosear",
    "voseamos": "vosear",
    "voseando": "vosear",
    "voseara": "vosear",
    "vosearam": "vosear",
    "vosearas": "vosear",
    "voseardes": "vosear",
    "vosearei": "vosear",
    "voseareis": "vosear",
    "vosearem": "vosear",
    "vosearemos": "vosear",
    "voseares": "vosear",
    "vosearia": "vosear",
    "voseariam": "vosear",
    "vosearias": "vosear",
    "vosearmo": "vosear",
    "vosearmos": "vosear",
    "voseará": "vosear",
    "vosearás": "vosear",
    "vosearão": "vosear",
    "vosearíamos": "vosear",
    "vosearíeis": "vosear",
    "voseasse": "vosear",
    "voseassem": "vosear",
    "voseasses": "vosear",
    "voseaste": "vosear",
    "voseastes": "vosear",
    "voseava": "vosear",
    "voseavam": "vosear",
    "voseavas": "vosear",
    "voseei": "vosear",
    "voseeis": "vosear",
    "voseemo": "vosear",
    "voseemos": "vosear",
    "voseia": "vosear",
    "voseiam": "vosear",
    "voseias": "vosear",
    "voseie": "vosear",
    "voseiem": "vosear",
    "voseies": "vosear",
    "voseio": "vosear",
    "voseou": "vosear",
    "voseámo": "vosear",
    "voseámos": "vosear",
    "voseáramo": "vosear",
    "voseáramos": "vosear",
    "voseáreis": "vosear",
    "voseásseis": "vosear",
    "voseássemos": "vosear",
    "voseávamo": "vosear",
    "voseávamos": "vosear",
    "voseáveis": "vosear",
    "vosmecês": "vosmecê",
    "vossa": "vosso",
    "vossas": "vosso",
    "vosselências": "vosselência",
    "vossemecês": "vossemecê",
    "vossorias": "vossoria",
    "vossos": "vosso",
    "vossências": "vossência",
    "vota": "votar",
    "votada": "votar",
    "votadas": "votar",
    "votado": "votar",
    "votados": "votar",
    "votai": "votar",
    "votais": "votar",
    "votam": "votar",
    "votamo": "votar",
    "votamos": "votar",
    "votando": "votar",
    "votantes": "votante",
    "votara": "votar",
    "votaram": "votar",
    "votaras": "votar",
    "votarde": "votar",
    "votardes": "votar",
    "votare": "votar",
    "votarei": "votar",
    "votareis": "votar",
    "votarem": "votar",
    "votaremos": "votar",
    "votares": "votar",
    "votaria": "votar",
    "votariam": "votar",
    "votarias": "votar",
    "votarmo": "votar",
    "votarmos": "votar",
    "votará": "votar",
    "votarás": "votar",
    "votarão": "votar",
    "votaríamos": "votar",
    "votaríeis": "votar",
    "votas": "votar",
    "votasse": "votar",
    "votassem": "votar",
    "votasses": "votar",
    "votaste": "votar",
    "votastes": "votar",
    "votava": "votar",
    "votavam": "votar",
    "votavas": "votar",
    "votações": "votação",
    "vote": "votar",
    "votei": "votar",
    "voteis": "votar",
    "votem": "votar",
    "votemo": "votar",
    "votemos": "votar",
    "votes": "votar",
    "votiva": "votivo",
    "votivas": "votivo",
    "votivos": "votivo",
    "voto": "votar",
    "votos": "voto",
    "votou": "votar",
    "votozinho": "voto",
    "votozinhos": "voto",
    "votozito": "voto",
    "votozitos": "voto",
    "votá": "votar",
    "votámo": "votar",
    "votámos": "votar",
    "votáramo": "votar",
    "votáramos": "votar",
    "votárei": "votar",
    "votáreis": "votar",
    "votásseis": "votar",
    "votássemos": "votar",
    "votávamo": "votar",
    "votávamos": "votar",
    "votávei": "votar",
    "votáveis": "votar",
    "votífera": "votífero",
    "votíferas": "votífero",
    "votíferos": "votífero",
    "vou": "ir",
    "voventes": "vovente",
    "vovozinha": "vovô",
    "vovozinhas": "vovô",
    "vovozinho": "vovô",
    "vovozinhos": "vovô",
    "vovozita": "vovô",
    "vovozitas": "vovô",
    "vovozito": "vovô",
    "vovozitos": "vovô",
    "vovó": "vovô",
    "vovós": "vovô",
    "vovôs": "vovô",
    "voyeurismos": "voyeurismo",
    "voyeuristas": "voyeurista",
    "vozeada": "vozear",
    "vozeadas": "vozear",
    "vozeado": "vozear",
    "vozeadora": "vozeador",
    "vozeadoras": "vozeador",
    "vozeadores": "vozeador",
    "vozeados": "vozear",
    "vozeai": "vozear",
    "vozeais": "vozear",
    "vozeamentos": "vozeamento",
    "vozeamo": "vozear",
    "vozeamos": "vozear",
    "vozeando": "vozear",
    "vozeara": "vozear",
    "vozearam": "vozear",
    "vozearas": "vozear",
    "vozeardes": "vozear",
    "vozearei": "vozear",
    "vozeareis": "vozear",
    "vozearem": "vozear",
    "vozearemos": "vozear",
    "vozeares": "vozear",
    "vozearia": "vozear",
    "vozeariam": "vozear",
    "vozearias": "vozearia",
    "vozearmo": "vozear",
    "vozearmos": "vozear",
    "vozeará": "vozear",
    "vozearás": "vozear",
    "vozearão": "vozear",
    "vozearíamos": "vozear",
    "vozearíeis": "vozear",
    "vozeasse": "vozear",
    "vozeassem": "vozear",
    "vozeasses": "vozear",
    "vozeaste": "vozear",
    "vozeastes": "vozear",
    "vozeava": "vozear",
    "vozeavam": "vozear",
    "vozeavas": "vozear",
    "vozeei": "vozear",
    "vozeeis": "vozear",
    "vozeemo": "vozear",
    "vozeemos": "vozear",
    "vozeia": "vozear",
    "vozeiam": "vozear",
    "vozeias": "vozear",
    "vozeie": "vozear",
    "vozeiem": "vozear",
    "vozeies": "vozear",
    "vozeio": "vozear",
    "vozeios": "vozeio",
    "vozeira": "vozeiro",
    "vozeirada": "vozeirar",
    "vozeiradas": "vozeirar",
    "vozeirado": "vozeirar",
    "vozeirados": "vozeirar",
    "vozeirai": "vozeirar",
    "vozeirais": "vozeirar",
    "vozeiram": "vozeirar",
    "vozeiramo": "vozeirar",
    "vozeiramos": "vozeirar",
    "vozeirando": "vozeirar",
    "vozeirara": "vozeirar",
    "vozeiraram": "vozeirar",
    "vozeiraras": "vozeirar",
    "vozeirardes": "vozeirar",
    "vozeirarei": "vozeirar",
    "vozeirareis": "vozeirar",
    "vozeirarem": "vozeirar",
    "vozeiraremos": "vozeirar",
    "vozeirares": "vozeirar",
    "vozeiraria": "vozeirar",
    "vozeirariam": "vozeirar",
    "vozeirarias": "vozeirar",
    "vozeirarmo": "vozeirar",
    "vozeirarmos": "vozeirar",
    "vozeirará": "vozeirar",
    "vozeirarás": "vozeirar",
    "vozeirarão": "vozeirar",
    "vozeiraríamos": "vozeirar",
    "vozeiraríeis": "vozeirar",
    "vozeiras": "vozeiro",
    "vozeirasse": "vozeirar",
    "vozeirassem": "vozeirar",
    "vozeirasses": "vozeirar",
    "vozeiraste": "vozeirar",
    "vozeirastes": "vozeirar",
    "vozeirava": "vozeirar",
    "vozeiravam": "vozeirar",
    "vozeiravas": "vozeirar",
    "vozeire": "vozeirar",
    "vozeirei": "vozeirar",
    "vozeireis": "vozeirar",
    "vozeirem": "vozeirar",
    "vozeiremo": "vozeirar",
    "vozeiremos": "vozeirar",
    "vozeires": "vozeirar",
    "vozeiro": "vozeirar",
    "vozeiros": "vozeiro",
    "vozeirou": "vozeirar",
    "vozeirámo": "vozeirar",
    "vozeirámos": "vozeirar",
    "vozeiráramo": "vozeirar",
    "vozeiráramos": "vozeirar",
    "vozeiráreis": "vozeirar",
    "vozeirásseis": "vozeirar",
    "vozeirássemos": "vozeirar",
    "vozeirávamo": "vozeirar",
    "vozeirávamos": "vozeirar",
    "vozeiráveis": "vozeirar",
    "vozeirões": "vozeirão",
    "vozeou": "vozear",
    "vozerias": "vozeria",
    "vozes": "voz",
    "vozeámo": "vozear",
    "vozeámos": "vozear",
    "vozeáramo": "vozear",
    "vozeáramos": "vozear",
    "vozeáreis": "vozear",
    "vozeásseis": "vozear",
    "vozeássemos": "vozear",
    "vozeávamo": "vozear",
    "vozeávamos": "vozear",
    "vozeáveis": "vozear",
    "vozinha": "voz",
    "vozinhas": "voz",
    "vozita": "voz",
    "vozitas": "voz",
    "voámo": "voar",
    "voámos": "voar",
    "voáramo": "voar",
    "voáramos": "voar",
    "voáreis": "voar",
    "voásseis": "voar",
    "voássemos": "voar",
    "voávamo": "voar",
    "voávamos": "voar",
    "voáveis": "voar",
    "vulcaniana": "vulcaniano",
    "vulcanianas": "vulcaniano",
    "vulcanianos": "vulcaniano",
    "vulcanicidades": "vulcanicidade",
    "vulcaniformes": "vulcaniforme",
    "vulcanismos": "vulcanismo",
    "vulcanistas": "vulcanista",
    "vulcanites": "vulcanite",
    "vulcaniza": "vulcanizar",
    "vulcanizada": "vulcanizar",
    "vulcanizadas": "vulcanizar",
    "vulcanizado": "vulcanizar",
    "vulcanizadora": "vulcanizador",
    "vulcanizadoras": "vulcanizador",
    "vulcanizadores": "vulcanizador",
    "vulcanizados": "vulcanizar",
    "vulcanizai": "vulcanizar",
    "vulcanizais": "vulcanizar",
    "vulcanizam": "vulcanizar",
    "vulcanizamo": "vulcanizar",
    "vulcanizamos": "vulcanizar",
    "vulcanizando": "vulcanizar",
    "vulcanizara": "vulcanizar",
    "vulcanizaram": "vulcanizar",
    "vulcanizaras": "vulcanizar",
    "vulcanizarde": "vulcanizar",
    "vulcanizardes": "vulcanizar",
    "vulcanizare": "vulcanizar",
    "vulcanizarei": "vulcanizar",
    "vulcanizareis": "vulcanizar",
    "vulcanizarem": "vulcanizar",
    "vulcanizaremos": "vulcanizar",
    "vulcanizares": "vulcanizar",
    "vulcanizaria": "vulcanizar",
    "vulcanizariam": "vulcanizar",
    "vulcanizarias": "vulcanizar",
    "vulcanizarmo": "vulcanizar",
    "vulcanizarmos": "vulcanizar",
    "vulcanizará": "vulcanizar",
    "vulcanizarás": "vulcanizar",
    "vulcanizarão": "vulcanizar",
    "vulcanizaríamos": "vulcanizar",
    "vulcanizaríeis": "vulcanizar",
    "vulcanizas": "vulcanizar",
    "vulcanizasse": "vulcanizar",
    "vulcanizassem": "vulcanizar",
    "vulcanizasses": "vulcanizar",
    "vulcanizaste": "vulcanizar",
    "vulcanizastes": "vulcanizar",
    "vulcanizava": "vulcanizar",
    "vulcanizavam": "vulcanizar",
    "vulcanizavas": "vulcanizar",
    "vulcanizações": "vulcanização",
    "vulcanize": "vulcanizar",
    "vulcanizei": "vulcanizar",
    "vulcanizeis": "vulcanizar",
    "vulcanizem": "vulcanizar",
    "vulcanizemo": "vulcanizar",
    "vulcanizemos": "vulcanizar",
    "vulcanizes": "vulcanizar",
    "vulcanizo": "vulcanizar",
    "vulcanizou": "vulcanizar",
    "vulcanizá": "vulcanizar",
    "vulcanizámo": "vulcanizar",
    "vulcanizámos": "vulcanizar",
    "vulcanizáramo": "vulcanizar",
    "vulcanizáramos": "vulcanizar",
    "vulcanizárei": "vulcanizar",
    "vulcanizáreis": "vulcanizar",
    "vulcanizásseis": "vulcanizar",
    "vulcanizássemos": "vulcanizar",
    "vulcanizávamo": "vulcanizar",
    "vulcanizávamos": "vulcanizar",
    "vulcanizávei": "vulcanizar",
    "vulcanizáveis": "vulcanizável",
    "vulcanologias": "vulcanologia",
    "vulcanologistas": "vulcanologista",
    "vulcanos": "vulcano",
    "vulcanóloga": "vulcanólogo",
    "vulcanólogas": "vulcanólogo",
    "vulcanólogos": "vulcanólogo",
    "vulcânea": "vulcâneo",
    "vulcâneas": "vulcâneo",
    "vulcâneos": "vulcâneo",
    "vulcânica": "vulcânico",
    "vulcânicas": "vulcânico",
    "vulcânicos": "vulcânico",
    "vulcões": "vulcão",
    "vulgachos": "vulgacho",
    "vulgares": "vulgar",
    "vulgaridades": "vulgaridade",
    "vulgarismos": "vulgarismo",
    "vulgariza": "vulgarizar",
    "vulgarizada": "vulgarizar",
    "vulgarizadas": "vulgarizar",
    "vulgarizado": "vulgarizar",
    "vulgarizadora": "vulgarizador",
    "vulgarizadoras": "vulgarizador",
    "vulgarizadores": "vulgarizador",
    "vulgarizados": "vulgarizar",
    "vulgarizai": "vulgarizar",
    "vulgarizais": "vulgarizar",
    "vulgarizam": "vulgarizar",
    "vulgarizamo": "vulgarizar",
    "vulgarizamos": "vulgarizar",
    "vulgarizando": "vulgarizar",
    "vulgarizara": "vulgarizar",
    "vulgarizaram": "vulgarizar",
    "vulgarizaras": "vulgarizar",
    "vulgarizarde": "vulgarizar",
    "vulgarizardes": "vulgarizar",
    "vulgarizare": "vulgarizar",
    "vulgarizarei": "vulgarizar",
    "vulgarizareis": "vulgarizar",
    "vulgarizarem": "vulgarizar",
    "vulgarizaremos": "vulgarizar",
    "vulgarizares": "vulgarizar",
    "vulgarizaria": "vulgarizar",
    "vulgarizariam": "vulgarizar",
    "vulgarizarias": "vulgarizar",
    "vulgarizarmo": "vulgarizar",
    "vulgarizarmos": "vulgarizar",
    "vulgarizará": "vulgarizar",
    "vulgarizarás": "vulgarizar",
    "vulgarizarão": "vulgarizar",
    "vulgarizaríamos": "vulgarizar",
    "vulgarizaríeis": "vulgarizar",
    "vulgarizas": "vulgarizar",
    "vulgarizasse": "vulgarizar",
    "vulgarizassem": "vulgarizar",
    "vulgarizasses": "vulgarizar",
    "vulgarizaste": "vulgarizar",
    "vulgarizastes": "vulgarizar",
    "vulgarizava": "vulgarizar",
    "vulgarizavam": "vulgarizar",
    "vulgarizavas": "vulgarizar",
    "vulgarizações": "vulgarização",
    "vulgarize": "vulgarizar",
    "vulgarizei": "vulgarizar",
    "vulgarizeis": "vulgarizar",
    "vulgarizem": "vulgarizar",
    "vulgarizemo": "vulgarizar",
    "vulgarizemos": "vulgarizar",
    "vulgarizes": "vulgarizar",
    "vulgarizo": "vulgarizar",
    "vulgarizou": "vulgarizar",
    "vulgarizá": "vulgarizar",
    "vulgarizámo": "vulgarizar",
    "vulgarizámos": "vulgarizar",
    "vulgarizáramo": "vulgarizar",
    "vulgarizáramos": "vulgarizar",
    "vulgarizárei": "vulgarizar",
    "vulgarizáreis": "vulgarizar",
    "vulgarizásseis": "vulgarizar",
    "vulgarizássemos": "vulgarizar",
    "vulgarizávamo": "vulgarizar",
    "vulgarizávamos": "vulgarizar",
    "vulgarizávei": "vulgarizar",
    "vulgarizáveis": "vulgarizar",
    "vulgaríssima": "vulgar",
    "vulgaríssimas": "vulgar",
    "vulgaríssimo": "vulgar",
    "vulgaríssimos": "vulgar",
    "vulgocracias": "vulgocracia",
    "vulgos": "vulgo",
    "vulgívaga": "vulgívago",
    "vulgívagas": "vulgívago",
    "vulgívagos": "vulgívago",
    "vulnera": "vulnerar",
    "vulnerabilidades": "vulnerabilidade",
    "vulnerabiliza": "vulnerabilizar",
    "vulnerabilizada": "vulnerabilizar",
    "vulnerabilizadas": "vulnerabilizar",
    "vulnerabilizado": "vulnerabilizar",
    "vulnerabilizados": "vulnerabilizar",
    "vulnerabilizai": "vulnerabilizar",
    "vulnerabilizais": "vulnerabilizar",
    "vulnerabilizam": "vulnerabilizar",
    "vulnerabilizamo": "vulnerabilizar",
    "vulnerabilizamos": "vulnerabilizar",
    "vulnerabilizando": "vulnerabilizar",
    "vulnerabilizara": "vulnerabilizar",
    "vulnerabilizaram": "vulnerabilizar",
    "vulnerabilizaras": "vulnerabilizar",
    "vulnerabilizarde": "vulnerabilizar",
    "vulnerabilizardes": "vulnerabilizar",
    "vulnerabilizare": "vulnerabilizar",
    "vulnerabilizarei": "vulnerabilizar",
    "vulnerabilizareis": "vulnerabilizar",
    "vulnerabilizarem": "vulnerabilizar",
    "vulnerabilizaremos": "vulnerabilizar",
    "vulnerabilizares": "vulnerabilizar",
    "vulnerabilizaria": "vulnerabilizar",
    "vulnerabilizariam": "vulnerabilizar",
    "vulnerabilizarias": "vulnerabilizar",
    "vulnerabilizarmo": "vulnerabilizar",
    "vulnerabilizarmos": "vulnerabilizar",
    "vulnerabilizará": "vulnerabilizar",
    "vulnerabilizarás": "vulnerabilizar",
    "vulnerabilizarão": "vulnerabilizar",
    "vulnerabilizaríamos": "vulnerabilizar",
    "vulnerabilizaríeis": "vulnerabilizar",
    "vulnerabilizas": "vulnerabilizar",
    "vulnerabilizasse": "vulnerabilizar",
    "vulnerabilizassem": "vulnerabilizar",
    "vulnerabilizasses": "vulnerabilizar",
    "vulnerabilizaste": "vulnerabilizar",
    "vulnerabilizastes": "vulnerabilizar",
    "vulnerabilizava": "vulnerabilizar",
    "vulnerabilizavam": "vulnerabilizar",
    "vulnerabilizavas": "vulnerabilizar",
    "vulnerabilize": "vulnerabilizar",
    "vulnerabilizei": "vulnerabilizar",
    "vulnerabilizeis": "vulnerabilizar",
    "vulnerabilizem": "vulnerabilizar",
    "vulnerabilizemo": "vulnerabilizar",
    "vulnerabilizemos": "vulnerabilizar",
    "vulnerabilizes": "vulnerabilizar",
    "vulnerabilizo": "vulnerabilizar",
    "vulnerabilizou": "vulnerabilizar",
    "vulnerabilizá": "vulnerabilizar",
    "vulnerabilizámo": "vulnerabilizar",
    "vulnerabilizámos": "vulnerabilizar",
    "vulnerabilizáramo": "vulnerabilizar",
    "vulnerabilizáramos": "vulnerabilizar",
    "vulnerabilizárei": "vulnerabilizar",
    "vulnerabilizáreis": "vulnerabilizar",
    "vulnerabilizásseis": "vulnerabilizar",
    "vulnerabilizássemos": "vulnerabilizar",
    "vulnerabilizávamo": "vulnerabilizar",
    "vulnerabilizávamos": "vulnerabilizar",
    "vulnerabilizávei": "vulnerabilizar",
    "vulnerabilizáveis": "vulnerabilizar",
    "vulnerabilíssima": "vulnerável",
    "vulnerabilíssimas": "vulnerável",
    "vulnerabilíssimo": "vulnerável",
    "vulnerabilíssimos": "vulnerável",
    "vulnerada": "vulnerar",
    "vulneradas": "vulnerar",
    "vulnerado": "vulnerar",
    "vulneradora": "vulnerador",
    "vulneradoras": "vulnerador",
    "vulneradores": "vulnerador",
    "vulnerados": "vulnerar",
    "vulnerai": "vulnerar",
    "vulnerais": "vulnerar",
    "vulneram": "vulnerar",
    "vulneramo": "vulnerar",
    "vulneramos": "vulnerar",
    "vulnerando": "vulnerar",
    "vulnerantes": "vulnerante",
    "vulnerara": "vulnerar",
    "vulneraram": "vulnerar",
    "vulneraras": "vulnerar",
    "vulnerarde": "vulnerar",
    "vulnerardes": "vulnerar",
    "vulnerare": "vulnerar",
    "vulnerarei": "vulnerar",
    "vulnerareis": "vulnerar",
    "vulnerarem": "vulnerar",
    "vulneraremos": "vulnerar",
    "vulnerares": "vulnerar",
    "vulneraria": "vulnerar",
    "vulnerariam": "vulnerar",
    "vulnerarias": "vulnerar",
    "vulnerarmo": "vulnerar",
    "vulnerarmos": "vulnerar",
    "vulnerará": "vulnerar",
    "vulnerarás": "vulnerar",
    "vulnerarão": "vulnerar",
    "vulneraríamos": "vulnerar",
    "vulneraríeis": "vulnerar",
    "vulneras": "vulnerar",
    "vulnerasse": "vulnerar",
    "vulnerassem": "vulnerar",
    "vulnerasses": "vulnerar",
    "vulneraste": "vulnerar",
    "vulnerastes": "vulnerar",
    "vulnerava": "vulnerar",
    "vulneravam": "vulnerar",
    "vulneravas": "vulnerar",
    "vulnerações": "vulneração",
    "vulnere": "vulnerar",
    "vulnerei": "vulnerar",
    "vulnereis": "vulnerar",
    "vulnerem": "vulnerar",
    "vulneremo": "vulnerar",
    "vulneremos": "vulnerar",
    "vulneres": "vulnerar",
    "vulnero": "vulnerar",
    "vulnerou": "vulnerar",
    "vulnerá": "vulnerar",
    "vulnerámo": "vulnerar",
    "vulnerámos": "vulnerar",
    "vulneráramo": "vulnerar",
    "vulneráramos": "vulnerar",
    "vulnerárei": "vulnerar",
    "vulneráreis": "vulnerar",
    "vulnerária": "vulnerário",
    "vulnerárias": "vulnerário",
    "vulnerários": "vulnerário",
    "vulnerásseis": "vulnerar",
    "vulnerássemos": "vulnerar",
    "vulnerávamo": "vulnerar",
    "vulnerávamos": "vulnerar",
    "vulnerávei": "vulnerar",
    "vulneráveis": "vulnerável",
    "vulnífica": "vulnífico",
    "vulníficas": "vulnífico",
    "vulníficos": "vulnífico",
    "vulpina": "vulpino",
    "vulpinas": "vulpino",
    "vulpinos": "vulpino",
    "vultos": "vulto",
    "vultosa": "vultoso",
    "vultosas": "vultoso",
    "vultosos": "vultoso",
    "vultuosa": "vultuoso",
    "vultuosas": "vultuoso",
    "vultuosidades": "vultuosidade",
    "vultuosos": "vultuoso",
    "vulturina": "vulturino",
    "vulturinas": "vulturino",
    "vulturinos": "vulturino",
    "vulturnos": "vulturno",
    "vulturídeos": "vulturídeo",
    "vultúridas": "vultúrida",
    "vulvares": "vulvar",
    "vulvas": "vulva",
    "vulvites": "vulvite",
    "vulvovaginites": "vulvovaginite",
    "vulvária": "vulvário",
    "vulvárias": "vulvário",
    "vulvários": "vulvário",
    "vunvuns": "vunvum",
    "vurbanas": "vurbana",
    "vurma": "vurmar",
    "vurmada": "vurmar",
    "vurmadas": "vurmar",
    "vurmado": "vurmar",
    "vurmados": "vurmar",
    "vurmai": "vurmar",
    "vurmais": "vurmar",
    "vurmam": "vurmar",
    "vurmamo": "vurmar",
    "vurmamos": "vurmar",
    "vurmando": "vurmar",
    "vurmara": "vurmar",
    "vurmaram": "vurmar",
    "vurmaras": "vurmar",
    "vurmardes": "vurmar",
    "vurmarei": "vurmar",
    "vurmareis": "vurmar",
    "vurmarem": "vurmar",
    "vurmaremos": "vurmar",
    "vurmares": "vurmar",
    "vurmaria": "vurmar",
    "vurmariam": "vurmar",
    "vurmarias": "vurmar",
    "vurmarmo": "vurmar",
    "vurmarmos": "vurmar",
    "vurmará": "vurmar",
    "vurmarás": "vurmar",
    "vurmarão": "vurmar",
    "vurmaríamos": "vurmar",
    "vurmaríeis": "vurmar",
    "vurmas": "vurmar",
    "vurmasse": "vurmar",
    "vurmassem": "vurmar",
    "vurmasses": "vurmar",
    "vurmaste": "vurmar",
    "vurmastes": "vurmar",
    "vurmava": "vurmar",
    "vurmavam": "vurmar",
    "vurmavas": "vurmar",
    "vurme": "vurmar",
    "vurmei": "vurmar",
    "vurmeiros": "vurmeiro",
    "vurmeis": "vurmar",
    "vurmem": "vurmar",
    "vurmemo": "vurmar",
    "vurmemos": "vurmar",
    "vurmes": "vurmar",
    "vurmo": "vurmar",
    "vurmos": "vurmo",
    "vurmosa": "vurmoso",
    "vurmosas": "vurmoso",
    "vurmosos": "vurmoso",
    "vurmou": "vurmar",
    "vurmámo": "vurmar",
    "vurmámos": "vurmar",
    "vurmáramo": "vurmar",
    "vurmáramos": "vurmar",
    "vurmáreis": "vurmar",
    "vurmásseis": "vurmar",
    "vurmássemos": "vurmar",
    "vurmávamo": "vurmar",
    "vurmávamos": "vurmar",
    "vurmáveis": "vurmar",
    "vurtemberguesa": "vurtemberguês",
    "vurtemberguesas": "vurtemberguês",
    "vurtembergueses": "vurtemberguês",
    "vv": "v",
    "vá": "ir",
    "vácua": "vácuo",
    "vácuas": "vácuo",
    "vácuos": "vácuo",
    "vágados": "vágado",
    "válida": "válido",
    "válidas": "válido",
    "válidos": "válido",
    "vális": "váli",
    "válvulas": "válvula",
    "vápida": "vápido",
    "vápidas": "vápido",
    "vápidos": "vápido",
    "várgeas": "várgea",
    "vária": "vário",
    "várias": "vários",
    "vários": "vário",
    "várzeas": "várzea",
    "vás": "ir",
    "vática": "vático",
    "váticas": "vático",
    "váticos": "vático",
    "vátios": "vátio",
    "vátuas": "vátua",
    "vândala": "vândalo",
    "vândalas": "vândalo",
    "vândalos": "vândalo",
    "vã": "vão",
    "vão": "ir",
    "vãos": "vão",
    "vãs": "vão",
    "védica": "védico",
    "védicas": "védico",
    "védicos": "védico",
    "végeta": "végeto",
    "végetas": "végeto",
    "végetos": "végeto",
    "vélites": "vélite",
    "vénera": "vénero",
    "véneras": "vénero",
    "véneros": "vénero",
    "véneta": "véneto",
    "vénetas": "véneto",
    "vénetos": "véneto",
    "vénias": "vénia",
    "vénulas": "vénula",
    "vérmica": "vérmico",
    "vérmicas": "vérmico",
    "vérmicos": "vérmico",
    "vérminas": "vérmina",
    "vértebras": "vértebra",
    "vértices": "vértice",
    "vésperas": "véspera",
    "vésperos": "véspero",
    "véspers": "vésper",
    "véspidas": "véspida",
    "véstias": "véstia",
    "véus": "véu",
    "vê": "ver",
    "vêem": "ver",
    "vêm": "vir",
    "vêntulos": "vêntulo",
    "vês": "ver",
    "víamo": "ver",
    "víamos": "ver",
    "víboras": "víbora",
    "vícios": "vício",
    "vídeos": "vídeo",
    "víei": "ver",
    "víeis": "ver",
    "vígis": "vígil",
    "vílicos": "vílico",
    "vínculos": "vínculo",
    "víndices": "víndice",
    "vínea": "víneo",
    "víneas": "víneo",
    "víneos": "víneo",
    "vínhamo": "vir",
    "vínhamos": "vir",
    "vínhei": "vir",
    "vínheis": "vir",
    "vínica": "vínico",
    "vínicas": "vínico",
    "vínicos": "vínico",
    "víramo": "ver",
    "víramos": "ver",
    "vírei": "ver",
    "víreis": "ver",
    "vírgulas": "vírgula",
    "víros": "vírus",
    "vísceras": "víscera",
    "víscida": "víscido",
    "víscidas": "víscido",
    "víscidos": "víscido",
    "vísporas": "víspora",
    "vísseis": "ver",
    "víssemos": "ver",
    "vítimas": "vítima",
    "vítrea": "vítreo",
    "vítreas": "vítreo",
    "vítreos": "vítreo",
    "vítulos": "vítulo",
    "vívulas": "vívula",
    "vólei": "voleibol",
    "vóltios": "vóltio",
    "vóltzias": "vóltzia",
    "vólvulos": "vólvulo",
    "vómeres": "vómer",
    "vómicas": "vómica",
    "vómitos": "vómito",
    "vórmios": "vórmio",
    "vórtices": "vórtice",
    "wades": "wad",
    "wagneriana": "wagneriano",
    "wagnerianas": "wagneriano",
    "wagnerianos": "wagneriano",
    "wagnerismos": "wagnerismo",
    "wagnerites": "wagnerite",
    "walchias": "walchia",
    "washingtoniana": "washingtoniano",
    "washingtonianas": "washingtoniano",
    "washingtonianos": "washingtoniano",
    "watts": "watt",
    "wattímetros": "wattímetro",
    "wealdianos": "wealdiano",
    "weberiana": "weberiano",
    "weberianas": "weberiano",
    "weberianos": "weberiano",
    "webers": "weber",
    "wellingtoniana": "wellingtoniano",
    "wellingtonianas": "wellingtoniano",
    "wellingtonianos": "wellingtoniano",
    "wellingtónias": "wellingtónia",
    "wenlockianos": "wenlockiano",
    "werfenianos": "werfeniano",
    "westerns": "western",
    "westminsteriana": "westminsteriano",
    "westminsterianas": "westminsteriano",
    "westminsterianos": "westminsteriano",
    "whiskies": "whisky",
    "whists": "whist",
    "wiclefismos": "wiclefismo",
    "wiclefistas": "wiclefista",
    "wilsoniana": "wilsoniano",
    "wilsonianas": "wilsoniano",
    "wilsonianos": "wilsoniano",
    "windsoriana": "windsoriano",
    "windsorianas": "windsoriano",
    "windsorianos": "windsoriano",
    "workshops": "workshop",
    "wronskiana": "wronskiano",
    "wronskianas": "wronskiano",
    "wronskianos": "wronskiano",
    "wurtzites": "wurtzite",
    "ww": "w",
    "xaboca": "xaboco",
    "xabocas": "xaboco",
    "xabocos": "xaboco",
    "xabouca": "xabouco",
    "xaboucada": "xaboucar",
    "xaboucadas": "xaboucar",
    "xaboucado": "xaboucar",
    "xaboucados": "xaboucar",
    "xaboucai": "xaboucar",
    "xaboucais": "xaboucar",
    "xaboucam": "xaboucar",
    "xaboucamo": "xaboucar",
    "xaboucamos": "xaboucar",
    "xaboucando": "xaboucar",
    "xaboucara": "xaboucar",
    "xaboucaram": "xaboucar",
    "xaboucaras": "xaboucar",
    "xaboucarde": "xaboucar",
    "xaboucardes": "xaboucar",
    "xaboucare": "xaboucar",
    "xaboucarei": "xaboucar",
    "xaboucareis": "xaboucar",
    "xaboucarem": "xaboucar",
    "xaboucaremos": "xaboucar",
    "xaboucares": "xaboucar",
    "xaboucaria": "xaboucar",
    "xaboucariam": "xaboucar",
    "xaboucarias": "xaboucar",
    "xaboucarmo": "xaboucar",
    "xaboucarmos": "xaboucar",
    "xaboucará": "xaboucar",
    "xaboucarás": "xaboucar",
    "xaboucarão": "xaboucar",
    "xaboucaríamos": "xaboucar",
    "xaboucaríeis": "xaboucar",
    "xaboucas": "xabouco",
    "xaboucasse": "xaboucar",
    "xaboucassem": "xaboucar",
    "xaboucasses": "xaboucar",
    "xaboucaste": "xaboucar",
    "xaboucastes": "xaboucar",
    "xaboucava": "xaboucar",
    "xaboucavam": "xaboucar",
    "xaboucavas": "xaboucar",
    "xabouco": "xaboucar",
    "xaboucos": "xabouco",
    "xaboucou": "xaboucar",
    "xaboucá": "xaboucar",
    "xaboucámo": "xaboucar",
    "xaboucámos": "xaboucar",
    "xaboucáramo": "xaboucar",
    "xaboucáramos": "xaboucar",
    "xaboucárei": "xaboucar",
    "xaboucáreis": "xaboucar",
    "xaboucásseis": "xaboucar",
    "xaboucássemos": "xaboucar",
    "xaboucávamo": "xaboucar",
    "xaboucávamos": "xaboucar",
    "xaboucávei": "xaboucar",
    "xaboucáveis": "xaboucar",
    "xabouque": "xaboucar",
    "xabouquei": "xaboucar",
    "xabouqueira": "xabouqueiro",
    "xabouqueiras": "xabouqueiro",
    "xabouqueiros": "xabouqueiro",
    "xabouqueis": "xaboucar",
    "xabouquem": "xaboucar",
    "xabouquemo": "xaboucar",
    "xabouquemos": "xaboucar",
    "xabouques": "xaboucar",
    "xabraques": "xabraque",
    "xabregana": "xabregano",
    "xabreganas": "xabregano",
    "xabreganos": "xabregano",
    "xabregas": "xabrega",
    "xacoca": "xacoco",
    "xacocas": "xacoco",
    "xacocos": "xacoco",
    "xadreza": "xadrezar",
    "xadrezada": "xadrezar",
    "xadrezadas": "xadrezar",
    "xadrezado": "xadrezar",
    "xadrezados": "xadrezar",
    "xadrezai": "xadrezar",
    "xadrezais": "xadrezar",
    "xadrezam": "xadrezar",
    "xadrezamo": "xadrezar",
    "xadrezamos": "xadrezar",
    "xadrezando": "xadrezar",
    "xadrezara": "xadrezar",
    "xadrezaram": "xadrezar",
    "xadrezaras": "xadrezar",
    "xadrezarde": "xadrezar",
    "xadrezardes": "xadrezar",
    "xadrezare": "xadrezar",
    "xadrezarei": "xadrezar",
    "xadrezareis": "xadrezar",
    "xadrezarem": "xadrezar",
    "xadrezaremos": "xadrezar",
    "xadrezares": "xadrezar",
    "xadrezaria": "xadrezar",
    "xadrezariam": "xadrezar",
    "xadrezarias": "xadrezar",
    "xadrezarmo": "xadrezar",
    "xadrezarmos": "xadrezar",
    "xadrezará": "xadrezar",
    "xadrezarás": "xadrezar",
    "xadrezarão": "xadrezar",
    "xadrezaríamos": "xadrezar",
    "xadrezaríeis": "xadrezar",
    "xadrezas": "xadrezar",
    "xadrezasse": "xadrezar",
    "xadrezassem": "xadrezar",
    "xadrezasses": "xadrezar",
    "xadrezaste": "xadrezar",
    "xadrezastes": "xadrezar",
    "xadrezava": "xadrezar",
    "xadrezavam": "xadrezar",
    "xadrezavas": "xadrezar",
    "xadreze": "xadrezar",
    "xadrezei": "xadrezar",
    "xadrezeis": "xadrezar",
    "xadrezem": "xadrezar",
    "xadrezemo": "xadrezar",
    "xadrezemos": "xadrezar",
    "xadrezes": "xadrezar",
    "xadrezinho": "xadrez",
    "xadrezinhos": "xadrez",
    "xadrezito": "xadrez",
    "xadrezitos": "xadrez",
    "xadrezo": "xadrezar",
    "xadrezou": "xadrezar",
    "xadrezá": "xadrezar",
    "xadrezámo": "xadrezar",
    "xadrezámos": "xadrezar",
    "xadrezáramo": "xadrezar",
    "xadrezáramos": "xadrezar",
    "xadrezárei": "xadrezar",
    "xadrezáreis": "xadrezar",
    "xadrezásseis": "xadrezar",
    "xadrezássemos": "xadrezar",
    "xadrezávamo": "xadrezar",
    "xadrezávamos": "xadrezar",
    "xadrezávei": "xadrezar",
    "xadrezáveis": "xadrezar",
    "xafarrazes": "xafarraz",
    "xaguões": "xaguão",
    "xaias": "xaia",
    "xailes": "xaile",
    "xaiméis": "xaimel",
    "xaireis": "xairel",
    "xairelada": "xairelado",
    "xaireladas": "xairelado",
    "xairelados": "xairelado",
    "xairéis": "xairel",
    "xaiás": "xaiá",
    "xajás": "xajá",
    "xales": "xale",
    "xalezinho": "xale",
    "xalezinhos": "xale",
    "xalezito": "xale",
    "xalezitos": "xale",
    "xamanes": "xamane",
    "xamanismos": "xamanismo",
    "xamanistas": "xamanista",
    "xamanística": "xamanístico",
    "xamanísticas": "xamanístico",
    "xamanísticos": "xamanístico",
    "xamas": "xama",
    "xamatas": "xamata",
    "xamates": "xamate",
    "xamãs": "xamã",
    "xangaenses": "xangaense",
    "xangaêsa": "xangaês",
    "xangaêsas": "xangaês",
    "xangaêses": "xangaês",
    "xangaêss": "xangaês",
    "xangaína": "xangaíno",
    "xangaínas": "xangaíno",
    "xangaínos": "xangaíno",
    "xantatos": "xantato",
    "xantelomas": "xanteloma",
    "xantenas": "xantena",
    "xanteínas": "xanteína",
    "xantinas": "xantina",
    "xantocarotinas": "xantocarotina",
    "xantocromias": "xantocromia",
    "xantocéfala": "xantocéfalo",
    "xantocéfalas": "xantocéfalo",
    "xantocéfalos": "xantocéfalo",
    "xantodermias": "xantodermia",
    "xantofilas": "xantofila",
    "xantogénica": "xantogénico",
    "xantogénicas": "xantogénico",
    "xantogénicos": "xantogénico",
    "xantogénios": "xantogénio",
    "xantoleucitos": "xantoleucito",
    "xantomas": "xantoma",
    "xantomatoses": "xantomatose",
    "xantoplasmas": "xantoplasma",
    "xantoplastídios": "xantoplastídio",
    "xantopsias": "xantopsia",
    "xantos": "xanto",
    "xantoses": "xantose",
    "xantoxiláceas": "xantoxilácea",
    "xantoxíleas": "xantoxílea",
    "xantólitos": "xantólito",
    "xantóxila": "xantóxilo",
    "xantóxilas": "xantóxilo",
    "xantóxilos": "xantóxilo",
    "xantúrias": "xantúria",
    "xaputas": "xaputa",
    "xaqueada": "xaquear",
    "xaqueadas": "xaquear",
    "xaqueado": "xaquear",
    "xaqueados": "xaquear",
    "xaqueai": "xaquear",
    "xaqueais": "xaquear",
    "xaqueamo": "xaquear",
    "xaqueamos": "xaquear",
    "xaqueando": "xaquear",
    "xaqueara": "xaquear",
    "xaquearam": "xaquear",
    "xaquearas": "xaquear",
    "xaquearde": "xaquear",
    "xaqueardes": "xaquear",
    "xaqueare": "xaquear",
    "xaquearei": "xaquear",
    "xaqueareis": "xaquear",
    "xaquearem": "xaquear",
    "xaquearemos": "xaquear",
    "xaqueares": "xaquear",
    "xaquearia": "xaquear",
    "xaqueariam": "xaquear",
    "xaquearias": "xaquear",
    "xaquearmo": "xaquear",
    "xaquearmos": "xaquear",
    "xaqueará": "xaquear",
    "xaquearás": "xaquear",
    "xaquearão": "xaquear",
    "xaquearíamos": "xaquear",
    "xaquearíeis": "xaquear",
    "xaqueasse": "xaquear",
    "xaqueassem": "xaquear",
    "xaqueasses": "xaquear",
    "xaqueaste": "xaquear",
    "xaqueastes": "xaquear",
    "xaqueava": "xaquear",
    "xaqueavam": "xaquear",
    "xaqueavas": "xaquear",
    "xaqueei": "xaquear",
    "xaqueeis": "xaquear",
    "xaqueemo": "xaquear",
    "xaqueemos": "xaquear",
    "xaqueia": "xaquear",
    "xaqueiam": "xaquear",
    "xaqueias": "xaquear",
    "xaqueie": "xaquear",
    "xaqueiem": "xaquear",
    "xaqueies": "xaquear",
    "xaqueio": "xaquear",
    "xaqueou": "xaquear",
    "xaques": "xaque",
    "xaqueá": "xaquear",
    "xaqueámo": "xaquear",
    "xaqueámos": "xaquear",
    "xaqueáramo": "xaquear",
    "xaqueáramos": "xaquear",
    "xaqueárei": "xaquear",
    "xaqueáreis": "xaquear",
    "xaqueásseis": "xaquear",
    "xaqueássemos": "xaquear",
    "xaqueávamo": "xaquear",
    "xaqueávamos": "xaquear",
    "xaqueávei": "xaquear",
    "xaqueáveis": "xaquear",
    "xarafa": "xarafo",
    "xarafas": "xarafo",
    "xarafins": "xarafim",
    "xarafos": "xarafo",
    "xaras": "xara",
    "xaraus": "xarau",
    "xardas": "xarda",
    "xardosa": "xardoso",
    "xardosas": "xardoso",
    "xardosos": "xardoso",
    "xareletes": "xarelete",
    "xaretas": "xareta",
    "xarifados": "xarifado",
    "xarifes": "xarife",
    "xarocos": "xaroco",
    "xaropa": "xaropar",
    "xaropada": "xaropar",
    "xaropadas": "xaropar",
    "xaropado": "xaropar",
    "xaropados": "xaropar",
    "xaropai": "xaropar",
    "xaropais": "xaropar",
    "xaropam": "xaropar",
    "xaropamo": "xaropar",
    "xaropamos": "xaropar",
    "xaropando": "xaropar",
    "xaropara": "xaropar",
    "xaroparam": "xaropar",
    "xaroparas": "xaropar",
    "xaroparde": "xaropar",
    "xaropardes": "xaropar",
    "xaropare": "xaropar",
    "xaroparei": "xaropar",
    "xaropareis": "xaropar",
    "xaroparem": "xaropar",
    "xaroparemos": "xaropar",
    "xaropares": "xaropar",
    "xaroparia": "xaropar",
    "xaropariam": "xaropar",
    "xaroparias": "xaropar",
    "xaroparmo": "xaropar",
    "xaroparmos": "xaropar",
    "xaropará": "xaropar",
    "xaroparás": "xaropar",
    "xaroparão": "xaropar",
    "xaroparíamos": "xaropar",
    "xaroparíeis": "xaropar",
    "xaropas": "xaropar",
    "xaropasse": "xaropar",
    "xaropassem": "xaropar",
    "xaropasses": "xaropar",
    "xaropaste": "xaropar",
    "xaropastes": "xaropar",
    "xaropava": "xaropar",
    "xaropavam": "xaropar",
    "xaropavas": "xaropar",
    "xarope": "xaropar",
    "xaropei": "xaropar",
    "xaropeis": "xaropar",
    "xaropem": "xaropar",
    "xaropemo": "xaropar",
    "xaropemos": "xaropar",
    "xaropes": "xarope",
    "xaropo": "xaropar",
    "xaroposa": "xaroposo",
    "xaroposas": "xaroposo",
    "xaroposos": "xaroposo",
    "xaropou": "xaropar",
    "xaropá": "xaropar",
    "xaropámo": "xaropar",
    "xaropámos": "xaropar",
    "xaropáramo": "xaropar",
    "xaropáramos": "xaropar",
    "xaropárei": "xaropar",
    "xaropáreis": "xaropar",
    "xaropásseis": "xaropar",
    "xaropássemos": "xaropar",
    "xaropávamo": "xaropar",
    "xaropávamos": "xaropar",
    "xaropávei": "xaropar",
    "xaropáveis": "xaropar",
    "xarrascas": "xarrasca",
    "xarrocos": "xarroco",
    "xarás": "xará",
    "xaréis": "xarel",
    "xaréns": "xarém",
    "xaréus": "xaréu",
    "xates": "xate",
    "xauteres": "xauter",
    "xavantes": "xavante",
    "xavecos": "xaveco",
    "xaís": "xaí",
    "xecados": "xecado",
    "xelindrós": "xelindró",
    "xelins": "xelim",
    "xelmas": "xelma",
    "xenartos": "xenarto",
    "xenartra": "xenartro",
    "xenartras": "xenartro",
    "xenartros": "xenartro",
    "xenatos": "xenato",
    "xenelasias": "xenelasia",
    "xenobioses": "xenobiose",
    "xenodontes": "xenodonte",
    "xenofilias": "xenofilia",
    "xenofobias": "xenofobia",
    "xenofobismos": "xenofobismo",
    "xenologias": "xenologia",
    "xenomanias": "xenomania",
    "xenomórfica": "xenomórfico",
    "xenomórficas": "xenomórfico",
    "xenomórficos": "xenomórfico",
    "xenxéns": "xenxém",
    "xenófila": "xenófilo",
    "xenófilas": "xenófilo",
    "xenófilos": "xenófilo",
    "xenófoba": "xenófobo",
    "xenófobas": "xenófobo",
    "xenófobos": "xenófobo",
    "xenólitos": "xenólito",
    "xenótimos": "xenótimo",
    "xeques": "xeque",
    "xerafins": "xerafim",
    "xereta": "xeretar",
    "xeretada": "xeretar",
    "xeretadas": "xeretar",
    "xeretado": "xeretar",
    "xeretados": "xeretar",
    "xeretai": "xeretar",
    "xeretais": "xeretar",
    "xeretam": "xeretar",
    "xeretamo": "xeretar",
    "xeretamos": "xeretar",
    "xeretando": "xeretar",
    "xeretara": "xeretar",
    "xeretaram": "xeretar",
    "xeretaras": "xeretar",
    "xeretarde": "xeretar",
    "xeretardes": "xeretar",
    "xeretare": "xeretar",
    "xeretarei": "xeretar",
    "xeretareis": "xeretar",
    "xeretarem": "xeretar",
    "xeretaremos": "xeretar",
    "xeretares": "xeretar",
    "xeretaria": "xeretar",
    "xeretariam": "xeretar",
    "xeretarias": "xeretar",
    "xeretarmo": "xeretar",
    "xeretarmos": "xeretar",
    "xeretará": "xeretar",
    "xeretarás": "xeretar",
    "xeretarão": "xeretar",
    "xeretaríamos": "xeretar",
    "xeretaríeis": "xeretar",
    "xeretas": "xeretar",
    "xeretasse": "xeretar",
    "xeretassem": "xeretar",
    "xeretasses": "xeretar",
    "xeretaste": "xeretar",
    "xeretastes": "xeretar",
    "xeretava": "xeretar",
    "xeretavam": "xeretar",
    "xeretavas": "xeretar",
    "xerete": "xeretar",
    "xeretei": "xeretar",
    "xereteis": "xeretar",
    "xeretem": "xeretar",
    "xeretemo": "xeretar",
    "xeretemos": "xeretar",
    "xeretes": "xeretar",
    "xereto": "xeretar",
    "xeretou": "xeretar",
    "xeretá": "xeretar",
    "xeretámo": "xeretar",
    "xeretámos": "xeretar",
    "xeretáramo": "xeretar",
    "xeretáramos": "xeretar",
    "xeretárei": "xeretar",
    "xeretáreis": "xeretar",
    "xeretásseis": "xeretar",
    "xeretássemos": "xeretar",
    "xeretávamo": "xeretar",
    "xeretávamos": "xeretar",
    "xeretávei": "xeretar",
    "xeretáveis": "xeretar",
    "xerezes": "xerez",
    "xergas": "xerga",
    "xergões": "xergão",
    "xerifados": "xerifado",
    "xerifes": "xerife",
    "xerifina": "xerifino",
    "xerifinas": "xerifino",
    "xerifinos": "xerifino",
    "xerimbabos": "xerimbabo",
    "xeringosas": "xeringosa",
    "xeringueiras": "xeringueira",
    "xeroca": "xerocar",
    "xerocada": "xerocar",
    "xerocadas": "xerocar",
    "xerocado": "xerocar",
    "xerocados": "xerocar",
    "xerocai": "xerocar",
    "xerocais": "xerocar",
    "xerocam": "xerocar",
    "xerocamo": "xerocar",
    "xerocamos": "xerocar",
    "xerocando": "xerocar",
    "xerocara": "xerocar",
    "xerocaram": "xerocar",
    "xerocaras": "xerocar",
    "xerocarde": "xerocar",
    "xerocardes": "xerocar",
    "xerocare": "xerocar",
    "xerocarei": "xerocar",
    "xerocareis": "xerocar",
    "xerocarem": "xerocar",
    "xerocaremos": "xerocar",
    "xerocares": "xerocar",
    "xerocaria": "xerocar",
    "xerocariam": "xerocar",
    "xerocarias": "xerocar",
    "xerocarmo": "xerocar",
    "xerocarmos": "xerocar",
    "xerocará": "xerocar",
    "xerocarás": "xerocar",
    "xerocarão": "xerocar",
    "xerocaríamos": "xerocar",
    "xerocaríeis": "xerocar",
    "xerocas": "xerocar",
    "xerocasse": "xerocar",
    "xerocassem": "xerocar",
    "xerocasses": "xerocar",
    "xerocaste": "xerocar",
    "xerocastes": "xerocar",
    "xerocava": "xerocar",
    "xerocavam": "xerocar",
    "xerocavas": "xerocar",
    "xeroco": "xerocar",
    "xerocou": "xerocar",
    "xerocá": "xerocar",
    "xerocámo": "xerocar",
    "xerocámos": "xerocar",
    "xerocáramo": "xerocar",
    "xerocáramos": "xerocar",
    "xerocárei": "xerocar",
    "xerocáreis": "xerocar",
    "xerocásseis": "xerocar",
    "xerocássemos": "xerocar",
    "xerocávamo": "xerocar",
    "xerocávamos": "xerocar",
    "xerocávei": "xerocar",
    "xerocáveis": "xerocar",
    "xerodermias": "xerodermia",
    "xerofagias": "xerofagia",
    "xerofilias": "xerofilia",
    "xerofitias": "xerofitia",
    "xerofitismos": "xerofitismo",
    "xeroftalmias": "xeroftalmia",
    "xeroftálmica": "xeroftálmico",
    "xeroftálmicas": "xeroftálmico",
    "xeroftálmicos": "xeroftálmico",
    "xerofítica": "xerofítico",
    "xerofíticas": "xerofítico",
    "xerofíticos": "xerofítico",
    "xerografias": "xerografia",
    "xerográfica": "xerográfico",
    "xerográficas": "xerográfico",
    "xerográficos": "xerográfico",
    "xeromas": "xeroma",
    "xeroque": "xerocar",
    "xeroquei": "xerocar",
    "xeroqueis": "xerocar",
    "xeroquem": "xerocar",
    "xeroquemo": "xerocar",
    "xeroquemos": "xerocar",
    "xeroques": "xerocar",
    "xerorradiografias": "xerorradiografia",
    "xeroses": "xerose",
    "xeroterma": "xerotermo",
    "xerotermas": "xerotermo",
    "xerotermos": "xerotermo",
    "xerumes": "xerume",
    "xeréns": "xerém",
    "xerófaga": "xerófago",
    "xerófagas": "xerófago",
    "xerófagos": "xerófago",
    "xerófila": "xerófilo",
    "xerófilas": "xerófilo",
    "xerófilos": "xerófilo",
    "xerófita": "xerófito",
    "xerófitas": "xerófito",
    "xerófitos": "xerófito",
    "xetas": "xeta",
    "xeuras": "xeura",
    "xevás": "xevá",
    "xexés": "xexé",
    "xexéus": "xexéu",
    "xibas": "xiba",
    "xicacas": "xicaca",
    "xicaradas": "xicarada",
    "xifiplastrões": "xifiplastrão",
    "xifirrinca": "xifirrinco",
    "xifirrincas": "xifirrinco",
    "xifirrincos": "xifirrinco",
    "xifisternos": "xifisterno",
    "xifoidiana": "xifoidiano",
    "xifoidianas": "xifoidiano",
    "xifoidianos": "xifoidiano",
    "xifopagias": "xifopagia",
    "xifosuros": "xifosuro",
    "xifíidas": "xifíida",
    "xifófila": "xifófilo",
    "xifófilas": "xifófilo",
    "xifófilos": "xifófilo",
    "xifógapa": "xifógapo",
    "xifógapas": "xifógapo",
    "xifógapos": "xifógapo",
    "xifóidea": "xifóideo",
    "xifóideas": "xifóideo",
    "xifóideos": "xifóideo",
    "xifóides": "xifóide",
    "xifópagos": "xifópago",
    "xigogos": "xigogo",
    "xiitas": "xiita",
    "xilarmónicos": "xilarmónico",
    "xilas": "xila",
    "xilemas": "xilema",
    "xilenos": "xileno",
    "xilidinas": "xilidina",
    "xilobálsamos": "xilobálsamo",
    "xilocarpos": "xilocarpo",
    "xiloculturas": "xilocultura",
    "xilofagias": "xilofagia",
    "xilofinistas": "xilofinista",
    "xilofones": "xilofone",
    "xilofórias": "xilofória",
    "xiloglifias": "xiloglifia",
    "xiloglífica": "xiloglífico",
    "xiloglíficas": "xiloglífico",
    "xiloglíficos": "xiloglífico",
    "xilografias": "xilografia",
    "xilogravada": "xilogravado",
    "xilogravadas": "xilogravado",
    "xilogravadora": "xilogravador",
    "xilogravadoras": "xilogravador",
    "xilogravadores": "xilogravador",
    "xilogravados": "xilogravado",
    "xilogravuras": "xilogravura",
    "xilogénios": "xilogénio",
    "xilolatrias": "xilolatria",
    "xilologias": "xilologia",
    "xilomancias": "xilomancia",
    "xilomas": "xiloma",
    "xilometrias": "xilometria",
    "xilopódios": "xilopódio",
    "xilos": "xilo",
    "xiloses": "xilose",
    "xilreus": "xilreu",
    "xilócopa": "xilócopo",
    "xilócopas": "xilócopo",
    "xilócopos": "xilócopo",
    "xilódias": "xilódia",
    "xilódios": "xilódio",
    "xilófaga": "xilófago",
    "xilófagas": "xilófago",
    "xilófagos": "xilófago",
    "xilófila": "xilófilo",
    "xilófilas": "xilófilo",
    "xilófilos": "xilófilo",
    "xilófitos": "xilófito",
    "xilóforos": "xilóforo",
    "xilógena": "xilógeno",
    "xilógenas": "xilógeno",
    "xilógenos": "xilógeno",
    "xilóglifa": "xilóglifo",
    "xilóglifas": "xilóglifo",
    "xilóglifos": "xilóglifo",
    "xilógrafa": "xilógrafo",
    "xilógrafas": "xilógrafo",
    "xilógrafos": "xilógrafo",
    "xilóides": "xilóide",
    "xilóis": "xilol",
    "xilólatras": "xilólatra",
    "xilólitos": "xilólito",
    "xilóloga": "xilólogo",
    "xilólogas": "xilólogo",
    "xilólogos": "xilólogo",
    "xilópias": "xilópia",
    "xilórgões": "xilórgão",
    "ximangos": "ximango",
    "ximarrões": "ximarrão",
    "ximbaúvas": "ximbaúva",
    "ximbeques": "ximbeque",
    "ximburus": "ximburu",
    "ximburés": "ximburé",
    "ximbutes": "ximbute",
    "xinga": "xingar",
    "xingada": "xingar",
    "xingadas": "xingar",
    "xingado": "xingar",
    "xingadora": "xingador",
    "xingadoras": "xingador",
    "xingadores": "xingador",
    "xingados": "xingar",
    "xingai": "xingar",
    "xingais": "xingar",
    "xingam": "xingar",
    "xingamentos": "xingamento",
    "xingamo": "xingar",
    "xingamos": "xingar",
    "xingando": "xingar",
    "xingara": "xingar",
    "xingaram": "xingar",
    "xingaras": "xingar",
    "xingarde": "xingar",
    "xingardes": "xingar",
    "xingare": "xingar",
    "xingarei": "xingar",
    "xingareis": "xingar",
    "xingarem": "xingar",
    "xingaremos": "xingar",
    "xingares": "xingar",
    "xingaria": "xingar",
    "xingariam": "xingar",
    "xingarias": "xingar",
    "xingarmo": "xingar",
    "xingarmos": "xingar",
    "xingará": "xingar",
    "xingarás": "xingar",
    "xingarão": "xingar",
    "xingaríamos": "xingar",
    "xingaríeis": "xingar",
    "xingas": "xingar",
    "xingasse": "xingar",
    "xingassem": "xingar",
    "xingasses": "xingar",
    "xingaste": "xingar",
    "xingastes": "xingar",
    "xingava": "xingar",
    "xingavam": "xingar",
    "xingavas": "xingar",
    "xingações": "xingação",
    "xingo": "xingar",
    "xingou": "xingar",
    "xingue": "xingar",
    "xinguei": "xingar",
    "xingueis": "xingar",
    "xinguem": "xingar",
    "xinguemo": "xingar",
    "xinguemos": "xingar",
    "xingues": "xingar",
    "xingá": "xingar",
    "xingámo": "xingar",
    "xingámos": "xingar",
    "xingáramo": "xingar",
    "xingáramos": "xingar",
    "xingárei": "xingar",
    "xingáreis": "xingar",
    "xingásseis": "xingar",
    "xingássemos": "xingar",
    "xingávamo": "xingar",
    "xingávamos": "xingar",
    "xingávei": "xingar",
    "xingáveis": "xingar",
    "xintoísmos": "xintoísmo",
    "xintoístas": "xintoísta",
    "xipos": "xipo",
    "xiquexiques": "xiquexique",
    "xiridáceas": "xiridácea",
    "xiriubeiras": "xiriubeira",
    "xirós": "xiró",
    "xises": "xis",
    "xisgaravizes": "xisgaraviz",
    "xistarcas": "xistarca",
    "xistenta": "xistento",
    "xistentas": "xistento",
    "xistentos": "xistento",
    "xistocarpa": "xistocarpo",
    "xistocarpas": "xistocarpo",
    "xistocarpos": "xistocarpo",
    "xistocristalina": "xistocristalino",
    "xistocristalinas": "xistocristalino",
    "xistocristalinos": "xistocristalino",
    "xistos": "xisto",
    "xistosa": "xistoso",
    "xistosas": "xistoso",
    "xistosidades": "xistosidade",
    "xistosos": "xistoso",
    "xistros": "xistro",
    "xistrópodes": "xistrópode",
    "xistóides": "xistóide",
    "xivaísmos": "xivaísmo",
    "xivaístas": "xivaísta",
    "xivaítas": "xivaíta",
    "xixicas": "xixica",
    "xixis": "xixi",
    "xixizinho": "xixi",
    "xixizinhos": "xixi",
    "xixizito": "xixi",
    "xixizitos": "xixi",
    "xixuãos": "xixuão",
    "xoca": "xocar",
    "xocada": "xocar",
    "xocadas": "xocar",
    "xocado": "xocar",
    "xocados": "xocar",
    "xocai": "xocar",
    "xocais": "xocar",
    "xocam": "xocar",
    "xocamo": "xocar",
    "xocamos": "xocar",
    "xocando": "xocar",
    "xocara": "xocar",
    "xocaram": "xocar",
    "xocaras": "xocar",
    "xocarde": "xocar",
    "xocardes": "xocar",
    "xocare": "xocar",
    "xocarei": "xocar",
    "xocareis": "xocar",
    "xocarem": "xocar",
    "xocaremos": "xocar",
    "xocares": "xocar",
    "xocaria": "xocar",
    "xocariam": "xocar",
    "xocarias": "xocar",
    "xocarmo": "xocar",
    "xocarmos": "xocar",
    "xocará": "xocar",
    "xocarás": "xocar",
    "xocarão": "xocar",
    "xocaríamos": "xocar",
    "xocaríeis": "xocar",
    "xocas": "xocar",
    "xocasse": "xocar",
    "xocassem": "xocar",
    "xocasses": "xocar",
    "xocaste": "xocar",
    "xocastes": "xocar",
    "xocava": "xocar",
    "xocavam": "xocar",
    "xocavas": "xocar",
    "xoco": "xocar",
    "xocou": "xocar",
    "xocá": "xocar",
    "xocámo": "xocar",
    "xocámos": "xocar",
    "xocáramo": "xocar",
    "xocáramos": "xocar",
    "xocárei": "xocar",
    "xocáreis": "xocar",
    "xocásseis": "xocar",
    "xocássemos": "xocar",
    "xocávamo": "xocar",
    "xocávamos": "xocar",
    "xocávei": "xocar",
    "xocáveis": "xocar",
    "xodós": "xodó",
    "xofrangos": "xofrango",
    "xoque": "xocar",
    "xoquei": "xocar",
    "xoqueis": "xocar",
    "xoquem": "xocar",
    "xoquemo": "xocar",
    "xoquemos": "xocar",
    "xoques": "xocar",
    "xorcas": "xorca",
    "xorda": "xordo",
    "xordas": "xordo",
    "xordos": "xordo",
    "xota": "xotar",
    "xotada": "xotar",
    "xotadas": "xotar",
    "xotado": "xotar",
    "xotados": "xotar",
    "xotai": "xotar",
    "xotais": "xotar",
    "xotam": "xotar",
    "xotamo": "xotar",
    "xotamos": "xotar",
    "xotando": "xotar",
    "xotara": "xotar",
    "xotaram": "xotar",
    "xotaras": "xotar",
    "xotarde": "xotar",
    "xotardes": "xotar",
    "xotare": "xotar",
    "xotarei": "xotar",
    "xotareis": "xotar",
    "xotarem": "xotar",
    "xotaremos": "xotar",
    "xotares": "xotar",
    "xotaria": "xotar",
    "xotariam": "xotar",
    "xotarias": "xotar",
    "xotarmo": "xotar",
    "xotarmos": "xotar",
    "xotará": "xotar",
    "xotarás": "xotar",
    "xotarão": "xotar",
    "xotaríamos": "xotar",
    "xotaríeis": "xotar",
    "xotas": "xotar",
    "xotasse": "xotar",
    "xotassem": "xotar",
    "xotasses": "xotar",
    "xotaste": "xotar",
    "xotastes": "xotar",
    "xotava": "xotar",
    "xotavam": "xotar",
    "xotavas": "xotar",
    "xote": "xotar",
    "xotei": "xotar",
    "xoteis": "xotar",
    "xotem": "xotar",
    "xotemo": "xotar",
    "xotemos": "xotar",
    "xotes": "xotar",
    "xoto": "xotar",
    "xotou": "xotar",
    "xotá": "xotar",
    "xotámo": "xotar",
    "xotámos": "xotar",
    "xotáramo": "xotar",
    "xotáramos": "xotar",
    "xotárei": "xotar",
    "xotáreis": "xotar",
    "xotásseis": "xotar",
    "xotássemos": "xotar",
    "xotávamo": "xotar",
    "xotávamos": "xotar",
    "xotávei": "xotar",
    "xotáveis": "xotar",
    "xucra": "xucro",
    "xucras": "xucro",
    "xucros": "xucro",
    "xumberga": "xumbergar",
    "xumbergada": "xumbergar",
    "xumbergadas": "xumbergar",
    "xumbergado": "xumbergar",
    "xumbergados": "xumbergar",
    "xumbergai": "xumbergar",
    "xumbergais": "xumbergar",
    "xumbergam": "xumbergar",
    "xumbergamo": "xumbergar",
    "xumbergamos": "xumbergar",
    "xumbergando": "xumbergar",
    "xumbergara": "xumbergar",
    "xumbergaram": "xumbergar",
    "xumbergaras": "xumbergar",
    "xumbergardes": "xumbergar",
    "xumbergarei": "xumbergar",
    "xumbergareis": "xumbergar",
    "xumbergarem": "xumbergar",
    "xumbergaremos": "xumbergar",
    "xumbergares": "xumbergar",
    "xumbergaria": "xumbergar",
    "xumbergariam": "xumbergar",
    "xumbergarias": "xumbergar",
    "xumbergarmo": "xumbergar",
    "xumbergarmos": "xumbergar",
    "xumbergará": "xumbergar",
    "xumbergarás": "xumbergar",
    "xumbergarão": "xumbergar",
    "xumbergaríamos": "xumbergar",
    "xumbergaríeis": "xumbergar",
    "xumbergas": "xumbergar",
    "xumbergasse": "xumbergar",
    "xumbergassem": "xumbergar",
    "xumbergasses": "xumbergar",
    "xumbergaste": "xumbergar",
    "xumbergastes": "xumbergar",
    "xumbergava": "xumbergar",
    "xumbergavam": "xumbergar",
    "xumbergavas": "xumbergar",
    "xumbergo": "xumbergar",
    "xumbergou": "xumbergar",
    "xumbergue": "xumbergar",
    "xumberguei": "xumbergar",
    "xumbergueis": "xumbergar",
    "xumberguem": "xumbergar",
    "xumberguemo": "xumbergar",
    "xumberguemos": "xumbergar",
    "xumbergues": "xumbergar",
    "xumbergámo": "xumbergar",
    "xumbergámos": "xumbergar",
    "xumbergáramo": "xumbergar",
    "xumbergáramos": "xumbergar",
    "xumbergáreis": "xumbergar",
    "xumbergásseis": "xumbergar",
    "xumbergássemos": "xumbergar",
    "xumbergávamo": "xumbergar",
    "xumbergávamos": "xumbergar",
    "xumbergáveis": "xumbergar",
    "xurreiras": "xurreira",
    "xuxas": "xuxa",
    "xuxos": "xuxo",
    "xués": "xué",
    "xx": "x",
    "xácaras": "xácara",
    "xácomas": "xácoma",
    "xágaras": "xágara",
    "xáquemas": "xáquema",
    "xáquimas": "xáquima",
    "xás": "xá",
    "xátrias": "xátria",
    "xávegas": "xávega",
    "xântica": "xântico",
    "xânticas": "xântico",
    "xânticos": "xântico",
    "xântios": "xântio",
    "xénios": "xénio",
    "xénons": "xénon",
    "xéus": "xéu",
    "xícaras": "xícara",
    "xífios": "xífio",
    "xílones": "xílon",
    "xística": "xístico",
    "xísticas": "xístico",
    "xísticos": "xístico",
    "yankees": "yankee",
    "yogurtes": "yogurte",
    "yy": "y",
    "zabelês": "zabelê",
    "zabonas": "zabona",
    "zabras": "zabra",
    "zabumba": "zabumbar",
    "zabumbada": "zabumbar",
    "zabumbadas": "zabumbar",
    "zabumbado": "zabumbar",
    "zabumbados": "zabumbar",
    "zabumbai": "zabumbar",
    "zabumbais": "zabumbar",
    "zabumbam": "zabumbar",
    "zabumbamo": "zabumbar",
    "zabumbamos": "zabumbar",
    "zabumbando": "zabumbar",
    "zabumbara": "zabumbar",
    "zabumbaram": "zabumbar",
    "zabumbaras": "zabumbar",
    "zabumbarde": "zabumbar",
    "zabumbardes": "zabumbar",
    "zabumbare": "zabumbar",
    "zabumbarei": "zabumbar",
    "zabumbareis": "zabumbar",
    "zabumbarem": "zabumbar",
    "zabumbaremos": "zabumbar",
    "zabumbares": "zabumbar",
    "zabumbaria": "zabumbar",
    "zabumbariam": "zabumbar",
    "zabumbarias": "zabumbar",
    "zabumbarmo": "zabumbar",
    "zabumbarmos": "zabumbar",
    "zabumbará": "zabumbar",
    "zabumbarás": "zabumbar",
    "zabumbarão": "zabumbar",
    "zabumbaríamos": "zabumbar",
    "zabumbaríeis": "zabumbar",
    "zabumbas": "zabumbar",
    "zabumbasse": "zabumbar",
    "zabumbassem": "zabumbar",
    "zabumbasses": "zabumbar",
    "zabumbaste": "zabumbar",
    "zabumbastes": "zabumbar",
    "zabumbava": "zabumbar",
    "zabumbavam": "zabumbar",
    "zabumbavas": "zabumbar",
    "zabumbe": "zabumbar",
    "zabumbei": "zabumbar",
    "zabumbeira": "zabumbeiro",
    "zabumbeiras": "zabumbeiro",
    "zabumbeiros": "zabumbeiro",
    "zabumbeis": "zabumbar",
    "zabumbem": "zabumbar",
    "zabumbemo": "zabumbar",
    "zabumbemos": "zabumbar",
    "zabumbes": "zabumbar",
    "zabumbo": "zabumbar",
    "zabumbou": "zabumbar",
    "zabumbá": "zabumbar",
    "zabumbámo": "zabumbar",
    "zabumbámos": "zabumbar",
    "zabumbáramo": "zabumbar",
    "zabumbáramos": "zabumbar",
    "zabumbárei": "zabumbar",
    "zabumbáreis": "zabumbar",
    "zabumbásseis": "zabumbar",
    "zabumbássemos": "zabumbar",
    "zabumbávamo": "zabumbar",
    "zabumbávamos": "zabumbar",
    "zabumbávei": "zabumbar",
    "zabumbáveis": "zabumbar",
    "zaburreiras": "zaburreira",
    "zaburreiros": "zaburreiro",
    "zaburros": "zaburro",
    "zacas": "zaca",
    "zacos": "zaco",
    "zacuns": "zacum",
    "zadonas": "zadona",
    "zadrezistas": "zadrezista",
    "zagaia": "zagaiar",
    "zagaiada": "zagaiar",
    "zagaiadas": "zagaiar",
    "zagaiado": "zagaiar",
    "zagaiados": "zagaiar",
    "zagaiai": "zagaiar",
    "zagaiais": "zagaiar",
    "zagaiam": "zagaiar",
    "zagaiamo": "zagaiar",
    "zagaiamos": "zagaiar",
    "zagaiando": "zagaiar",
    "zagaiara": "zagaiar",
    "zagaiaram": "zagaiar",
    "zagaiaras": "zagaiar",
    "zagaiarde": "zagaiar",
    "zagaiardes": "zagaiar",
    "zagaiare": "zagaiar",
    "zagaiarei": "zagaiar",
    "zagaiareis": "zagaiar",
    "zagaiarem": "zagaiar",
    "zagaiaremos": "zagaiar",
    "zagaiares": "zagaiar",
    "zagaiaria": "zagaiar",
    "zagaiariam": "zagaiar",
    "zagaiarias": "zagaiar",
    "zagaiarmo": "zagaiar",
    "zagaiarmos": "zagaiar",
    "zagaiará": "zagaiar",
    "zagaiarás": "zagaiar",
    "zagaiarão": "zagaiar",
    "zagaiaríamos": "zagaiar",
    "zagaiaríeis": "zagaiar",
    "zagaias": "zagaiar",
    "zagaiasse": "zagaiar",
    "zagaiassem": "zagaiar",
    "zagaiasses": "zagaiar",
    "zagaiaste": "zagaiar",
    "zagaiastes": "zagaiar",
    "zagaiava": "zagaiar",
    "zagaiavam": "zagaiar",
    "zagaiavas": "zagaiar",
    "zagaie": "zagaiar",
    "zagaiei": "zagaiar",
    "zagaieira": "zagaieiro",
    "zagaieiras": "zagaieiro",
    "zagaieiros": "zagaieiro",
    "zagaieis": "zagaiar",
    "zagaiem": "zagaiar",
    "zagaiemo": "zagaiar",
    "zagaiemos": "zagaiar",
    "zagaies": "zagaiar",
    "zagaio": "zagaiar",
    "zagaiou": "zagaiar",
    "zagais": "zagal",
    "zagaiá": "zagaiar",
    "zagaiámo": "zagaiar",
    "zagaiámos": "zagaiar",
    "zagaiáramo": "zagaiar",
    "zagaiáramos": "zagaiar",
    "zagaiárei": "zagaiar",
    "zagaiáreis": "zagaiar",
    "zagaiásseis": "zagaiar",
    "zagaiássemos": "zagaiar",
    "zagaiávamo": "zagaiar",
    "zagaiávamos": "zagaiar",
    "zagaiávei": "zagaiar",
    "zagaiáveis": "zagaiar",
    "zagala": "zagal",
    "zagalas": "zagal",
    "zagalotes": "zagalote",
    "zagas": "zaga",
    "zagatais": "zagatai",
    "zagatés": "zagaté",
    "zagores": "zagor",
    "zagorra": "zagorro",
    "zagorras": "zagorro",
    "zagorrina": "zagorrino",
    "zagorrinas": "zagorrino",
    "zagorrinos": "zagorrino",
    "zagorros": "zagorro",
    "zagraísmos": "zagraísmo",
    "zagres": "zagre",
    "zagucha": "zagucho",
    "zaguchas": "zagucho",
    "zaguchos": "zagucho",
    "zagueiros": "zagueiro",
    "zaguncha": "zagunchar",
    "zagunchada": "zagunchar",
    "zagunchadas": "zagunchar",
    "zagunchado": "zagunchar",
    "zagunchados": "zagunchar",
    "zagunchai": "zagunchar",
    "zagunchais": "zagunchar",
    "zaguncham": "zagunchar",
    "zagunchamo": "zagunchar",
    "zagunchamos": "zagunchar",
    "zagunchando": "zagunchar",
    "zagunchara": "zagunchar",
    "zaguncharam": "zagunchar",
    "zaguncharas": "zagunchar",
    "zaguncharde": "zagunchar",
    "zagunchardes": "zagunchar",
    "zagunchare": "zagunchar",
    "zaguncharei": "zagunchar",
    "zagunchareis": "zagunchar",
    "zaguncharem": "zagunchar",
    "zaguncharemos": "zagunchar",
    "zagunchares": "zagunchar",
    "zaguncharia": "zagunchar",
    "zagunchariam": "zagunchar",
    "zaguncharias": "zagunchar",
    "zaguncharmo": "zagunchar",
    "zaguncharmos": "zagunchar",
    "zagunchará": "zagunchar",
    "zaguncharás": "zagunchar",
    "zaguncharão": "zagunchar",
    "zaguncharíamos": "zagunchar",
    "zaguncharíeis": "zagunchar",
    "zagunchas": "zagunchar",
    "zagunchasse": "zagunchar",
    "zagunchassem": "zagunchar",
    "zagunchasses": "zagunchar",
    "zagunchaste": "zagunchar",
    "zagunchastes": "zagunchar",
    "zagunchava": "zagunchar",
    "zagunchavam": "zagunchar",
    "zagunchavas": "zagunchar",
    "zagunche": "zagunchar",
    "zagunchei": "zagunchar",
    "zaguncheis": "zagunchar",
    "zagunchem": "zagunchar",
    "zagunchemo": "zagunchar",
    "zagunchemos": "zagunchar",
    "zagunches": "zagunchar",
    "zaguncho": "zagunchar",
    "zagunchos": "zaguncho",
    "zagunchou": "zagunchar",
    "zagunchá": "zagunchar",
    "zagunchámo": "zagunchar",
    "zagunchámos": "zagunchar",
    "zaguncháramo": "zagunchar",
    "zaguncháramos": "zagunchar",
    "zagunchárei": "zagunchar",
    "zaguncháreis": "zagunchar",
    "zagunchásseis": "zagunchar",
    "zagunchássemos": "zagunchar",
    "zagunchávamo": "zagunchar",
    "zagunchávamos": "zagunchar",
    "zagunchávei": "zagunchar",
    "zaguncháveis": "zagunchar",
    "zaidas": "zaida",
    "zaina": "zaino",
    "zainas": "zaino",
    "zainos": "zaino",
    "zairas": "zaira",
    "zairenses": "zairense",
    "zamas": "zama",
    "zamba": "zambo",
    "zambaia": "zambaio",
    "zambaias": "zambaio",
    "zambaios": "zambaio",
    "zambanas": "zambana",
    "zambas": "zambo",
    "zambeques": "zambeque",
    "zambetas": "zambeta",
    "zambiana": "zambiano",
    "zambianas": "zambiano",
    "zambianos": "zambiano",
    "zamboas": "zamboa",
    "zamboeiras": "zamboeira",
    "zamborradas": "zamborrada",
    "zambos": "zambo",
    "zambra": "zambro",
    "zambralhos": "zambralho",
    "zambras": "zambro",
    "zambros": "zambro",
    "zambucos": "zambuco",
    "zambujais": "zambujal",
    "zambujeiros": "zambujeiro",
    "zambujos": "zambujo",
    "zambulhas": "zambulha",
    "zambulheiras": "zambulheira",
    "zamias": "zamia",
    "zamiáceas": "zamiácea",
    "zampa": "zampar",
    "zampada": "zampar",
    "zampadas": "zampar",
    "zampado": "zampar",
    "zampados": "zampar",
    "zampai": "zampar",
    "zampais": "zampar",
    "zampam": "zampar",
    "zampamo": "zampar",
    "zampamos": "zampar",
    "zampando": "zampar",
    "zampara": "zampar",
    "zamparam": "zampar",
    "zamparas": "zampar",
    "zamparde": "zampar",
    "zampardes": "zampar",
    "zampare": "zampar",
    "zamparei": "zampar",
    "zampareis": "zampar",
    "zamparem": "zampar",
    "zamparemos": "zampar",
    "zampares": "zampar",
    "zamparia": "zampar",
    "zampariam": "zampar",
    "zamparias": "zampar",
    "zamparinas": "zamparina",
    "zamparmo": "zampar",
    "zamparmos": "zampar",
    "zampará": "zampar",
    "zamparás": "zampar",
    "zamparão": "zampar",
    "zamparíamos": "zampar",
    "zamparíeis": "zampar",
    "zampas": "zampar",
    "zampasse": "zampar",
    "zampassem": "zampar",
    "zampasses": "zampar",
    "zampaste": "zampar",
    "zampastes": "zampar",
    "zampava": "zampar",
    "zampavam": "zampar",
    "zampavas": "zampar",
    "zampe": "zampar",
    "zampei": "zampar",
    "zampeis": "zampar",
    "zampem": "zampar",
    "zampemo": "zampar",
    "zampemos": "zampar",
    "zampes": "zampar",
    "zampo": "zampar",
    "zampou": "zampar",
    "zampá": "zampar",
    "zampámo": "zampar",
    "zampámos": "zampar",
    "zampáramo": "zampar",
    "zampáramos": "zampar",
    "zampárei": "zampar",
    "zampáreis": "zampar",
    "zampásseis": "zampar",
    "zampássemos": "zampar",
    "zampávamo": "zampar",
    "zampávamos": "zampar",
    "zampávei": "zampar",
    "zampáveis": "zampar",
    "zamumos": "zamumo",
    "zanagas": "zanaga",
    "zanagos": "zanago",
    "zanga": "zangar",
    "zangada": "zangar",
    "zangadas": "zangar",
    "zangadazinha": "zangado",
    "zangadazinhas": "zangado",
    "zangadazita": "zangado",
    "zangadazitas": "zangado",
    "zangadinha": "zangado",
    "zangadinhas": "zangado",
    "zangadinho": "zangado",
    "zangadinhos": "zangado",
    "zangadita": "zangado",
    "zangaditas": "zangado",
    "zangadito": "zangado",
    "zangaditos": "zangado",
    "zangado": "zangar",
    "zangadora": "zangador",
    "zangadoras": "zangador",
    "zangadores": "zangador",
    "zangados": "zangar",
    "zangadozinho": "zangado",
    "zangadozinhos": "zangado",
    "zangadozito": "zangado",
    "zangadozitos": "zangado",
    "zangadíssima": "zangado",
    "zangadíssimas": "zangado",
    "zangadíssimo": "zangado",
    "zangadíssimos": "zangado",
    "zangai": "zangar",
    "zangais": "zangar",
    "zangalha": "zangalho",
    "zangalhas": "zangalho",
    "zangalhona": "zangalhão",
    "zangalhonas": "zangalhão",
    "zangalhos": "zangalho",
    "zangalhões": "zangalhão",
    "zangam": "zangar",
    "zangamo": "zangar",
    "zangamos": "zangar",
    "zangando": "zangar",
    "zangara": "zangar",
    "zangaralhona": "zangaralhão",
    "zangaralhonas": "zangaralhão",
    "zangaralhões": "zangaralhão",
    "zangaram": "zangar",
    "zangaras": "zangar",
    "zangarde": "zangar",
    "zangardes": "zangar",
    "zangare": "zangar",
    "zangarei": "zangar",
    "zangareis": "zangar",
    "zangarelhas": "zangarelha",
    "zangarelhos": "zangarelho",
    "zangarem": "zangar",
    "zangaremos": "zangar",
    "zangares": "zangar",
    "zangaria": "zangar",
    "zangariam": "zangar",
    "zangarias": "zangar",
    "zangarilha": "zangarilho",
    "zangarilhada": "zangarilhar",
    "zangarilhadas": "zangarilhar",
    "zangarilhado": "zangarilhar",
    "zangarilhados": "zangarilhar",
    "zangarilhai": "zangarilhar",
    "zangarilhais": "zangarilhar",
    "zangarilham": "zangarilhar",
    "zangarilhamo": "zangarilhar",
    "zangarilhamos": "zangarilhar",
    "zangarilhando": "zangarilhar",
    "zangarilhara": "zangarilhar",
    "zangarilharam": "zangarilhar",
    "zangarilharas": "zangarilhar",
    "zangarilhardes": "zangarilhar",
    "zangarilharei": "zangarilhar",
    "zangarilhareis": "zangarilhar",
    "zangarilharem": "zangarilhar",
    "zangarilharemos": "zangarilhar",
    "zangarilhares": "zangarilhar",
    "zangarilharia": "zangarilhar",
    "zangarilhariam": "zangarilhar",
    "zangarilharias": "zangarilhar",
    "zangarilharmo": "zangarilhar",
    "zangarilharmos": "zangarilhar",
    "zangarilhará": "zangarilhar",
    "zangarilharás": "zangarilhar",
    "zangarilharão": "zangarilhar",
    "zangarilharíamos": "zangarilhar",
    "zangarilharíeis": "zangarilhar",
    "zangarilhas": "zangarilho",
    "zangarilhasse": "zangarilhar",
    "zangarilhassem": "zangarilhar",
    "zangarilhasses": "zangarilhar",
    "zangarilhaste": "zangarilhar",
    "zangarilhastes": "zangarilhar",
    "zangarilhava": "zangarilhar",
    "zangarilhavam": "zangarilhar",
    "zangarilhavas": "zangarilhar",
    "zangarilhe": "zangarilhar",
    "zangarilhei": "zangarilhar",
    "zangarilheiras": "zangarilheira",
    "zangarilheis": "zangarilhar",
    "zangarilhem": "zangarilhar",
    "zangarilhemo": "zangarilhar",
    "zangarilhemos": "zangarilhar",
    "zangarilhes": "zangarilhar",
    "zangarilho": "zangarilhar",
    "zangarilhos": "zangarilho",
    "zangarilhou": "zangarilhar",
    "zangarilhámo": "zangarilhar",
    "zangarilhámos": "zangarilhar",
    "zangarilháramo": "zangarilhar",
    "zangarilháramos": "zangarilhar",
    "zangarilháreis": "zangarilhar",
    "zangarilhásseis": "zangarilhar",
    "zangarilhássemos": "zangarilhar",
    "zangarilhávamo": "zangarilhar",
    "zangarilhávamos": "zangarilhar",
    "zangarilháveis": "zangarilhar",
    "zangarinheiros": "zangarinheiro",
    "zangarinhos": "zangarinho",
    "zangarmo": "zangar",
    "zangarmos": "zangar",
    "zangarreada": "zangarrear",
    "zangarreadas": "zangarrear",
    "zangarreado": "zangarrear",
    "zangarreados": "zangarrear",
    "zangarreai": "zangarrear",
    "zangarreais": "zangarrear",
    "zangarreamo": "zangarrear",
    "zangarreamos": "zangarrear",
    "zangarreando": "zangarrear",
    "zangarreara": "zangarrear",
    "zangarrearam": "zangarrear",
    "zangarrearas": "zangarrear",
    "zangarrearde": "zangarrear",
    "zangarreardes": "zangarrear",
    "zangarreare": "zangarrear",
    "zangarrearei": "zangarrear",
    "zangarreareis": "zangarrear",
    "zangarrearem": "zangarrear",
    "zangarrearemos": "zangarrear",
    "zangarreares": "zangarrear",
    "zangarrearia": "zangarrear",
    "zangarreariam": "zangarrear",
    "zangarrearias": "zangarrear",
    "zangarrearmo": "zangarrear",
    "zangarrearmos": "zangarrear",
    "zangarreará": "zangarrear",
    "zangarrearás": "zangarrear",
    "zangarrearão": "zangarrear",
    "zangarrearíamos": "zangarrear",
    "zangarrearíeis": "zangarrear",
    "zangarreasse": "zangarrear",
    "zangarreassem": "zangarrear",
    "zangarreasses": "zangarrear",
    "zangarreaste": "zangarrear",
    "zangarreastes": "zangarrear",
    "zangarreava": "zangarrear",
    "zangarreavam": "zangarrear",
    "zangarreavas": "zangarrear",
    "zangarreei": "zangarrear",
    "zangarreeis": "zangarrear",
    "zangarreemo": "zangarrear",
    "zangarreemos": "zangarrear",
    "zangarreia": "zangarrear",
    "zangarreiam": "zangarrear",
    "zangarreias": "zangarrear",
    "zangarreie": "zangarrear",
    "zangarreiem": "zangarrear",
    "zangarreies": "zangarrear",
    "zangarreio": "zangarrear",
    "zangarreios": "zangarreio",
    "zangarreou": "zangarrear",
    "zangarreá": "zangarrear",
    "zangarreámo": "zangarrear",
    "zangarreámos": "zangarrear",
    "zangarreáramo": "zangarrear",
    "zangarreáramos": "zangarrear",
    "zangarreárei": "zangarrear",
    "zangarreáreis": "zangarrear",
    "zangarreásseis": "zangarrear",
    "zangarreássemos": "zangarrear",
    "zangarreávamo": "zangarrear",
    "zangarreávamos": "zangarrear",
    "zangarreávei": "zangarrear",
    "zangarreáveis": "zangarrear",
    "zangarrilhões": "zangarrilhão",
    "zangarrões": "zangarrão",
    "zangará": "zangar",
    "zangarás": "zangar",
    "zangarão": "zangar",
    "zangaríamos": "zangar",
    "zangaríeis": "zangar",
    "zangas": "zangar",
    "zangasse": "zangar",
    "zangassem": "zangar",
    "zangasses": "zangar",
    "zangaste": "zangar",
    "zangastes": "zangar",
    "zangava": "zangar",
    "zangavam": "zangar",
    "zangavas": "zangar",
    "zango": "zangar",
    "zangona": "zangão",
    "zangonas": "zangão",
    "zangou": "zangar",
    "zangue": "zangar",
    "zanguei": "zangar",
    "zangueis": "zangar",
    "zanguem": "zangar",
    "zanguemo": "zangar",
    "zanguemos": "zangar",
    "zangues": "zangar",
    "zanguizarras": "zanguizarra",
    "zangurra": "zangurrar",
    "zangurrada": "zangurrar",
    "zangurradas": "zangurrar",
    "zangurrado": "zangurrar",
    "zangurrados": "zangurrar",
    "zangurrai": "zangurrar",
    "zangurrais": "zangurrar",
    "zangurram": "zangurrar",
    "zangurramo": "zangurrar",
    "zangurramos": "zangurrar",
    "zangurrando": "zangurrar",
    "zangurrara": "zangurrar",
    "zangurraram": "zangurrar",
    "zangurraras": "zangurrar",
    "zangurrardes": "zangurrar",
    "zangurrarei": "zangurrar",
    "zangurrareis": "zangurrar",
    "zangurrarem": "zangurrar",
    "zangurraremos": "zangurrar",
    "zangurrares": "zangurrar",
    "zangurraria": "zangurrar",
    "zangurrariam": "zangurrar",
    "zangurrarias": "zangurrar",
    "zangurrarmo": "zangurrar",
    "zangurrarmos": "zangurrar",
    "zangurrará": "zangurrar",
    "zangurrarás": "zangurrar",
    "zangurrarão": "zangurrar",
    "zangurraríamos": "zangurrar",
    "zangurraríeis": "zangurrar",
    "zangurras": "zangurrar",
    "zangurrasse": "zangurrar",
    "zangurrassem": "zangurrar",
    "zangurrasses": "zangurrar",
    "zangurraste": "zangurrar",
    "zangurrastes": "zangurrar",
    "zangurrava": "zangurrar",
    "zangurravam": "zangurrar",
    "zangurravas": "zangurrar",
    "zangurre": "zangurrar",
    "zangurrei": "zangurrar",
    "zangurreis": "zangurrar",
    "zangurrem": "zangurrar",
    "zangurremo": "zangurrar",
    "zangurremos": "zangurrar",
    "zangurres": "zangurrar",
    "zangurriadas": "zangurriada",
    "zangurro": "zangurrar",
    "zangurrou": "zangurrar",
    "zangurrámo": "zangurrar",
    "zangurrámos": "zangurrar",
    "zangurráramo": "zangurrar",
    "zangurráramos": "zangurrar",
    "zangurráreis": "zangurrar",
    "zangurrásseis": "zangurrar",
    "zangurrássemos": "zangurrar",
    "zangurrávamo": "zangurrar",
    "zangurrávamos": "zangurrar",
    "zangurráveis": "zangurrar",
    "zangá": "zangar",
    "zangámo": "zangar",
    "zangámos": "zangar",
    "zangáramo": "zangar",
    "zangáramos": "zangar",
    "zangárei": "zangar",
    "zangáreis": "zangar",
    "zangásseis": "zangar",
    "zangássemos": "zangar",
    "zangávamo": "zangar",
    "zangávamos": "zangar",
    "zangávei": "zangar",
    "zangáveis": "zangar",
    "zangões": "zangão",
    "zanizos": "zanizo",
    "zanociáceas": "zanociácea",
    "zanoia": "zanoio",
    "zanoias": "zanoio",
    "zanoios": "zanoio",
    "zanolha": "zanolho",
    "zanolhas": "zanolho",
    "zanolhos": "zanolho",
    "zantes": "zante",
    "zantoxiláceas": "zantoxilácea",
    "zantóxilos": "zantóxilo",
    "zanza": "zanzar",
    "zanzada": "zanzar",
    "zanzadas": "zanzar",
    "zanzado": "zanzar",
    "zanzadora": "zanzador",
    "zanzadoras": "zanzador",
    "zanzadores": "zanzador",
    "zanzados": "zanzar",
    "zanzai": "zanzar",
    "zanzais": "zanzar",
    "zanzam": "zanzar",
    "zanzamo": "zanzar",
    "zanzamos": "zanzar",
    "zanzando": "zanzar",
    "zanzara": "zanzar",
    "zanzaram": "zanzar",
    "zanzaras": "zanzar",
    "zanzardes": "zanzar",
    "zanzarei": "zanzar",
    "zanzareis": "zanzar",
    "zanzarem": "zanzar",
    "zanzaremos": "zanzar",
    "zanzares": "zanzar",
    "zanzaria": "zanzar",
    "zanzariam": "zanzar",
    "zanzarias": "zanzar",
    "zanzarilha": "zanzarilhar",
    "zanzarilhada": "zanzarilhar",
    "zanzarilhadas": "zanzarilhar",
    "zanzarilhado": "zanzarilhar",
    "zanzarilhados": "zanzarilhar",
    "zanzarilhai": "zanzarilhar",
    "zanzarilhais": "zanzarilhar",
    "zanzarilham": "zanzarilhar",
    "zanzarilhamo": "zanzarilhar",
    "zanzarilhamos": "zanzarilhar",
    "zanzarilhando": "zanzarilhar",
    "zanzarilhara": "zanzarilhar",
    "zanzarilharam": "zanzarilhar",
    "zanzarilharas": "zanzarilhar",
    "zanzarilhardes": "zanzarilhar",
    "zanzarilharei": "zanzarilhar",
    "zanzarilhareis": "zanzarilhar",
    "zanzarilharem": "zanzarilhar",
    "zanzarilharemos": "zanzarilhar",
    "zanzarilhares": "zanzarilhar",
    "zanzarilharia": "zanzarilhar",
    "zanzarilhariam": "zanzarilhar",
    "zanzarilharias": "zanzarilhar",
    "zanzarilharmo": "zanzarilhar",
    "zanzarilharmos": "zanzarilhar",
    "zanzarilhará": "zanzarilhar",
    "zanzarilharás": "zanzarilhar",
    "zanzarilharão": "zanzarilhar",
    "zanzarilharíamos": "zanzarilhar",
    "zanzarilharíeis": "zanzarilhar",
    "zanzarilhas": "zanzarilhar",
    "zanzarilhasse": "zanzarilhar",
    "zanzarilhassem": "zanzarilhar",
    "zanzarilhasses": "zanzarilhar",
    "zanzarilhaste": "zanzarilhar",
    "zanzarilhastes": "zanzarilhar",
    "zanzarilhava": "zanzarilhar",
    "zanzarilhavam": "zanzarilhar",
    "zanzarilhavas": "zanzarilhar",
    "zanzarilhe": "zanzarilhar",
    "zanzarilhei": "zanzarilhar",
    "zanzarilheis": "zanzarilhar",
    "zanzarilhem": "zanzarilhar",
    "zanzarilhemo": "zanzarilhar",
    "zanzarilhemos": "zanzarilhar",
    "zanzarilhes": "zanzarilhar",
    "zanzarilho": "zanzarilhar",
    "zanzarilhou": "zanzarilhar",
    "zanzarilhámo": "zanzarilhar",
    "zanzarilhámos": "zanzarilhar",
    "zanzarilháramo": "zanzarilhar",
    "zanzarilháramos": "zanzarilhar",
    "zanzarilháreis": "zanzarilhar",
    "zanzarilhásseis": "zanzarilhar",
    "zanzarilhássemos": "zanzarilhar",
    "zanzarilhávamo": "zanzarilhar",
    "zanzarilhávamos": "zanzarilhar",
    "zanzarilháveis": "zanzarilhar",
    "zanzarmo": "zanzar",
    "zanzarmos": "zanzar",
    "zanzará": "zanzar",
    "zanzarás": "zanzar",
    "zanzarão": "zanzar",
    "zanzaríamos": "zanzar",
    "zanzaríeis": "zanzar",
    "zanzas": "zanzar",
    "zanzasse": "zanzar",
    "zanzassem": "zanzar",
    "zanzasses": "zanzar",
    "zanzaste": "zanzar",
    "zanzastes": "zanzar",
    "zanzava": "zanzar",
    "zanzavam": "zanzar",
    "zanzavas": "zanzar",
    "zanze": "zanzar",
    "zanzei": "zanzar",
    "zanzeis": "zanzar",
    "zanzem": "zanzar",
    "zanzemo": "zanzar",
    "zanzemos": "zanzar",
    "zanzes": "zanzar",
    "zanzibaritas": "zanzibarita",
    "zanzibars": "zanzibar",
    "zanzinos": "zanzino",
    "zanzo": "zanzar",
    "zanzos": "zanzo",
    "zanzou": "zanzar",
    "zanzámo": "zanzar",
    "zanzámos": "zanzar",
    "zanzáramo": "zanzar",
    "zanzáramos": "zanzar",
    "zanzáreis": "zanzar",
    "zanzásseis": "zanzar",
    "zanzássemos": "zanzar",
    "zanzávamo": "zanzar",
    "zanzávamos": "zanzar",
    "zanzáveis": "zanzar",
    "zapes": "zape",
    "zapetrapes": "zapetrape",
    "zarabatanadas": "zarabatanada",
    "zarabatanas": "zarabatana",
    "zaracoteias": "zaracoteia",
    "zaragalhadas": "zaragalhada",
    "zaragatas": "zaragata",
    "zaragateada": "zaragatear",
    "zaragateadas": "zaragatear",
    "zaragateado": "zaragatear",
    "zaragateados": "zaragatear",
    "zaragateai": "zaragatear",
    "zaragateais": "zaragatear",
    "zaragateamo": "zaragatear",
    "zaragateamos": "zaragatear",
    "zaragateando": "zaragatear",
    "zaragateara": "zaragatear",
    "zaragatearam": "zaragatear",
    "zaragatearas": "zaragatear",
    "zaragateardes": "zaragatear",
    "zaragatearei": "zaragatear",
    "zaragateareis": "zaragatear",
    "zaragatearem": "zaragatear",
    "zaragatearemos": "zaragatear",
    "zaragateares": "zaragatear",
    "zaragatearia": "zaragatear",
    "zaragateariam": "zaragatear",
    "zaragatearias": "zaragatear",
    "zaragatearmo": "zaragatear",
    "zaragatearmos": "zaragatear",
    "zaragateará": "zaragatear",
    "zaragatearás": "zaragatear",
    "zaragatearão": "zaragatear",
    "zaragatearíamos": "zaragatear",
    "zaragatearíeis": "zaragatear",
    "zaragateasse": "zaragatear",
    "zaragateassem": "zaragatear",
    "zaragateasses": "zaragatear",
    "zaragateaste": "zaragatear",
    "zaragateastes": "zaragatear",
    "zaragateava": "zaragatear",
    "zaragateavam": "zaragatear",
    "zaragateavas": "zaragatear",
    "zaragateei": "zaragatear",
    "zaragateeis": "zaragatear",
    "zaragateemo": "zaragatear",
    "zaragateemos": "zaragatear",
    "zaragateia": "zaragatear",
    "zaragateiam": "zaragatear",
    "zaragateias": "zaragatear",
    "zaragateie": "zaragatear",
    "zaragateiem": "zaragatear",
    "zaragateies": "zaragatear",
    "zaragateio": "zaragatear",
    "zaragateira": "zaragateiro",
    "zaragateiras": "zaragateiro",
    "zaragateiros": "zaragateiro",
    "zaragateou": "zaragatear",
    "zaragateámo": "zaragatear",
    "zaragateámos": "zaragatear",
    "zaragateáramo": "zaragatear",
    "zaragateáramos": "zaragatear",
    "zaragateáreis": "zaragatear",
    "zaragateásseis": "zaragatear",
    "zaragateássemos": "zaragatear",
    "zaragateávamo": "zaragatear",
    "zaragateávamos": "zaragatear",
    "zaragateáveis": "zaragatear",
    "zaragatoa": "zaragatoar",
    "zaragatoada": "zaragatoar",
    "zaragatoadas": "zaragatoar",
    "zaragatoadelas": "zaragatoadela",
    "zaragatoado": "zaragatoar",
    "zaragatoados": "zaragatoar",
    "zaragatoai": "zaragatoar",
    "zaragatoais": "zaragatoar",
    "zaragatoam": "zaragatoar",
    "zaragatoamo": "zaragatoar",
    "zaragatoamos": "zaragatoar",
    "zaragatoando": "zaragatoar",
    "zaragatoara": "zaragatoar",
    "zaragatoaram": "zaragatoar",
    "zaragatoaras": "zaragatoar",
    "zaragatoarde": "zaragatoar",
    "zaragatoardes": "zaragatoar",
    "zaragatoare": "zaragatoar",
    "zaragatoarei": "zaragatoar",
    "zaragatoareis": "zaragatoar",
    "zaragatoarem": "zaragatoar",
    "zaragatoaremos": "zaragatoar",
    "zaragatoares": "zaragatoar",
    "zaragatoaria": "zaragatoar",
    "zaragatoariam": "zaragatoar",
    "zaragatoarias": "zaragatoar",
    "zaragatoarmo": "zaragatoar",
    "zaragatoarmos": "zaragatoar",
    "zaragatoará": "zaragatoar",
    "zaragatoarás": "zaragatoar",
    "zaragatoarão": "zaragatoar",
    "zaragatoaríamos": "zaragatoar",
    "zaragatoaríeis": "zaragatoar",
    "zaragatoas": "zaragatoar",
    "zaragatoasse": "zaragatoar",
    "zaragatoassem": "zaragatoar",
    "zaragatoasses": "zaragatoar",
    "zaragatoaste": "zaragatoar",
    "zaragatoastes": "zaragatoar",
    "zaragatoava": "zaragatoar",
    "zaragatoavam": "zaragatoar",
    "zaragatoavas": "zaragatoar",
    "zaragatoe": "zaragatoar",
    "zaragatoei": "zaragatoar",
    "zaragatoeis": "zaragatoar",
    "zaragatoem": "zaragatoar",
    "zaragatoemo": "zaragatoar",
    "zaragatoemos": "zaragatoar",
    "zaragatoes": "zaragatoar",
    "zaragatoo": "zaragatoar",
    "zaragatoou": "zaragatoar",
    "zaragatoá": "zaragatoar",
    "zaragatoámo": "zaragatoar",
    "zaragatoámos": "zaragatoar",
    "zaragatoáramo": "zaragatoar",
    "zaragatoáramos": "zaragatoar",
    "zaragatoárei": "zaragatoar",
    "zaragatoáreis": "zaragatoar",
    "zaragatoásseis": "zaragatoar",
    "zaragatoássemos": "zaragatoar",
    "zaragatoávamo": "zaragatoar",
    "zaragatoávamos": "zaragatoar",
    "zaragatoávei": "zaragatoar",
    "zaragatoáveis": "zaragatoar",
    "zaralhas": "zaralha",
    "zaranza": "zaranzar",
    "zaranzada": "zaranzar",
    "zaranzadas": "zaranzar",
    "zaranzado": "zaranzar",
    "zaranzados": "zaranzar",
    "zaranzai": "zaranzar",
    "zaranzais": "zaranzar",
    "zaranzam": "zaranzar",
    "zaranzamo": "zaranzar",
    "zaranzamos": "zaranzar",
    "zaranzando": "zaranzar",
    "zaranzara": "zaranzar",
    "zaranzaram": "zaranzar",
    "zaranzaras": "zaranzar",
    "zaranzardes": "zaranzar",
    "zaranzarei": "zaranzar",
    "zaranzareis": "zaranzar",
    "zaranzarem": "zaranzar",
    "zaranzaremos": "zaranzar",
    "zaranzares": "zaranzar",
    "zaranzaria": "zaranzar",
    "zaranzariam": "zaranzar",
    "zaranzarias": "zaranzar",
    "zaranzarmo": "zaranzar",
    "zaranzarmos": "zaranzar",
    "zaranzará": "zaranzar",
    "zaranzarás": "zaranzar",
    "zaranzarão": "zaranzar",
    "zaranzaríamos": "zaranzar",
    "zaranzaríeis": "zaranzar",
    "zaranzas": "zaranzar",
    "zaranzasse": "zaranzar",
    "zaranzassem": "zaranzar",
    "zaranzasses": "zaranzar",
    "zaranzaste": "zaranzar",
    "zaranzastes": "zaranzar",
    "zaranzava": "zaranzar",
    "zaranzavam": "zaranzar",
    "zaranzavas": "zaranzar",
    "zaranze": "zaranzar",
    "zaranzei": "zaranzar",
    "zaranzeis": "zaranzar",
    "zaranzem": "zaranzar",
    "zaranzemo": "zaranzar",
    "zaranzemos": "zaranzar",
    "zaranzes": "zaranzar",
    "zaranzo": "zaranzar",
    "zaranzou": "zaranzar",
    "zaranzámo": "zaranzar",
    "zaranzámos": "zaranzar",
    "zaranzáramo": "zaranzar",
    "zaranzáramos": "zaranzar",
    "zaranzáreis": "zaranzar",
    "zaranzásseis": "zaranzar",
    "zaranzássemos": "zaranzar",
    "zaranzávamo": "zaranzar",
    "zaranzávamos": "zaranzar",
    "zaranzáveis": "zaranzar",
    "zarapelhos": "zarapelho",
    "zarapilheiras": "zarapilheira",
    "zarapotecos": "zarapoteco",
    "zarascas": "zarasca",
    "zarca": "zarco",
    "zarcas": "zarco",
    "zarcos": "zarco",
    "zarcões": "zarcão",
    "zarelha": "zarelho",
    "zarelhada": "zarelhar",
    "zarelhadas": "zarelhar",
    "zarelhado": "zarelhar",
    "zarelhados": "zarelhar",
    "zarelhai": "zarelhar",
    "zarelhais": "zarelhar",
    "zarelham": "zarelhar",
    "zarelhamo": "zarelhar",
    "zarelhamos": "zarelhar",
    "zarelhando": "zarelhar",
    "zarelhara": "zarelhar",
    "zarelharam": "zarelhar",
    "zarelharas": "zarelhar",
    "zarelhardes": "zarelhar",
    "zarelharei": "zarelhar",
    "zarelhareis": "zarelhar",
    "zarelharem": "zarelhar",
    "zarelharemos": "zarelhar",
    "zarelhares": "zarelhar",
    "zarelharia": "zarelhar",
    "zarelhariam": "zarelhar",
    "zarelharias": "zarelhar",
    "zarelharmo": "zarelhar",
    "zarelharmos": "zarelhar",
    "zarelhará": "zarelhar",
    "zarelharás": "zarelhar",
    "zarelharão": "zarelhar",
    "zarelharíamos": "zarelhar",
    "zarelharíeis": "zarelhar",
    "zarelhas": "zarelho",
    "zarelhasse": "zarelhar",
    "zarelhassem": "zarelhar",
    "zarelhasses": "zarelhar",
    "zarelhaste": "zarelhar",
    "zarelhastes": "zarelhar",
    "zarelhava": "zarelhar",
    "zarelhavam": "zarelhar",
    "zarelhavas": "zarelhar",
    "zarelhe": "zarelhar",
    "zarelhei": "zarelhar",
    "zarelheis": "zarelhar",
    "zarelhem": "zarelhar",
    "zarelhemo": "zarelhar",
    "zarelhemos": "zarelhar",
    "zarelhes": "zarelhar",
    "zarelho": "zarelhar",
    "zarelhos": "zarelho",
    "zarelhou": "zarelhar",
    "zarelhámo": "zarelhar",
    "zarelhámos": "zarelhar",
    "zarelháramo": "zarelhar",
    "zarelháramos": "zarelhar",
    "zarelháreis": "zarelhar",
    "zarelhásseis": "zarelhar",
    "zarelhássemos": "zarelhar",
    "zarelhávamo": "zarelhar",
    "zarelhávamos": "zarelhar",
    "zarelháveis": "zarelhar",
    "zarga": "zargo",
    "zargas": "zargo",
    "zargos": "zargo",
    "zarguelistas": "zarguelista",
    "zarguncha": "zargunchar",
    "zargunchada": "zargunchar",
    "zargunchadas": "zargunchar",
    "zargunchado": "zargunchar",
    "zargunchados": "zargunchar",
    "zargunchai": "zargunchar",
    "zargunchais": "zargunchar",
    "zarguncham": "zargunchar",
    "zargunchamo": "zargunchar",
    "zargunchamos": "zargunchar",
    "zargunchando": "zargunchar",
    "zargunchara": "zargunchar",
    "zarguncharam": "zargunchar",
    "zarguncharas": "zargunchar",
    "zarguncharde": "zargunchar",
    "zargunchardes": "zargunchar",
    "zargunchare": "zargunchar",
    "zarguncharei": "zargunchar",
    "zargunchareis": "zargunchar",
    "zarguncharem": "zargunchar",
    "zarguncharemos": "zargunchar",
    "zargunchares": "zargunchar",
    "zarguncharia": "zargunchar",
    "zargunchariam": "zargunchar",
    "zarguncharias": "zargunchar",
    "zarguncharmo": "zargunchar",
    "zarguncharmos": "zargunchar",
    "zargunchará": "zargunchar",
    "zarguncharás": "zargunchar",
    "zarguncharão": "zargunchar",
    "zarguncharíamos": "zargunchar",
    "zarguncharíeis": "zargunchar",
    "zargunchas": "zargunchar",
    "zargunchasse": "zargunchar",
    "zargunchassem": "zargunchar",
    "zargunchasses": "zargunchar",
    "zargunchaste": "zargunchar",
    "zargunchastes": "zargunchar",
    "zargunchava": "zargunchar",
    "zargunchavam": "zargunchar",
    "zargunchavas": "zargunchar",
    "zargunche": "zargunchar",
    "zargunchei": "zargunchar",
    "zarguncheis": "zargunchar",
    "zargunchem": "zargunchar",
    "zargunchemo": "zargunchar",
    "zargunchemos": "zargunchar",
    "zargunches": "zargunchar",
    "zarguncho": "zargunchar",
    "zargunchos": "zarguncho",
    "zargunchou": "zargunchar",
    "zargunchá": "zargunchar",
    "zargunchámo": "zargunchar",
    "zargunchámos": "zargunchar",
    "zarguncháramo": "zargunchar",
    "zarguncháramos": "zargunchar",
    "zargunchárei": "zargunchar",
    "zarguncháreis": "zargunchar",
    "zargunchásseis": "zargunchar",
    "zargunchássemos": "zargunchar",
    "zargunchávamo": "zargunchar",
    "zargunchávamos": "zargunchar",
    "zargunchávei": "zargunchar",
    "zarguncháveis": "zargunchar",
    "zarolha": "zarolho",
    "zarolhas": "zarolho",
    "zarolhices": "zarolhice",
    "zarolhos": "zarolho",
    "zarpa": "zarpar",
    "zarpada": "zarpar",
    "zarpadas": "zarpar",
    "zarpado": "zarpar",
    "zarpados": "zarpar",
    "zarpai": "zarpar",
    "zarpais": "zarpar",
    "zarpam": "zarpar",
    "zarpamo": "zarpar",
    "zarpamos": "zarpar",
    "zarpando": "zarpar",
    "zarpara": "zarpar",
    "zarparam": "zarpar",
    "zarparas": "zarpar",
    "zarparde": "zarpar",
    "zarpardes": "zarpar",
    "zarpare": "zarpar",
    "zarparei": "zarpar",
    "zarpareis": "zarpar",
    "zarparem": "zarpar",
    "zarparemos": "zarpar",
    "zarpares": "zarpar",
    "zarparia": "zarpar",
    "zarpariam": "zarpar",
    "zarparias": "zarpar",
    "zarparmo": "zarpar",
    "zarparmos": "zarpar",
    "zarpará": "zarpar",
    "zarparás": "zarpar",
    "zarparão": "zarpar",
    "zarparíamos": "zarpar",
    "zarparíeis": "zarpar",
    "zarpas": "zarpar",
    "zarpasse": "zarpar",
    "zarpassem": "zarpar",
    "zarpasses": "zarpar",
    "zarpaste": "zarpar",
    "zarpastes": "zarpar",
    "zarpava": "zarpar",
    "zarpavam": "zarpar",
    "zarpavas": "zarpar",
    "zarpe": "zarpar",
    "zarpei": "zarpar",
    "zarpeis": "zarpar",
    "zarpem": "zarpar",
    "zarpemo": "zarpar",
    "zarpemos": "zarpar",
    "zarpes": "zarpar",
    "zarpo": "zarpar",
    "zarpou": "zarpar",
    "zarpá": "zarpar",
    "zarpámo": "zarpar",
    "zarpámos": "zarpar",
    "zarpáramo": "zarpar",
    "zarpáramos": "zarpar",
    "zarpárei": "zarpar",
    "zarpáreis": "zarpar",
    "zarpásseis": "zarpar",
    "zarpássemos": "zarpar",
    "zarpávamo": "zarpar",
    "zarpávamos": "zarpar",
    "zarpávei": "zarpar",
    "zarpáveis": "zarpar",
    "zarra": "zarro",
    "zarras": "zarro",
    "zarros": "zarro",
    "zarucas": "zaruca",
    "zaruco": "zaruca",
    "zarucos": "zaruca",
    "zarzagitânias": "zarzagitânia",
    "zarzuelas": "zarzuela",
    "zarés": "zaré",
    "zarões": "zarão",
    "zava": "zavar",
    "zavada": "zavar",
    "zavadas": "zavar",
    "zavado": "zavar",
    "zavados": "zavar",
    "zavai": "zavar",
    "zavais": "zavar",
    "zavam": "zavar",
    "zavamo": "zavar",
    "zavamos": "zavar",
    "zavando": "zavar",
    "zavaneiras": "zavaneira",
    "zavara": "zavar",
    "zavaram": "zavar",
    "zavaras": "zavar",
    "zavardes": "zavar",
    "zavarei": "zavar",
    "zavareis": "zavar",
    "zavarem": "zavar",
    "zavaremos": "zavar",
    "zavares": "zavar",
    "zavaria": "zavar",
    "zavariam": "zavar",
    "zavarias": "zavar",
    "zavarmo": "zavar",
    "zavarmos": "zavar",
    "zavará": "zavar",
    "zavarás": "zavar",
    "zavarão": "zavar",
    "zavaríamos": "zavar",
    "zavaríeis": "zavar",
    "zavas": "zavar",
    "zavasse": "zavar",
    "zavassem": "zavar",
    "zavasses": "zavar",
    "zavaste": "zavar",
    "zavastes": "zavar",
    "zavava": "zavar",
    "zavavam": "zavar",
    "zavavas": "zavar",
    "zave": "zavar",
    "zavei": "zavar",
    "zaveis": "zavar",
    "zavem": "zavar",
    "zavemo": "zavar",
    "zavemos": "zavar",
    "zaves": "zavar",
    "zavo": "zavar",
    "zavou": "zavar",
    "zavras": "zavra",
    "zavámo": "zavar",
    "zavámos": "zavar",
    "zaváramo": "zavar",
    "zaváramos": "zavar",
    "zaváreis": "zavar",
    "zavásseis": "zavar",
    "zavássemos": "zavar",
    "zavávamo": "zavar",
    "zavávamos": "zavar",
    "zaváveis": "zavar",
    "zazos": "zazo",
    "zebos": "zebo",
    "zebra": "zebrar",
    "zebrada": "zebrar",
    "zebradas": "zebrar",
    "zebrado": "zebrar",
    "zebrados": "zebrar",
    "zebrai": "zebrar",
    "zebrainhos": "zebrainho",
    "zebrais": "zebrar",
    "zebram": "zebrar",
    "zebramo": "zebrar",
    "zebramos": "zebrar",
    "zebrando": "zebrar",
    "zebrara": "zebrar",
    "zebraram": "zebrar",
    "zebraras": "zebrar",
    "zebrarde": "zebrar",
    "zebrardes": "zebrar",
    "zebrare": "zebrar",
    "zebrarei": "zebrar",
    "zebrareis": "zebrar",
    "zebrarem": "zebrar",
    "zebraremos": "zebrar",
    "zebrares": "zebrar",
    "zebraria": "zebrar",
    "zebrariam": "zebrar",
    "zebrarias": "zebrar",
    "zebrarmo": "zebrar",
    "zebrarmos": "zebrar",
    "zebrará": "zebrar",
    "zebrarás": "zebrar",
    "zebrarão": "zebrar",
    "zebraríamos": "zebrar",
    "zebraríeis": "zebrar",
    "zebras": "zebrar",
    "zebrasse": "zebrar",
    "zebrassem": "zebrar",
    "zebrasses": "zebrar",
    "zebraste": "zebrar",
    "zebrastes": "zebrar",
    "zebrava": "zebrar",
    "zebravam": "zebrar",
    "zebravas": "zebrar",
    "zebre": "zebrar",
    "zebrei": "zebrar",
    "zebreis": "zebrar",
    "zebrem": "zebrar",
    "zebremo": "zebrar",
    "zebremos": "zebrar",
    "zebres": "zebrar",
    "zebrina": "zebrino",
    "zebrinas": "zebrino",
    "zebrinos": "zebrino",
    "zebro": "zebrar",
    "zebros": "zebro",
    "zebrou": "zebrar",
    "zebruna": "zebruno",
    "zebrunas": "zebruno",
    "zebrunos": "zebruno",
    "zebruns": "zebrum",
    "zebrá": "zebrar",
    "zebrámo": "zebrar",
    "zebrámos": "zebrar",
    "zebráramo": "zebrar",
    "zebráramos": "zebrar",
    "zebrárei": "zebrar",
    "zebráreis": "zebrar",
    "zebrária": "zebrário",
    "zebrárias": "zebrário",
    "zebrários": "zebrário",
    "zebrásseis": "zebrar",
    "zebrássemos": "zebrar",
    "zebrávamo": "zebrar",
    "zebrávamos": "zebrar",
    "zebrávei": "zebrar",
    "zebráveis": "zebrar",
    "zebróides": "zebróide",
    "zebus": "zebu",
    "zedoárias": "zedoária",
    "zefires": "zefire",
    "zefirina": "zefirino",
    "zefirinas": "zefirino",
    "zefirinos": "zefirino",
    "zegres": "zegre",
    "zeimã": "zeimão",
    "zeimãos": "zeimão",
    "zeimãs": "zeimão",
    "zela": "zelar",
    "zelada": "zelar",
    "zeladas": "zelar",
    "zelado": "zelar",
    "zeladora": "zelador",
    "zeladoras": "zelador",
    "zeladores": "zelador",
    "zeladorias": "zeladoria",
    "zelados": "zelar",
    "zelai": "zelar",
    "zelais": "zelar",
    "zelam": "zelar",
    "zelamo": "zelar",
    "zelamos": "zelar",
    "zelandeses": "zelandês",
    "zelando": "zelar",
    "zelantes": "zelante",
    "zelara": "zelar",
    "zelaram": "zelar",
    "zelaras": "zelar",
    "zelarde": "zelar",
    "zelardes": "zelar",
    "zelare": "zelar",
    "zelarei": "zelar",
    "zelareis": "zelar",
    "zelarem": "zelar",
    "zelaremos": "zelar",
    "zelares": "zelar",
    "zelaria": "zelar",
    "zelariam": "zelar",
    "zelarias": "zelar",
    "zelarmo": "zelar",
    "zelarmos": "zelar",
    "zelará": "zelar",
    "zelarás": "zelar",
    "zelarão": "zelar",
    "zelaríamos": "zelar",
    "zelaríeis": "zelar",
    "zelas": "zelar",
    "zelasse": "zelar",
    "zelassem": "zelar",
    "zelasses": "zelar",
    "zelaste": "zelar",
    "zelastes": "zelar",
    "zelava": "zelar",
    "zelavam": "zelar",
    "zelavas": "zelar",
    "zelações": "zelação",
    "zele": "zelar",
    "zelei": "zelar",
    "zeleis": "zelar",
    "zelem": "zelar",
    "zelemo": "zelar",
    "zelemos": "zelar",
    "zeles": "zelar",
    "zelhas": "zelha",
    "zelo": "zelar",
    "zelos": "zelo",
    "zelosa": "zeloso",
    "zelosas": "zeloso",
    "zelosias": "zelosia",
    "zelosos": "zeloso",
    "zelotas": "zelota",
    "zelotes": "zelote",
    "zelotipias": "zelotipia",
    "zelou": "zelar",
    "zelá": "zelar",
    "zelámo": "zelar",
    "zelámos": "zelar",
    "zeláramo": "zelar",
    "zeláramos": "zelar",
    "zelárei": "zelar",
    "zeláreis": "zelar",
    "zelásseis": "zelar",
    "zelássemos": "zelar",
    "zelávamo": "zelar",
    "zelávamos": "zelar",
    "zelávei": "zelar",
    "zeláveis": "zelar",
    "zembra": "zembro",
    "zembras": "zembro",
    "zembros": "zembro",
    "zemiobioses": "zemiobiose",
    "zemiodemias": "zemiodemia",
    "zena": "zenir",
    "zenais": "zenir",
    "zenam": "zenir",
    "zenamo": "zenir",
    "zenamos": "zenir",
    "zenas": "zenir",
    "zendas": "zenda",
    "zendes": "zende",
    "zendicismos": "zendicismo",
    "zendicistas": "zendicista",
    "zene": "zenir",
    "zenem": "zenir",
    "zenes": "zenir",
    "zeni": "zenir",
    "zenia": "zenir",
    "zeniam": "zenir",
    "zenias": "zenir",
    "zenida": "zenir",
    "zenidas": "zenir",
    "zenido": "zenir",
    "zenidos": "zenir",
    "zenimo": "zenir",
    "zenimos": "zenir",
    "zenindo": "zenir",
    "zenira": "zenir",
    "zeniram": "zenir",
    "zeniras": "zenir",
    "zenirdes": "zenir",
    "zenirei": "zenir",
    "zenireis": "zenir",
    "zenirem": "zenir",
    "zeniremos": "zenir",
    "zenires": "zenir",
    "zeniria": "zenir",
    "zeniriam": "zenir",
    "zenirias": "zenir",
    "zenirmo": "zenir",
    "zenirmos": "zenir",
    "zenirá": "zenir",
    "zenirás": "zenir",
    "zenirão": "zenir",
    "zeniríamos": "zenir",
    "zeniríeis": "zenir",
    "zenis": "zenir",
    "zenisse": "zenir",
    "zenissem": "zenir",
    "zenisses": "zenir",
    "zeniste": "zenir",
    "zenistes": "zenir",
    "zenitais": "zenital",
    "zeniu": "zenir",
    "zeno": "zenir",
    "zenonismos": "zenonismo",
    "zenonistas": "zenonista",
    "zenzéms": "zenzém",
    "zeníamo": "zenir",
    "zeníamos": "zenir",
    "zeníeis": "zenir",
    "zeníramo": "zenir",
    "zeníramos": "zenir",
    "zeníreis": "zenir",
    "zenísseis": "zenir",
    "zeníssemos": "zenir",
    "zenónica": "zenónico",
    "zenónicas": "zenónico",
    "zenónicos": "zenónico",
    "zeolíticos": "zeolítico",
    "zepelins": "zepelim",
    "zerbos": "zerbo",
    "zeribandas": "zeribanda",
    "zerichias": "zerichia",
    "zeros": "zero",
    "zerumbas": "zerumba",
    "zerumbetes": "zerumbete",
    "zerês": "zerê",
    "zestos": "zesto",
    "zetacismos": "zetacismo",
    "zetas": "zeta",
    "zetética": "zetético",
    "zetéticas": "zetético",
    "zetéticos": "zetético",
    "zeugitana": "zeugitano",
    "zeugitanas": "zeugitano",
    "zeugitanos": "zeugitano",
    "zeugitas": "zeugita",
    "zeugmas": "zeugma",
    "zeugmática": "zeugmático",
    "zeugmáticas": "zeugmático",
    "zeugmáticos": "zeugmático",
    "zeugos": "zeugo",
    "zeídeos": "zeídeo",
    "zeísmos": "zeísmo",
    "zeógaga": "zeógago",
    "zeógagas": "zeógago",
    "zeógagos": "zeógago",
    "zeólitos": "zeólito",
    "zibelinas": "zibelina",
    "zibetas": "zibeta",
    "zicha": "zichar",
    "zichada": "zichar",
    "zichadas": "zichar",
    "zichado": "zichar",
    "zichados": "zichar",
    "zichai": "zichar",
    "zichais": "zichar",
    "zicham": "zichar",
    "zichamo": "zichar",
    "zichamos": "zichar",
    "zichando": "zichar",
    "zichara": "zichar",
    "zicharam": "zichar",
    "zicharas": "zichar",
    "zichardes": "zichar",
    "zicharei": "zichar",
    "zichareis": "zichar",
    "zicharem": "zichar",
    "zicharemos": "zichar",
    "zichares": "zichar",
    "zicharia": "zichar",
    "zichariam": "zichar",
    "zicharias": "zichar",
    "zicharmo": "zichar",
    "zicharmos": "zichar",
    "zichará": "zichar",
    "zicharás": "zichar",
    "zicharão": "zichar",
    "zicharíamos": "zichar",
    "zicharíeis": "zichar",
    "zichas": "zichar",
    "zichasse": "zichar",
    "zichassem": "zichar",
    "zichasses": "zichar",
    "zichaste": "zichar",
    "zichastes": "zichar",
    "zichava": "zichar",
    "zichavam": "zichar",
    "zichavas": "zichar",
    "ziche": "zichar",
    "zichei": "zichar",
    "zicheis": "zichar",
    "zichem": "zichar",
    "zichemo": "zichar",
    "zichemos": "zichar",
    "ziches": "zichar",
    "zicho": "zichar",
    "zichos": "zicho",
    "zichou": "zichar",
    "zichámo": "zichar",
    "zichámos": "zichar",
    "zicháramo": "zichar",
    "zicháramos": "zichar",
    "zicháreis": "zichar",
    "zichásseis": "zichar",
    "zichássemos": "zichar",
    "zichávamo": "zichar",
    "zichávamos": "zichar",
    "zicháveis": "zichar",
    "zigoblastos": "zigoblasto",
    "zigobrânquia": "zigobrânquio",
    "zigobrânquias": "zigobrânquio",
    "zigobrânquios": "zigobrânquio",
    "zigocardíaca": "zigocardíaco",
    "zigocardíacas": "zigocardíaco",
    "zigocardíacos": "zigocardíaco",
    "zigodontes": "zigodonte",
    "zigodáctila": "zigodáctilo",
    "zigodáctilas": "zigodáctilo",
    "zigodáctilos": "zigodáctilo",
    "zigofilos": "zigofilo",
    "zigofiláceas": "zigofilácea",
    "zigofíleas": "zigofílea",
    "zigogâmetas": "zigogâmeta",
    "zigomas": "zigoma",
    "zigomatauriculares": "zigomatauricular",
    "zigomatolabiais": "zigomatolabial",
    "zigomatomaxilares": "zigomatomaxilar",
    "zigomicetales": "zigomicetale",
    "zigomicetes": "zigomicete",
    "zigomorfa": "zigomorfo",
    "zigomorfas": "zigomorfo",
    "zigomorfos": "zigomorfo",
    "zigomática": "zigomático",
    "zigomáticas": "zigomático",
    "zigomáticos": "zigomático",
    "zigonemas": "zigonema",
    "zigoses": "zigose",
    "zigotactismos": "zigotactismo",
    "zigotena": "zigoteno",
    "zigotenas": "zigoteno",
    "zigotenos": "zigoteno",
    "zigotos": "zigoto",
    "zigotáctica": "zigotáctico",
    "zigotácticas": "zigotáctico",
    "zigotácticos": "zigotáctico",
    "zigotómeros": "zigotómero",
    "ziguezagueada": "ziguezaguear",
    "ziguezagueadas": "ziguezaguear",
    "ziguezagueado": "ziguezaguear",
    "ziguezagueados": "ziguezaguear",
    "ziguezagueai": "ziguezaguear",
    "ziguezagueais": "ziguezaguear",
    "ziguezagueamo": "ziguezaguear",
    "ziguezagueamos": "ziguezaguear",
    "ziguezagueando": "ziguezaguear",
    "ziguezagueantes": "ziguezagueante",
    "ziguezagueara": "ziguezaguear",
    "ziguezaguearam": "ziguezaguear",
    "ziguezaguearas": "ziguezaguear",
    "ziguezagueardes": "ziguezaguear",
    "ziguezaguearei": "ziguezaguear",
    "ziguezagueareis": "ziguezaguear",
    "ziguezaguearem": "ziguezaguear",
    "ziguezaguearemos": "ziguezaguear",
    "ziguezagueares": "ziguezaguear",
    "ziguezaguearia": "ziguezaguear",
    "ziguezagueariam": "ziguezaguear",
    "ziguezaguearias": "ziguezaguear",
    "ziguezaguearmo": "ziguezaguear",
    "ziguezaguearmos": "ziguezaguear",
    "ziguezagueará": "ziguezaguear",
    "ziguezaguearás": "ziguezaguear",
    "ziguezaguearão": "ziguezaguear",
    "ziguezaguearíamos": "ziguezaguear",
    "ziguezaguearíeis": "ziguezaguear",
    "ziguezagueasse": "ziguezaguear",
    "ziguezagueassem": "ziguezaguear",
    "ziguezagueasses": "ziguezaguear",
    "ziguezagueaste": "ziguezaguear",
    "ziguezagueastes": "ziguezaguear",
    "ziguezagueava": "ziguezaguear",
    "ziguezagueavam": "ziguezaguear",
    "ziguezagueavas": "ziguezaguear",
    "ziguezagueei": "ziguezaguear",
    "ziguezagueeis": "ziguezaguear",
    "ziguezagueemo": "ziguezaguear",
    "ziguezagueemos": "ziguezaguear",
    "ziguezagueia": "ziguezaguear",
    "ziguezagueiam": "ziguezaguear",
    "ziguezagueias": "ziguezaguear",
    "ziguezagueie": "ziguezaguear",
    "ziguezagueiem": "ziguezaguear",
    "ziguezagueies": "ziguezaguear",
    "ziguezagueio": "ziguezaguear",
    "ziguezagueou": "ziguezaguear",
    "ziguezagues": "ziguezague",
    "ziguezagueámo": "ziguezaguear",
    "ziguezagueámos": "ziguezaguear",
    "ziguezagueáramo": "ziguezaguear",
    "ziguezagueáramos": "ziguezaguear",
    "ziguezagueáreis": "ziguezaguear",
    "ziguezagueásseis": "ziguezaguear",
    "ziguezagueássemos": "ziguezaguear",
    "ziguezagueávamo": "ziguezaguear",
    "ziguezagueávamos": "ziguezaguear",
    "ziguezagueáveis": "ziguezaguear",
    "ziguezigues": "ziguezigue",
    "zigurates": "zigurate",
    "zigófases": "zigófase",
    "zigófitos": "zigófito",
    "zigósporos": "zigósporo",
    "zigóstatas": "zigóstata",
    "zilros": "zilro",
    "zimas": "zima",
    "zimbabueana": "zimbabueano",
    "zimbabueanas": "zimbabueano",
    "zimbabueanos": "zimbabueano",
    "zimbos": "zimbo",
    "zimbra": "zimbrar",
    "zimbrada": "zimbrar",
    "zimbradas": "zimbrar",
    "zimbrado": "zimbrar",
    "zimbrados": "zimbrar",
    "zimbrai": "zimbrar",
    "zimbrais": "zimbrar",
    "zimbram": "zimbrar",
    "zimbramo": "zimbrar",
    "zimbramos": "zimbrar",
    "zimbrando": "zimbrar",
    "zimbrara": "zimbrar",
    "zimbraram": "zimbrar",
    "zimbraras": "zimbrar",
    "zimbrarde": "zimbrar",
    "zimbrardes": "zimbrar",
    "zimbrare": "zimbrar",
    "zimbrarei": "zimbrar",
    "zimbrareis": "zimbrar",
    "zimbrarem": "zimbrar",
    "zimbraremos": "zimbrar",
    "zimbrares": "zimbrar",
    "zimbraria": "zimbrar",
    "zimbrariam": "zimbrar",
    "zimbrarias": "zimbrar",
    "zimbrarmo": "zimbrar",
    "zimbrarmos": "zimbrar",
    "zimbrará": "zimbrar",
    "zimbrarás": "zimbrar",
    "zimbrarão": "zimbrar",
    "zimbraríamos": "zimbrar",
    "zimbraríeis": "zimbrar",
    "zimbras": "zimbrar",
    "zimbrasse": "zimbrar",
    "zimbrassem": "zimbrar",
    "zimbrasses": "zimbrar",
    "zimbraste": "zimbrar",
    "zimbrastes": "zimbrar",
    "zimbrava": "zimbrar",
    "zimbravam": "zimbrar",
    "zimbravas": "zimbrar",
    "zimbre": "zimbrar",
    "zimbrei": "zimbrar",
    "zimbreirais": "zimbreiral",
    "zimbreiros": "zimbreiro",
    "zimbreis": "zimbrar",
    "zimbrem": "zimbrar",
    "zimbremo": "zimbrar",
    "zimbremos": "zimbrar",
    "zimbres": "zimbrar",
    "zimbro": "zimbrar",
    "zimbros": "zimbro",
    "zimbrou": "zimbrar",
    "zimbrá": "zimbrar",
    "zimbrámo": "zimbrar",
    "zimbrámos": "zimbrar",
    "zimbráramo": "zimbrar",
    "zimbráramos": "zimbrar",
    "zimbrárei": "zimbrar",
    "zimbráreis": "zimbrar",
    "zimbrásseis": "zimbrar",
    "zimbrássemos": "zimbrar",
    "zimbrávamo": "zimbrar",
    "zimbrávamos": "zimbrar",
    "zimbrávei": "zimbrar",
    "zimbráveis": "zimbrar",
    "zimbórios": "zimbório",
    "zimeoses": "zimeose",
    "zimogenias": "zimogenia",
    "zimogénica": "zimogénico",
    "zimogénicas": "zimogénico",
    "zimogénicos": "zimogénico",
    "zimologias": "zimologia",
    "zimoses": "zimose",
    "zimosimetrias": "zimosimetria",
    "zimosimétrica": "zimosimétrico",
    "zimosimétricas": "zimosimétrico",
    "zimosimétricos": "zimosimétrico",
    "zimosímetros": "zimosímetro",
    "zimotecnias": "zimotecnia",
    "zimoterapias": "zimoterapia",
    "zimotécnica": "zimotécnico",
    "zimotécnicas": "zimotécnico",
    "zimotécnicos": "zimotécnico",
    "zimógena": "zimógeno",
    "zimógenas": "zimógeno",
    "zimógenos": "zimógeno",
    "zimótica": "zimótico",
    "zimóticas": "zimótico",
    "zimóticos": "zimótico",
    "zina": "zinir",
    "zinabres": "zinabre",
    "zinais": "zinir",
    "zinam": "zinir",
    "zinamo": "zinir",
    "zinamos": "zinir",
    "zinas": "zinir",
    "zinca": "zincar",
    "zincada": "zincar",
    "zincadas": "zincar",
    "zincado": "zincar",
    "zincados": "zincar",
    "zincagens": "zincagem",
    "zincai": "zincar",
    "zincais": "zincar",
    "zincam": "zincar",
    "zincamo": "zincar",
    "zincamos": "zincar",
    "zincando": "zincar",
    "zincara": "zincar",
    "zincaram": "zincar",
    "zincaras": "zincar",
    "zincarde": "zincar",
    "zincardes": "zincar",
    "zincare": "zincar",
    "zincarei": "zincar",
    "zincareis": "zincar",
    "zincarem": "zincar",
    "zincaremos": "zincar",
    "zincares": "zincar",
    "zincaria": "zincar",
    "zincariam": "zincar",
    "zincarias": "zincar",
    "zincarmo": "zincar",
    "zincarmos": "zincar",
    "zincará": "zincar",
    "zincarás": "zincar",
    "zincarão": "zincar",
    "zincaríamos": "zincar",
    "zincaríeis": "zincar",
    "zincas": "zincar",
    "zincasse": "zincar",
    "zincassem": "zincar",
    "zincasses": "zincar",
    "zincaste": "zincar",
    "zincastes": "zincar",
    "zincava": "zincar",
    "zincavam": "zincar",
    "zincavas": "zincar",
    "zincites": "zincite",
    "zinco": "zincar",
    "zincografa": "zincografar",
    "zincografada": "zincografar",
    "zincografadas": "zincografar",
    "zincografado": "zincografar",
    "zincografados": "zincografar",
    "zincografai": "zincografar",
    "zincografais": "zincografar",
    "zincografam": "zincografar",
    "zincografamo": "zincografar",
    "zincografamos": "zincografar",
    "zincografando": "zincografar",
    "zincografara": "zincografar",
    "zincografaram": "zincografar",
    "zincografaras": "zincografar",
    "zincografarde": "zincografar",
    "zincografardes": "zincografar",
    "zincografare": "zincografar",
    "zincografarei": "zincografar",
    "zincografareis": "zincografar",
    "zincografarem": "zincografar",
    "zincografaremos": "zincografar",
    "zincografares": "zincografar",
    "zincografaria": "zincografar",
    "zincografariam": "zincografar",
    "zincografarias": "zincografar",
    "zincografarmo": "zincografar",
    "zincografarmos": "zincografar",
    "zincografará": "zincografar",
    "zincografarás": "zincografar",
    "zincografarão": "zincografar",
    "zincografaríamos": "zincografar",
    "zincografaríeis": "zincografar",
    "zincografas": "zincografar",
    "zincografasse": "zincografar",
    "zincografassem": "zincografar",
    "zincografasses": "zincografar",
    "zincografaste": "zincografar",
    "zincografastes": "zincografar",
    "zincografava": "zincografar",
    "zincografavam": "zincografar",
    "zincografavas": "zincografar",
    "zincografe": "zincografar",
    "zincografei": "zincografar",
    "zincografeis": "zincografar",
    "zincografem": "zincografar",
    "zincografemo": "zincografar",
    "zincografemos": "zincografar",
    "zincografes": "zincografar",
    "zincografias": "zincografia",
    "zincografo": "zincografar",
    "zincografou": "zincografar",
    "zincografá": "zincografar",
    "zincografámo": "zincografar",
    "zincografámos": "zincografar",
    "zincografáramo": "zincografar",
    "zincografáramos": "zincografar",
    "zincografárei": "zincografar",
    "zincografáreis": "zincografar",
    "zincografásseis": "zincografar",
    "zincografássemos": "zincografar",
    "zincografávamo": "zincografar",
    "zincografávamos": "zincografar",
    "zincografávei": "zincografar",
    "zincografáveis": "zincografar",
    "zincograva": "zincogravar",
    "zincogravada": "zincogravar",
    "zincogravadas": "zincogravar",
    "zincogravado": "zincogravar",
    "zincogravadora": "zincogravador",
    "zincogravadoras": "zincogravador",
    "zincogravadores": "zincogravador",
    "zincogravados": "zincogravar",
    "zincogravai": "zincogravar",
    "zincogravais": "zincogravar",
    "zincogravam": "zincogravar",
    "zincogravamo": "zincogravar",
    "zincogravamos": "zincogravar",
    "zincogravando": "zincogravar",
    "zincogravara": "zincogravar",
    "zincogravaram": "zincogravar",
    "zincogravaras": "zincogravar",
    "zincogravarde": "zincogravar",
    "zincogravardes": "zincogravar",
    "zincogravare": "zincogravar",
    "zincogravarei": "zincogravar",
    "zincogravareis": "zincogravar",
    "zincogravarem": "zincogravar",
    "zincogravaremos": "zincogravar",
    "zincogravares": "zincogravar",
    "zincogravaria": "zincogravar",
    "zincogravariam": "zincogravar",
    "zincogravarias": "zincogravar",
    "zincogravarmo": "zincogravar",
    "zincogravarmos": "zincogravar",
    "zincogravará": "zincogravar",
    "zincogravarás": "zincogravar",
    "zincogravarão": "zincogravar",
    "zincogravaríamos": "zincogravar",
    "zincogravaríeis": "zincogravar",
    "zincogravas": "zincogravar",
    "zincogravasse": "zincogravar",
    "zincogravassem": "zincogravar",
    "zincogravasses": "zincogravar",
    "zincogravaste": "zincogravar",
    "zincogravastes": "zincogravar",
    "zincogravava": "zincogravar",
    "zincogravavam": "zincogravar",
    "zincogravavas": "zincogravar",
    "zincograve": "zincogravar",
    "zincogravei": "zincogravar",
    "zincograveis": "zincogravar",
    "zincogravem": "zincogravar",
    "zincogravemo": "zincogravar",
    "zincogravemos": "zincogravar",
    "zincograves": "zincogravar",
    "zincogravo": "zincogravar",
    "zincogravou": "zincogravar",
    "zincogravuras": "zincogravura",
    "zincogravá": "zincogravar",
    "zincogravámo": "zincogravar",
    "zincogravámos": "zincogravar",
    "zincograváramo": "zincogravar",
    "zincograváramos": "zincogravar",
    "zincogravárei": "zincogravar",
    "zincograváreis": "zincogravar",
    "zincogravásseis": "zincogravar",
    "zincogravássemos": "zincogravar",
    "zincogravávamo": "zincogravar",
    "zincogravávamos": "zincogravar",
    "zincogravávei": "zincogravar",
    "zincograváveis": "zincogravável",
    "zincográfica": "zincográfico",
    "zincográficas": "zincográfico",
    "zincográficos": "zincográfico",
    "zincos": "zinco",
    "zincou": "zincar",
    "zincá": "zincar",
    "zincámo": "zincar",
    "zincámos": "zincar",
    "zincáramo": "zincar",
    "zincáramos": "zincar",
    "zincárei": "zincar",
    "zincáreis": "zincar",
    "zincásseis": "zincar",
    "zincássemos": "zincar",
    "zincávamo": "zincar",
    "zincávamos": "zincar",
    "zincávei": "zincar",
    "zincáveis": "zincável",
    "zincífera": "zincífero",
    "zincíferas": "zincífero",
    "zincíferos": "zincífero",
    "zincógrafa": "zincógrafo",
    "zincógrafas": "zincógrafo",
    "zincógrafos": "zincógrafo",
    "zine": "zinir",
    "zineiras": "zineira",
    "zinem": "zinir",
    "zines": "zinir",
    "zinga": "zingar",
    "zingada": "zingar",
    "zingadas": "zingar",
    "zingado": "zingar",
    "zingadora": "zingador",
    "zingadoras": "zingador",
    "zingadores": "zingador",
    "zingados": "zingar",
    "zingai": "zingar",
    "zingais": "zingar",
    "zingam": "zingar",
    "zingamo": "zingar",
    "zingamochos": "zingamocho",
    "zingamos": "zingar",
    "zingando": "zingar",
    "zingara": "zingar",
    "zingaram": "zingar",
    "zingaras": "zingar",
    "zingardes": "zingar",
    "zingareada": "zingarear",
    "zingareadas": "zingarear",
    "zingareado": "zingarear",
    "zingareados": "zingarear",
    "zingareai": "zingarear",
    "zingareais": "zingarear",
    "zingareamo": "zingarear",
    "zingareamos": "zingarear",
    "zingareando": "zingarear",
    "zingareara": "zingarear",
    "zingarearam": "zingarear",
    "zingarearas": "zingarear",
    "zingareardes": "zingarear",
    "zingarearei": "zingarear",
    "zingareareis": "zingarear",
    "zingarearem": "zingarear",
    "zingarearemos": "zingarear",
    "zingareares": "zingarear",
    "zingarearia": "zingarear",
    "zingareariam": "zingarear",
    "zingarearias": "zingarear",
    "zingarearmo": "zingarear",
    "zingarearmos": "zingarear",
    "zingareará": "zingarear",
    "zingarearás": "zingarear",
    "zingarearão": "zingarear",
    "zingarearíamos": "zingarear",
    "zingarearíeis": "zingarear",
    "zingareasse": "zingarear",
    "zingareassem": "zingarear",
    "zingareasses": "zingarear",
    "zingareaste": "zingarear",
    "zingareastes": "zingarear",
    "zingareava": "zingarear",
    "zingareavam": "zingarear",
    "zingareavas": "zingarear",
    "zingareei": "zingarear",
    "zingareeis": "zingarear",
    "zingareemo": "zingarear",
    "zingareemos": "zingarear",
    "zingarei": "zingar",
    "zingareia": "zingarear",
    "zingareiam": "zingarear",
    "zingareias": "zingarear",
    "zingareie": "zingarear",
    "zingareiem": "zingarear",
    "zingareies": "zingarear",
    "zingareio": "zingarear",
    "zingareis": "zingar",
    "zingarelada": "zingarelado",
    "zingareladas": "zingarelado",
    "zingarelados": "zingarelado",
    "zingarem": "zingar",
    "zingaremos": "zingar",
    "zingareou": "zingarear",
    "zingares": "zingar",
    "zingareámo": "zingarear",
    "zingareámos": "zingarear",
    "zingareáramo": "zingarear",
    "zingareáramos": "zingarear",
    "zingareáreis": "zingarear",
    "zingareásseis": "zingarear",
    "zingareássemos": "zingarear",
    "zingareávamo": "zingarear",
    "zingareávamos": "zingarear",
    "zingareáveis": "zingarear",
    "zingaria": "zingar",
    "zingariam": "zingar",
    "zingarias": "zingar",
    "zingarmo": "zingar",
    "zingarmos": "zingar",
    "zingará": "zingar",
    "zingarás": "zingar",
    "zingarão": "zingar",
    "zingaríamos": "zingar",
    "zingaríeis": "zingar",
    "zingas": "zingar",
    "zingasse": "zingar",
    "zingassem": "zingar",
    "zingasses": "zingar",
    "zingaste": "zingar",
    "zingastes": "zingar",
    "zingava": "zingar",
    "zingavam": "zingar",
    "zingavas": "zingar",
    "zingiberáceas": "zingiberácea",
    "zingo": "zingar",
    "zingou": "zingar",
    "zingra": "zingrar",
    "zingrada": "zingrar",
    "zingradas": "zingrar",
    "zingrado": "zingrar",
    "zingrados": "zingrar",
    "zingrai": "zingrar",
    "zingrais": "zingrar",
    "zingram": "zingrar",
    "zingramo": "zingrar",
    "zingramos": "zingrar",
    "zingrando": "zingrar",
    "zingrara": "zingrar",
    "zingraram": "zingrar",
    "zingraras": "zingrar",
    "zingrarde": "zingrar",
    "zingrardes": "zingrar",
    "zingrare": "zingrar",
    "zingrarei": "zingrar",
    "zingrareis": "zingrar",
    "zingrarem": "zingrar",
    "zingraremos": "zingrar",
    "zingrares": "zingrar",
    "zingraria": "zingrar",
    "zingrariam": "zingrar",
    "zingrarias": "zingrar",
    "zingrarmo": "zingrar",
    "zingrarmos": "zingrar",
    "zingrará": "zingrar",
    "zingrarás": "zingrar",
    "zingrarão": "zingrar",
    "zingraríamos": "zingrar",
    "zingraríeis": "zingrar",
    "zingras": "zingrar",
    "zingrasse": "zingrar",
    "zingrassem": "zingrar",
    "zingrasses": "zingrar",
    "zingraste": "zingrar",
    "zingrastes": "zingrar",
    "zingrava": "zingrar",
    "zingravam": "zingrar",
    "zingravas": "zingrar",
    "zingrações": "zingração",
    "zingre": "zingrar",
    "zingrei": "zingrar",
    "zingreis": "zingrar",
    "zingrem": "zingrar",
    "zingremo": "zingrar",
    "zingremos": "zingrar",
    "zingres": "zingrar",
    "zingro": "zingrar",
    "zingrou": "zingrar",
    "zingrá": "zingrar",
    "zingrámo": "zingrar",
    "zingrámos": "zingrar",
    "zingráramo": "zingrar",
    "zingráramos": "zingrar",
    "zingrárei": "zingrar",
    "zingráreis": "zingrar",
    "zingrásseis": "zingrar",
    "zingrássemos": "zingrar",
    "zingrávamo": "zingrar",
    "zingrávamos": "zingrar",
    "zingrávei": "zingrar",
    "zingráveis": "zingrar",
    "zingue": "zingar",
    "zinguei": "zingar",
    "zingueis": "zingar",
    "zinguem": "zingar",
    "zinguemo": "zingar",
    "zinguemos": "zingar",
    "zinguerreada": "zinguerrear",
    "zinguerreadas": "zinguerrear",
    "zinguerreado": "zinguerrear",
    "zinguerreados": "zinguerrear",
    "zinguerreai": "zinguerrear",
    "zinguerreais": "zinguerrear",
    "zinguerreamo": "zinguerrear",
    "zinguerreamos": "zinguerrear",
    "zinguerreando": "zinguerrear",
    "zinguerreara": "zinguerrear",
    "zinguerrearam": "zinguerrear",
    "zinguerrearas": "zinguerrear",
    "zinguerreardes": "zinguerrear",
    "zinguerrearei": "zinguerrear",
    "zinguerreareis": "zinguerrear",
    "zinguerrearem": "zinguerrear",
    "zinguerrearemos": "zinguerrear",
    "zinguerreares": "zinguerrear",
    "zinguerrearia": "zinguerrear",
    "zinguerreariam": "zinguerrear",
    "zinguerrearias": "zinguerrear",
    "zinguerrearmo": "zinguerrear",
    "zinguerrearmos": "zinguerrear",
    "zinguerreará": "zinguerrear",
    "zinguerrearás": "zinguerrear",
    "zinguerrearão": "zinguerrear",
    "zinguerrearíamos": "zinguerrear",
    "zinguerrearíeis": "zinguerrear",
    "zinguerreasse": "zinguerrear",
    "zinguerreassem": "zinguerrear",
    "zinguerreasses": "zinguerrear",
    "zinguerreaste": "zinguerrear",
    "zinguerreastes": "zinguerrear",
    "zinguerreava": "zinguerrear",
    "zinguerreavam": "zinguerrear",
    "zinguerreavas": "zinguerrear",
    "zinguerreei": "zinguerrear",
    "zinguerreeis": "zinguerrear",
    "zinguerreemo": "zinguerrear",
    "zinguerreemos": "zinguerrear",
    "zinguerreia": "zinguerrear",
    "zinguerreiam": "zinguerrear",
    "zinguerreias": "zinguerrear",
    "zinguerreie": "zinguerrear",
    "zinguerreiem": "zinguerrear",
    "zinguerreies": "zinguerrear",
    "zinguerreio": "zinguerrear",
    "zinguerreou": "zinguerrear",
    "zinguerreámo": "zinguerrear",
    "zinguerreámos": "zinguerrear",
    "zinguerreáramo": "zinguerrear",
    "zinguerreáramos": "zinguerrear",
    "zinguerreáreis": "zinguerrear",
    "zinguerreásseis": "zinguerrear",
    "zinguerreássemos": "zinguerrear",
    "zinguerreávamo": "zinguerrear",
    "zinguerreávamos": "zinguerrear",
    "zinguerreáveis": "zinguerrear",
    "zingues": "zingar",
    "zingámo": "zingar",
    "zingámos": "zingar",
    "zingáramo": "zingar",
    "zingáramos": "zingar",
    "zingáreis": "zingar",
    "zingásseis": "zingar",
    "zingássemos": "zingar",
    "zingávamo": "zingar",
    "zingávamos": "zingar",
    "zingáveis": "zingar",
    "zinha": "zinho",
    "zinhas": "zinho",
    "zinhos": "zinho",
    "zini": "zinir",
    "zinia": "zinir",
    "ziniam": "zinir",
    "zinias": "zinir",
    "zinida": "zinir",
    "zinidas": "zinir",
    "zinideiras": "zinideira",
    "zinido": "zinir",
    "zinidos": "zinir",
    "zinimo": "zinir",
    "zinimos": "zinir",
    "zinindo": "zinir",
    "zinira": "zinir",
    "ziniram": "zinir",
    "ziniras": "zinir",
    "zinirdes": "zinir",
    "zinirei": "zinir",
    "zinireis": "zinir",
    "zinirem": "zinir",
    "ziniremos": "zinir",
    "zinires": "zinir",
    "ziniria": "zinir",
    "ziniriam": "zinir",
    "zinirias": "zinir",
    "zinirmo": "zinir",
    "zinirmos": "zinir",
    "zinirá": "zinir",
    "zinirás": "zinir",
    "zinirão": "zinir",
    "ziniríamos": "zinir",
    "ziniríeis": "zinir",
    "zinis": "zinir",
    "zinisse": "zinir",
    "zinissem": "zinir",
    "zinisses": "zinir",
    "ziniste": "zinir",
    "zinistes": "zinir",
    "ziniu": "zinir",
    "zino": "zinir",
    "zinque": "zincar",
    "zinquei": "zincar",
    "zinqueis": "zincar",
    "zinquem": "zincar",
    "zinquemo": "zincar",
    "zinquemos": "zincar",
    "zinques": "zincar",
    "ziníamo": "zinir",
    "ziníamos": "zinir",
    "ziníeis": "zinir",
    "ziníramo": "zinir",
    "ziníramos": "zinir",
    "ziníreis": "zinir",
    "zinísseis": "zinir",
    "ziníssemos": "zinir",
    "zipa": "zipar",
    "zipada": "zipar",
    "zipadas": "zipar",
    "zipado": "zipar",
    "zipados": "zipar",
    "zipai": "zipar",
    "zipais": "zipar",
    "zipam": "zipar",
    "zipamo": "zipar",
    "zipamos": "zipar",
    "zipando": "zipar",
    "zipara": "zipar",
    "ziparam": "zipar",
    "ziparas": "zipar",
    "ziparde": "zipar",
    "zipardes": "zipar",
    "zipare": "zipar",
    "ziparei": "zipar",
    "zipareis": "zipar",
    "ziparem": "zipar",
    "ziparemos": "zipar",
    "zipares": "zipar",
    "ziparia": "zipar",
    "zipariam": "zipar",
    "ziparias": "zipar",
    "ziparmo": "zipar",
    "ziparmos": "zipar",
    "zipará": "zipar",
    "ziparás": "zipar",
    "ziparão": "zipar",
    "ziparíamos": "zipar",
    "ziparíeis": "zipar",
    "zipas": "zipar",
    "zipasse": "zipar",
    "zipassem": "zipar",
    "zipasses": "zipar",
    "zipaste": "zipar",
    "zipastes": "zipar",
    "zipava": "zipar",
    "zipavam": "zipar",
    "zipavas": "zipar",
    "zipe": "zipar",
    "zipei": "zipar",
    "zipeis": "zipar",
    "zipem": "zipar",
    "zipemo": "zipar",
    "zipemos": "zipar",
    "zipes": "zipar",
    "zipo": "zipar",
    "zipou": "zipar",
    "zipá": "zipar",
    "zipámo": "zipar",
    "zipámos": "zipar",
    "zipáramo": "zipar",
    "zipáramos": "zipar",
    "zipárei": "zipar",
    "zipáreis": "zipar",
    "zipásseis": "zipar",
    "zipássemos": "zipar",
    "zipávamo": "zipar",
    "zipávamos": "zipar",
    "zipávei": "zipar",
    "zipáveis": "zipar",
    "zirbais": "zirbal",
    "zirbeiros": "zirbeiro",
    "zirbos": "zirbo",
    "zircónios": "zircónio",
    "zircões": "zircão",
    "zirneiras": "zirneira",
    "zirra": "zirrar",
    "zirrada": "zirrar",
    "zirradas": "zirrar",
    "zirrado": "zirrar",
    "zirrados": "zirrar",
    "zirrai": "zirrar",
    "zirrais": "zirrar",
    "zirram": "zirrar",
    "zirramo": "zirrar",
    "zirramos": "zirrar",
    "zirrando": "zirrar",
    "zirrara": "zirrar",
    "zirraram": "zirrar",
    "zirraras": "zirrar",
    "zirrardes": "zirrar",
    "zirrarei": "zirrar",
    "zirrareis": "zirrar",
    "zirrarem": "zirrar",
    "zirraremos": "zirrar",
    "zirrares": "zirrar",
    "zirraria": "zirrar",
    "zirrariam": "zirrar",
    "zirrarias": "zirrar",
    "zirrarmo": "zirrar",
    "zirrarmos": "zirrar",
    "zirrará": "zirrar",
    "zirrarás": "zirrar",
    "zirrarão": "zirrar",
    "zirraríamos": "zirrar",
    "zirraríeis": "zirrar",
    "zirras": "zirrar",
    "zirrasse": "zirrar",
    "zirrassem": "zirrar",
    "zirrasses": "zirrar",
    "zirraste": "zirrar",
    "zirrastes": "zirrar",
    "zirrava": "zirrar",
    "zirravam": "zirrar",
    "zirravas": "zirrar",
    "zirre": "zirrar",
    "zirrei": "zirrar",
    "zirreis": "zirrar",
    "zirrem": "zirrar",
    "zirremo": "zirrar",
    "zirremos": "zirrar",
    "zirres": "zirrar",
    "zirro": "zirrar",
    "zirros": "zirro",
    "zirrou": "zirrar",
    "zirrámo": "zirrar",
    "zirrámos": "zirrar",
    "zirráramo": "zirrar",
    "zirráramos": "zirrar",
    "zirráreis": "zirrar",
    "zirrásseis": "zirrar",
    "zirrássemos": "zirrar",
    "zirrávamo": "zirrar",
    "zirrávamos": "zirrar",
    "zirráveis": "zirrar",
    "zitógalas": "zitógala",
    "zizaneia": "zizaniar",
    "zizaneiam": "zizaniar",
    "zizaneias": "zizaniar",
    "zizaneie": "zizaniar",
    "zizaneiem": "zizaniar",
    "zizaneies": "zizaniar",
    "zizaneio": "zizaniar",
    "zizaniada": "zizaniar",
    "zizaniadas": "zizaniar",
    "zizaniado": "zizaniar",
    "zizaniados": "zizaniar",
    "zizaniai": "zizaniar",
    "zizaniais": "zizaniar",
    "zizaniamo": "zizaniar",
    "zizaniamos": "zizaniar",
    "zizaniando": "zizaniar",
    "zizaniara": "zizaniar",
    "zizaniaram": "zizaniar",
    "zizaniaras": "zizaniar",
    "zizaniardes": "zizaniar",
    "zizaniarei": "zizaniar",
    "zizaniareis": "zizaniar",
    "zizaniarem": "zizaniar",
    "zizaniaremos": "zizaniar",
    "zizaniares": "zizaniar",
    "zizaniaria": "zizaniar",
    "zizaniariam": "zizaniar",
    "zizaniarias": "zizaniar",
    "zizaniarmo": "zizaniar",
    "zizaniarmos": "zizaniar",
    "zizaniará": "zizaniar",
    "zizaniarás": "zizaniar",
    "zizaniarão": "zizaniar",
    "zizaniaríamos": "zizaniar",
    "zizaniaríeis": "zizaniar",
    "zizaniasse": "zizaniar",
    "zizaniassem": "zizaniar",
    "zizaniasses": "zizaniar",
    "zizaniaste": "zizaniar",
    "zizaniastes": "zizaniar",
    "zizaniava": "zizaniar",
    "zizaniavam": "zizaniar",
    "zizaniavas": "zizaniar",
    "zizaniei": "zizaniar",
    "zizanieis": "zizaniar",
    "zizaniemo": "zizaniar",
    "zizaniemos": "zizaniar",
    "zizaniou": "zizaniar",
    "zizanistas": "zizanista",
    "zizaniámo": "zizaniar",
    "zizaniámos": "zizaniar",
    "zizaniáramo": "zizaniar",
    "zizaniáramos": "zizaniar",
    "zizaniáreis": "zizaniar",
    "zizaniásseis": "zizaniar",
    "zizaniássemos": "zizaniar",
    "zizaniávamo": "zizaniar",
    "zizaniávamos": "zizaniar",
    "zizaniáveis": "zizaniar",
    "zizia": "ziziar",
    "ziziada": "ziziar",
    "ziziadas": "ziziar",
    "ziziado": "ziziar",
    "ziziados": "ziziar",
    "ziziai": "ziziar",
    "ziziais": "ziziar",
    "ziziam": "ziziar",
    "ziziamo": "ziziar",
    "ziziamos": "ziziar",
    "ziziando": "ziziar",
    "ziziara": "ziziar",
    "ziziaram": "ziziar",
    "ziziaras": "ziziar",
    "ziziardes": "ziziar",
    "ziziarei": "ziziar",
    "ziziareis": "ziziar",
    "ziziarem": "ziziar",
    "ziziaremos": "ziziar",
    "ziziares": "ziziar",
    "ziziaria": "ziziar",
    "ziziariam": "ziziar",
    "ziziarias": "ziziar",
    "ziziarmo": "ziziar",
    "ziziarmos": "ziziar",
    "ziziará": "ziziar",
    "ziziarás": "ziziar",
    "ziziarão": "ziziar",
    "ziziaríamos": "ziziar",
    "ziziaríeis": "ziziar",
    "zizias": "ziziar",
    "ziziasse": "ziziar",
    "ziziassem": "ziziar",
    "ziziasses": "ziziar",
    "ziziaste": "ziziar",
    "ziziastes": "ziziar",
    "ziziava": "ziziar",
    "ziziavam": "ziziar",
    "ziziavas": "ziziar",
    "zizie": "ziziar",
    "ziziei": "ziziar",
    "zizieis": "ziziar",
    "ziziem": "ziziar",
    "ziziemo": "ziziar",
    "ziziemos": "ziziar",
    "zizies": "ziziar",
    "zizifiáceas": "zizifiácea",
    "zizio": "ziziar",
    "ziziou": "ziziar",
    "ziziámo": "ziziar",
    "ziziámos": "ziziar",
    "ziziáramo": "ziziar",
    "ziziáramos": "ziziar",
    "ziziáreis": "ziziar",
    "ziziásseis": "ziziar",
    "ziziássemos": "ziziar",
    "ziziávamo": "ziziar",
    "ziziávamos": "ziziar",
    "ziziáveis": "ziziar",
    "zizânias": "zizânia",
    "zoa": "zoar",
    "zoada": "zoar",
    "zoadas": "zoar",
    "zoadeiras": "zoadeira",
    "zoado": "zoar",
    "zoados": "zoar",
    "zoai": "zoar",
    "zoais": "zoar",
    "zoam": "zoar",
    "zoamo": "zoar",
    "zoamos": "zoar",
    "zoando": "zoar",
    "zoantropias": "zoantropia",
    "zoantropos": "zoantropo",
    "zoantários": "zoantário",
    "zoantídeos": "zoantídeo",
    "zoara": "zoar",
    "zoaram": "zoar",
    "zoaras": "zoar",
    "zoardes": "zoar",
    "zoarei": "zoar",
    "zoareis": "zoar",
    "zoarem": "zoar",
    "zoaremos": "zoar",
    "zoares": "zoar",
    "zoaria": "zoar",
    "zoariam": "zoar",
    "zoarias": "zoar",
    "zoarmo": "zoar",
    "zoarmos": "zoar",
    "zoará": "zoar",
    "zoarás": "zoar",
    "zoarão": "zoar",
    "zoaríamos": "zoar",
    "zoaríeis": "zoar",
    "zoas": "zoar",
    "zoasse": "zoar",
    "zoassem": "zoar",
    "zoasses": "zoar",
    "zoaste": "zoar",
    "zoastes": "zoar",
    "zoava": "zoar",
    "zoavam": "zoar",
    "zoavas": "zoar",
    "zodiacais": "zodiacal",
    "zodíacos": "zodíaco",
    "zoe": "zoar",
    "zoei": "zoar",
    "zoeias": "zoeia",
    "zoeiras": "zoeira",
    "zoeis": "zoar",
    "zoem": "zoar",
    "zoemo": "zoar",
    "zoemos": "zoar",
    "zoes": "zoar",
    "zogadas": "zogada",
    "zogas": "zoga",
    "zoiatras": "zoiatra",
    "zoiatrias": "zoiatria",
    "zoiatrologias": "zoiatrologia",
    "zoiatrologistas": "zoiatrologista",
    "zoiatróloga": "zoiatrólogo",
    "zoiatrólogas": "zoiatrólogo",
    "zoiatrólogos": "zoiatrólogo",
    "zoidiofilias": "zoidiofilia",
    "zoidiogamias": "zoidiogamia",
    "zoidiófila": "zoidiófilo",
    "zoidiófilas": "zoidiófilo",
    "zoidiófilos": "zoidiófilo",
    "zoidiógama": "zoidiógamo",
    "zoidiógamas": "zoidiógamo",
    "zoidiógamos": "zoidiógamo",
    "zoilos": "zoilo",
    "zoinas": "zoina",
    "zoisites": "zoisite",
    "zolaica": "zolaico",
    "zolaicas": "zolaico",
    "zolaicos": "zolaico",
    "zolas": "zola",
    "zolaísmos": "zolaísmo",
    "zolaístas": "zolaísta",
    "zolesca": "zolesco",
    "zolescas": "zolesco",
    "zolescos": "zolesco",
    "zolis": "zoli",
    "zolismos": "zolismo",
    "zolistas": "zolista",
    "zomba": "zombar",
    "zombada": "zombar",
    "zombadas": "zombar",
    "zombado": "zombar",
    "zombadora": "zombador",
    "zombadoras": "zombador",
    "zombadores": "zombador",
    "zombados": "zombar",
    "zombai": "zombar",
    "zombais": "zombar",
    "zombam": "zombar",
    "zombamo": "zombar",
    "zombamos": "zombar",
    "zombando": "zombar",
    "zombara": "zombar",
    "zombaram": "zombar",
    "zombaras": "zombar",
    "zombardes": "zombar",
    "zombarei": "zombar",
    "zombareis": "zombar",
    "zombarem": "zombar",
    "zombaremos": "zombar",
    "zombares": "zombar",
    "zombaria": "zombar",
    "zombariam": "zombar",
    "zombarias": "zombaria",
    "zombarmo": "zombar",
    "zombarmos": "zombar",
    "zombará": "zombar",
    "zombarás": "zombar",
    "zombarão": "zombar",
    "zombaríamos": "zombar",
    "zombaríeis": "zombar",
    "zombas": "zombar",
    "zombasse": "zombar",
    "zombassem": "zombar",
    "zombasses": "zombar",
    "zombaste": "zombar",
    "zombastes": "zombar",
    "zombava": "zombar",
    "zombavam": "zombar",
    "zombavas": "zombar",
    "zombe": "zombar",
    "zombei": "zombar",
    "zombeirona": "zombeirão",
    "zombeironas": "zombeirão",
    "zombeirões": "zombeirão",
    "zombeis": "zombar",
    "zombem": "zombar",
    "zombemo": "zombar",
    "zombemos": "zombar",
    "zombes": "zombar",
    "zombeteada": "zombetear",
    "zombeteadas": "zombetear",
    "zombeteado": "zombetear",
    "zombeteados": "zombetear",
    "zombeteai": "zombetear",
    "zombeteais": "zombetear",
    "zombeteamo": "zombetear",
    "zombeteamos": "zombetear",
    "zombeteando": "zombetear",
    "zombeteara": "zombetear",
    "zombetearam": "zombetear",
    "zombetearas": "zombetear",
    "zombeteardes": "zombetear",
    "zombetearei": "zombetear",
    "zombeteareis": "zombetear",
    "zombetearem": "zombetear",
    "zombetearemos": "zombetear",
    "zombeteares": "zombetear",
    "zombetearia": "zombetear",
    "zombeteariam": "zombetear",
    "zombetearias": "zombetear",
    "zombetearmo": "zombetear",
    "zombetearmos": "zombetear",
    "zombeteará": "zombetear",
    "zombetearás": "zombetear",
    "zombetearão": "zombetear",
    "zombetearíamos": "zombetear",
    "zombetearíeis": "zombetear",
    "zombeteasse": "zombetear",
    "zombeteassem": "zombetear",
    "zombeteasses": "zombetear",
    "zombeteaste": "zombetear",
    "zombeteastes": "zombetear",
    "zombeteava": "zombetear",
    "zombeteavam": "zombetear",
    "zombeteavas": "zombetear",
    "zombeteei": "zombetear",
    "zombeteeis": "zombetear",
    "zombeteemo": "zombetear",
    "zombeteemos": "zombetear",
    "zombeteia": "zombetear",
    "zombeteiam": "zombetear",
    "zombeteias": "zombetear",
    "zombeteie": "zombetear",
    "zombeteiem": "zombetear",
    "zombeteies": "zombetear",
    "zombeteio": "zombetear",
    "zombeteira": "zombeteiro",
    "zombeteiras": "zombeteiro",
    "zombeteiros": "zombeteiro",
    "zombeteou": "zombetear",
    "zombeteámo": "zombetear",
    "zombeteámos": "zombetear",
    "zombeteáramo": "zombetear",
    "zombeteáramos": "zombetear",
    "zombeteáreis": "zombetear",
    "zombeteásseis": "zombetear",
    "zombeteássemos": "zombetear",
    "zombeteávamo": "zombetear",
    "zombeteávamos": "zombetear",
    "zombeteáveis": "zombetear",
    "zombies": "zombie",
    "zombo": "zombar",
    "zombou": "zombar",
    "zombámo": "zombar",
    "zombámos": "zombar",
    "zombáramo": "zombar",
    "zombáramos": "zombar",
    "zombáreis": "zombar",
    "zombásseis": "zombar",
    "zombássemos": "zombar",
    "zombávamo": "zombar",
    "zombávamos": "zombar",
    "zombáveis": "zombar",
    "zomoterapias": "zomoterapia",
    "zompeira": "zompeiro",
    "zompeiras": "zompeiro",
    "zompeiros": "zompeiro",
    "zona": "zonar",
    "zonada": "zonar",
    "zonadas": "zonar",
    "zonado": "zonar",
    "zonados": "zonar",
    "zonai": "zonar",
    "zonais": "zonar",
    "zonam": "zonar",
    "zonamo": "zonar",
    "zonamos": "zonar",
    "zonando": "zonar",
    "zonara": "zonar",
    "zonaram": "zonar",
    "zonaras": "zonar",
    "zonarde": "zonar",
    "zonardes": "zonar",
    "zonare": "zonar",
    "zonarei": "zonar",
    "zonareis": "zonar",
    "zonarem": "zonar",
    "zonaremos": "zonar",
    "zonares": "zonar",
    "zonaria": "zonar",
    "zonariam": "zonar",
    "zonarias": "zonar",
    "zonarmo": "zonar",
    "zonarmos": "zonar",
    "zonará": "zonar",
    "zonarás": "zonar",
    "zonarão": "zonar",
    "zonaríamos": "zonar",
    "zonaríeis": "zonar",
    "zonas": "zonar",
    "zonasse": "zonar",
    "zonassem": "zonar",
    "zonasses": "zonar",
    "zonaste": "zonar",
    "zonastes": "zonar",
    "zonava": "zonar",
    "zonavam": "zonar",
    "zonavas": "zonar",
    "zoncha": "zonchar",
    "zonchada": "zonchar",
    "zonchadas": "zonchar",
    "zonchado": "zonchar",
    "zonchados": "zonchar",
    "zonchaduras": "zonchadura",
    "zonchai": "zonchar",
    "zonchais": "zonchar",
    "zoncham": "zonchar",
    "zonchamo": "zonchar",
    "zonchamos": "zonchar",
    "zonchando": "zonchar",
    "zonchara": "zonchar",
    "zoncharam": "zonchar",
    "zoncharas": "zonchar",
    "zonchardes": "zonchar",
    "zoncharei": "zonchar",
    "zonchareis": "zonchar",
    "zoncharem": "zonchar",
    "zoncharemos": "zonchar",
    "zonchares": "zonchar",
    "zoncharia": "zonchar",
    "zonchariam": "zonchar",
    "zoncharias": "zonchar",
    "zoncharmo": "zonchar",
    "zoncharmos": "zonchar",
    "zonchará": "zonchar",
    "zoncharás": "zonchar",
    "zoncharão": "zonchar",
    "zoncharíamos": "zonchar",
    "zoncharíeis": "zonchar",
    "zonchas": "zonchar",
    "zonchasse": "zonchar",
    "zonchassem": "zonchar",
    "zonchasses": "zonchar",
    "zonchaste": "zonchar",
    "zonchastes": "zonchar",
    "zonchava": "zonchar",
    "zonchavam": "zonchar",
    "zonchavas": "zonchar",
    "zonche": "zonchar",
    "zonchei": "zonchar",
    "zoncheis": "zonchar",
    "zonchem": "zonchar",
    "zonchemo": "zonchar",
    "zonchemos": "zonchar",
    "zonches": "zonchar",
    "zoncho": "zonchar",
    "zonchos": "zoncho",
    "zonchou": "zonchar",
    "zonchámo": "zonchar",
    "zonchámos": "zonchar",
    "zoncháramo": "zonchar",
    "zoncháramos": "zonchar",
    "zoncháreis": "zonchar",
    "zonchásseis": "zonchar",
    "zonchássemos": "zonchar",
    "zonchávamo": "zonchar",
    "zonchávamos": "zonchar",
    "zoncháveis": "zonchar",
    "zondália": "zondálio",
    "zondálias": "zondálio",
    "zondálios": "zondálio",
    "zone": "zonar",
    "zonei": "zonar",
    "zoneis": "zonar",
    "zonem": "zonar",
    "zonemo": "zonar",
    "zonemos": "zonar",
    "zones": "zonar",
    "zoniformes": "zoniforme",
    "zonifuga": "zonifugo",
    "zonifugas": "zonifugo",
    "zonifugos": "zonifugo",
    "zono": "zonar",
    "zonou": "zonar",
    "zonza": "zonzo",
    "zonzas": "zonzo",
    "zonzeada": "zonzear",
    "zonzeadas": "zonzear",
    "zonzeado": "zonzear",
    "zonzeados": "zonzear",
    "zonzeai": "zonzear",
    "zonzeais": "zonzear",
    "zonzeamo": "zonzear",
    "zonzeamos": "zonzear",
    "zonzeando": "zonzear",
    "zonzeara": "zonzear",
    "zonzearam": "zonzear",
    "zonzearas": "zonzear",
    "zonzeardes": "zonzear",
    "zonzearei": "zonzear",
    "zonzeareis": "zonzear",
    "zonzearem": "zonzear",
    "zonzearemos": "zonzear",
    "zonzeares": "zonzear",
    "zonzearia": "zonzear",
    "zonzeariam": "zonzear",
    "zonzearias": "zonzear",
    "zonzearmo": "zonzear",
    "zonzearmos": "zonzear",
    "zonzeará": "zonzear",
    "zonzearás": "zonzear",
    "zonzearão": "zonzear",
    "zonzearíamos": "zonzear",
    "zonzearíeis": "zonzear",
    "zonzeasse": "zonzear",
    "zonzeassem": "zonzear",
    "zonzeasses": "zonzear",
    "zonzeaste": "zonzear",
    "zonzeastes": "zonzear",
    "zonzeava": "zonzear",
    "zonzeavam": "zonzear",
    "zonzeavas": "zonzear",
    "zonzeei": "zonzear",
    "zonzeeis": "zonzear",
    "zonzeemo": "zonzear",
    "zonzeemos": "zonzear",
    "zonzeia": "zonzear",
    "zonzeiam": "zonzear",
    "zonzeias": "zonzear",
    "zonzeie": "zonzear",
    "zonzeiem": "zonzear",
    "zonzeies": "zonzear",
    "zonzeio": "zonzear",
    "zonzeou": "zonzear",
    "zonzeámo": "zonzear",
    "zonzeámos": "zonzear",
    "zonzeáramo": "zonzear",
    "zonzeáramos": "zonzear",
    "zonzeáreis": "zonzear",
    "zonzeásseis": "zonzear",
    "zonzeássemos": "zonzear",
    "zonzeávamo": "zonzear",
    "zonzeávamos": "zonzear",
    "zonzeáveis": "zonzear",
    "zonzona": "zonzonar",
    "zonzonada": "zonzonar",
    "zonzonadas": "zonzonar",
    "zonzonado": "zonzonar",
    "zonzonados": "zonzonar",
    "zonzonai": "zonzonar",
    "zonzonais": "zonzonar",
    "zonzonam": "zonzonar",
    "zonzonamo": "zonzonar",
    "zonzonamos": "zonzonar",
    "zonzonando": "zonzonar",
    "zonzonara": "zonzonar",
    "zonzonaram": "zonzonar",
    "zonzonaras": "zonzonar",
    "zonzonardes": "zonzonar",
    "zonzonarei": "zonzonar",
    "zonzonareis": "zonzonar",
    "zonzonarem": "zonzonar",
    "zonzonaremos": "zonzonar",
    "zonzonares": "zonzonar",
    "zonzonaria": "zonzonar",
    "zonzonariam": "zonzonar",
    "zonzonarias": "zonzonar",
    "zonzonarmo": "zonzonar",
    "zonzonarmos": "zonzonar",
    "zonzonará": "zonzonar",
    "zonzonarás": "zonzonar",
    "zonzonarão": "zonzonar",
    "zonzonaríamos": "zonzonar",
    "zonzonaríeis": "zonzonar",
    "zonzonas": "zonzonar",
    "zonzonasse": "zonzonar",
    "zonzonassem": "zonzonar",
    "zonzonasses": "zonzonar",
    "zonzonaste": "zonzonar",
    "zonzonastes": "zonzonar",
    "zonzonava": "zonzonar",
    "zonzonavam": "zonzonar",
    "zonzonavas": "zonzonar",
    "zonzone": "zonzonar",
    "zonzonei": "zonzonar",
    "zonzoneis": "zonzonar",
    "zonzonem": "zonzonar",
    "zonzonemo": "zonzonar",
    "zonzonemos": "zonzonar",
    "zonzones": "zonzonar",
    "zonzono": "zonzonar",
    "zonzonou": "zonzonar",
    "zonzons": "zonzom",
    "zonzonámo": "zonzonar",
    "zonzonámos": "zonzonar",
    "zonzonáramo": "zonzonar",
    "zonzonáramos": "zonzonar",
    "zonzonáreis": "zonzonar",
    "zonzonásseis": "zonzonar",
    "zonzonássemos": "zonzonar",
    "zonzonávamo": "zonzonar",
    "zonzonávamos": "zonzonar",
    "zonzonáveis": "zonzonar",
    "zonzos": "zonzo",
    "zoná": "zonar",
    "zonámo": "zonar",
    "zonámos": "zonar",
    "zonáramo": "zonar",
    "zonáramos": "zonar",
    "zonárei": "zonar",
    "zonáreis": "zonar",
    "zonárias": "zonária",
    "zonásseis": "zonar",
    "zonássemos": "zonar",
    "zonávamo": "zonar",
    "zonávamos": "zonar",
    "zonávei": "zonar",
    "zonáveis": "zonar",
    "zonípeta": "zonípeto",
    "zonípetas": "zonípeto",
    "zonípetos": "zonípeto",
    "zoo": "zoar",
    "zoobias": "zoobia",
    "zoobiologias": "zoobiologia",
    "zoobiótica": "zoobiótico",
    "zoobióticas": "zoobiótico",
    "zoobióticos": "zoobiótico",
    "zoocecídias": "zoocecídia",
    "zoocinas": "zoocina",
    "zoocistes": "zoociste",
    "zooclorelas": "zooclorela",
    "zoococinas": "zoococina",
    "zoodinâmicas": "zoodinâmica",
    "zoodomácias": "zoodomácia",
    "zooelectricidades": "zooelectricidade",
    "zoofagias": "zoofagia",
    "zoofilias": "zoofilia",
    "zoofitantrácea": "zoofitantráceo",
    "zoofitantráceas": "zoofitantráceo",
    "zoofitantráceos": "zoofitantráceo",
    "zoofitobias": "zoofitobia",
    "zoofitologias": "zoofitologia",
    "zoofitária": "zoofitário",
    "zoofitárias": "zoofitário",
    "zoofitários": "zoofitário",
    "zoofitógrafa": "zoofitógrafo",
    "zoofitógrafas": "zoofitógrafo",
    "zoofitógrafos": "zoofitógrafo",
    "zoofitóides": "zoofitóide",
    "zoofitóloga": "zoofitólogo",
    "zoofitólogas": "zoofitólogo",
    "zoofitólogos": "zoofitólogo",
    "zooflagelados": "zooflagelado",
    "zoofobias": "zoofobia",
    "zoofítica": "zoofítico",
    "zoofíticas": "zoofítico",
    "zoofíticos": "zoofítico",
    "zoogamias": "zoogamia",
    "zoogenias": "zoogenia",
    "zoogeografias": "zoogeografia",
    "zoogleias": "zoogleia",
    "zoogonias": "zoogonia",
    "zoografa": "zoografar",
    "zoografada": "zoografar",
    "zoografadas": "zoografar",
    "zoografado": "zoografar",
    "zoografados": "zoografar",
    "zoografai": "zoografar",
    "zoografais": "zoografar",
    "zoografam": "zoografar",
    "zoografamo": "zoografar",
    "zoografamos": "zoografar",
    "zoografando": "zoografar",
    "zoografara": "zoografar",
    "zoografaram": "zoografar",
    "zoografaras": "zoografar",
    "zoografarde": "zoografar",
    "zoografardes": "zoografar",
    "zoografare": "zoografar",
    "zoografarei": "zoografar",
    "zoografareis": "zoografar",
    "zoografarem": "zoografar",
    "zoografaremos": "zoografar",
    "zoografares": "zoografar",
    "zoografaria": "zoografar",
    "zoografariam": "zoografar",
    "zoografarias": "zoografar",
    "zoografarmo": "zoografar",
    "zoografarmos": "zoografar",
    "zoografará": "zoografar",
    "zoografarás": "zoografar",
    "zoografarão": "zoografar",
    "zoografaríamos": "zoografar",
    "zoografaríeis": "zoografar",
    "zoografas": "zoografar",
    "zoografasse": "zoografar",
    "zoografassem": "zoografar",
    "zoografasses": "zoografar",
    "zoografaste": "zoografar",
    "zoografastes": "zoografar",
    "zoografava": "zoografar",
    "zoografavam": "zoografar",
    "zoografavas": "zoografar",
    "zoografe": "zoografar",
    "zoografei": "zoografar",
    "zoografeis": "zoografar",
    "zoografem": "zoografar",
    "zoografemo": "zoografar",
    "zoografemos": "zoografar",
    "zoografes": "zoografar",
    "zoografias": "zoografia",
    "zoografo": "zoografar",
    "zoografou": "zoografar",
    "zoografá": "zoografar",
    "zoografámo": "zoografar",
    "zoografámos": "zoografar",
    "zoografáramo": "zoografar",
    "zoografáramos": "zoografar",
    "zoografárei": "zoografar",
    "zoografáreis": "zoografar",
    "zoografásseis": "zoografar",
    "zoografássemos": "zoografar",
    "zoografávamo": "zoografar",
    "zoografávamos": "zoografar",
    "zoografávei": "zoografar",
    "zoografáveis": "zoografar",
    "zoográfica": "zoográfico",
    "zoográficas": "zoográfico",
    "zoográficos": "zoográfico",
    "zoogâmetas": "zoogâmeta",
    "zoogénica": "zoogénico",
    "zoogénicas": "zoogénico",
    "zoogénicos": "zoogénico",
    "zoogénios": "zoogénio",
    "zooiatras": "zooiatra",
    "zoolatrias": "zoolatria",
    "zoolitífera": "zoolitífero",
    "zoolitíferas": "zoolitífero",
    "zoolitíferos": "zoolitífero",
    "zoolitófora": "zoolitóforo",
    "zoolitóforas": "zoolitóforo",
    "zoolitóforos": "zoolitóforo",
    "zoologias": "zoologia",
    "zoologistas": "zoologista",
    "zoolátrica": "zoolátrico",
    "zoolátricas": "zoolátrico",
    "zoolátricos": "zoolátrico",
    "zoolítica": "zoolítico",
    "zoolíticas": "zoolítico",
    "zoolíticos": "zoolítico",
    "zoológica": "zoológico",
    "zoológicas": "zoológico",
    "zoológicos": "zoológico",
    "zoomagnetismos": "zoomagnetismo",
    "zoomagnética": "zoomagnético",
    "zoomagnéticas": "zoomagnético",
    "zoomagnéticos": "zoomagnético",
    "zoomanias": "zoomania",
    "zoomaníaca": "zoomaníaco",
    "zoomaníacas": "zoomaníaco",
    "zoomaníacos": "zoomaníaco",
    "zoomastiginos": "zoomastigino",
    "zoomes": "zoom",
    "zoomorfa": "zoomorfo",
    "zoomorfas": "zoomorfo",
    "zoomorfias": "zoomorfia",
    "zoomorfismos": "zoomorfismo",
    "zoomorfites": "zoomorfite",
    "zoomorfos": "zoomorfo",
    "zoomorfoses": "zoomorfose",
    "zoomórfica": "zoomórfico",
    "zoomórficas": "zoomórfico",
    "zoomórficos": "zoomórfico",
    "zoonitos": "zoonito",
    "zoonomias": "zoonomia",
    "zoonoses": "zoonose",
    "zoonosias": "zoonosia",
    "zoonosologias": "zoonosologia",
    "zoonosológica": "zoonosológico",
    "zoonosológicas": "zoonosológico",
    "zoonosológicos": "zoonosológico",
    "zoontes": "zoonte",
    "zoonímias": "zoonímia",
    "zoonómica": "zoonómico",
    "zoonómicas": "zoonómico",
    "zoonómicos": "zoonómico",
    "zooparasitas": "zooparasita",
    "zooparasitos": "zooparasito",
    "zoopatias": "zoopatia",
    "zoopatologias": "zoopatologia",
    "zoopatológica": "zoopatológico",
    "zoopatológicas": "zoopatológico",
    "zoopatológicos": "zoopatológico",
    "zoopedias": "zoopedia",
    "zooplasmas": "zooplasma",
    "zooplastias": "zooplastia",
    "zooplânctons": "zooplâncton",
    "zoopolitas": "zoopolita",
    "zooporocistes": "zooporociste",
    "zoopsias": "zoopsia",
    "zooquímicas": "zooquímica",
    "zooscopias": "zooscopia",
    "zooscópica": "zooscópico",
    "zooscópicas": "zooscópico",
    "zooscópicos": "zooscópico",
    "zooses": "zoose",
    "zoospermas": "zoosperma",
    "zoospermias": "zoospermia",
    "zoosporângios": "zoosporângio",
    "zoospórica": "zoospórico",
    "zoospóricas": "zoospórico",
    "zoospóricos": "zoospórico",
    "zootaxias": "zootaxia",
    "zootecas": "zooteca",
    "zootecnias": "zootecnia",
    "zootecnistas": "zootecnista",
    "zooterapias": "zooterapia",
    "zooterapêuticas": "zooterapêutica",
    "zooterápica": "zooterápico",
    "zooterápicas": "zooterápico",
    "zooterápicos": "zooterápico",
    "zootipólitos": "zootipólito",
    "zootomias": "zootomia",
    "zootomistas": "zootomista",
    "zootropias": "zootropia",
    "zootrópios": "zootrópio",
    "zootáctica": "zootáctico",
    "zootácticas": "zootáctico",
    "zootácticos": "zootáctico",
    "zootáxica": "zootáxico",
    "zootáxicas": "zootáxico",
    "zootáxicos": "zootáxico",
    "zootécnica": "zootécnico",
    "zootécnicas": "zootécnico",
    "zootécnicos": "zootécnico",
    "zootómica": "zootómico",
    "zootómicas": "zootómico",
    "zootómicos": "zootómico",
    "zoou": "zoar",
    "zooxantelas": "zooxantela",
    "zooéticas": "zooética",
    "zopa": "zopo",
    "zopas": "zopo",
    "zopeira": "zopeiro",
    "zopeiras": "zopeiro",
    "zopeiros": "zopeiro",
    "zopos": "zopo",
    "zorata": "zorato",
    "zoratas": "zorato",
    "zorates": "zorate",
    "zoratos": "zorato",
    "zorlita": "zorlito",
    "zorlitas": "zorlito",
    "zorlitos": "zorlito",
    "zorna": "zornar",
    "zornada": "zornar",
    "zornadas": "zornar",
    "zornado": "zornar",
    "zornados": "zornar",
    "zornai": "zornar",
    "zornais": "zornar",
    "zornam": "zornar",
    "zornamo": "zornar",
    "zornamos": "zornar",
    "zornando": "zornar",
    "zornara": "zornar",
    "zornaram": "zornar",
    "zornaras": "zornar",
    "zornardes": "zornar",
    "zornarei": "zornar",
    "zornareis": "zornar",
    "zornarem": "zornar",
    "zornaremos": "zornar",
    "zornares": "zornar",
    "zornaria": "zornar",
    "zornariam": "zornar",
    "zornarias": "zornar",
    "zornarmo": "zornar",
    "zornarmos": "zornar",
    "zornará": "zornar",
    "zornarás": "zornar",
    "zornarão": "zornar",
    "zornaríamos": "zornar",
    "zornaríeis": "zornar",
    "zornas": "zornar",
    "zornasse": "zornar",
    "zornassem": "zornar",
    "zornasses": "zornar",
    "zornaste": "zornar",
    "zornastes": "zornar",
    "zornava": "zornar",
    "zornavam": "zornar",
    "zornavas": "zornar",
    "zorne": "zornar",
    "zornei": "zornar",
    "zorneis": "zornar",
    "zornem": "zornar",
    "zornemo": "zornar",
    "zornemos": "zornar",
    "zornes": "zornar",
    "zorno": "zornar",
    "zornou": "zornar",
    "zornámo": "zornar",
    "zornámos": "zornar",
    "zornáramo": "zornar",
    "zornáramos": "zornar",
    "zornáreis": "zornar",
    "zornásseis": "zornar",
    "zornássemos": "zornar",
    "zornávamo": "zornar",
    "zornávamos": "zornar",
    "zornáveis": "zornar",
    "zornões": "zornão",
    "zoroastriana": "zoroastriano",
    "zoroastrianas": "zoroastriano",
    "zoroastrianos": "zoroastriano",
    "zoroastrismos": "zoroastrismo",
    "zoroastristas": "zoroastrista",
    "zorongos": "zorongo",
    "zoroástrica": "zoroástrico",
    "zoroástricas": "zoroástrico",
    "zoroástricos": "zoroástrico",
    "zorrachas": "zorracha",
    "zorraga": "zorragar",
    "zorragada": "zorragar",
    "zorragadas": "zorragar",
    "zorragado": "zorragar",
    "zorragados": "zorragar",
    "zorragai": "zorragar",
    "zorragais": "zorragar",
    "zorragam": "zorragar",
    "zorragamo": "zorragar",
    "zorragamos": "zorragar",
    "zorragando": "zorragar",
    "zorragara": "zorragar",
    "zorragaram": "zorragar",
    "zorragaras": "zorragar",
    "zorragarde": "zorragar",
    "zorragardes": "zorragar",
    "zorragare": "zorragar",
    "zorragarei": "zorragar",
    "zorragareis": "zorragar",
    "zorragarem": "zorragar",
    "zorragaremos": "zorragar",
    "zorragares": "zorragar",
    "zorragaria": "zorragar",
    "zorragariam": "zorragar",
    "zorragarias": "zorragar",
    "zorragarmo": "zorragar",
    "zorragarmos": "zorragar",
    "zorragará": "zorragar",
    "zorragarás": "zorragar",
    "zorragarão": "zorragar",
    "zorragaríamos": "zorragar",
    "zorragaríeis": "zorragar",
    "zorragas": "zorragar",
    "zorragasse": "zorragar",
    "zorragassem": "zorragar",
    "zorragasses": "zorragar",
    "zorragaste": "zorragar",
    "zorragastes": "zorragar",
    "zorragava": "zorragar",
    "zorragavam": "zorragar",
    "zorragavas": "zorragar",
    "zorrago": "zorragar",
    "zorragou": "zorragar",
    "zorrague": "zorragar",
    "zorraguei": "zorragar",
    "zorragueis": "zorragar",
    "zorraguem": "zorragar",
    "zorraguemo": "zorragar",
    "zorraguemos": "zorragar",
    "zorragues": "zorrague",
    "zorragá": "zorragar",
    "zorragámo": "zorragar",
    "zorragámos": "zorragar",
    "zorragáramo": "zorragar",
    "zorragáramos": "zorragar",
    "zorragárei": "zorragar",
    "zorragáreis": "zorragar",
    "zorragásseis": "zorragar",
    "zorragássemos": "zorragar",
    "zorragávamo": "zorragar",
    "zorragávamos": "zorragar",
    "zorragávei": "zorragar",
    "zorragáveis": "zorragar",
    "zorrais": "zorral",
    "zorras": "zorra",
    "zorreira": "zorreiro",
    "zorreiras": "zorreiro",
    "zorreiros": "zorreiro",
    "zorrilhos": "zorrilho",
    "zorrona": "zorrão",
    "zorronas": "zorrão",
    "zorros": "zorro",
    "zorrões": "zorrão",
    "zorta": "zortar",
    "zortada": "zortar",
    "zortadas": "zortar",
    "zortado": "zortar",
    "zortados": "zortar",
    "zortai": "zortar",
    "zortais": "zortar",
    "zortam": "zortar",
    "zortamo": "zortar",
    "zortamos": "zortar",
    "zortando": "zortar",
    "zortara": "zortar",
    "zortaram": "zortar",
    "zortaras": "zortar",
    "zortardes": "zortar",
    "zortarei": "zortar",
    "zortareis": "zortar",
    "zortarem": "zortar",
    "zortaremos": "zortar",
    "zortares": "zortar",
    "zortaria": "zortar",
    "zortariam": "zortar",
    "zortarias": "zortar",
    "zortarmo": "zortar",
    "zortarmos": "zortar",
    "zortará": "zortar",
    "zortarás": "zortar",
    "zortarão": "zortar",
    "zortaríamos": "zortar",
    "zortaríeis": "zortar",
    "zortas": "zortar",
    "zortasse": "zortar",
    "zortassem": "zortar",
    "zortasses": "zortar",
    "zortaste": "zortar",
    "zortastes": "zortar",
    "zortava": "zortar",
    "zortavam": "zortar",
    "zortavas": "zortar",
    "zorte": "zortar",
    "zortei": "zortar",
    "zorteis": "zortar",
    "zortem": "zortar",
    "zortemo": "zortar",
    "zortemos": "zortar",
    "zortes": "zortar",
    "zorto": "zortar",
    "zortou": "zortar",
    "zortámo": "zortar",
    "zortámos": "zortar",
    "zortáramo": "zortar",
    "zortáramos": "zortar",
    "zortáreis": "zortar",
    "zortásseis": "zortar",
    "zortássemos": "zortar",
    "zortávamo": "zortar",
    "zortávamos": "zortar",
    "zortáveis": "zortar",
    "zorzais": "zorzal",
    "zorzaleira": "zorzaleiro",
    "zorzaleiras": "zorzaleiro",
    "zorzaleiros": "zorzaleiro",
    "zosteráceas": "zosterácea",
    "zotecas": "zoteca",
    "zotes": "zote",
    "zotismos": "zotismo",
    "zoupa": "zoupo",
    "zoupas": "zoupo",
    "zoupeira": "zoupeiro",
    "zoupeiras": "zoupeiro",
    "zoupeiros": "zoupeiro",
    "zoupos": "zoupo",
    "zouvineira": "zouvineiro",
    "zouvineiras": "zouvineiro",
    "zouvineiros": "zouvineiro",
    "zovos": "zovo",
    "zoámo": "zoar",
    "zoámos": "zoar",
    "zoáramo": "zoar",
    "zoáramos": "zoar",
    "zoáreis": "zoar",
    "zoários": "zoário",
    "zoásseis": "zoar",
    "zoássemos": "zoar",
    "zoávamo": "zoar",
    "zoávamos": "zoar",
    "zoáveis": "zoar",
    "zoécias": "zoécia",
    "zoécios": "zoécio",
    "zoísmos": "zoísmo",
    "zoóbia": "zoóbio",
    "zoóbias": "zoóbio",
    "zoóbios": "zoóbio",
    "zoófaga": "zoófago",
    "zoófagas": "zoófago",
    "zoófagos": "zoófago",
    "zoófila": "zoófilo",
    "zoófilas": "zoófilo",
    "zoófilos": "zoófilo",
    "zoófitos": "zoófito",
    "zoófoba": "zoófobo",
    "zoófobas": "zoófobo",
    "zoófobos": "zoófobo",
    "zoóforos": "zoóforo",
    "zoógama": "zoógamo",
    "zoógamas": "zoógamo",
    "zoógamos": "zoógamo",
    "zoógona": "zoógono",
    "zoógonas": "zoógono",
    "zoógonos": "zoógono",
    "zoógrafa": "zoógrafo",
    "zoógrafas": "zoógrafo",
    "zoógrafos": "zoógrafo",
    "zoóides": "zoóide",
    "zoólatras": "zoólatra",
    "zoólitos": "zoólito",
    "zoóloga": "zoólogo",
    "zoólogas": "zoólogo",
    "zoólogos": "zoólogo",
    "zua": "zuir",
    "zuais": "zuir",
    "zuam": "zuir",
    "zuamo": "zuir",
    "zuamos": "zuir",
    "zuaques": "zuaque",
    "zuartes": "zuarte",
    "zuas": "zuir",
    "zuates": "zuate",
    "zuavos": "zuavo",
    "zuca": "zuco",
    "zucada": "zucar",
    "zucadas": "zucar",
    "zucado": "zucar",
    "zucados": "zucar",
    "zucai": "zucar",
    "zucais": "zucar",
    "zucam": "zucar",
    "zucamo": "zucar",
    "zucamos": "zucar",
    "zucando": "zucar",
    "zucara": "zucar",
    "zucaram": "zucar",
    "zucaras": "zucar",
    "zucarde": "zucar",
    "zucardes": "zucar",
    "zucare": "zucar",
    "zucarei": "zucar",
    "zucareis": "zucar",
    "zucarem": "zucar",
    "zucaremos": "zucar",
    "zucares": "zucar",
    "zucaria": "zucar",
    "zucariam": "zucar",
    "zucarias": "zucar",
    "zucarmo": "zucar",
    "zucarmos": "zucar",
    "zucará": "zucar",
    "zucarás": "zucar",
    "zucarão": "zucar",
    "zucaríamos": "zucar",
    "zucaríeis": "zucar",
    "zucas": "zuco",
    "zucasse": "zucar",
    "zucassem": "zucar",
    "zucasses": "zucar",
    "zucaste": "zucar",
    "zucastes": "zucar",
    "zucava": "zucar",
    "zucavam": "zucar",
    "zucavas": "zucar",
    "zuco": "zucar",
    "zucos": "zuco",
    "zucou": "zucar",
    "zucá": "zucar",
    "zucámo": "zucar",
    "zucámos": "zucar",
    "zucáramo": "zucar",
    "zucáramos": "zucar",
    "zucárei": "zucar",
    "zucáreis": "zucar",
    "zucásseis": "zucar",
    "zucássemos": "zucar",
    "zucávamo": "zucar",
    "zucávamos": "zucar",
    "zucávei": "zucar",
    "zucáveis": "zucar",
    "zuem": "zuir",
    "zui": "zuir",
    "zuidoiros": "zuidoiro",
    "zuidouros": "zuidouro",
    "zuindo": "zuir",
    "zuingliana": "zuingliano",
    "zuinglianas": "zuingliano",
    "zuinglianismos": "zuinglianismo",
    "zuinglianos": "zuingliano",
    "zuirde": "zuir",
    "zuirdes": "zuir",
    "zuirei": "zuir",
    "zuireis": "zuir",
    "zuiremos": "zuir",
    "zuiria": "zuir",
    "zuiriam": "zuir",
    "zuirias": "zuir",
    "zuirmo": "zuir",
    "zuirmos": "zuir",
    "zuirá": "zuir",
    "zuirás": "zuir",
    "zuirão": "zuir",
    "zuiríamos": "zuir",
    "zuiríeis": "zuir",
    "zuis": "zuir",
    "zuiu": "zuir",
    "zula": "zular",
    "zulada": "zular",
    "zuladas": "zular",
    "zulado": "zular",
    "zulados": "zular",
    "zulai": "zular",
    "zulais": "zular",
    "zulam": "zular",
    "zulamo": "zular",
    "zulamos": "zular",
    "zulando": "zular",
    "zulara": "zular",
    "zularam": "zular",
    "zularas": "zular",
    "zularde": "zular",
    "zulardes": "zular",
    "zulare": "zular",
    "zularei": "zular",
    "zulareis": "zular",
    "zularem": "zular",
    "zularemos": "zular",
    "zulares": "zular",
    "zularia": "zular",
    "zulariam": "zular",
    "zularias": "zular",
    "zularmo": "zular",
    "zularmos": "zular",
    "zulará": "zular",
    "zularás": "zular",
    "zularão": "zular",
    "zularíamos": "zular",
    "zularíeis": "zular",
    "zulas": "zular",
    "zulasse": "zular",
    "zulassem": "zular",
    "zulasses": "zular",
    "zulaste": "zular",
    "zulastes": "zular",
    "zulava": "zular",
    "zulavam": "zular",
    "zulavas": "zular",
    "zule": "zular",
    "zulei": "zular",
    "zuleis": "zular",
    "zulem": "zular",
    "zulemo": "zular",
    "zulemos": "zular",
    "zules": "zular",
    "zulo": "zular",
    "zulos": "zulo",
    "zulou": "zular",
    "zulunidades": "zulunidade",
    "zulus": "zulu",
    "zulá": "zular",
    "zulámo": "zular",
    "zulámos": "zular",
    "zuláramo": "zular",
    "zuláramos": "zular",
    "zulárei": "zular",
    "zuláreis": "zular",
    "zulásseis": "zular",
    "zulássemos": "zular",
    "zulávamo": "zular",
    "zulávamos": "zular",
    "zulávei": "zular",
    "zuláveis": "zular",
    "zumba": "zumbir",
    "zumbada": "zumbar",
    "zumbadas": "zumbar",
    "zumbado": "zumbar",
    "zumbados": "zumbar",
    "zumbai": "zumbar",
    "zumbaia": "zumbaiar",
    "zumbaiada": "zumbaiar",
    "zumbaiadas": "zumbaiar",
    "zumbaiado": "zumbaiar",
    "zumbaiados": "zumbaiar",
    "zumbaiai": "zumbaiar",
    "zumbaiais": "zumbaiar",
    "zumbaiam": "zumbaiar",
    "zumbaiamo": "zumbaiar",
    "zumbaiamos": "zumbaiar",
    "zumbaiando": "zumbaiar",
    "zumbaiara": "zumbaiar",
    "zumbaiaram": "zumbaiar",
    "zumbaiaras": "zumbaiar",
    "zumbaiarde": "zumbaiar",
    "zumbaiardes": "zumbaiar",
    "zumbaiare": "zumbaiar",
    "zumbaiarei": "zumbaiar",
    "zumbaiareis": "zumbaiar",
    "zumbaiarem": "zumbaiar",
    "zumbaiaremos": "zumbaiar",
    "zumbaiares": "zumbaiar",
    "zumbaiaria": "zumbaiar",
    "zumbaiariam": "zumbaiar",
    "zumbaiarias": "zumbaiar",
    "zumbaiarmo": "zumbaiar",
    "zumbaiarmos": "zumbaiar",
    "zumbaiará": "zumbaiar",
    "zumbaiarás": "zumbaiar",
    "zumbaiarão": "zumbaiar",
    "zumbaiaríamos": "zumbaiar",
    "zumbaiaríeis": "zumbaiar",
    "zumbaias": "zumbaiar",
    "zumbaiasse": "zumbaiar",
    "zumbaiassem": "zumbaiar",
    "zumbaiasses": "zumbaiar",
    "zumbaiaste": "zumbaiar",
    "zumbaiastes": "zumbaiar",
    "zumbaiava": "zumbaiar",
    "zumbaiavam": "zumbaiar",
    "zumbaiavas": "zumbaiar",
    "zumbaie": "zumbaiar",
    "zumbaiei": "zumbaiar",
    "zumbaieira": "zumbaieiro",
    "zumbaieiras": "zumbaieiro",
    "zumbaieiros": "zumbaieiro",
    "zumbaieis": "zumbaiar",
    "zumbaiem": "zumbaiar",
    "zumbaiemo": "zumbaiar",
    "zumbaiemos": "zumbaiar",
    "zumbaies": "zumbaiar",
    "zumbaio": "zumbaiar",
    "zumbaiou": "zumbaiar",
    "zumbais": "zumbir",
    "zumbaiá": "zumbaiar",
    "zumbaiámo": "zumbaiar",
    "zumbaiámos": "zumbaiar",
    "zumbaiáramo": "zumbaiar",
    "zumbaiáramos": "zumbaiar",
    "zumbaiárei": "zumbaiar",
    "zumbaiáreis": "zumbaiar",
    "zumbaiásseis": "zumbaiar",
    "zumbaiássemos": "zumbaiar",
    "zumbaiávamo": "zumbaiar",
    "zumbaiávamos": "zumbaiar",
    "zumbaiávei": "zumbaiar",
    "zumbaiáveis": "zumbaiar",
    "zumbam": "zumbir",
    "zumbamo": "zumbir",
    "zumbamos": "zumbir",
    "zumbando": "zumbar",
    "zumbara": "zumbar",
    "zumbaram": "zumbar",
    "zumbaras": "zumbar",
    "zumbardes": "zumbar",
    "zumbarei": "zumbar",
    "zumbareis": "zumbar",
    "zumbarem": "zumbar",
    "zumbaremos": "zumbar",
    "zumbares": "zumbar",
    "zumbaria": "zumbar",
    "zumbariam": "zumbar",
    "zumbarias": "zumbar",
    "zumbarmo": "zumbar",
    "zumbarmos": "zumbar",
    "zumbará": "zumbar",
    "zumbarás": "zumbar",
    "zumbarão": "zumbar",
    "zumbaríamos": "zumbar",
    "zumbaríeis": "zumbar",
    "zumbas": "zumbir",
    "zumbasse": "zumbar",
    "zumbassem": "zumbar",
    "zumbasses": "zumbar",
    "zumbaste": "zumbar",
    "zumbastes": "zumbar",
    "zumbava": "zumbar",
    "zumbavam": "zumbar",
    "zumbavas": "zumbar",
    "zumbe": "zumbir",
    "zumbei": "zumbar",
    "zumbeira": "zumbeirar",
    "zumbeirada": "zumbeirar",
    "zumbeiradas": "zumbeirar",
    "zumbeirado": "zumbeirar",
    "zumbeirados": "zumbeirar",
    "zumbeirai": "zumbeirar",
    "zumbeirais": "zumbeirar",
    "zumbeiram": "zumbeirar",
    "zumbeiramo": "zumbeirar",
    "zumbeiramos": "zumbeirar",
    "zumbeirando": "zumbeirar",
    "zumbeirara": "zumbeirar",
    "zumbeiraram": "zumbeirar",
    "zumbeiraras": "zumbeirar",
    "zumbeirarde": "zumbeirar",
    "zumbeirardes": "zumbeirar",
    "zumbeirare": "zumbeirar",
    "zumbeirarei": "zumbeirar",
    "zumbeirareis": "zumbeirar",
    "zumbeirarem": "zumbeirar",
    "zumbeiraremos": "zumbeirar",
    "zumbeirares": "zumbeirar",
    "zumbeiraria": "zumbeirar",
    "zumbeirariam": "zumbeirar",
    "zumbeirarias": "zumbeirar",
    "zumbeirarmo": "zumbeirar",
    "zumbeirarmos": "zumbeirar",
    "zumbeirará": "zumbeirar",
    "zumbeirarás": "zumbeirar",
    "zumbeirarão": "zumbeirar",
    "zumbeiraríamos": "zumbeirar",
    "zumbeiraríeis": "zumbeirar",
    "zumbeiras": "zumbeirar",
    "zumbeirasse": "zumbeirar",
    "zumbeirassem": "zumbeirar",
    "zumbeirasses": "zumbeirar",
    "zumbeiraste": "zumbeirar",
    "zumbeirastes": "zumbeirar",
    "zumbeirava": "zumbeirar",
    "zumbeiravam": "zumbeirar",
    "zumbeiravas": "zumbeirar",
    "zumbeire": "zumbeirar",
    "zumbeirei": "zumbeirar",
    "zumbeireis": "zumbeirar",
    "zumbeirem": "zumbeirar",
    "zumbeiremo": "zumbeirar",
    "zumbeiremos": "zumbeirar",
    "zumbeires": "zumbeirar",
    "zumbeiro": "zumbeirar",
    "zumbeirou": "zumbeirar",
    "zumbeirá": "zumbeirar",
    "zumbeirámo": "zumbeirar",
    "zumbeirámos": "zumbeirar",
    "zumbeiráramo": "zumbeirar",
    "zumbeiráramos": "zumbeirar",
    "zumbeirárei": "zumbeirar",
    "zumbeiráreis": "zumbeirar",
    "zumbeirásseis": "zumbeirar",
    "zumbeirássemos": "zumbeirar",
    "zumbeirávamo": "zumbeirar",
    "zumbeirávamos": "zumbeirar",
    "zumbeirávei": "zumbeirar",
    "zumbeiráveis": "zumbeirar",
    "zumbeis": "zumbar",
    "zumbem": "zumbir",
    "zumbemo": "zumbar",
    "zumbemos": "zumbar",
    "zumbes": "zumbir",
    "zumbi": "zumbir",
    "zumbia": "zumbir",
    "zumbiam": "zumbir",
    "zumbias": "zumbir",
    "zumbida": "zumbir",
    "zumbidas": "zumbir",
    "zumbido": "zumbir",
    "zumbidora": "zumbidor",
    "zumbidoras": "zumbidor",
    "zumbidores": "zumbidor",
    "zumbidos": "zumbir",
    "zumbimo": "zumbir",
    "zumbimos": "zumbir",
    "zumbindo": "zumbir",
    "zumbira": "zumbir",
    "zumbiram": "zumbir",
    "zumbiras": "zumbir",
    "zumbirdes": "zumbir",
    "zumbirei": "zumbir",
    "zumbireis": "zumbir",
    "zumbirem": "zumbir",
    "zumbiremos": "zumbir",
    "zumbires": "zumbir",
    "zumbiria": "zumbir",
    "zumbiriam": "zumbir",
    "zumbirias": "zumbir",
    "zumbirmo": "zumbir",
    "zumbirmos": "zumbir",
    "zumbirá": "zumbir",
    "zumbirás": "zumbir",
    "zumbirão": "zumbir",
    "zumbiríamos": "zumbir",
    "zumbiríeis": "zumbir",
    "zumbis": "zumbir",
    "zumbisse": "zumbir",
    "zumbissem": "zumbir",
    "zumbisses": "zumbir",
    "zumbiste": "zumbir",
    "zumbistes": "zumbir",
    "zumbiu": "zumbir",
    "zumbo": "zumbir",
    "zumbos": "zumbo",
    "zumbou": "zumbar",
    "zumbra": "zumbrir",
    "zumbrais": "zumbrir",
    "zumbram": "zumbrir",
    "zumbramo": "zumbrir",
    "zumbramos": "zumbrir",
    "zumbras": "zumbrir",
    "zumbre": "zumbrir",
    "zumbrem": "zumbrir",
    "zumbres": "zumbrir",
    "zumbri": "zumbrir",
    "zumbria": "zumbrir",
    "zumbriam": "zumbrir",
    "zumbrias": "zumbrir",
    "zumbrida": "zumbrir",
    "zumbridas": "zumbrir",
    "zumbrido": "zumbrir",
    "zumbridos": "zumbrir",
    "zumbrimo": "zumbrir",
    "zumbrimos": "zumbrir",
    "zumbrindo": "zumbrir",
    "zumbrira": "zumbrir",
    "zumbriram": "zumbrir",
    "zumbriras": "zumbrir",
    "zumbrirde": "zumbrir",
    "zumbrirdes": "zumbrir",
    "zumbrire": "zumbrir",
    "zumbrirei": "zumbrir",
    "zumbrireis": "zumbrir",
    "zumbrirem": "zumbrir",
    "zumbriremos": "zumbrir",
    "zumbrires": "zumbrir",
    "zumbriria": "zumbrir",
    "zumbririam": "zumbrir",
    "zumbririas": "zumbrir",
    "zumbrirmo": "zumbrir",
    "zumbrirmos": "zumbrir",
    "zumbrirá": "zumbrir",
    "zumbrirás": "zumbrir",
    "zumbrirão": "zumbrir",
    "zumbriríamos": "zumbrir",
    "zumbriríeis": "zumbrir",
    "zumbris": "zumbrir",
    "zumbrisse": "zumbrir",
    "zumbrissem": "zumbrir",
    "zumbrisses": "zumbrir",
    "zumbriste": "zumbrir",
    "zumbristes": "zumbrir",
    "zumbriu": "zumbrir",
    "zumbro": "zumbrir",
    "zumbríamo": "zumbrir",
    "zumbríamos": "zumbrir",
    "zumbríei": "zumbrir",
    "zumbríeis": "zumbrir",
    "zumbríramo": "zumbrir",
    "zumbríramos": "zumbrir",
    "zumbrírei": "zumbrir",
    "zumbríreis": "zumbrir",
    "zumbrísseis": "zumbrir",
    "zumbríssemos": "zumbrir",
    "zumbámo": "zumbar",
    "zumbámos": "zumbar",
    "zumbáramo": "zumbar",
    "zumbáramos": "zumbar",
    "zumbáreis": "zumbar",
    "zumbásseis": "zumbar",
    "zumbássemos": "zumbar",
    "zumbávamo": "zumbar",
    "zumbávamos": "zumbar",
    "zumbáveis": "zumbar",
    "zumbíamo": "zumbir",
    "zumbíamos": "zumbir",
    "zumbíeis": "zumbir",
    "zumbíramo": "zumbir",
    "zumbíramos": "zumbir",
    "zumbíreis": "zumbir",
    "zumbísseis": "zumbir",
    "zumbíssemos": "zumbir",
    "zuna": "zunir",
    "zunais": "zunir",
    "zunam": "zunir",
    "zunamo": "zunir",
    "zunamos": "zunir",
    "zunas": "zunir",
    "zune": "zunir",
    "zunem": "zunir",
    "zunes": "zunir",
    "zunga": "zungar",
    "zungada": "zungar",
    "zungadas": "zungar",
    "zungado": "zungar",
    "zungados": "zungar",
    "zungai": "zungar",
    "zungais": "zungar",
    "zungam": "zungar",
    "zungamo": "zungar",
    "zungamos": "zungar",
    "zungando": "zungar",
    "zungara": "zungar",
    "zungaram": "zungar",
    "zungaras": "zungar",
    "zungardes": "zungar",
    "zungarei": "zungar",
    "zungareis": "zungar",
    "zungarem": "zungar",
    "zungaremos": "zungar",
    "zungares": "zungar",
    "zungaria": "zungar",
    "zungariam": "zungar",
    "zungarias": "zungar",
    "zungarmo": "zungar",
    "zungarmos": "zungar",
    "zungará": "zungar",
    "zungarás": "zungar",
    "zungarão": "zungar",
    "zungaríamos": "zungar",
    "zungaríeis": "zungar",
    "zungas": "zungar",
    "zungasse": "zungar",
    "zungassem": "zungar",
    "zungasses": "zungar",
    "zungaste": "zungar",
    "zungastes": "zungar",
    "zungatos": "zungato",
    "zungava": "zungar",
    "zungavam": "zungar",
    "zungavas": "zungar",
    "zungo": "zungar",
    "zungou": "zungar",
    "zungue": "zungar",
    "zunguei": "zungar",
    "zungueis": "zungar",
    "zunguem": "zungar",
    "zunguemo": "zungar",
    "zunguemos": "zungar",
    "zungues": "zungar",
    "zungámo": "zungar",
    "zungámos": "zungar",
    "zungáramo": "zungar",
    "zungáramos": "zungar",
    "zungáreis": "zungar",
    "zungásseis": "zungar",
    "zungássemos": "zungar",
    "zungávamo": "zungar",
    "zungávamos": "zungar",
    "zungáveis": "zungar",
    "zuni": "zunir",
    "zunia": "zunir",
    "zuniam": "zunir",
    "zunias": "zunir",
    "zunida": "zunir",
    "zunidas": "zunir",
    "zunideiras": "zunideira",
    "zunido": "zunir",
    "zunidora": "zunidor",
    "zunidoras": "zunidor",
    "zunidores": "zunidor",
    "zunidos": "zunir",
    "zunimentos": "zunimento",
    "zunimo": "zunir",
    "zunimos": "zunir",
    "zunindo": "zunir",
    "zunira": "zunir",
    "zuniram": "zunir",
    "zuniras": "zunir",
    "zunirdes": "zunir",
    "zunirei": "zunir",
    "zunireis": "zunir",
    "zunirem": "zunir",
    "zuniremos": "zunir",
    "zunires": "zunir",
    "zuniria": "zunir",
    "zuniriam": "zunir",
    "zunirias": "zunir",
    "zunirmo": "zunir",
    "zunirmos": "zunir",
    "zunirá": "zunir",
    "zunirás": "zunir",
    "zunirão": "zunir",
    "zuniríamos": "zunir",
    "zuniríeis": "zunir",
    "zunis": "zunir",
    "zunisse": "zunir",
    "zunissem": "zunir",
    "zunisses": "zunir",
    "zuniste": "zunir",
    "zunistes": "zunir",
    "zuniu": "zunir",
    "zuno": "zunir",
    "zunzuna": "zunzunar",
    "zunzunada": "zunzunar",
    "zunzunadas": "zunzunar",
    "zunzunado": "zunzunar",
    "zunzunados": "zunzunar",
    "zunzunai": "zunzunar",
    "zunzunais": "zunzunar",
    "zunzunam": "zunzunar",
    "zunzunamo": "zunzunar",
    "zunzunamos": "zunzunar",
    "zunzunando": "zunzunar",
    "zunzunara": "zunzunar",
    "zunzunaram": "zunzunar",
    "zunzunaras": "zunzunar",
    "zunzunardes": "zunzunar",
    "zunzunarei": "zunzunar",
    "zunzunareis": "zunzunar",
    "zunzunarem": "zunzunar",
    "zunzunaremos": "zunzunar",
    "zunzunares": "zunzunar",
    "zunzunaria": "zunzunar",
    "zunzunariam": "zunzunar",
    "zunzunarias": "zunzunar",
    "zunzunarmo": "zunzunar",
    "zunzunarmos": "zunzunar",
    "zunzunará": "zunzunar",
    "zunzunarás": "zunzunar",
    "zunzunarão": "zunzunar",
    "zunzunaríamos": "zunzunar",
    "zunzunaríeis": "zunzunar",
    "zunzunas": "zunzunar",
    "zunzunasse": "zunzunar",
    "zunzunassem": "zunzunar",
    "zunzunasses": "zunzunar",
    "zunzunaste": "zunzunar",
    "zunzunastes": "zunzunar",
    "zunzunava": "zunzunar",
    "zunzunavam": "zunzunar",
    "zunzunavas": "zunzunar",
    "zunzune": "zunzunar",
    "zunzunei": "zunzunar",
    "zunzuneis": "zunzunar",
    "zunzunem": "zunzunar",
    "zunzunemo": "zunzunar",
    "zunzunemos": "zunzunar",
    "zunzunes": "zunzunar",
    "zunzuno": "zunzunar",
    "zunzunou": "zunzunar",
    "zunzuns": "zunzum",
    "zunzunzuns": "zunzunzum",
    "zunzunámo": "zunzunar",
    "zunzunámos": "zunzunar",
    "zunzunáramo": "zunzunar",
    "zunzunáramos": "zunzunar",
    "zunzunáreis": "zunzunar",
    "zunzunásseis": "zunzunar",
    "zunzunássemos": "zunzunar",
    "zunzunávamo": "zunzunar",
    "zunzunávamos": "zunzunar",
    "zunzunáveis": "zunzunar",
    "zuníamo": "zunir",
    "zuníamos": "zunir",
    "zuníeis": "zunir",
    "zuníramo": "zunir",
    "zuníramos": "zunir",
    "zuníreis": "zunir",
    "zunísseis": "zunir",
    "zuníssemos": "zunir",
    "zuo": "zuir",
    "zupa": "zupar",
    "zupada": "zupar",
    "zupadas": "zupar",
    "zupado": "zupar",
    "zupadora": "zupador",
    "zupadoras": "zupador",
    "zupadores": "zupador",
    "zupados": "zupar",
    "zupai": "zupar",
    "zupais": "zupar",
    "zupam": "zupar",
    "zupamo": "zupar",
    "zupamos": "zupar",
    "zupando": "zupar",
    "zupara": "zupar",
    "zuparam": "zupar",
    "zuparas": "zupar",
    "zuparde": "zupar",
    "zupardes": "zupar",
    "zupare": "zupar",
    "zuparei": "zupar",
    "zupareis": "zupar",
    "zuparem": "zupar",
    "zuparemos": "zupar",
    "zupares": "zupar",
    "zuparia": "zupar",
    "zupariam": "zupar",
    "zuparias": "zupar",
    "zuparmo": "zupar",
    "zuparmos": "zupar",
    "zupará": "zupar",
    "zuparás": "zupar",
    "zuparão": "zupar",
    "zuparíamos": "zupar",
    "zuparíeis": "zupar",
    "zupas": "zupar",
    "zupasse": "zupar",
    "zupassem": "zupar",
    "zupasses": "zupar",
    "zupaste": "zupar",
    "zupastes": "zupar",
    "zupava": "zupar",
    "zupavam": "zupar",
    "zupavas": "zupar",
    "zupe": "zupar",
    "zupei": "zupar",
    "zupeis": "zupar",
    "zupem": "zupar",
    "zupemo": "zupar",
    "zupemos": "zupar",
    "zupes": "zupar",
    "zupo": "zupar",
    "zupou": "zupar",
    "zupá": "zupar",
    "zupámo": "zupar",
    "zupámos": "zupar",
    "zupáramo": "zupar",
    "zupáramos": "zupar",
    "zupárei": "zupar",
    "zupáreis": "zupar",
    "zupásseis": "zupar",
    "zupássemos": "zupar",
    "zupávamo": "zupar",
    "zupávamos": "zupar",
    "zupávei": "zupar",
    "zupáveis": "zupar",
    "zuque": "zucar",
    "zuquei": "zucar",
    "zuqueis": "zucar",
    "zuquem": "zucar",
    "zuquemo": "zucar",
    "zuquemos": "zucar",
    "zuques": "zucar",
    "zuraques": "zuraque",
    "zurbadas": "zurbada",
    "zurcas": "zurca",
    "zurpas": "zurpa",
    "zurra": "zurrar",
    "zurrada": "zurrar",
    "zurradas": "zurrar",
    "zurrado": "zurrar",
    "zurradora": "zurrador",
    "zurradoras": "zurrador",
    "zurradores": "zurrador",
    "zurrados": "zurrar",
    "zurrai": "zurrar",
    "zurrais": "zurrar",
    "zurram": "zurrar",
    "zurramo": "zurrar",
    "zurramos": "zurrar",
    "zurrando": "zurrar",
    "zurrapas": "zurrapa",
    "zurrara": "zurrar",
    "zurraram": "zurrar",
    "zurraras": "zurrar",
    "zurrardes": "zurrar",
    "zurrarei": "zurrar",
    "zurrareis": "zurrar",
    "zurrarem": "zurrar",
    "zurraremos": "zurrar",
    "zurrares": "zurrar",
    "zurraria": "zurrar",
    "zurrariam": "zurrar",
    "zurrarias": "zurraria",
    "zurrarmo": "zurrar",
    "zurrarmos": "zurrar",
    "zurrará": "zurrar",
    "zurrarás": "zurrar",
    "zurrarão": "zurrar",
    "zurraríamos": "zurrar",
    "zurraríeis": "zurrar",
    "zurras": "zurrar",
    "zurrasse": "zurrar",
    "zurrassem": "zurrar",
    "zurrasses": "zurrar",
    "zurraste": "zurrar",
    "zurrastes": "zurrar",
    "zurrava": "zurrar",
    "zurravam": "zurrar",
    "zurravas": "zurrar",
    "zurre": "zurrar",
    "zurrei": "zurrar",
    "zurreis": "zurrar",
    "zurrem": "zurrar",
    "zurremo": "zurrar",
    "zurremos": "zurrar",
    "zurres": "zurrar",
    "zurro": "zurrar",
    "zurros": "zurro",
    "zurrou": "zurrar",
    "zurrámo": "zurrar",
    "zurrámos": "zurrar",
    "zurráramo": "zurrar",
    "zurráramos": "zurrar",
    "zurráreis": "zurrar",
    "zurrásseis": "zurrar",
    "zurrássemos": "zurrar",
    "zurrávamo": "zurrar",
    "zurrávamos": "zurrar",
    "zurráveis": "zurrar",
    "zurvadas": "zurvada",
    "zurvanadas": "zurvanada",
    "zurza": "zurzir",
    "zurzais": "zurzir",
    "zurzam": "zurzir",
    "zurzamo": "zurzir",
    "zurzamos": "zurzir",
    "zurzas": "zurzir",
    "zurze": "zurzir",
    "zurzem": "zurzir",
    "zurzes": "zurzir",
    "zurzi": "zurzir",
    "zurzia": "zurzir",
    "zurziam": "zurzir",
    "zurzias": "zurzir",
    "zurzida": "zurzir",
    "zurzidas": "zurzir",
    "zurzidelas": "zurzidela",
    "zurzido": "zurzir",
    "zurzidora": "zurzidor",
    "zurzidoras": "zurzidor",
    "zurzidores": "zurzidor",
    "zurzidos": "zurzir",
    "zurzimo": "zurzir",
    "zurzimos": "zurzir",
    "zurzindo": "zurzir",
    "zurzira": "zurzir",
    "zurziram": "zurzir",
    "zurziras": "zurzir",
    "zurzirde": "zurzir",
    "zurzirdes": "zurzir",
    "zurzire": "zurzir",
    "zurzirei": "zurzir",
    "zurzireis": "zurzir",
    "zurzirem": "zurzir",
    "zurziremos": "zurzir",
    "zurzires": "zurzir",
    "zurziria": "zurzir",
    "zurziriam": "zurzir",
    "zurzirias": "zurzir",
    "zurzirmo": "zurzir",
    "zurzirmos": "zurzir",
    "zurzirá": "zurzir",
    "zurzirás": "zurzir",
    "zurzirão": "zurzir",
    "zurziríamos": "zurzir",
    "zurziríeis": "zurzir",
    "zurzis": "zurzir",
    "zurzisse": "zurzir",
    "zurzissem": "zurzir",
    "zurzisses": "zurzir",
    "zurziste": "zurzir",
    "zurzistes": "zurzir",
    "zurziu": "zurzir",
    "zurzo": "zurzir",
    "zurzíamo": "zurzir",
    "zurzíamos": "zurzir",
    "zurzíei": "zurzir",
    "zurzíeis": "zurzir",
    "zurzíramo": "zurzir",
    "zurzíramos": "zurzir",
    "zurzírei": "zurzir",
    "zurzíreis": "zurzir",
    "zurzísseis": "zurzir",
    "zurzíssemos": "zurzir",
    "zuí": "zuir",
    "zuía": "zuir",
    "zuíam": "zuir",
    "zuíamo": "zuir",
    "zuíamos": "zuir",
    "zuías": "zuir",
    "zuída": "zuir",
    "zuídas": "zuir",
    "zuído": "zuir",
    "zuídos": "zuir",
    "zuíei": "zuir",
    "zuíeis": "zuir",
    "zuímo": "zuir",
    "zuímos": "zuir",
    "zuíra": "zuir",
    "zuíram": "zuir",
    "zuíramo": "zuir",
    "zuíramos": "zuir",
    "zuíras": "zuir",
    "zuíre": "zuir",
    "zuírei": "zuir",
    "zuíreis": "zuir",
    "zuírem": "zuir",
    "zuíres": "zuir",
    "zuís": "zuir",
    "zuísse": "zuir",
    "zuísseis": "zuir",
    "zuíssem": "zuir",
    "zuíssemos": "zuir",
    "zuísses": "zuir",
    "zuíste": "zuir",
    "zuístes": "zuir",
    "zz": "z",
    "zápetes": "zápete",
    "zânganos": "zângano",
    "zângãos": "zângão",
    "zântios": "zântio",
    "zânzeres": "zânzere",
    "zãiba": "zãibo",
    "zãibas": "zãibo",
    "zãibos": "zãibo",
    "zécoras": "zécora",
    "zéfiros": "zéfiro",
    "zéidas": "zéida",
    "zénites": "zénite",
    "zés": "zé",
    "zês": "zê",
    "zígnias": "zígnia",
    "zímases": "zímase",
    "zímica": "zímico",
    "zímicas": "zímico",
    "zímicos": "zímico",
    "zíncica": "zíncico",
    "zíncicas": "zíncico",
    "zíncicos": "zíncico",
    "zíngara": "zíngaro",
    "zíngaras": "zíngaro",
    "zíngaros": "zíngaro",
    "zínias": "zínia",
    "zízifos": "zízifo",
    "zóica": "zóico",
    "zóicas": "zóico",
    "zóicos": "zóico",
    "zóides": "zóide",
    "zósteres": "zóster",
    "ábacos": "ábaco",
    "ábdita": "ábdito",
    "ábditas": "ábdito",
    "ábditos": "ábdito",
    "ábia": "ábio",
    "ábias": "ábio",
    "ábios": "ábio",
    "ábregos": "ábrego",
    "ábsides": "ábside",
    "ábsona": "ábsono",
    "ábsonas": "ábsono",
    "ábsonos": "ábsono",
    "ácaros": "ácaro",
    "ácera": "ácero",
    "áceras": "ácero",
    "áceros": "ácero",
    "ácida": "ácido",
    "ácidas": "ácido",
    "ácidos": "ácido",
    "ácinos": "ácino",
    "áclides": "áclide",
    "ácnuas": "ácnua",
    "ácoros": "ácoro",
    "ácratas": "ácrata",
    "ádipes": "ádipe",
    "ádipos": "ádipo",
    "áditos": "ádito",
    "ádvenas": "ádvena",
    "áfia": "áfio",
    "áfias": "áfio",
    "áfida": "áfido",
    "áfidas": "áfido",
    "áfidos": "áfido",
    "áfios": "áfio",
    "áfona": "áfono",
    "áfonas": "áfono",
    "áfonos": "áfono",
    "áfrica": "áfrico",
    "áfricas": "áfrico",
    "áfricos": "áfrico",
    "ágama": "ágamo",
    "ágamas": "ágamo",
    "ágamos": "ágamo",
    "ágapas": "ágapa",
    "ágapes": "ágape",
    "ágares": "ágar",
    "ágatas": "ágata",
    "ágates": "ágate",
    "ágeis": "ágil",
    "ágina": "ágino",
    "áginas": "ágino",
    "áginos": "ágino",
    "ágios": "ágio",
    "ágnata": "ágnato",
    "ágnatas": "ágnato",
    "ágnatos": "ágnato",
    "ágona": "ágono",
    "ágonas": "ágono",
    "ágonos": "ágono",
    "ágoras": "ágora",
    "ágrafa": "ágrafo",
    "ágrafas": "ágrafo",
    "ágrafos": "ágrafo",
    "águabresas": "águabresa",
    "águas": "água",
    "águias": "águia",
    "águilas": "águila",
    "álacres": "álacre",
    "álala": "álalo",
    "álalas": "álalo",
    "álalos": "álalo",
    "álamos": "álamo",
    "álbuns": "álbum",
    "álcalis": "álcali",
    "álceas": "álcea",
    "álcidas": "álcida",
    "álcoois": "álcool",
    "áleas": "álea",
    "álgebras": "álgebra",
    "álgica": "álgico",
    "álgicas": "álgico",
    "álgicos": "álgico",
    "álgida": "álgido",
    "álgidas": "álgido",
    "álgidos": "álgido",
    "álibis": "álibi",
    "álicas": "álica",
    "álticas": "áltica",
    "álulas": "álula",
    "álveos": "álveo",
    "álvidros": "álvidro",
    "ápices": "ápice",
    "ápira": "ápiro",
    "ápiras": "ápiro",
    "ápiros": "ápiro",
    "ápocas": "ápoca",
    "ápoda": "ápodo",
    "ápodas": "ápodo",
    "ápodes": "ápode",
    "ápodos": "ápodo",
    "ápora": "áporo",
    "áporas": "áporo",
    "áporos": "áporo",
    "ápsides": "ápside",
    "áptera": "áptero",
    "ápteras": "áptero",
    "ápteros": "áptero",
    "áptica": "áptico",
    "ápticas": "áptico",
    "ápticos": "áptico",
    "áquea": "áqueo",
    "áqueas": "áqueo",
    "áqueos": "áqueo",
    "árabes": "árabe",
    "árbitra": "árbitro",
    "árbitras": "árbitro",
    "árbitros": "árbitro",
    "árcades": "árcade",
    "árctica": "árctico",
    "árcticas": "árctico",
    "árcticos": "árctico",
    "árdua": "árduo",
    "árduas": "árduo",
    "árduos": "árduo",
    "áreas": "área",
    "árias": "ária",
    "árica": "árico",
    "áricas": "árico",
    "áricos": "árico",
    "árida": "árido",
    "áridas": "árido",
    "áridos": "árido",
    "árulas": "árula",
    "árvores": "árvore",
    "ásaros": "ásaro",
    "áscela": "áscelo",
    "áscelas": "áscelo",
    "ásceles": "áscele",
    "áscelos": "áscelo",
    "áscia": "áscio",
    "áscias": "áscio",
    "áscios": "áscio",
    "áscoas": "áscoa",
    "áscones": "áscon",
    "áscons": "áscon",
    "áscuas": "áscua",
    "áses": "ás",
    "áspera": "áspero",
    "ásperas": "áspero",
    "ásperos": "áspero",
    "áspides": "áspide",
    "ástatos": "ástato",
    "ásteres": "áster",
    "ástoma": "ástomo",
    "ástomas": "ástomo",
    "ástomos": "ástomo",
    "ástria": "ástrio",
    "ástrias": "ástrio",
    "ástrios": "ástrio",
    "ástures": "ásture",
    "ática": "ático",
    "áticas": "ático",
    "áticos": "ático",
    "átimos": "átimo",
    "átomos": "átomo",
    "átona": "átono",
    "átonas": "átono",
    "átonos": "átono",
    "átrios": "átrio",
    "átropa": "átropo",
    "átropas": "átropo",
    "átropos": "átropo",
    "áudios": "áudio",
    "áuguratriz": "áugure",
    "áuguratrizes": "áugure",
    "áugures": "áugure",
    "áulica": "áulico",
    "áulicas": "áulico",
    "áulicos": "áulico",
    "áurea": "áureo",
    "áureas": "áureo",
    "áureos": "áureo",
    "ávida": "ávido",
    "ávidas": "ávido",
    "ávidos": "ávido",
    "ávilas": "ávila",
    "áxiis": "áxil",
    "áxila": "áxilo",
    "áxilas": "áxilo",
    "áxilos": "áxilo",
    "ázima": "ázimo",
    "ázimas": "ázimo",
    "ázimos": "ázimo",
    "âmagos": "âmago",
    "âmbares": "âmbar",
    "âmbitos": "âmbito",
    "âmbulas": "âmbula",
    "âmnios": "âmnio",
    "âncoras": "âncora",
    "ânditos": "ândito",
    "ânforas": "ânfora",
    "ânglica": "ânglico",
    "ânglicas": "ânglico",
    "ânglicos": "ânglico",
    "ângulos": "ângulo",
    "ânimos": "ânimo",
    "ânodos": "ânodo",
    "ânsias": "ânsia",
    "ântina": "ântino",
    "ântinas": "ântino",
    "ântinos": "ântino",
    "ânua": "ânuo",
    "ânuas": "ânuo",
    "ânula": "ânulo",
    "ânulas": "ânulo",
    "ânulos": "ânulo",
    "ânuos": "ânuo",
    "é": "ser",
    "ébanos": "ébano",
    "ébenos": "ébeno",
    "ébria": "ébrio",
    "ébrias": "ébrio",
    "ébrios": "ébrio",
    "ébulos": "ébulo",
    "écforas": "écfora",
    "éclogas": "écloga",
    "écrans": "écran",
    "éctases": "éctase",
    "éculos": "éculo",
    "édens": "éden",
    "édipos": "édipo",
    "éditos": "édito",
    "édredons": "édredon",
    "éforos": "éforo",
    "égides": "égide",
    "églogas": "égloga",
    "égrios": "égrio",
    "éguas": "égua",
    "élans": "élan",
    "élitros": "élitro",
    "émula": "émulo",
    "émulas": "émulo",
    "émulos": "émulo",
    "énea": "éneo",
    "éneas": "éneo",
    "éneos": "éneo",
    "énidra": "énidro",
    "énidras": "énidro",
    "énidros": "énidro",
    "énulas": "énula",
    "énuplas": "énupla",
    "éolos": "éolo",
    "épica": "épico",
    "épicas": "épico",
    "épicos": "épico",
    "épocas": "época",
    "épsilones": "épsilon",
    "épsilos": "épsilo",
    "épsilões": "épsilão",
    "équa": "équo",
    "équas": "équo",
    "équidas": "équida",
    "équos": "équo",
    "éramo": "ser",
    "éramos": "ser",
    "érbios": "érbio",
    "érea": "éreo",
    "éreas": "éreo",
    "érei": "ser",
    "éreis": "ser",
    "éreos": "éreo",
    "és": "ser",
    "ésipos": "ésipo",
    "ésteres": "éster",
    "ésulas": "ésula",
    "éteres": "éter",
    "ética": "ético",
    "éticas": "ético",
    "éticos": "ético",
    "étimos": "étimo",
    "étnica": "étnico",
    "étnicas": "étnico",
    "étnicos": "étnico",
    "êideres": "êider",
    "êmbolos": "êmbolo",
    "ênclises": "ênclise",
    "ênduas": "êndua",
    "ênfases": "ênfase",
    "ênteros": "êntero",
    "êrvedos": "êrvedo",
    "êrvodos": "êrvodo",
    "êuclases": "êuclase",
    "êufona": "êufono",
    "êufonas": "êufono",
    "êufonos": "êufono",
    "êugrafos": "êugrafo",
    "êuscara": "êuscaro",
    "êuscaras": "êuscaro",
    "êuscaros": "êuscaro",
    "êxcetras": "êxcetra",
    "êxedras": "êxedra",
    "êxitos": "êxito",
    "êxodos": "êxodo",
    "êxtases": "êxtase",
    "íamo": "ir",
    "íamos": "ir",
    "ícaros": "ícaro",
    "ícones": "ícone",
    "ídolas": "ídola",
    "ídolos": "ídolo",
    "íei": "ir",
    "íeis": "ir",
    "ígnea": "ígneo",
    "ígneas": "ígneo",
    "ígneos": "ígneo",
    "íleos": "íleo",
    "ília": "ílio",
    "ílias": "ílio",
    "ílions": "ílion",
    "ílios": "ílio",
    "ímans": "íman",
    "ímpares": "ímpar",
    "ímpetos": "ímpeto",
    "ímpia": "ímpio",
    "ímpias": "ímpio",
    "ímpios": "ímpio",
    "ímproba": "ímprobo",
    "ímprobas": "ímprobo",
    "ímprobos": "ímprobo",
    "ínclita": "ínclito",
    "ínclitas": "ínclito",
    "ínclitos": "ínclito",
    "íncolas": "íncola",
    "íncuba": "íncubo",
    "íncubas": "íncubo",
    "íncubos": "íncubo",
    "índia": "índio",
    "índias": "índio",
    "índica": "índico",
    "índicas": "índico",
    "índices": "índice",
    "índicos": "índico",
    "índigos": "índigo",
    "índios": "índio",
    "índoles": "índole",
    "índuas": "índua",
    "ínfima": "ínfimo",
    "ínfimas": "ínfimo",
    "ínfimos": "ínfimo",
    "íngremes": "íngreme",
    "ínguas": "íngua",
    "ínios": "ínio",
    "ínscia": "ínscio",
    "ínscias": "ínscio",
    "ínscios": "ínscio",
    "ínsita": "ínsito",
    "ínsitas": "ínsito",
    "ínsitos": "ínsito",
    "ínsuas": "ínsua",
    "ínsulas": "ínsula",
    "íntegra": "íntegro",
    "íntegras": "íntegro",
    "íntegros": "íntegro",
    "ínterins": "ínterim",
    "íntima": "íntimo",
    "íntimas": "íntimo",
    "íntimos": "íntimo",
    "ínuba": "ínubo",
    "ínubas": "ínubo",
    "ínubos": "ínubo",
    "ínvia": "ínvio",
    "ínvias": "ínvio",
    "ínvios": "ínvio",
    "ípsilons": "ípsilon",
    "ípsilos": "ípsilo",
    "írrita": "írrito",
    "írritas": "írrito",
    "írritos": "írrito",
    "ísquions": "ísquion",
    "ísquios": "ísquio",
    "ístmica": "ístmico",
    "ístmicas": "ístmico",
    "ístmicos": "ístmico",
    "ítala": "ítalo",
    "ítalas": "ítalo",
    "ítalos": "ítalo",
    "ítrios": "ítrio",
    "óbelos": "óbelo",
    "óbices": "óbice",
    "óbitos": "óbito",
    "óbolos": "óbolo",
    "óbvia": "óbvio",
    "óbvias": "óbvio",
    "óbvios": "óbvio",
    "ócciputes": "ócciput",
    "ócios": "ócio",
    "óctupla": "óctuplo",
    "óctuplo": "oito",
    "óctuplos": "óctuplo",
    "óculos": "óculo",
    "ódios": "ódio",
    "óleos": "óleo",
    "ómegas": "ómega",
    "ómicrons": "ómicron",
    "ómicros": "ómicro",
    "ónagros": "ónagro",
    "ópalos": "ópalo",
    "óperas": "ópera",
    "ópidos": "ópido",
    "ópios": "ópio",
    "óptica": "óptico",
    "ópticas": "óptico",
    "ópticos": "óptico",
    "óptima": "bom",
    "óptimas": "bom",
    "óptimo": "bom",
    "óptimos": "bom",
    "órbitas": "órbita",
    "órfica": "órfico",
    "órficas": "órfico",
    "órficos": "órfico",
    "órfã": "órfão",
    "órfãos": "órfão",
    "órfãs": "órfão",
    "órgãos": "órgão",
    "órobos": "órobo",
    "ós": "ó",
    "óscares": "óscar",
    "ósculos": "ósculo",
    "ósmica": "ósmico",
    "ósmicas": "ósmico",
    "ósmicos": "ósmico",
    "ósmios": "ósmio",
    "óssea": "ósseo",
    "ósseas": "ósseo",
    "ósseos": "ósseo",
    "ótica": "ótico",
    "óticas": "ótico",
    "óticos": "ótico",
    "óvalos": "óvalo",
    "óvea": "óveo",
    "óveas": "óveo",
    "óveos": "óveo",
    "óvnis": "óvni",
    "óvulos": "óvulo",
    "óxidos": "óxido",
    "ôndulas": "ôndula",
    "ôntica": "ôntico",
    "ônticas": "ôntico",
    "ônticos": "ôntico",
    "úberes": "úbere",
    "úlceras": "úlcera",
    "úlmica": "úlmico",
    "úlmicas": "úlmico",
    "úlmicos": "úlmico",
    "última": "último",
    "últimas": "último",
    "últimos": "último",
    "úmbrica": "úmbrico",
    "úmbricas": "úmbrico",
    "úmbricos": "úmbrico",
    "úmbrios": "úmbrio",
    "úmeros": "úmero",
    "única": "único",
    "únicas": "único",
    "únicos": "único",
    "úrica": "úrico",
    "úricas": "úrico",
    "úricos": "úrico",
    "úrnulas": "úrnula",
    "úsneas": "úsnea",
    "ústias": "ústia",
    "úteis": "útil",
    "úteros": "útero",
    "úvica": "úvico",
    "úvicas": "úvico",
    "úvicos": "úvico",
    "úvida": "úvido",
    "úvidas": "úvido",
    "úvidos": "úvido",
    "úvulas": "úvula"
}
